

(*Title : Biokinetic  data *)

(* : Author : Guillermo Sanchez*)

(* : Summary : 
      Here are included the biokinetic data for some isotopes included in 
ICRP 78. It is a part of Humorap  *)

(* : Context : `Biokdata`*)

(* : Package Version : 1.2*)

(* : Copyright : Copyright 2004, 
  Guillermo Sanchez.guillerm@usal.es or gsl@fab.enusa.es*)

(* : History :  Ver 1.0, April 2003, Ver 1.1, July 2003, Ver 1.2 January 2004*)

(* : Keywords : Compartmental Models, ICRP 66, ICRP78*)

(* : Sources : ICRP 78,The ICRP Database of Dose Coefficients: workers and 
members of the public*)

(* : Mathematica Version : 4.2*)

BeginPackage["Biokmod`Biokdata`", "Biokmod`Humorap3`", "Biokmod`Resptract`", "Biokmod`Master`", "Biokmod`SysModel`"]

CompartNumbers::usage = "CompartNumbers[element] gives for element the number 
of the compartments used in the transfer rate constants."; 

compartMatrix::usage = "compartMatrix[element] gives for element the 
compartmental matrix using the applicable ICRP model. If the element has 
reciclied throw SI mush be used compartMatrixE"; 

compartMatrixE::usage = "compartMatrixE[element] gives for element the 
compartmental matrix using the applicable ICRP model adding the GI Tract"; 

TransferRates::usage = "TransferRates[element] gives for element the transfer 
rate constants for adult workers for biokinetic model defined in ICRP"; 

TransferRatesE::usage = "TransferRatesE[element] gives for element the 
transfer rate constants for adult workers for biokinetic model defined in 
ICRP, including GI tract rates"; 

ElementICRP = {caesium, cobalt, iodine, uranium}; 

((MessageName[#1, "usage"] = StringJoin[ToString[#1], 
      " is a chemical element included in ICRP Models."]) & ) /@ ElementICRP; 

Unknown::usage = "Unknown or non included isotope. Check that the name of 
isotope are in small letters. Data about non included isotopes can be obtain 
of CD-ROM: The ICRP Database of Dose Coefficients: workers and members of the 
public\[RightGuillemet] Elsevier Science Ltd."; 

BiokdataReport::usage="BiokdataReport[element,intakeway, intaketype, report, int,  ifd (default AMAD5), fra(default F), 
fin1,  t1, lambda, options]";

SSEU238::usage ="SEE factor for U238";
SSEU235::usage ="SEE factor for U235";
SSEU234::usage ="SEE factor for U234";


Options[BiokdataReport] = {CompartNumbers -> "False", TransferRates-> "False"};

Begin["`Private`"]

CompartNumbers[name_Symbol] := (Message[CompartNumbers::unknown, name]; "Unknown 
or non included isotope. Check that the name of isotope are in small 
letters. Non included isotopes data can be obtained of CD-ROM: <<The ICRP 
Database of Dose Coefficients: workers and members of the public\[RightGuillemet] Elsevier 
Science Ltd>>.")

compartMatrix[name_Symbol] := (Message[compartMatrix::unknown, name]; "Unknown
or non included isotope. Check that the name of isotope are in small 
letters. Non included isotopes data can be obtained of CD-ROM: <<The ICRP 
Database of Dose Coefficients: workers and members of the public\[RightGuillemet] Elsevier 
Science Ltd>>."); 

compartMatrixE[name_Symbol] := (Message[compartMatrixE::unknown, name]; "Unknown or 
non included isotope. Check that the name of isotope are in small 
letters. Non included isotopes data can be obtained of CD-ROM: <<The ICRP 
Database of Dose Coefficients: workers and members of the public\[RightGuillemet] Elsevier 
Science Ltd>>."); 

TransferRates[name_Symbol] := (Message[TransferRates::unknown, name]; "Unknow
n or non included isotope. Check that the name of isotope are in small 
letters. Non included isotopes data can be obtained of CD-ROM: <<The ICRP 
Database of Dose Coefficients: workers and members of the public\[RightGuillemet] Elsevier 
Science Ltd>>."); 

TransferRatesE[name_Symbol] := (Message[TransferRatesE::unknown, name]; "Unknown or non included isotope. Check that the name of isotope are in small
letters. Non included isotopes data can be obtained of CD-ROM: <<The ICRP 
Database of Dose Coefficients: workers and members of the public\[RightGuillemet] Elsevier 
Science Ltd>>."); 


CompartNumbers[uranium] ^= TableForm[{{1, "Plasma"}, {2, "RBC"}, {3, "ST0"}, 
     {4, "ST1"}, {5, "ST2"}, {6, "Liver1"}, {7, "Liver2"}, 
     {8, "UrinaryPath"}, {9, "OtherKidney"}, {10, "TrabecularSurface"}, 
     {11, "ExchTrabVol"}, {12, "NonExchTrabVol"}, {13, "CorticalSurf"}, 
     {14, "CorticalVolExch"}, {15, "CorticalVolNonExch"}, {16, "Bladder"}, 
     {17, "Urine"}, {18, "ULI"}, {19, "LLI"}, {20, "FEC"}, {21, "SI"}, 
     {22, "ST"}}]; 

CompartNumbers[iodine] ^= TableForm[{{1, "Blood"}, {2, "Thyroid"}, 
     {3, "Rest"}, {4, "Bladder"}, {5, "Urine"}, {6, "ULI"}, {7, "LLI"}, 
     {8, "FEC"}}]; 

CompartNumbers[caesium] ^= TableForm[{{1, "Blood"}, {2, "Systemic A"}, 
     {3, "Systemic B"}, {4, "Bladder"}, {5, "Urine"}, {6, "ULI"}, {7, "LLI"}, 
     {8, "FEC"}}]; 

icrp30Number3 = TableForm[{{1,"Blood"},{2,"Systemic A"},{3,"Systemic B"},{4,
"Systemic C"},{5,"Bladder"},{6,"Urine"},{7,"ULI"},{8,"LLI"},{9,"FEC"}}];

CompartNumbers[cobalt]^= icrp30Number3;


TransferRates[iodine] ^= {{1, 2, 0.3*(Log[2]/0.25)}, 
    {1, 4, 0.7*(Log[2]/0.25)}, {2, 3, Log[2]/80}, {3, 6, (Log[2]/12)*0.2}, 
    {3, 1, (Log[2]/12)*0.8}, {4, 5, 12}, {6, 7, Subscript[k, ULI]}, 
    {7, 8, Subscript[k, LLI]}}; 

compartMatrix[iodine] ^= CompartMatrix[8, TransferRates[iodine]]; 

TransferRates[caesium] ^= {{1, 2, 0.27726}, {1, 3, 2.49533}, {2, 4, 0.2768}, 
    {2, 6, 0.0692}, {3, 4, 0.00504}, {3, 6, 0.00126}, {4, 5, 12}, 
    {6, 7, Subscript[k, ULI]}, {7, 8, Subscript[k, LLI]}}; 

compartMatrix[caesium] ^= CompartMatrix[8, TransferRates[caesium]]; 

TransferRates[uranium] ^= {{1, 3, 10.5}, {1, 2, 0.245}, {1, 16, 15.43}, 
    {1, 8, 2.94}, {1, 9, 0.0122}, {1, 18, 0.122}, {1, 6, 0.367}, 
    {1, 4, 1.63}, {1, 5, 0.0735}, {1, 10, 2.04}, {1, 13, 1.63}, {3, 1, 8.32}, 
    {2, 1, 0.347}, {8, 16, 0.099}, {9, 1, 0.00038}, {6, 1, 0.092}, 
    {6, 7, 0.00693}, {4, 1, 0.0347}, {5, 1, 0.000019}, {13, 1, 0.0693}, 
    {13, 14, 0.0693}, {7, 1, 0.00019}, {11, 12, 0.00578}, {12, 1, 0.000493}, 
    {15, 1, 0.0000821}, {14, 13, 0.0173}, {14, 15, 0.00578}, {10, 1, 0.0693}, 
    {11, 10, 0.0173}, {10, 11, 0.0693}, {16, 17, 12}, 
    {18, 19, Subscript[k, ULI]}, {19, 20, Subscript[k, LLI]}}; 

compartMatrix[uranium] ^= CompartMatrix[20, TransferRates[uranium]]; 

TransferRatesE[uranium] ^= {{1, 3, 10.5}, {1, 2, 0.245}, {1, 16, 15.43}, 
    {1, 8, 2.94}, {1, 9, 0.0122}, {1, 18, 0.122}, {1, 6, 0.367}, 
    {1, 4, 1.63}, {1, 5, 0.0735}, {1, 10, 2.04}, {1, 13, 1.63}, {3, 1, 8.32}, 
    {2, 1, 0.347}, {8, 16, 0.099}, {9, 1, 0.00038}, {6, 1, 0.092}, 
    {6, 7, 0.00693}, {4, 1, 0.0347}, {5, 1, 0.000019}, {13, 1, 0.0693}, 
    {13, 14, 0.0693}, {7, 1, 0.00019}, {11, 12, 0.00578}, {12, 1, 0.000493}, 
    {15, 1, 0.0000821}, {14, 13, 0.0173}, {14, 15, 0.00578}, {10, 1, 0.0693}, 
    {11, 10, 0.0173}, {10, 11, 0.0693}, {16, 17, 12}, 
    {18, 19, Subscript[k, ULI]}, {19, 20, Subscript[k, LLI]}, 
    {21, 1, Subscript[f, B]*Subscript[k, SI]}, {21, 18, Subscript[k, SI]}, 
    {22, 21, Subscript[k, ST]}}; 

compartMatrixE[uranium] ^= CompartMatrix[22, TransferRatesE[uranium]]; 


TransferRates[cobalt] ^= {{1, 2, 0.4158883083359672}, {1, 3, 0.13862943611198905}, {1, 4, 0.13862943611198905}, 
  {1, 5, 0.5941261547656673}, {1, 7, 0.09902102579427789}, {2, 5, Log[2]/7}, {3, 5, Log[2]/70}, 
  {4, 5, (3*Log[2])/2800}, {2, 7, Log[2]/42}, {3, 7, Log[2]/420}, {4, 7, Log[2]/5600}, 
  {5, 6, 12}, {7, 8, Subscript[k, ULI]}, {8, 9, Subscript[k, LLI]}}; 
     

compartMatrix[cobalt] ^= CompartMatrix[9, TransferRates[cobalt]]; 

TransferRatesE[lead] ^= {{1, 2, 28.00}, {1, 17, 
  1.750}, {1, 19, 0.7}, {1, 9, 
    4.86}, {1, 6, 3.89}, {1, 12, 4.9}, {1, 14, 2.45}, {1, 15, 0.0245}, {1, 3, 
      22.16}, {1, 4, 0.7}, {1, 5, 0.14}, {1, 16, 0.42}, {2, 1, 0.139}, {6, 1, 
    0.5}, {9, 1, 0.5}, {6, 7, 0.5}, {9, 10, 0.5}, {7, 6, 0.0185}, {
    10, 9, 0.0185}, {7, 8, 0.0046}, {10, 11, 0.0046}, {11, 1, 
    0.000493}, {8, 1, 0.00008210}, {12, 1, 0.03120}, {12, 22, 
    0.03210}, {12, 13, 0.006930}, {13, 1, 0.0019}, {14, 17, 
    0.139}, {15, 1, 0.0019}, {
    3, 1, 7.39}, {4, 1, 0.00416}, {4, 21, 0.00277}, {5, 1,
     0.00038}, {17, 18, 12}, {19, 20, Subscript[k, ULI]}, {20, 21, 
    Subscript[k, LLI]}, {22, 1, Subscript[f, B]*Subscript[k, SI]}, {22, 19,
     Subscript[k, SI]}, {23, 22, Subscript[k, ST]}};

compartMatrixE[lead] ^= CompartMatrix[23, TransferRatesE[lead]];

(*Added in version 1.2*)

icrp30Model1[{fu_,ff_,ti_List,fi_List,TB_}]:=
Module[{a,fR,h,n,i,k1},a=Log[2]/ti;fR=1-Plus@@fi;
n=Length[ti];
h=Flatten[{{fi,fR*fu,fR*ff}*(Log[2]/TB),{fu*a,ff*a},
{12,Subscript[k,ULI],Subscript[k,LLI]}}];
k1=Flatten[{Table[{1,1+i},{i,n+1}],{{1,n+4}},Table[{1+i,2+n},{i,n}],
Table[{1+i,2+n+2},{i,n}],{{n+2,n+3}},{{n+4,n+5}},{{n+5,n+6}}},1];
Transpose[Append[Transpose[k1],h]]];

(* Elements with three systemic comparments *)
(*ICRP 78*)




(*Injection*)

BiokdataReport[element_, intway_, opt1_, opt2_, int_, fin1_, t1_, lambda_, 
options___Rule] /; "Injection" === intway := 
   With[{m = {CompartNumbers, TransferRates} /. Flatten[{options}] /. 
       Options[BiokdataReport]}, 
    If[element === lead || element === thorium || element === neptunium || 
       element === plutonium || element === americium || 
       element === curium || element === iron || element === radium, 
      {BioassayReportE[compartMatrixE[element], int, fin1, t1, lambda, 
        IntakeWay -> "Injection", IntakeType -> opt1, ShowReport -> opt2, 
        options], {"Compart numbers" -> CompartNumbers[element]}, 
       {"Transfer Rates" -> TableForm[TransferRatesE[element], 
          TableHeadings -> {None, {"From", "to", 
             "Tranfer Rates(\!\(days\^\(-1\)\))"}}]}}, 
      {BioassayReport[compartMatrix[element], int, t1, lambda, 
        IntakeWay -> "Injection", IntakeType -> opt1, ShowReport -> opt2, 
        options], {"Compart numbers" -> CompartNumbers[element]}, 
       {"Transfer Rates" -> TableForm[TransferRates[element], 
          TableHeadings -> {None, {"From", "to", 
             "Tranfer Rates(\!\(days\^\(-1\)\))"}}]}}] /; 
     m === {"True", "True"}]; 

BiokdataReport[element_, intway_, opt1_, opt2_, int_, 
     fin1_, t1_, lambda_, options___Rule] /; "Injection" === intway := 
   With[{m = {CompartNumbers, TransferRates} /. Flatten[{options}] /. 
       Options[BiokdataReport]}, 
    If[element === lead || element === thorium || element === neptunium || 
       element === plutonium || element === americium || 
       element === curium || element === iron || element === radium, 
      BioassayReportE[compartMatrixE[element], int, fin1, t1, lambda, 
       IntakeWay -> "Injection", IntakeType -> opt1, ShowReport -> opt2, 
       options], BioassayReport[compartMatrix[element], int, t1, lambda, 
       IntakeWay -> "Injection", IntakeType -> opt1, ShowReport -> opt2, 
       options]] /; m === {"False", "False"}]; 

BiokdataReport[element_, intway_, opt1_, opt2_, int_, ifd_, fra_, 
     fin1_, t1_, lambda_, options___Rule] /; "Injection" === intway := 
   With[{m = {CompartNumbers, TransferRates} /. Flatten[{options}] /. 
       Options[BiokdataReport]}, 
    If[element === lead || element === thorium || element === neptunium || 
       element === plutonium || element === americium || 
       element === curium || element === iron || element === radium, 
      {BioassayReportE[compartMatrixE[element], int, fin1, t1, lambda, 
        IntakeWay -> "Injection", IntakeType -> opt1, ShowReport -> opt2, 
        options], {"Compart numbers" -> CompartNumbers[element]}, 
       {"Transfer Rates" -> TableForm[TransferRatesE[element], 
          TableHeadings -> {None, {"From", "to", 
             "Tranfer Rates(\!\(days\^\(-1\)\))"}}]}}, 
      {BioassayReport[compartMatrix[element], int, t1, lambda, 
        IntakeWay -> "Injection", IntakeType -> opt1, ShowReport -> opt2, 
        options], {"Compart numbers" -> CompartNumbers[element]}, 
       {"Transfer Rates" -> TableForm[TransferRates[element], 
          TableHeadings -> {None, {"From", "to", 
             "Tranfer Rates(\!\(days\^\(-1\)\))"}}]}}] /; 
     m === {"True", "True"}]; 

BiokdataReport[element_, intway_, opt1_, opt2_, int_, ifd_, fra_, 
     fin1_, t1_, lambda_, options___Rule] /; "Injection" === intway := 
   With[{m = {CompartNumbers, TransferRates} /. Flatten[{options}] /. 
       Options[BiokdataReport]}, 
    If[element === lead || element === thorium || element === neptunium || 
       element === plutonium || element === americium || 
       element === curium || element === iron || element === radium, 
      BioassayReportE[compartMatrixE[element], int, fin1, t1, lambda, 
       IntakeWay -> "Injection", IntakeType -> opt1, ShowReport -> opt2, 
       options], BioassayReport[compartMatrix[element], int, t1, lambda, 
       IntakeWay -> "Injection", IntakeType -> opt1, ShowReport -> opt2, 
       options]] /; m === {"False", "False"}]; 

(*Ingestion*)

BiokdataReport[element_, intway_, opt1_, opt2_, int_, fin1_, t1_, lambda_, 
     options___Rule] /; "Ingestion" === intway := 
   With[{m = {CompartNumbers, TransferRates} /. Flatten[{options}] /. 
       Options[BiokdataReport]}, If[element === lead || element === thorium || 
       element === neptunium || element === plutonium || element === americium || 
       element === curium || element === iron || element === radium, 
      {BioassayReportE[compartMatrixE[element], int, fin1, t1, lambda, 
        IntakeWay -> "Ingestion", IntakeType -> opt1, ShowReport -> opt2, options], 
       {"Compart numbers" -> CompartNumbers[element]}, 
       {"Transfer Rates" -> TableForm[TransferRatesE[element], TableHeadings -> 
           {None, {"From", "to", "Tranfer Rates(\!\(days\^\(-1\)\))"}}]}}, 
      {BioassayReport[compartMatrix[element], int, fin1, t1, lambda, 
        IntakeWay -> "Ingestion", IntakeType -> opt1, ShowReport -> opt2, options], 
       {"Compart numbers" -> CompartNumbers[element]}, 
       {"Transfer Rates" -> TableForm[TransferRates[element], TableHeadings -> 
           {None, {"From", "to", "Tranfer Rates(\!\(days\^\(-1\)\))"}}]}}] /; 
     m === {"True", "True"}]; 

BiokdataReport[element_, intway_, opt1_, opt2_, int_, fin1_, t1_, 
lambda_, options___Rule] /; "Ingestion" === intway := 
   With[{m = {CompartNumbers, TransferRates} /. Flatten[{options}] /. 
       Options[BiokdataReport]}, 
    If[element === lead || element === thorium || element === neptunium || 
       element === plutonium || element === americium || 
       element === curium || element === iron || element === radium, 
      BioassayReportE[compartMatrixE[element], int, fin1, t1, lambda, 
       IntakeWay -> "Ingestion", IntakeType -> opt1, ShowReport -> opt2, 
       options], BioassayReport[compartMatrix[element], int, fin1, t1, lambda, 
       IntakeWay -> "Ingestion", IntakeType -> opt1, ShowReport -> opt2, 
       options]] /; m === {"False", "False"}]; 

BiokdataReport[element_, intway_, opt1_, opt2_, int_, ifd_, fra_, 
     fin1_, t1_, lambda_, options___Rule] /; "Ingestion" === intway := 
   With[{m = {CompartNumbers, TransferRates} /. Flatten[{options}] /. 
       Options[BiokdataReport]}, 
    If[element === lead || element === thorium || element === neptunium || 
       element === plutonium || element === americium || 
       element === curium || element === iron || element === radium, 
      {BioassayReportE[compartMatrixE[element], int, fin1, t1, lambda, 
        IntakeWay -> "Ingestion", IntakeType -> opt1, ShowReport -> opt2, 
        options], {"Compart numbers" -> CompartNumbers[element]}, 
       {"Transfer Rates" -> TableForm[TransferRatesE[element], 
          TableHeadings -> {None, {"From", "to", 
             "Tranfer Rates(\!\(days\^\(-1\)\))"}}]}}, 
      {BioassayReport[compartMatrix[element], int, fin1, t1, lambda, 
        IntakeWay -> "Ingestion", IntakeType -> opt1, ShowReport -> opt2, 
        options], {"Compart numbers" -> CompartNumbers[element]}, 
       {"Transfer Rates" -> TableForm[TransferRates[element], 
          TableHeadings -> {None, {"From", "to", 
             "Tranfer Rates(\!\(days\^\(-1\)\))"}}]}}] /; 
     m === {"True", "True"}]; 

BiokdataReport[element_, intway_, opt1_, opt2_, int_, ifd_, fra_, 
     fin1_, t1_, lambda_, options___Rule] /; "Ingestion" === intway := 
   With[{m = {CompartNumbers, TransferRates} /. Flatten[{options}] /. 
       Options[BiokdataReport]}, 
    If[element === lead || element === thorium || element === neptunium || 
       element === plutonium || element === americium || 
       element === curium || element === iron || element === radium, 
      BioassayReportE[compartMatrixE[element], int, fin1, t1, lambda, 
       IntakeWay -> "Ingestion", IntakeType -> opt1, ShowReport -> opt2, 
       options], BioassayReport[compartMatrix[element], int, fin1, t1, lambda, 
       IntakeWay -> "Ingestion", IntakeType -> opt1, ShowReport -> opt2, 
       options]] /; m === {"False", "False"}]; 

(*Inhalation*)

BiokdataReport[element_, intway_, opt1_, opt2_, int_, ifd_, fra_, 
     fin1_, t1_, lambda_, options___Rule] /; "Inhalation" === intway := 
   With[{m = {CompartNumbers, TransferRates} /. Flatten[{options}] /. 
       Options[BiokdataReport]}, 
    If[element === lead || element === thorium || element === neptunium || 
       element === plutonium || element === americium || 
       element === curium || element === iron || element === radium, 
      {BioassayReportE[compartMatrixE[element], int, ifd, fra, fin1, t1, lambda, 
        IntakeWay -> "Inhalation", IntakeType -> opt1, ShowReport -> opt2, 
        options], {"Compart numbers" -> CompartNumbers[element]}, 
       {"Transfer Rates" -> TableForm[TransferRatesE[element], 
          TableHeadings -> {None, {"From", "to", 
             "Tranfer Rates(\!\(days\^\(-1\)\))"}}]}}, 
      {BioassayReport[compartMatrix[element], int, ifd, fra, fin1, t1, lambda, 
        IntakeWay -> "Inhalation", IntakeType -> opt1, ShowReport -> opt2, 
        options], {"Compart numbers" -> CompartNumbers[element]}, 
       {"Transfer Rates" -> TableForm[TransferRates[element], 
          TableHeadings -> {None, {"From", "to", 
             "Tranfer Rates(\!\(days\^\(-1\)\))"}}]}}] /; 
     m === {"True", "True"}]; 

BiokdataReport[element_, intway_, opt1_, opt2_, int_, ifd_, fra_, 
     fin1_, t1_, lambda_, options___Rule] /; "Inhalation" === intway := 
   With[{m = {CompartNumbers, TransferRates} /. Flatten[{options}] /. 
       Options[BiokdataReport]}, 
    If[element === lead || element === thorium || element === neptunium || 
       element === plutonium || element === americium || 
       element === curium || element === iron || element === radium, 
      BioassayReportE[compartMatrixE[element], int,ifd, fra,  fin1, t1, lambda, 
       IntakeWay -> "Inhalation", IntakeType -> opt1, ShowReport -> opt2, 
       options], BioassayReport[compartMatrix[element], int, ifd, fra, fin1, t1, lambda, 
       IntakeWay -> "Inhalation", IntakeType -> opt1, ShowReport -> opt2, 
       options]] /; m === {"False", "False"}]; 


SSEU238={{"Colon",3.43*10^-19,2.84*10^-18,2.84*10^-18,2.84*10^-18,2.84*10^-18,
        2.84*10^-18,2.84*10^-18,2.84*10^-18,2.84*10^-18,3.43*10^-19,
        3.43*10^-19,3.43*10^-19,.0000000000002,.000000000000216,2.17*10^-17,
        2.6*10^-17,3.42*10^-17,3.42*10^-17,1.19*10^-17,1.19*10^-17,
        6.28*10^-17,.000000000000359,.000000000000177,2.51*10^-16,
        3.64*10^-17},{"Oesophagus",3.16*10^-17,5.58*10^-17,5.58*10^-17,
        5.58*10^-17,5.58*10^-17,5.58*10^-17,5.58*10^-17,5.58*10^-17,
        5.58*10^-17,3.16*10^-17,3.16*10^-17,
        3.16*10^-17,.0000000000002,.000000000000216,1.2*10^-17,4.23*10^-18,
        1.74*10^-17,1.74*10^-17,1.01*10^-17,1.01*10^-17,4.93*10^-19,
        1.74*10^-18,8.5*10^-19,1.41*10^-18,8.68*10^-18},{"St Wall",
        1.42*10^-18,2.32*10^-17,2.32*10^-17,2.32*10^-17,2.32*10^-17,
        2.32*10^-17,2.32*10^-17,2.32*10^-17,2.32*10^-17,1.42*10^-18,
        1.42*10^-18,1.42*10^-18,.0000000000002,.000000000000216,2.82*10^-17,
        4.83*10^-17,1.56*10^-17,1.56*10^-17,7.74*10^-18,7.74*10^-18,
        4.7*10^-18,5.71*10^-17,2.45*10^-17,
        4.13*10^-17,.000000000000555},{"Testes",2.18*10^-19,1.6*10^-18,
        1.6*10^-18,1.6*10^-18,1.6*10^-18,1.6*10^-18,1.6*10^-18,1.6*10^-18,
        1.6*10^-18,2.18*10^-19,2.18*10^-19,
        2.18*10^-19,.0000000000002,.000000000000216,7.84*10^-18,1.37*10^-17,
        4*10^-17,4*10^-17,1.24*10^-17,1.24*10^-17,9.77*10^-17,1.59*10^-16,
        2.82*10^-16,1.88*10^-16,1.16*10^-17},{"Liver",2.17*10^-18,4.04*10^-17,
        4.04*10^-17,4.04*10^-17,4.04*10^-17,4.04*10^-17,4.04*10^-17,
        4.04*10^-17,4.04*10^-17,2.17*10^-18,2.17*10^-18,
        2.17*10^-18,.0000000000002,.000000000000216,.00000000000589,
        5.38*10^-17,1.73*10^-17,1.73*10^-17,9.68*10^-18,9.68*10^-18,
        3.13*10^-18,3.69*10^-17,4.38*10^-18,2.23*10^-17,
        2.78*10^-17},{"Red Marrow",1.54*10^-17,2.22*10^-17,2.22*10^-17,
        2.22*10^-17,2.22*10^-17,2.22*10^-17,2.22*10^-17,2.22*10^-17,
        2.22*10^-17,1.54*10^-17,1.54*10^-17,
        1.54*10^-17,.0000000000002,.000000000000216,1.68*10^-17,
        3.35*10^-17,.00000000000452,.000000000000481,5.06*10^-17,5.06*10^-17,
        1.5*10^-17,2.73*10^-17,4.09*10^-17,3.42*10^-17,1.48*10^-17},{"Skin",
        9.81*10^-18,8.87*10^-18,8.87*10^-18,8.87*10^-18,8.87*10^-18,
        8.87*10^-18,8.87*10^-18,8.87*10^-18,8.87*10^-18,9.81*10^-18,
        9.81*10^-18,9.81*10^-18,.0000000000002,.000000000000216,8.53*10^-18,
        9.13*10^-18,9.93*10^-18,9.93*10^-18,1.15*10^-17,1.15*10^-17,
        8.83*10^-18,7.07*10^-18,7.99*10^-18,6.85*10^-18,7.89*10^-18},{"Lungs",
       1.73*10^-17,.00000000000425,.000000000544,.000000000553,.000000000259,.000000000119,
	.000000000301,.000000000477,.000000000000936,1.73*10^-17,
        1.73*10^-17,1.73*10^-17,.0000000000002,.000000000000216,4.12*10^-17,
        1.39*10^-17,2.25*10^-17,2.25*10^-17,1.38*10^-17,1.38*10^-17,
        5.09*10^-19,4.17*10^-18,1.44*10^-18,3.55*10^-18,
        2.21*10^-17},{"Remainder",5.13*10^-14,1.84*10^-17,1.84*10^-17,
        1.84*10^-17,1.84*10^-17,1.84*10^-17,1.84*10^-17,1.84*10^-17,
        1.84*10^-17,.00000000000123,.00000000207,.00000000000047,
	.0000000000002,.000000000000216,9.06*10^-18,.000000000000224,1.73*10^-17,
        1.73*10^-17,1.57*10^-17,1.57*10^-17,1.3*10^-17,1.31*10^-17,
        1.32*10^-17,3.62*10^-15,1.14*10^-17},{"Bone Surface",3.34*10^-17,
        2.99*10^-17,2.99*10^-17,2.99*10^-17,2.99*10^-17,2.99*10^-17,
        2.99*10^-17,2.99*10^-17,2.99*10^-17,3.34*10^-17,3.34*10^-17,
        3.34*10^-17,.0000000000002,.000000000000108,2.06*10^-17,
        2.69*10^-17,.000000000028,.00000000000282,.000000000028,.00000000000114,
	1.5*10^-17,2*10^-17,3.15*10^-17,2.38*10^-17,
        1.59*10^-17},{"Thyroid",2.65*10^-17,1.71*10^-17,1.71*10^-17,
        1.71*10^-17,1.71*10^-17,1.71*10^-17,1.71*10^-17,1.71*10^-17,
        1.71*10^-17,2.65*10^-17,2.65*10^-17,
        2.65*10^-17,.0000000000002,.000000000000216,2.17*10^-18,1.19*10^-18,
        1.52*10^-17,1.52*10^-17,1.57*10^-17,1.57*10^-18,1.26*10^-19,
        4.6*10^-19,2.15*10^-19,2.63*10^-19,1.13*10^-18},{"Bladder Wall",
        1.26*10^-19,6.47*10^-19,6.47*10^-19,6.47*10^-19,6.47*10^-19,
        6.47*10^-19,6.47*10^-19,6.47*10^-19,6.47*10^-19,1.26*10^-19,
        1.26*10^-19,1.26*10^-19,.0000000000002,.000000000000216,3.31*10^-18,
        4.83*10^-18,1.59*10^-17,1.59*10^-17,7.4*10^-18,
        7.4*10^-18,.00000000000116,2.93*10^-17,9.13*10^-17,3.89*10^-17,
        4.59*10^-18}};


SSEU235={{"Colon",8.57*10^-19,1.57*10^-17,1.57*10^-17,1.57*10^-17,1.57*10^-17,
          1.57*10^-17,1.57*10^-17,1.57*10^-17,1.57*10^-17,8.57*10^-19,
          8.57*10^-19,8.57*10^-19,.000000000000209,.000000000000225,
          1.45*10^-16,1.88*10^-16,2.33*10^-16,2.33*10^-16,7.95*10^-17,
          7.95*10^-17,4.41*10^-16,.000000000000231,.000000000000283,
          1.64*10^-15,2.42*10^-16},{"Oesophagus",2.03*10^-16,3.74*10^-16,
          3.74*10^-16,3.74*10^-16,3.74*10^-16,3.74*10^-16,3.74*10^-16,
          3.74*10^-16,3.74*10^-16,2.03*10^-16,2.03*10^-16,
          2.03*10^-16,.000000000000209,.000000000000225,7.66*10^-17,
          2.43*10^-17,1.12*10^-16,1.12*10^-16,6.44*10^-17,6.44*10^-17,
          1.31*10^-18,8.22*10^-18,3.07*10^-18,7.02*10^-18,
          4.9*10^-17},{"St Wall",5.92*10^-18,1.54*10^-16,1.54*10^-16,
          1.54*10^-16,1.54*10^-16,1.54*10^-16,1.54*10^-16,1.54*10^-16,
          1.54*10^-16,5.92*10^-18,5.92*10^-18,
          5.92*10^-18,.000000000000209,.000000000000225,1.88*10^-16,
          3.21*10^-16,1.08*10^-16,1.08*10^-16,5.21*10^-17,5.21*10^-17,
          2.8*10^-17,3.79*10^-16,1.61*10^-16,
          2.79*10^-16,.000000000000357},{"Testes",4.01*10^-19,8.18*10^-18,
          8.18*10^-18,8.18*10^-18,8.18*10^-18,8.18*10^-18,8.18*10^-18,
          8.18*10^-18,8.18*10^-18,4.01*10^-19,4.01*10^-19,
          4.01*10^-19,.000000000000209,.000000000000225,4.9*10^-17,
          9.01*10^-17,2.76*10^-16,2.76*10^-16,8.46*10^-17,8.46*10^-17,
          6.83*10^-16,1.06*10^-15,1.83*10^-15,1.27*10^-15,
          7.27*10^-17},{"Liver",1.22*10^-17,2.74*10^-16,2.74*10^-16,
          2.74*10^-16,2.74*10^-16,2.74*10^-16,2.74*10^-16,2.74*10^-16,
          2.74*10^-16,1.22*10^-17,1.22*10^-17,
          1.22*10^-17,.000000000000209,.000000000000225,.00000000000626,
          3.79*10^-16,1.16*10^-16,1.16*10^-16,6.3*10^-17,6.3*10^-17,
          1.63*10^-17,2.4*10^-16,2.37*10^-17,1.5*10^-16,1.87*10^-16},{"Mama",
          3.91*10^-17,3.04*10^-16,3.04*10^-16,3.04*10^-16,3.04*10^-16,
          3.04*10^-16,3.04*10^-16,3.04*10^-16,3.04*10^-16,3.91*10^-17,
          3.91*10^-17,3.91*10^-17,.000000000000209,.000000000000225,
          8.93*10^-17,2.7*10^-17,7.15*10^-17,7.15*10^-17,4.16*10^-17,
          4.16*10^-17,2.08*10^-18,1.15*10^-17,3.46*10^-18,1.04*10^-17,
          7.34*10^-17},{"Red Marrow",1.02*10^-16,1.46*10^-16,1.46*10^-16,
          1.46*10^-16,1.46*10^-16,1.46*10^-16,1.46*10^-16,1.46*10^-16,
          1.46*10^-16,1.02*10^-16,1.02*10^-16,
          1.02*10^-16,.000000000000209,.000000000000225,1.09*10^-16,
          2.26*10^-16,.00000000000471,.000000000000478,3.22*10^-16,
          3.22*10^-16,1.03*10^-16,1.85*10^-16,2.77*10^-16,2.31*10^-16,
          9.78*10^-17},{"Skin",5.93*10^-17,5.35*10^-17,5.35*10^-17,
          5.35*10^-17,5.35*10^-17,5.35*10^-17,5.35*10^-17,5.35*10^-17,
          5.35*10^-17,5.93*10^-17,5.93*10^-17,
          5.93*10^-17,.000000000000209,.000000000000225,4.78*10^-17,
          5.28*10^-17,5.85*10^-17,5.85*10^-17,6.63*10^-17,6.63*10^-17,
          5.32*10^-17,4.23*10^-17,4.7*10^-17,3.95*10^-17,
          4.61*10^-17},{"Lungs",
          1.11*10^-16,.00000000000438,.000000000576,.000000000586,.000000000275, 	.000000000169,.000000000361,.000000000595,.000000000000965,
          1.11*10^-16,1.11*10^-16,
          1.11*10^-16,.000000000000209,.000000000000225,2.77*10^-16,
          8.59*10^-17,1.45*10^-16,1.45*10^-16,8.76*10^-17,8.76*10^-17,
          1.52*10^-18,2.26*10^-17,6.6*10^-18,1.8*10^-17,
          1.4*10^-16},{"Remainder",8.42*10^-14,1.2*10^-16,1.2*10^-16,
          1.2*10^-16,1.2*10^-16,1.2*10^-16,1.2*10^-16,1.2*10^-16,
          1.2*10^-16,.000000000000733,.0000000022,.000000000000537,
	.000000000000209,.000000000000225,5.79*10^-17,.000000000000234,1.13*10^-16,
          1.13*10^-16,1.01*10^-16,1.01*10^-16,8.51*10^-17,8.62*10^-17,
          8.74*10^-17,2.37*10^-15,7.33*10^-17},{"Bone Surface",2.29*10^-16,
          2*10^-16,2*10^-16,2*10^-16,2*10^-16,2*10^-16,2*10^-16,2*10^-16,
          2*10^-16,2.29*10^-16,2.29*10^-16,
          2.29*10^-16,.000000000000209,.000000000000113,1.46*10^-16,
	  1.89*10^-16,.0000000000294,.00000000000294,.0000000000294,.00000000000118,
	1.19*10^-16,1.46*10^-16,2.18*10^-16,1.72*10^-16,
          1.18*10^-16},{"Thyroid",1.76*10^-16,1.11*10^-16,1.11*10^-16,
          1.11*10^-16,1.11*10^-16,1.11*10^-16,1.11*10^-16,1.11*10^-16,
          1.11*10^-16,1.76*10^-16,1.76*10^-16,
          1.76*10^-16,.000000000000209,.000000000000225,1.22*10^-17,
          4.9*10^-18,9.88*10^-17,9.88*10^-17,9.98*10^-17,9.98*10^-17,
          1.71*10^-19,1.24*10^-18,4.28*10^-19,7.27*10^-19,
          4.04*10^-18},{"Bladder Wall",1.73*10^-19,2.12*10^-18,2.12*10^-18,
          2.12*10^-18,2.12*10^-18,2.12*10^-18,2.12*10^-18,2.12*10^-18,
          2.12*10^-18,1.73*10^-19,1.73*10^-19,
          1.73*10^-19,.000000000000209,.000000000000225,1.64*10^-17,
          2.65*10^-17,1.17*10^-16,1.17*10^-16,5.19*10^-17,
          5.19*10^-17,.000000000000745,2.04*10^-16,6.54*10^-16,2.75*10^-16,
          2.41*10^-17}};

SSEU234={{"Colon",2.23*10^-22,8.07*10^-21,8.07*10^-21,8.07*10^-21,8.07*10^-21,
          8.07*10^-21,8.07*10^-21,8.07*10^-21,8.07*10^-21,2.23*10^-22,
          2.23*10^-22,2.23*10^-22,.000000000000225,.000000000000225,
          2.21*10^-19,1.57*10^-19,7.09*10^-19,7.09*10^-19,1.19*10^-19,
          1.19*10^-19,5.74*10^-19,.0000000000002,.000000000000246,2.88*10^-17,
          5.19*10^-19},{"Oesophagus",1.5*10^-19,4.15*10^-19,4.15*10^-19,
          4.15*10^-19,4.15*10^-19,4.15*10^-19,4.15*10^-19,4.15*10^-19,
          4.15*10^-19,1.5*10^-19,1.5*10^-19,
          1.5*10^-19,.000000000000225,.00000000000025,5.3*10^-20,1.17*10^-20,
          2.2*10^-19,2.2*10^-19,1.16*10^-19,1.16*10^-19,3.43*10^-22,
          3.11*10^-21,1*10^-21,2.47*10^-21,2.54*10^-20},{"St Wall",
          1.85*10^-21,3.6*10^-19,3.6*10^-19,3.6*10^-19,3.6*10^-19,3.6*10^-19,
          3.6*10^-19,3.6*10^-19,3.6*10^-19,1.85*10^-21,1.85*10^-21,
          1.85*10^-21,.000000000000225,.000000000000225,1.89*10^-19,
          2.97*10^-19,1.18*10^-19,1.18*10^-19,5.86*10^-20,5.86*10^-20,
          1.4*10^-20,1.35*10^-18,1.83*10^-19,
          6.35*10^-19,.000000000000309},{"Testes",8.9*10^-23,2.73*10^-21,
          2.73*10^-21,2.73*10^-21,2.73*10^-21,2.73*10^-21,2.73*10^-21,
          2.73*10^-21,2.73*10^-21,8.9*10^-23,8.9*10^-23,
          8.9*10^-23,.000000000000225,.000000000000225,2.87*10^-20,5.4*10^-20,
          3*10^-19,3*10^-19,8.32*10^-20,8.32*10^-20,7.58*10^-19,6.91*10^-18,
          1.76*10^-17,7.74*10^-18,4.55*10^-20},{"Liver",5.79*10^-21,
          1.32*10^-18,1.32*10^-18,1.32*10^-18,1.32*10^-18,1.32*10^-18,
          1.32*10^-18,1.32*10^-18,1.32*10^-18,5.79*10^-21,5.79*10^-21,
          5.79*10^-21,.000000000000225,.000000000000225,.00000000000663,
          6.8*10^-19,1.73*10^-19,1.73*10^-19,9.55*10^-20,9.55*10^-20,
          7.56*10^-21,3.33*10^-19,1.16*10^-20,2.04*10^-19,
          1.77*10^-19},{"Mama",2.08*10^-20,6.15*10^-19,6.15*10^-19,
          6.15*10^-19,6.15*10^-19,6.15*10^-19,6.15*10^-19,6.15*10^-19,
          6.15*10^-19,2.08*10^-20,2.08*10^-20,
          2.08*10^-20,.000000000000225,.000000000000225,6.89*10^-20,
          1.43*10^-20,2.25*10^-19,2.25*10^-19,1.17*10^-19,1.17*10^-19,
          5.85*10^-22,5.3*10^-21,1.26*10^-21,4.59*10^-21,
          4.97*10^-20},{"Red Marrow",1.02*10^-19,2.54*10^-19,2.54*10^-19,
          2.54*10^-19,2.54*10^-19,2.54*10^-19,2.54*10^-19,2.54*10^-19,
          2.54*10^-19,1.02*10^-19,1.02*10^-19,
          1.02*10^-19,.000000000000225,.000000000000225,1.65*10^-19,
          2.83*10^-19,.00000000000508,.000000000000509,5.9*10^-18,5.9*10^-18,
          7.04*10^-20,2.52*10^-19,6.82*10^-19,4.22*10^-19,
          8.35*10^-20},{"Skin",8.01*10^-20,7.75*10^-20,7.75*10^-20,
          7.75*10^-20,7.75*10^-20,7.75*10^-20,7.75*10^-20,7.75*10^-20,
          7.75*10^-20,8.01*10^-20,8.01*10^-20,
          8.01*10^-20,.000000000000225,.000000000000225,7.28*10^-20,
          1.36*10^-19,2.91*10^-19,2.91*10^-19,3.02*10^-19,3.02*10^-19,
          6.62*10^-20,3.58*10^-20,1.01*10^-19,3.32*10^-20,
          5.98*10^-20},{"Lungs",
          9.1*10^-20,.00000000000478,.00000000062,.000000000633,.000000000297,
	.000000000283,.000000000467,.000000000811,.00000000000103,9.1*10^-20,
          9.1*10^-20,9.1*10^-20,.000000000000225,.000000000000225,1.46*10^-18,
          6.71*10^-20,2.95*10^-19,2.95*10^-19,1.63*10^-19,1.63*10^-19,
          5.73*10^-22,1.25*10^-20,2.64*10^-21,9.54*10^-21,
          1.96*10^-19},{"Remainder",3.73*10^-15,7.18*10^-19,7.18*10^-19,
          7.18*10^-19,7.18*10^-19,7.18*10^-19,7.18*10^-19,7.18*10^-19,
          7.18*10^-19,
          5.74*10^-15,.0000000024,.000000000000521,.000000000000225,
	.000000000000225,2.7*10^-19,.000000000000252,2.82*10^-19,2.82*10^-19,
          2.43*10^-19,2.43*10^-19,3.49*10^-19,3.55*10^-19,3.45*10^-19,
          2.01*10^-15,2.44*10^-19},{"Bone Surface",5.38*10^-19,7.27*10^-19,
          7.27*10^-19,7.27*10^-19,7.27*10^-19,7.27*10^-19,7.27*10^-19,
          7.27*10^-19,7.27*10^-19,5.38*10^-19,5.38*10^-19,
          5.38*10^-19,.000000000000225,.000000000000225,4.79*10^-19,
          4.99*10^-19,.0000000000318,.00000000000318,.0000000000318,
	.00000000000127,1.23*10^-19,3.53*10^-19,9.99*10^-19,5.88*10^-19,
          1.94*10^-19},{"Thyroid",1.16*10^-19,8.7*10^-20,8.7*10^-20,
          8.7*10^-20,8.7*10^-20,8.7*10^-20,8.7*10^-20,8.7*10^-20,8.7*10^-20,
          8.7*10^-20,8.7*10^-20,8.7*10^-20,.000000000000225,.000000000000225,
          5.79*10^-21,1.29*10^-21,9.69*10^-20,9.69*10^-20,1.14*10^-19,
          1.14*10^-19,3.46*10^-23,3.27*10^-22,1*10^-22,2.33*10^-22,
          1.48*10^-21},{"Bladder Wall",3.49*10^-23,6.49*10^-22,6.49*10^-22,
          6.49*10^-22,6.49*10^-22,6.49*10^-22,6.49*10^-22,6.49*10^-22,
          6.49*10^-22,3.49*10^-23,3.49*10^-23,
          3.49*10^-23,.000000000000225,.000000000000225,7.5*10^-21,
          1.37*10^-20,8.16*10^-20,8.16*10^-20,3.23*10^-20,
          3.23*10^-20,.000000000000645,1.6*10^-19,1*10^-18,2.44*10^-19,
          1.33*10^-20}};


End[]


Protect[CompartNumbers, TransferRates, compartMatrix, TransferRatesE, compartMatrixE, 
BiokdataReport]; 

Print["Biokdata 1.2.2 2004-09-3 (Lite version. The full version includes all ICRP models)"]

EndPackage[]































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































