

(*The Package*)

(*Title : FitModel, a Mathematica package to fit coeffs with application to Biokinetic 
Systems*)


(* : Author : Guillermo Sanchez*)


(* : Summary : This package provides Mathematica functions for fitting coefficients*)


(* : Context : Biokmod`Fitmodel`*)


(* : Package Version : 0.3 *)

(* : Copyright : Copyright 2005. Guillermo Sanchez.http : //web.usal.es/~guillerm/*)

(* : History : Version 1 *)

(* : Keywords : Fit, Compartmental Model, Physiological Model, Biokinetic, 
Pharmacokinetic, Internal Dosimetry, Radiological Protection*)
 
(*Sources : *)

(* : Warning :*)

(* : Mathematica Version : 5.2*)

(* : Limitation : None known.*)

(* : Discussion :*)

BeginPackage["Biokmod`Fitmodel`"]

MLFit::usage = "MLFit[data1, model1, , data2, model2, ...,t]";

X2FitE::usage = "X2FitE[pars, data1, model1, , data2, model2, ...,t]";


X2Fit::usage = "X2FitE[pars, data1, model1, , data2, model2, ...,t]";

Begin["`Private`"]

linearfit1[t_] = 0; 
linearfit1[list1_, model1_,  r___, t_] := Module[{a, t1, y1, s1}, 
   {t1, y1, s1} = Transpose[list1]; Plus @@ ((model1 /. t -> t1)*(y1/s1^2)) + 
     linearfit1[r, t]]
linearfit2[t_] = 0; 
linearfit2[list1_, model1_,  r___, t_] := Module[{a, t1, y1, s1}, 
   {t1, y1, s1} = Transpose[list1]; Plus @@ ((model1 /. t -> t1)^2/s1^2) + 
     linearfit2[r, t]]

MLFit[list1_,model1_,  r___, t_] := Module[{a, b}, 
   a = linearfit1[list1, model1,  r, t]; b = linearfit2[list1, model1,  r, t]; 
    Thread[{"Mean", "s"} -> {a/b, 1/Sqrt[b]}]]

X2FitE[{(par__)?NumberQ}, list1_,model1_,  t_] := 
   Module[{t1, y1, s1}, {t1, y1, s1} = Transpose[list1]; 
     Block[{a}, a = model1 /. t -> t1; Plus @@ ((a - y1)^2/s1^2)]]; 

X2FitE[{(par__)?NumberQ}, list1_, model1_, list2_, model2_,  t_] := 
   Module[{t1, y1, s1, t2, y2, s2}, {t1, y1, s1} = Transpose[list1]; 
     {t2, y2, s2} = Transpose[list2]; 
     Block[{a, b}, a = model1 /. t -> t1; 
       b = model2 /. t -> t2; Plus @@ ((a - y1)^2/s1^2) + 
        Plus @@ ((b - y2)^2/s2^2)]]; 

X2FitE[{(par__)?NumberQ}, list1_, model1_, list2_, model2_, list3_, 
model3_,  t_] := Module[{t1, y1, s1, t2, y2, s2, t3, y3, s3}, 
    {t1, y1, s1} = Transpose[list1]; 
    {t2, y2, s2} = Transpose[list2]; 
    {t3, y3, s3} = Transpose[list3];
     Block[{a, b, c}, a = model1 /. t -> t1; b = model2 /. t -> t2; 
       c = model3 /. t -> t3; Plus @@ ((a - y1)^2/s1^2) + 
        Plus @@ ((b - y2)^2/s2^2) + Plus @@ ((c - y3)^2/s3^2)]]; 

X2Fit[{(par__)?NumberQ}, list1_,model1_,  t_] := 
   Module[{t1, y1}, {t1, y1} = Transpose[list1]; 
     Block[{a}, a = model1 /. t -> t1; Plus @@ ((a - y1)^2)]]; 

X2Fit[{(par__)?NumberQ}, list1_, model1_,  list2_, model2_,  t_] := 
   Module[{t1, y1, t2, y2}, {t1, y1} = Transpose[list1]; 
     {t2, y2} = Transpose[list2]; 
     Block[{a, b}, a = model1 /. t -> t1; 
       b = model2 /. t -> t2; Plus @@ ((a - y1)^2) +
        Plus @@ ((b - y2)^2)]]; 

X2Fit[{(par__)?NumberQ}, list1_,model1_,  list2_, model2_, 
list3_, model3_, t_] := Module[{t1, y1, t2, y2, t3, y3}, 
{t1, y1} = Transpose[list1]; {t2, y2} = Transpose[list2]; 
Block[{a, b, c}, a = model1 /. t -> t1; 
b = model2 /. t -> t2; c = model3 /. t -> t3; 
Plus @@ ((a - y1)^2) + Plus @@ ((b - y2)^2) + 
Plus @@ ((c - y3)^2)]]; 

End[]

Protect[MLFit, X2FitE, X2Fit]; 

 
Print["Fitmodel, guillermo@usal.es, version 0.3   2005-09-13"]

EndPackage[]














































































































































