(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    174513,       4784]*)
(*NotebookOutlinePosition[    176438,       4845]*)
(*  CellTagsIndexPosition[    176299,       4837]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Fitting bioassay data  ", "Chapter"],

Cell["Last update of this help. 2005-08-22", "Commentary"],

Cell[CellGroupData[{

Cell[BoxData[
    \($Version\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("5.2 for Microsoft Windows (June 20, 2005)"\)], "Output",
  CellLabel->"Out[1]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Initialization", "SubsectionIcon"],

Cell["We will need the following packages ", "MathCaption",
  CellTags->"ICRP 78"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Needs["\<Biokmod`Biokdata`\>"]\)], "Input",
  CellLabel->"In[2]:=",
  CellTags->"Introduction"],

Cell[BoxData[
    \("Resptract 1.2 b1 2005-05-16"\)], "Print",
  CellLabel->"From In[2]:=",
  CellTags->"Introduction"],

Cell[BoxData[
    \("SysModel, guillermo@usal.es, version 1.3.   2005-08-24"\)], "Print",
  CellLabel->"From In[2]:=",
  CellTags->"Introduction"],

Cell[BoxData[
    \("Humorap 3.3 b1 2005-06-17"\)], "Print",
  CellLabel->"From In[2]:=",
  CellTags->"Introduction"],

Cell[BoxData[
    \("Biokdata 1.2.2 2004-09-3 (Lite version. The full version includes all \
ICRP models)"\)], "Print",
  CellLabel->"From In[2]:=",
  CellTags->"Introduction"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Needs["\<Biokmod`Fitmodel`\>"]\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \("Fitmodel, guillermo@usal.es, version 0.3   2005-09-13"\)], "Print",
  CellLabel->"From In[3]:="]
}, Open  ]],

Cell[BoxData[
    \(Needs["\<Graphics`Graphics`\>"]\)], "Input",
  CellLabel->"In[4]:=",
  CellTags->"Introduction"],

Cell[BoxData[
    \(Needs["\<Statistics`ContinuousDistributions`\>"]\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(Needs["\<Statistics`LinearRegression`\>"]\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(Needs["\<Statistics`NonlinearFit`\>"]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(Off[General::spell1]; Off[General::spell];\)], "Input",
  CellLabel->"In[8]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Fitting bioassay data  ", "Section",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell["Using a kind of bioassay  to evaluate the intake  ", "SubsectionIcon"],

Cell["\<\
Bioassays can be used to estimate the intake, even the AMAD , when they are \
unknown. \
\>", "Text"],

Cell[CellGroupData[{

Cell["Example 1", "SubsubsectionIcon"],

Cell[TextData[{
  "A worker has been exposed to an (unknown) acute intake of  uranium \
aerosols (class S) by inhalation in ",
  Cell[BoxData[
      \(TraditionalForm\`t\  = \ 0\)]],
  ". With a lung counter have been taken measured the following days after \
the intake: ",
  "{1, 10, 30, 60, 90, 120, 180, 270,350}",
  " obtaining the values given by sampleLung."
}], "Text"],

Cell["\<\
This funtion give the uranium lung retention as funtion of time after \
intake(t), the intake (int) and AMAD (p)\
\>", "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(uraniumLungRet[t_, int_, \ p_]\), ":=", 
        RowBox[{
          StyleBox["LungsRetention",
            "Input"], "[", \(int, AMADAdultW[p], S, \ t, 0\), "]"}]}], 
      ";"}]], "Input",
  CellLabel->"In[9]:="],

Cell[TextData[{
  "We simulate the lung measured assuming an \"unknown\" intake of 850 Bq of \
",
  Cell[BoxData[
      \(TraditionalForm\`\^235\)]],
  "U  with AMAD 7 \[Mu]m in t = 0 (a random noise is included). "
}], "MathCaption"],

Cell[BoxData[
    \(SeedRandom[110]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(\(daymeasured\  = \ {1, \ 10, \ 30, \ 60, \ 90, \ 120, \ 180, \ 270, 
          350};\)\)], "Input",
  CellLabel->"In[11]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(sampleLung\  = 
      Map[{#, uraniumLungRet[#, 850, \ 7] + 
                Random[NormalDistribution[0, \ 1.5]]} &, daymeasured] // 
        Round\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \({{1, 39}, {10, 36}, {30, 29}, {60, 26}, {90, 23}, {120, 22}, {180, 
        20}, {270, 18}, {350, 14}}\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell[TextData[{
  "Here are assumed an uncertainty of 5 Bq of ",
  Cell[BoxData[
      \(TraditionalForm\`\^235\)]],
  "U in the measured of the lung counter"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sampleLungUnc\  = Map[Append[#, 5] &, sampleLung]\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \({{1, 39, 5}, {10, 36, 5}, {30, 29, 5}, {60, 26, 5}, {90, 23, 5}, {120, 
        22, 5}, {180, 20, 5}, {270, 18, 5}, {350, 14, 5}}\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[Evaluate[uraniumLungRet[t, 850, \ 7]], {t, 0, 400}, 
      Epilog \[RuleDelayed] 
        Map[{Orange, PointSize[ .02], Point[##]} &, sampleLung]\ ]\)], "Input",\

  CellLabel->"In[14]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00238095 -0.231056 0.0157568 [
[.2619 -0.0072 -9 -9 ]
[.2619 -0.0072 9 0 ]
[.5 -0.0072 -9 -9 ]
[.5 -0.0072 9 0 ]
[.7381 -0.0072 -9 -9 ]
[.7381 -0.0072 9 0 ]
[.97619 -0.0072 -9 -9 ]
[.97619 -0.0072 9 0 ]
[.01131 .08408 -12 -4.5 ]
[.01131 .08408 0 4.5 ]
[.01131 .16286 -12 -4.5 ]
[.01131 .16286 0 4.5 ]
[.01131 .24165 -12 -4.5 ]
[.01131 .24165 0 4.5 ]
[.01131 .32043 -12 -4.5 ]
[.01131 .32043 0 4.5 ]
[.01131 .39922 -12 -4.5 ]
[.01131 .39922 0 4.5 ]
[.01131 .478 -12 -4.5 ]
[.01131 .478 0 4.5 ]
[.01131 .55678 -12 -4.5 ]
[.01131 .55678 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .0053 m
.2619 .01155 L
s
[(100)] .2619 -0.0072 0 1 Mshowa
.5 .0053 m
.5 .01155 L
s
[(200)] .5 -0.0072 0 1 Mshowa
.7381 .0053 m
.7381 .01155 L
s
[(300)] .7381 -0.0072 0 1 Mshowa
.97619 .0053 m
.97619 .01155 L
s
[(400)] .97619 -0.0072 0 1 Mshowa
.125 Mabswid
.07143 .0053 m
.07143 .00905 L
s
.11905 .0053 m
.11905 .00905 L
s
.16667 .0053 m
.16667 .00905 L
s
.21429 .0053 m
.21429 .00905 L
s
.30952 .0053 m
.30952 .00905 L
s
.35714 .0053 m
.35714 .00905 L
s
.40476 .0053 m
.40476 .00905 L
s
.45238 .0053 m
.45238 .00905 L
s
.54762 .0053 m
.54762 .00905 L
s
.59524 .0053 m
.59524 .00905 L
s
.64286 .0053 m
.64286 .00905 L
s
.69048 .0053 m
.69048 .00905 L
s
.78571 .0053 m
.78571 .00905 L
s
.83333 .0053 m
.83333 .00905 L
s
.88095 .0053 m
.88095 .00905 L
s
.92857 .0053 m
.92857 .00905 L
s
.25 Mabswid
0 .0053 m
1 .0053 L
s
.02381 .08408 m
.03006 .08408 L
s
[(20)] .01131 .08408 1 0 Mshowa
.02381 .16286 m
.03006 .16286 L
s
[(25)] .01131 .16286 1 0 Mshowa
.02381 .24165 m
.03006 .24165 L
s
[(30)] .01131 .24165 1 0 Mshowa
.02381 .32043 m
.03006 .32043 L
s
[(35)] .01131 .32043 1 0 Mshowa
.02381 .39922 m
.03006 .39922 L
s
[(40)] .01131 .39922 1 0 Mshowa
.02381 .478 m
.03006 .478 L
s
[(45)] .01131 .478 1 0 Mshowa
.02381 .55678 m
.03006 .55678 L
s
[(50)] .01131 .55678 1 0 Mshowa
.125 Mabswid
.02381 .02105 m
.02756 .02105 L
s
.02381 .03681 m
.02756 .03681 L
s
.02381 .05257 m
.02756 .05257 L
s
.02381 .06832 m
.02756 .06832 L
s
.02381 .09984 m
.02756 .09984 L
s
.02381 .11559 m
.02756 .11559 L
s
.02381 .13135 m
.02756 .13135 L
s
.02381 .14711 m
.02756 .14711 L
s
.02381 .17862 m
.02756 .17862 L
s
.02381 .19438 m
.02756 .19438 L
s
.02381 .21013 m
.02756 .21013 L
s
.02381 .22589 m
.02756 .22589 L
s
.02381 .2574 m
.02756 .2574 L
s
.02381 .27316 m
.02756 .27316 L
s
.02381 .28892 m
.02756 .28892 L
s
.02381 .30467 m
.02756 .30467 L
s
.02381 .33619 m
.02756 .33619 L
s
.02381 .35195 m
.02756 .35195 L
s
.02381 .3677 m
.02756 .3677 L
s
.02381 .38346 m
.02756 .38346 L
s
.02381 .41497 m
.02756 .41497 L
s
.02381 .43073 m
.02756 .43073 L
s
.02381 .44649 m
.02756 .44649 L
s
.02381 .46224 m
.02756 .46224 L
s
.02381 .49376 m
.02756 .49376 L
s
.02381 .50951 m
.02756 .50951 L
s
.02381 .52527 m
.02756 .52527 L
s
.02381 .54103 m
.02756 .54103 L
s
.02381 .57254 m
.02756 .57254 L
s
.02381 .5883 m
.02756 .5883 L
s
.02381 .60405 m
.02756 .60405 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .41695 L
.02605 .39352 L
.02729 .38149 L
.02846 .3754 L
.02954 .37149 L
.03053 .36849 L
.03279 .36245 L
.04262 .33868 L
.06244 .29727 L
.0825 .26272 L
.10458 .23148 L
.14393 .1892 L
.18422 .15842 L
.22299 .13677 L
.26421 .11947 L
.30392 .10659 L
.34212 .09657 L
.38276 .0877 L
.42189 .08037 L
.46347 .07349 L
.50354 .06751 L
.54209 .06219 L
.58309 .05689 L
.62258 .05204 L
.66055 .04756 L
.70098 .04297 L
.73989 .03868 L
.78125 .03425 L
.82109 .03008 L
.85942 .02617 L
.9002 .02209 L
.93947 .01824 L
.97619 .01472 L
s
1 .5 0 r
.02 w
.02619 .38346 Mdot
.04762 .33619 Mdot
.09524 .22589 Mdot
.16667 .17862 Mdot
.2381 .13135 Mdot
.30952 .11559 Mdot
.45238 .08408 Mdot
.66667 .05257 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[14]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo001_Ool7
0003Ool40005Ool40019Ool60004Ool40005Ool4001:Ool40005Ool40005Ool4001;Ool40004Ool4
0005Ool4000:Ool0079oo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`16Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo
04Ioo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol0BWoo
00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Moo`00LWoo00<0
07ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo04Moo`03001oogoo00Eo
o`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`1;Ool01@00Oomoogoo000017oo00D0
07ooOomoo`0000Aoo`03001oogoo04Yoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`07Ool0079oo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`18Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool0Bgoo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`16Ool60003Ool00`00
Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol01goo001bOol00`00Oomoo`03Ool00`00Oomo
o`02Ool01@00Oomoogoo000017oo00<007ooOol0BGoo00<007ooOol00goo00<007ooOol00Woo00D0
07ooOomoo`0000Aoo`03001oogoo04Uoo`8000Aoo`03001oogoo009oo`05001oogooOol00004Ool0
0`00Oomoo`17Ool01000Oomoo`0017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo
00Moo`00LWoo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo04Yo
o`03001oogoo009oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`1;Ool01@00Oomo
ogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo04Moo`04001oogoo0004Ool00`00Oomoo`02
Ool01@00Oomoogoo000017oo00<007ooOol01goo001bOol00`00Oomoo`03Ool00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00<007ooOol0AWoo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001o
ogooOol00004Ool00`00Oomoo`1;Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001o
ogoo04Qoo`03001oo`0000Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`07Ool0
071oo`<000Eoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`16Ool00`00Oomoo`02
Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo04Ioo`03001oogoo009oo`05
001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol0B7oo00<007oo000017oo00<007oo
Ool00Woo00D007ooOomoo`0000Aoo`03001oogoo00Moo`00LWoo00<007ooOol017oo10001Goo1000
BWoo10001Goo10001Goo1000BWoo10001Goo10001Goo1000C7oo0P001Goo10001Goo10002Woo003o
OonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo000LOol00`00Oomoo`3o
OonBOol001aoo`03001oogoo0?mooi9oo`004Wooo`00UP002Goo000LOol00`00Oomoo`0@Ool00`00
Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00
Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00
Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00
Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0AOol001ao
o`03001oogoo011oo`03001oogoo011oo`03001oogoo011oo`03001oogoo011oo`03001oogoo015o
o`03001oogoo011oo`03001oogoo011oo`03001oogoo011oo`03001oogoo015oo`03001oogoo011o
o`03001oogoo011oo`03001oogoo011oo`03001oogoo011oo`03001oogoo015oo`03001oogoo011o
o`03001oogoo011oo`03001oogoo011oo`03001oogoo015oo`03001oogoo011oo`03001oogoo011o
o`03001oogoo015oo`0077oo00<007ooOol0GGoo00<007ooOol0GGoo00<007ooOol0GGoo00<007oo
Ool0GGoo00<007ooOol04Goo000LOol00`00Oomoo`3oOomgOol8000COol001aoo`03001oogoo0?mo
ofaoo`/001]oo`0077oo00<007ooOol0ogooI7oo20009Woo000LOol2003oOomMOol8000^Ool001ao
o`03001oogoo0?mooeAoo`P003Ioo`0077oo00<007ooOol0ogooB7oo3000?Woo000LOol00`00Oomo
o`3oOollOol<001:Ool001aoo`03001oogoo0?moocAoo`P005Ioo`0077oo00<007ooOol0ogoo;7oo
2000GWoo000LOol2003oOolUOol8001VOol001aoo`03001oogoo0?mooaQoo``006ioo`0077oo00<0
07ooOol0ogoo37oo3000NWoo000LOol00`00Oomoo`3oOol1Ool2ON000goo000000060026Ool001ao
o`03001oogoo0?]oo`<000Imh8eoo`0077oo00<007ooOol0lgoo20000goo1WgPSGoo000LOol2003/
Ool8000:Ool8ON2<Ool001aoo`03001oogoo0>=oo`P0019oo`Qmh8aoo`0077oo00<007ooOol0fgoo
20006goo1WgPSGoo000LOol00`00Oomoo`3COol8000SOol6ON2=Ool001aoo`03001oogoo0<]oo`P0
02eoo`9mh8moo`0077oo00<007ooOol0`goo2000aWoo000LOol00`00Oomoo`2lOol7003>Ool001ao
o`800;Qoo`D00=Eoo`0077oo00<007ooOol0/Goo1P00fWoo0006Ool60004Ool40008Ool00`00Oomo
o`2YOol2ON06003POol000Ioo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`05Ool0
0`00Oomoo`2ROol50006ON3TOol000Moo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Eo
o`03001oogoo09]oo`L000Eoo`Imh>Aoo`0027oo00<007ooOol017oo00<007ooOol00Woo00<007oo
Ool01Goo00<007ooOol0UWoo1@002goo27gPhgoo0009Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Oomoo`05Ool3002@Ool6000@Ool8ON3SOol000Yoo`03001oogoo009oo`03001oogoo009oo`03
001oogoo00Eoo`03001oogoo08aoo`@001Moo`Imh>Aoo`001Woo00<007ooOol00Woo00D007ooOomo
o`0000Aoo`03001oogoo00Eoo`03001oogoo08Qoo`@001]oo`Imh>Aoo`001Woo00<007ooOol00Woo
00D007ooOomoo`0000Aoo`03001oogoo00Eoo`03001oogoo08Aoo`@0025oo`9mh>Ioo`001goo1000
1Goo100027oo00<007ooOol0P7oo1000ogoo3Woo000LOol00`00Oomoo`1lOol4003oOolBOol001ao
o`8007Uoo`@00?mooaIoo`0077oo00<007ooOol0M7oo1000ogoo6Woo000LOol00`00Oomoo`1`Ool4
003oOolNOol001aoo`03001oogoo06eoo`80009mh?moob5oo`0077oo00<007ooOol0JWoo0`001WgP
ogoo7goo000LOol00`00Oomoo`1WOol30003Ool6ON3oOolOOol001aoo`03001oogoo06=oo`@000Eo
o`Qmh?mooaioo`0077oo0P00HGoo0`002Goo27gPogoo7Woo000LOol00`00Oomoo`1MOol3000=Ool6
ON3oOolOOol001aoo`03001oogoo05]oo`80011oo`Imh?mooamoo`0077oo00<007ooOol0Dgoo0WgP
0goo0`0057oo0WgPogoo8Goo000LOol00`00Oomoo`1AOol6ON000`00Oomoo`3oOolhOol001aoo`03
001oogoo055oo`Imh?mooc]oo`0077oo0P00DGoo27gPogoo>Woo000LOol00`00Oomoo`1?Ool00`00
ON1mh006ON3oOoljOol001aoo`03001oogoo04eoo`80009oo`Imh?mooc]oo`0077oo00<007ooOol0
Bgoo0P0017oo1WgPogoo>goo000LOol00`00Oomoo`19Ool20008Ool2ON3oOolmOol001aoo`03001o
ogoo04Moo`800?moodUoo`0077oo0P00Agoo00<007ooOol0ogooBGoo000LOol00`00Oomoo`14Ool2
003oOom<Ool001aoo`03001oogoo049oo`800?moodioo`001Woo1P0017oo100027oo00<007ooOol0
@7oo0P00ogooD7oo0006Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol01Goo00<0
07ooOol0?Woo0P00ogooDWoo0007Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0mOol0
0`00Oomoo`3oOomBOol000Qoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo03aoo`03001o
ogoo0?mooe=oo`002Goo00<007ooOol027oo00<007ooOol01Goo0`00>Woo0P00ogooEWoo000:Ool0
0`00Oomoo`03Ool40008Ool00`00Oomoo`0iOol00`00Oomoo`3oOomFOol000Ioo`03001oogoo009o
o`03001oogoo009oo`03001oogoo00Uoo`03001oogoo03Qoo`03001oogoo0?mooeMoo`001Woo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0=Woo0WgPogooFWoo0007Ool4
0005Ool50007Ool00`00Oomoo`0dOol6ON3oOomHOol001aoo`03001oogoo03Aoo`Imh?mooeQoo`00
77oo0P00<goo00<007gPON001WgPogooEgoo000LOol00`00Oomoo`0aOol00`00Oommh007ON3oOomG
Ool001aoo`03001oogoo031oo`04001oogooOol6ON3oOomHOol001aoo`03001oogoo02ioo`8000Ao
o`Imh?mooeQoo`0077oo00<007ooOol0;Goo00<007ooOol01Woo0WgPogooFWoo000LOol00`00Oomo
o`0/Ool00`00Oomoo`3oOomSOol001aoo`8002aoo`03001oogoo0?moofAoo`0077oo00<007ooOol0
:Woo00<007ooOol0ogooIGoo000LOol00`00Oomoo`0YOol00`00Oomoo`3oOomVOol001aoo`03001o
ogoo02Qoo`03001oogoo0?moofMoo`0077oo00<007ooOol09goo00<007ooOol0ogooJ7oo000LOol0
0`00Oomoo`0VOol00`00Oomoo`3oOomYOol001aoo`03001oogoo02Eoo`03001oogoo0?moofYoo`00
77oo0P009Woo00<007ooOol0ogooJWoo000LOol00`00Oomoo`0TOol00`00Oomoo`3oOom[Ool001ao
o`03001oogoo02=oo`03001oogoo0?moofaoo`0077oo00<007ooOol06Goo0WgP1goo00<007ooOol0
ogooKGoo000LOol00`00Oomoo`0GOol6ON04Ool00`00Oomoo`3oOom^Ool001aoo`03001oogoo01Mo
o`Imh0=oo`03001oogoo0?moofmoo`0077oo0P005goo27gP00=oo`00Ool0ogooLGoo000LOol00`00
Oomoo`0FOol8ON000`00Oomoo`3oOomaOol001aoo`03001oogoo01Moo`Imh003001oogoo0?moog9o
o`001goo10001Goo100027oo00<007ooOol05goo1WgPogooMGoo0006Ool00`00Oomoo`02Ool01@00
Oomoogoo000017oo00<007ooOol01Goo00<007ooOol06Goo0WgP00=oo`00Ool0ogooM7oo000;Ool0
1@00Oomoogoo000017oo00<007ooOol01Goo00<007ooOol06goo00<007ooOol0ogooM7oo000;Ool0
1@00Oomoogoo000017oo00<007ooOol01Goo00<007ooOol06Woo00<007ooOol0ogooMGoo0009Ool2
0004Ool00`00Oomoo`02Ool00`00Oomoo`05Ool3000JOol00`00Oomoo`3oOomeOol000]oo`05001o
ogooOol00004Ool00`00Oomoo`05Ool00`00Oomoo`0IOol00`00Oomoo`3oOomfOol000]oo`05001o
ogooOol00004Ool00`00Oomoo`05Ool00`00Oomoo`0HOol00`00Oomoo`3oOomgOol000Ioo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`05Ool00`00Oomoo`0GOol00`00Oomoo`3oOomh
Ool000Moo`@000Eoo`@000Qoo`03001oogoo01Moo`03001oogoo0?moogQoo`0077oo00<007ooOol0
5Woo00<007ooOol0ogooNGoo000LOol2000FOol00`00Oomoo`3oOomjOol001aoo`03001oogoo01Eo
o`03001oogoo0?moogYoo`0077oo00<007ooOol057oo00<007ooOol0ogooNgoo000LOol00`00Oomo
o`0COol00`00Oomoo`3oOomlOol001aoo`03001oogoo01=oo`03001oogoo0?moogaoo`0077oo00<0
07ooOol04Woo00<007ooOol0ogooOGoo000LOol2000COol00`00Oomoo`3oOommOol001aoo`03001o
ogoo015oo`03001oogoo0?moogioo`0077oo00<007ooOol04Goo00<007ooOol0ogooOWoo000LOol0
0`00Oomoo`0@Ool00`00Oomoo`3oOomoOol001aoo`03001oogoo00moo`03001oogoo0?mooh1oo`00
77oo00<007ooOol03goo00<007ooOol0ogooP7oo000LOol00`00Oomoo`0>Ool00`00Oomoo`3oOon1
Ool001aoo`8000moo`03001oogoo0?mooh5oo`0077oo00<007ooOol03Goo00<007ooOol0ogooPWoo
000LOol00`00Oomoo`0=Ool00`00Oomoo`3oOon2Ool001aoo`03001oogoo00aoo`03001oogoo0?mo
oh=oo`0077oo00<007ooOol037oo00<007ooOol0ogooPgoo000LOol00`00Oomoo`0;Ool00`00Oomo
o`3oOon4Ool001aoo`8000aoo`03001oogoo0?moohAoo`0077oo00<007ooOol02Woo00<007ooOol0
ogooQGoo000LOol00`00Oomoo`0:Ool00`00Oomoo`3oOon5Ool000Moo`@000Eoo`@000Qoo`03001o
ogoo00Uoo`03001oogoo0?moohIoo`001Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001o
ogoo00Eoo`03001oogoo00Uoo`03001oogoo0?moohIoo`002goo00<007ooOol01Woo00<007ooOol0
1Goo00<007ooOol027oo00<007ooOol0ogooQgoo000;Ool00`00Oomoo`06Ool00`00Oomoo`05Ool3
0008Ool00`00Oomoo`3oOon7Ool000Uoo`8000Uoo`03001oogoo00Eoo`03001oogoo00Moo`03001o
ogoo0?moohQoo`002goo00<007ooOol00Woo100027oo00<007ooOol01goo00<007ooOol0ogooR7oo
000;Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`06Ool2ON3oOon:Ool000Ioo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo00Aoo`Imh?moohQoo`001goo1000
1Goo1@001goo00<007ooOol017oo1WgPogooR7oo000LOol00`00Oomoo`03Ool8ON3oOon7Ool001ao
o`8000Aoo`Qmh?moohMoo`0077oo00<007ooOol017oo1WgPogooR7oo000LOol00`00Oomoo`04Ool6
ON3oOon8Ool001aoo`03001oogoo00=oo`03001oogoo009mh?moohYoo`0077oo00<007ooOol00goo
00<007ooOol0ogooS7oo000LOol00`00Oomoo`02Ool00`00Oomoo`3oOon=Ool001aoo`8000=oo`03
001oogoo0?mooheoo`0077oo00D007ooOomoo`000?mooi1oo`0077oo00D007ooOomoo`000?mooi1o
o`0077oo00@007ooOol00?mooi5oo`0077oo00@007ooOol00?mooi5oo`0077oo00@007ooOol00?mo
oi5oo`0077oo0`00ogooTWoo000LOol00`00Ool0003oOonBOol001aoo`03001oo`000?mooi9oo`00
77oo0WgPogooTgoo000JOol6ON3oOonAOol001Yoo`Imh?mooi5oo`006Goo27gPogooT7oo000IOol8
ON3oOon@Ool001Yoo`Imh?mooi5oo`006Woo1WgPogooTGoo0008Ool40004Ool40008Ool2ON3oOonC
Ool000Yoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo0?mooi9oo`00
2Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0ogooTWoo0006Ool6
0003Ool00`00Oomoo`02Ool00`00Oomoo`05Ool3003oOonBOol000Moo`04001oogoo0004Ool00`00
Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`3oOonBOol000Moo`04001oogoo0004Ool00`00Oomo
o`02Ool00`00Oomoo`05Ool00`00Oomoo`3oOonBOol000Qoo`03001oo`0000Aoo`03001oogoo009o
o`03001oogoo00Eoo`03001oogoo0?mooi9oo`0027oo00<007oo000017oo00<007ooOol00Woo00<0
07ooOol01Goo00<007ooOol0ogooTWoo0009Ool20005Ool40008Ool00`00Oomoo`3oOonBOol001ao
o`03001oogoo0?mooi9oo`0077oo0P00ogooTgoo000LOol00`00Oomoo`3oOonBOol001aoo`03001o
ogoo0?mooi9oo`0077oo00<007ooOol0ogooTWoo000LOol00`00Oomoo`3oOonBOol001aoo`03001o
ogoo0?mooi9oo`0077oo0P00ogooTgoo000LOol00`00Oomoo`3oOonBOol001aoo`03001oogoo0?mo
oi9oo`0077oo00<007ooOol0ogooTWoo000LOol00`00Oomoo`3oOonBOol001aoo`03001oogoo0?mo
oi9oo`0077oo0P00ogooTgoo000LOol00`00Oomoo`3oOonBOol001aoo`03001oogoo0?mooi9oo`00
77oo00<007ooOol0ogooTWoo000LOol00`00Oomoo`3oOonBOol001aoo`03001oogoo0?mooi9oo`00
77oo00<007ooOol0ogooTWoo000LOol2003oOonCOol001aoo`03001oogoo0?mooi9oo`0027oo1000
17oo100027oo00<007ooOol0ogooTWoo000:Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`05Ool00`00Oomoo`3oOonBOol000Yoo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo0?mo
oi9oo`001Woo1P0027oo00<007ooOol01Goo00<007ooOol0ogooTWoo0007Ool01000Oomoo`002Goo
00<007ooOol01Goo0`00ogooTWoo0007Ool01000Oomoo`001Goo100027oo00<007ooOol0ogooTWoo
0008Ool00`00Ool00005Ool00`00Oomoo`09Ool00`00Oomoo`3oOonBOol000Qoo`03001oo`0000Eo
o`03001oogoo00Uoo`03001oogoo0?mooi9oo`002Goo0P001Goo1@001goo00<007ooOol0ogooTWoo
000LOol00`00Oomoo`3oOonBOol001aoo`800?mooi=oo`0077oo00<007ooOol0ogooTWoo000LOol0
0`00Oomoo`3oOonBOol001aoo`03001oogoo0?mooi9oo`0077oo00<007ooOol0ogooTWoo000LOol0
0`00Oomoo`3oOonBOol001aoo`03001oogoo0?mooi9oo`0077oo0P00ogooTgoo000LOol00`00Oomo
o`3oOonBOol001aoo`03001oogoo0?mooi9oo`0077oo00<007ooOol0ogooTWoo000LOol00`00Oomo
o`3oOonBOol001aoo`03001oogoo0?mooi9oo`0077oo0P00ogooTgoo000LOol00`00Oomoo`3oOonB
Ool001aoo`03001oogoo0?mooi9oo`0077oo00<007ooOol0ogooTWoo000LOol00`00Oomoo`3oOonB
Ool001aoo`03001oogoo0?mooi9oo`0077oo0P00ogooTgoo000LOol00`00Oomoo`3oOonBOol001ao
o`03001oogoo0?mooi9oo`001goo10001Goo100027oo00<007ooOol0ogooTWoo0006Ool00`00Oomo
o`02Ool01@00Oomoogoo000017oo00<007ooOol01Goo00<007ooOol0ogooTWoo000;Ool01@00Oomo
ogoo000017oo00<007ooOol01Goo00<007ooOol0ogooTWoo000;Ool01@00Oomoogoo000017oo00<0
07ooOol01Goo00<007ooOol0ogooTWoo000;Ool01@00Oomoogoo000017oo00<007ooOol01Goo0`00
ogooTWoo0007Ool40004Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`3oOonBOol000Mo
o`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo0?mooi9oo`001goo00<0
07ooOol01Goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0ogooTWoo0007Ool50004Ool4
0008Ool00`00Oomoo`3oOonBOol001aoo`03001oogoo0?mooi9oo`0077oo0P00ogooTgoo000LOol0
0`00Oomoo`3oOonBOol001aoo`03001oogoo0?mooi9oo`0077oo00<007ooOol0ogooTWoo000LOol0
0`00Oomoo`3oOonBOol001aoo`03001oogoo0?mooi9oo`0077oo0P00ogooTgoo000LOol00`00Oomo
o`3oOonBOol001aoo`03001oogoo0?mooi9oo`0077oo00<007ooOol0ogooTWoo000LOol00`00Oomo
o`3oOonBOol001aoo`03001oogoo0?mooi9oo`0077oo00<007ooOol0ogooTWoo000LOol2003oOonC
Ool001aoo`03001oogoo0?mooi9oo`0077oo00<007ooOol0ogooTWoo000LOol00`00Oomoo`3oOonB
Ool001aoo`03001oogoo0?mooi9oo`0077oo00<007ooOol0ogooTWoo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-29.1965, 12.0842, 1.56077, \
0.235842}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell["Method 1", "Text",
  Background->RGBColor[0, 1, 1]],

Cell["It is taken by defauld  AMAD 5 .", "Text"],

Cell["\<\
They are fitted the \"experimental\" data versus the retention function for \
an  intake \"1\" in t=0 assuming AMAD 5 .    \
\>", "MathCaption"],

Cell[BoxData[
    \(\(sampleLung1 = 
        Transpose[{Map[uraniumLungRet[#, 1, \ 5] &, 
              daymeasured], \(Drop[Transpose[sampleLung], 
                1]\)[\([1]\)]}];\)\)], "Input",
  CellLabel->"In[15]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(regress\  = 
      Regress[sampleLung1, {a}\ , a, \ IncludeConstant \[Rule] \ False, \ 
        RegressionReport \[Rule] \ {BestFitParameters, FitResiduals, 
            ParameterConfidenceRegion}]\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \({BestFitParameters \[Rule] {608.5453227642292`}, 
      FitResiduals \[Rule] {\(-0.11457010841079551`\), 
          0.7767960307602095`, \(-1.0343456183662596`\), 0.5397031631116178`, 
          0.09310268223250873`, 0.6600025607916322`, 0.5430092599493541`, 
          0.3470350133070461`, \(-2.3522009742471646`\)}, 
      ParameterConfidenceRegion \[Rule] 
        Ellipsoid[{608.5453227642292`}, {18.144030090819143`}]}\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[
      Evaluate[uraniumLungRet[t, BestFitParameters /. regress, \ 5]], {t, 0, 
        400}, \ \ Epilog \[RuleDelayed] 
        Map[{Orange, PointSize[ .02], Point[##]} &, sampleLung]]\)], "Input",
  CellLabel->"In[17]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00238095 -0.253343 0.0171731 [
[.2619 -0.00825 -9 -9 ]
[.2619 -0.00825 9 0 ]
[.5 -0.00825 -9 -9 ]
[.5 -0.00825 9 0 ]
[.7381 -0.00825 -9 -9 ]
[.7381 -0.00825 9 0 ]
[.97619 -0.00825 -9 -9 ]
[.97619 -0.00825 9 0 ]
[.01131 .09012 -12 -4.5 ]
[.01131 .09012 0 4.5 ]
[.01131 .17598 -12 -4.5 ]
[.01131 .17598 0 4.5 ]
[.01131 .26185 -12 -4.5 ]
[.01131 .26185 0 4.5 ]
[.01131 .34772 -12 -4.5 ]
[.01131 .34772 0 4.5 ]
[.01131 .43358 -12 -4.5 ]
[.01131 .43358 0 4.5 ]
[.01131 .51945 -12 -4.5 ]
[.01131 .51945 0 4.5 ]
[.01131 .60531 -12 -4.5 ]
[.01131 .60531 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .00425 m
.2619 .0105 L
s
[(100)] .2619 -0.00825 0 1 Mshowa
.5 .00425 m
.5 .0105 L
s
[(200)] .5 -0.00825 0 1 Mshowa
.7381 .00425 m
.7381 .0105 L
s
[(300)] .7381 -0.00825 0 1 Mshowa
.97619 .00425 m
.97619 .0105 L
s
[(400)] .97619 -0.00825 0 1 Mshowa
.125 Mabswid
.07143 .00425 m
.07143 .008 L
s
.11905 .00425 m
.11905 .008 L
s
.16667 .00425 m
.16667 .008 L
s
.21429 .00425 m
.21429 .008 L
s
.30952 .00425 m
.30952 .008 L
s
.35714 .00425 m
.35714 .008 L
s
.40476 .00425 m
.40476 .008 L
s
.45238 .00425 m
.45238 .008 L
s
.54762 .00425 m
.54762 .008 L
s
.59524 .00425 m
.59524 .008 L
s
.64286 .00425 m
.64286 .008 L
s
.69048 .00425 m
.69048 .008 L
s
.78571 .00425 m
.78571 .008 L
s
.83333 .00425 m
.83333 .008 L
s
.88095 .00425 m
.88095 .008 L
s
.92857 .00425 m
.92857 .008 L
s
.25 Mabswid
0 .00425 m
1 .00425 L
s
.02381 .09012 m
.03006 .09012 L
s
[(20)] .01131 .09012 1 0 Mshowa
.02381 .17598 m
.03006 .17598 L
s
[(25)] .01131 .17598 1 0 Mshowa
.02381 .26185 m
.03006 .26185 L
s
[(30)] .01131 .26185 1 0 Mshowa
.02381 .34772 m
.03006 .34772 L
s
[(35)] .01131 .34772 1 0 Mshowa
.02381 .43358 m
.03006 .43358 L
s
[(40)] .01131 .43358 1 0 Mshowa
.02381 .51945 m
.03006 .51945 L
s
[(45)] .01131 .51945 1 0 Mshowa
.02381 .60531 m
.03006 .60531 L
s
[(50)] .01131 .60531 1 0 Mshowa
.125 Mabswid
.02381 .02143 m
.02756 .02143 L
s
.02381 .0386 m
.02756 .0386 L
s
.02381 .05577 m
.02756 .05577 L
s
.02381 .07295 m
.02756 .07295 L
s
.02381 .10729 m
.02756 .10729 L
s
.02381 .12447 m
.02756 .12447 L
s
.02381 .14164 m
.02756 .14164 L
s
.02381 .15881 m
.02756 .15881 L
s
.02381 .19316 m
.02756 .19316 L
s
.02381 .21033 m
.02756 .21033 L
s
.02381 .2275 m
.02756 .2275 L
s
.02381 .24468 m
.02756 .24468 L
s
.02381 .27902 m
.02756 .27902 L
s
.02381 .2962 m
.02756 .2962 L
s
.02381 .31337 m
.02756 .31337 L
s
.02381 .33054 m
.02756 .33054 L
s
.02381 .36489 m
.02756 .36489 L
s
.02381 .38206 m
.02756 .38206 L
s
.02381 .39923 m
.02756 .39923 L
s
.02381 .41641 m
.02756 .41641 L
s
.02381 .45075 m
.02756 .45075 L
s
.02381 .46793 m
.02756 .46793 L
s
.02381 .4851 m
.02756 .4851 L
s
.02381 .50227 m
.02756 .50227 L
s
.02381 .53662 m
.02756 .53662 L
s
.02381 .55379 m
.02756 .55379 L
s
.02381 .57097 m
.02756 .57097 L
s
.02381 .58814 m
.02756 .58814 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .44239 L
.02605 .42013 L
.02729 .40842 L
.02846 .40232 L
.02954 .3983 L
.03053 .39516 L
.03279 .38877 L
.04262 .36349 L
.06244 .31938 L
.0825 .28252 L
.10458 .24915 L
.14393 .20387 L
.18422 .17081 L
.22299 .14749 L
.26421 .12881 L
.30392 .11486 L
.34212 .104 L
.38276 .09435 L
.42189 .08637 L
.46347 .07888 L
.50354 .07236 L
.54209 .06655 L
.58309 .06076 L
.62258 .05547 L
.66055 .05058 L
.70098 .04557 L
.73989 .04088 L
.78125 .03604 L
.82109 .0315 L
.85942 .02722 L
.9002 .02277 L
.93947 .01857 L
.97619 .01472 L
s
1 .5 0 r
.02 w
.02619 .41641 Mdot
.04762 .36489 Mdot
.09524 .24468 Mdot
.16667 .19316 Mdot
.2381 .14164 Mdot
.30952 .12447 Mdot
.45238 .09012 Mdot
.66667 .05577 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[17]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo001`Ool7
0003Ool40005Ool40018Ool60004Ool40005Ool4001:Ool40005Ool40005Ool4001:Ool40004Ool4
0005Ool4000;Ool007=oo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`15Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo
04Ioo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol0BGoo
00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Qoo`00Lgoo00<0
07ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo04Ioo`03001oogoo00Eo
o`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`1;Ool01@00Oomoogoo000017oo00D0
07ooOomoo`0000Aoo`03001oogoo04Uoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`08Ool007=oo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`17Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool0Bgoo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`15Ool60003Ool00`00
Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol027oo001cOol00`00Oomoo`03Ool00`00Oomo
o`02Ool01@00Oomoogoo000017oo00<007ooOol0B7oo00<007ooOol00goo00<007ooOol00Woo00D0
07ooOomoo`0000Aoo`03001oogoo04Uoo`8000Aoo`03001oogoo009oo`05001oogooOol00004Ool0
0`00Oomoo`16Ool01000Oomoo`0017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo
00Qoo`00Lgoo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo04Uo
o`03001oogoo009oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`1;Ool01@00Oomo
ogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo04Ioo`04001oogoo0004Ool00`00Oomoo`02
Ool01@00Oomoogoo000017oo00<007ooOol027oo001cOol00`00Oomoo`03Ool00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00<007ooOol0AGoo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001o
ogooOol00004Ool00`00Oomoo`1;Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001o
ogoo04Moo`03001oo`0000Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`08Ool0
075oo`<000Eoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`15Ool00`00Oomoo`02
Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo04Ioo`03001oogoo009oo`05
001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol0Agoo00<007oo000017oo00<007oo
Ool00Woo00D007ooOomoo`0000Aoo`03001oogoo00Qoo`00Lgoo00<007ooOol017oo10001Goo1000
BGoo10001Goo10001Goo1000BWoo10001Goo10001Goo1000Bgoo0P001Goo10001Goo10002goo003o
OonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo000MOol00`00Oomoo`3o
OonAOol001eoo`03001oogoo0?mooi5oo`0057ooo`00TP002goo000MOol00`00Oomoo`0@Ool00`00
Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00
Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00
Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00
Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0COol001eo
o`03001oogoo011oo`03001oogoo011oo`03001oogoo011oo`03001oogoo011oo`03001oogoo011o
o`03001oogoo015oo`03001oogoo011oo`03001oogoo011oo`03001oogoo011oo`03001oogoo011o
o`03001oogoo011oo`03001oogoo011oo`03001oogoo011oo`03001oogoo011oo`03001oogoo011o
o`03001oogoo011oo`03001oogoo011oo`03001oogoo011oo`03001oogoo011oo`03001oogoo011o
o`03001oogoo01=oo`007Goo00<007ooOol0G7oo00<007ooOol0GGoo00<007ooOol0G7oo00<007oo
Ool0G7oo00<007ooOol04goo000MOol00`00Oomoo`3oOomhOol4000EOol001eoo`03001oogoo0?mo
og5oo`L001Uoo`007Goo00<007ooOol0ogooJWoo1`0087oo000MOol3003oOomROol8000WOol001eo
o`03001oogoo0?mooeIoo``002moo`007Goo00<007ooOol0ogooBWoo3000>goo000MOol00`00Oomo
o`3oOom2Ool80017Ool001eoo`03001oogoo0?moocYoo`P004moo`007Goo00<007ooOol0ogoo<Woo
2000Egoo000MOol00`00Oomoo`3oOolZOol8001OOol001eoo`<00?moob9oo`P006Moo`007Goo00<0
07ooOol0ogoo6Woo2000Kgoo000MOol00`00Oomoo`3oOolBOol8001gOol001eoo`03001oogoo0?io
o`9mh0Uoo`P007moo`007Goo00<007ooOol0o7oo1WgP1`00Qgoo000MOol00`00Oomoo`3iOol30006
ON2>Ool001eoo`03001oogoo0?5oo`P0009oo`Qmh8eoo`007Goo0`00jWoo1`002Woo27gPSGoo000M
Ool00`00Oomoo`3ROol8000BOol6ON2>Ool001eoo`03001oogoo0=Yoo`P001Yoo`Imh8ioo`007Goo
00<007ooOol0dWoo200097oo0WgPT7oo000MOol00`00Oomoo`3:Ool8002nOol001eoo`03001oogoo
0<9oo`P00<Ioo`007Goo00<007ooOol0^goo1`00cWoo000MOol3002fOol5003EOol001eoo`03001o
ogoo0;1oo`H00=Yoo`007Goo00<007ooOol0Zgoo1@00h7oo0007Ool60004Ool40008Ool00`00Oomo
o`2UOol30002ON000`00Oomoo`3SOol000Moo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`05Ool00`00Oomoo`2OOol600000gooON1mh004ON3TOol000Qoo`03001oogoo00Eoo`03001o
ogoo009oo`03001oogoo00Eoo`03001oogoo09Yoo`D000Moo`Imh>Aoo`002Goo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0UGoo1@002goo27gPhgoo000:Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`05Ool4002?Ool5000@Ool8ON3SOol000]oo`03001oogoo
009oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo08aoo`@001Ioo`Imh>Aoo`001goo00<0
07ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Eoo`03001oogoo08Qoo`@001Yoo`Imh>Ao
o`001goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Eoo`03001oogoo08Aoo`@0
021oo`9mh>Ioo`0027oo10001Goo100027oo00<007ooOol0P7oo1000ogoo3Goo000MOol00`00Oomo
o`1lOol4003oOolAOol001eoo`<007Qoo`@00?mooaEoo`007Goo00<007ooOol0M7oo1000ogoo6Goo
000MOol00`00Oomoo`1`Ool4003oOolMOol001eoo`03001oogoo06aoo`@00?moob5oo`007Goo00<0
07ooOol0JWoo0P000goo0WgPogoo87oo000MOol00`00Oomoo`1WOol30003Ool6ON3oOolNOol001eo
o`03001oogoo06Aoo`<000Ioo`Imh?mooaioo`007Goo0`00HWoo0P0027oo27gPogoo7Goo000MOol0
0`00Oomoo`1OOol3000:Ool8ON3oOolMOol001eoo`03001oogoo05aoo`<000ioo`Imh?mooaioo`00
7Goo00<007ooOol0FWoo0P004Goo1WgPogoo7Woo000MOol00`00Oomoo`1BOol2ON04Ool2000EOol2
ON3oOolPOol001eoo`03001oogoo051oo`Imh0800?moocUoo`007Goo00<007ooOol0D7oo1WgPogoo
>goo000MOol3001?Ool8ON3oOoljOol001eoo`03001oogoo04moo`Qmh?moocYoo`007Goo00<007oo
Ool0CGoo0P0000=ooggPON0017gPogoo>goo000MOol00`00Oomoo`1;Ool20003Ool6ON3oOolkOol0
01eoo`03001oogoo04Yoo`03001oogoo00Eoo`9mh?mooceoo`007Goo00<007ooOol0B7oo0P00ogoo
Agoo000MOol00`00Oomoo`16Ool2003oOom9Ool001eoo`<004Eoo`03001oogoo0?moodUoo`007Goo
00<007ooOol0@goo0P00ogooC7oo000MOol00`00Oomoo`12Ool00`00Oomoo`3oOom<Ool000Moo`H0
00Aoo`@000Qoo`03001oogoo041oo`800?moodmoo`001goo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`03001oogoo00Eoo`03001oogoo03ioo`800?mooe5oo`0027oo00<007ooOol02Woo00<007oo
Ool01Goo00<007ooOol0?Goo00<007ooOol0ogooDGoo0009Ool00`00Oomoo`09Ool00`00Oomoo`05
Ool00`00Oomoo`0lOol00`00Oomoo`3oOomBOol000Yoo`03001oogoo00Qoo`03001oogoo00Eoo`@0
03Uoo`800?mooeEoo`002goo00<007ooOol00goo100027oo00<007ooOol0>Goo00<007ooOol0ogoo
EGoo0007Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`0hOol00`00
Oomoo`3oOomFOol000Moo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo
03Ioo`9mh?mooeUoo`0027oo10001Goo1@001goo00<007ooOol0=7oo1WgPogooEgoo000MOol00`00
Oomoo`0dOol6ON3oOomGOol001eoo`03001oogoo03=oo`Qmh?mooeIoo`007Goo0`00<Woo00<007gP
ON001WgPogooEWoo000MOol00`00Oomoo`0aOol00`00Oomoo`06ON3oOomGOol001eoo`03001oogoo
02moo`8000=oo`Imh?mooeMoo`007Goo00<007ooOol0;Woo00<007ooOol01Goo0WgPogooFGoo000M
Ool00`00Oomoo`0]Ool00`00Oomoo`3oOomQOol001eoo`03001oogoo02aoo`03001oogoo0?moof9o
o`007Goo00<007ooOol0:goo00<007ooOol0ogooHgoo000MOol3000ZOol00`00Oomoo`3oOomTOol0
01eoo`03001oogoo02Uoo`03001oogoo0?moofEoo`007Goo00<007ooOol0:Goo00<007ooOol0ogoo
IGoo000MOol00`00Oomoo`0XOol00`00Oomoo`3oOomVOol001eoo`03001oogoo02Moo`03001oogoo
0?moofMoo`007Goo00<007ooOol09Woo00<007ooOol0ogooJ7oo000MOol00`00Oomoo`0UOol00`00
Oomoo`3oOomYOol001eoo`<002Aoo`03001oogoo0?moofYoo`007Goo00<007ooOol08goo00<007oo
Ool0ogooJgoo000MOol00`00Oomoo`0ROol00`00Oomoo`3oOom/Ool001eoo`03001oogoo01Uoo`9m
h0Ioo`03001oogoo0?moofeoo`007Goo00<007ooOol05goo1WgP17oo00<007ooOol0ogooKGoo000M
Ool00`00Oomoo`0GOol6ON03Ool00`00Oomoo`3oOom^Ool001eoo`<001Ioo`Qmh003Ool007oo0?mo
og1oo`007Goo00<007ooOol05Woo27gP00<007ooOol0ogooL7oo000MOol00`00Oomoo`0GOol6ON00
0`00Oomoo`3oOomaOol001eoo`03001oogoo01Moo`Imh?moogAoo`0027oo10001Goo100027oo00<0
07ooOol06Goo0WgP00=oo`00Ool0ogooLgoo0007Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo
00<007ooOol01Goo00<007ooOol06goo00<007ooOol0ogooLgoo000<Ool01@00Oomoogoo000017oo
00<007ooOol01Goo00<007ooOol06goo00<007ooOol0ogooLgoo000<Ool01@00Oomoogoo000017oo
00<007ooOol01Goo10006Goo00<007ooOol0ogooM7oo000:Ool20004Ool00`00Oomoo`02Ool00`00
Oomoo`05Ool00`00Oomoo`0JOol00`00Oomoo`3oOomdOol000aoo`05001oogooOol00004Ool00`00
Oomoo`05Ool00`00Oomoo`0IOol00`00Oomoo`3oOomeOol000aoo`05001oogooOol00004Ool00`00
Oomoo`05Ool00`00Oomoo`0HOol00`00Oomoo`3oOomfOol000Moo`03001oogoo009oo`05001oogoo
Ool00004Ool00`00Oomoo`05Ool00`00Oomoo`0HOol00`00Oomoo`3oOomfOol000Qoo`@000Eoo`@0
00Qoo`03001oogoo01Moo`03001oogoo0?moogMoo`007Goo00<007ooOol05goo00<007ooOol0ogoo
Mgoo000MOol3000FOol00`00Oomoo`3oOomhOol001eoo`03001oogoo01Ioo`03001oogoo0?moogQo
o`007Goo00<007ooOol05Goo00<007ooOol0ogooNGoo000MOol00`00Oomoo`0DOol00`00Oomoo`3o
OomjOol001eoo`03001oogoo01Aoo`03001oogoo0?moogYoo`007Goo00<007ooOol04goo00<007oo
Ool0ogooNgoo000MOol00`00Oomoo`0COol00`00Oomoo`3oOomkOol001eoo`<0019oo`03001oogoo
0?moogaoo`007Goo00<007ooOol04Woo00<007ooOol0ogooO7oo000MOol00`00Oomoo`0AOol00`00
Oomoo`3oOommOol001eoo`03001oogoo011oo`03001oogoo0?moogioo`007Goo00<007ooOol047oo
00<007ooOol0ogooOWoo000MOol00`00Oomoo`0?Ool00`00Oomoo`3oOomoOol001eoo`03001oogoo
00moo`03001oogoo0?moogmoo`007Goo0`003Woo00<007ooOol0ogooP7oo000MOol00`00Oomoo`0>
Ool00`00Oomoo`3oOon0Ool001eoo`03001oogoo00eoo`03001oogoo0?mooh5oo`007Goo00<007oo
Ool03Goo00<007ooOol0ogooPGoo000MOol00`00Oomoo`0<Ool00`00Oomoo`3oOon2Ool001eoo`03
001oogoo00aoo`03001oogoo0?mooh9oo`007Goo00<007ooOol02goo00<007ooOol0ogooPgoo000M
Ool3000;Ool00`00Oomoo`3oOon3Ool001eoo`03001oogoo00Yoo`03001oogoo0?moohAoo`007Goo
00<007ooOol02Woo00<007ooOol0ogooQ7oo0008Ool40005Ool40008Ool00`00Oomoo`09Ool00`00
Oomoo`3oOon5Ool000Moo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool00`00Oomoo`3oOon5Ool000aoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo
00Uoo`03001oogoo0?moohEoo`0037oo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol027oo
00<007ooOol0ogooQWoo000:Ool20009Ool00`00Oomoo`05Ool40007Ool00`00Oomoo`3oOon6Ool0
00aoo`03001oogoo009oo`@000Qoo`03001oogoo00Moo`03001oogoo0?moohMoo`0037oo00<007oo
Ool00Woo00<007ooOol02Goo00<007ooOol01goo00<007ooOol0ogooQgoo0007Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`06Ool2ON3oOon9Ool000Qoo`@000Eoo`D0
00Moo`03001oogoo00Aoo`Imh?moohMoo`007Goo00<007ooOol017oo1WgPogooQgoo000MOol00`00
Oomoo`03Ool8ON3oOon6Ool001eoo`<000=oo`Qmh?moohIoo`007Goo00<007ooOol017oo1WgPogoo
Qgoo000MOol00`00Oomoo`04Ool6ON3oOon7Ool001eoo`03001oogoo00=oo`03001oogoo009mh?mo
ohUoo`007Goo00<007ooOol00goo00<007ooOol0ogooRgoo000MOol00`00Oomoo`03Ool00`00Oomo
o`3oOon;Ool001eoo`<0009oo`03001oogoo0?moohaoo`007Goo00<007ooOol00Woo00<007ooOol0
ogooS7oo000MOol01@00Oomoogoo0000ogooSgoo000MOol01@00Oomoogoo0000ogooSgoo000MOol0
1@00Oomoogoo0000ogooSgoo000MOol01000Oomoo`00ogooT7oo000MOol01000Oomoo`00ogooT7oo
000MOol3003oOonAOol001eoo`03001oo`000?mooi5oo`007Goo00<007oo0000ogooTGoo000MOol0
0`00Ool0003oOonAOol001eoo`03001mh7gP0?mooi5oo`0077oo1WgPogooSgoo000LOol6ON3oOon?
Ool001]oo`Qmh?moohioo`006goo27gPogooSWoo000LOol6ON3oOon?Ool000Uoo`@000Aoo`@000Mo
o`Imh?moohmoo`002goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Goo00<007gPON00
ogooTGoo000;Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool2003oOonBOol000Mo
o`H000=oo`03001oogoo009oo`03001oogoo00Eoo`800?mooi9oo`0027oo00@007ooOol000Aoo`03
001oogoo009oo`03001oogoo00Eoo`@00?mooi1oo`0027oo00@007ooOol000Aoo`03001oogoo009o
o`03001oogoo00Eoo`800?mooi9oo`002Goo00<007oo000017oo00<007ooOol00Woo00<007ooOol0
1Goo0P00ogooTWoo0009Ool00`00Ool00004Ool00`00Oomoo`02Ool00`00Oomoo`05Ool2003oOonB
Ool000Yoo`8000Eoo`@000Qoo`800?mooi9oo`007Goo0P00ogooTWoo000MOol2003oOonBOol001eo
o`<00?mooi5oo`007Goo0P00ogooTWoo000MOol2003oOonBOol001eoo`800?mooi9oo`007Goo0P00
ogooTWoo000MOol2003oOonBOol001eoo`800?mooi9oo`007Goo0`00ogooTGoo000MOol2003oOonB
Ool001eoo`800?mooi9oo`007Goo0P00ogooTWoo000MOol2003oOonBOol001eoo`800?mooi9oo`00
7Goo0P00ogooTWoo000MOol3003oOonAOol001eoo`800?mooi9oo`007Goo0P00ogooTWoo000MOol2
003oOonBOol001eoo`800?mooi9oo`007Goo0P00ogooTWoo000MOol3003oOonAOol001eoo`800?mo
oi9oo`007Goo0P00ogooTWoo000MOol2003oOonBOol000Uoo`@000Aoo`@000Qoo`800?mooi9oo`00
2goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Goo0P00ogooTWoo000;Ool00`00Oomo
o`07Ool00`00Oomoo`05Ool2003oOonBOol000Moo`H000Qoo`03001oogoo00Eoo`@00?mooi1oo`00
27oo00@007ooOol000Uoo`03001oogoo00Eoo`800?mooi9oo`0027oo00@007ooOol000Eoo`@000Qo
o`03001oogoo0?mooi5oo`002Goo00<007oo00001Goo00<007ooOol02Goo00<007ooOol0ogooTGoo
0009Ool00`00Ool00005Ool00`00Oomoo`09Ool00`00Oomoo`3oOonAOol000Yoo`8000Eoo`D000Mo
o`03001oogoo0?mooi5oo`007Goo00<007ooOol0ogooTGoo000MOol3003oOonAOol001eoo`03001o
ogoo0?mooi5oo`007Goo00<007ooOol0ogooTGoo000MOol00`00Oomoo`3oOonAOol001eoo`03001o
ogoo0?mooi5oo`007Goo00<007ooOol0ogooTGoo000MOol00`00Oomoo`3oOonAOol001eoo`<00?mo
oi5oo`007Goo00<007ooOol0ogooTGoo000MOol00`00Oomoo`3oOonAOol001eoo`03001oogoo0?mo
oi5oo`007Goo00<007ooOol0ogooTGoo000MOol00`00Oomoo`3oOonAOol001eoo`03001oogoo0?mo
oi5oo`007Goo0`00ogooTGoo000MOol00`00Oomoo`3oOonAOol001eoo`03001oogoo0?mooi5oo`00
7Goo00<007ooOol0ogooTGoo000MOol00`00Oomoo`3oOonAOol001eoo`03001oogoo0?mooi5oo`00
7Goo00<007ooOol0ogooTGoo000MOol3003oOonAOol001eoo`03001oogoo0?mooi5oo`007Goo00<0
07ooOol0ogooTGoo0008Ool40005Ool40008Ool00`00Oomoo`3oOonAOol000Moo`03001oogoo009o
o`05001oogooOol00004Ool00`00Oomoo`05Ool00`00Oomoo`3oOonAOol000aoo`05001oogooOol0
0004Ool00`00Oomoo`05Ool00`00Oomoo`3oOonAOol000aoo`05001oogooOol00004Ool00`00Oomo
o`05Ool00`00Oomoo`3oOonAOol000aoo`05001oogooOol00004Ool00`00Oomoo`05Ool4003oOon@
Ool000Qoo`@000Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo0?mooi5oo`0027oo00<0
07ooOol01Goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0ogooTGoo0008Ool00`00Oomo
o`05Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`3oOonAOol000Qoo`D000Aoo`@000Qo
o`03001oogoo0?mooi5oo`007Goo00<007ooOol0ogooTGoo003oOonaOol00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-31.0777, 12.308, 1.57373, \
0.218188}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[17]="]
}, Open  ]],

Cell["Method 2", "Text",
  Background->RGBColor[0, 1, 1]],

Cell["\<\
It is taken by defauld  AMAD 5, but they are taken accoung the lung counter \
uncertainties \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MLFit[sampleLungUnc, Evaluate[uraniumLungRet[t, 1, \ 5]], t]\)], "Input",\

  CellLabel->"In[18]:="],

Cell[BoxData[
    \({"Mean" \[Rule] 608.5453227642292`, 
      "s" \[Rule] 38.461241420137796`}\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell["Method 3", "Text",
  Background->RGBColor[0, 1, 1]],

Cell["\<\
Experimental data are fitted assuming unkown the intake and the AMAD, \
\>", "Text"],

Cell[BoxData[
    \(model[t_, int_?NumberQ, \ p_?NumberQ] := 
      uraniumLungRet[t, int, \ p]\)], "Input",
  CellLabel->"In[19]:="],

Cell[TextData[{
  "We obtain the best fit of intake and AMAD using ",
  StyleBox["FindFit", "Input"],
  " "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindFit[sampleLung, model[t, int, \ p], {{int, 500, 1000}, {p, 3, 10}}, 
        t] // Timing\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({129.735`\ Second, {int \[Rule] 666.1408736799293`, 
        p \[Rule] 5.519336324663032`}}\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["\<\
Here the model is the fitted using being accoung the lung counter \
uncertainties \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(FindMinimum[
        X2FitE[{int, \ p}, sampleLungUnc, model[t, int, \ p], \ \ \ t], {int, 
          500, 1000}\ , {p, 3, 10}] // Timing\)\)\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \({207.92200000000003`\ Second, {0.3341194220598622`, {int \[Rule] 
            666.1408757533676`, p \[Rule] 5.519336344627052`}}}\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["NMinimize", "Input"],
  " should be used when  we wish to establish some restrictions in the \
parameters. Ex.: \n",
  StyleBox["NMinimize[{X2FitE[{int,p},sampleLungUnc, model[t,int, p], t], 5\
\[LessEqual]p\[LessEqual]10},{int,p}] \n", "Input"],
  "but it will take a long time."
}], "Text"],

Cell["Method 4", "Text",
  Background->RGBColor[0, 1, 1]],

Cell["\<\
The speed of computation increase dramatically if it is used AMADfit[p] in \
place of AMADAdultW[p] . That  it is so because AMADfit[p] is an analytical \
expression obtained by fitting the numerical values of IDF while \
AMADAdultW[p] the IDF are obtained by numerical computation.  \
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(model1[t_, int_, \ p_]\), "=", 
        RowBox[{
          StyleBox["LungsRetention",
            "Input"], "[", \(int, AMADfit[p], S, \ t, 0\), "]"}]}], 
      ";"}]], "Input",
  CellLabel->"In[22]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindFit[sampleLung, 
        model1[t, int, \ p], {{int, 500, 1000}, {p, 3, 10}}, t] // 
      Timing\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \({0.5790000000000077`\ Second, {int \[Rule] 725.607907423642`, 
        p \[Rule] 6.219486881714645`}}\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(FindMinimum[
        X2FitE[{int, \ p}, sampleLungUnc, 
          model1[t, int, \ p], \ \ \ t], {int, 500, 1000}\ , {p, 3, 10}] // 
      Timing\)\)\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \({17.84299999999996`\ Second, {0.3343183570646734`, {int \[Rule] 
            725.6079135413817`, p \[Rule] 6.219486934334659`}}}\)], "Output",
  CellLabel->"Out[24]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[\(NMinimize[{X2FitE[{int, p}, sampleLungUnc, \ 
              model1[t, int, \ p], \ t], \ 
            5 \[LessEqual] p \[LessEqual] 10}, {int, p}]\),
        "Input"], 
      StyleBox[" ",
        "Input"], "//", "Timing"}]], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \({288.672`\ Second, {0.3343183572757002`, {int \[Rule] 
            725.5648732206251`, p \[Rule] 6.219129949173128`}}}\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell["\<\
The solution obtained is a better aproximation of the \"true\" parameters\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2", "SubsubsectionIcon"],

Cell["\<\
As a result of Chernobyl accident (26 april 1986) a male 39 years old and 80 \
kg (member of the public) has been exposed to continuous and unknown \
ingestion  of Cs-137 (This data has been supplied by Ansoborlo)\
\>", "Text"],

Cell["\<\
The results of the whole body activity retention are given below : {time \
after the accident (d), activity (Bq)} \
\>", "MathCaption"],

Cell[BoxData[
    \(\(wholeData = {{39, 300}, {58, 671}, {75, 737}, {130, 1661}, {156, 
            1846}, {170, 1882}, {198, 2247}, {234, 2493}, {263, 2926}, {297, 
            3224}, {325, 3608}, {374, 3883}, {408, 3773}, {432, 3723}, {494, 
            3195}, {520, 2740}, {556, 2469}, {592, 2375}, {625, 1954}, {682, 
            1614}, {744, 1221}, {800, 1174}, {880, 739}};\)\)], "Input",
  CellLabel->"In[26]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[wholeData, \ PlotJoined \[Rule] \ True]\)], "Input",
  CellLabel->"In[27]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00108225 0.0147151 0.000151585 [
[.24026 .00222 -9 -9 ]
[.24026 .00222 9 0 ]
[.45671 .00222 -9 -9 ]
[.45671 .00222 9 0 ]
[.67316 .00222 -9 -9 ]
[.67316 .00222 9 0 ]
[.88961 .00222 -9 -9 ]
[.88961 .00222 9 0 ]
[.01131 .1663 -24 -4.5 ]
[.01131 .1663 0 4.5 ]
[.01131 .31788 -24 -4.5 ]
[.01131 .31788 0 4.5 ]
[.01131 .46947 -24 -4.5 ]
[.01131 .46947 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.24026 .01472 m
.24026 .02097 L
s
[(200)] .24026 .00222 0 1 Mshowa
.45671 .01472 m
.45671 .02097 L
s
[(400)] .45671 .00222 0 1 Mshowa
.67316 .01472 m
.67316 .02097 L
s
[(600)] .67316 .00222 0 1 Mshowa
.88961 .01472 m
.88961 .02097 L
s
[(800)] .88961 .00222 0 1 Mshowa
.125 Mabswid
.07792 .01472 m
.07792 .01847 L
s
.13203 .01472 m
.13203 .01847 L
s
.18615 .01472 m
.18615 .01847 L
s
.29437 .01472 m
.29437 .01847 L
s
.34848 .01472 m
.34848 .01847 L
s
.4026 .01472 m
.4026 .01847 L
s
.51082 .01472 m
.51082 .01847 L
s
.56494 .01472 m
.56494 .01847 L
s
.61905 .01472 m
.61905 .01847 L
s
.72727 .01472 m
.72727 .01847 L
s
.78139 .01472 m
.78139 .01847 L
s
.8355 .01472 m
.8355 .01847 L
s
.94372 .01472 m
.94372 .01847 L
s
.99784 .01472 m
.99784 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .1663 m
.03006 .1663 L
s
[(1000)] .01131 .1663 1 0 Mshowa
.02381 .31788 m
.03006 .31788 L
s
[(2000)] .01131 .31788 1 0 Mshowa
.02381 .46947 m
.03006 .46947 L
s
[(3000)] .01131 .46947 1 0 Mshowa
.125 Mabswid
.02381 .04503 m
.02756 .04503 L
s
.02381 .07535 m
.02756 .07535 L
s
.02381 .10567 m
.02756 .10567 L
s
.02381 .13598 m
.02756 .13598 L
s
.02381 .19662 m
.02756 .19662 L
s
.02381 .22693 m
.02756 .22693 L
s
.02381 .25725 m
.02756 .25725 L
s
.02381 .28757 m
.02756 .28757 L
s
.02381 .3482 m
.02756 .3482 L
s
.02381 .37852 m
.02756 .37852 L
s
.02381 .40884 m
.02756 .40884 L
s
.02381 .43915 m
.02756 .43915 L
s
.02381 .49979 m
.02756 .49979 L
s
.02381 .5301 m
.02756 .5301 L
s
.02381 .56042 m
.02756 .56042 L
s
.02381 .59074 m
.02756 .59074 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.06602 .06019 m
.08658 .11643 L
.10498 .12643 L
.1645 .2665 L
.19264 .29454 L
.20779 .3 L
.2381 .35533 L
.27706 .39262 L
.30844 .45825 L
.34524 .50342 L
.37554 .56163 L
.42857 .60332 L
.46537 .58664 L
.49134 .57907 L
.55844 .49903 L
.58658 .43006 L
.62554 .38898 L
.6645 .37473 L
.70022 .31091 L
.7619 .25937 L
.829 .1998 L
.88961 .19268 L
.97619 .12674 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[27]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo001bOol60004Ool40005Ool40012Ool40004Ool40005Ool40011Ool4
0004Ool40005Ool40011Ool40005Ool40005Ool4000SOol0079oo`03001oogoo009oo`05001oogoo
Ool00004Ool01@00Oomoogoo000017oo00<007ooOol0@Goo00<007ooOol00Woo00<007ooOol00Woo
00D007ooOomoo`0000Aoo`03001oogoo03eoo`03001oogoo009oo`04001oogoo0004Ool01@00Oomo
ogoo000017oo00<007ooOol0?Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol0
0004Ool00`00Oomoo`0POol007=oo`03001oogoo00Eoo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`11Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool0?Goo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00004Ool00`00Oomoo`0mOol0
0`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo021oo`00M7oo
00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo03eoo`H000=oo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0mOol20003Ool01000Oomoo`0017oo00D0
07ooOomoo`0000Aoo`03001oogoo03eoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomo
ogoo000017oo00<007ooOol087oo001eOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo
000017oo00<007ooOol0?Woo00@007ooOol000Aoo`03001oogoo009oo`05001oogooOol00004Ool0
0`00Oomoo`0mOol00`00Ool000020003Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool0?Woo100017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo021oo`00MWoo00<0
07ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo03ioo`04001oogoo0004
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0?Goo00<007ooOol01Goo00<007oo
Ool00Woo00D007ooOomoo`0000Aoo`03001oogoo03eoo`03001oogoo009oo`05001oogooOol00004
Ool01@00Oomoogoo000017oo00<007ooOol087oo001bOol00`00Oomoo`02Ool01@00Oomoogoo0000
17oo00D007ooOomoo`0000Aoo`03001oogoo03moo`03001oo`0000Aoo`03001oogoo009oo`05001o
ogooOol00004Ool00`00Oomoo`0nOol00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo0000
17oo00<007ooOol0?Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool0
0`00Oomoo`0POol0079oo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo
00<007ooOol0?goo00<007oo000017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo
03moo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0mOol00`00
Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo021oo`00Lgoo1000
1Goo10001Goo1000@goo0P001Goo10001Goo1000@goo0`000goo10001Goo1000@Goo10001Goo1000
1Goo10008goo003oOonaOol00?mook5oo`00:7oo00<007ooOol0ogooQWoo000XOol00`00Oomoo`3o
Oon6Ool002Qoo`03001oogoo0?moohIoo`00:7oo00<007ooOol0ogooQWoo000XOol00`00Oomoo`3o
Oon6Ool002Qoo`03001oogoo0?moohIoo`007gooo`00T@000Goo000XOol00`00Oomoo`0COol00`00
Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0BOol00`00
Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0BOol00`00
Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00
Oomoo`0COol00`00Oomoo`0COol10001Ool002Qoo`03001oogoo01=oo`03001oogoo01=oo`03001o
ogoo019oo`03001oogoo01=oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001o
ogoo019oo`03001oogoo01=oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001o
ogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001o
ogoo01=oo`40005oo`00:7oo00<007ooOol0E7oo00<007ooOol0Dgoo00<007ooOol0E7oo00<007oo
Ool0Dgoo00<007ooOol0:goo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`00
:7oo00<007ooOol0ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`00
:7oo00<007ooOol0ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`00
:7oo0`00ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`00:7oo00<0
07ooOol0ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`00:7oo00<0
07ooOol03Woo00<007ooOol0ogooMGoo000XOol00`00Oomoo`0>Ool00`00Oomoo`3oOomeOol002Qo
o`03001oogoo00moo`03001oogoo0?moogAoo`00:7oo00<007ooOol03goo00<007ooOol0ogooM7oo
000XOol00`00Oomoo`0@Ool00`00Oomoo`3oOomcOol002Qoo`03001oogoo011oo`03001oogoo0?mo
og=oo`00:7oo00<007ooOol047oo00<007ooOol0ogooLgoo000XOol3000AOol00`00Oomoo`3oOomb
Ool002Qoo`03001oogoo015oo`03001oogoo0?moog9oo`00:7oo00<007ooOol04Woo00<007ooOol0
ogooLGoo000XOol00`00Oomoo`0BOol00`00Oomoo`3oOomaOol002Qoo`03001oogoo019oo`03001o
ogoo0?moog5oo`00:7oo00<007ooOol04goo00<007ooOol0ogooL7oo000XOol00`00Oomoo`0COol0
0`00Oomoo`3oOom`Ool002Qoo`03001oogoo01=oo`03001oogoo0?moog1oo`00:7oo00<007ooOol0
57oo00<007ooOol0ogooKgoo000XOol00`00Oomoo`0DOol00`00Oomoo`3oOom_Ool002Qoo`03001o
ogoo01Eoo`03001oogoo0?moofioo`00:7oo00<007ooOol05Goo00<007ooOol0ogooKWoo000XOol3
000EOol00`00Oomoo`3oOom^Ool002Qoo`03001oogoo01Ioo`03001oogoo0?moofeoo`00:7oo00<0
07ooOol05Woo00<007ooOol0ogooKGoo000XOol00`00Oomoo`0GOol00`00Oomoo`3oOom/Ool002Qo
o`03001oogoo01Moo`03001oogoo0?moofaoo`00:7oo00<007ooOol067oo0P00ogooK7oo000XOol0
0`00Oomoo`0JOol2003oOomZOol002Qoo`03001oogoo01aoo`800?moofQoo`00:7oo00<007ooOol0
7Woo00<007ooOol0ogooFWoo00<007ooOol027oo000XOol00`00Oomoo`0NOol00`00Oomoo`3oOomH
Ool2000;Ool002Qoo`03001oogoo01moo`03001oogoo0?mooeIoo`03001oogoo00]oo`00:7oo00<0
07ooOol07goo00<007ooOol0ogooEGoo00<007ooOol037oo000XOol3000POol00`00Oomoo`3oOomB
Ool2000?Ool002Qoo`03001oogoo021oo`03001oogoo0?mooe5oo`03001oogoo00moo`00:7oo00<0
07ooOol08Goo00<007ooOol0ogooCgoo00<007ooOol047oo000XOol00`00Oomoo`0QOol00`00Oomo
o`3oOom=Ool2000COol002Qoo`03001oogoo025oo`03001oogoo0?moodaoo`03001oogoo01=oo`00
:7oo00<007ooOol08Woo00<007ooOol0ogooBWoo00<007ooOol057oo000XOol00`00Oomoo`0ROol0
0`00Oomoo`3oOom8Ool2000GOol002Qoo`03001oogoo02=oo`03001oogoo0?moodIoo`03001oogoo
01Moo`0000=oo`0000001@000goo10001Goo10001Goo10001goo00<007ooOol08goo00<007ooOol0
ogooAGoo00<007ooOol067oo0004Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo0000
17oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo02Aoo`03001oogoo0?mood9oo`80
01]oo`0017oo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol0
0004Ool00`00Oomoo`04Ool00`00Oomoo`0TOol00`00Oomoo`3oOom1Ool00`00Oomoo`0KOol000Ao
o`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<0
07ooOol017oo00<007ooOol097oo00<007ooOol0ogoo@7oo00<007ooOol077oo0004Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Ao
o`@002Aoo`03001oogoo0?mooceoo`8001moo`0017oo00<007ooOol00goo00<007ooOol00Woo00D0
07ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`0UOol00`00Oomo
o`3oOollOol00`00Oomoo`0OOol000Aoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol0
0004Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol09Woo00<007ooOol0ogoo>Woo
00<007ooOol087oo0002Ool30005Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomo
o`0000Aoo`03001oogoo00Aoo`03001oogoo02Ioo`03001oogoo0?moocQoo`8002=oo`0017oo00<0
07ooOol017oo10001Goo10001Goo10001goo00<007ooOol09goo00<007ooOol0ogoo=Woo00<007oo
Ool08goo000XOol00`00Oomoo`0WOol00`00Oomoo`3oOoleOol00`00Oomoo`0TOol002Qoo`03001o
ogoo02Moo`03001oogoo0?mooc=oo`8002Moo`00:7oo00<007ooOol0:7oo00<007ooOol0ogoo<Goo
00<007ooOol09goo000XOol00`00Oomoo`0XOol00`00Oomoo`3oOol`Ool00`00Oomoo`0XOol002Qo
o`03001oogoo02Uoo`03001oogoo0?moobeoo`8002]oo`00:7oo00<007ooOol0:Goo00<007ooOol0
ogoo:Goo1000;Goo000XOol00`00Oomoo`0ZOol00`00Oomoo`3oOolPOol8000aOol002Qoo`<002Yo
o`03001oogoo0?mooaQoo`P003Uoo`00:7oo00<007ooOol0:Woo00<007ooOol0ogoo4goo1@00@Goo
000XOol00`00Oomoo`0[Ool00`00Oomoo`3oOolAOol00`00Oomoo`14Ool002Qoo`03001oogoo02]o
o`03001oogoo0?mooa1oo`03001oogoo04Eoo`00:7oo00<007ooOol0;7oo00<007ooOol0ogoo3Woo
00<007ooOol0AWoo000XOol00`00Oomoo`0/Ool00`00Oomoo`3oOol<Ool20019Ool002Qoo`03001o
ogoo02eoo`03001oogoo0?moo`Yoo`03001oogoo04Uoo`00:7oo00<007ooOol0;Goo00<007ooOol0
ogoo2Goo00<007ooOol0BWoo000XOol00`00Oomoo`0]Ool00`00Oomoo`3oOol8Ool00`00Oomoo`1;
Ool002Qoo`03001oogoo02ioo`03001oogoo0?moo`Ioo`03001oogoo04aoo`00:7oo00<007ooOol0
;Woo00<007ooOol0ogoo1Goo00<007ooOol0CGoo000XOol00`00Oomoo`0_Ool00`00Oomoo`3oOol3
Ool00`00Oomoo`1>Ool002Qoo`<002moo`03001oogoo0?moo`9oo`03001oogoo04moo`00:7oo00<0
07ooOol0<7oo00<007ooOol0oWoo0P00DWoo000XOol00`00Oomoo`0`Ool00`00Oomoo`3mOol00`00
Oomoo`1BOol002Qoo`03001oogoo031oo`03001oogoo0?aoo`03001oogoo05=oo`00:7oo00<007oo
Ool0<Goo00<007ooOol0nWoo00<007ooOol0E7oo000XOol00`00Oomoo`0aOol00`00Oomoo`3iOol0
0`00Oomoo`1EOol002Qoo`03001oogoo039oo`03001oogoo0?Moo`03001oogoo05Ioo`00:7oo00<0
07ooOol0<Woo00<007ooOol0mWoo00<007ooOol0Egoo000XOol00`00Oomoo`0cOol00`00Oomoo`3d
Ool00`00Oomoo`1HOol002Qoo`03001oogoo03=oo`03001oogoo0?9oo`8005]oo`00:7oo00<007oo
Ool0<goo00<007ooOol0lGoo00<007ooOol0Fgoo000XOol00`00Oomoo`0dOol00`00Oomoo`3_Ool0
0`00Oomoo`1LOol002Qoo`<003Aoo`03001oogoo0>ioo`03001oogoo05eoo`00:7oo00<007ooOol0
=Goo00<007ooOol0k7oo00<007ooOol0GWoo000XOol00`00Oomoo`0eOol00`00Oomoo`3[Ool00`00
Oomoo`1OOol002Qoo`03001oogoo03Ioo`03001oogoo0>Uoo`03001oogoo061oo`00:7oo00<007oo
Ool0=Woo00<007ooOol0j7oo00<007ooOol0HGoo000XOol00`00Oomoo`0gOol00`00Oomoo`3UOol2
001TOol002Qoo`03001oogoo03Qoo`03001oogoo0>=oo`03001oogoo06Aoo`00:7oo00<007ooOol0
>Goo00<007ooOol0hGoo00<007ooOol0IGoo000XOol00`00Oomoo`0jOol00`00Oomoo`3OOol00`00
Oomoo`1VOol002Qoo`03001oogoo03]oo`03001oogoo0=eoo`03001oogoo06Moo`00:7oo00<007oo
Ool0?7oo00<007ooOol0fgoo00<007ooOol0J7oo000XOol00`00Oomoo`0mOol00`00Oomoo`3IOol0
0`00Oomoo`1YOol002Qoo`<003ioo`03001oogoo0=Ioo`8006aoo`00:7oo00<007ooOol0?goo00<0
07ooOol0e7oo00<007ooOol0K7oo000XOol00`00Oomoo`10Ool00`00Oomoo`3BOol00`00Oomoo`1]
Ool002Qoo`03001oogoo045oo`800=5oo`03001oogoo06ioo`00:7oo00<007ooOol0@goo0`00cGoo
00<007ooOol0Kgoo000XOol00`00Oomoo`16Ool2003:Ool00`00Oomoo`1`Ool002Qoo`03001oogoo
04Qoo`03001oogoo0<Ioo`03001oogoo075oo`00:7oo00<007ooOol0B7oo00<007ooOol0a7oo0P00
M7oo000XOol00`00Oomoo`19Ool00`00Oomoo`32Ool00`00Oomoo`1dOol00003Ool0000000@000Ao
o`@000Eoo`@000Eoo`@000Moo`03001oogoo04Uoo`03001oogoo0<5oo`03001oogoo07Eoo`0000=o
o`00Ool00goo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<0
07ooOol017oo00<007ooOol0BWoo00<007ooOol0_goo00<007ooOol0MWoo0002Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03
001oogoo04Yoo`03001oogoo0;ioo`03001oogoo07Moo`000goo00<007ooOol017oo00<007ooOol0
0Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool4001:Ool00`00Oomo
o`2mOol00`00Oomoo`1gOol000Aoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004
Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol0Bgoo00<007ooOol0_7oo00<007oo
Ool0N7oo0005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomo
o`0000Aoo`03001oogoo00Aoo`03001oogoo04aoo`03001oogoo0;]oo`03001oogoo07Qoo`0000=o
o`00Ool00goo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<0
07ooOol017oo00<007ooOol0C7oo00<007ooOol0^Woo00<007ooOol0NGoo00000goo001oo`03Ool0
1@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool0
0`00Oomoo`1=Ool00`00Oomoo`2hOol00`00Oomoo`1jOol0009oo`@000Eoo`@000Eoo`@000Eoo`@0
00Moo`03001oogoo04ioo`03001oogoo0;Moo`03001oogoo07Yoo`00:7oo00<007ooOol0CWoo00<0
07ooOol0]Woo00<007ooOol0Ngoo000XOol00`00Oomoo`1?Ool00`00Oomoo`2eOol00`00Oomoo`1k
Ool002Qoo`03001oogoo04moo`03001oogoo0;Aoo`03001oogoo07aoo`00:7oo00<007ooOol0D7oo
00<007ooOol0/Woo00<007ooOol0OGoo000XOol00`00Oomoo`1@Ool00`00Oomoo`2bOol00`00Oomo
o`1mOol002Qoo`03001oogoo055oo`03001oogoo0;1oo`03001oogoo07ioo`00:7oo00<007ooOol0
DGoo00<007ooOol0/7oo00<007ooOol0OWoo000XOol3001BOol00`00Oomoo`2^Ool00`00Oomoo`1o
Ool002Qoo`03001oogoo059oo`03001oogoo0:eoo`03001oogoo081oo`00:7oo00<007ooOol0Dgoo
00<007ooOol0[7oo00<007ooOol0P7oo000XOol00`00Oomoo`1DOol00`00Oomoo`2ZOol00`00Oomo
o`21Ool002Qoo`03001oogoo05Eoo`03001oogoo0:Uoo`03001oogoo085oo`00:7oo00<007ooOol0
EWoo00<007ooOol0Ygoo00<007ooOol0PWoo000XOol00`00Oomoo`1GOol00`00Oomoo`2UOol00`00
Oomoo`23Ool002Qoo`03001oogoo05Qoo`03001oogoo0:Aoo`03001oogoo08=oo`00:7oo00<007oo
Ool0FGoo00<007ooOol0XWoo00<007ooOol0Q7oo000XOol00`00Oomoo`1JOol00`00Oomoo`2QOol0
0`00Oomoo`24Ool002Qoo`03001oogoo05]oo`8009moo`8008Moo`00:7oo00<007ooOol0GGoo00<0
07ooOol0VWoo0P00RGoo000XOol3001NOol00`00Oomoo`2FOol3002;Ool002Qoo`03001oogoo05mo
o`03001oogoo09=oo`8008ioo`00:7oo00<007ooOol0H7oo00<007ooOol0Sgoo0`00T7oo000XOol0
0`00Oomoo`1QOol00`00Oomoo`2<Ool2002COol002Qoo`03001oogoo069oo`03001oogoo08Uoo`80
09Eoo`00:7oo00<007ooOol0Hgoo00<007ooOol0Qgoo00<007ooOol0UGoo000XOol00`00Oomoo`1S
Ool00`00Oomoo`26Ool00`00Oomoo`2FOol002Qoo`03001oogoo06Aoo`03001oogoo08Aoo`03001o
ogoo09Moo`00:7oo00<007ooOol0I7oo00<007ooOol0Pgoo00<007ooOol0V7oo000XOol00`00Oomo
o`1UOol00`00Oomoo`21Ool00`00Oomoo`2IOol002Qoo`03001oogoo06Eoo`03001oogoo081oo`03
001oogoo09Yoo`00:7oo00<007ooOol0IWoo00<007ooOol0OWoo00<007ooOol0Vgoo000XOol3001V
Ool00`00Oomoo`1mOol00`00Oomoo`2LOol002Qoo`03001oogoo06Moo`03001oogoo07]oo`03001o
ogoo09eoo`00:7oo00<007ooOol0Igoo00<007ooOol0NWoo00<007ooOol0WWoo000XOol00`00Oomo
o`1XOol00`00Oomoo`1hOol00`00Oomoo`2OOol002Qoo`03001oogoo06Qoo`03001oogoo07Moo`03
001oogoo0:1oo`00:7oo00<007ooOol0JGoo00<007ooOol0MGoo00<007ooOol0XGoo000XOol00`00
Oomoo`1YOol00`00Oomoo`1dOol00`00Oomoo`2ROol002Qoo`03001oogoo06Uoo`03001oogoo07=o
o`03001oogoo0:=oo`00:7oo00<007ooOol0JWoo00<007ooOol0LGoo00<007ooOol0Y7oo000XOol0
0`00Oomoo`1ZOol00`00Oomoo`1aOol00`00Oomoo`2TOol002Qoo`03001oogoo06]oo`03001oogoo
06moo`03001oogoo0:Eoo`00:7oo00<007ooOol0Jgoo00<007ooOol0Kgoo00<007ooOol0YGoo000X
Ool3001/Ool00`00Oomoo`1]Ool00`00Oomoo`2VOol002Qoo`03001oogoo06aoo`03001oogoo06eo
o`03001oogoo0:Ioo`00:7oo00<007ooOol0KGoo00<007ooOol0K7oo00<007ooOol0YWoo000XOol0
0`00Oomoo`1]Ool00`00Oomoo`1[Ool00`00Oomoo`2WOol002Qoo`03001oogoo06ioo`03001oogoo
06Yoo`03001oogoo0:Moo`00:7oo00<007ooOol0KWoo00<007ooOol0JGoo00<007ooOol0Z7oo000X
Ool00`00Oomoo`1_Ool00`00Oomoo`1XOol00`00Oomoo`2XOol002Qoo`03001oogoo06moo`03001o
ogoo06Qoo`03001oogoo0:Qoo`000Woo10001Goo10001Goo10001Goo10001goo00<007ooOol0L7oo
00<007ooOol0IWoo00<007ooOol0ZGoo00000goo001oo`03Ool01@00Oomoogoo000017oo00D007oo
Oomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`1aOol00`00Oomoo`1U
Ool00`00Oomoo`2YOol000Ioo`05001oogooOol00004Ool01@00Oomoogoo000017oo00D007ooOomo
o`0000Aoo`03001oogoo00Aoo`03001oogoo075oo`03001oogoo06Aoo`03001oogoo0:Yoo`001Woo
00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol017oo
00<007ooOol0LWoo00<007ooOol0Hgoo00<007ooOol0ZWoo0004Ool20004Ool00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`@0079oo`03001oogoo069o
o`03001oogoo0:Yoo`001Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01@00Oomoogoo
000017oo00<007ooOol017oo00<007ooOol0M7oo00<007ooOol0H7oo00<007ooOol0Zgoo0006Ool0
1@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool0
0`00Oomoo`1eOol00`00Oomoo`1OOol00`00Oomoo`2[Ool00003Ool007oo00=oo`05001oogooOol0
0004Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo07Eo
o`03001oogoo05moo`03001oogoo0:]oo`000Woo10001Goo10001Goo10001Goo10001goo00<007oo
Ool0MWoo00<007ooOol0GGoo00<007ooOol0[7oo000XOol00`00Oomoo`1gOol00`00Oomoo`1LOol0
0`00Oomoo`2/Ool002Qoo`03001oogoo07Qoo`03001oogoo05Yoo`03001oogoo0:eoo`00:7oo00<0
07ooOol0N7oo00<007ooOol0FWoo00<007ooOol0[Goo000XOol00`00Oomoo`1iOol00`00Oomoo`1I
Ool00`00Oomoo`2]Ool002Qoo`03001oogoo07Yoo`03001oogoo05Moo`03001oogoo0:ioo`00:7oo
00<007ooOol0Ngoo00<007ooOol0EWoo00<007ooOol0[Woo000XOol00`00Oomoo`1lOol00`00Oomo
o`1DOol00`00Oomoo`2_Ool002Qoo`<007aoo`03001oogoo05Aoo`03001oogoo0:moo`00:7oo00<0
07ooOol0OGoo00<007ooOol0DWoo00<007ooOol0/7oo000XOol00`00Oomoo`1nOol00`00Oomoo`1@
Ool00`00Oomoo`2aOol002Qoo`03001oogoo07moo`03001oogoo04ioo`03001oogoo0;9oo`00:7oo
00<007ooOol0Ogoo00<007ooOol0CWoo00<007ooOol0/Woo000XOol00`00Oomoo`20Ool00`00Oomo
o`1<Ool00`00Oomoo`2cOol002Qoo`03001oogoo081oo`03001oogoo04]oo`03001oogoo0;Aoo`00
:7oo00<007ooOol0PGoo00<007ooOol0BGoo00<007ooOol0]Goo000XOol00`00Oomoo`21Ool00`00
Oomoo`18Ool00`00Oomoo`2fOol002Qoo`03001oogoo089oo`03001oogoo04Ioo`03001oogoo0;Mo
o`00:7oo00<007ooOol0PWoo00<007ooOol0AWoo00<007ooOol0]goo000XOol00`00Oomoo`23Ool0
0`00Oomoo`14Ool00`00Oomoo`2hOol002Qoo`<008=oo`03001oogoo04=oo`03001oogoo0;Uoo`00
:7oo00<007ooOol0Q7oo00<007ooOol0@Goo00<007ooOol0^Woo000XOol00`00Oomoo`24Ool00`00
Oomoo`10Ool00`00Oomoo`2kOol002Qoo`03001oogoo08Eoo`03001oogoo03ioo`03001oogoo0;ao
o`00:7oo00<007ooOol0QGoo00<007ooOol0?Goo00<007ooOol0_Goo000XOol00`00Oomoo`26Ool0
0`00Oomoo`0lOol00`00Oomoo`2mOol002Qoo`03001oogoo08Ioo`03001oogoo03]oo`03001oogoo
0;ioo`00:7oo00<007ooOol0Qgoo00<007ooOol0>Goo00<007ooOol0_goo000XOol00`00Oomoo`27
Ool00`00Oomoo`0hOol00`00Oomoo`30Ool002Qoo`03001oogoo08Qoo`03001oogoo03Ioo`03001o
ogoo0<5oo`00:7oo00<007ooOol0R7oo00<007ooOol0=Goo00<007ooOol0`Woo000XOol00`00Oomo
o`29Ool00`00Oomoo`0dOol00`00Oomoo`32Ool002Qoo`<008Uoo`03001oogoo03=oo`03001oogoo
0<=oo`00:7oo00<007ooOol0RWoo00<007ooOol0<Goo00<007ooOol0a7oo000XOol00`00Oomoo`2;
Ool00`00Oomoo`0_Ool00`00Oomoo`35Ool002Qoo`03001oogoo08aoo`8002ioo`03001oogoo0<Io
o`00:7oo00<007ooOol0SWoo00<007ooOol0:Woo00<007ooOol0agoo000XOol00`00Oomoo`2?Ool0
0`00Oomoo`0YOol00`00Oomoo`37Ool002Qoo`03001oogoo091oo`8002Qoo`03001oogoo0<Qoo`00
:7oo00<007ooOol0TWoo00<007ooOol097oo00<007ooOol0bGoo000XOol00`00Oomoo`2COol00`00
Oomoo`0QOol2003<Ool002Qoo`03001oogoo09Aoo`8001ioo`<00<ioo`00:7oo00<007ooOol0UWoo
00<007ooOol05goo1000dGoo000XOol00`00Oomoo`2GOol00`00Oomoo`0COol3003EOol002Qoo`<0
09Qoo`80015oo`800=Qoo`00:7oo00<007ooOol0VWoo00<007ooOol02goo0`00fWoo000XOol00`00
Oomoo`2KOol00`00Oomoo`08Ool2003MOol002Qoo`03001oogoo09aoo`8000Eoo`<00=moo`00:7oo
00<007ooOol0WWoo00<007ooOol00P00hWoo000XOol00`00Oomoo`2OOol2003TOol002Qoo`03001o
ogoo0?moohIoo`00:7oo00<007ooOol0ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001o
ogoo0?moohIoo`00:7oo00<007ooOol0ogooQWoo000XOol00`00Oomoo`3oOon6Ool00?mook5oo`00
ogoo/Goo003oOonaOol00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-94.8152, -357.774, 3.46921, \
24.7687}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell["\<\
Here is evaluated the retention in the whole body for an acute intake \"1\" \
of Cs-137 in t=0 [More details in Help \"Isotope\"]\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(qWbCs137[t1_] = 
      qWholebody[compartMatrix[caesium], 1, \ 1, t1, \ 
        Log[2]/\((30*365.24)\)]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(\(-0.00017738115401735866`\)\ \
\[ExponentialE]\^\(\(-24.00006325951708`\)\ t1\) + 
      0.0016546204083943063`\ \[ExponentialE]\^\(\(-12.00006325951708`\)\ \
t1\) - 0.023033308019801538`\ \[ExponentialE]\^\(\(-2.772653259517082`\)\ \
t1\) + 0.020769923715010356`\ \[ExponentialE]\^\(\(-1.8000632595170818`\)\ t1\
\) - 0.04304818930792357`\ \[ExponentialE]\^\(\(-1.000063259517081`\)\ t1\) + 
      0.13938708446501963`\ \[ExponentialE]\^\(\(-0.3460632595170811`\)\ t1\) \
+ 0.9044472498933186`\ \[ExponentialE]\^\(\(-0.006363259517080529`\)\ \
t1\)\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell["\<\
This function supposes a daily chronic ingestion \"inp\" during a time t1.  \
\
\>", "MathCaption"],

Cell[BoxData[
    \(\(qWbCsChronic[
          t1_] = \[Integral]\_0\%t1 qWbCs137[
              t] \[DifferentialD]t;\)\)], "Input",
  CellLabel->"In[29]:="],

Cell[TextData[{
  "The ingestion of caesium stop in ",
  Cell[BoxData[
      \(TraditionalForm\`t\  = \ T\)]],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`t > T\)]],
  ", inp = 0. Then the retention is evaluated as follows"
}], "MathCaption"],

Cell[BoxData[
    \(\(qWbCsCeased[t1_, 
          T_] = \[Integral]\_\(t1 - T\)\%t1 qWbCs137[
              t] \[DifferentialD]t;\)\)], "Input",
  CellLabel->"In[30]:="],

Cell["This function represents the evolution for both periods", "MathCaption"],

Cell[BoxData[
    \(\(qCaesiumIng[inp_, \ t_, \ T_] := 
        inp\ If[t < T, qWbCsChronic[t], qWbCsCeased[t, T]];\)\)], "Input",
  CellLabel->"In[31]:="],

Cell["\<\
It can be observed that the retention was increasing until T = 400 days \
aprox.  We can suppose that the caesium ingestion happened until = 400, when \
it ceased.  Now we can fit the experimental data to bearing in mind both \
periods\
\>", "MathCaption"],

Cell["\<\
model1[t1_?NumericQ, p_?NumericQ] := p qCaesiumIng[1, t1, 400]\
\>", "Input",
  CellLabel->"In[32]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(intake = \(\(p\)\(/.\)\(FindFit[wholeData, \ model1[t, p], \ {p}, \ 
          t]\)\(\ \)\)\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \(28.284457966118733`\)], "Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[qCaesiumIng[intake, \ t, 400], \ {t, \ 1, 1000}, \ 
      Epilog \[Rule] \ {Hue[0. ], \ PointSize[0.02], 
          Map[Point, wholeData]}]\)], "Input",
  CellLabel->"In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000952381 0.0147151 0.000158469 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -12 -9 ]
[.97619 .00222 12 0 ]
[.01131 .09395 -18 -4.5 ]
[.01131 .09395 0 4.5 ]
[.01131 .17318 -24 -4.5 ]
[.01131 .17318 0 4.5 ]
[.01131 .25242 -24 -4.5 ]
[.01131 .25242 0 4.5 ]
[.01131 .33165 -24 -4.5 ]
[.01131 .33165 0 4.5 ]
[.01131 .41089 -24 -4.5 ]
[.01131 .41089 0 4.5 ]
[.01131 .49012 -24 -4.5 ]
[.01131 .49012 0 4.5 ]
[.01131 .56936 -24 -4.5 ]
[.01131 .56936 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(200)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(400)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(600)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(800)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1000)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .09395 m
.03006 .09395 L
s
[(500)] .01131 .09395 1 0 Mshowa
.02381 .17318 m
.03006 .17318 L
s
[(1000)] .01131 .17318 1 0 Mshowa
.02381 .25242 m
.03006 .25242 L
s
[(1500)] .01131 .25242 1 0 Mshowa
.02381 .33165 m
.03006 .33165 L
s
[(2000)] .01131 .33165 1 0 Mshowa
.02381 .41089 m
.03006 .41089 L
s
[(2500)] .01131 .41089 1 0 Mshowa
.02381 .49012 m
.03006 .49012 L
s
[(3000)] .01131 .49012 1 0 Mshowa
.02381 .56936 m
.03006 .56936 L
s
[(3500)] .01131 .56936 1 0 Mshowa
.125 Mabswid
.02381 .03056 m
.02756 .03056 L
s
.02381 .04641 m
.02756 .04641 L
s
.02381 .06226 m
.02756 .06226 L
s
.02381 .0781 m
.02756 .0781 L
s
.02381 .1098 m
.02756 .1098 L
s
.02381 .12564 m
.02756 .12564 L
s
.02381 .14149 m
.02756 .14149 L
s
.02381 .15734 m
.02756 .15734 L
s
.02381 .18903 m
.02756 .18903 L
s
.02381 .20488 m
.02756 .20488 L
s
.02381 .22072 m
.02756 .22072 L
s
.02381 .23657 m
.02756 .23657 L
s
.02381 .26827 m
.02756 .26827 L
s
.02381 .28411 m
.02756 .28411 L
s
.02381 .29996 m
.02756 .29996 L
s
.02381 .31581 m
.02756 .31581 L
s
.02381 .3475 m
.02756 .3475 L
s
.02381 .36335 m
.02756 .36335 L
s
.02381 .37919 m
.02756 .37919 L
s
.02381 .39504 m
.02756 .39504 L
s
.02381 .42673 m
.02756 .42673 L
s
.02381 .44258 m
.02756 .44258 L
s
.02381 .45843 m
.02756 .45843 L
s
.02381 .47428 m
.02756 .47428 L
s
.02381 .50597 m
.02756 .50597 L
s
.02381 .52182 m
.02756 .52182 L
s
.02381 .53766 m
.02756 .53766 L
s
.02381 .55351 m
.02756 .55351 L
s
.02381 .5852 m
.02756 .5852 L
s
.02381 .60105 m
.02756 .60105 L
s
.02381 .6169 m
.02756 .6169 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02476 .01917 m
.06336 .16428 L
.10545 .2842 L
.14498 .36991 L
.183 .4335 L
.22347 .48561 L
.26242 .52406 L
.30383 .55533 L
.34372 .57828 L
.38209 .59527 L
.39233 .59912 L
.39733 .6009 L
.40191 .60249 L
.40309 .60289 L
.40438 .60332 L
.4056 .59981 L
.40673 .59502 L
.41191 .57458 L
.42292 .53475 L
.46201 .41521 L
.50355 .31815 L
.54358 .24694 L
.58209 .19426 L
.62305 .15127 L
.6625 .11963 L
.70043 .09614 L
.74082 .07689 L
.77969 .06267 L
.82101 .0511 L
.86081 .0426 L
.8991 .03631 L
.93984 .03116 L
.97619 .02762 L
s
1 0 0 r
.02 w
.06095 .06226 Mdot
.07905 .12105 Mdot
.09524 .13151 Mdot
.14762 .27793 Mdot
.17238 .30725 Mdot
.18571 .31295 Mdot
.21238 .37079 Mdot
.24667 .40978 Mdot
.27429 .4784 Mdot
.30667 .52562 Mdot
.33333 .58647 Mdot
.41238 .61262 Mdot
.43524 .6047 Mdot
.49429 .52102 Mdot
.51905 .44892 Mdot
.55333 .40598 Mdot
.58762 .39108 Mdot
.61905 .32436 Mdot
.67333 .27048 Mdot
.73238 .20821 Mdot
.78571 .20076 Mdot
.8619 .13182 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo001VOol60004Ool40005Ool4
000fOol40004Ool40005Ool4000eOol40004Ool40005Ool4000eOol40005Ool40005Ool4000_Ool7
0003Ool40005Ool40005Ool40004Ool006Ioo`03001oogoo009oo`05001oogooOol00004Ool01@00
Oomoogoo000017oo00<007ooOol0=Goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`03001oogoo035oo`03001oogoo009oo`04001oogoo0004Ool01@00Oomoogoo000017oo00<0
07ooOol0<Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomo
o`0_Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Ao
o`03001oogoo005oo`00Igoo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03
001oogoo03Eoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0a
Ool00`00Oomoo`02Ool01000Oomoo`0017oo00D007ooOomoo`0000Aoo`03001oogoo035oo`03001o
ogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol0;goo00<007ooOol0
0goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`01Ool0
06Qoo`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0aOol60003
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0<Goo0P000goo00@007ooOol000Ao
o`05001oogooOol00004Ool00`00Oomoo`0aOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00D0
07ooOomoo`0000Aoo`03001oogoo02moo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol0
0004Ool01@00Oomoogoo000017oo00<007ooOol00Goo001YOol00`00Oomoo`03Ool00`00Oomoo`02
Ool01@00Oomoogoo000017oo00<007ooOol0<Woo00@007ooOol000Aoo`03001oogoo009oo`05001o
ogooOol00004Ool00`00Oomoo`0aOol00`00Ool000020003Ool00`00Oomoo`02Ool01@00Oomoogoo
000017oo00<007ooOol0<Woo100017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo
02moo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo
00<007ooOol00Goo001ZOol00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<0
07ooOol0<Woo00@007ooOol000Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0a
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0<Goo00<007oo
Ool00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`0_Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo005oo`00
IWoo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`0cOol0
0`00Ool00004Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0<Woo00<007ooOol0
17oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo035oo`03001oogoo009oo`05001o
ogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol0;goo00<007ooOol00goo00<007ooOol0
0Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`01Ool006Ioo`03001oogoo
009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol0<goo00<007oo000017oo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo03=oo`03001oogoo00=oo`03001oogoo
009oo`05001oogooOol00004Ool00`00Oomoo`0aOol00`00Oomoo`02Ool01@00Oomoogoo000017oo
00D007ooOomoo`0000Aoo`03001oogoo02eoo`<000Eoo`03001oogoo009oo`05001oogooOol00004
Ool01@00Oomoogoo000017oo00<007ooOol00Goo001WOol40005Ool40005Ool4000gOol20005Ool4
0005Ool4000gOol30003Ool40005Ool4000eOol40005Ool40005Ool4000bOol00`00Oomoo`04Ool4
0005Ool40005Ool40004Ool00?mook5oo`00ogoo/Goo000XOol00`00Oomoo`3oOon6Ool002Qoo`03
001oogoo0?moohIoo`00:7oo00<007ooOol0ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03
001oogoo0?moohIoo`00:7oo00<007ooOol0ogooQWoo000OOooo00290009Ool002Qoo`03001oogoo
011oo`03001oogoo011oo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo
011oo`03001oogoo011oo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo
011oo`03001oogoo011oo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo
011oo`03001oogoo011oo`03001oogoo00moo`03001oogoo011oo`03001oogoo011oo`03001oogoo
011oo`00:7oo0P00BGoo00<007ooOol0Agoo00<007ooOol0B7oo00<007ooOol0Agoo00<007ooOol0
B7oo00<007ooOol047oo000XOol2003oOon7Ool002Qoo`03001oo`000?moohIoo`00:7oo00<007oo
0000ogooK7oo20004Woo000XOol3003oOomQOol;000JOol002Qoo`03001oo`000?mooeUoo`P002Eo
o`00:7oo00@007ooOol00?mooe5oo`L002eoo`00:7oo00@007ooOol00?moodaoo`D003Aoo`00:7oo
00@007ooOol00?moodMoo`D003Uoo`00:7oo00@007ooOol00?mood9oo`D003ioo`00:7oo0`0000=o
o`00Ool0ogoo>goo1@00@goo000XOol01@00Oomoogoo0000ogoo=goo1@00B7oo000XOol01@00Oomo
ogoo0000ogoo<goo1000CGoo000XOol01@00Oomoogoo0000ogoo<7oo0`00DGoo000XOol00`00Oomo
o`02Ool00`00Oomoo`06Ool3O03oOolQOol3001DOol002Qoo`03001oogoo009oo`03001oogoo00Eo
o`El0?mooaaoo`@005Moo`00:7oo0`000Woo00<007ooOol017oo1g`0ogoo67oo0`00Fgoo000XOol0
0`00Oomoo`03Ool00`00Oomoo`03Ool7O03oOolEOol3001NOol002Qoo`03001oogoo00=oo`03001o
ogoo00=oo`Ml0?mooa9oo`<0065oo`00:7oo00<007ooOol00goo00<007ooOol017oo1G`0ogoo47oo
0`00I7oo000XOol00`00Oomoo`03Ool00`00Oomoo`05Ool3O03oOol>Ool3001WOol002Qoo`03001o
ogoo00Aoo`03001oogoo0?mooa9oo`<006Yoo`00:7oo00<007ooOol017oo00<007ooOol0ogoo47oo
0P00KGoo000XOol30004Ool00`00Oomoo`3oOol>Ool2001_Ool002Qoo`03001oogoo00Aoo`03001o
ogoo0?moo`aoo`80075oo`002goo10001Goo10001Goo10001goo00<007ooOol01Goo00<007ooOol0
ogoo2Goo0P00Lgoo000:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Ao
o`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo0?moo`Moo`8007Eoo`003goo00D007ooOomo
o`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`3oOol5
Ool2001gOol000moo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol017oo00<0
07ooOol01Goo00<007ooOol0ogoo0goo0P00NGoo000?Ool01@00Oomoogoo000017oo00D007ooOomo
o`0000Aoo`03001oogoo00Aoo`@000Eoo`03001oogoo0?moo`8007]oo`002goo100017oo00<007oo
Ool00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo0?eoo`80
07eoo`002goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Ao
o`03001oogoo00Ioo`03001oogoo0?]oo`8007moo`002goo00<007ooOol01Goo00<007ooOol00Woo
00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo0?Qoo`80085oo`00
2goo1@0017oo10001Goo10001goo00<007ooOol01goo00<007ooOol0mgoo00<007ooOol0PGoo000X
Ool00`00Oomoo`07Ool00`00Oomoo`3eOol20024Ool002Qoo`<000Moo`03001oogoo0?=oo`8008Io
o`00:7oo00<007ooOol027oo00<007ooOol0lGoo00<007ooOol0QWoo000XOol00`00Oomoo`08Ool0
0`00Oomoo`07Ool3O03UOol20029Ool002Qoo`03001oogoo00Qoo`03001oogoo00Ioo`El0>9oo`80
08]oo`00:7oo00<007ooOol027oo00<007ooOol01Goo1g`0h7oo00<007ooOol0Rgoo000XOol00`00
Oomoo`09Ool00`00Oomoo`04Ool7O03OOol00`00Oomoo`2<Ool002Qoo`<000Uoo`03001oogoo00Ao
o`Ml0004Ooml07`0O03IOol2001=Ool3O00oOol002Qoo`03001oogoo00Uoo`03001oogoo00Eoo`El
0003Ooml07`000=l0=Moo`03001oogoo04aoo`El03ioo`00:7oo00<007ooOol02Woo00<007ooOol0
1Goo0g`000=oog`0O0001G`0eGoo00<007ooOol0C7oo1g`0?Goo000XOol00`00Oomoo`0:Ool00`00
Oomoo`09Ool7O03DOol00`00Oomoo`1=Ool7O00mOol002Qoo`03001oogoo00Yoo`03001oogoo00Uo
o`Ml0=9oo`80051oo`Ml03eoo`00:7oo00<007ooOol02Woo00<007ooOol02Woo1G`0dWoo00<007oo
Ool0DGoo1G`0?Woo000XOol3000;Ool00`00Oomoo`0:Ool3O03BOol00`00Oomoo`1COol3O00oOol0
02Qoo`03001oogoo00]oo`03001oogoo0=ioo`03001oogoo09Ioo`00:7oo00<007ooOol02goo00<0
07ooOol0g7oo0P00VGoo000XOol00`00Oomoo`0;Ool00`00Oomoo`3KOol00`00Oomoo`2IOol002Qo
o`03001oogoo00aoo`03001oogoo0=Uoo`03001oogoo09Yoo`00:7oo00<007ooOol037oo00<007oo
Ool0f7oo00<007ooOol0Vgoo000XOol00`00Oomoo`0<Ool00`00Oomoo`3GOol00`00Oomoo`2LOol0
02Qoo`<000aoo`03001oogoo0=Ioo`03001oogoo09eoo`00:7oo00<007ooOol03Goo00<007ooOol0
e7oo00<007ooOol0WWoo00000goo000000050003Ool40005Ool40005Ool40007Ool00`00Oomoo`0=
Ool00`00Oomoo`3COol00`00Oomoo`2OOol000Aoo`03001oogoo00=oo`03001oogoo009oo`05001o
ogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol03Goo00<007ooOol0
dWoo00<007ooOol0X7oo0004Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo
00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo0=1oo`03001oogoo
0:5oo`0017oo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol0
0004Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`3?Ool00`00Oomoo`2ROol000Aoo`03
001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007oo
Ool017oo10003Goo00<007ooOol0cgoo00<007ooOol0XWoo0004Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00mo
o`03001oogoo0<eoo`03001oogoo0:=oo`0017oo00<007ooOol00goo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool00`00Oomoo`3<
Ool00`00Oomoo`2TOol0009oo`<000Eoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomo
ogoo000017oo00<007ooOol017oo00<007ooOol03goo00<007ooOol0bgoo00<007ooOol0YGoo0004
Ool00`00Oomoo`04Ool40005Ool40005Ool40007Ool00`00Oomoo`0@Ool00`00Oomoo`39Ool00`00
Oomoo`2VOol002Qoo`03001oogoo011oo`03001oogoo0<Qoo`03001oogoo0:Moo`00:7oo0`0047oo
00<007ooOol0agoo00<007ooOol0Z7oo000XOol00`00Oomoo`0AOol00`00Oomoo`35Ool00`00Oomo
o`2YOol002Qoo`03001oogoo015oo`03001oogoo0<Aoo`03001oogoo04]oo`=l05aoo`00:7oo00<0
07ooOol04Goo00<007ooOol0`goo00<007ooOol0Bgoo1G`0Fgoo000XOol00`00Oomoo`0BOol00`00
Oomoo`31Ool00`00Oomoo`1;Ool7O01JOol002Qoo`03001oogoo019oo`03001oogoo0<5oo`03001o
ogoo03Qoo`=l011oo`Ml05Yoo`00:7oo0`004Woo00<007ooOol0`7oo00<007ooOol0>7oo1G`03goo
1g`0FWoo000XOol00`00Oomoo`0COol00`00Oomoo`2nOol00`00Oomoo`0hOol7O00?Ool5O01KOol0
02Qoo`03001oogoo01=oo`03001oogoo0;eoo`03001oogoo03Uoo`Ml011oo`=l05aoo`00:7oo00<0
07ooOol04goo00<007ooOol0_Goo00<007ooOol0>Goo1g`0Kgoo000XOol00`00Oomoo`0DOol00`00
Oomoo`2kOol00`00Oomoo`0kOol5O01`Ool002Qoo`03001oogoo01Aoo`03001oogoo0;Yoo`03001o
ogoo03eoo`=l075oo`00:7oo0`0057oo00<007ooOol0^Goo00<007ooOol0/Woo000XOol00`00Oomo
o`0EOol00`00Oomoo`2hOol00`00Oomoo`2bOol002Qoo`03001oogoo01Eoo`03001oogoo0;Moo`03
001oogoo0;=oo`00:7oo00<007ooOol05Woo00<007ooOol0]Goo00<007ooOol0]7oo000XOol00`00
Oomoo`0FOol00`00Oomoo`2dOol00`00Oomoo`2eOol002Qoo`03001oogoo01Ioo`03001oogoo0;Ao
o`03001oogoo0;Eoo`00:7oo00<007ooOol05goo00<007ooOol0/Woo00<007ooOol0]Woo000XOol3
000GOol00`00Oomoo`2aOol00`00Oomoo`2gOol002Qoo`03001oogoo01Moo`03001oogoo0;1oo`03
001oogoo0;Qoo`0000=oo`0000001@000goo10001Goo10001Goo10001goo00<007ooOol067oo00<0
07ooOol0[goo00<007ooOol0^7oo0004Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo
000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo01Qoo`03001oogoo0:ioo`03
001oogoo0;Uoo`0017oo00<007ooOol027oo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool0
0`00Oomoo`04Ool00`00Oomoo`0HOol00`00Oomoo`2]Ool00`00Oomoo`2jOol000Aoo`03001oogoo
00Qoo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol06Goo
00<007ooOol0Zgoo00<007ooOol0^goo0004Ool00`00Oomoo`08Ool01@00Oomoogoo000017oo00D0
07ooOomoo`0000Aoo`03001oogoo00Aoo`@001Qoo`03001oogoo0:]oo`03001oogoo0;]oo`0017oo
00<007ooOol017oo100017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03
001oogoo01Uoo`03001oogoo0:Yoo`03001oogoo0;aoo`0017oo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo01Yoo`03001o
ogoo0:Uoo`03001oogoo0;aoo`000Woo0`001Woo00<007ooOol01Goo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`03001oogoo00Aoo`03001oogoo01Yoo`03001oogoo0:Qoo`03001oogoo0;eoo`00
17oo00<007ooOol017oo1@0017oo10001Goo10001goo00<007ooOol06Woo00<007ooOol0Z7oo00<0
07ooOol0<Woo0g`0R7oo000XOol00`00Oomoo`0KOol00`00Oomoo`2VOol00`00Oomoo`0bOol5O027
Ool002Qoo`<001]oo`03001oogoo0:Ioo`03001oogoo035oo`Ml08Ioo`00:7oo00<007ooOol06goo
00<007ooOol03Woo0g`0U7oo00<007ooOol0<Woo1g`0QWoo000XOol00`00Oomoo`0LOol00`00Oomo
o`0<Ool5O02BOol00`00Oomoo`0cOol7O026Ool002Qoo`03001oogoo01aoo`03001oogoo00]oo`Ml
095oo`03001oogoo03Aoo`El08Moo`00:7oo00<007ooOol077oo00<007ooOol02goo1g`0T7oo00<0
07ooOol0=Woo0g`0R7oo000XOol00`00Oomoo`0MOol00`00Oomoo`0:Ool7O02@Ool00`00Oomoo`31
Ool002Qoo`<001eoo`03001oogoo00]oo`El091oo`03001oogoo0<9oo`00:7oo00<007ooOol07Goo
00<007ooOol037oo0g`0TGoo00<007ooOol0`Woo000XOol00`00Oomoo`0NOol00`00Oomoo`2NOol0
0`00Oomoo`33Ool002Qoo`03001oogoo01ioo`03001oogoo09ioo`03001oogoo0<=oo`00:7oo00<0
07ooOol07goo00<007ooOol0W7oo00<007ooOol0a7oo000XOol00`00Oomoo`0OOol00`00Oomoo`2K
Ool00`00Oomoo`35Ool002Qoo`<0021oo`03001oogoo09Yoo`03001oogoo0<Eoo`00:7oo00<007oo
Ool087oo00<007ooOol04goo0g`0Pgoo00<007ooOol0aWoo000XOol00`00Oomoo`0QOol00`00Oomo
o`0AOol5O022Ool00`00Oomoo`36Ool002Qoo`03001oogoo025oo`03001oogoo011oo`Yl07eoo`03
001oogoo0<Moo`00:7oo00<007ooOol08Woo00<007ooOol03goo2g`0O7oo00<007ooOol0agoo000X
Ool00`00Oomoo`0ROol00`00Oomoo`0?Ool<O01jOol00`00Oomoo`38Ool002Qoo`03001oogoo02=o
o`03001oogoo00moo`]l07Yoo`03001oogoo0<Qoo`00:7oo0`008goo00<007ooOol047oo2W`0NGoo
00<007ooOol0:Goo0g`0WGoo000XOol00`00Oomoo`0TOol00`00Oomoo`0COol5O01jOol00`00Oomo
o`0XOol5O02LOol00003Ool0000000@000Aoo`@000Eoo`@000Eoo`@000Moo`03001oogoo02Aoo`03
001oogoo01Aoo`=l07Yoo`03001oogoo02Qoo`Ml09]oo`0000=oo`00Ool00goo00D007ooOomoo`00
00Aoo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol09Goo
00<007ooOol0T7oo00<007ooOol0:7oo1g`0Vgoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo02Eoo`03001o
ogoo08moo`03001oogoo02Uoo`Ml09]oo`000goo00<007ooOol017oo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`0UOol00`00Oomoo`2?
Ool00`00Oomoo`0ZOol5O02LOol000Aoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol0
0004Ool01@00Oomoogoo000017oo00<007ooOol017oo10009Goo00<007ooOol0SGoo00<007ooOol0
;7oo0g`0WGoo0005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007oo
Oomoo`0000Aoo`03001oogoo00Aoo`03001oogoo02Ioo`03001oogoo08eoo`03001oogoo0<aoo`00
00=oo`00Ool00goo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01@00Oomoogoo000017oo
00<007ooOol017oo00<007ooOol09goo00<007ooOol0S7oo00<007ooOol0c7oo00000goo001oo`03
Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04
Ool00`00Oomoo`0WOol00`00Oomoo`2;Ool00`00Oomoo`3=Ool0009oo`@000Eoo`@000Eoo`@000Eo
o`@000Moo`03001oogoo02Qoo`03001oogoo08Yoo`03001oogoo0<eoo`00:7oo00<007ooOol0:7oo
00<007ooOol0RGoo00<007ooOol0cWoo000XOol3000YOol00`00Oomoo`28Ool00`00Oomoo`3>Ool0
02Qoo`03001oogoo02Uoo`03001oogoo08Qoo`03001oogoo0<ioo`00:7oo00<007ooOol0:Woo00<0
07ooOol0QWoo00<007ooOol0cgoo000XOol00`00Oomoo`0ZOol00`00Oomoo`26Ool00`00Oomoo`3?
Ool002Qoo`03001oogoo02]oo`03001oogoo08Aoo`03001oogoo0=1oo`00:7oo00<007ooOol0:goo
00<007ooOol0Q7oo00<007ooOol0d7oo000XOol3000/Ool00`00Oomoo`0GOol3O01XOol00`00Oomo
o`3AOol002Qoo`03001oogoo02aoo`03001oogoo01Ioo`El06Moo`03001oogoo0=5oo`00:7oo00<0
07ooOol0;Goo00<007ooOol057oo1g`0IWoo00<007ooOol0dGoo000XOol00`00Oomoo`0]Ool00`00
Oomoo`0DOol7O01UOol00`00Oomoo`3BOol002Qoo`03001oogoo02ioo`03001oogoo01=oo`Ml06Eo
o`03001oogoo0=9oo`00:7oo00<007ooOol0;Woo00<007ooOol057oo1G`0IGoo00<007ooOol0dgoo
000XOol3000_Ool00`00Oomoo`0DOol3O01VOol00`00Oomoo`3COol002Qoo`03001oogoo02moo`03
001oogoo07aoo`03001oogoo0=Aoo`00:7oo00<007ooOol0<7oo00<007ooOol0Ngoo00<007ooOol0
9goo0g`0ZWoo000XOol00`00Oomoo`0aOol00`00Oomoo`1jOol00`00Oomoo`0VOol5O02YOol002Qo
o`03001oogoo035oo`03001oogoo07Uoo`03001oogoo02Ioo`Ml0:Qoo`00:7oo00<007ooOol0<Woo
00<007ooOol0N7oo00<007ooOol09Woo1g`0Z7oo000XOol3000bOol00`00Oomoo`1gOol00`00Oomo
o`0WOol7O02XOol002Qoo`03001oogoo03=oo`03001oogoo07Ioo`03001oogoo02Qoo`El0:Uoo`00
:7oo00<007ooOol0=7oo00<007ooOol0MGoo00<007ooOol077oo0g`02Woo0g`0ZWoo00000goo0000
00040004Ool40005Ool40005Ool40007Ool00`00Oomoo`0dOol00`00Oomoo`1dOol00`00Oomoo`0L
Ool5O02fOol00003Ool007oo00=oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00D007oo
Oomoo`0000Aoo`03001oogoo00Aoo`03001oogoo03Eoo`03001oogoo01]oo`=l05Eoo`03001oogoo
01]oo`Ml0;Eoo`000Woo00<007ooOol02Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool0
0`00Oomoo`04Ool00`00Oomoo`0eOol00`00Oomoo`0JOol5O01COol00`00Oomoo`0LOol7O02eOol0
00=oo`03001oogoo00Uoo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol017oo
00<007ooOol0=Woo00<007ooOol067oo1g`0DWoo00<007ooOol077oo1g`0]Goo0004Ool00`00Oomo
o`08Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`@003Ioo`03001o
ogoo01Moo`Ml055oo`03001oogoo01ioo`El0;Ioo`001Goo00<007ooOol00goo100017oo00<007oo
Ool00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo03Moo`03001oogoo01Moo`Ml
055oo`03001oogoo01moo`=l0;Moo`0000=oo`00Ool00goo00<007ooOol00Woo00<007ooOol01Goo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo03Qoo`03001oogoo
01Moo`El059oo`03001oogoo0=Uoo`0000=oo`00Ool00goo00<007ooOol00Woo00<007ooOol01Goo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo03Qoo`03001oogoo
01Qoo`=l059oo`03001oogoo0=Yoo`000Woo10001Goo1@0017oo10001Goo10001goo00<007ooOol0
>Goo00<007ooOol0K7oo00<007ooOol0fWoo000XOol00`00Oomoo`0jOol00`00Oomoo`1[Ool00`00
Oomoo`3JOol002Qoo`<003Yoo`03001oogoo06Yoo`03001oogoo0=]oo`00:7oo00<007ooOol0>goo
00<007ooOol0JGoo00<007ooOol0fgoo000XOol00`00Oomoo`0kOol00`00Oomoo`1YOol00`00Oomo
o`3KOol002Qoo`03001oogoo03aoo`03001oogoo06Moo`03001oogoo0=aoo`00:7oo00<007ooOol0
?Goo00<007ooOol0IWoo00<007ooOol0g7oo000XOol00`00Oomoo`0mOol00`00Oomoo`1VOol00`00
Oomoo`3LOol002Qoo`<003ioo`03001oogoo06Aoo`03001oogoo01Ioo`=l0<Aoo`00:7oo00<007oo
Ool0?goo00<007ooOol0Hgoo00<007ooOol05Goo1G`0`goo000XOol00`00Oomoo`10Ool00`00Oomo
o`1ROol00`00Oomoo`0DOol7O032Ool002Qoo`03001oogoo041oo`03001oogoo065oo`03001oogoo
01Eoo`Ml0<9oo`00:7oo00<007ooOol0@Goo00<007ooOol0H7oo00<007ooOol05Goo1g`0`Woo000X
Ool00`00Oomoo`12Ool00`00Oomoo`1OOol00`00Oomoo`0FOol5O033Ool002Qoo`<004=oo`03001o
ogoo05eoo`03001oogoo01Qoo`=l0<Aoo`00:7oo00<007ooOol0@goo00<007ooOol0GGoo00<007oo
Ool0ggoo000XOol00`00Oomoo`14Ool00`00Oomoo`1LOol00`00Oomoo`3OOol002Qoo`03001oogoo
04Eoo`03001oogoo05Yoo`03001oogoo0>1oo`00:7oo00<007ooOol0AWoo00<007ooOol0FGoo00<0
07ooOol0h7oo000XOol00`00Oomoo`16Ool00`00Oomoo`0EOol3O011Ool00`00Oomoo`3POol002Qo
o`<004Moo`03001oogoo01=oo`El03moo`03001oogoo0>5oo`00:7oo00<007ooOol0B7oo00<007oo
Ool04Goo1g`0?Woo00<007ooOol0hGoo000XOol00`00Oomoo`19Ool00`00Oomoo`0@Ool7O00mOol0
0`00Oomoo`3ROol0009oo`@000Eoo`@000Eoo`@000Eoo`@000Moo`03001oogoo04Uoo`03001oogoo
011oo`Ml03eoo`03001oogoo0>9oo`0000=oo`00Ool00goo00D007ooOomoo`0000Aoo`05001oogoo
Ool00004Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol0BWoo00<007ooOol047oo
1G`0?Woo00<007ooOol0hWoo0006Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`05001o
ogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`1;Ool00`00Oomoo`0@Ool3O00nOol00`00Oomo
o`3SOol000Ioo`05001oogooOol00004Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03
001oogoo00Aoo`03001oogoo04aoo`03001oogoo051oo`03001oogoo0>=oo`0017oo0P0017oo00<0
07ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool4001<Ool0
0`00Oomoo`1?Ool00`00Oomoo`3SOol000Ioo`05001oogooOol00004Ool01@00Oomoogoo000017oo
00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo04ioo`03001oogoo04eoo`03001oogoo
0>Aoo`001Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<0
07ooOol017oo00<007ooOol0Cgoo00<007ooOol0C7oo00<007ooOol0i7oo00000goo001oo`03Ool0
1@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool0
0`00Oomoo`1@Ool00`00Oomoo`1;Ool00`00Oomoo`3TOol0009oo`@000Eoo`@000Eoo`@000Eoo`@0
00Moo`03001oogoo055oo`03001oogoo04Uoo`03001oogoo0>Eoo`00:7oo00<007ooOol0DWoo00<0
07ooOol0B7oo00<007ooOol0iGoo000XOol3001COol20018Ool00`00Oomoo`3UOol002Qoo`03001o
ogoo05Eoo`03001oogoo04Aoo`03001oogoo0>Ioo`00:7oo00<007ooOol0EWoo00<007ooOol0@goo
00<007ooOol0iWoo000XOol00`00Oomoo`1GOol00`00Oomoo`12Ool00`00Oomoo`0EOol3O03>Ool0
02Qoo`03001oogoo05Qoo`03001oogoo041oo`03001oogoo01Eoo`El0<eoo`00:7oo00<007ooOol0
FGoo00<007ooOol03goo0g`0;Goo00<007ooOol057oo1g`0c7oo000XOol3001JOol00`00Oomoo`0=
Ool5O00/Ool00`00Oomoo`0DOol7O03<Ool002Qoo`03001oogoo05]oo`03001oogoo00]oo`Ml02Yo
o`03001oogoo01Eoo`Ml0<aoo`00:7oo00<007ooOol0G7oo00<007ooOol02Woo1g`0:Woo00<007oo
Ool05Woo1G`0cGoo000XOol00`00Oomoo`1MOol2000:Ool7O00ZOol00`00Oomoo`0GOol3O03>Ool0
02Qoo`03001oogoo05moo`03001oogoo00Qoo`El02Yoo`03001oogoo0>Uoo`00:7oo00<007ooOol0
H7oo00<007ooOol027oo0g`0:goo00<007ooOol0jGoo000XOol3001QOol2000fOol00`00Oomoo`3Y
Ool002Qoo`03001oogoo06=oo`03001oogoo039oo`03001oogoo0>Yoo`00:7oo00<007ooOol0I7oo
00<007ooOol0<Goo00<007ooOol0jWoo000XOol00`00Oomoo`1UOol2000aOol00`00Oomoo`3ZOol0
02Qoo`03001oogoo06Moo`03001oogoo02ioo`03001oogoo0>Yoo`00:7oo00<007ooOol0J7oo00<0
07ooOol0;7oo00<007ooOol0jgoo000XOol3001YOol2000/Ool00`00Oomoo`3[Ool002Qoo`03001o
ogoo06]oo`03001oogoo02Uoo`03001oogoo0>]oo`00:7oo00<007ooOol0K7oo0P00:Goo00<007oo
Ool0jgoo0002Ool40005Ool40005Ool40005Ool40007Ool00`00Oomoo`1^Ool2000VOol00`00Oomo
o`3/Ool00003Ool007oo00=oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00D007ooOomo
o`0000Aoo`03001oogoo00Aoo`03001oogoo071oo`03001oogoo02=oo`03001oogoo0>aoo`001Woo
00<007ooOol01Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00
Oomoo`1aOol2000SOol00`00Oomoo`3/Ool000Ioo`03001oogoo00Ioo`05001oogooOol00004Ool0
1@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol0Lgoo0P008Goo00<007ooOol0k7oo0004
Ool20009Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`@007Aoo`03
001oogoo01eoo`03001oogoo0>eoo`001Woo00<007ooOol00Woo100017oo00<007ooOol00Woo00D0
07ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo07Ioo`8001eoo`03001oogoo0>eoo`001Woo
00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo
00Aoo`03001oogoo07Qoo`8001]oo`03001oogoo0>eoo`0000=oo`00Ool00goo00<007ooOol00Woo
00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo
07Yoo`8001Uoo`03001oogoo0>eoo`000Woo10001Goo1@0017oo10001Goo10001goo00<007ooOol0
MGoo0g`017oo0P005Woo00<007ooOol0kWoo000XOol00`00Oomoo`1dOol5O005Ool2000DOol00`00
Oomoo`3^Ool002Qoo`<007=oo`Ml00Ioo`80019oo`03001oogoo0>ioo`00:7oo00<007ooOol0Lgoo
1g`027oo0P0047oo00<007ooOol0kWoo000XOol00`00Oomoo`1cOol7O00:Ool2000=Ool00`00Oomo
o`3_Ool002Qoo`03001oogoo07Aoo`El00eoo`8000]oo`03001oogoo0>moo`00:7oo00<007ooOol0
MGoo0g`047oo0`0027oo00<007ooOol0kgoo000XOol00`00Oomoo`2;Ool30005Ool00`00Oomoo`07
Ool3O03UOol002Qoo`<008ioo`80009oo`03001oogoo00Moo`El0>Aoo`00:7oo00<007ooOol0T7oo
0`0027oo1g`0hgoo000XOol00`00Oomoo`2DOol3O004Ool7O03SOol002Qoo`03001oogoo09=oo`El
00=oo`Ml0>=oo`00:7oo00<007ooOol0TWoo1g`00goo1G`0i7oo000XOol00`00Oomoo`2BOol7O004
Ool3O03UOol002Qoo`<0099oo`Ml0>aoo`00:7oo00<007ooOol0Tgoo1G`0kGoo003oOonaOol00?mo
ok5oo`00ogoo/Goo003oOonaOol00?mook5oo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-109.874, -391.905, 4.03104, \
24.2261}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[34]="]
}, Open  ]],

Cell["\<\
This means that the person was inteking  of 28.28 Bq/day of Cs 137 during 400 \
 days, so the total intake was:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(400\ day\ \ intake\ Bq\ /day\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \(11313.783186447494`\ Bq\)], "Output",
  CellLabel->"Out[35]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[wholeData, qWbCs137, qWbCsChronic, qWbCsCeased, \ model1, \ 
      intake]\)], "Input",
  CellLabel->"In[36]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 3", "SubsubsectionIcon"],

Cell["\<\
In this example it is shown how the intake and the AMAD can be estimated  \
using the lung retention measured (simulated). It is supposed radioactive \
airborne type S an the decay constant = 0.\
\>", "MathCaption"],

Cell[BoxData[
    \(\(lungData1\  = {{10, 726}, {20, 666}, {30, 618}, {40, 579}, {50, 
            548}, {60, 522}, {70, 501}, {80, 484}, {90, 469}, {100, 
            457}};\)\)], "Input",
  CellLabel->"In[37]:="],

Cell[TextData[{
  "This function gives the lung retention as function of the initial \
deposition factors in the Respiratory tract ",
  Cell[BoxData[
      \({AI\)]],
  ", ",
  Cell[BoxData[
      \(bb\_\(fast + seq\)\)]],
  ", ",
  Cell[BoxData[
      \(\(\(bb\_slow\)\(,\)\)\)]],
  " ",
  Cell[BoxData[
      \(BB\_\(fast + seq\)\)]],
  " ",
  Cell[BoxData[
      \(\(\(,\)\(\ \)\(BB\_slow\)\(,\)\(\ \)\)\)]],
  " ",
  Cell[BoxData[
      \(\(\(ET\_2, \ ET\_1\)\(}\)\)\)]],
  "according ICRP 66 model"
}], "MathCaption"],

Cell[BoxData[
    \(\(lung[{ai_, bbf_, \ bbs_, \ BBf_, \ BBs_, \ et2_, \ et1_}, \ t_\ ] = 
        LungsRetention[1, {ai, bbf, \ bbs, \ BBf, \ BBs, \ et2, \ et1}\ , 
          S, \ t, 0];\)\)], "Input",
  CellLabel->"In[38]:="],

Cell["\<\
Now we build a function that gives the lung retention as function of the \
intake \"int\" and AMAD \"p\". It is applied for fitting the experimental \
data\
\>", "MathCaption"],

Cell["model1[t1_, inp_, p_]:= inp lung[AMADfit[p] ,t1]  ", "Input",
  CellLabel->"In[39]:="],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"regress", " ", "=", " ", 
      StyleBox[\(NonlinearRegress[lungData1, 
          model1[t, inp, \ 
            p]\ , {t}, {{inp, 10000, \ 20000}, {p, 4, \ 10}}]\),
        FormatType->StandardForm]}]], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(BestFitParameters \[Rule] {inp \[Rule] 17590.599042539587`, 
            p \[Rule] 7.207195849207303`}\), ",", 
        RowBox[{"ParameterCITable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"Asymptotic SE\"\>", "\<\
\"CI\"\>"},
                {"inp", "17590.599042539587`", 
                  "299.8360050255346`", \({16899.175975067606`, 
                    18282.022110011567`}\)},
                {"p", "7.207195849207303`", 
                  "0.10208932123651877`", \({6.971777452275704`, 
                    7.442614246138902`}\)}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            Function[ BoxForm`e$, 
              TableForm[ 
              BoxForm`e$, TableDepth -> 2, TableHeadings -> {{inp, p}, {
                "Estimate", "Asymptotic SE", "CI"}}]]]}], 
        ",", \(EstimatedVariance \[Rule] 0.07503364850813733`\), ",", 
        RowBox[{"ANOVATable", "\[Rule]", 
          InterpretationBox[GridBox[{
                {"\<\"\"\>", "\<\"DF\"\>", "\<\"SumOfSq\"\>", \
"\<\"MeanSq\"\>"},
                {"\<\"Model\"\>", "2", "3.174651399730812`*^6", 
                  "1.587325699865406`*^6"},
                {"\<\"Error\"\>", "8", "0.6002691880650987`", 
                  "0.07503364850813733`"},
                {"\<\"Uncorrected Total\"\>", "10", 
                  "3.174652`*^6", "\<\"\"\>"},
                {"\<\"Corrected Total\"\>", "9", "72162.`", "\<\"\"\>"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            
            TableForm[ {{2, 3174651.3997308118, 1587325.6998654059}, {
              8, .60026918806509866, .075033648508137332}, {10, 3174652.0}, {
              9, 72162.0}}, TableHeadings -> {{"Model", "Error", 
              "Uncorrected Total", "Corrected Total"}, {"DF", "SumOfSq", 
              "MeanSq"}}]]}], ",", 
        RowBox[{"AsymptoticCorrelationMatrix", "\[Rule]", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1.`", "0.9999593245326618`"},
                  {"0.9999593245326615`", "1.`"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]]}], ",", 
        RowBox[{"FitCurvatureTable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Curvature\"\>"},
                {"\<\"Max Intrinsic\"\>", "0.0000324500042733249`"},
                {"\<\"Max Parameter-Effects\"\>", "2.663263180199361`"},
                {"\<\"95. % Confidence Region\"\>", "0.4735684046058749`"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            Function[ BoxForm`e$, 
              TableForm[ 
              BoxForm`e$, TableDepth -> 2, TableHeadings -> {{"Max Intrinsic",
                 "Max Parameter-Effects", "95. % Confidence Region"}, {
                "Curvature"}}]]]}]}], "}"}]], "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell["\<\
It is obtained that the intake has been 17590 Bq and the AMAD 7.2. Here are \
represented the experimental data versus the fitted parameters\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[
      model1[t, inp, \ p] /. Evaluate[BestFitParameters /. regress], \ {t, 
        1, \ 100}, \ \n\ \ Epilog\  -> \ {Hue[0. ], \ PointSize[0.02], \ 
          Map[Point, lungData1]}, \ PlotRange\  -> \ All]\)], "Input",
  CellLabel->"In[41]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0141895 0.00962001 -0.747699 0.00166879 [
[.20659 -0.00925 -6 -9 ]
[.20659 -0.00925 6 0 ]
[.39899 -0.00925 -6 -9 ]
[.39899 -0.00925 6 0 ]
[.59139 -0.00925 -6 -9 ]
[.59139 -0.00925 6 0 ]
[.78379 -0.00925 -6 -9 ]
[.78379 -0.00925 6 0 ]
[.97619 -0.00925 -9 -9 ]
[.97619 -0.00925 9 0 ]
[.00169 .08669 -18 -4.5 ]
[.00169 .08669 0 4.5 ]
[.00169 .17013 -18 -4.5 ]
[.00169 .17013 0 4.5 ]
[.00169 .25357 -18 -4.5 ]
[.00169 .25357 0 4.5 ]
[.00169 .33701 -18 -4.5 ]
[.00169 .33701 0 4.5 ]
[.00169 .42045 -18 -4.5 ]
[.00169 .42045 0 4.5 ]
[.00169 .50389 -18 -4.5 ]
[.00169 .50389 0 4.5 ]
[.00169 .58733 -18 -4.5 ]
[.00169 .58733 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20659 .00325 m
.20659 .0095 L
s
[(20)] .20659 -0.00925 0 1 Mshowa
.39899 .00325 m
.39899 .0095 L
s
[(40)] .39899 -0.00925 0 1 Mshowa
.59139 .00325 m
.59139 .0095 L
s
[(60)] .59139 -0.00925 0 1 Mshowa
.78379 .00325 m
.78379 .0095 L
s
[(80)] .78379 -0.00925 0 1 Mshowa
.97619 .00325 m
.97619 .0095 L
s
[(100)] .97619 -0.00925 0 1 Mshowa
.125 Mabswid
.06229 .00325 m
.06229 .007 L
s
.11039 .00325 m
.11039 .007 L
s
.15849 .00325 m
.15849 .007 L
s
.25469 .00325 m
.25469 .007 L
s
.30279 .00325 m
.30279 .007 L
s
.35089 .00325 m
.35089 .007 L
s
.44709 .00325 m
.44709 .007 L
s
.49519 .00325 m
.49519 .007 L
s
.54329 .00325 m
.54329 .007 L
s
.63949 .00325 m
.63949 .007 L
s
.68759 .00325 m
.68759 .007 L
s
.73569 .00325 m
.73569 .007 L
s
.83189 .00325 m
.83189 .007 L
s
.87999 .00325 m
.87999 .007 L
s
.92809 .00325 m
.92809 .007 L
s
.25 Mabswid
0 .00325 m
1 .00325 L
s
.01419 .08669 m
.02044 .08669 L
s
[(500)] .00169 .08669 1 0 Mshowa
.01419 .17013 m
.02044 .17013 L
s
[(550)] .00169 .17013 1 0 Mshowa
.01419 .25357 m
.02044 .25357 L
s
[(600)] .00169 .25357 1 0 Mshowa
.01419 .33701 m
.02044 .33701 L
s
[(650)] .00169 .33701 1 0 Mshowa
.01419 .42045 m
.02044 .42045 L
s
[(700)] .00169 .42045 1 0 Mshowa
.01419 .50389 m
.02044 .50389 L
s
[(750)] .00169 .50389 1 0 Mshowa
.01419 .58733 m
.02044 .58733 L
s
[(800)] .00169 .58733 1 0 Mshowa
.125 Mabswid
.01419 .01994 m
.01794 .01994 L
s
.01419 .03663 m
.01794 .03663 L
s
.01419 .05332 m
.01794 .05332 L
s
.01419 .07001 m
.01794 .07001 L
s
.01419 .10338 m
.01794 .10338 L
s
.01419 .12007 m
.01794 .12007 L
s
.01419 .13676 m
.01794 .13676 L
s
.01419 .15345 m
.01794 .15345 L
s
.01419 .18682 m
.01794 .18682 L
s
.01419 .20351 m
.01794 .20351 L
s
.01419 .2202 m
.01794 .2202 L
s
.01419 .23688 m
.01794 .23688 L
s
.01419 .27026 m
.01794 .27026 L
s
.01419 .28695 m
.01794 .28695 L
s
.01419 .30364 m
.01794 .30364 L
s
.01419 .32032 m
.01794 .32032 L
s
.01419 .3537 m
.01794 .3537 L
s
.01419 .37039 m
.01794 .37039 L
s
.01419 .38708 m
.01794 .38708 L
s
.01419 .40376 m
.01794 .40376 L
s
.01419 .43714 m
.01794 .43714 L
s
.01419 .45383 m
.01794 .45383 L
s
.01419 .47051 m
.01794 .47051 L
s
.01419 .4872 m
.01794 .4872 L
s
.01419 .52058 m
.01794 .52058 L
s
.01419 .53727 m
.01794 .53727 L
s
.01419 .55395 m
.01794 .55395 L
s
.01419 .57064 m
.01794 .57064 L
s
.01419 .60402 m
.01794 .60402 L
s
.25 Mabswid
.01419 0 m
.01419 .61803 L
s
.5 Mabswid
.02381 .60332 m
.02605 .5905 L
.02846 .58073 L
.03072 .57382 L
.03279 .56876 L
.04262 .55151 L
.06244 .52416 L
.10458 .47126 L
.14451 .42588 L
.18292 .38616 L
.22379 .34769 L
.26314 .31398 L
.30098 .28435 L
.34126 .2555 L
.38004 .23011 L
.42126 .20541 L
.46097 .18364 L
.49916 .16438 L
.53981 .14554 L
.57894 .12884 L
.62052 .11251 L
.66059 .098 L
.69914 .08507 L
.74014 .07234 L
.77963 .06096 L
.8176 .05076 L
.85802 .04063 L
.89693 .03153 L
.93829 .02249 L
.97619 .01472 L
s
1 0 0 r
.02 w
.11039 .46384 Mdot
.20659 .36371 Mdot
.30279 .28361 Mdot
.39899 .21853 Mdot
.49519 .1668 Mdot
.59139 .12341 Mdot
.68759 .08836 Mdot
.78379 .05999 Mdot
.87999 .03496 Mdot
.97619 .01494 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[41]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool006Eoo`H000Aoo`@0045oo`@000Aoo`@0045oo`@000Aoo`@0041oo`@000Eoo`@003]oo`L000=o
o`@000Eoo`@000Aoo`00IGoo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo041oo`03
001oogoo009oo`03001oogoo009oo`03001oogoo03eoo`03001oogoo009oo`04001oogoo0004Ool0
0`00Oomoo`0lOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0>goo00<007ooOol0
0goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo005oo`00IWoo00<007ooOol01Goo
00<007ooOol00Woo00<007ooOol0@7oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0?Goo
00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo03aoo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`0kOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<0
07ooOol00Goo001WOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0lOol60003Ool00`00
Oomoo`02Ool00`00Oomoo`0mOol20003Ool01000Oomoo`0017oo00<007ooOol0?7oo00<007ooOol0
0Woo00D007ooOomoo`0000Aoo`03001oogoo03]oo`03001oogoo00=oo`03001oogoo009oo`05001o
ogooOol00004Ool00`00Oomoo`01Ool006Qoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
03eoo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`0mOol00`00Ool000020003Ool00`00
Oomoo`02Ool00`00Oomoo`0mOol40004Ool00`00Oomoo`02Ool00`00Oomoo`0kOol00`00Oomoo`03
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol00Goo001YOol00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`0mOol01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol0?Goo
00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0?7oo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`03001oogoo03]oo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`01Ool006Eoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0nOol00`00Ool0
0004Ool00`00Oomoo`02Ool00`00Oomoo`0nOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomo
o`0lOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0>goo00<007ooOol00goo00<0
07ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo005oo`00IGoo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`03001oogoo03ioo`03001oo`0000Aoo`03001oogoo009oo`03001oogoo03moo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo03aoo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0iOol30005Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol00Goo
001VOol40005Ool40012Ool20005Ool40013Ool30003Ool40010Ool40005Ool4000nOol00`00Oomo
o`04Ool40005Ool40004Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003o
OonaOol0021oo`03001oogoo0?moohioo`0087oo00<007ooOol0ogooSWoo000JOooo002C0004Ool0
021oo`03001oogoo011oo`03001oogoo011oo`03001oogoo011oo`03001oogoo015oo`03001oogoo
011oo`03001oogoo011oo`03001oogoo011oo`03001oogoo015oo`03001oogoo011oo`03001oogoo
011oo`03001oogoo015oo`03001oogoo011oo`03001oogoo011oo`03001oogoo011oo`03001oogoo
015oo`03001oogoo011oo`03001oogoo011oo`03001oogoo011oo`03001oogoo015oo`03001oogoo
011oo`9l00eoo`0087oo00<007ooOol0BWoo00<007ooOol0BWoo00<007ooOol0BWoo00<007ooOol0
BWoo00<007ooOol0B7oo1W`02goo000POol00`00Oomoo`3oOommOol6O00;Ool0021oo`03001oogoo
0?moogaoo`Ql00Yoo`0087oo00<007ooOol0ogooN7oo100027`02Woo000POol2003oOomdOol50005
Ool6O00;Ool0021oo`03001oogoo0?moofioo`D000Yoo`Il00]oo`0087oo00<007ooOol0ogooJWoo
10004Goo0W`03Goo000POol00`00Oomoo`3oOomHOol2O00<Ool4000TOol0021oo`03001oogoo0?mo
oeIoo`Il00Ioo`@002Qoo`0087oo00<007ooOol0ogooEWoo1W`00Woo1000;7oo000POol00`00Oomo
o`3oOomEOol8O0000`00Oomoo`0^Ool0021oo`800?mooeIoo`Ql035oo`0087oo00<007ooOol0ogoo
DWoo10001W`0<Woo000POol00`00Oomoo`3oOom>Ool40004Ool6O00bOol0021oo`03001oogoo0?mo
odYoo`@000Yoo`9l03Aoo`0087oo00<007ooOol0ogooAWoo1000A7oo000POol00`00Oomoo`3oOom2
Ool40018Ool0021oo`03001oogoo0?mooc5oo`9l00]oo`@004aoo`0087oo0P00ogoo<7oo1W`01Goo
1000D7oo000POol00`00Oomoo`3oOol_Ool6O0000goo00000002001DOol0021oo`03001oogoo0?mo
obioo`Ql05Qoo`0087oo00<007ooOol0ogoo;Woo27`0F7oo000POol00`00Oomoo`3oOol[Ool40006
O01IOol0021oo`03001oogoo0?moobMoo`@000Aoo`Il05Uoo`0087oo0P00ogoo97oo10002Woo0W`0
Fgoo000POol00`00Oomoo`3oOolOOol4001[Ool0021oo`03001oogoo0?mooaaoo`<006moo`0087oo
00<007ooOol0ogoo6Goo0`00LWoo0002Ool40005Ool40005Ool40008Ool00`00Oomoo`3oOol;Ool2
O008Ool4001eOol00003Ool007oo00=oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<0
07ooOol01Goo00<007ooOol0ogoo2Goo1W`00goo0`00NGoo0006Ool01@00Oomoogoo000017oo00D0
07ooOomoo`0000Aoo`03001oogoo00Eoo`03001oogoo0?moo`Uoo`Il00<007aoo`001Woo00D007oo
Oomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`05Ool3003oOol8Ool8O01nOol000Ioo`05
001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol01Goo00<007ooOol0ogoo27oo27`0
OWoo0002Ool40004Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol01Goo00<007oo
Ool0ogoo27oo00<007`0O00017`0Ogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00<007ooOol01Goo00<007ooOol0ogoo1Goo0`0000=oog`0O00017`0Ogoo0002Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol01Goo00<007ooOol0
ogoo0goo0P001Woo0W`0PGoo0002Ool50004Ool40005Ool40008Ool00`00Oomoo`3oOol3002;Ool0
021oo`03001oogoo0?]oo`@008ioo`0087oo0P00nGoo0`00TWoo000POol00`00Oomoo`3eOol3002E
Ool0021oo`03001oogoo0?5oo`@009Qoo`0087oo00<007ooOol0kWoo0`00W7oo000POol00`00Oomo
o`3SOol2O007Ool2002OOol0021oo`03001oogoo0>5oo`Il00=oo`800:5oo`0087oo0P00hWoo1W`0
00=oo`000000Xgoo000POol00`00Oomoo`3POol8O02UOol0021oo`03001oogoo0>1oo`Ql0:Eoo`00
87oo00<007ooOol0hGoo1W`0YWoo000POol00`00Oomoo`3NOol30006O02VOol0021oo`03001oogoo
0=aoo`8000Eoo`9l0:Qoo`0087oo00<007ooOol0fWoo0P00/Goo000POol2003IOol2002cOol0021o
o`03001oogoo0=Eoo`<00;Eoo`0087oo00<007ooOol0dgoo0P00^7oo000POol00`00Oomoo`3AOol2
002jOol0021oo`03001oogoo0<ioo`<00;aoo`0087oo00<007ooOol0c7oo0P00_goo000POol00`00
Oomoo`3:Ool20031Ool0021oo`800<Uoo`800<=oo`0087oo00<007ooOol0aGoo0`00aGoo000POol0
0`00Oomoo`2mOol2O004Ool20038Ool0009oo`@000Eoo`@000Eoo`@000Qoo`03001oogoo0;]oo`Il
00800<Yoo`0000=oo`00Ool00goo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomo
o`05Ool00`00Oomoo`2kOol6O03<Ool000Ioo`03001oogoo00Ioo`05001oogooOol00004Ool00`00
Oomoo`05Ool00`00Oomoo`2jOol8O03;Ool000Ioo`03001oogoo00Ioo`05001oogooOol00004Ool0
0`00Oomoo`05Ool00`00Oomoo`2jOol8O03;Ool000Ioo`03001oogoo00Ioo`05001oogooOol00004
Ool00`00Oomoo`05Ool3002iOol20006O03<Ool0009oo`@000Eoo`@000Aoo`03001oogoo009oo`03
001oogoo00Eoo`03001oogoo0;Moo`80009oo`Il0<aoo`000Woo00<007ooOol01Woo00<007ooOol0
1Goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0]Goo0P001Woo0W`0cWoo0002Ool00`00
Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`2cOol2003H
Ool0009oo`D000Aoo`D000Aoo`@000Qoo`03001oogoo0;5oo`800=Yoo`0087oo00<007ooOol0/7oo
00<007ooOol0fWoo000POol2002_Ool2003MOol0021oo`03001oogoo0:aoo`800=moo`0087oo00<0
07ooOol0ZWoo0P00hGoo000POol00`00Oomoo`2YOol00`00Oomoo`3QOol0021oo`03001oogoo0:Mo
o`800>Aoo`0087oo00<007ooOol0YGoo0P00iWoo000POol00`00Oomoo`2SOol2003XOol0021oo`80
0:9oo`800>Yoo`0087oo00<007ooOol0X7oo00<007ooOol0jWoo000POol00`00Oomoo`2FOol2O006
Ool2003]Ool0021oo`03001oogoo09Aoo`Il009oo`800>moo`0087oo00<007ooOol0U7oo1W`000=o
o`00Ool0l7oo000POol00`00Oomoo`2COol8O03bOol0021oo`03001oogoo09=oo`Ql0?9oo`0087oo
0P00UGoo1W`0lgoo000POol00`00Oomoo`2DOol6O03cOol0021oo`03001oogoo099oo`80009oo`9l
0?Eoo`0087oo00<007ooOol0T7oo0P00ngoo000POol00`00Oomoo`2?Ool00`00Oomoo`3kOol0021o
o`03001oogoo08eoo`800?ioo`0087oo0P00SGoo00<007ooOol0oWoo000POol00`00Oomoo`2:Ool2
003oOol2Ool0021oo`03001oogoo08Uoo`03001oogoo0?moo`9oo`000goo100017oo10001Goo1000
27oo00<007ooOol0Qgoo0P00ogoo1Goo0002Ool00`00Oomoo`02Ool01000Oomoo`0017oo00D007oo
Oomoo`0000Aoo`03001oogoo00Eoo`03001oogoo08Ioo`03001oogoo0?moo`Eoo`000Woo00<007oo
Ool00Woo00@007ooOol000Aoo`05001oogooOol00004Ool00`00Oomoo`05Ool00`00Oomoo`24Ool2
003oOol8Ool0009oo`8000=oo`04001oogoo0004Ool01@00Oomoogoo000017oo00<007ooOol01Goo
00<007ooOol0Pgoo00<007ooOol0ogoo27oo0002Ool00`00Ool000020003Ool00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00<007ooOol01Goo0`00PGoo0P00ogoo2goo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol01Goo00<007ooOol0P7oo00<007ooOol0
ogoo2goo0003Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0
1Goo00<007ooOol0OWoo0P00ogoo3Woo0004Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00<007ooOol01Goo00<007ooOol0OGoo00<007ooOol0ogoo3Woo0005Ool30003Ool4
0005Ool40008Ool00`00Oomoo`1kOol2003oOolAOol0021oo`03001oogoo07Yoo`03001oogoo0?mo
oa5oo`0087oo00<007ooOol0N7oo0P00ogoo57oo000POol2001gOol2003oOolFOol0021oo`03001o
ogoo071oo`9l00=oo`03001oogoo0?mooaIoo`0087oo00<007ooOol0KWoo1W`000<007ooOol0ogoo
5goo000POol00`00Oomoo`1^Ool6O03oOolJOol0021oo`03001oogoo06eoo`Ql0?mooaUoo`0087oo
00<007ooOol0KGoo27`0ogoo6Goo000POol2001_Ool6O03oOolJOol0021oo`03001oogoo06aoo`80
00Il0?mooaYoo`0087oo00<007ooOol0Jgoo00<007ooOol00Woo0W`0ogoo77oo000POol00`00Oomo
o`1ZOol00`00Oomoo`3oOolQOol0021oo`03001oogoo06Uoo`03001oogoo0?moob9oo`0087oo00<0
07ooOol0Igoo0P00ogoo9Goo000POol00`00Oomoo`1VOol00`00Oomoo`3oOolUOol0021oo`8006Io
o`03001oogoo0?moobIoo`0087oo00<007ooOol0I7oo00<007ooOol0ogoo9goo000POol00`00Oomo
o`1ROol2003oOolZOol0021oo`03001oogoo065oo`03001oogoo0?moobYoo`0087oo00<007ooOol0
H7oo00<007ooOol0ogoo:goo000POol00`00Oomoo`1OOol00`00Oomoo`3oOol/Ool0021oo`03001o
ogoo05ioo`03001oogoo0?moobeoo`0087oo0P00GWoo00<007ooOol0ogoo;Woo000POol00`00Oomo
o`1LOol00`00Oomoo`3oOol_Ool0021oo`03001oogoo05]oo`03001oogoo0?mooc1oo`000goo1000
17oo10001Goo100027oo00<007ooOol0FWoo00<007ooOol0ogoo<Goo0002Ool00`00Oomoo`02Ool0
1000Oomoo`0017oo00D007ooOomoo`0000Aoo`03001oogoo00Eoo`03001oogoo05Qoo`800?moocAo
o`000Woo00<007ooOol00Woo00<007ooOol01Goo00D007ooOomoo`0000Aoo`03001oogoo00Eoo`03
001oogoo05Moo`03001oogoo0?moocAoo`000Woo0P000goo00<007ooOol01Goo00D007ooOomoo`00
00Aoo`03001oogoo00Eoo`<005Ioo`03001oogoo0?moocEoo`000Woo00<007oo00000P0027oo00D0
07ooOomoo`0000Aoo`03001oogoo00Eoo`03001oogoo05Eoo`03001oogoo0?moocIoo`000Woo00<0
07ooOol01Woo100017oo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0E7oo00<007ooOol0
ogoo=goo0003Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`05Ool0
0`00Oomoo`1COol00`00Oomoo`3oOolhOol000Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03001o
ogoo009oo`03001oogoo00Eoo`03001oogoo059oo`03001oogoo0?moocUoo`001Goo0`000goo1@00
17oo100027oo00<007ooOol0DGoo00<007ooOol0ogoo>Woo000POol00`00Oomoo`1@Ool00`00Oomo
o`3oOolkOol0021oo`80051oo`03001oogoo0?moocaoo`0087oo00<007ooOol0BGoo0W`00goo00<0
07ooOol0ogoo?Goo000POol00`00Oomoo`17Ool6O0000`00Oomoo`3oOolnOol0021oo`03001oogoo
04Moo`Il0?mood5oo`0087oo00<007ooOol0AWoo27`0ogoo@7oo000POol00`00Oomoo`16Ool8O03o
Oom0Ool0021oo`03001oogoo04Moo`Il0?mood5oo`0087oo0P00B7oo1W`0ogoo@Goo000POol00`00
Oomoo`16Ool00`00Oomoo`02O03oOom3Ool0021oo`03001oogoo04Aoo`800?moodQoo`0087oo00<0
07ooOol0@goo00<007ooOol0ogooB7oo000POol00`00Oomoo`12Ool00`00Oomoo`3oOom9Ool0021o
o`03001oogoo045oo`03001oogoo0?moodYoo`0087oo0P00@Goo00<007ooOol0ogooBgoo000POol0
0`00Oomoo`0oOol00`00Oomoo`3oOom<Ool0021oo`03001oogoo03ioo`03001oogoo0?moodeoo`00
87oo00<007ooOol0?Goo00<007ooOol0ogooCWoo000POol00`00Oomoo`0lOol00`00Oomoo`3oOom?
Ool0021oo`03001oogoo03]oo`03001oogoo0?mooe1oo`0087oo00<007ooOol0>Woo00<007ooOol0
ogooDGoo000POol2000jOol00`00Oomoo`3oOomBOol0021oo`03001oogoo03Qoo`03001oogoo0?mo
oe=oo`0087oo00<007ooOol0>7oo00<007ooOol0ogooDgoo0004Ool00`00Oomoo`04Ool40005Ool4
0008Ool00`00Oomoo`0gOol00`00Oomoo`3oOomDOol000Aoo`03001oogoo00=oo`03001oogoo009o
o`05001oogooOol00004Ool00`00Oomoo`05Ool00`00Oomoo`0fOol00`00Oomoo`3oOomEOol000Ao
o`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`05Ool00`00Oomo
o`0eOol00`00Oomoo`3oOomFOol000Eoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`05Ool00`00Oomoo`0dOol00`00Oomoo`3oOomGOol000Eoo`03001oogoo009o
o`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`05Ool3000cOol00`00Oomoo`3oOomH
Ool000Eoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`05Ool0
0`00Oomoo`0bOol00`00Oomoo`3oOomIOol000Ioo`05001oogooOol00004Ool01@00Oomoogoo0000
17oo00<007ooOol01Goo00<007ooOol0<Goo00<007ooOol0ogooFWoo00000goo001oo`03Ool01@00
Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Eoo`03001oogoo031oo`03001oogoo
0?mooe]oo`0000=oo`000000100017oo10001Goo100027oo00<007ooOol0;goo00<007ooOol0ogoo
G7oo000POol00`00Oomoo`0^Ool00`00Oomoo`3oOomMOol0021oo`03001oogoo02eoo`03001oogoo
0?mooeioo`0087oo0P00;Woo00<007ooOol0ogooGWoo000POol00`00Oomoo`0/Ool00`00Oomoo`3o
OomOOol0021oo`03001oogoo02]oo`03001oogoo0?moof1oo`0087oo00<007ooOol0:Woo00<007oo
Ool0ogooHGoo000POol00`00Oomoo`0YOol00`00Oomoo`3oOomROol0021oo`03001oogoo02Qoo`03
001oogoo0?moof=oo`0087oo0P00:7oo00<007ooOol0ogooI7oo000POol00`00Oomoo`0SOol2O000
0goo001oo`3oOomVOol0021oo`03001oogoo025oo`Il0?moofMoo`0087oo00<007ooOol08Goo1W`0
ogooIgoo000POol00`00Oomoo`0POol8O03oOomVOol0021oo`03001oogoo021oo`Ql0?moofIoo`00
87oo00<007ooOol08Goo1W`0ogooIgoo000POol2000ROol6O03oOomWOol0021oo`03001oogoo021o
o`03001oogoo009l0?moofUoo`0087oo00<007ooOol07goo00<007ooOol0ogooK7oo000POol00`00
Oomoo`0OOol00`00Oomoo`3oOom/Ool0021oo`03001oogoo01ioo`03001oogoo0?moofeoo`0087oo
00<007ooOol07Goo00<007ooOol0ogooKWoo000POol00`00Oomoo`0LOol00`00Oomoo`3oOom_Ool0
021oo`8001aoo`03001oogoo0?moog1oo`0087oo00<007ooOol06goo00<007ooOol0ogooL7oo000P
Ool00`00Oomoo`0JOol00`00Oomoo`3oOomaOol000Aoo`03001oogoo00Aoo`@000Eoo`@000Qoo`03
001oogoo01Uoo`03001oogoo0?moog9oo`0017oo00<007ooOol00goo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`03001oogoo00Eoo`03001oogoo01Qoo`03001oogoo0?moog=oo`0017oo00<007oo
Ool027oo00D007ooOomoo`0000Aoo`03001oogoo00Eoo`03001oogoo01Moo`03001oogoo0?moogAo
o`001Goo00<007ooOol01goo00D007ooOomoo`0000Aoo`03001oogoo00Eoo`<001Ioo`03001oogoo
0?moogEoo`001Goo00<007ooOol01goo00D007ooOomoo`0000Aoo`03001oogoo00Eoo`03001oogoo
01Ioo`03001oogoo0?moogEoo`001Goo00<007ooOol00goo100017oo00<007ooOol00Woo00<007oo
Ool01Goo00<007ooOol05Goo00<007ooOol0ogooMWoo0006Ool00`00Oomoo`02Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`0DOol00`00Oomoo`3oOomgOol00003Ool0
07oo00=oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Eoo`03001o
ogoo01=oo`03001oogoo0?moogQoo`0000=oo`000000100017oo1@0017oo100027oo00<007ooOol0
4Woo00<007ooOol0ogooNGoo000POol00`00Oomoo`0BOol00`00Oomoo`3oOomiOol0021oo`80019o
o`03001oogoo0?moogYoo`0087oo00<007ooOol047oo00<007ooOol0ogooNgoo000POol00`00Oomo
o`0?Ool00`00Oomoo`3oOomlOol0021oo`03001oogoo00moo`03001oogoo0?moogaoo`0087oo00<0
07ooOol03Woo00<007ooOol0ogooOGoo000POol00`00Oomoo`0=Ool00`00Oomoo`3oOomnOol0021o
o`03001oogoo00aoo`03001oogoo0?moogmoo`0087oo0P003Goo00<007ooOol0ogooOgoo000POol0
0`00Oomoo`0;Ool00`00Oomoo`3oOon0Ool0021oo`03001oogoo00Yoo`03001oogoo0?mooh5oo`00
87oo00<007ooOol02Goo00<007ooOol0ogooPWoo000POol00`00Oomoo`09Ool00`00Oomoo`3oOon2
Ool0021oo`03001oogoo00Qoo`03001oogoo0?mooh=oo`0087oo0P0027oo00<007ooOol0ogooQ7oo
000POol00`00Oomoo`07Ool00`00Oomoo`3oOon4Ool0021oo`03001oogoo00Ioo`03001oogoo0?mo
ohEoo`0087oo00<007ooOol01Woo00<007ooOol0ogooQGoo000POol00`00Oomoo`05Ool00`00Oomo
o`3oOon6Ool0021oo`03001oogoo00Eoo`03001oogoo0?moohIoo`0087oo00<007ooOol017oo00<0
07ooOol0ogooQgoo000POol20004Ool00`00Oomoo`3oOon8Ool0021oo`03001oogoo00=oo`03001o
ogoo0?moohQoo`0087oo00<007ooOol00goo00<007ooOol0ogooR7oo0002Ool40005Ool40005Ool4
0008Ool00`00Oomoo`02Ool00`00Oomoo`3oOon9Ool00003Ool007oo00=oo`05001oogooOol00004
Ool01@00Oomoogoo000017oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0ogooRGoo0000
0goo001oo`03Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Eoo`03001o
ogoo009oo`03001oogoo0?moohUoo`0000=oo`00Ool00goo00D007ooOomoo`0000Aoo`05001oogoo
Ool00004Ool00`00Oomoo`05Ool01@00Oomoogoo0000ogooS7oo0002Ool40004Ool00`00Oomoo`02
Ool01@00Oomoogoo000017oo00<007ooOol01Goo0`0000=oo`00Ool0ogooRgoo00000goo001oo`03
Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Eoo`05001oogooOol0003o
Oon<Ool00003Ool007oo00=oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol0
1Goo00D007ooOomoo`000?moohaoo`0000=oo`00Ool00goo00D007ooOomoo`0000Aoo`05001oogoo
Ool00004Ool00`00Oomoo`05Ool01@00Oomoogoo0000ogooS7oo0002Ool40005Ool40005Ool40008
Ool01000Oomoo`00ogooSGoo000POol01000Oomoo`00ogooSGoo000POol200000goo001oo`3oOon<
Ool0021oo`03001oogoo0?moohioo`0087oo00<007ooOol0ogooSWoo000POol00`00Oomoo`3oOon>
Ool0021oo`03001oogoo0?moohioo`0087oo00<007ooOol0ogooSWoo000POol00`00Oomoo`3oOon>
Ool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-8.30395, 421.559, 0.389118, \
2.24313}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[41]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 4", "SubsubsectionIcon"],

Cell["\<\
Here is repeted the previous example including experimental uncertainties\
\>", "Text"],

Cell[BoxData[
    \(\(lungData2\  = {{10, 726\ , \ 12}, {20, 666, \ 7}, {30, 618, \ 
            6}, {40, 579, \ 5}, {50, 548, \ 5}, {60, 522, \ 5}, {70, 501, \ 
            5}, {80, 484, \ 5}, {90, 469, \ 5}, {100, 457, \ 
            5}};\)\)], "Input",
  CellLabel->"In[42]:="],

Cell[TextData[{
  "Note it is used the function ",
  StyleBox["X2FitE", "Input"],
  " included in the ",
  StyleBox["Biokmod", "Input"],
  " package ",
  StyleBox["Fitmodel", "Input"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindMinimum[
      X2FitE[{int, \ p}, lungData2, model1[t1, int, p], \ \ \ t1], {int, \ 
        10000, \ 20000}, {p, \ 3, \ 10}]\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \({0.016577930738200755`, {int \[Rule] 17917.547183310493`, 
        p \[Rule] 7.316944939890148`}}\)], "Output",
  CellLabel->"Out[43]="]
}, Open  ]],

Cell["\<\
Here is the same example but chosen the best fit for a discrete number of \
AMADs\
\>", "MathCaption"],

Cell["model2[t1_, inp_, amad_]:= inp lung[amad ,t1]  ", "Input",
  CellLabel->"In[44]:="],

Cell[TextData[{
  "Note it is used the function ",
  StyleBox["X2Fit", "Input"],
  " included in the ",
  StyleBox["Biokmod", "Input"],
  " package ",
  StyleBox["Fitmodel", "Input"]
}], "Text"],

Cell[BoxData[
    \(\(amadfitted = 
        Map[FindMinimum[
              X2FitE[{int}, lungData2, 
                model2[t, int, AMADAdultW[#1]], \ \ \ t], {int, \ 10000, \ 
                20000}] &, \ Range[15]];\)\)], "Input",
  CellLabel->"In[45]:="],

Cell["\<\
The best fit is an intake of {17415-20287} Bq with and AMAD {7 - 8}.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[{Table[amad[i], \ {i, \ 1, \ 15}], amadfitted\ }] // 
      TableForm\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(amad[1]\), GridBox[{
                {"14.682108415463908`"},
                {\(int \[Rule] 6356.574227849551`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(amad[2]\), GridBox[{
                {"6.9344742169467155`"},
                {\(int \[Rule] 7297.937694228812`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(amad[3]\), GridBox[{
                {"2.9536523995475967`"},
                {\(int \[Rule] 8676.595775137614`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(amad[4]\), GridBox[{
                {"1.2956690462492815`"},
                {\(int \[Rule] 10424.743974483614`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(amad[5]\), GridBox[{
                {"0.3928043122752117`"},
                {\(int \[Rule] 12491.981582916962`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(amad[6]\), GridBox[{
                {"0.06841157576445209`"},
                {\(int \[Rule] 14854.54355030752`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(amad[7]\), GridBox[{
                {"0.019581006984564844`"},
                {\(int \[Rule] 17415.588636644366`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(amad[8]\), GridBox[{
                {"0.018368242299815218`"},
                {\(int \[Rule] 20287.700974748255`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(amad[9]\), GridBox[{
                {"0.050897583651047205`"},
                {\(int \[Rule] 23600.154451786453`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(amad[10]\), GridBox[{
                {"0.443705861057878`"},
                {\(int \[Rule] 27793.660807076285`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(amad[11]\), GridBox[{
                {"0.8295104830577158`"},
                {\(int \[Rule] 32309.028040124016`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(amad[12]\), GridBox[{
                {"1.3127512748476766`"},
                {\(int \[Rule] 37325.50353560237`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(amad[13]\), GridBox[{
                {"1.8390939545278222`"},
                {\(int \[Rule] 42761.143255950934`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(amad[14]\), GridBox[{
                {"2.3330875184514306`"},
                {\(int \[Rule] 48496.95502883842`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(amad[15]\), GridBox[{
                {"2.7183339178887986`"},
                {\(int \[Rule] 54408.919034331404`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{
        amad[ 1], {14.682108415463908, {int -> 6356.5742278495509}}}, {
        amad[ 2], {6.9344742169467155, {int -> 7297.9376942288118}}}, {
        amad[ 3], {2.9536523995475967, {int -> 8676.5957751376136}}}, {
        amad[ 4], {1.2956690462492815, {int -> 10424.743974483614}}}, {
        amad[ 5], {.39280431227521168, {int -> 12491.981582916962}}}, {
        amad[ 6], {.068411575764452087, {int -> 14854.54355030752}}}, {
        amad[ 7], {.019581006984564844, {int -> 17415.588636644366}}}, {
        amad[ 8], {.018368242299815218, {int -> 20287.700974748255}}}, {
        amad[ 9], {.050897583651047205, {int -> 23600.154451786453}}}, {
        amad[ 10], {.44370586105787801, {int -> 27793.660807076285}}}, {
        amad[ 11], {.8295104830577158, {int -> 32309.028040124016}}}, {
        amad[ 12], {1.3127512748476766, {int -> 37325.503535602373}}}, {
        amad[ 13], {1.8390939545278222, {int -> 42761.143255950934}}}, {
        amad[ 14], {2.3330875184514306, {int -> 48496.95502883842}}}, {
        amad[ 15], {2.7183339178887986, {int -> 
        54408.919034331404}}}}]]], "Output",
  CellLabel->"Out[46]//TableForm="]
}, Open  ]],

Cell[BoxData[
    \(Clear[lungData1, \ lung, \ regress, \ lungData2, \ model1, \ \ model2, 
      amadfitted\ ]\)], "Input",
  CellLabel->"In[47]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 5", "SubsubsectionIcon"],

Cell["\<\
In this example it is shown how the intake and the AMAD can be estimated \
using the daily urine excretion retention measured (simulated). It is \
supposed uranium airborne type S.We will need to build a function that give \
the daily urine excretion as function of the intake and AMAD.\
\>", "MathCaption"],

Cell[BoxData[
    \(\(blood[{ai_, bbf_, \ bbs_, \ BBf_, \ BBs_, \ et2_, \ et1_}, \ t_\ ] = 
        qB[t] /. qRTandGI[1, {ai, bbf, \ bbs, \ BBf, \ BBs, \ et2, \ et1}, S, 
            0.002, \ t];\)\)], "Input",
  CellLabel->"In[48]:="],

Cell["\<\
inputB[t1_, inp_, p_]= inp Rationalize[D[blood[AMADfit[p], t1], t1]];\
\>", "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \(\(uraniumMatrix\  = \ 
        compartMatrix[uranium] /. Options[qGI];\)\)], "Input",
  CellLabel->"In[50]:="],

Cell[BoxData[
    \(uraniumURI[t1_, inp_?NumericQ, 
        p_?NumericQ] := \((b[t2_]\  = \ 
          x\_17[t2] /. 
            SystemNDSolve[uraniumMatrix\ \ , \ PadRight[{}, 20], 
              PadRight[{inputB[t, inp, p] // ExpandAll}, 20]\ , {t, \ 0, \ 
                1000}, t2, \ x]; \ 
        b[t2] - b[t2 - 1] /. t2 \[Rule] \ t1\ )\)\)], "Input",
  CellLabel->"In[51]:="],

Cell["\<\
uriData are the experimental data. They are already simulated using a  random \
measured from an input of 13000 Bq and AMAD 7 \
\>", "MathCaption"],

Cell[BoxData[
    \(\(uriData\  = {{2, 0.531}, {7, 0.214}, {18, 0.124}, {50, 0.065}, {90, 
            0.040}, {120, 0.056}, {180, 0.028}, {300, 0.026}, {360, 
            0.035}, {420, 0.007}, {600, 0.014}};\)\)], "Input",
  CellLabel->"In[52]:="],

Cell["Here are estimated the input and the AMAD ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindMinimum[
        X2Fit[{inp, \ p}, uriData, uraniumURI[t1, inp, p]\ , \ t1], {inp, 
          10000, \ 15000}, {p, 5, \ 10}] // Timing\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    \({161.76599999999996`\ Second, {0.0009318592195078345`, {inp \[Rule] 
            12423.034266162089`, p \[Rule] 6.568524703288289`}}}\)], "Output",\

  CellLabel->"Out[53]="]
}, Open  ]],

Cell[TextData[{
  "Note: It can be used ",
  Cell[BoxData[
      \(TraditionalForm\`FindFit[
        uriData, \ \ uraniumURI[t1, inp, 
          p], \ {{inp, 10000, \ 15000}, {p, 5, \ 10}}, \ t1]\)]],
  " but it will take a long time"
}], "Text"],

Cell["\<\
If we are interested in obtain a full statistic report, we can used \
NonlinearRegress. Because uraniumURI gives numeric solution we will need to \
define the derivatives.\
\>", "MathCaption"],

Cell[BoxData[
    \(\(\(Derivative[0, 1, 0]\)[uraniumURI]\)[a1_, n_, a3_] := 
      uraniumURI[a1, 1, a3]\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \(\(\(Derivative[0, 0, 1]\)[uraniumURI]\)[a1_, a2_, n_] := 
      100  a2\ \((uraniumURI[a1, 1, n + 0.005] - 
            uraniumURI[a1, 1, n - 0.005])\)\)], "Input",
  CellLabel->"In[55]:="],

Cell["\<\
This derivative is an approximation obtained using the derivative \
definition\
\>", "Commentary"],

Cell[CellGroupData[{

Cell[BoxData[
    \(regress = \ 
      NonlinearRegress[uriData, 
        uraniumURI[t1, inp, 
          p], {t1}, {{inp, {10000, 15000}}, {p, {6, 9}}}]\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(BestFitParameters \[Rule] {inp \[Rule] 12425.401096280148`, 
            p \[Rule] 6.576196732397172`}\), ",", 
        RowBox[{"ParameterCITable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"Asymptotic SE\"\>", "\<\
\"CI\"\>"},
                {"inp", "12425.401096280148`", 
                  "425.9003853227268`", \({11461.947488983826`, 
                    13388.85470357647`}\)},
                {"p", "6.576196732397172`", 
                  "0.772569547112778`", \({4.828522997636236`, 
                    8.323870467158107`}\)}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            Function[ BoxForm`e$, 
              TableForm[ 
              BoxForm`e$, TableDepth -> 2, TableHeadings -> {{inp, p}, {
                "Estimate", "Asymptotic SE", "CI"}}]]]}], 
        ",", \(EstimatedVariance \[Rule] 0.0001035385819380558`\), ",", 
        RowBox[{"ANOVATable", "\[Rule]", 
          InterpretationBox[GridBox[{
                {"\<\"\"\>", "\<\"DF\"\>", "\<\"SumOfSq\"\>", \
"\<\"MeanSq\"\>"},
                {"\<\"Model\"\>", "2", "0.35409215276255745`", 
                  "0.17704607638127873`"},
                {"\<\"Error\"\>", "9", "0.0009318472374425023`", 
                  "0.0001035385819380558`"},
                {"\<\"Uncorrected Total\"\>", "11", 
                  "0.35502399999999995`", "\<\"\"\>"},
                {"\<\"Corrected Total\"\>", "10", 
                  "0.2368785454545455`", "\<\"\"\>"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            
            TableForm[ {{2, .35409215276255745, .17704607638127873}, {
              9, .00093184723744250226, .00010353858193805581}, {
              11, .35502399999999995}, {10, .23687854545454551}}, 
              TableHeadings -> {{"Model", "Error", "Uncorrected Total", 
              "Corrected Total"}, {"DF", "SumOfSq", "MeanSq"}}]]}], ",", 
        RowBox[{"AsymptoticCorrelationMatrix", "\[Rule]", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1.0000000000000002`", "0.8666438859170091`"},
                  {"0.8666438859170091`", "1.0000000000000002`"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]]}], ",", 
        RowBox[{"FitCurvatureTable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Curvature\"\>"},
                {"\<\"Max Intrinsic\"\>", "0.0026655890787262637`"},
                {"\<\"Max Parameter-Effects\"\>", "0.22011723871921204`"},
                {"\<\"95. % Confidence Region\"\>", "0.4847010382866134`"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            Function[ BoxForm`e$, 
              TableForm[ 
              BoxForm`e$, TableDepth -> 2, TableHeadings -> {{"Max Intrinsic",
                 "Max Parameter-Effects", "95. % Confidence Region"}, {
                "Curvature"}}]]]}]}], "}"}]], "Output",
  CellLabel->"Out[56]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[
      Evaluate[uraniumURI[t, inp, \ p] /. 
          Evaluate[BestFitParameters /. regress]], \ {t, 5, \ 
        700}, \ \n\ \ Epilog\  -> \ {Hue[0. ], \ PointSize[0.02], \ 
          Map[Point, uriData]}, \ PlotRange\  -> \ All]\)], "Input",
  CellLabel->"In[57]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0169578 0.00137033 -0.0327443 2.46862 [
[.15399 .20162 -9 -9 ]
[.15399 .20162 9 0 ]
[.29102 .20162 -9 -9 ]
[.29102 .20162 9 0 ]
[.42806 .20162 -9 -9 ]
[.42806 .20162 9 0 ]
[.56509 .20162 -9 -9 ]
[.56509 .20162 9 0 ]
[.70212 .20162 -9 -9 ]
[.70212 .20162 9 0 ]
[.83916 .20162 -9 -9 ]
[.83916 .20162 9 0 ]
[.97619 .20162 -9 -9 ]
[.97619 .20162 9 0 ]
[.00446 .09069 -24 -4.5 ]
[.00446 .09069 0 4.5 ]
[.00446 .33755 -24 -4.5 ]
[.00446 .33755 0 4.5 ]
[.00446 .46098 -18 -4.5 ]
[.00446 .46098 0 4.5 ]
[.00446 .58441 -24 -4.5 ]
[.00446 .58441 0 4.5 ]
[ 0 -0.00818 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15399 .21412 m
.15399 .22037 L
s
[(100)] .15399 .20162 0 1 Mshowa
.29102 .21412 m
.29102 .22037 L
s
[(200)] .29102 .20162 0 1 Mshowa
.42806 .21412 m
.42806 .22037 L
s
[(300)] .42806 .20162 0 1 Mshowa
.56509 .21412 m
.56509 .22037 L
s
[(400)] .56509 .20162 0 1 Mshowa
.70212 .21412 m
.70212 .22037 L
s
[(500)] .70212 .20162 0 1 Mshowa
.83916 .21412 m
.83916 .22037 L
s
[(600)] .83916 .20162 0 1 Mshowa
.97619 .21412 m
.97619 .22037 L
s
[(700)] .97619 .20162 0 1 Mshowa
.125 Mabswid
.04436 .21412 m
.04436 .21787 L
s
.07177 .21412 m
.07177 .21787 L
s
.09918 .21412 m
.09918 .21787 L
s
.12658 .21412 m
.12658 .21787 L
s
.1814 .21412 m
.1814 .21787 L
s
.2088 .21412 m
.2088 .21787 L
s
.23621 .21412 m
.23621 .21787 L
s
.26362 .21412 m
.26362 .21787 L
s
.31843 .21412 m
.31843 .21787 L
s
.34584 .21412 m
.34584 .21787 L
s
.37324 .21412 m
.37324 .21787 L
s
.40065 .21412 m
.40065 .21787 L
s
.45546 .21412 m
.45546 .21787 L
s
.48287 .21412 m
.48287 .21787 L
s
.51028 .21412 m
.51028 .21787 L
s
.53768 .21412 m
.53768 .21787 L
s
.5925 .21412 m
.5925 .21787 L
s
.6199 .21412 m
.6199 .21787 L
s
.64731 .21412 m
.64731 .21787 L
s
.67472 .21412 m
.67472 .21787 L
s
.72953 .21412 m
.72953 .21787 L
s
.75694 .21412 m
.75694 .21787 L
s
.78434 .21412 m
.78434 .21787 L
s
.81175 .21412 m
.81175 .21787 L
s
.86656 .21412 m
.86656 .21787 L
s
.89397 .21412 m
.89397 .21787 L
s
.92138 .21412 m
.92138 .21787 L
s
.94878 .21412 m
.94878 .21787 L
s
.25 Mabswid
0 .21412 m
1 .21412 L
s
.01696 .09069 m
.02321 .09069 L
s
[(0.05)] .00446 .09069 1 0 Mshowa
.01696 .33755 m
.02321 .33755 L
s
[(0.15)] .00446 .33755 1 0 Mshowa
.01696 .46098 m
.02321 .46098 L
s
[(0.2)] .00446 .46098 1 0 Mshowa
.01696 .58441 m
.02321 .58441 L
s
[(0.25)] .00446 .58441 1 0 Mshowa
.125 Mabswid
.01696 .11537 m
.02071 .11537 L
s
.01696 .14006 m
.02071 .14006 L
s
.01696 .16475 m
.02071 .16475 L
s
.01696 .18943 m
.02071 .18943 L
s
.01696 .2388 m
.02071 .2388 L
s
.01696 .26349 m
.02071 .26349 L
s
.01696 .28818 m
.02071 .28818 L
s
.01696 .31286 m
.02071 .31286 L
s
.01696 .36223 m
.02071 .36223 L
s
.01696 .38692 m
.02071 .38692 L
s
.01696 .41161 m
.02071 .41161 L
s
.01696 .43629 m
.02071 .43629 L
s
.01696 .48567 m
.02071 .48567 L
s
.01696 .51035 m
.02071 .51035 L
s
.01696 .53504 m
.02071 .53504 L
s
.01696 .55972 m
.02071 .55972 L
s
.01696 .066 m
.02071 .066 L
s
.01696 .04131 m
.02071 .04131 L
s
.01696 .01663 m
.02071 .01663 L
s
.01696 .6091 m
.02071 .6091 L
s
.25 Mabswid
.01696 0 m
.01696 .61803 L
s
.5 Mabswid
.02381 .60332 m
.02605 .53221 L
.02846 .46978 L
.03279 .38284 L
.03793 .30913 L
.04262 .26086 L
.0475 .22352 L
.05281 .19348 L
.05782 .17212 L
.06244 .1567 L
.07218 .13319 L
.07771 .12341 L
.0829 .11583 L
.09334 .10376 L
.10458 .09394 L
.12571 .08064 L
.1458 .07171 L
.16561 .06511 L
.184 .06033 L
.22313 .05293 L
.24454 .04994 L
.26471 .04756 L
.30326 .04387 L
.34426 .04072 L
.38375 .03816 L
.42172 .03599 L
.46215 .03389 L
.50106 .03202 L
.54242 .03015 L
.58226 .02845 L
.62059 .02689 L
.66137 .02529 L
.70064 .02382 L
.73839 .02244 L
.77859 .02103 L
.81728 .01971 L
.85842 .01836 L
.89804 .01709 L
.93615 .01592 L
.97619 .01472 L
s
1 0 0 r
.02 w
.02655 .49554 Mdot
.04162 .27336 Mdot
.08547 .12772 Mdot
.14029 .066 Mdot
.1814 .1055 Mdot
.26362 .03638 Mdot
.42806 .03144 Mdot
.51028 .05366 Mdot
.83916 .00182 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[57]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[57]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[uriData, blood, uraniumMatrix, inputToB, inputToST, \ 
      uraniumURI]\)], "Input",
  CellLabel->"In[58]:="]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Using simultaneously several bioassay to evaluate the intake  \
\>", "SubsectionIcon"],

Cell["\<\
Often it is better make more than one kind of bioassay (e.g.: lung retention \
and urine excretion) to estimate the intake and  AMAD. \
\>", "Text"],

Cell[BoxData[
    \(Clear[uraniumLungRet, model, model1, \ uraniumUriExcretion, 
      uraniumFecExcretion, sampleLung, sampleUri, sampleFec, intakefitted, \ 
      caesiumWb, caesiumUri, sampleWb, sampleUri, xUri, fittedparameters, 
      fitUri]\)], "Input",
  CellLabel->"In[59]:="],

Cell[CellGroupData[{

Cell["Example 1", "SubsubsectionIcon"],

Cell["\<\
Here are simulated the lung retention and the urine and faecal excretion for \
an acute intake of uranium S inhalation of 13500 Bq of  AMAD 7, including a \
random noise and the measured uncertainties. It will be used in the following \
examples has if it were experimental data\
\>", "MathCaption"],

Cell[BoxData[
    \(\({uraniumLungRet[int_, t_], \ uraniumUriExcretion[int_, t_], \ 
          uraniumFecExcretion[int_, t_]} = {qLungs[t], qDailyUrine[t], 
            qDailyFaecal[t]} /. 
          BiokdataReport[
            uranium, "\<Inhalation\>", \ "\<Acute\>", "\<Automatic\>", int, \ 
            AMADAdultW[7], S, \ 0.002, t, 0];\)\)], "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    \(\(sampleLung = \ 
        Map[{#, uraniumLungRet[13500, #] + 
                Random[NormalDistribution[0, 5]], \ 5} &, {2, 7, 18, 50, 90, 
            120, 180, 300, 360, 420, 600, \ 1500}];\)\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \(\(sampleUri = \ 
        Map[{#, uraniumUriExcretion[13500, #] + 
                Random[NormalDistribution[0, 0.02]], \ 0.02} &, {2, 14, 24, 
            80, 130, 320, 560}];\)\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \(\(sampleFec = \ 
        Map[{#, uraniumFecExcretion[13500, #] + 
                Random[NormalDistribution[0, 0.02]], \ 0.02} &, {1, 5, 9, 14, 
            30, \ 60, \ 120}];\)\)], "Input",
  CellLabel->"In[63]:="],

Cell["\<\
Here it is obtained the intake and their uncertainty, using the measured of \
bioassay.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(intakefitted = 
      MLFit[sampleLung, uraniumLungRet[1, t], sampleUri, 
        uraniumUriExcretion[1, t], sampleFec, uraniumFecExcretion[1, t], 
        t]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \({"Mean" \[Rule] 13499.835844879617`, 
      "s" \[Rule] 0.1743424369565607`}\)], "Output",
  CellLabel->"Out[64]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Plot[
      Evaluate[{uraniumLungRet["\<Mean\>", t], \ 
            uraniumUriExcretion["\<Mean\>", t], \ 
            uraniumFecExcretion["\<Mean\>", t]} /. intakefitted], {t, \ 1, \ 
        300}, \ Epilog \[Rule] \ {{Hue[0.3], \ PointSize[0.02], 
            Map[Point, Map[Drop[#, \(-1\)] &, sampleLung]]\ }, {Hue[0.5], \ 
            PointSize[0.02], 
            Map[Point, \ Map[Drop[#, \(-1\)] &, sampleUri]\ ]\ }, {Hue[0], \ 
            PointSize[0.02], 
            Map[Point, 
              Map[Drop[#, \(-1\)] &, sampleFec]]\ }}]\)\(\ \)\)\)], "Input",
  CellLabel->"In[65]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0031746 0.0147151 0.000665339 [
[.18254 .00222 -6 -9 ]
[.18254 .00222 6 0 ]
[.34127 .00222 -9 -9 ]
[.34127 .00222 9 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.65873 .00222 -9 -9 ]
[.65873 .00222 9 0 ]
[.81746 .00222 -9 -9 ]
[.81746 .00222 9 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .14778 -18 -4.5 ]
[.01131 .14778 0 4.5 ]
[.01131 .28085 -18 -4.5 ]
[.01131 .28085 0 4.5 ]
[.01131 .41392 -18 -4.5 ]
[.01131 .41392 0 4.5 ]
[.01131 .54699 -18 -4.5 ]
[.01131 .54699 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(50)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(100)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(150)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(200)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(250)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(300)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .14778 m
.03006 .14778 L
s
[(200)] .01131 .14778 1 0 Mshowa
.02381 .28085 m
.03006 .28085 L
s
[(400)] .01131 .28085 1 0 Mshowa
.02381 .41392 m
.03006 .41392 L
s
[(600)] .01131 .41392 1 0 Mshowa
.02381 .54699 m
.03006 .54699 L
s
[(800)] .01131 .54699 1 0 Mshowa
.125 Mabswid
.02381 .04798 m
.02756 .04798 L
s
.02381 .08125 m
.02756 .08125 L
s
.02381 .11452 m
.02756 .11452 L
s
.02381 .18105 m
.02756 .18105 L
s
.02381 .21432 m
.02756 .21432 L
s
.02381 .24758 m
.02756 .24758 L
s
.02381 .31412 m
.02756 .31412 L
s
.02381 .34738 m
.02756 .34738 L
s
.02381 .38065 m
.02756 .38065 L
s
.02381 .44719 m
.02756 .44719 L
s
.02381 .48045 m
.02756 .48045 L
s
.02381 .51372 m
.02756 .51372 L
s
.02381 .58025 m
.02756 .58025 L
s
.02381 .61352 m
.02756 .61352 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02698 .43235 m
.02816 .42655 L
.02922 .42324 L
.03045 .42054 L
.03162 .41853 L
.03593 .41254 L
.04573 .40049 L
.06549 .37874 L
.10749 .34166 L
.14577 .31619 L
.1865 .29542 L
.22572 .27994 L
.26343 .26815 L
.30358 .25807 L
.34223 .25018 L
.38331 .24324 L
.42289 .23761 L
.46095 .23294 L
.50146 .22858 L
.54046 .22483 L
.58191 .22123 L
.62184 .21804 L
.66026 .21517 L
.70113 .21231 L
.74049 .20968 L
.77833 .20726 L
.81862 .20478 L
.8574 .20247 L
.89862 .20008 L
.93833 .19783 L
.97619 .19574 L
s
.02698 .02091 m
.02816 .01722 L
.02922 .01549 L
.03045 .01504 L
.03162 .01496 L
.03269 .01494 L
.03368 .01493 L
.03477 .01492 L
.03593 .01491 L
.04099 .01489 L
.04573 .01487 L
.05513 .01484 L
.06549 .01482 L
.07606 .01481 L
.08572 .01479 L
.09688 .01478 L
.10749 .01478 L
.11704 .01477 L
.12722 .01477 L
.14555 .01476 L
.1558 .01476 L
.16689 .01476 L
.18699 .01475 L
.20687 .01475 L
.22786 .01475 L
.26571 .01475 L
.306 .01474 L
.34477 .01474 L
.386 .01474 L
.42571 .01474 L
.46391 .01474 L
.50456 .01474 L
.54369 .01474 L
.58132 .01474 L
.62139 .01474 L
.65995 .01474 L
.70095 .01474 L
.74044 .01474 L
.77842 .01473 L
.81885 .01473 L
.85776 .01473 L
.89912 .01473 L
.93897 .01473 L
.97619 .01473 L
s
.03419 .61803 m
.03477 .52711 L
.03593 .38489 L
.03719 .27229 L
.03837 .19704 L
.03946 .14711 L
.04063 .10854 L
.04128 .0922 L
.04199 .07767 L
.04329 .05811 L
.04456 .04525 L
.04573 .03706 L
.04697 .03109 L
.04767 .02861 L
.04831 .02676 L
.0495 .02418 L
.05075 .02231 L
.05187 .02114 L
.05291 .02036 L
.05406 .01974 L
.05529 .01928 L
.05661 .01893 L
.05735 .01879 L
.05803 .01867 L
.05929 .01851 L
.06063 .01839 L
.06182 .01831 L
.06294 .01824 L
.06549 .01813 L
.06794 .01805 L
.07063 .01798 L
.07603 .01785 L
.0857 .01763 L
.10749 .01721 L
.14791 .01659 L
.18683 .01616 L
.22819 .01583 L
.26803 .01559 L
.30637 .01542 L
.34715 .01529 L
.38643 .01519 L
.42419 .01512 L
.46439 .01506 L
.50309 .01502 L
.54423 .01499 L
.58385 .01496 L
.62197 .01494 L
.66253 .01493 L
.70159 .01491 L
.74308 .0149 L
Mistroke
.78307 .0149 L
.82154 .01489 L
.86246 .01488 L
.90187 .01488 L
.93976 .01487 L
.97619 .01487 L
Mfstroke
.2 1 0 r
.02 w
.03016 .41712 Mdot
.04603 .40237 Mdot
.08095 .37272 Mdot
.18254 .29571 Mdot
.30952 .26253 Mdot
.40476 .24214 Mdot
.59524 .22313 Mdot
.97619 .198 Mdot
0 1 1 r
.03016 .0151 Mdot
.06825 .01482 Mdot
.1 .01479 Mdot
.27778 .01472 Mdot
.43651 .01476 Mdot
1 0 0 r
.03968 .1387 Mdot
.05238 .02071 Mdot
.06825 .01804 Mdot
.11905 .01698 Mdot
.21429 .01592 Mdot
.40476 .01516 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[65]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00FGoo10001Goo1000;Woo1`000goo10001Goo1000:Goo1`000goo10001Goo1000
:Goo1P0017oo10001Goo1000:Goo1P0017oo10001Goo1000:goo10001Goo10001Goo100017oo001H
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0;Woo00<007ooOol00goo00<007oo
Ool00Woo00D007ooOomoo`0000Aoo`03001oogoo02Uoo`03001oogoo00=oo`03001oogoo009oo`05
001oogooOol00004Ool00`00Oomoo`0VOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007oo
Oomoo`0000Aoo`03001oogoo02Ioo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo
000017oo00<007ooOol09goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004
Ool00`00Oomoo`01Ool005eoo`05001oogooOol00004Ool00`00Oomoo`0^Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0:Goo00<007ooOol027oo00D007ooOomo
o`0000Aoo`03001oogoo02Moo`03001oogoo00Eoo`03001oogoo009oo`05001oogooOol00004Ool0
0`00Oomoo`0WOol00`00Oomoo`0:Ool01@00Oomoogoo000017oo00<007ooOol0;7oo00D007ooOomo
o`0000Aoo`05001oogooOol00004Ool00`00Oomoo`01Ool005eoo`05001oogooOol00004Ool00`00
Oomoo`0^Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0:Goo
00<007ooOol027oo00D007ooOomoo`0000Aoo`03001oogoo02Qoo`03001oogoo00Aoo`03001oogoo
009oo`05001oogooOol00004Ool00`00Oomoo`0XOol00`00Oomoo`09Ool01@00Oomoogoo000017oo
00<007ooOol0;7oo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`01Ool005eo
o`05001oogooOol00004Ool00`00Oomoo`0^Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00<007ooOol0:Goo00<007ooOol027oo00D007ooOomoo`0000Aoo`03001oogoo02Uo
o`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0YOol00`00Oomo
o`08Ool01@00Oomoogoo000017oo00<007ooOol0:Woo0P0017oo00<007ooOol00Woo00D007ooOomo
o`0000Aoo`03001oogoo005oo`00FGoo100017oo00<007ooOol00Woo00<007ooOol0;Woo00<007oo
Ool00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo02Uoo`03001oogoo00Aoo`@0
00Aoo`03001oogoo009oo`03001oogoo02Yoo`03001oogoo009oo`03001oogoo009oo`05001oogoo
Ool00004Ool00`00Oomoo`0ZOol00`00Oomoo`03Ool40004Ool00`00Oomoo`02Ool00`00Oomoo`0/
Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo005oo`00FGoo00<007ooOol0
1Goo00<007ooOol00Woo00<007ooOol0;Woo00<007ooOol00goo00<007ooOol00Woo00D007ooOomo
o`0000Aoo`03001oogoo02Uoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo009oo`03001o
ogoo02Ioo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol0
9Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0
;7oo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`01Ool005Uoo`03001oogoo
00Eoo`03001oogoo009oo`03001oogoo02aoo`<000Eoo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0WOol30006Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`0VOol00`00
Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo02Ioo`03001oogoo
009oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo02Moo`03001oogoo
009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol00Goo001IOol50004Ool4
000aOol00`00Oomoo`04Ool40005Ool4000/Ool00`00Oomoo`04Ool50004Ool4000ZOol40005Ool4
0005Ool4000ZOol40005Ool50004Ool4000[Ool40005Ool40005Ool40004Ool00?mook5oo`00ogoo
/Goo000POol00`00Oomoo`3oOon>Ool0021oo`03001oogoo0?moohioo`0087oo00@007oo0ol3o`eo
o`83o`]oo`83odIoo`83oc5oo`9l00]oo`83onQoo`0087oo1P?o2Goo1P?o1goo1P?o17oo0W`097oo
0W`05Woo1P?o;Goo1W`01goo1P?oiWoo000POol60ol9Ool20ol2O0020ol7Ool60ol2Ool6O00POol6
O00DOol60ol]Ool6O007Ool60ooVOol001moo`P3o`Aoo`9l0003Ool3og`000El00030omoogoo00=o
o`P3o`03Ooml07`000Al021oo`Il01=oo`P3ob]oo`Ql00Eoo`P3onEoo`005Woo2@0020?o0P0037`0
00<3o`0000000`0020?o27`07P0027`04P0020?o:`0027`01@0020?oh@0017oo000POol60ol3Ool=
O00600060ol00`00O01l0006O00@0005Ool00`00Oomoo`06Ool8O008Ool00`00Oomoo`08Ool60ol9
Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool6O007Ool60ol9Ool00`00Oomoo`0:
Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`0<Ool0021oo`H3o`9oo`il00Ioo`H3o`9oo`Il01Ioo`03001oogoo00Moo`Il01Ao
o`H3oaIoo`03001oogoo01Aoo`Il00Moo`H3oaIoo`03001oogoo03ioo`03001oogoo03eoo`03001o
ogoo03eoo`03001oogoo00aoo`0087oo00@007oo0ol3o`Aoo`el00Uoo`83o`Aoo`Il021oo`Il01Io
o`83oc5oo`9l00]oo`83onQoo`0087oo00<007ooOol01Woo37`04Goo0W`097oo0W`0ogoo@goo000P
Ool00`00Oomoo`06Ool6O002Ool2O03oOomnOol0021oo`03001oogoo00Ioo`04001oog`0O03oOon4
Ool0021oo`03001oogoo00Ioo`03001oogoo0?moohEoo`0087oo00<007ooOol01Goo00<007ooOol0
ogooQWoo000POol00`00Oomoo`05Ool00`00Oomoo`3oOon6Ool0021oo`03001oogoo00Eoo`03001o
ogoo0?moohIoo`0087oo00<007ooOol01Goo00<007ooOol0ogooQWoo000POol00`00Oomoo`05Ool0
0`00Oomoo`3oOon6Ool0021oo`8000Ioo`03001oogoo0?moohIoo`0087oo00<007ooOol01Goo00<0
07ooOol0ogooQWoo000POol00`00Oomoo`04Ool00`00Oomoo`3oOon7Ool0021oo`03001oogoo00Ao
o`03001oogoo0?moohMoo`0087oo00<007ooOol017oo00<007ooOol0ogooQgoo000POol00`00Oomo
o`04Ool00`00Oomoo`3oOon7Ool0021oo`03001oogoo00Aoo`03001oogoo0?moohMoo`0087oo00<0
07ooOol017oo00<007ooOol0ogooQgoo000POol00`00Oomoo`04Ool00`00Oomoo`3oOon7Ool0021o
o`03001oogoo00Aoo`03001oogoo0?moohMoo`0087oo00<007ooOol017oo00<007ooOol0ogooQgoo
000POol00`00Oomoo`04Ool00`00Oomoo`3oOon7Ool0021oo`03001oogoo00Aoo`03001oogoo0?mo
ohMoo`0087oo00<007ooOol017oo00<007ooOol0ogooQgoo000POol20005Ool00`00Oomoo`3oOon7
Ool0021oo`03001oogoo00Aoo`03001oogoo0?moohMoo`0087oo00<007ooOol017oo00<007ooOol0
ogooQgoo000POol00`00Oomoo`04Ool00`00Oomoo`3oOon7Ool0021oo`03001oogoo00Aoo`03001o
ogoo0?moohMoo`0087oo00<007ooOol017oo00<007ooOol0ogooQgoo000POol00`00Oomoo`04Ool0
0`00Oomoo`3oOon7Ool0021oo`03001oogoo00Aoo`03001oogoo0?moohMoo`0087oo00<007ooOol0
0goo00<007ooOol0ogooR7oo000POol00`00Oomoo`03Ool00`00Oomoo`3oOon8Ool0021oo`03001o
ogoo00=oo`03001oogoo0?moohQoo`0087oo00<007ooOol00goo00<007ooOol0ogooR7oo000POol0
0`00Oomoo`03Ool00`00Oomoo`3oOon8Ool0021oo`8000Aoo`03001oogoo0?moohQoo`0087oo00<0
07ooOol00goo00<007ooOol0ogooR7oo000POol00`00Oomoo`03Ool00`00Oomoo`3oOon8Ool0021o
o`03001oogoo00=oo`03001oogoo0?moohQoo`0087oo00<007ooOol00goo00<007ooOol0ogooR7oo
000POol00`00Oomoo`03Ool00`00Oomoo`3oOon8Ool0021oo`03001oogoo009oo`9l0?moohYoo`00
87oo00<007ooOol01W`0ogooR7oo000POol00`00Oomoo`06O03oOon8Ool0021oo`03001oog`000Ml
0?moohMoo`0000=oo`000000100017oo10001Goo100027oo00<007ooO0001g`0ogooQgoo00000goo
001oo`03Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Eoo`03001oogoo
00Il0?moohQoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001o
ogoo00Eoo`03001oogoo00Il0?moohQoo`000goo00<007ooOol017oo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`03001oogoo00Eoo`03001oogoo009oo`9l0?moohYoo`0017oo00<007ooOol00goo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Eoo`<000=oo`03001oogoo0?moohQo
o`001Goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Eoo`03
001oogoo00=oo`03001oogoo0?moohQoo`0000=oo`00Ool00goo00D007ooOomoo`0000Aoo`05001o
ogooOol00004Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`3oOon8Ool00003Ool007oo
00=oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol01Goo00<007ooOol00goo
00<007ooOol0ogooR7oo0002Ool40005Ool40005Ool40008Ool00`00Oomoo`03Ool00`00Oomoo`3o
Oon8Ool0021oo`03001oogoo00=oo`03001oogoo0?moohQoo`0087oo00<007ooOol00goo00<007oo
Ool0ogooR7oo000POol00`00Oomoo`03Ool00`00Oomoo`3oOon8Ool0021oo`03001oogoo00=oo`03
001oogoo0?moohQoo`0087oo00<007ooOol00goo00<007ooOol0ogooR7oo000POol00`00Oomoo`02
Ool00`00Oomoo`3oOon9Ool0021oo`03001oogoo009oo`03001oogoo0?moohUoo`0087oo00<007oo
Ool00Woo00<007ooOol0ogooRGoo000POol20003Ool00`00Oomoo`3oOon9Ool0021oo`03001oogoo
009oo`03001oogoo0?moohUoo`0087oo00<007ooOol00Woo00<007ooOol0ogooRGoo000POol00`00
Oomoo`02Ool00`00Oomoo`3oOomjOol26n0=Ool0021oo`03001oogoo009oo`03001oogoo0?moogQo
o`HKh0]oo`0087oo00<007ooOol00Woo00<007ooOol0ogooN7oo1Q_P2goo000POol00`00Oomoo`02
Ool00`00Oomoo`3oOomcOol400086n0:Ool0021oo`03001oogoo009oo`03001oogoo0?moofAoo`l0
00Aoo`PKh0Yoo`0087oo00<007ooOol00Woo00<007ooOol0ogooDgoo4@0057oo1Q_P2goo000POol0
0`00Oomoo`02Ool00`00Oomoo`3oOom3Ool@000UOol66n0;Ool0021oo`03001oogoo009oo`03001o
ogoo0?mooc=ooa0003Moo`8Kh0eoo`0087oo00<007ooOol00Woo00<007ooOol0ogoo8goo4000EWoo
000POol00`00Oomoo`02Ool00`00Oomoo`3oOolDOol?001VOol0021oo`03001oogoo009oo`03001o
ogoo0?moo`=ooa4007Eoo`0087oo0P000goo00<007ooOol0gWoo0Q_P4Woo4000QWoo000POol00`00
Oomoo`02Ool00`00Oomoo`3LOol66n0@002FOol0021oo`03001oogoo009oo`03001oogoo0=Ioo`H0
00HKh:Ioo`0087oo00<007ooOol00Woo00<007ooOol0cWoo20001Goo21_PYGoo000POol00`00Oomo
o`02Ool00`00Oomoo`32Ool<000=Ool86n2UOol0021oo`03001oogoo009oo`03001oogoo0;Eoo`d0
01Yoo`HKh:Ioo`0087oo00<007ooOol00Woo00<007ooOol0[Goo20009goo1Q_PYWoo000POol00`00
Oomoo`02Ool00`00Oomoo`2AOol26n0BOol8000aOol26n2XOol0021oo`03001oogoo009oo`03001o
ogoo08moo`HKh0Qoo`P00>=oo`0087oo00<007ooOol00Woo00<007ooOol0Sgoo1Q_P00=oo`000000
1@00jgoo000POol00`00Oomoo`02Ool00`00Oomoo`2>Ool86n3bOol0021oo`03001oogoo009oo`03
001oogoo08Moo`L000PKh?9oo`0087oo00<007ooOol00Woo00<007ooOol0PGoo1P0027oo1Q_Plgoo
000POol20003Ool00`00Oomoo`1kOol6000>Ool66n3cOol0021oo`03001oogoo009oo`03001oogoo
07Ioo`D001Ioo`8Kh?Eoo`0087oo00<007ooOol00Woo00<007ooOol0LGoo1@00ogoo4goo000POol0
0`00Oomoo`02Ool00`00Oomoo`1[Ool26n04003oOolHOol0021oo`03001oogoo009oo`03001oogoo
06Qoo`03000Kh1_P00@Kh?mooaYoo`0087oo00<007ooOol00Woo00<007ooOol0I7oo100000=ooa_P
6n0011_Pogoo6Woo000POol00`00Oomoo`02Ool00`00Oomoo`1POol40004Ool86n3oOolIOol0021o
o`03001oogoo009oo`03001oogoo05aoo`@000Qoo`PKh?mooaUoo`0087oo00<007ooOol00Woo00<0
07ooOol0F7oo10003Goo1Q_Pogoo6Woo000POol00`00Oomoo`02Ool00`00Oomoo`1EOol3000AOol6
6n3oOolJOol000=oo`@000Aoo`@000Eoo`@000Qoo`03001oogoo009oo`03001oogoo059oo`<001Io
o`8Kh?mooaaoo`001Goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001o
ogoo00Eoo`03001oogoo009oo`03001oogoo04ioo`@00?moocMoo`001Goo00<007ooOol00Woo00<0
07ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo04]o
o`<00?mooc]oo`0000=oo`00000010000goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001o
ogoo00Eoo`<0009oo`03001oogoo04Qoo`<00?moocioo`000Woo00@007ooOol000Aoo`03001oogoo
009oo`05001oogooOol00004Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`16Ool2003o
Oom1Ool0009oo`04001oogoo0004Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0
1Goo00<007ooOol00Woo00<007ooOol0@goo0`00ogoo@goo0003Ool00`00Ool00004Ool00`00Oomo
o`02Ool01@00Oomoogoo000017oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0=goo0Q_P
1goo0`00ogooAWoo0003Ool00`00Ool00004Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<0
07ooOol01Goo00<007ooOol00Woo00<007ooOol0=Goo1Q_P0goo0P00ogooBGoo0004Ool20005Ool4
0005Ool40008Ool00`00Oomoo`02Ool00`00Oomoo`0eOol66n03003oOom;Ool0021oo`03001oogoo
009oo`03001oogoo03Aoo`PKh?moodeoo`0087oo00<007ooOol00Woo00<007ooOol0=7oo21_Pogoo
CGoo000POol00`00Oomoo`02Ool00`00Oomoo`0eOol66n3oOom>Ool0021oo`03001oogoo009oo`03
001oogoo03=oo`8000HKh?moodioo`0087oo00<007ooOol00Woo00<007ooOol0<Woo00<007ooOol0
0Woo0Q_PogooD7oo000POol00`00Oomoo`02Ool00`00Oomoo`0`Ool2003oOomGOol0021oo`03001o
ogoo009oo`03001oogoo02ioo`800?mooeUoo`0087oo00<007ooOol00Woo00<007ooOol0;7oo0P00
ogooFgoo000POol20003Ool00`00Oomoo`0ZOol2003oOomMOol0021oo`03001oogoo009oo`03001o
ogoo02Uoo`03001oogoo0?mooeeoo`0087oo00<007ooOol00Woo00<007ooOol09goo0P00ogooH7oo
000POol00`00Oomoo`02Ool00`00Oomoo`0VOol00`00Oomoo`3oOomPOol0021oo`03001oogoo009o
o`03001oogoo02Aoo`800?moof=oo`0087oo00<007ooOol00Woo00<007ooOol08Woo0P00ogooIGoo
000POol01@00Oomoogoo000097oo00<007ooOol0ogooIGoo000POol01@00Oomoogoo00008Woo0P00
ogooJ7oo000POol01@00Oomoogoo00008Goo00<007ooOol0ogooJ7oo000POol01@00Oomoogoo0000
7goo0P00ogooJgoo000POol01@00Oomoogoo00007Goo0P00ogooKGoo000POol01@00Oomoogoo0000
77oo00<007ooOol0ogooKGoo000POol01@00Oomoogoo00006goo00<007ooOol0ogooKWoo000POol2
0002Ool00`00Oomoo`0HOol00`00Oomoo`3oOom_Ool0021oo`05001oogooOol0000IOol00`00Oomo
o`3oOom`Ool0021oo`05001oogooOol0000GOol2003oOomcOol0021oo`05001oogooOol0000FOol0
0`00Oomoo`3oOomcOol0021oo`05001oogooOol0000EOol00`00Oomoo`3oOomdOol0021oo`05001o
ogooOol0000DOol00`00Oomoo`3oOomeOol0021oo`05001oogooOol0000COol00`00Oomoo`3oOomf
Ool0021oo`05001oogooOol0000AOol26n3oOomiOol0021oo`05001oogooOol0000?Ool66n3oOomg
Ool0021oo`05001oogooOol0000?Ool66n3oOomgOol0021oo`05001oogooOol0000>Ool86n3oOomf
Ool0021oo`05001oogooOol0000=Ool00`006n0Kh0066n3oOomfOol0021oo`05001oogooOol0000<
Ool00`00Oomoo`066n3oOomgOol0021oo`05001oogooOol0000;Ool01000Oomoogoo1Q_PogooMgoo
000POol20002Ool00`00Oomoo`08Ool00`00Oomoo`04Ool26n3oOomiOol0021oo`05001oogooOol0
0009Ool00`00Oomoo`3oOon0Ool0021oo`05001oogooOol00008Ool00`00Oomoo`3oOon1Ool0021o
o`05001oogooOol00007Ool00`00Oomoo`3oOon2Ool0021oo`05001oogooOol00007Ool00`00Oomo
o`3oOon2Ool0021oo`05001oogooOol00003Ool26n000goo001oo`3oOon4Ool0021oo`06001oogoo
Ool007oo1Q_PogooQGoo000POol01P00Oomoogoo001oo`HKh?moohEoo`0087oo00D007ooOomoo`00
00PKh?moohAoo`0087oo00D007ooOomoo`0000PKh?moohAoo`000goo100017oo10001Goo100027oo
00H007ooOomoo`00Ool66n3oOon5Ool0009oo`03001oogoo009oo`04001oogoo0004Ool01@00Oomo
ogoo000017oo00<007ooOol01Goo00H007oo6n0Kh000Ool66n3oOon5Ool0009oo`03001oogoo009o
o`04001oogoo0004Ool01@00Oomoogoo000017oo00<007ooOol01Goo1Q_P0Woo0Q_PogooQgoo0002
Ool20003Ool01000Oomoo`0017oo00D007ooOomoo`0000Aoo`03001oogoo00Eoo`HKh?mooh]oo`00
0Woo00<007oo00000P000goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`PK
h?moohYoo`000Woo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo
00Aoo`PKh?moohYoo`000goo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03
001oogoo00Eoo`HKh?mooh]oo`0017oo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`03001oogoo00Eoo`HKh?mooh]oo`001Goo0`000goo10001Goo100027oo0P000Q_P00<007oo
Ool0ogooRWoo000POol20002Ool00`00Oomoo`3oOon:Ool0021oo`80009oo`03001oogoo0?moohYo
o`0087oo0P000Woo00<007ooOol0ogooRWoo000POol01@00Oomoogoo0000ogooS7oo000POol01@00
Oomoogoo0000ogooS7oo000POol01@00Oomoogoo0000ogooS7oo000POol01@00Oomoogoo0000ogoo
S7oo000POol01@00Oomoogoo0000ogooS7oo000POol20002Ool00`00Oomoo`3oOon:Ool0021oo`05
001oogooOol0003oOon<Ool0021oo`05001oogooOol0003oOon<Ool0021oo`05001oogooOol0003o
Oon<Ool0021oo`05001oogooOol0003oOon<Ool0021oo`05001oogooOol0003oOon<Ool0021oo`05
001oogooOol0003oOon<Ool0021oo`05001oogooOol0003oOon<Ool0021oo`05001oogooOol0003o
Oon<Ool0021oo`05001oogooOol0003oOon<Ool0021oo`05001oogooOol0003oOon<Ool0021oo`05
001oogooOol0003oOon<Ool0021oo`05001oogooOol0003oOon<Ool0021oo`80009oo`03001oogoo
0?moohYoo`0087oo00D007ooOomoo`000?moohaoo`0087oo00D007ooOomoo`000?moohaoo`0087oo
00D007ooOomoo`000?moohaoo`0087oo00D007ooOomoo`000?moohaoo`0087oo00D007ooOomoo`00
0?moohaoo`0087oo00D007ooOomoo`000?moohaoo`0087oo00D007ooOomoo`000?moohaoo`0087oo
00D007ooOomoo`000?moohaoo`0087oo00D007ooOomoo`000?moohaoo`0087oo00D007ooOomoo`00
0?moohaoo`0087oo00D007ooOomoo`000?moohaoo`0087oo00D007ooOomoo`000?moohaoo`0087oo
00D007ooOomoo`000?moohaoo`0087oo0P000Woo00<007ooOol0ogooRWoo000POol01@00Oomoogoo
0000ogooS7oo000POol01@00Oomoogoo0000ogooS7oo000POol01@00Oomoogoo0000ogooS7oo000P
Ool01@00Oomoogoo0000ogooS7oo000POol01@00Oomoogoo0000ogooS7oo000POol01@00Oomoogoo
0000ogooS7oo000POol01@00Oomoogoo0000ogooS7oo000POol01@00Oomoogoo0000ogooS7oo000P
Ool01@00Oomoogoo0000ogooS7oo0002Ool40005Ool40005Ool40008Ool01@00Oomoogoo0000ogoo
S7oo00000goo001oo`03Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Eo
o`05001oogooOol0003oOon<Ool00003Ool007oo00=oo`05001oogooOol00004Ool01@00Oomoogoo
000017oo00<007ooOol01Goo00D007ooOomoo`000?moohaoo`0000=oo`00Ool00goo00D007ooOomo
o`0000Aoo`05001oogooOol00004Ool00`00Oomoo`05Ool300000goo001oo`3oOon;Ool0009oo`@0
00Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`05Ool01@00Oomoogoo0000ogoo
S7oo00000goo001oo`03Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Eo
o`05001oogooOol0003oOon<Ool00003Ool007oo00=oo`05001oogooOol00004Ool01@00Oomoogoo
000017oo00<007ooOol01Goo00D007ooOomoo`000?moohaoo`0000=oo`00Ool00goo00D007ooOomo
o`0000Aoo`05001oogooOol00004Ool00`00Oomoo`05Ool01@00Oomoogoo0000ogooS7oo0002Ool4
0005Ool40005Ool40008Ool01@00Oomoogoo0000ogooS7oo000POol01@00Oomoogoo0000ogooS7oo
000POol01@00Oomoogoo0000ogooS7oo000POol01@00Oomoogoo0000ogooS7oo000POol01@00Oomo
ogoo0000ogooS7oo000POol01@00Oomoogoo0000ogooS7oo000POol01@00Oomoogoo0000ogooS7oo
000POol01@00Oomoogoo0000ogooS7oo000POol01@00Oomoogoo0000ogooS7oo000POol20002Ool0
0`00Oomoo`3oOon:Ool0021oo`05001oogooOol0003oOon<Ool0021oo`05001oogooOol0003oOon<
Ool0021oo`05001oogooOol0003oOon<Ool0021oo`05001oogooOol0003oOon<Ool0021oo`05001o
ogooOol0003oOon<Ool0021oo`05001oogooOol0003oOon<Ool0021oo`05001oogooOol0003oOon<
Ool0021oo`05001oogooOol0003oOon<Ool0021oo`05001oogooOol0003oOon<Ool0021oo`05001o
ogooOol0003oOon<Ool0021oo`05001oogooOol0003oOon<Ool0021oo`05001oogooOol0003oOon<
Ool0021oo`80009oo`03001oogoo0?moohYoo`0087oo00D007ooOomoo`000?moohaoo`0087oo00D0
07ooOomoo`000?moohaoo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-24.954, -74.7665, 1.16751, \
5.57064}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[65]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2", "SubsubsectionIcon"],

Cell["\<\
In this example it is shown how the intake can be estimated  using both the \
lung retention and the daily urine excretion measured (simulated). It is \
supposed an acute intake by  inhalation of caesium 137 (\[Lambda] will be \
asumed -> 0) . It is assumed an AMAD = 5 \[Mu]m \
\>", "Text"],

Cell["\<\
Here are builded two funtions for computing de whobody retention and the \
urine excretion as funtion of intale (inp) and the AMAD (p)\
\>", "Text"],

Cell[BoxData[
    \(\(\(\ \)\(caesiumWb[t1_, inp_?NumericQ] := 
        qWholebody[t1] /. 
          BiokdataReport[
            caesium, "\<Inhalation\>", \ "\<Acute\>", "\<Automatic\>", 
            inp, \ \ AMADAdultW[5], F, \ 1, t1, 0];\)\)\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \(\(\(\ \)\(caesiumUri[t1_, inp_?NumericQ] := 
        qDailyUrine[t1] /. 
          BiokdataReport[
            caesium, "\<Inhalation\>", \ "\<Acute\>", "\<Automatic\>", 
            inp, \ \ AMADAdultW[p], F, \ 1, t1, 0];\)\)\)], "Input",
  CellLabel->"In[74]:="],

Cell["\<\
Now we simulate the experimental data including uncertainties\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sampleWb\  = \ 
      Map[{#, caesiumWb[#, \ 7000] + Random[NormalDistribution[0, 5]], \ 
            Random[Integer, \ {5, 10}]} &, {5, 25, \ 50, 90, 120, 300, 
          500}]\)], "Input",
  CellLabel->"In[76]:="],

Cell[BoxData[
    \({{5, 3053.3051186434823`, 9}, {25, 2606.670829149768`, 6}, {50, 
        2226.6909425388776`, 9}, {90, 1723.1722314743397`, 10}, {120, 
        1430.6148943633953`, 6}, {300, 459.5792943635378`, 6}, {500, 
        126.68520500233943`, 6}}\)], "Output",
  CellLabel->"Out[76]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sampleUri\  = \ 
      Map[{#, caesiumUri[#, \ 7000] + Random[NormalDistribution[0, 5]], \ 
            Random[Integer, \ {1, 3}]} &, {2, 7, 18, 50, 90}]\)], "Input",
  CellLabel->"In[77]:="],

Cell[BoxData[
    \({{2, 79.06943978139535`, 3}, {7, 23.441426108293832`, 2}, {18, 
        14.458789151013706`, 2}, {50, 6.246306824312357`, 1}, {90, 
        11.551028535661482`, 3}}\)], "Output",
  CellLabel->"Out[77]="]
}, Open  ]],

Cell["Finally we obtein the best fit for the intake .", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindMinimum[
        X2FitE[{inp}, sampleWb\ , \ caesiumWb[t1, inp]\ , \ 
          sampleUri\ , \ \ caesiumUri[t1, inp]\ , t1], {inp, 5000, \ 15000}] // 
      Timing\)], "Input",
  CellLabel->"In[78]:="],

Cell[BoxData[
    \({132.65600000000018`\ Second, {29.256986677155666`, {inp \[Rule] 
            7010.926727305085`}}}\)], "Output",
  CellLabel->"Out[78]="]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{891, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageFooters->{{Inherited, Cell[ 
        TextData[ {
          "\[Copyright]2004 Guillermo Sanchez & ENUSA. All rights \
reserved."}], "PageFooter"], Inherited}, {Inherited, Cell[ 
        TextData[ {
          "\[Copyright]2004 Guillermo Sanchez & ENUSA . All rights \
reserved."}], "PageFooter"], Inherited}},
ShowSelection->True,
Magnification->1.5,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "ICRP 78"->{
    Cell[2153, 72, 82, 1, 58, "MathCaption",
      CellTags->"ICRP 78"]},
  "Introduction"->{
    Cell[2260, 77, 115, 3, 40, "Input",
      CellTags->"Introduction"],
    Cell[2378, 82, 119, 3, 32, "Print",
      CellTags->"Introduction"],
    Cell[2500, 87, 146, 3, 32, "Print",
      CellTags->"Introduction"],
    Cell[2649, 92, 117, 3, 32, "Print",
      CellTags->"Introduction"],
    Cell[2769, 97, 176, 4, 57, "Print",
      CellTags->"Introduction"],
    Cell[3204, 115, 116, 3, 40, "Input",
      CellTags->"Introduction"]},
  "Examples"->{
    Cell[3765, 139, 66, 1, 54, "Section",
      CellTags->"Examples"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"ICRP 78", 175652, 4814},
  {"Introduction", 175746, 4817},
  {"Examples", 176202, 4830}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 42, 0, 136, "Chapter"],
Cell[1821, 55, 58, 0, 47, "Commentary"],

Cell[CellGroupData[{
Cell[1904, 59, 65, 2, 40, "Input"],
Cell[1972, 63, 101, 2, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2110, 70, 40, 0, 58, "SubsectionIcon"],
Cell[2153, 72, 82, 1, 58, "MathCaption",
  CellTags->"ICRP 78"],

Cell[CellGroupData[{
Cell[2260, 77, 115, 3, 40, "Input",
  CellTags->"Introduction"],
Cell[2378, 82, 119, 3, 32, "Print",
  CellTags->"Introduction"],
Cell[2500, 87, 146, 3, 32, "Print",
  CellTags->"Introduction"],
Cell[2649, 92, 117, 3, 32, "Print",
  CellTags->"Introduction"],
Cell[2769, 97, 176, 4, 57, "Print",
  CellTags->"Introduction"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2982, 106, 87, 2, 40, "Input"],
Cell[3072, 110, 117, 2, 32, "Print"]
}, Open  ]],
Cell[3204, 115, 116, 3, 40, "Input",
  CellTags->"Introduction"],
Cell[3323, 120, 105, 2, 40, "Input"],
Cell[3431, 124, 98, 2, 40, "Input"],
Cell[3532, 128, 94, 2, 40, "Input"],
Cell[3629, 132, 99, 2, 40, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3765, 139, 66, 1, 54, "Section",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[3856, 144, 76, 0, 58, "SubsectionIcon"],
Cell[3935, 146, 111, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[4071, 153, 38, 0, 35, "SubsubsectionIcon"],
Cell[4112, 155, 377, 9, 78, "Text"],
Cell[4492, 166, 143, 3, 58, "MathCaption"],
Cell[4638, 171, 256, 7, 40, "Input"],
Cell[4897, 180, 234, 6, 80, "MathCaption"],
Cell[5134, 188, 73, 2, 40, "Input"],
Cell[5210, 192, 145, 3, 40, "Input"],

Cell[CellGroupData[{
Cell[5380, 199, 206, 5, 92, "Input"],
Cell[5589, 206, 161, 3, 63, "Output"]
}, Open  ]],
Cell[5765, 212, 177, 5, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[5967, 221, 107, 2, 40, "Input"],
Cell[6077, 225, 188, 3, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6302, 233, 213, 5, 66, "Input"],
Cell[6518, 240, 18097, 478, 276, 4243, 302, "GraphicsData", "PostScript", \
"Graphics"],
Cell[24618, 720, 155, 4, 38, "Output"]
}, Open  ]],
Cell[24788, 727, 57, 1, 58, "Text"],
Cell[24848, 730, 48, 0, 34, "Text"],
Cell[24899, 732, 154, 3, 80, "MathCaption"],
Cell[25056, 737, 221, 5, 92, "Input"],

Cell[CellGroupData[{
Cell[25302, 746, 255, 5, 92, "Input"],
Cell[25560, 753, 482, 8, 113, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26079, 766, 247, 5, 92, "Input"],
Cell[26329, 773, 17922, 468, 276, 4146, 293, "GraphicsData", "PostScript", \
"Graphics"],
Cell[44254, 1243, 155, 4, 38, "Output"]
}, Open  ]],
Cell[44424, 1250, 57, 1, 58, "Text"],
Cell[44484, 1253, 116, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[44625, 1260, 120, 3, 40, "Input"],
Cell[44748, 1265, 134, 3, 38, "Output"]
}, Open  ]],
Cell[44897, 1271, 57, 1, 58, "Text"],
Cell[44957, 1274, 94, 2, 34, "Text"],
Cell[45054, 1278, 133, 3, 40, "Input"],
Cell[45190, 1283, 119, 4, 39, "Text"],

Cell[CellGroupData[{
Cell[45334, 1291, 151, 3, 66, "Input"],
Cell[45488, 1296, 150, 3, 38, "Output"]
}, Open  ]],
Cell[45653, 1302, 106, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[45784, 1309, 209, 4, 66, "Input"],
Cell[45996, 1315, 188, 3, 38, "Output"]
}, Open  ]],
Cell[46199, 1321, 320, 7, 104, "Text"],
Cell[46522, 1330, 57, 1, 58, "Text"],
Cell[46582, 1333, 308, 5, 78, "Text"],
Cell[46893, 1340, 245, 7, 40, "Input"],

Cell[CellGroupData[{
Cell[47163, 1351, 159, 4, 66, "Input"],
Cell[47325, 1357, 160, 3, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47522, 1365, 217, 5, 66, "Input"],
Cell[47742, 1372, 187, 3, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47966, 1380, 303, 8, 66, "Input"],
Cell[48272, 1390, 177, 3, 38, "Output"]
}, Open  ]],
Cell[48464, 1396, 97, 2, 34, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[48598, 1403, 38, 0, 27, "SubsubsectionIcon"],
Cell[48639, 1405, 237, 4, 56, "Text"],
Cell[48879, 1411, 145, 3, 58, "MathCaption"],
Cell[49027, 1416, 419, 6, 118, "Input"],

Cell[CellGroupData[{
Cell[49471, 1426, 106, 2, 40, "Input"],
Cell[49580, 1430, 20451, 428, 276, 2907, 206, "GraphicsData", "PostScript", \
"Graphics"],
Cell[70034, 1860, 155, 4, 38, "Output"]
}, Open  ]],
Cell[70204, 1867, 160, 3, 80, "MathCaption"],

Cell[CellGroupData[{
Cell[70389, 1874, 162, 4, 66, "Input"],
Cell[70554, 1880, 609, 10, 92, "Output"]
}, Open  ]],
Cell[71178, 1893, 109, 3, 58, "MathCaption"],
Cell[71290, 1898, 157, 4, 61, "Input"],
Cell[71450, 1904, 251, 8, 58, "MathCaption"],
Cell[71704, 1914, 169, 4, 61, "Input"],
Cell[71876, 1920, 78, 0, 58, "MathCaption"],
Cell[71957, 1922, 155, 3, 40, "Input"],
Cell[72115, 1927, 266, 5, 80, "MathCaption"],
Cell[72384, 1934, 112, 3, 43, "Input"],

Cell[CellGroupData[{
Cell[72521, 1941, 149, 3, 40, "Input"],
Cell[72673, 1946, 78, 2, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[72788, 1953, 202, 4, 66, "Input"],
Cell[72993, 1959, 26306, 591, 276, 4615, 318, "GraphicsData", "PostScript", \
"Graphics"],
Cell[99302, 2552, 155, 4, 38, "Output"]
}, Open  ]],
Cell[99472, 2559, 142, 3, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[99639, 2566, 86, 2, 40, "Input"],
Cell[99728, 2570, 82, 2, 38, "Output"]
}, Open  ]],
Cell[99825, 2575, 138, 3, 40, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[100000, 2583, 38, 0, 27, "SubsubsectionIcon"],
Cell[100041, 2585, 225, 4, 80, "MathCaption"],
Cell[100269, 2591, 214, 4, 66, "Input"],
Cell[100486, 2597, 522, 21, 81, "MathCaption"],
Cell[101011, 2620, 227, 4, 66, "Input"],
Cell[101241, 2626, 186, 4, 80, "MathCaption"],
Cell[101430, 2632, 92, 1, 43, "Input"],

Cell[CellGroupData[{
Cell[101547, 2637, 263, 6, 66, "Input"],
Cell[101813, 2645, 3373, 73, 70, "Output"]
}, Open  ]],
Cell[105201, 2721, 171, 3, 80, "MathCaption"],

Cell[CellGroupData[{
Cell[105397, 2728, 271, 5, 118, "Input"],
Cell[105671, 2735, 20182, 499, 70, 4274, 297, "GraphicsData", "PostScript", \
"Graphics"],
Cell[125856, 3236, 155, 4, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[126060, 3246, 38, 0, 27, "SubsubsectionIcon"],
Cell[126101, 3248, 97, 2, 34, "Text"],
Cell[126201, 3252, 280, 5, 92, "Input"],
Cell[126484, 3259, 195, 7, 39, "Text"],

Cell[CellGroupData[{
Cell[126704, 3270, 187, 4, 66, "Input"],
Cell[126894, 3276, 156, 3, 70, "Output"]
}, Open  ]],
Cell[127065, 3282, 112, 3, 58, "MathCaption"],
Cell[127180, 3287, 89, 1, 43, "Input"],
Cell[127272, 3290, 194, 7, 39, "Text"],
Cell[127469, 3299, 257, 6, 92, "Input"],
Cell[127729, 3307, 99, 2, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[127853, 3313, 137, 3, 40, "Input"],
Cell[127993, 3318, 5771, 144, 70, "Output"]
}, Open  ]],
Cell[133779, 3465, 149, 3, 40, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[133965, 3473, 38, 0, 27, "SubsubsectionIcon"],
Cell[134006, 3475, 317, 5, 102, "MathCaption"],
Cell[134326, 3482, 235, 4, 66, "Input"],
Cell[134564, 3488, 119, 3, 43, "Input"],
Cell[134686, 3493, 130, 3, 40, "Input"],
Cell[134819, 3498, 382, 8, 118, "Input"],
Cell[135204, 3508, 157, 3, 80, "MathCaption"],
Cell[135364, 3513, 248, 4, 92, "Input"],
Cell[135615, 3519, 65, 0, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[135705, 3523, 196, 4, 66, "Input"],
Cell[135904, 3529, 194, 4, 70, "Output"]
}, Open  ]],
Cell[136113, 3536, 246, 7, 56, "Text"],
Cell[136362, 3545, 202, 4, 80, "MathCaption"],
Cell[136567, 3551, 143, 3, 40, "Input"],
Cell[136713, 3556, 209, 4, 66, "Input"],
Cell[136925, 3562, 108, 3, 47, "Commentary"],

Cell[CellGroupData[{
Cell[137058, 3569, 190, 5, 66, "Input"],
Cell[137251, 3576, 3475, 74, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[140763, 3655, 294, 6, 92, "Input"],
Cell[141060, 3663, 4580, 317, 70, 4428, 312, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[145643, 3982, 155, 4, 70, "Output"]
}, Open  ]],
Cell[145813, 3989, 136, 3, 40, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[145998, 3998, 96, 2, 58, "SubsectionIcon"],
Cell[146097, 4002, 158, 3, 56, "Text"],
Cell[146258, 4007, 285, 5, 118, "Input"],

Cell[CellGroupData[{
Cell[146568, 4016, 38, 0, 35, "SubsubsectionIcon"],
Cell[146609, 4018, 309, 5, 102, "MathCaption"],
Cell[146921, 4025, 380, 7, 144, "Input"],
Cell[147304, 4034, 251, 5, 92, "Input"],
Cell[147558, 4041, 235, 5, 92, "Input"],
Cell[147796, 4048, 235, 5, 92, "Input"],
Cell[148034, 4055, 111, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[148170, 4062, 216, 5, 92, "Input"],
Cell[148389, 4069, 135, 3, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[148561, 4077, 614, 12, 196, "Input"],
Cell[149178, 4091, 22378, 594, 276, 5633, 382, "GraphicsData", "PostScript", \
"Graphics"],
Cell[171559, 4687, 155, 4, 38, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[171763, 4697, 38, 0, 27, "SubsubsectionIcon"],
Cell[171804, 4699, 301, 5, 78, "Text"],
Cell[172108, 4706, 158, 3, 56, "Text"],
Cell[172269, 4711, 282, 6, 92, "Input"],
Cell[172554, 4719, 284, 6, 92, "Input"],
Cell[172841, 4727, 85, 2, 34, "Text"],

Cell[CellGroupData[{
Cell[172951, 4733, 235, 5, 92, "Input"],
Cell[173189, 4740, 297, 5, 88, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[173523, 4750, 211, 4, 92, "Input"],
Cell[173737, 4756, 223, 4, 63, "Output"]
}, Open  ]],
Cell[173975, 4763, 63, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[174063, 4767, 225, 5, 92, "Input"],
Cell[174291, 4774, 158, 3, 38, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

