(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1210250,      30013]*)
(*NotebookOutlinePosition[   1213507,      30104]*)
(*  CellTagsIndexPosition[   1213256,      30094]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  "Humorap: A ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package for solving Current ICRP compartmental models and more."
}], "Chapter"],

Cell[TextData[{
  StyleBox["By Guillermo S\[AAcute]nchez, ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        ButtonBox[\(\(\(http\)\(:\)\) // \(\(web . usal . es/
                guillermo\)\(/\)\)\),
          ButtonData:>{
            URL[ "http://web.usal.es/guillermo/"], None},
          ButtonStyle->"Hyperlink"], TraditionalForm]]],
  StyleBox["; Email: ",
    FontWeight->"Plain"],
  "gsl@fab.enusa.es or guillermo@usal.es. \n",
  StyleBox["This package has been developed with the support of ENUSA \
Industrias Avanzadas S.A. ",
    FontWeight->"Plain"],
  StyleBox[ButtonBox["http://www.enusa.es",
    ButtonData:>{
      URL[ "http://www.enusa.es"], None}],
    ButtonBoxOptions -> {DefaultStyle -> "Hyperlink"}]
}], "Text",
  CellTags->"Introduction"],

Cell["Last update of this help. 2005-08-22", "Commentary"],

Cell[CellGroupData[{

Cell[BoxData[
    \($Version\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("5.2 for Microsoft Windows (June 20, 2005)"\)], "Output",
  CellLabel->"Out[1]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["About Humorap 3", "SubsectionIcon"],

Cell[TextData[{
  StyleBox["Humorap 3 ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "is a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " program that solves ICRP Models. It is a tool for research and \
educational purposed, although it can be used  for routines evaluations.\nIt \
has the following innovations:\na) Gives analytic solutions, apart from \
numeric.\nb) All parameters (deposition factors, rate transfer coefficients, \
fractional rate of absorption, etc.) can be modified by users. It can be very \
useful for sensitivity analysis and for fitting  experimental data.\nc) \
Besides acute and chronic (constant) inputs, it can practically be used for \
any kind of continuous inputs (exponentials, periodic, etc.), even for random \
inputs. \nd) The user can build himself compartmental models in a very easy \
way.\ne) The program uses symbolic computation (eigenvalues and eigensystem \
methods, laplace transformation, analytic integration, etc.)"
}], "Text",
  CellDingbat->None],

Cell[TextData[{
  StyleBox["Humorap 3 ",
    FontWeight->"Bold"],
  "is a package included in Biokmod. Biokmod is a Mathematica Toolbox for \
solving compartmental and physiological models and for fitting parameters. It \
can be applied in Medicine, Pharmacology and Radioprotection.\n",
  StyleBox["Requirements",
    FontWeight->"Bold"],
  ": It needs Mathematica for running. The requirements are the same as ",
  StyleBox["Mathematica:",
    FontSlant->"Italic"],
  " ",
  StyleBox["http://www.",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".com",
    FontColor->RGBColor[0, 0, 1]]
}], "Commentary"]
}, Closed]],

Cell[CellGroupData[{

Cell["Introduction ", "SubsectionIcon"],

Cell[TextData[{
  "The package provides several ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions to calculate retention as function of time in each compartment \
or region given after a inhalation, ingestion or injection for one simple \
intake ",
  Cell[BoxData[
      \(TraditionalForm\`I\_0\)]],
  ".  Also, it can be used to include continuous and other kinds of intake.   \
Default values for standard worker are applied but many parameters (decay \
constants, initial depositions, clearances , absorption type factors, etc) \
can be modified by users. It is possible to obtain both numeric and the \
analytical solutions. The respiratory tract model has been developed \
according ICRP 66.  It is applied to compute the retention in regions AI, bb, \
BB, ET2, ET1 and Lungs. For  Gastro Intestinal (GI) Tract  is applied ICRP \
30.  The full metabolic model, including systemic compartments, for some \
specific elements has been modeled applying the ICRP 78. Also of the \
compartment content it can be evaluated the  urine and faecal excretion.  The \
user not only can change the default values but also it can be build other \
models not include in the program. \nThe program can be used for evaluating \
unknown intakes fitting bioassay experimental data .  Some examples for \
computer the dose conversion factors are  included."
}], "Text",
  CellTags->"Introduction"],

Cell[CellGroupData[{

Cell["Respiratory tract model  (ICRP66)", "SubsubsectionIcon"],

Cell[TextData[{
  "ICRP 66 describes the compartmental model of the human respiratory tract \
(RT) applied to the intake of radioactive aerosols by inhalation (Fig.1). The \
respiratory tract is represented by five regions. The extrathoracic (ET) \
airways are divided into ",
  Cell[BoxData[
      \(TraditionalForm\`ET\_1\)]],
  "(nasal passage) and ",
  Cell[BoxData[
      \(TraditionalForm\`ET\_2\)]],
  " (posterior nasal and oral passages, the pharynx and the larynx) and the \
thoracic region (lungs) is divided into BB (Bronchial), bronchiolar (bb), and \
alveolar-interstitial (AI: AI1, AI2, and AI3). ",
  Cell[BoxData[
      \(TraditionalForm\`LN\_ET\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`LN\_TH\)]],
  " represent extrathoracic and thoracic airways. "
}], "Text"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@000bd40@0006`000320`00D@000<H5001X0P00
69L008P>001@iP00R5h00215CDH0004012d30?LM000;0000000000000000000080<005P200100@00
l0000000000000000000003R1020Z@<0AP0002`0000P0000ADe6:`500@0L00004000004@`=/10000
H000060000160000G00005000015CDH[8T0400`0000000007T0100`000000000940100`000000000
8D0700`000000000<4020100000400000020?`A0000<0000000001P0000<0000000001T0000<0000
oooo01@0000<00003@000180000<00000P00024000080000500000`0000=0000<00000`0000?0020
AP0002P0000L0000AdA9@`8000370`00G@000<85001M0P00000004H0000X0000700004M4BD<20000
a`<005d000321@004@80000000160000:00001`00017A4U30P000>D4001j00007@D009d000000000
AP00050000140000ADe6:bY0000T000060000000P3l0000000000000P3l00000000000Y00<0L0000
40000?ooool10000iPAk03H08@0Q000020000680000<00000@0002@0000T00000020?@0000000000
0020?@00000000000P0002D0000<00000000P2D0000<00002000P4`0001T0000iP@007/0000K1@00
V`0005Q>002X1`00H0<00102000Q0?00000000000000080o000000000000080o0000000000000000
000000000000000000000000000U0000300000L0080U000030000000080T000090000000P4400000
00000000P44000000000008000160000R00007`00015CDH[24000S`0000`00000A30f`00001F0000
00000000P3l200000P000000044200000A30f`000000003o24010b`0000P00000A30f`@00000@000
iPAk0>H4W00L1I`070Ek00010H4E@040400000@000000000>P0000`000080000900002@00000080m
000000000000080m0000000000020000G`0003P000010000>0000000000h00000000000P0@0@0000
000000000000000000000000000U000030000040000U0000300000D0081F0000;0000=T4001^0000
:0D00:P000040000F4jX1eQ>^0VhDKP9^56X1bD0000<00001`00P2D0000<00000000P2@0000T0000
0020@@00000000000020@@00000000000P0002P0000<00000@0003X0000<00002P000280000<0000
ooooodH0000L0000400004E=AR/4@0003000000000160000500000P00017A4U30`0004H0000X0000
700004M4BD<20000n0@00800000F1@00V000000000160000D00004@00015CDH[:T0002@0000H0000
0020?`00000000000020?`00000000002T00`1`0000@0000ooooo`40003i1840700F024000080000
HP0000`000010000900002@00000080m000000000000080m00000000000200009@0000`000000020
9@0000`000080020C00006@0003i1000P@0001@5002F0000R4l000P800300@00H0400240l0000000
00000000P3l0000000000000P3l0000000000000000000000000000000000000000002D0000<0000
1`00P2D0000<00000000P2@0000T00000020@@00000000000020@@00000000000P0004H000280000
O00004E=AR/8@082?000030000014<3K000005H0000000000020?`80000200000000@@8000014<3K
00000?ooool8@0<3;000020000014<3K10000010003i1840n@BG01D5U`0E1H400041PAE00`0@0000
10000080000j0000300000P0000T000090000000P3d0000000000000P3d0000000000080001O0000
>0000040000h0000000003P0000000000201010000000000oooo000000000000000002D0000<0000
0@0002D0000<00001@00P5H0000/0000k0@007@0000Q1@00X`0000@00028C`P8R4mX2DQAJ0U8D@P8
9@0000`0000700209@0000`000000020900002@00000081100000000000008110000000000020000
:00000`000010000>P0000`0000:00008P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000
000004H0000D0000200004M4BD<300008@0000P0000N000060000?`4002200004`D009L0001B0000
L0400040003coooo0000000000000000T040000000000000@@1b06T0H@1/00000000000000000000
0000000000000000000000000000000000000000000000000000000000010000I7H02000001h0000
00000;CO4`3@h1<0N0000800003k1`00;R@d<K3O4`010000000005T^/30=0000`9NU0;CO4`3CZ`0`
B9NU0>CO4`0<0000d>0C0:cQ4`000000loooo`000000000000000;`20000000000000440LP1Y0640
K0000000000000000000000000000000000000000000000000000000000000000000000000060000
8`000000000@00003@0000<0003I?/AgNDo4MbH;2P9L0000i=hC0=2FY@38gQ<06oL0<2H;2P9TMP08
000002D0000<00000@000580001`0@000P000?Ooool0000000000000002@0@000000000002110780
J@1Q06`0000000000000000000000000000000000000000000000000000000000000000000000000
000C00`0000900000`0007P00000000068<C0>B34`1h0000P00005a4a7LMA<Ag58<C00400023>lAg
FBj`<0L0003PWM0168<C0=>[031XWM01B8<C00`00010i]01A8`C01d000000001000005@0H@1X06l0
K@1Q0000000001EKk=8GFhSBV`3PPA<0DDlEFm3CV`0LdY/0E=:K0?SAV`0/0000NP0002`3002H0000
188C040o5E_0eI/0000EFd3FV`20Q1<0n=6K0000000000400@020=Tna7MiClAg:`X:R5`00018PQ<0
J9g@0Bb24`0Km`0`:`X:R6Af00P000009@0000`0000200009@0000`0000100009@0000`0000=0020
9@0000`0000200009@0000`0000100004P0000`000010000E00005P0003l1000Q00000/5002C0000
0@00000084800212o0@008@000020000C00000000000000000000?ooooooooooD00004D0E0090000
1`0002D0000<00000P0005@0001D000030D008X0000@1@00U@00004000000212000P@P`5002:0000
0@0004`00000000000000000003ooooooooooe00000a00001@0002D0000<00003@00P280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@000?8200210@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000000209@0000`0000=0020
AP0002P0000L0000AdA9@`80000b1@00k`4008L5000A0P00000004H0001@0000A00004E=AR/Z@000
900001P00000080o000000000000080o00000000000:@030700001000030`<3o0@0003<5l05C0200
8@0000P0001R000030000040000T000090000000P3d0000000000000P3d0000000000080000W0000
600000<000000000`<300000000U0000300000<0000U0000300000P0081<0000I00003<5003`0@00
Q@D000l2000XD`00n1h0030500000P008@3`0000000000000020?`00000000000020?`0000000000
000000000000000000000000000000009@0000`0000700209@0000`000000020900002@000000811
00000000000008110000000000020000AP0008P0001l0000ADe6:`Q0108l0000<000004@`=/00000
EP0000000000080o0P000080000000110P00004@`=/000000000o`Q01@</00008000004@`=/40000
040003<5l04c1A02QPD@0XH5l0400@615D05010000040000100003X0000<0000200002@0000T0000
0020?@00000000000020?@00000000000P0005l0000h0000100003P000000000>000000000008040
400000000000000000000000000000009@0000`0000400009@0000`000050020EP0002`0000V1@00
h`400985000L0P00100002QCn1hXDoPPF5Sh85QHn1hU0000300000L0080U000030000000080T0000
90000000P440000000000000P440000000000080000X0000300000@0000j0000300000X0000R0000
30000?oooom60000700001000015CDH[140000`000000000AP0001@000080000AdA9@`<0000Q0000
200001h0000H0000=PD00?4100241@0040800580001`0@0010000??oool0000000000000002l0P00
0000000002110780J@1Q06`000000000000000000000000000000000000000000000000000000000
00000000000000000002<0X40001000064dC07P000000000V4dC06A>4`1h0000P00001Q=4`0/C1<0
U4dC004000000000FBj`<0d0000T3N41V4dC0=>[032/3>41b4dC00`0003d2N41a5HC00L0003coooo
0000000000000000_08000000000000P@@1b06T0H@1/000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000001l2N4194dC0=Tna7MiClAg
D0/:1e`00038C1<0[0cQ0Ja<4`0Km`0`D0/:1fAf00P000009@0000`0000400009@0000`0000=0020
9@0000`000040000500000`0000=00004P0000`000010000E00007`000141@00n04007D500070P00
0@00000084800212A0D00?P100080000C00000000000000000000?ooooooooooG00004L0B@0P05@0
LP1Q06<0M00:0000100000@0000800001@0000P000070000100002D0000<00003@00P280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@000?8200210@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000000209@0000`0000=0020
AP0002P0000L0000AdA9@`80003?1000k`400?8400070P00000004H0001@0000A00004E=AR/Z@000
900001P00000080o000000000000080o00000000000:@03070000100003ooooo0@000=04l04Q01H0
:00000`0000300008@0000P0001R000030000040000T000090000000P3d0000000000000P3d00000
00000080000W0000600000<000000000oooo0000000U0000300000<0000U0000300000P0081<0000
I0000=04003`0@00l0@000D2003hC000n1h00102001P0@008@3`0000000000000020?`0000000000
0020?`0000000000000000000000000000000000000000009@0000`0000700209@0000`000000020
900002@00000081100000000000008110000000000020000AP0008P0001l0000ADe6:`Q01P8l0000
<000004@`=/00000EP0000000000080o0P000080000000110P00004@`=/00000ooooo`Q01`</0000
8000004@`=/4000004000=04l07@10H2l@@60_44l0400@615D070100000400001P0003X0000<0000
200002@0000T00000020?@00000000000020?@00000000000P0005l0000h00001@0003P000000000
>00000000000804040000000003oool000000000000000009@0000`0000500009@0000`000050020
EP0002`000331000h`400?d4000B0P0010000?Q<n1khC5PP24mH80Q?n1hU0000300000L0080U0000
30000000080T000090000000P440000000000000P440000000000080000X0000300000D0000j0000
300000X0000R000030000?oooom60000700001000015CDH[140000`000000000AP0001@000080000
AdA9@`<0000Q0000200001h0000H0000d`@00?41003_10001P8002D0000<00000@0002D0000<0000
0P0002D0000<00000@0002D0000<00003@00P2D0000<00000P0002D0000<00000@0001@0000<0000
3@000180000<00000@0005@0001D0000d`@00?<1003I10000P80004000000212000P@]<4003c0@00
0@0004`00000000000000000003ooooooooooe00001c00001`0002D0000<00000P0005@0001H0000
fP@00?T1003Q10001080004000000212000P@]X4003i0@000P0004`00000000000000000003ooooo
oooooe00001`07@01@0000<0000U0000300000d0080R000030000?oooolQ0000200001T0000<0000
oooo01P0000<0000000001h0000H00006P000140003b0P00P@400280000<0000oooooaP0000<0000
000001T0000<0000oooo02D0000<00000000P2D0000<00003@00P4H0000X0000700004M4BD<20000
>@@00=01001L1000j040000000160000D00004@00015CDH[:T0002@0000H00000020?`0000000000
0020?`00000000002T00`1`0000@0000ooooo`40000j1=418@0F024000080000HP0000`000010000
900002@00000080m000000000000080m00000000000200009@0000`0000300009@0000`000080020
C00006@0000j1000d@4005X4003V0@00V4<000PM000@0P00H0400240l000000000000000P3l00000
00000000P3l0000000000000000000000000000000000000000002D0000<00001`00P2D0000<0000
0000P2@0000T00000020@@00000000000020@@00000000000P0004H000280000O00004E=AR/8@0P2
?000030000014<3K000005H0000000000020?`80000200000000@@8000014<3K00000?ooool8@0T3
;000020000014<3K10000010000j1=41>PCW0E/4i`5K1=410041PAE02@0@0000100000P0000j0000
300000P0000T000090000000P3d0000000000000P3d0000000000080001O0000>00000D0000h0000
000003P0000000000201010000000000oooo000000000000000002D0000<00001@0002D0000<0000
1@00P5H0000/0000;@@00<@1001W1000l`4000@0002H@`PMV4=X7ZQ5J1jXA@PM9@0000`000070020
9@0000`000000020900002@00000081100000000000008110000000000020000:00000`000050000
>P0000`0000:00008P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000000004H0000D0000
200004M4BD<300008@0000P0000N0000600003d4003B0@00F@@00>L1000U000030000040000U0000
30000080000U000030000040000U0000300000d0080U000030000080000U000030000040000D0000
300000d0000B000030000040001D0000E00003d4003D0@00@`@00><100010000000P@P00848m1000
e0400040001<00000000000000000000oooooooooom@0000L`0000L0000U000030000080001D0000
E00004@4003J0@00B0@00>D100010000000P@P0084941000fP400040001<00000000000000000000
oooooooooom@0000L00000D0000U0000300000d0080R000030000?oooolQ0000200001T0000<0000
oooo01P0000<0000000001h0000H00006P000140003b0P00P@400280000<0000oooooaP0000<0000
000001T0000<0000oooo02D0000<00000000P2D0000<00003@00P4H0000X0000700004M4BD<20000
:P@00<D1000i1000l040000000160000W00009000015CDH[:T0002@0000H00000020?`0000000000
0020?`0000000000240:0eP0001<00000A30f`L0000000000825A000lT<0f8E4003b@`3HQD@00>=3
08R6A000hd<0R8I4003b@`3PQT@00?930326A000md<00@410@6101A02X0@000010000?oooolQ0000
20000680000<00000@0002@0000T00000020?@00000000000020?@00000000000P0002D0000<0000
0`0001<0000<00000@0002D0000<00002000P5H0000h0000:`@00<D1000g1000kP4000L0002h@SPN
i48h7^A2F1`l@ePL?4<h7VQ3>1h@@mPN9@0000`0000700204`0000`0000100009@0000`000000020
900002@00000081100000000000008110000000000020000AP000600001D0000ADe6:`Q02`900000
=000004@`=/00000GP0000000000080o0P000080000200000000@@8000014<3K000000000?lE@0X0
400000@0000;0000900002@00000080m000000000000080m0000000000020000G`0003P000050000
>0000000000h0000000000000@0@0000000000000000000000000000000U0000300000D0000U0000
300000D0081F0000>00002X400340@00>0@00>l100070000^48h7^A2>1kT@UPL?4=H73a3>1iX@cPN
44?H7RD0000<00001`00P2D0000<00000000P2@0000T00000020@@00000000000020@@0000000000
0P0002P0000<00001@000280000<0000ooooodH0000L0000400004E=AR/4@0003000000000160000
500000P00017A4U30`0004H0000X0000700004M4BD<20000a`<00:d0002^1@00b040000000160000
D00004@00015CDH[:T0002@0000H00000020?`00000000000020?`00000000002T00`1`0000@0000
ooooo`4000380jh0i@4I0B4000080000HP0000`000010000900002@00000080m000000000000080m
00000000000200009@0000`0000300009@0000`000080020C00006@000380`00[P000:`500360@00
N3`00=P:001@7P00T1400240l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000002D0000<00001`00P2D0000<00000000P2@0000T00000020@@0000000000
0020@@00000000000P0004H0002<0000P00004E=AR/8@0`2@00003@000014<3K000007H000000000
ZjZZ?`80000200000000@@80000200000A30f`000000003o240=0b`0000P00000A30f`@00000@000
b0>^0<P3a`6]1LL1[@F^00010H4E@0d0400000@0000<0000:00000`000030000900002@00000080m
000000000000080m0000000000020000G`0003P000030000>0000000000h00000000000B0@0@0000
000000000000000000000000000U0000300000<0000W0000600000D00000000000000000000U0000
300000D0000C000030000080000k0000200001/0000@0000/eX00><:000f000040000;=J003S2P00
F00003@00000000000000?oooooooooo1P000:eJh`ZXF]h:Z5[H2ZQJd`Z]F/h:/e[>2SH0000@0000
/eX00<h:001H0000=000000000000000ooooooooool60000^E[>2[iJd`ZnF]P:_U[N2[UJh`ZcF^<:
?@0000P0000K0000400008QJ003S2P00=P0001000028FP00h`X005P0000d000000000000003ooooo
ooooo`H00023F^<:OU[N2WiJf0YnF]<:Pe[>2XQJcPXf0000400008QJ003>2P00F00003@000000000
00000?oooooooooo1P0008iJcPZCF]<:Te[H2Y=JgPZ>F^<:R5[S2Sd0000800006`000100001NFP00
h`X003H0000@0000GUX00><:001H0000=000000000000000ooooooooool60000F5[S2U=JgPYCF]P:
De[C2UQJcPYNF/h:=P000100001NFP00cPX005P0000d000000000000003oooooooooo`H0001TF/h:
J5[C2VQJf0YXF]h:I5[S2UiJh`Xm0000200001/0000@0000<eX00><:000f0000400003=J003S2P00
F00003@00000000000000?oooooooooo1P0002eJh`XXF]h::5[H2RQJd`X]F/h:<e[>2SH0000@0000
<eX00<h:001H0000=000000000000000ooooooooool60000>E[>2SiJd`XnF]P:?U[N2SUJh`XcF^<:
?@0000P0000K0000400000QJ003S2P00=P0001000008FP00h`X005P0000d000000000000003ooooo
ooooo`H00002F^<:oUWN2_iIf0[nFM<:0U[>2PQJcPXf0000400000QJ003>2P00F00003@000000000
00000?oooooooooo1P0000iJcPXCF]<:4e[H2Q=JgPX>F^<:25[S2Sd0000800006`000100003NF@00
h`X003H0000@0000gUT00><:001H0000=000000000000000ooooooooool60000f5WS2]=IgP[CFMP:
deWC2]QIcP[NFLh:=P000100003NF@00cPX005P0000d000000000000003oooooooooo`H0003TFLh:
j5WC2^QIf0[XFMh:i5WS2]iIh`Xm0000200001/0000@0000/eT00><:000f000040000;=I003S2P00
F00003@00000000000000?oooooooooo1P000:eIh`ZXFMh:Z5WH2ZQId`Z]FLh:/eW>2SH0000@0000
/eT00<h:001H0000=000000000000000ooooooooool60000^EW>2[iId`ZnFMP:_UWN2[UIh`ZcFN<:
?@0000P0000K0000400008QI003S2P00=P0001000028F@00h`X005P0000d000000000000003ooooo
ooooo`H00022FN<:OUWN2WiIf0YnFM<:PUW>2XQIcPXf0000400008QI003>2P00F00003@000000000
00000?oooooooooo1P0008iIcPZCFM<:TeWH2Y=IgPZ>FN<:R5WS2Sd0000800006`000100001NF@00
h`X003H0000@0000GUT00><:001H0000=000000000000000ooooooooool60000F5WS2U=IgPYCFMP:
DeWC2UQIcPYNFLh:=P000100001NF@00cPX005P0000d000000000000003oooooooooo`H0001TFLh:
J5WC2VQIf0YXFMh:I5WS2UiIh`Xm0000200001/0000@0000<eT00><:000f0000400003=I003S2P00
F00003@00000000000000?oooooooooo1P0002eIh`XXFMh::5WH2RQId`X]FLh:<eW>2SH0000@0000
<eT00<h:001H0000=000000000000000ooooooooool60000>EW>2SiId`XnFMP:?UWN2SUIh`XcFN<:
?@0000P0000K0000400000QI003S2P00=P0001000008F@00h`X005P0000d000000000000003ooooo
ooooo`H00002FN<:oUSN2_iHf0[nF=<:0UW>2PQIcPXf0000400000QI003>2P00F00003@000000000
00000?oooooooooo1P0000iIcPXCFM<:4eWH2Q=IgPX>FN<:25WS2Sd0000800006`000100003NF000
h`X003H0000@0000gUP00><:001H0000=000000000000000ooooooooool60000f5SS2]=HgP[CF=P:
deSC2]QHcP[NF<h:=P000100003NF000cPX005P0000d000000000000003oooooooooo`H0003SF<h:
j5SC2^QHf0[XF=h:heSS2]iHh`Xm0000200001/0000@0000/eP00><:000f000040000;=H003S2P00
F00003@00000000000000?oooooooooo1P000:eHh`ZXF=h:Z5SH2ZQHd`Z]F<h:/eS>2SH0000@0000
/eP00<h:001H0000=000000000000000ooooooooool60000^ES>2[iHd`ZnF=P:_USN2[UHh`ZcF><:
?@0000P0000K0000400008QH003S2P00=P0001000028F000h`X005P0000d000000000000003ooooo
ooooo`H00022F><:OESN2WeHf0YmF=<:PUS>2XQHcPXf0000400008QH003>2P00F00003@000000000
00000?oooooooooo1P0008iHcPZCF=<:TeSH2Y=HgPZ>F><:R5SS2Sd0000800006`000100001MF000
h`X003H0000@0000GEP00><:001H0000=000000000000000ooooooooool60000F5SS2U=HgPYCF=P:
DeSC2UQHcPYMF<h:=P000100001MF000cPX005P0000d000000000000003oooooooooo`H0001SF<h:
J5SC2VQHf0YXF=h:HeSS2UeHh`Xm0000200001/0000@0000<eP00><:000f0000400003=H003S2P00
F00003@00000000000000?oooooooooo1P0002eHh`XXF=h::5SH2RQHd`X]F<h:<eS>2SH0000@0000
<eP00<h:001H0000=000000000000000ooooooooool60000>ES>2SeHd`XmF=P:?ESN2SUHh`XcF><:
?@0000P0000K0000400000QH003S2P00=P0001000008F000h`X005P0000d000000000000003ooooo
ooooo`H00002F><:oEON2_eGf0[mEm<:0US>2PQHcPXf0000400000QH003>2P00F00003@000000000
00000?oooooooooo1P0000iHcPXCF=<:4eSH2Q=HgPX>F><:25SS2Sd0000800006`000100003ME`00
h`X003H0000@0000gEL00><:001H0000=000000000000000ooooooooool60000f5OS2]=GgP[CEmP:
deOC2]QGcP[MElh:=P000100003ME`00cPX005P0000d000000000000003oooooooooo`H0003SElh:
j5OC2^QGf0[XEmh:heOS2]eGh`Xm0000200001/0000@0000/eL00><:000f000040000;=G003S2P00
F00003@00000000000000?oooooooooo1P000:eGh`ZXEmh:Z5OH2ZQGd`Z]Elh:/eO>2SH0000@0000
/eL00<h:001H0000=000000000000000ooooooooool60000^EO>2[eGd`ZmEmP:_EON2[UGh`ZcEn<:
?@0000P0000K0000400008QG003S2P00=P0001000028E`00h`X005P0000d000000000000003ooooo
ooooo`H00022En<:OEON2WeGf0YmEm<:PUO>2XQGcPXf0000400008QG003>2P00F00003@000000000
00000?oooooooooo1P0008iGcPZCEm<:TeOH2Y=GgPZ>En<:R5OS2Sd0000800006`000100001ME`00
h`X003H0000@0000GEL00><:001H0000=000000000000000ooooooooool60000EeOS2U=GgPYCEmP:
DeOC2UMGcPYMElh:=P000100001ME`00cPX005P0000d000000000000003oooooooooo`H0001SElh:
J5OC2VQGf0YXEmh:HeOS2UeGh`Xm0000200001/0000@0000<eL00><:000f0000400003=G003S2P00
F00003@00000000000000?oooooooooo1P0002eGh`XXEmh::5OH2RQGd`X]Elh:<eO>2SH0000@0000
<eL00<h:001H0000=000000000000000ooooooooool60000>EO>2SeGd`XmEmP:?EON2SUGh`XcEn<:
?@0000P0000K0000400000QG003S2P00=P0001000008E`00h`X005P0000d000000000000003ooooo
ooooo`H00002En<:oEKN2_eFf0[mE]<:0UO>2PQGcPXf0000400000QG003>2P00F00003@000000000
00000?oooooooooo1P0000iGcPXCEm<:4eOH2Q=GgPX>En<:25OS2Sd0000800006`000100003MEP00
h`X003H0000@0000gEH00><:001H0000=000000000000000ooooooooool60000eeKS2]=FgP[CE]P:
deKC2]MFcP[ME/h:=P000100003MEP00cPX005P0000d000000000000003oooooooooo`H0003SE/h:
j5KC2^QFf0[XE]h:heKS2]eFh`Xm0000200001/0000@0000/eH00><:000f000040000;=F003S2P00
F00003@00000000000000?oooooooooo1P000:eFh`ZXE]h:Z5KH2ZQFd`Z]E/h:/eK>2SH0000@0000
/eH00<h:001H0000=000000000000000ooooooooool60000^5K>2[eFd`ZmE]P:_EKN2[QFh`ZcE^<:
?@0000P0000K0000400008QF003S2P00=P0001000028EP00h`X005P0000d000000000000003ooooo
ooooo`H00022E^<:OEKN2WeFf0YmE]<:PUK>2XQFcPXf0000400008QF003>2P00F00003@000000000
00000?oooooooooo1P0008iFcPZCE]<:TeKH2Y=FgPZ>E^<:R5KS2Sd0000800006`000100001MEP00
h`X003H0000@0000GEH00><:001H0000=000000000000000ooooooooool60000EeKS2U=FgPYCE]P:
DeKC2UMFcPYME/h:=P000100001MEP00cPX005P0000d000000000000003oooooooooo`H0001SE/h:
J5KC2VQFf0YXE]h:HeKS2UeFh`Xm0000200001/0000@0000<eH00><:000f00004000039F003S2P00
F00003@00000000000000?oooooooooo1P0002eFh`XXE]h::5KH2RQFd`X]E/h:<UK>2SH0000@0000
<eH00<h:001H0000=000000000000000ooooooooool60000>5K>2SeFd`XmE]P:?EKN2SQFh`XcE^<:
?@0000P0000K0000400000QF003S2P00=P0001000008EP00h`X005P0000d000000000000003ooooo
ooooo`H00002E^<:oEGN2_eEf0[mEM<:0UK>2PQFcPXf0000400000QF003>2P00F00003@000000000
00000?oooooooooo1P0000iFcPXBE]<:4UKH2Q9FgPX>E^<:25KS2Sd0000800006`000100003ME@00
h`X003H0000@0000gED00><:001H0000=000000000000000ooooooooool60000eeGS2]9EgP[BEMP:
dUGC2]MEcP[MELh:=P000100003ME@00cPX005P0000d000000000000003oooooooooo`H0003SELh:
j5GC2^QEf0[XEMh:heGS2]eEh`Xm0000200001/0000@0000/UD00><:000f000040000;9E003S2P00
F00003@00000000000000?oooooooooo1P000:eEh`ZXEMh:Z5GH2ZQEd`Z]ELh:/UG>2SH0000@0000
/UD00<h:001H0000=000000000000000ooooooooool60000^5G>2[eEd`ZmEMP:_EGN2[QEh`ZbEN<:
?@0000P0000K0000400008QE003S2P00=P0001000028E@00h`X005P0000d000000000000003ooooo
ooooo`H00022EN<:OEGN2WeEf0YmEM<:PUG>2XQEcPXf0000400008QE003>2P00F00003@000000000
00000?oooooooooo1P0008iEcPZBEM<:TUGH2Y9EgPZ>EN<:R5GS2Sd0000800006`000100001ME@00
h`X003H0000@0000GED00><:001H0000=000000000000000ooooooooool60000EeGS2U9EgPYBEMP:
DUGC2UMEcPYMELh:=P000100001ME@00cPX005P0000d000000000000003oooooooooo`H0001SELh:
J5GC2VQEf0YXEMh:HeGS2UeEh`Xm0000200001/0000@0000<UD00><:000f00004000039E003S2P00
F00003@00000000000000?oooooooooo1P0002aEh`XXEMh::5GH2RQEd`X/ELh:<UG>2SH0000@0000
<UD00<h:001H0000=000000000000000ooooooooool60000>5G>2SeEd`XmEMP:?EGN2SQEh`XbEN<:
?@0000P0000K0000400000QE003S2P00=P0001000008E@00h`X005P0000d000000000000003ooooo
ooooo`H00002EN<:oECN2_eDf0[mE=<:0UG>2PQEcPXf0000400000QE003>2P00F00003@000000000
00000?oooooooooo1P0000iEcPXBEM<:4UGH2Q9EgPX>EN<:25GS2Sd0000800006`000100003ME000
h`X003H0000@0000gE@00><:001H0000=000000000000000ooooooooool60000eeCS2]9DgP[BE=P:
dUCC2]MDcP[ME<h:=P000100003ME000cPX005P0000d000000000000003oooooooooo`H0003SE<h:
j5CC2^QDf0[XE=h:heCS2]eDh`Xm0000200001/0000@0000/U@00><:000f000040000;9D003S2P00
F00003@00000000000000?oooooooooo1P000:aDh`ZXE=h:Z5CH2ZQDd`Z/E<h:/UC>2SH0000@0000
/U@00<h:001H0000=000000000000000ooooooooool60000^5C>2[eDd`ZmE=P:_ECN2[QDh`ZbE><:
?@0000P0000K0000400008QD003S2P00=P0001000028E000h`X005P0000d000000000000003ooooo
ooooo`H00022E><:OECN2WeDf0YmE=<:PUC>2XQDcPXf0000400008QD003>2P00F00003@000000000
00000?oooooooooo1P0008iDcPZBE=<:TUCH2Y9DgPZ>E><:R5CS2Sd0000800006`000100001ME000
h`X003H0000@0000GE@00><:001H0000=000000000000000ooooooooool60000EeCS2U9DgPYBE=P:
DUCC2UMDcPYME<h:=P000100001ME000cPX005P0000d000000000000003oooooooooo`H0001SE<h:
J5CC2VQDf0YXE=h:HeCS2UeDh`Xm0000200001/0000@0000<U@00><:000f00004000039D003S2P00
F00003@00000000000000?oooooooooo1P0002aDh`XXE=h::5CH2RQDd`X/E<h:<UC>2SH0000@0000
<U@00<h:001H0000=000000000000000ooooooooool60000>5C>2SeDd`XmE=P:?ECN2SQDh`XbE><:
?@0000P0000K0000400000QD003S2P00=P0001000008E000h`X005P0000d000000000000003ooooo
ooooo`H00002E><:oE?N2_eCf0[mDm<:0UC>2PQDcPXf0000400000QD003>2P00F00003@000000000
00000?oooooooooo1P0000eDcPXBE=<:4UCH2Q9DgPX=E><:25CS2Sd0000800006`000100003MD`00
h`X003H0000@0000gE<00><:001H0000=000000000000000ooooooooool60000ee?S2]9CgP[BDmP:
dU?C2]MCcP[MDlh:=P000100003MD`00cPX005P0000d000000000000003oooooooooo`H0003SDlh:
j5?C2^QCf0[XDmh:he?S2]eCh`Xm0000200001/0000@0000/U<00><:000f000040000;9C003S2P00
F00003@00000000000000?oooooooooo1P000:aCh`ZWDmh:Ye?H2ZMCd`Z/Dlh:/U?>2SH0000@0000
/U<00<h:001H0000=000000000000000ooooooooool60000^5?>2[eCd`ZmDmP:_E?N2[QCh`ZbDn<:
?@0000P0000K0000400008MC003S2P00=P0001000027D`00h`X005P0000d000000000000003ooooo
ooooo`H00022Dn<:OE?N2WeCf0YmDm<:PU?>2XMCcPXf0000400008MC003>2P00F00003@000000000
00000?oooooooooo1P0008eCcPZBDm<:TU?H2Y9CgPZ=Dn<:Qe?S2Sd0000800006`000100001MD`00
h`X003H0000@0000GE<00><:001H0000=000000000000000ooooooooool60000Ee?S2U9CgPYBDmP:
DU?C2UMCcPYMDlh:=P000100001MD`00cPX005P0000d000000000000003oooooooooo`H0001SDlh:
Ie?C2VMCf0YWDmh:He?S2UeCh`Xm0000200001/0000@0000<U<00><:000f00004000039C003S2P00
F00003@00000000000000?oooooooooo1P0002aCh`XWDmh:9e?H2RMCd`X/Dlh:<U?>2SH0000@0000
<U<00<h:001H0000=000000000000000ooooooooool60000>5?>2SeCd`XmDmP:?E?N2SQCh`XbDn<:
?@0000P0000K0000400000MC003S2P00=P0001000007D`00h`X005P0000d000000000000003ooooo
ooooo`H00002Dn<:oE;N2_eBf0[mD]<:0U?>2PMCcPXf0000400000MC003>2P00F00003@000000000
00000?oooooooooo1P0000eCcPXBDm<:4U?H2Q9CgPX=Dn<:1e?S2Sd0000800006`000100003MDP00
h`X003H0000@0000gE800><:001H0000=000000000000000ooooooooool60000ee;S2]9BgP[BD]P:
dU;C2]MBcP[MD/h:=P000100003MDP00cPX005P0000d000000000000003oooooooooo`H0003SD/h:
ie;C2^MBf0[WD]h:he;S2]eBh`Xm0000200001/0000@0000/U800><:000f000040000;9B003S2P00
F00003@00000000000000?oooooooooo1P000:aBh`ZWD]h:Ye;H2ZMBd`Z/D/h:/U;>2SH0000@0000
/U800<h:001H0000=000000000000000ooooooooool60000^5;>2[eBd`ZmD]P:_E;N2[QBh`ZbD^<:
?@0000P0000K0000400008MB003S2P00=P0001000027DP00h`X005P0000d000000000000003ooooo
ooooo`H00021D^<:OE;N2WeBf0YmD]<:PE;>2XMBcPXf0000400008MB003>2P00F00003@000000000
00000?oooooooooo1P0008eBcPZBD]<:TU;H2Y9BgPZ=D^<:Qe;S2Sd0000800006`000100001MDP00
h`X003H0000@0000GE800><:001H0000=000000000000000ooooooooool60000Ee;S2U9BgPYBD]P:
DU;C2UMBcPYMD/h:=P000100001MDP00cPX005P0000d000000000000003oooooooooo`H0001SD/h:
Ie;C2VMBf0YWD]h:He;S2UeBh`Xm0000200001/0000@0000<U800><:000f00004000039B003S2P00
F00003@00000000000000?oooooooooo1P0002aBh`XWD]h:9e;H2RMBd`X/D/h:<U;>2SH0000@0000
<U800<h:001H0000=000000000000000ooooooooool60000>5;>2SeBd`XmD]P:?E;N2SQBh`XbD^<:
?@0000P0000K0000400000MB003S2P00=P0001000007DP00h`X005P0000d000000000000003ooooo
ooooo`H00001D^<:oE7N2_eAf0[mDM<:0E;>2PMBcPXf0000400000MB003>2P00F00003@000000000
00000?oooooooooo1P0000eBcPXBD]<:4U;H2Q9BgPX=D^<:1e;S2Sd0000800006`000100003MD@00
h`X003H0000@0000gE400><:001H0000=000000000000000ooooooooool60000ee7S2]9AgP[BDMP:
dU7C2]MAcP[MDLh:=P000100003MD@00cPX005P0000d000000000000003oooooooooo`H0003RDLh:
ie7C2^MAf0[WDMh:hU7S2]eAh`Xm0000200001/0000@0000/U400><:000f000040000;9A003S2P00
F00003@00000000000000?oooooooooo1P000:aAh`ZWDMh:Ye7H2ZMAd`Z/DLh:/U7>2SH0000@0000
/U400<h:001H0000=000000000000000ooooooooool60000^57>2[eAd`ZmDMP:_E7N2[QAh`ZbDN<:
?@0000P0000K0000400008MA003S2P00=P0001000027D@00h`X005P0000d000000000000003ooooo
ooooo`H00021DN<:OE7N2WeAf0YmDM<:PE7>2XMAcPXf0000400008MA003>2P00F00003@000000000
00000?oooooooooo1P0008eAcPZBDM<:TU7H2Y9AgPZ=DN<:Qe7S2Sd0000800006`000100001MD@00
h`X003H0000@0000GE400><:001H0000=000000000000000ooooooooool60000Ee7S2U9AgPYBDMP:
DU7C2UMAcPYMDLh:=P000100001MD@00cPX005P0000d000000000000003oooooooooo`H0001RDLh:
Ie7C2VMAf0YWDMh:HU7S2UeAh`Xm0000200001/0000@0000<U400><:000f00004000039A003S2P00
F00003@00000000000000?oooooooooo1P0002aAh`XWDMh:9e7H2RMAd`X/DLh:<U7>2SH0000@0000
<U400<h:001H0000=000000000000000ooooooooool60000>57>2SeAd`XmDMP:?E7N2SQAh`XbDN<:
?@0000P0000K0000400000MA003S2P00=P0001000007D@00h`X005P0000d000000000000003ooooo
ooooo`H00001DN<:o53N2_a@f0[lD=<:0E7>2PMAcPXf0000400000MA003>2P00F00003@000000000
00000?oooooooooo1P0000eAcPXBDM<:4U7H2Q9AgPX=DN<:1e7S2Sd0000800006`000100003LD000
h`X003H0000@0000g5000><:001H0000=000000000000000ooooooooool60000ee3S2]9@gP[BD=P:
dU3C2]M@cP[LD<h:=P000100003LD000cPX005P0000d000000000000003oooooooooo`H0003RD<h:
ie3C2^M@f0[WD=h:hU3S2]a@h`Xm0000200001/0000@0000/U000><:000f000040000;9@003S2P00
F00003@00000000000000?oooooooooo1P000:a@h`ZWD=h:Ye3H2ZM@d`Z/D<h:/U3>2SH0000@0000
/U000<h:001H0000=000000000000000ooooooooool60000^53>2[a@d`ZlD=P:_53N2[Q@h`ZbD><:
?@0000P0000K0000400008M@003S2P00=P0001000027D000h`X005P0000d000000000000003ooooo
ooooo`H00021D><:O53N2Wa@f0YlD=<:PE3>2XM@cPXf0000400008M@003>2P00F00003@000000000
00000?oooooooooo1P0008e@cPZBD=<:TU3H2Y9@gPZ=D><:Qe3S2Sd0000800006`000100001LD000
h`X003H0000@0000G5000><:001H0000=000000000000000ooooooooool60000EU3S2U9@gPYBD=P:
DU3C2UI@cPYLD<h:=P000100001LD000cPX005P0000d000000000000003oooooooooo`H0001RD<h:
Ie3C2VM@f0YWD=h:HU3S2Ua@h`Xm0000200001/0000@0000<U000><:000f00004000039@003S2P00
F00003@00000000000000?oooooooooo1P0002a@h`XWD=h:9e3H2RM@d`X/D<h:<U3>2SH0000@0000
<U000<h:001H0000=000000000000000ooooooooool60000>53>2Sa@d`XlD=P:?53N2SQ@h`XbD><:
?@0000P0000K0000400000M@003S2P00=P0001000007D000h`X005P0000d000000000000003ooooo
ooooo`H00001D><:o4oN2_a?f0[lCm<:0E3>2PM@cPXf0000400000M@003>2P00F00003@000000000
00000?oooooooooo1P0000e@cPXBD=<:4U3H2Q9@gPX=D><:1e3S2Sd0000800006`000100003LC`00
h`X003H0000@0000g4l00><:001H0000=000000000000000ooooooooool60000eToS2]9?gP[BCmP:
dToC2]I?cP[LClh:=P000100003LC`00cPX005P0000d000000000000003oooooooooo`H0003RClh:
idoC2^M?f0[WCmh:hToS2]a?h`Xm0000200001/0000@0000/Tl00><:000f000040000;9?003S2P00
F00003@00000000000000?oooooooooo1P000:a?h`ZWCmh:YdoH2ZM?d`Z/Clh:/To>2SH0000@0000
/Tl00<h:001H0000=000000000000000ooooooooool60000^4o>2[a?d`ZlCmP:_4oN2[Q?h`ZbCn<:
?@0000P0000K0000400008M?003S2P00=P0001000027C`00h`X005P0000d000000000000003ooooo
ooooo`H00021Cn<:O4oN2Wa?f0YlCm<:PDo>2XM?cPXf0000400008M?003>2P00F00003@000000000
00000?oooooooooo1P0008e?cPZBCm<:TToH2Y9?gPZ=Cn<:QdoS2Sd0000800006`000100001LC`00
h`X003H0000@0000G4l00><:001H0000=000000000000000ooooooooool60000EToS2U9?gPYBCmP:
DToC2UI?cPYLClh:=P000100001LC`00cPX005P0000d000000000000003oooooooooo`H0001RClh:
IdoC2VM?f0YWCmh:HToS2Ua?h`Xm0000200001/0000@0000<Tl00><:000f00004000039?003S2P00
F00003@00000000000000?oooooooooo1P0002a?h`XWCmh:9doH2RM?d`X/Clh:<To>2SH0000@0000
<Tl00<h:001H0000=000000000000000ooooooooool60000=do>2Sa?d`XlCmP:?4oN2SM?h`XbCn<:
?@0000P0000K0000400000M?003S2P00=P0001000007C`00h`X005P0000d000000000000003ooooo
ooooo`H00001Cn<:o4kN2_a>f0[lC]<:0Do>2PM?cPXf0000400000M?003>2P00F00003@000000000
00000?oooooooooo1P0000e?cPXBCm<:4ToH2Q9?gPX=Cn<:1doS2Sd0000800006`000100003LCP00
h`X003H0000@0000g4h00><:001H0000=000000000000000ooooooooool60000eTkS2]5>gP[AC]P:
dDkC2]I>cP[LC/h:=P000100003LCP00cPX005P0000d000000000000003oooooooooo`H0003RC/h:
idkC2^M>f0[WC]h:hTkS2]a>h`Xm0000200001/0000@0000/Dh00><:000f000040000;5>003S2P00
F00003@00000000000000?oooooooooo1P000:a>h`ZWC]h:YdkH2ZM>d`Z/C/h:/Dk>2SH0000@0000
/Dh00<h:001H0000=000000000000000ooooooooool60000]dk>2[a>d`ZlC]P:_4kN2[M>h`ZaC^<:
?@0000P0000K0000400008M>003S2P00=P0001000027CP00h`X005P0000d000000000000003ooooo
ooooo`H00021C^<:O4kN2Wa>f0YlC]<:PDk>2XM>cPXf0000400008M>003>2P00F00003@000000000
00000?oooooooooo1P0008e>cPZAC]<:TDkH2Y5>gPZ=C^<:QdkS2Sd0000800006`000100001LCP00
h`X003H0000@0000G4h00><:001H0000=000000000000000ooooooooool60000ETkS2U5>gPYAC]P:
DDkC2UI>cPYLC/h:=P000100001LCP00cPX005P0000d000000000000003oooooooooo`H0001RC/h:
IdkC2VM>f0YWC]h:HTkS2Ua>h`Xm0000200001/0000@0000<Dh00><:000f00004000035>003S2P00
F00003@00000000000000?oooooooooo1P0002a>h`XWC]h:9dkH2RM>d`X/C/h:<Dk>2SH0000@0000
<Dh00<h:001H0000=000000000000000ooooooooool60000=dk>2Sa>d`XlC]P:?4kN2SM>h`XaC^<:
?@0000P0000K0000400000M>003S2P00=P0001000007CP00h`X005P0000d000000000000003ooooo
ooooo`H00001C^<:o4gN2_a=f0[lCM<:0Dk>2PM>cPXf0000400000M>003>2P00F00003@000000000
00000?oooooooooo1P0000e>cPXAC]<:4DkH2Q5>gPX=C^<:1dkS2Sd0000800006`000100003LC@00
h`X003H0000@0000g4d00><:001H0000=000000000000000ooooooooool60000eTgS2]5=gP[ACMP:
dDgC2]I=cP[LCLh:=P000100003LC@00cPX005P0000d000000000000003oooooooooo`H0003RCLh:
idgC2^M=f0[WCMh:hTgS2]a=h`Xm0000200001/0000@0000/Dd00><:000f000040000;5=003S2P00
F00003@00000000000000?oooooooooo1P000:]=h`ZWCMh:YdgH2ZM=d`Z[CLh:/Dg>2SH0000@0000
/Dd00<h:001H0000=000000000000000ooooooooool60000]dg>2[a=d`ZlCMP:_4gN2[M=h`ZaCN<:
?@0000P0000K0000400008M=003S2P00=P0001000027C@00h`X005P0000d000000000000003ooooo
ooooo`H00021CN<:O4gN2Wa=f0YlCM<:PDg>2XM=cPXf0000400008M=003>2P00F00003@000000000
00000?oooooooooo1P0008e=cPZACM<:TDgH2Y5=gPZ=CN<:QdgS2Sd0000800006`000100001LC@00
h`X003H0000@0000G4d00><:001H0000=000000000000000ooooooooool60000ETgS2U5=gPYACMP:
DDgC2UI=cPYLCLh:=P000100001LC@00cPX005P0000d000000000000003oooooooooo`H0001RCLh:
IdgC2VM=f0YWCMh:HTgS2Ua=h`Xm0000200001/0000@0000<Dd00><:000f00004000035=003S2P00
F00003@00000000000000?oooooooooo1P0002]=h`XWCMh:9dgH2RM=d`X[CLh:<Dg>2SH0000@0000
<Dd00<h:001H0000=000000000000000ooooooooool60000=dg>2Sa=d`XlCMP:?4gN2SM=h`XaCN<:
?@0000P0000K0000400000M=003S2P00=P0001000007C@00h`X005P0000d000000000000003ooooo
ooooo`H00001CN<:o4cN2_a<f0[lC=<:0Dg>2PM=cPXf0000400000M=003>2P00F00003@000000000
00000?oooooooooo1P0000e=cPXACM<:4DgH2Q5=gPX=CN<:1dgS2Sd0000800006`000100003LC000
h`X003H0000@0000g4`00><:001H0000=000000000000000ooooooooool60000eTcS2]5<gP[AC=P:
dDcC2]I<cP[LC<h:=P000100003LC000cPX005P0000d000000000000003oooooooooo`H0003RC<h:
idcC2^M<f0[WC=h:hTcS2]a<h`Xm0000200001/0000@0000/D`00><:000f000040000;5<003S2P00
F00003@00000000000000?oooooooooo1P000:]<h`ZWC=h:YdcH2ZM<d`Z[C<h:/Dc>2SH0000@0000
/D`00<h:001H0000=000000000000000ooooooooool60000]dc>2[a<d`ZlC=P:_4cN2[M<h`ZaC><:
?@0000P0000K0000400008M<003S2P00=P0001000027C000h`X005P0000d000000000000003ooooo
ooooo`H00021C><:O4cN2Wa<f0YlC=<:PDc>2XM<cPXf0000400008M<003>2P00F00003@000000000
00000?oooooooooo1P0008a<cPZAC=<:TDcH2Y5<gPZ<C><:QdcS2Sd0000800006`000100001LC000
h`X003H0000@0000G4`00><:001H0000=000000000000000ooooooooool60000ETcS2U5<gPYAC=P:
DDcC2UI<cPYLC<h:=P000100001LC000cPX005P0000d000000000000003oooooooooo`H0001RC<h:
IdcC2VM<f0YWC=h:HTcS2Ua<h`Xm0000200001/0000@0000<D`00><:000f00004000035<003S2P00
F00003@00000000000000?oooooooooo1P0002]<h`XVC=h:9TcH2RI<d`X[C<h:<Dc>2SH0000@0000
<D`00<h:001H0000=000000000000000ooooooooool60000=dc>2Sa<d`XlC=P:?4cN2SM<h`XaC><:
?@0000P0000K0000400000I<003S2P00=P0001000006C000h`X005P0000d000000000000003ooooo
ooooo`H00001C><:o4_N2_a;f0[lBm<:0Dc>2PI<cPXf0000400000I<003>2P00F00003@000000000
00000?oooooooooo1P0000a<cPXAC=<:4DcH2Q5<gPX<C><:1TcS2Sd0000800006`000100003LB`00
h`X003H0000@0000g4/00><:001H0000=000000000000000ooooooooool60000eT_S2]5;gP[ABmP:
dD_C2]I;cP[LBlh:=P000100003LB`00cPX005P0000d000000000000003oooooooooo`H0003RBlh:
iT_C2^I;f0[VBmh:hT_S2]a;h`Xm0000200001/0000@0000/D/00><:000f000040000;5;003S2P00
F00003@00000000000000?oooooooooo1P000:];h`ZVBmh:YT_H2ZI;d`Z[Blh:/D_>2SH0000@0000
/D/00<h:001H0000=000000000000000ooooooooool60000]d_>2[a;d`ZlBmP:_4_N2[M;h`ZaBn<:
?@0000P0000K0000400008I;003S2P00=P0001000026B`00h`X005P0000d000000000000003ooooo
ooooo`H00021Bn<:O4_N2Wa;f0YlBm<:PD_>2XI;cPXf0000400008I;003>2P00F00003@000000000
00000?oooooooooo1P0008a;cPZABm<:TD_H2Y5;gPZ<Bn<:QT_S2Sd0000800006`000100001LB`00
h`X003H0000@0000G4/00><:001H0000=000000000000000ooooooooool60000ET_S2U5;gPYABmP:
DD_C2UI;cPYLBlh:=P000100001LB`00cPX005P0000d000000000000003oooooooooo`H0001RBlh:
IT_C2VI;f0YVBmh:HT_S2Ua;h`Xm0000200001/0000@0000<D/00><:000f00004000035;003S2P00
F00003@00000000000000?oooooooooo1P0002];h`XVBmh:9T_H2RI;d`X[Blh:<D_>2SH0000@0000
<D/00<h:001H0000=000000000000000ooooooooool60000=d_>2Sa;d`XlBmP:?4_N2SM;h`XaBn<:
?@0000P0000K0000400000I;003S2P00=P0001000006B`00h`X005P0000d000000000000003ooooo
ooooo`H00000Bn<:o4[N2_a:f0[lB]<:04_>2PI;cPXf0000400000I;003>2P00F00003@000000000
00000?oooooooooo1P0000a;cPXABm<:4D_H2Q5;gPX<Bn<:1T_S2Sd0000800006`000100003LBP00
h`X003H0000@0000g4X00><:001H0000=000000000000000ooooooooool60000eT[S2]5:gP[AB]P:
dD[C2]I:cP[LB/h:=P000100003LBP00cPX005P0000d000000000000003oooooooooo`H0003RB/h:
iT[C2^I:f0[VB]h:hT[S2]a:h`Xm0000200001/0000@0000/DX00><:000f000040000;5:003S2P00
F00003@00000000000000?oooooooooo1P000:]:h`ZVB]h:YT[H2ZI:d`Z[B/h:/D[>2SH0000@0000
/DX00<h:001H0000=000000000000000ooooooooool60000]d[>2[a:d`ZlB]P:_4[N2[M:h`ZaB^<:
?@0000P0000K0000400008I:003S2P00=P0001000026BP00h`X005P0000d000000000000003ooooo
ooooo`H00020B^<:O4[N2Wa:f0YlB]<:P4[>2XI:cPXf0000400008I:003>2P00F00003@000000000
00000?oooooooooo1P0008a:cPZAB]<:TD[H2Y5:gPZ<B^<:QT[S2Sd0000800006`000100001LBP00
h`X003H0000@0000G4X00><:001H0000=000000000000000ooooooooool60000ET[S2U5:gPYAB]P:
DD[C2UI:cPYLB/h:=P000100001LBP00cPX005P0000d000000000000003oooooooooo`H0001RB/h:
IT[C2VI:f0YVB]h:HT[S2Ua:h`Xm0000200001/0000@0000<DX00><:000f00004000035:003S2P00
F00003@00000000000000?oooooooooo1P0002]:h`XVB]h:9T[H2RI:d`X[B/h:<D[>2SH0000@0000
<DX00<h:001H0000=000000000000000ooooooooool60000=d[>2Sa:d`XlB]P:?4[N2SM:h`XaB^<:
?@0000P0000K0000400000I:003S2P00=P0001000006BP00h`X005P0000d000000000000003ooooo
ooooo`H00000B^<:o4WN2_a9f0[lBM<:04[>2PI:cPXf0000400000I:003>2P00F00003@000000000
00000?oooooooooo1P0000a:cPXAB]<:4D[H2Q5:gPX<B^<:1T[S2Sd0000800006`000100003LB@00
h`X003H0000@0000g4T00><:001H0000=000000000000000ooooooooool60000eTWS2]59gP[ABMP:
dDWC2]I9cP[LBLh:=P000100003LB@00cPX005P0000d000000000000003oooooooooo`H0003QBLh:
iTWC2^I9f0[VBMh:hDWS2]a9h`Xm0000200001/0000@0000/DT00><:000f000040000;59003S2P00
F00003@00000000000000?oooooooooo1P000:]9h`ZVBMh:YTWH2ZI9d`Z[BLh:/DW>2SH0000@0000
/DT00<h:001H0000=000000000000000ooooooooool60000]dW>2[a9d`ZlBMP:_4WN2[M9h`ZaBN<:
?@0000P0000K0000400008I9003S2P00=P0001000026B@00h`X005P0000d000000000000003ooooo
ooooo`H00020BN<:NdWN2W]9f0YkBM<:P4W>2XI9cPXf0000400008I9003>2P00F00003@000000000
00000?oooooooooo1P0008a9cPZABM<:TDWH2Y59gPZ<BN<:QTWS2Sd0000800006`000100001KB@00
h`X003H0000@0000FdT00><:001H0000=000000000000000ooooooooool60000ETWS2U59gPYABMP:
DDWC2UI9cPYKBLh:=P000100001KB@00cPX005P0000d000000000000003oooooooooo`H0001QBLh:
ITWC2VI9f0YVBMh:HDWS2U]9h`Xm0000200001/0000@0000<DT00><:000f000040000359003S2P00
F00003@00000000000000?oooooooooo1P0002]9h`XVBMh:9TWH2RI9d`X[BLh:<DW>2SH0000@0000
<DT00<h:001H0000=000000000000000ooooooooool60000=dW>2S]9d`XkBMP:>dWN2SM9h`XaBN<:
?@0000P0000K0000400000I9003S2P00=P0001000006B@00h`X005P0000d000000000000003ooooo
ooooo`H00000BN<:ndSN2_]8f0[kB=<:04W>2PI9cPXf0000400000I9003>2P00F00003@000000000
00000?oooooooooo1P0000a9cPXABM<:4DWH2Q59gPX<BN<:1TWS2Sd0000800006`000100003KB000
h`X003H0000@0000fdP00><:001H0000=000000000000000ooooooooool60000eTSS2]58gP[AB=P:
dDSC2]I8cP[KB<h:=P000100003KB000cPX005P0000d000000000000003oooooooooo`H0003QB<h:
iTSC2^I8f0[VB=h:hDSS2]]8h`Xm0000200001/0000@0000/DP00><:000f000040000;58003S2P00
F00003@00000000000000?oooooooooo1P000:]8h`ZVB=h:YTSH2ZI8d`Z[B<h:/DS>2SH0000@0000
/DP00<h:001H0000=000000000000000ooooooooool60000]dS>2[]8d`ZkB=P:^dSN2[M8h`ZaB><:
?@0000P0000K0000400008I8003S2P00=P0001000026B000h`X005P0000d000000000000003ooooo
ooooo`H00020B><:NdSN2W]8f0YkB=<:P4S>2XI8cPXf0000400008I8003>2P00F00003@000000000
00000?oooooooooo1P0008a8cPZAB=<:TDSH2Y58gPZ<B><:QTSS2Sd0000800006`000100001KB000
h`X003H0000@0000FdP00><:001H0000=000000000000000ooooooooool60000EDSS2U58gPYAB=P:
DDSC2UE8cPYKB<h:=P000100001KB000cPX005P0000d000000000000003oooooooooo`H0001QB<h:
ITSC2VI8f0YVB=h:HDSS2U]8h`Xm0000200001/0000@0000<DP00><:000f000040000358003S2P00
F00003@00000000000000?oooooooooo1P0002]8h`XVB=h:9TSH2RI8d`X[B<h:<DS>2SH0000@0000
<DP00<h:001H0000=000000000000000ooooooooool60000=dS>2S]8d`XkB=P:>dSN2SM8h`XaB><:
?@0000P0000K0000400000I8003S2P00=P0001000006B000h`X005P0000d000000000000003ooooo
ooooo`H00000B><:ndON2_]7f0[kAm<:04S>2PI8cPXf0000400000I8003>2P00F00003@000000000
00000?oooooooooo1P0000a8cPXAB=<:4DSH2Q58gPX<B><:1TSS2Sd0000800006`000100003KA`00
h`X003H0000@0000fdL00><:001H0000=000000000000000ooooooooool60000eDOS2]57gP[AAmP:
dDOC2]E7cP[KAlh:=P000100003KA`00cPX005P0000d000000000000003oooooooooo`H0003QAlh:
iTOC2^I7f0[VAmh:hDOS2]]7h`Xm0000200001/0000@0000/DL00><:000f000040000;57003S2P00
F00003@00000000000000?oooooooooo1P000:]7h`ZVAmh:YTOH2ZI7d`Z[Alh:/DO>2SH0000@0000
/DL00<h:001H0000=000000000000000ooooooooool60000]dO>2[]7d`ZkAmP:^dON2[M7h`ZaAn<:
?@0000P0000K0000400008I7003S2P00=P0001000026A`00h`X005P0000d000000000000003ooooo
ooooo`H00020An<:NdON2W]7f0YkAm<:P4O>2XI7cPXf0000400008I7003>2P00F00003@000000000
00000?oooooooooo1P0008a7cPZAAm<:TDOH2Y57gPZ<An<:QTOS2Sd0000800006`000100001KA`00
h`X003H0000@0000FdL00><:001H0000=000000000000000ooooooooool60000EDOS2U57gPYAAmP:
DDOC2UE7cPYKAlh:=P000100001KA`00cPX005P0000d000000000000003oooooooooo`H0001QAlh:
ITOC2VI7f0YVAmh:HDOS2U]7h`Xm0000200001/0000@0000<DL00><:000f000040000357003S2P00
F00003@00000000000000?oooooooooo1P0002]7h`XVAmh:9TOH2RI7d`X[Alh:<DO>2SH0000@0000
<DL00<h:001H0000=000000000000000ooooooooool60000=TO>2S]7d`XkAmP:>dON2SI7h`XaAn<:
?@0000P0000K0000400000I7003S2P00=P0001000006A`00h`X005P0000d000000000000003ooooo
ooooo`H00000An<:ndKN2_]6f0[kA]<:04O>2PI7cPXf0000400000I7003>2P00F00003@000000000
00000?oooooooooo1P0000a7cPXAAm<:4DOH2Q57gPX<An<:1TOS2Sd0000800006`000100003KAP00
h`X003H0000@0000fdH00><:001H0000=000000000000000ooooooooool60000eDKS2]16gP[@A]P:
d4KC2]E6cP[KA/h:=P000100003KAP00cPX005P0000d000000000000003oooooooooo`H0003QA/h:
iTKC2^I6f0[VA]h:hDKS2]]6h`Xm0000200001/0000@0000/4H00><:000f000040000;16003S2P00
F00003@00000000000000?oooooooooo1P000:]6h`ZVA]h:YTKH2ZI6d`Z[A/h:/4K>2SH0000@0000
/4H00<h:001H0000=000000000000000ooooooooool60000]TK>2[]6d`ZkA]P:^dKN2[I6h`Z`A^<:
?@0000P0000K0000400008I6003S2P00=P0001000026AP00h`X005P0000d000000000000003ooooo
ooooo`H00020A^<:NdKN2W]6f0YkA]<:P4K>2XI6cPXf0000400008I6003>2P00F00003@000000000
00000?oooooooooo1P0008a6cPZ@A]<:T4KH2Y16gPZ<A^<:QTKS2Sd0000800006`000100001KAP00
h`X003H0000@0000FdH00><:001H0000=000000000000000ooooooooool60000EDKS2U16gPY@A]P:
D4KC2UE6cPYKA/h:=P000100001KAP00cPX005P0000d000000000000003oooooooooo`H0001QA/h:
ITKC2VI6f0YVA]h:HDKS2U]6h`Xm0000200001/0000@0000<4H00><:000f000040000316003S2P00
F00003@00000000000000?oooooooooo1P0002]6h`XVA]h:9TKH2RI6d`X[A/h:<4K>2SH0000@0000
<4H00<h:001H0000=000000000000000ooooooooool60000=TK>2S]6d`XkA]P:>dKN2SI6h`X`A^<:
?@0000P0000K0000400000I6003S2P00=P0001000006AP00h`X005P0000d000000000000003ooooo
ooooo`H00000A^<:ndGN2_]5f0[kAM<:04K>2PI6cPXf0000400000I6003>2P00F00003@000000000
00000?oooooooooo1P0000a6cPX@A]<:44KH2Q16gPX<A^<:1TKS2Sd0000800006`000100003KA@00
h`X003H0000@0000fdD00><:001H0000=000000000000000ooooooooool60000eDGS2]15gP[@AMP:
d4GC2]E5cP[KALh:=P000100003KA@00cPX005P0000d000000000000003oooooooooo`H0003QALh:
iTGC2^I5f0[VAMh:hDGS2]]5h`Xm0000200001/0000@0000/4D00><:000f000040000;15003S2P00
F00003@00000000000000?oooooooooo1P000:Y5h`ZVAMh:YTGH2ZI5d`ZZALh:/4G>2SH0000@0000
/4D00<h:001H0000=000000000000000ooooooooool60000]TG>2[]5d`ZkAMP:^dGN2[I5h`Z`AN<:
?@0000P0000K0000400008I5003S2P00=P0001000026A@00h`X005P0000d000000000000003ooooo
ooooo`H00020AN<:NdGN2W]5f0YkAM<:P4G>2XI5cPXf0000400008I5003>2P00F00003@000000000
00000?oooooooooo1P0008a5cPZ@AM<:T4GH2Y15gPZ<AN<:QTGS2Sd0000800006`000100001KA@00
h`X003H0000@0000FdD00><:001H0000=000000000000000ooooooooool60000EDGS2U15gPY@AMP:
D4GC2UE5cPYKALh:=P000100001KA@00cPX005P0000d000000000000003oooooooooo`H0001QALh:
ITGC2VI5f0YVAMh:HDGS2U]5h`Xm0000200001/0000@0000<4D00><:000f000040000315003S2P00
F00003@00000000000000?oooooooooo1P0002Y5h`XVAMh:9TGH2RI5d`XZALh:<4G>2SH0000@0000
<4D00<h:001H0000=000000000000000ooooooooool60000=TG>2S]5d`XkAMP:>dGN2SI5h`X`AN<:
?@0000P0000K0000400000I5003S2P00=P0001000006A@00h`X005P0000d000000000000003ooooo
ooooo`H00000AN<:ndCN2_]4f0[kA=<:04G>2PI5cPXf0000400000I5003>2P00F00003@000000000
00000?oooooooooo1P0000a5cPX@AM<:44GH2Q15gPX<AN<:1TGS2Sd0000800006`000100003KA000
h`X003H0000@0000fd@00><:001H0000=000000000000000ooooooooool60000eDCS2]14gP[@A=P:
d4CC2]E4cP[KA<h:=P000100003KA000cPX005P0000d000000000000003oooooooooo`H0003QA<h:
iTCC2^I4f0[VA=h:hDCS2]]4h`Xm0000200001/0000@0000/4@00><:000f000040000;14003S2P00
F00003@00000000000000?oooooooooo1P000:Y4h`ZVA=h:YTCH2ZI4d`ZZA<h:/4C>2SH0000@0000
/4@00<h:001H0000=000000000000000ooooooooool60000]TC>2[]4d`ZkA=P:^dCN2[I4h`Z`A><:
?@0000P0000K0000400008I4003S2P00=P0001000026A000h`X005P0000d000000000000003ooooo
ooooo`H00020A><:NdCN2W]4f0YkA=<:P4C>2XI4cPXf0000400008I4003>2P00F00003@000000000
00000?oooooooooo1P0008]4cPZ@A=<:T4CH2Y14gPZ;A><:QTCS2Sd0000800006`000100001KA000
h`X003H0000@0000Fd@00><:001H0000=000000000000000ooooooooool60000EDCS2U14gPY@A=P:
D4CC2UE4cPYKA<h:=P000100001KA000cPX005P0000d000000000000003oooooooooo`H0001QA<h:
ITCC2VI4f0YVA=h:HDCS2U]4h`Xm0000200001/0000@0000<4@00><:000f000040000314003S2P00
F00003@00000000000000?oooooooooo1P0002Y4h`XUA=h:9DCH2RE4d`XZA<h:<4C>2SH0000@0000
<4@00<h:001H0000=000000000000000ooooooooool60000=TC>2S]4d`XkA=P:>dCN2SI4h`X`A><:
?@0000P0000K0000400000E4003S2P00=P0001000005A000h`X005P0000d000000000000003ooooo
ooooo`H00000A><:nd?N2_]3f0[k@m<:04C>2PE4cPXf0000400000E4003>2P00F00003@000000000
00000?oooooooooo1P0000]4cPX@A=<:44CH2Q14gPX;A><:1DCS2Sd0000800006`000100003K@`00
h`X003H0000@0000fd<00><:001H0000=000000000000000ooooooooool60000eD?S2]13gP[@@mP:
d4?C2]E3cP[K@lh:=P000100003K@`00cPX005P0000d000000000000003oooooooooo`H0003Q@lh:
iD?C2^E3f0[U@mh:hD?S2]]3h`Xm0000200001/0000@0000/4<00><:000f000040000;13003S2P00
F00003@00000000000000?oooooooooo1P000:Y3h`ZU@mh:YD?H2ZE3d`ZZ@lh:/4?>2SH0000@0000
/4<00<h:001H0000=000000000000000ooooooooool60000]T?>2[]3d`Zk@mP:^d?N2[I3h`Z`@n<:
?@0000P0000K0000400008E3003S2P00=P0001000025@`00h`X005P0000d000000000000003ooooo
ooooo`H00020@n<:Nd?N2W]3f0Yk@m<:P4?>2XE3cPXf0000400008E3003>2P00F00003@000000000
00000?oooooooooo1P0008]3cPZ@@m<:T4?H2Y13gPZ;@n<:QD?S2Sd0000800006`000100001K@`00
h`X003H0000@0000Fd<00><:001H0000=000000000000000ooooooooool60000ED?S2U13gPY@@mP:
D4?C2UE3cPYK@lh:=P000100001K@`00cPX005P0000d000000000000003oooooooooo`H0001Q@lh:
ID?C2VE3f0YU@mh:HD?S2U]3h`Xm0000200001/0000@0000<4<00><:000f000040000313003S2P00
F00003@00000000000000?oooooooooo1P0002Y3h`XU@mh:9D?H2RE3d`XZ@lh:<4?>2SH0000@0000
<4<00<h:001H0000=000000000000000ooooooooool60000=T?>2S]3d`Xk@mP:>d?N2SI3h`X`@n<:
?@0000P0000K0000400000E3003S2P00=P0001000005@`00h`X005P0000d000000000000003ooooo
ooooo`H0003o@^<:nd;N2_]2f0[k@]<:od;>2PE3cPXf0000400000E3003>2P00F00003@000000000
00000?oooooooooo1P0000]3cPX@@m<:44?H2Q13gPX;@n<:1D?S2Sd0000800006`000100003K@P00
h`X003H0000@0000fd800><:001H0000=000000000000000ooooooooool60000eD;S2]12gP[@@]P:
d4;C2]E2cP[K@/h:=P000100003K@P00cPX005P0000d000000000000003oooooooooo`H0003Q@/h:
iD;C2^E2f0[U@]h:hD;S2]]2h`Xm0000200001/0000@0000/4800><:000f000040000;12003S2P00
F00003@00000000000000?oooooooooo1P000:Y2h`ZU@]h:YD;H2ZE2d`ZZ@/h:/4;>2SH0000@0000
/4800<h:001H0000=000000000000000ooooooooool60000]T;>2[]2d`Zk@]P:^d;N2[I2h`Z`@^<:
?@0000P0000K0000400008E2003S2P00=P0001000025@P00h`X005P0000d000000000000003ooooo
ooooo`H0001o@^<:Nd;N2W]2f0Yk@]<:Od;>2XE2cPXf0000400008E2003>2P00F00003@000000000
00000?oooooooooo1P0008]2cPZ@@]<:T4;H2Y12gPZ;@^<:QD;S2Sd0000800006`000100001K@P00
h`X003H0000@0000Fd800><:001H0000=000000000000000ooooooooool60000ED;S2U12gPY@@]P:
D4;C2UE2cPYK@/h:=P000100001K@P00cPX005P0000d000000000000003oooooooooo`H0001Q@/h:
ID;C2VE2f0YU@]h:HD;S2U]2h`Xm0000200001/0000@0000<4800><:000f000040000312003S2P00
F00003@00000000000000?oooooooooo1P0002Y2h`XU@]h:9D;H2RE2d`XZ@/h:<4;>2SH0000@0000
<4800<h:001H0000=000000000000000ooooooooool60000=T;>2S]2d`Xk@]P:>d;N2SI2h`X`@^<:
?@0000P0000K0000400000E2003S2P00=P0001000005@P00h`X005P0000d000000000000003ooooo
ooooo`H0003o@N<:nd7N2_]1f0[k@M<:od7>2PE2cPXf0000400000E2003>2P00F00003@000000000
00000?oooooooooo1P0000]2cPX@@]<:44;H2Q12gPX;@^<:1D;S2Sd0000800006`000100003K@@00
h`X003H0000@0000fd400><:001H0000=000000000000000ooooooooool60000eD7S2]11gP[@@MP:
d47C2]E1cP[K@Lh:=P000100003K@@00cPX005P0000d000000000000003oooooooooo`H0003P@Lh:
iD7C2^E1f0[U@Mh:h47S2]]1h`Xm0000200001/0000@0000/4400><:000f000040000;11003S2P00
F00003@00000000000000?oooooooooo1P000:Y1h`ZU@Mh:YD7H2ZE1d`ZZ@Lh:/47>2SH0000@0000
/4400<h:001H0000=000000000000000ooooooooool60000]T7>2[]1d`Zk@MP:^d7N2[I1h`Z`@N<:
?@0000P0000K0000400008E1003S2P00=P0001000025@@00h`X005P0000d000000000000003ooooo
ooooo`H0001o@N<:NT7N2WY1f0Yj@M<:Od7>2XE1cPXf0000400008E1003>2P00F00003@000000000
00000?oooooooooo1P0008]1cPZ@@M<:T47H2Y11gPZ;@N<:QD7S2Sd0000800006`000100001J@@00
h`X003H0000@0000FT400><:001H0000=000000000000000ooooooooool60000ED7S2U11gPY@@MP:
D47C2UE1cPYJ@Lh:=P000100001J@@00cPX005P0000d000000000000003oooooooooo`H0001P@Lh:
ID7C2VE1f0YU@Mh:H47S2UY1h`Xm0000200001/0000@0000<4400><:000f000040000311003S2P00
F00003@00000000000000?oooooooooo1P0002Y1h`XU@Mh:9D7H2RE1d`XZ@Lh:<47>2SH0000@0000
<4400<h:001H0000=000000000000000ooooooooool60000=T7>2SY1d`Xj@MP:>T7N2SI1h`X`@N<:
?@0000P0000K0000400000E1003S2P00=P0001000005@@00h`X005P0000d000000000000003ooooo
ooooo`H0003o@><:nT3N2_Y0f0[j@=<:od3>2PE1cPXf0000400000E1003>2P00F00003@000000000
00000?oooooooooo1P0000]1cPX@@M<:447H2Q11gPX;@N<:1D7S2Sd0000800006`000100003J@000
h`X003H0000@0000fT000><:001H0000=000000000000000ooooooooool60000eD3S2]10gP[@@=P:
d43C2]E0cP[J@<h:=P000100003J@000cPX005P0000d000000000000003oooooooooo`H0003P@<h:
iD3C2^E0f0[U@=h:h43S2]Y0h`Xm0000200001/0000@0000/4000><:000f000040000;10003S2P00
F00003@00000000000000?oooooooooo1P000:Y0h`ZU@=h:YD3H2ZE0d`ZZ@<h:/43>2SH0000@0000
/4000<h:001H0000=000000000000000ooooooooool60000]T3>2[Y0d`Zj@=P:^T3N2[I0h`Z`@><:
?@0000P0000K0000400008E0003S2P00=P0001000025@000h`X005P0000d000000000000003ooooo
ooooo`H0001o@><:NT3N2WY0f0Yj@=<:Od3>2XE0cPXf0000400008E0003>2P00F00003@000000000
00000?oooooooooo1P0008]0cPZ@@=<:T43H2Y10gPZ;@><:QD3S2Sd0000800006`000100001J@000
h`X003H0000@0000FT000><:001H0000=000000000000000ooooooooool60000E43S2U10gPY@@=P:
D43C2UA0cPYJ@<h:=P000100001J@000cPX005P0000d000000000000003oooooooooo`H0001P@<h:
ID3C2VE0f0YU@=h:H43S2UY0h`Xm0000200001/0000@0000<4000><:000f000040000310003S2P00
F00003@00000000000000?oooooooooo1P0002Y0h`XU@=h:9D3H2RE0d`XZ@<h:<43>2SH0000@0000
<4000<h:001H0000=000000000000000ooooooooool60000=T3>2SY0d`Xj@=P:>T3N2SI0h`X`@><:
?@0000P0000K0000400000E0003S2P00=P0001000005@000h`X005P0000d000000000000003ooooo
ooooo`H0003o?n<:nSoN2_Xof0[j?m<:oco>2PE0cPXf0000400000E0003>2P00F00003@000000000
00000?oooooooooo1P0000]0cPX@@=<:443H2Q10gPX;@><:1D3S2Sd0000800006`000100003J?`00
h`X003H0000@0000fSl00><:001H0000=000000000000000ooooooooool60000e3oS2]0ogP[@?mP:
d3oC2]@ocP[J?lh:=P000100003J?`00cPX005P0000d000000000000003oooooooooo`H0003P?lh:
iCoC2^Dof0[U?mh:h3oS2]Xoh`Xm0000200001/0000@0000/3l00><:000f000040000;0o003S2P00
F00003@00000000000000?oooooooooo1P000:Xoh`ZU?mh:YCoH2ZDod`ZZ?lh:/3o>2SH0000@0000
/3l00<h:001H0000=000000000000000ooooooooool60000]So>2[Xod`Zj?mP:^SoN2[Hoh`Z`?n<:
?@0000P0000K0000400008Do003S2P00=P0001000025?`00h`X005P0000d000000000000003ooooo
ooooo`H0001o?n<:NSoN2WXof0Yj?m<:Oco>2XDocPXf0000400008Do003>2P00F00003@000000000
00000?oooooooooo1P0008/ocPZ@?m<:T3oH2Y0ogPZ;?n<:QCoS2Sd0000800006`000100001J?`00
h`X003H0000@0000FSl00><:001H0000=000000000000000ooooooooool60000E3oS2U0ogPY@?mP:
D3oC2U@ocPYJ?lh:=P000100001J?`00cPX005P0000d000000000000003oooooooooo`H0001P?lh:
ICoC2VDof0YU?mh:H3oS2UXoh`Xm0000200001/0000@0000<3l00><:000f00004000030o003S2P00
F00003@00000000000000?oooooooooo1P0002Xoh`XU?mh:9CoH2RDod`XZ?lh:<3o>2SH0000@0000
<3l00<h:001H0000=000000000000000ooooooooool60000=Co>2SXod`Xj?mP:>SoN2SDoh`X`?n<:
?@0000P0000K0000400000Do003S2P00=P0001000005?`00h`X005P0000d000000000000003ooooo
ooooo`H0003o?^<:nSkN2_Xnf0[j?]<:ock>2PDocPXf0000400000Do003>2P00F00003@000000000
00000?oooooooooo1P0000/ocPX@?m<:43oH2Q0ogPX;?n<:1CoS2Sd0000800006`000100003J?P00
h`X003H0000@0000fSh00><:001H0000=000000000000000ooooooooool60000e3kS2/lngP[??]P:
cckC2]@ncP[J?/h:=P000100003J?P00cPX005P0000d000000000000003oooooooooo`H0003P?/h:
iCkC2^Dnf0[U?]h:h3kS2]Xnh`Xm0000200001/0000@0000[ch00><:000f000040000:ln003S2P00
F00003@00000000000000?oooooooooo1P000:Xnh`ZU?]h:YCkH2ZDnd`ZZ?/h:[ck>2SH0000@0000
[ch00<h:001H0000=000000000000000ooooooooool60000]Ck>2[Xnd`Zj?]P:^SkN2[Dnh`Z_?^<:
?@0000P0000K0000400008Dn003S2P00=P0001000025?P00h`X005P0000d000000000000003ooooo
ooooo`H0001o?^<:NSkN2WXnf0Yj?]<:Ock>2XDncPXf0000400008Dn003>2P00F00003@000000000
00000?oooooooooo1P0008/ncPZ??]<:SckH2XlngPZ;?^<:QCkS2Sd0000800006`000100001J?P00
h`X003H0000@0000FSh00><:001H0000=000000000000000ooooooooool60000E3kS2TlngPY??]P:
CckC2U@ncPYJ?/h:=P000100001J?P00cPX005P0000d000000000000003oooooooooo`H0001P?/h:
ICkC2VDnf0YU?]h:H3kS2UXnh`Xm0000200001/0000@0000;ch00><:000f0000400002ln003S2P00
F00003@00000000000000?oooooooooo1P0002Xnh`XU?]h:9CkH2RDnd`XZ?/h:;ck>2SH0000@0000
;ch00<h:001H0000=000000000000000ooooooooool60000=Ck>2SXnd`Xj?]P:>SkN2SDnh`X_?^<:
?@0000P0000K0000400000Dn003S2P00=P0001000005?P00h`X005P0000d000000000000003ooooo
ooooo`H0003o?N<:nSgN2_Xmf0[j?M<:ocg>2PDncPXf0000400000Dn003>2P00F00003@000000000
00000?oooooooooo1P0000/ncPX??]<:3ckH2PlngPX;?^<:1CkS2Sd0000800006`000100003J?@00
h`X003H0000@0000fSd00><:001H0000=000000000000000ooooooooool60000e3gS2/lmgP[??MP:
ccgC2]@mcP[J?Lh:=P000100003J?@00cPX005P0000d000000000000003oooooooooo`H0003P?Lh:
iCgC2^Dmf0[U?Mh:h3gS2]Xmh`Xm0000200001/0000@0000[cd00><:000f000040000:lm003S2P00
F00003@00000000000000?oooooooooo1P000:Tmh`ZU?Mh:YCgH2ZDmd`ZY?Lh:[cg>2SH0000@0000
[cd00<h:001H0000=000000000000000ooooooooool60000]Cg>2[Xmd`Zj?MP:^SgN2[Dmh`Z_?N<:
?@0000P0000K0000400008Dm003S2P00=P0001000025?@00h`X005P0000d000000000000003ooooo
ooooo`H0001o?N<:NSgN2WXmf0Yj?M<:Ocg>2XDmcPXf0000400008Dm003>2P00F00003@000000000
00000?oooooooooo1P0008/mcPZ??M<:ScgH2XlmgPZ;?N<:QCgS2Sd0000800006`000100001J?@00
h`X003H0000@0000FSd00><:001H0000=000000000000000ooooooooool60000E3gS2TlmgPY??MP:
CcgC2U@mcPYJ?Lh:=P000100001J?@00cPX005P0000d000000000000003oooooooooo`H0001P?Lh:
ICgC2VDmf0YU?Mh:H3gS2UXmh`Xm0000200001/0000@0000;cd00><:000f0000400002lm003S2P00
F00003@00000000000000?oooooooooo1P0002Tmh`XU?Mh:9CgH2RDmd`XY?Lh:;cg>2SH0000@0000
;cd00<h:001H0000=000000000000000ooooooooool60000=Cg>2SXmd`Xj?MP:>SgN2SDmh`X_?N<:
?@0000P0000K0000400000Dm003S2P00=P0001000005?@00h`X005P0000d000000000000003ooooo
ooooo`H0003o?><:nScN2_Xlf0[j?=<:occ>2PDmcPXf0000400000Dm003>2P00F00003@000000000
00000?oooooooooo1P0000/mcPX??M<:3cgH2PlmgPX;?N<:1CgS2Sd0000800006`000100003J?000
h`X003H0000@0000fS`00><:001H0000=000000000000000ooooooooool60000e3cS2/llgP[??=P:
cccC2]@lcP[J?<h:=P000100003J?000cPX005P0000d000000000000003oooooooooo`H0003P?<h:
iCcC2^Dlf0[U?=h:h3cS2]Xlh`Xm0000200001/0000@0000[c`00><:000f000040000:ll003S2P00
F00003@00000000000000?oooooooooo1P000:Tlh`ZU?=h:YCcH2ZDld`ZY?<h:[cc>2SH0000@0000
[c`00<h:001H0000=000000000000000ooooooooool60000]Cc>2[Xld`Zj?=P:^ScN2[Dlh`Z_?><:
?@0000P0000K0000400008Dl003S2P00=P0001000025?000h`X005P0000d000000000000003ooooo
ooooo`H0001o?><:NScN2WXlf0Yj?=<:Occ>2XDlcPXf0000400008Dl003>2P00F00003@000000000
00000?oooooooooo1P0008XlcPZ??=<:SccH2XllgPZ:?><:QCcS2Sd0000800006`0001000023?000
m`X003H0000@0000Pc`00?L:001H0000=000000000000000ooooooooool60000Pccm2Whl0P]h?08;
Lc`22fhlo@Y^??L:=P000100001^?000m`X005P0000d000000000000003oooooooooo`H0001^??4:
Lcc/2WPlk0Yn?>`:Pcca2X<lm`Xm0000200001/0000@0000Pc`0028;000f0000400008<l000R2`00
F00003@00000000000000?oooooooooo1P0008<l:0]n?2`;N3`/2g<l;0]^?2P;KS`R2cH0000@0000
KS`0028;001H0000=000000000000000ooooooooool60000KS`L2g<l5`]h?1L;OS`G2h<l70^3?28;
?@0000P0000K0000400008<l001<2`00=P0001000023?000C0/005P0000d000000000000003ooooo
ooooo`H00023?58;OSaG2gPlE`]c?5L;KSaB2fhlC0/f0000400006hl001<2`00F00003@000000000
00000?oooooooooo1P0006hlA`]c?48;N3a22ghl@P^3?4L;Pca<2cd0000800006`0001000023?000
M`/003H0000@0000Pc`007L;001H0000=000000000000000ooooooooool60000Pcam2ghlPP]h?88;
Lcb22fhlO@]^?7L;=P000100001^?000M`/005P0000d000000000000003oooooooooo`H0001^?74;
Lca/2gPlK0]n?6`;Pcaa2h<lM`/m0000200001/0000@0000Pc`00:8;000f0000400008<l002R2`00
F00003@00000000000000?oooooooooo1P0008<lZ0]n?:d;N3b]2g<l[@]^?:P;KSbR2cH0000@0000
KS`00:8;001H0000=000000000000000ooooooooool60000KSbL2g<lU`]h?9L;OSbG2h<lW0^3?:8;
?@0000P0000K0000400008<l003=2`00=P0001000023?000c@/005P0000d000000000000003ooooo
ooooo`H00023?=8;OScG2gPle`]c?=L;KScB2fhlc@/f0000400006hl003=2`00F00003@000000000
00000?oooooooooo1P0006hla`]c?<8;N3c22ghl`P^3?<L;Pcc=2cd0000800006`0001000023?000
m`/003H0000@0000Pc`00?L;001H0000=000000000000000ooooooooool60000Pccm2ghl0Pah?08<
Lc`236hlo@]^??L;=P000100001^?000m`/005P0000d000000000000003oooooooooo`H0001^??4;
Lcc]2gPlk@]n?>d;Pcca2h<lm`/m0000200001/0000@0000Pc`0028<000f0000400008<l000R3000
F00003@00000000000000?oooooooooo1P0008<l:0an?2d<N3`]37<l;@a^?2P<KS`R33H0000@0000
KS`0028<001H0000=000000000000000ooooooooool60000KS`L37<l5`ah?1L<OS`G38<l70b3?28<
?@0000P0000K0000400008<l001=3000=P0001000023?000C@`005P0000d000000000000003ooooo
ooooo`H00023?58<OSaG37PlE`ac?5L<KSaB36hlC@`f0000400006hl001=3000F00003@000000000
00000?oooooooooo1P0006hlA`ac?48<N3a237hl@Pb3?4L<Pca=33d0000800006`0001000023?000
M``003H0000@0000Pc`007L<001H0000=000000000000000ooooooooool60000Pcam37hlPPah?88<
Lcb236hlO@a^?7L<=P000100001^?000M``005P0000d000000000000003oooooooooo`H0001^?74<
Lca]37PlK@an?6d<Pcaa38<lM``m0000200001/0000@0000Pc`00:8<000f0000400008<l002R3000
F00003@00000000000000?oooooooooo1P0008<lZ0an?:d<N3b]37<l[@a^?:P<KSbR33H0000@0000
KS`00:8<001H0000=000000000000000ooooooooool60000KSbL37<lU`ah?9L<OSbG38<lW0b3?:8<
?@0000P0000K0000400008<l003=3000=P0001000023?000c@`005P0000d000000000000003ooooo
ooooo`H00023?=<<OScG37Ple`ac?=L<KScC36hlc@`f0000400006hl003=3000F00003@000000000
00000?oooooooooo1P0006hla`ac?<8<N3c237hl`Pb3?<L<Pcc=33d0000800006`0001000023?000
m``003H0000@0000Pc`00?L<001H0000=000000000000000ooooooooool60000Pccm37hl0Peh?08=
Lc`23Fhlo@a^??L<=P000100001^?000m``005P0000d000000000000003oooooooooo`H0001^??4<
Lcc]37Plk@an?>d<Pcca38<lm``m0000200001/0000@0000Pc`0028=000f0000400008<l000R3@00
F00003@00000000000000?oooooooooo1P0008<l:0en?2d=N3`]3G<l;@e^?2P=KS`R3CH0000@0000
KS`0028=001H0000=000000000000000ooooooooool60000KS`L3G<l5`eh?1L=OS`G3H<l70f3?28=
?@0000P0000K0000400008<l001=3@00=P0001000023?000C@d005P0000d000000000000003ooooo
ooooo`H00023?5<=OSaG3GPlE`ec?5L=KSaC3FhlC@df0000400006hl001=3@00F00003@000000000
00000?oooooooooo1P0006hlA`ec?48=N3a23Ghl@Pf3?4L=Pca=3Cd0000800006`0001000023?000
M`d003H0000@0000Pc`007L=001H0000=000000000000000ooooooooool60000Pcam3GhlPPeh?88=
Lcb23FhlO@e^?7L==P000100001^?000M`d005P0000d000000000000003oooooooooo`H0001^?74=
Lca]3GPlK@en?6d=Pcaa3H<lM`dm0000200001/0000@0000Pc`00:8=000f0000400008<l002R3@00
F00003@00000000000000?oooooooooo1P0008<lZ0en?:d=N3b]3G<l[@e^?:P=KSbR3CH0000@0000
KS`00:8=001H0000=000000000000000ooooooooool60000KSbL3G<lU`eh?9L=OSbG3H<lW0f3?:8=
?@0000P0000K0000400008<l003=3@00=P0001000023?000c@d005P0000d000000000000003ooooo
ooooo`H00023?=<=OScG3GPle`ec?=L=KScC3Fhlc@df0000400006hl003=3@00F00003@000000000
00000?oooooooooo1P0006hla`ec?<8=N3c23Ghl`Pf3?<L=Pcc=3Cd0000800006`0001000023?000
m`d003H0000@0000Pc`00?L=001H0000=000000000000000ooooooooool60000Pccm3Ghl0Pih?08>
Lc`23Vhlo@e^??L==P000100001^?000m`d005P0000d000000000000003oooooooooo`H0001^??8=
Lcc]3GPlk@en?>d=Pccb3H<lm`dm0000200001/0000@0000Pc`0028>000f0000400008<l000R3P00
F00003@00000000000000?oooooooooo1P0008<l:0in?2d>N3`]3W<l;@i^?2P>KS`R3SH0000@0000
KS`0028>001H0000=000000000000000ooooooooool60000KS`L3W<l5`ih?1L>OS`G3X<l70j3?28>
?@0000P0000K0000400008<l001=3P00=P0001000023?000C@h005P0000d000000000000003ooooo
ooooo`H00023?5<>OSaH3WPlF0ic?5P>KSaC3VhlC@hf0000400006hl001=3P00F00003@000000000
00000?oooooooooo1P0006hlA`ic?48>N3a23Whl@Pj3?4L>Pca=3Sd0000800006`0001000023?000
N0h003H0000@0000Pc`007P>001H0000=000000000000000ooooooooool60000Pcam3WhlPPih?88>
Lcb23VhlO@i^?7P>=P000100001^?000N0h005P0000d000000000000003oooooooooo`H0001^?78>
Lca]3WPlK@in?6d>Pcab3X<lN0hm0000200001/0000@0000Pc`00:8>000f0000400008<l002R3P00
F00003@00000000000000?oooooooooo1P0008<lZ0in?:d>N3b]3W<l[@i^?:P>KSbR3SH0000@0000
KS`00:8>001H0000=000000000000000ooooooooool60000KSbL3W<lV0ih?9P>OSbH3X<lW0j3?:8>
?@0000P0000K0000400008<l003=3P00=P0001000023?000c@h005P0000d000000000000003ooooo
ooooo`H00023?=<>OScH3WPlf0ic?=P>KScC3Vhlc@hf0000400006hl003=3P00F00003@000000000
00000?oooooooooo1P0006hla`ic?<8>N3c23Whl`Pj3?<L>Pcc=3Sd0000800006`0001000023?000
n0h003H0000@0000Pc`00?P>001H0000=000000000000000ooooooooool60000Pccm3Whl0Pmh?08?
Lc`23fhlo@i^??P>=P000100001^?000n0h005P0000d000000000000003oooooooooo`H0001^??8>
Lcc]3WPlk@in?>d>Pccb3X<ln0hm0000200001/0000@0000Pc`0028?000f0000400008<l000R3`00
F00003@00000000000000?oooooooooo1P0008<l:0mn?2d?N3`]3g<l;@m^?2P?KS`R3cH0000@0000
KS`0028?001H0000=000000000000000ooooooooool60000KS`L3g<l60mh?1P?OS`H3h<l70n3?28?
?@0000P0000K0000400008<l001=3`00=P0001000023?000C@l005P0000d000000000000003ooooo
ooooo`H00023?5<?OSaH3gPlF0mc?5P?KSaC3fhlC@lf0000400006hl001=3`00F00003@000000000
00000?oooooooooo1P0006hlA`mc?48?N3a23ghl@Pn3?4L?Pca=3cd0000800006`0001000023?000
N0l003H0000@0000Pc`007P?001H0000=000000000000000ooooooooool60000Pcan3ghlPPmh?88?
Lcb23fhlOPm^?7P?=P000100001^?000N0l005P0000d000000000000003oooooooooo`H0001^?78?
Lca]3gPlK@mn?6d?Pcab3h<lN0lm0000200001/0000@0000Pc`00:8?000f0000400008<l002R3`00
F00003@00000000000000?oooooooooo1P0008<lZ0mn?:d?N3b]3g<l[@m^?:P?KSbR3cH0000@0000
KS`00:8?001H0000=000000000000000ooooooooool60000KSbL3g<lV0mh?9P?OSbH3h<lW0n3?:8?
?@0000P0000K0000400008<l003=3`00=P0001000023?000c@l005P0000d000000000000003ooooo
ooooo`H00023?=<?OScH3gPlf0mc?=P?KScC3fhlc@lf0000400006hl003=3`00F00003@000000000
00000?oooooooooo1P0006hla`mc?<8?N3c23ghl`Pn3?<L?Pcc=3cd0000800006`0001000023?000
n0l003H0000@0000Pc`00?P?001H0000=000000000000000ooooooooool60000Pccn3ghl0Q1h?08@
Lc`246hloPm^??P?=P000100001^?000n0l005P0000d000000000000003oooooooooo`H0001^??8?
Lcc]3gPlk@mn?>d?Pccb3h<ln0lm0000200001/0000@0000Pc`0028@000f0000400008<l000R4000
F00003@00000000000000?oooooooooo1P0008<l:11n?2d@N3`]47<l;A1^?2P@KS`R43H0000@0000
KS`0028@001H0000=000000000000000ooooooooool60000KS`M47<l611h?1P@OS`H48<l7A23?28@
?@0000P0000K0000400008<l001=4000=P0001000023?000CA0005P0000d000000000000003ooooo
ooooo`H00023?5<@OSaH47PlF11c?5P@KSaC46hlCA0f0000400006hl001=4000F00003@000000000
00000?oooooooooo1P0006hlAa1c?48@N3a247hl@Q23?4L@Pca=43d0000800006`0001000023?000
N10003H0000@0000Pc`007P@001H0000=000000000000000ooooooooool60000Pcan47hlPQ1h?88@
Lcb246hlOQ1^?7P@=P000100001^?000N10005P0000d000000000000003oooooooooo`H0001^?78@
Lca]47PlKA1n?6d@Pcab48<lN10m0000200001/0000@0000Pc`00:8@000f0000400008<l002R4000
F00003@00000000000000?oooooooooo1P0008<lZ11n?:d@N3b]47<l[A1^?:P@KSbR43H0000@0000
KS`00:8@001H0000=000000000000000ooooooooool60000KSbM47<lV11h?9P@OSbH48<lWA23?:8@
?@0000P0000K0000400008<l003=4000=P0001000023?000cA0005P0000d000000000000003ooooo
ooooo`H00023?=<@OScH47Plf11c?=P@KScC46hlcA0f0000400006hl003=4000F00003@000000000
00000?oooooooooo1P0006hlaa1c?<8@N3c247hl`Q23?<L@Pcc=43d0000800006`0001000023?000
n10003H0000@0000Pc`00?P@001H0000=000000000000000ooooooooool60000Pccn47hl0a5h?0<A
Lc`34FhloQ1^??P@=P000100001^?000n10005P0000d000000000000003oooooooooo`H0001^??8@
Lcc]47PlkA1n?>d@Pccb48<ln10m0000200001/0000@0000Pc`002<A000f0000400008<l000S4@00
F00003@00000000000000?oooooooooo1P0008<l:15n?2dAN3`]4G<l;A5^?2PAKS`S4CH0000@0000
KS`002<A001H0000=000000000000000ooooooooool60000KS`M4G<l615h?1PAOS`H4H<l7A63?2<A
?@0000P0000K0000400008<l001=4@00=P0001000023?000CA4005P0000d000000000000003ooooo
ooooo`H00023?5<AOSaH4GPlF15c?5PAKSaC4FhlCA4f0000400006hl001=4@00F00003@000000000
00000?oooooooooo1P0006hlAa5c?4<AN3a34Ghl@a63?4LAPca=4Cd0000800006`0001000023?000
N14003H0000@0000Pc`007PA001H0000=000000000000000ooooooooool60000Pcan4GhlPa5h?8<A
Lcb34FhlOQ5^?7PA=P000100001^?000N14005P0000d000000000000003oooooooooo`H0001^?78A
Lca]4GPlKA5n?6dAPcab4H<lN14m0000200001/0000@0000Pc`00:<A000f0000400008<l002S4@00
F00003@00000000000000?oooooooooo1P0008<lZ15n?:dAN3b]4G<l[A5^?:PAKSbS4CH0000@0000
KS`00:<A001H0000=000000000000000ooooooooool60000KSbM4G<lV15h?9PAOSbH4H<lWA63?:<A
?@0000P0000K0000400008<l003=4@00=P0001000023?000cA4005P0000d000000000000003ooooo
ooooo`H00023?=<AOScH4GPlf15c?=PAKScC4FhlcA4f0000400006hl003=4@00F00003@000000000
00000?oooooooooo1P0006hlaa5c?<<AN3c34Ghl`a63?<LAPcc=4Cd0000800006`0001000023?000
n14003H0000@0000Pc`00?PA001H0000=000000000000000ooooooooool60000Pccn4Ghl0a9h?0<B
Lc`34VhloQ5^??PA=P000100001^?000n14005P0000d000000000000003oooooooooo`H0001^??8A
Lcc]4GPlkA5n?>dAPccb4H<ln14m0000200001/0000@0000Pc`002<B000f0000400008<l000S4P00
F00003@00000000000000?oooooooooo1P0008<l:A9n?2dBN3`]4W<l;A9^?2TBKS`S4SH0000@0000
KS`002<B001H0000=000000000000000ooooooooool60000KS`M4W<l619h?1PBOS`H4X<l7A:3?2<B
?@0000P0000K0000400008<l001=4P00=P0001000023?000CA8005P0000d000000000000003ooooo
ooooo`H00023?5<BOSaH4WPlF19c?5PBKSaC4VhlCA8f0000400006hl001=4P00F00003@000000000
00000?oooooooooo1P0006hlAa9c?4<BN3a34Whl@a:3?4LBPca=4Sd0000800006`0001000023?000
N18003H0000@0000Pc`007PB001H0000=000000000000000ooooooooool60000Pcan4WhlPa9h?8<B
Lcb34VhlOQ9^?7PB=P000100001^?000N18005P0000d000000000000003oooooooooo`H0001^?78B
Lca]4WPlKA9n?6dBPcab4X<lN18m0000200001/0000@0000Pc`00:<B000f0000400008<l002S4P00
F00003@00000000000000?oooooooooo1P0008<lZA9n?:dBN3b]4W<l[A9^?:TBKSbS4SH0000@0000
KS`00:<B001H0000=000000000000000ooooooooool60000KSbM4W<lV19h?9PBOSbH4X<lWA:3?:<B
?@0000P0000K0000400008<l003=4P00=P0001000023?000cA8005P0000d000000000000003ooooo
ooooo`H00023?=<BOScH4WPlf19c?=PBKScC4VhlcA8f0000400006hl003=4P00F00003@000000000
00000?oooooooooo1P0006hlb19c?<<BN3c34Whl`a:3?<PBPcc=4Sd0000800006`0001000023?000
n18003H0000@0000Pc`00?PB001H0000=000000000000000ooooooooool60000Pccn4Whl0a=h?0<C
Lc`34fhloQ9^??PB=P000100001^?000n18005P0000d000000000000003oooooooooo`H0001^??8B
Lcc]4WPlkA9n?>dBPccb4X<ln18m0000200001/0000@0000Pc`002<C000f0000400008<l000S4`00
F00003@00000000000000?oooooooooo1P0008<l:A=n?2dCN3`]4g<l;A=^?2TCKS`S4cH0000@0000
KS`002<C001H0000=000000000000000ooooooooool60000KS`M4g<l61=h?1PCOS`H4h<l7A>3?2<C
?@0000P0000K0000400008<l001=4`00=P0001000023?000CA<005P0000d000000000000003ooooo
ooooo`H00023?5<COSaH4gPlF1=c?5PCKSaC4fhlCA<f0000400006hl001=4`00F00003@000000000
00000?oooooooooo1P0006hlB1=c?4<CN3a34ghl@a>3?4PCPca=4cd0000800006`0001000023?000
N1<003H0000@0000Pc`007PC001H0000=000000000000000ooooooooool60000Pcan4ghlPa=h?8<C
Lcb34fhlOQ=^?7PC=P000100001^?000N1<005P0000d000000000000003oooooooooo`H0001^?78C
Lca]4gPlKA=n?6dCPcab4h<lN1<m0000200001/0000@0000Pc`00:<C000f0000400008<l002S4`00
F00003@00000000000000?oooooooooo1P0008<lZA=n?:hCN3b^4g<l[Q=^?:TCKSbS4cH0000@0000
KS`00:<C001H0000=000000000000000ooooooooool60000KSbM4g<lV1=h?9PCOSbH4h<lWA>3?:<C
?@0000P0000K0000400008<l003>4`00=P0001000023?000cQ<005P0000d000000000000003ooooo
ooooo`H00023?=<COScH4gPlf1=c?=PCKScC4fhlcQ<f0000400006hl003>4`00F00003@000000000
00000?oooooooooo1P0006hlb1=c?<<CN3c34ghl`a>3?<PCPcc>4cd0000800006`0001000023?000
n1<003H0000@0000Pc`00?PC001H0000=000000000000000ooooooooool60000Pccn4ghl0aAh?0<D
Lc`356hloQ=^??PC=P000100001^?000n1<005P0000d000000000000003oooooooooo`H0001^??8C
Lcc^4gPlkQ=n?>hCPccb4h<ln1<m0000200001/0000@0000Pc`002<D000f0000400008<l000S5000
F00003@00000000000000?oooooooooo1P0008<l:AAn?2hDN3`^57<l;QA^?2TDKS`S53H0000@0000
KS`002<D001H0000=000000000000000ooooooooool60000KS`M57<l61Ah?1PDOS`H58<l7AB3?2<D
?@0000P0000K0000400008<l001>5000=P0001000023?000CQ@005P0000d000000000000003ooooo
ooooo`H00023?5@DOSaH57PlF1Ac?5PDKSaD56hlCQ@f0000400006hl001>5000F00003@000000000
00000?oooooooooo1P0006hlB1Ac?4<DN3a357hl@aB3?4PDPca>53d0000800006`0001000023?000
N1@003H0000@0000Pc`007PD001H0000=000000000000000ooooooooool60000Pcan57hlPaAh?8<D
Lcb356hlOQA^?7PD=P000100001^?000N1@005P0000d000000000000003oooooooooo`H0001^?78D
Lca^57PlKQAn?6hDPcab58<lN1@m0000200001/0000@0000Pc`00:<D000f0000400008<l002S5000
F00003@00000000000000?oooooooooo1P0008<lZAAn?:hDN3b^57<l[QA^?:TDKSbS53H0000@0000
KS`00:<D001H0000=000000000000000ooooooooool60000KSbM57<lV1Ah?9PDOSbH58<lWAB3?:<D
?@0000P0000K0000400008<l003>5000=P0001000023?000cQ@005P0000d000000000000003ooooo
ooooo`H00023?=@DOScH57Plf1Ac?=PDKScD56hlcQ@f0000400006hl003>5000F00003@000000000
00000?oooooooooo1P0006hlb1Ac?<<DN3c357hl`aB3?<PDPcc>53d0000800006`0001000023?000
n1@003H0000@0000Pc`00?PD001H0000=000000000000000ooooooooool60000Pccn57hl0aEh?0<E
Lc`35FhloQA^??PD=P000100001^?000n1@005P0000d000000000000003oooooooooo`H0001^??8D
Lcc^57PlkQAn?>hDPccb58<ln1@m0000200001/0000@0000Pc`002<E000f0000400008<l000S5@00
F00003@00000000000000?oooooooooo1P0008<l:AEn?2hEN3`^5G<l;QE^?2TEKS`S5CH0000@0000
KS`002<E001H0000=000000000000000ooooooooool60000KS`M5G<l61Eh?1PEOS`H5H<l7AF3?2<E
?@0000P0000K0000400008<l001>5@00=P0001000023?000CQD005P0000d000000000000003ooooo
ooooo`H00023?5@EOSaH5GPlF1Ec?5PEKSaD5FhlCQDf0000400006hl001>5@00F00003@000000000
00000?oooooooooo1P0006hlB1Ec?4<EN3a35Ghl@aF3?4PEPca>5Cd0000800006`0001000023?000
N1D003H0000@0000Pc`007PE001H0000=000000000000000ooooooooool60000Pcan5GhlPaEh?8<E
Lcb35FhlOQE^?7PE=P000100001^?000N1D005P0000d000000000000003oooooooooo`H0001^?7<E
Lca^5GPlKQEn?6hEPcac5H<lN1Dm0000200001/0000@0000Pc`00:<E000f0000400008<l002S5@00
F00003@00000000000000?oooooooooo1P0008<lZAEn?:hEN3b^5G<l[QE^?:TEKSbS5CH0000@0000
KS`00:<E001H0000=000000000000000ooooooooool60000KSbM5G<lV1Eh?9PEOSbH5H<lWAF3?:<E
?@0000P0000K0000400008<l003>5@00=P0001000023?000cQD005P0000d000000000000003ooooo
ooooo`H00023?=@EOScH5GPlf1Ec?=PEKScD5FhlcQDf0000400006hl003>5@00F00003@000000000
00000?oooooooooo1P0006hlb1Ec?<<EN3c35Ghl`aF3?<PEPcc>5Cd0000800006`0001000023?000
n1D003H0000@0000Pc`00?PE001H0000=000000000000000ooooooooool60000Pccn5Ghl0aIh?0<F
Lc`35VhloQE^??PE=P000100001^?000n1D005P0000d000000000000003oooooooooo`H0001^??<E
Lcc^5GPlkQEn?>hEPccc5H<ln1Dm0000200001/0000@0000Pc`002<F000f0000400008<l000S5P00
F00003@00000000000000?oooooooooo1P0008<l:AIn?2hFN3`^5W<l;QI^?2TFKS`S5SH0000@0000
KS`002<F001H0000=000000000000000ooooooooool60000KS`M5W<l61Ih?1PFOS`H5X<l7AJ3?2<F
?@0000P0000K0000400008<l001>5P00=P0001000023?000CQH005P0000d000000000000003ooooo
ooooo`H00023?5@FOSaI5WPlFAIc?5TFKSaD5VhlCQHf0000400006hl001>5P00F00003@000000000
00000?oooooooooo1P0006hlB1Ic?4<FN3a35Whl@aJ3?4PFPca>5Sd0000800006`0001000023?000
NAH003H0000@0000Pc`007TF001H0000=000000000000000ooooooooool60000Pcan5WhlPaIh?8<F
Lcb35VhlOQI^?7TF=P000100001^?000NAH005P0000d000000000000003oooooooooo`H0001^?7<F
Lca^5WPlKQIn?6hFPcac5X<lNAHm0000200001/0000@0000Pc`00:<F000f0000400008<l002S5P00
F00003@00000000000000?oooooooooo1P0008<lZAIn?:hFN3b^5W<l[QI^?:TFKSbS5SH0000@0000
KS`00:<F001H0000=000000000000000ooooooooool60000KSbM5W<lVAIh?9TFOSbI5X<lWAJ3?:<F
?@0000P0000K0000400008<l003>5P00=P0001000023?000cQH005P0000d000000000000003ooooo
ooooo`H00023?=@FOScI5WPlfAIc?=TFKScD5VhlcQHf0000400006hl003>5P00F00003@000000000
00000?oooooooooo1P0006hlb1Ic?<<FN3c35Whl`aJ3?<PFPcc>5Sd0000800006`0001000023?000
nAH003H0000@0000Pc`00?TF001H0000=000000000000000ooooooooool60000Pcco5Whl0aMh?0<G
Lc`35fhloaI^??TF=P000100001^?000nAH005P0000d000000000000003oooooooooo`H0001^??<F
Lcc^5WPlkQIn?>hFPccc5X<lnAHm0000200001/0000@0000Pc`002<G000f0000400008<l000S5`00
F00003@00000000000000?oooooooooo1P0008<l:AMn?2hGN3`^5g<l;QM^?2TGKS`S5cH0000@0000
KS`002<G001H0000=000000000000000ooooooooool60000KS`M5g<l6AMh?1TGOS`I5h<l7AN3?2<G
?@0000P0000K0000400008<l001>5`00=P0001000023?000CQL005P0000d000000000000003ooooo
ooooo`H00023?5@GOSaI5gPlFAMc?5TGKSaD5fhlCQLf0000400006hl001>5`00F00003@000000000
00000?oooooooooo1P0006hlB1Mc?4<GN3a35ghl@aN3?4PGPca>5cd0000800006`0001000023?000
NAL003H0000@0000Pc`007TG001H0000=000000000000000ooooooooool60000Pcao5ghlPaMh?8<G
Lcb35fhlOaM^?7TG=P000100001^?000NAL005P0000d000000000000003oooooooooo`H0001^?7<G
Lca^5gPlKQMn?6hGPcac5h<lNALm0000200001/0000@0000Pc`00:<G000f0000400008<l002S5`00
F00003@00000000000000?oooooooooo1P0008<lZAMn?:hGN3b^5g<l[QM^?:TGKSbS5cH0000@0000
KS`00:<G001H0000=000000000000000ooooooooool60000KSbM5g<lVAMh?9TGOSbI5h<lWAN3?:<G
?@0000P0000K0000400008<l003>5`00=P0001000023?000cQL005P0000d000000000000003ooooo
ooooo`H00023?=@GOScI5gPlfAMc?=TGKScD5fhlcQLf0000400006hl003>5`00F00003@000000000
00000?oooooooooo1P0006hlb1Mc?<<GN3c35ghl`aN3?<PGPcc>5cd0000800006`0001000023?000
nAL003H0000@0000Pc`00?TG001H0000=000000000000000ooooooooool60000Pcco5ghl0aQh?0<H
Lc`366hloaM^??TG=P000100001^?000nAL005P0000d000000000000003oooooooooo`H0001^??<G
Lcc^5gPlkQMn?>hGPccc5h<lnALm0000200001/0000@0000Pc`002<H000f0000400008<l000S6000
F00003@00000000000000?oooooooooo1P0008<l:AQn?2hHN3`^67<l;QQ^?2THKS`S63H0000@0000
KS`002<H001H0000=000000000000000ooooooooool60000KS`N67<l6AQh?1THOS`I68<l7QR3?2<H
?@0000P0000K0000400008<l001>6000=P0001000023?000CQP005P0000d000000000000003ooooo
ooooo`H00023?5@HOSaI67PlFAQc?5THKSaD66hlCQPf0000400006hl001>6000F00003@000000000
00000?oooooooooo1P0006hlB1Qc?4<HN3a367hl@aR3?4PHPca>63d0000800006`0001000023?000
NAP003H0000@0000Pc`007TH001H0000=000000000000000ooooooooool60000Pcao67hlPaQh?8<H
Lcb366hlOaQ^?7TH=P000100001^?000NAP005P0000d000000000000003oooooooooo`H0001^?7<H
Lca^67PlKQQn?6hHPcac68<lNAPm0000200001/0000@0000Pc`00:<H000f0000400008<l002T6000
F00003@00000000000000?oooooooooo1P0008<lZAQn?:hHN3b^67<l[QQ^?:THKSbT63H0000@0000
KS`00:<H001H0000=000000000000000ooooooooool60000KSbN67<lVAQh?9THOSbI68<lWQR3?:<H
?@0000P0000K0000400008<l003>6000=P0001000023?000cQP005P0000d000000000000003ooooo
ooooo`H00023?=@HOScI67PlfAQc?=THKScD66hlcQPf0000400006hl003>6000F00003@000000000
00000?oooooooooo1P0006hlb1Qc?<@HN3c467hla1R3?<PHPcc>63d0000800006`0001000023?000
nAP003H0000@0000Pc`00?TH001H0000=000000000000000ooooooooool60000Pcco67hl11Uh?0@I
Lc`46FhloaQ^??TH=P000100001^?000nAP005P0000d000000000000003oooooooooo`H0001^??<H
Lcc^67PlkQQn?>hHPccc68<lnAPm0000200001/0000@0000Pc`002@I000f0000400008<l000T6@00
F00003@00000000000000?oooooooooo1P0008<l:AUn?2hIN3`^6G<l;QU^?2TIKS`T6CH0000@0000
KS`002@I001H0000=000000000000000ooooooooool60000KS`N6G<l6AUh?1TIOS`I6H<l7QV3?2@I
?@0000P0000K0000400008<l001>6@00=P0001000023?000CQT005P0000d000000000000003ooooo
ooooo`H00023?5@IOSaI6GPlFAUc?5TIKSaD6FhlCQTf0000400006hl001>6@00F00003@000000000
00000?oooooooooo1P0006hlB1Uc?4@IN3a46GhlA1V3?4PIPca>6Cd0000800006`0001000023?000
NAT003H0000@0000Pc`007TI001H0000=000000000000000ooooooooool60000Pcao6GhlQ1Uh?8@I
Lcb46FhlOaU^?7TI=P000100001^?000NAT005P0000d000000000000003oooooooooo`H0001^?7<I
Lca^6GPlKQUn?6hIPcac6H<lNATm0000200001/0000@0000Pc`00:@I000f0000400008<l002T6@00
F00003@00000000000000?oooooooooo1P0008<lZQUn?:hIN3b^6G<l[QU^?:XIKSbT6CH0000@0000
KS`00:@I001H0000=000000000000000ooooooooool60000KSbN6G<lVAUh?9TIOSbI6H<lWQV3?:@I
?@0000P0000K0000400008<l003>6@00=P0001000023?000cQT005P0000d000000000000003ooooo
ooooo`H00023?=@IOScI6GPlfAUc?=TIKScD6FhlcQTf0000400006hl003>6@00F00003@000000000
00000?oooooooooo1P0006hlb1Uc?<@IN3c46Ghla1V3?<PIPcc>6Cd0000800006`0001000023?000
nAT003H0000@0000Pc`00?TI001H0000=000000000000000ooooooooool60000Pcco6Ghl11Yh?0@J
Lc`46VhloaU^??TI=P000100001^?000nAT005P0000d000000000000003oooooooooo`H0001^??<I
Lcc^6GPlkQUn?>hIPccc6H<lnATm0000200001/0000@0000Pc`002@J000f0000400008<l000T6P00
F00003@00000000000000?oooooooooo1P0008<l:QYn?2hJN3`^6W<l;QY^?2XJKS`T6SH0000@0000
KS`002@J001H0000=000000000000000ooooooooool60000KS`N6W<l6AYh?1TJOS`I6X<l7QZ3?2@J
?@0000P0000K0000400008<l001>6P00=P0001000023?000CQX005P0000d000000000000003ooooo
ooooo`H00023?5@JOSaI6WPlFAYc?5TJKSaD6VhlCQXf0000400006hl001>6P00F00003@000000000
00000?oooooooooo1P0006hlB1Yc?4@JN3a46WhlA1Z3?4PJPca>6Sd0000800006`0001000023?000
NAX003H0000@0000Pc`007TJ001H0000=000000000000000ooooooooool60000Pcao6WhlQ1Yh?8@J
Lcb46VhlOaY^?7TJ=P000100001^?000NAX005P0000d000000000000003oooooooooo`H0001^?7<J
Lca^6WPlKQYn?6hJPcac6X<lNAXm0000200001/0000@0000Pc`00:@J000f0000400008<l002T6P00
F00003@00000000000000?oooooooooo1P0008<lZQYn?:hJN3b^6W<l[QY^?:XJKSbT6SH0000@0000
KS`00:@J001H0000=000000000000000ooooooooool60000KSbN6W<lVAYh?9TJOSbI6X<lWQZ3?:@J
?@0000P0000K0000400008<l003>6P00=P0001000023?000cQX005P0000d000000000000003ooooo
ooooo`H00023?=@JOScI6WPlfAYc?=TJKScD6VhlcQXf0000400006hl003>6P00F00003@000000000
00000?oooooooooo1P0006hlbAYc?<@JN3c46Whla1Z3?<TJPcc>6Sd0000800006`0001000023?000
nAX003H0000@0000Pc`00?TJ001H0000=000000000000000ooooooooool60000Pcco6Whl11]h?0@K
Lc`46fhloaY^??TJ=P000100001^?000nAX005P0000d000000000000003oooooooooo`H0001^??<J
Lcc^6WPlkQYn?>hJPccc6X<lnAXm0000200001/0000@0000Pc`002@K000f0000400008<l000T6`00
F00003@00000000000000?oooooooooo1P0008<l:Q]n?2lKN3`_6g<l;a]^?2XKKS`T6cH0000@0000
KS`002@K001H0000=000000000000000ooooooooool60000KS`N6g<l6A]h?1TKOS`I6h<l7Q^3?2@K
?@0000P0000K0000400008<l001?6`00=P0001000023?000Ca/005P0000d000000000000003ooooo
ooooo`H00023?5@KOSaI6gPlFA]c?5TKKSaD6fhlCa/f0000400006hl001?6`00F00003@000000000
00000?oooooooooo1P0006hlBA]c?4@KN3a46ghlA1^3?4TKPca?6cd0000800006`0001000023?000
NA/003H0000@0000Pc`007TK001H0000=000000000000000ooooooooool60000Pcao6ghlQ1]h?8@K
Lcb46fhlOa]^?7TK=P000100001^?000NA/005P0000d000000000000003oooooooooo`H0001^?7<K
Lca_6gPlKa]n?6lKPcac6h<lNA/m0000200001/0000@0000Pc`00:@K000f0000400008<l002T6`00
F00003@00000000000000?oooooooooo1P0008<lZQ]n?:lKN3b_6g<l[a]^?:XKKSbT6cH0000@0000
KS`00:@K001H0000=000000000000000ooooooooool60000KSbN6g<lVA]h?9TKOSbI6h<lWQ^3?:@K
?@0000P0000K0000400008<l003?6`00=P0001000023?000ca/005P0000d000000000000003ooooo
ooooo`H00023?=@KOScI6gPlfA]c?=TKKScD6fhlca/f0000400006hl003?6`00F00003@000000000
00000?oooooooooo1P0006hlbA]c?<@KN3c46ghla1^3?<TKPcc?6cd0000800006`0001000023?000
nA/003H0000@0000Pc`00?TK001H0000=000000000000000ooooooooool60000Pcco6ghl11ah?0@L
Lc`476hloa]^??TK=P000100001^?000nA/005P0000d000000000000003oooooooooo`H0001^??<K
Lcc_6gPlka]n?>lKPccc6h<lnA/m0000200001/0000@0000Pc`002@L000f0000400008<l000T7000
F00003@00000000000000?oooooooooo1P0008<l:Qan?2lLN3`_77<l;aa^?2XLKS`T73H0000@0000
KS`002@L001H0000=000000000000000ooooooooool60000KS`N77<l6Aah?1TLOS`I78<l7Qb3?2@L
?@0000P0000K0000400008<l001?7000=P0001000023?000Ca`005P0000d000000000000003ooooo
ooooo`H00023?5DLOSaI77PlFAac?5TLKSaE76hlCa`f0000400006hl001?7000F00003@000000000
00000?oooooooooo1P0006hlBAac?4@LN3a477hlA1b3?4TLPca?73d0000800006`0001000029?000
GQ`003H0000@0000RC`005hL001H0000=000000000000000ooooooooool60000ScaN79@lHabD?6PL
U3a^78llLab9?7<L=P0001000029?000La`005P0000d000000000000003oooooooooo`H00023?7<L
Oca^77llJ1ao?6<LPcaN78TlGQ`m0000200001/0000@0000]3`005hL000f000040000;@l001N7000
F00003@00000000000000?oooooooooo1P000;XlGQbo?6<L_caX7;llKQbj?7<L]3ac73H0000@0000
]3`007<L001H0000=000000000000000ooooooooool60000[Sac7:TlKQbY?6PLZCaS7:hlGQbd?5hL
?@0000P0000K000040000=ll001N7000=P000100003O?000GQ`005P0000d000000000000003ooooo
ooooo`H0003U?5hLjCaS7>TlJ1cY?6hLiCac7=llLa`f000040000=ll001c7000F00003@000000000
00000?oooooooooo1P000=TlLacD?6hLe3aX7=@lHacI?5hLgcaN73d0000800006`0001000009?@00
GQ`003H0000@00002Cd005hL001H0000=000000000000000ooooooooool600003ceN71@mHa`D?FPL
53e^70lmLa`9?G<L=P0001000009?@00La`005P0000d000000000000003oooooooooo`H00004?G<L
oca^7?llJ1co?6<L13eN70TmGQ`m0000200001/0000@0000=3d005hL000f0000400003@m001N7000
F00003@00000000000000?oooooooooo1P0003XmGQ`o?F<L?ceX73lmKQ`j?G<L=3ec73H0000@0000
=3d007<L001H0000=000000000000000ooooooooool60000;Sec72TmKQ`Y?FPL:CeS72hmGQ`d?EhL
?@0000P0000K0000400005lm001N7000=P000100001O?@00GQ`005P0000d000000000000003ooooo
ooooo`H0001U?EhLJCeS76TmJ1aY?FhLICec75lmLa`f0000400005lm001c7000F00003@000000000
00000?oooooooooo1P0005TmLaaD?FhLE3eX75@mHaaI?EhLGceN73d0000800006`0001000029?@00
GQ`003H0000@0000RCd005hL001H0000=000000000000000ooooooooool60000SceN79@mHabD?FPL
U3e^78lmLab9?G<L=P0001000029?@00La`005P0000d000000000000003oooooooooo`H00024?G<L
Oce^77lmJ1ao?F<LQ3eN78TmGQ`m0000200001/0000@0000]3d005hL000f000040000;@m001N7000
F00003@00000000000000?oooooooooo1P000;XmGQbo?F<L_ceX7;lmKQbj?G<L]3ec73H0000@0000
]3d007<L001H0000=000000000000000ooooooooool60000[Sec7:TmKQbY?FPLZCeS7:hmGQbd?EhL
?@0000P0000K000040000=lm001N7000=P000100003O?@00GQ`005P0000d000000000000003ooooo
ooooo`H0003U?EhLjSeS7>XmJ1cZ?FhLiCec7=lmLa`f000040000=lm001c7000F00003@000000000
00000?oooooooooo1P000=TmLacD?FhLe3eX7=@mHacI?EhLgceN73d0000800006`000100000:?P00
GQ`003H0000@00002Sh005hL001H0000=000000000000000ooooooooool600003ciN71@nHa`D?VPL
53i^70lnLa`:?W<L=P000100000:?P00La`005P0000d000000000000003oooooooooo`H00004?W<L
oce^7?lmJ1co?F<L13iN70XnGQ`m0000200001/0000@0000=3h005hL000f0000400003@n001N7000
F00003@00000000000000?oooooooooo1P0003XnGQ`o?V<L?ciX73lnKQ`j?W<L=3ic73H0000@0000
=3h007<L001H0000=000000000000000ooooooooool60000;Sic72XnKQ`Z?VPL:SiS72hnGQ`d?UhL
?@0000P0000K0000400005ln001N7000=P000100001O?P00GQ`005P0000d000000000000003ooooo
ooooo`H0001U?UhLJSiS76XnJ1aZ?VhLICic75lnLa`f0000400005ln001c7000F00003@000000000
00000?oooooooooo1P0005TnLaaD?VhLE3iX75@nHaaI?UhLGciN73d0000800006`000100002:?P00
GQ`003H0000@0000RSh005hL001H0000=000000000000000ooooooooool60000SciN79@nHabD?VPL
U3i^78lnLab:?W<L=P000100002:?P00La`005P0000d000000000000003oooooooooo`H00024?W<L
Oci^77lnJ1ao?V<LQ3iN78XnGQ`m0000200001/0000@0000]3h005hL000f000040000;@n001N7000
F00003@00000000000000?oooooooooo1P000;XnGQbo?V<L_ciX7;lnKQbj?W<L]3ic73H0000@0000
]3h007<L001H0000=000000000000000ooooooooool60000[Sic7:XnKQbZ?VPLZSiS7:hnGQbd?UhL
?@0000P0000K000040000=ln001N7000=P000100003O?P00GQ`005P0000d000000000000003ooooo
ooooo`H0003U?UhLjSiS7>XnJ1cZ?VhLiCic7=lnLa`f000040000=ln001c7000F00003@000000000
00000?oooooooooo1P000=TnLacD?VhLe3iX7=@nHacI?UhLgciN73d0000800006`000100000:?`00
GQ`003H0000@00002Sl005hL001H0000=000000000000000ooooooooool6000043mN71@oHa`D?fPL
53m^710oLa`:?g<L=P000100000:?`00La`005P0000d000000000000003oooooooooo`H00004?g<L
oci^7?lnJ1co?V<L13mN70XoGQ`m0000200001/0000@0000=3l005hL000f0000400003@o001N7000
F00003@00000000000000?oooooooooo1P0003XoGQ`o?f<L?cmX73loKQ`j?g<L=3mc73H0000@0000
=3l007<L001H0000=000000000000000ooooooooool60000;Smc72XoKQ`Z?fPL:SmS72hoGQ`d?ehL
?@0000P0000K0000400005lo001N7000=P000100001O?`00GQ`005P0000d000000000000003ooooo
ooooo`H0001U?ehLJSmS76XoJ1aZ?fhLICmc75loLa`f0000400005lo001c7000F00003@000000000
00000?oooooooooo1P0005ToLaaD?fhLE3mX75@oHaaI?ehLGcmN73d0000800006`000100002:?`00
GQ`003H0000@0000RSl005hL001H0000=000000000000000ooooooooool60000T3mN79@oHabD?fPL
U3m^790oLab:?g<L=P000100002:?`00La`005P0000d000000000000003oooooooooo`H00024?g<L
Ocm^77loJ1ao?f<LQ3mN78XoGQ`m0000200001/0000@0000]3l005hL000f000040000;@o001N7000
F00003@00000000000000?oooooooooo1P000;XoGQbo?f<L_cmX7;loKQbj?g<L]3mc73H0000@0000
]3l007<L001H0000=000000000000000ooooooooool60000[Smc7:XoKQbZ?fPLZSmS7:hoGQbd?ehL
?@0000P0000K000040000=lo001N7000=P000100003O?`00GQ`005P0000d000000000000003ooooo
ooooo`H0003U?ehLjSmS7>XoJ1cZ?fhLiCmc7=loLa`f000040000=lo001c7000F00003@000000000
00000?oooooooooo1P000=ToLacD?fhLe3mX7=@oHacI?ehLgcmN73d0000800006`000100000:@000
GQ`003H0000@00002T0005hL001H0000=000000000000000ooooooooool60000441N71A0Ha`D@6PL
541^7110La`:@7<L=P000100000:@000La`005P0000d000000000000003oooooooooo`H00004@7<L
ocm^7?loJ1co?f<L141N70Y0GQ`m0000200001/0000@0000=40005hL000f0000400003A0001N7000
F00003@00000000000000?oooooooooo1P0003Y0GQ`o@6<L?d1X73m0KQ`j@7<L=41c73H0000@0000
=40007<L001H0000=000000000000000ooooooooool60000;d1c72Y0KQ`Z@6PL:T1S72m0GQ`d@5hL
?@0000P0000K0000400005m0001N7000=P000100001O@000GQ`005P0000d000000000000003ooooo
ooooo`H0001U@5hLJT1S76Y0J1aZ@6hLID1c75m0La`f0000400005m0001c7000F00003@000000000
00000?oooooooooo1P0005U0LaaD@6hLE41X75A0HaaI@5hLGd1N73d0000800006`000100002:@000
GQ`003H0000@0000RT0005hL001H0000=000000000000000ooooooooool60000T41N79A0HabD@6PL
U41^7910Lab:@7<L=P000100002:@000La`005P0000d000000000000003oooooooooo`H00024@7<L
Od1^77m0J1ao@6<LQ41N78Y0GQ`m0000200001/0000@0000]40005hL000f000040000;E0001N7000
F00003@00000000000000?oooooooooo1P000;Y0GQbo@6<L_d1X7;m0KQbj@7<L]D1c73H0000@0000
]40007<L001H0000=000000000000000ooooooooool60000[d1c7:Y0KQbZ@6PLZT1S7:m0GQbd@5hL
?@0000P0000K000040000=m0001N7000=P000100003O@000GQ`005P0000d000000000000003ooooo
ooooo`H0003U@5hLjT1S7>Y0J1cZ@6hLiD1c7=m0La`f000040000=m0001c7000F00003@000000000
00000?oooooooooo1P000=U0LacE@6hLeD1X7=E0HacI@5hLgd1N73d0000800006`000100000:@@00
GQ`003H0000@00002T4005hL001H0000=000000000000000ooooooooool60000445N71E1Ha`E@FPL
5D5^7111La`:@G<L=P000100000:@@00La`005P0000d000000000000003oooooooooo`H00004@G<L
od1^7?m0J1co@6<L145N70Y1GQ`m0000200001/0000@0000=D4005hL000f0000400003E1001N7000
F00003@00000000000000?oooooooooo1P0003Y1GQ`o@F<L?d5X73m1KQ`j@G<L=D5c73H0000@0000
=D4007<L001H0000=000000000000000ooooooooool60000;d5c72Y1KQ`Z@FPL:T5S72m1GQ`e@EhL
?@0000P0000K0000400005m1001N7000=P000100001O@@00GQ`005P0000d000000000000003ooooo
ooooo`H0001U@EhLJT5S76Y1J1aZ@FhLID5c75m1La`f0000400005m1001c7000F00003@000000000
00000?oooooooooo1P0005U1LaaE@FhLED5X75E1HaaI@EhLGd5N73d0000800006`000100002:@@00
GQ`003H0000@0000RT4005hL001H0000=000000000000000ooooooooool60000T45N79E1HabE@FPL
UD5^7911Lab:@G<L=P000100002:@@00La`005P0000d000000000000003oooooooooo`H00024@G<L
Od5^77m1J1ao@F<LQ45N78Y1GQ`m0000200001/0000@0000]D4005hL000f000040000;E1001N7000
F00003@00000000000000?oooooooooo1P000;]1GQbo@F<L_d5X7;m1KQbk@G<L]D5c73H0000@0000
]D4007<L001H0000=000000000000000ooooooooool60000[d5c7:Y1KQbZ@FPLZT5S7:m1GQbe@EhL
?@0000P0000K000040000=m1001N7000=P000100003O@@00GQ`005P0000d000000000000003ooooo
ooooo`H0003U@EhLjT5S7>Y1J1cZ@FhLiD5c7=m1La`f000040000=m1001c7000F00003@000000000
00000?oooooooooo1P000=U1LacE@FhLeD5X7=E1HacI@EhLgd5N73d0000800006`000100000:@P00
GQ`003H0000@00002T8005hL001H0000=000000000000000ooooooooool60000449N71E2Ha`E@VPL
5D9^7112La`:@W<L=P000100000:@P00La`005P0000d000000000000003oooooooooo`H00004@W<L
od5^7?m1J1co@F<L149N70Y2GQ`m0000200001/0000@0000=D8005hL000f0000400003E2001N7000
F00003@00000000000000?oooooooooo1P0003]2GQ`o@V<L?d9X73m2KQ`k@W<L=D9c73H0000@0000
=D8007<L001H0000=000000000000000ooooooooool60000;d9c72Y2KQ`Z@VPL:T9S72m2GQ`e@UhL
?@0000P0000K0000400005m2001N7000=P000100001O@P00GQ`005P0000d000000000000003ooooo
ooooo`H0001U@UhLJT9S76Y2J1aZ@VhLID9c75m2La`f0000400005m2001c7000F00003@000000000
00000?oooooooooo1P0005U2LaaE@VhLED9X75E2HaaI@UhLGd9N73d0000800006`000100002:@P00
GQ`003H0000@0000RT8005hL001H0000=000000000000000ooooooooool60000T49N79E2HabE@VPL
UD9^7912Lab:@W<L=P000100002:@P00La`005P0000d000000000000003oooooooooo`H00024@W<L
Od9^77m2J1ao@V<LQ49N78Y2GQ`m0000200001/0000@0000]D8005hL000f000040000;E2001N7000
F00003@00000000000000?oooooooooo1P000;]2GQbo@V<L_d9X7;m2KQbk@W<L]D9c73H0000@0000
]D8007<L001H0000=000000000000000ooooooooool60000[d9c7:Y2KQbZ@VPLZT9S7:m2GQbe@UhL
?@0000P0000K000040000=m2001N7000=P000100003O@P00GQ`005P0000d000000000000003ooooo
ooooo`H0003U@UhLjT9S7>Y2J1cZ@VhLiD9c7=m2La`f000040000=m2001c7000F00003@000000000
00000?oooooooooo1P000=Y2LacE@VhLeD9X7=E2HacJ@UhLgd9N73d0000800006`000100000:@`00
GQ`003H0000@00002T<005hL001H0000=000000000000000ooooooooool6000044=N71E3Ha`E@fPL
5D=^7113La`:@g<L=P000100000:@`00La`005P0000d000000000000003oooooooooo`H00004@g<L
od9^7?m2J1co@V<L14=N70Y3GQ`m0000200001/0000@0000=D<005hL000f0000400003E3001N7000
F00003@00000000000000?oooooooooo1P0003]3GQ`o@f<L?d=X73m3KQ`k@g<L=D=c73H0000@0000
=D<007<L001H0000=000000000000000ooooooooool60000;d=c72Y3KQ`Z@fPL:T=S72m3GQ`e@ehL
?@0000P0000K0000400005m3001N7000=P000100001O@`00GQ`005P0000d000000000000003ooooo
ooooo`H0001U@ehLJT=S76Y3J1aZ@fhLID=c75m3La`f0000400005m3001c7000F00003@000000000
00000?oooooooooo1P0005Y3LaaE@fhLED=X75E3HaaJ@ehLGd=N73d0000800006`000100002:@`00
GQ`003H0000@0000RT<005hL001H0000=000000000000000ooooooooool60000T4=N79E3HabE@fPL
UD=^7913Lab:@g<L=P000100002:@`00La`005P0000d000000000000003oooooooooo`H00024@g<L
Od=^77m3J1ao@f<LQ4=N78Y3GQ`m0000200001/0000@0000]D<005hL000f000040000;E3001N7000
F00003@00000000000000?oooooooooo1P000;]3GQc0@f<L`4=X7<13KQbk@g<L]D=c73H0000@0000
]D<007<L001H0000=000000000000000ooooooooool60000[d=c7:Y3KQbZ@fPLZT=S7:m3GQbe@ehL
?@0000P0000K000040000>13001N7000=P000100003P@`00GQ`005P0000d000000000000003ooooo
ooooo`H0003U@ehLjT=S7>Y3J1cZ@fhLiD=c7>13La`f000040000>13001c7000F00003@000000000
00000?oooooooooo1P000=Y3LacE@fhLeD=X7=E3HacJ@ehLh4=N73d0000800006`000100000:A000
GQ`003H0000@00002T@005hL001H0000=000000000000000ooooooooool6000044AN71E4Ha`EA6PL
5DA^7114La`:A7<L=P000100000:A000La`005P0000d000000000000003oooooooooo`H00004A7<L
04A^7014J1`0A6<L14AN70Y4GQ`m0000200001/0000@0000=D@005hL000f0000400003E4001N7000
F00003@00000000000000?oooooooooo1P0003]4GQa0A6<L@4AX7414KQ`kA7<L=DAc73H0000@0000
=D@007<L001H0000=000000000000000ooooooooool60000;dAc72Y4KQ`ZA6PL:TAS72m4GQ`eA5hL
?@0000P0000K000040000614001N7000=P000100001PA000GQ`005P0000d000000000000003ooooo
ooooo`H0001UA5hLJTAS76Y4J1aZA6hLIDAc7614La`f000040000614001c7000F00003@000000000
00000?oooooooooo1P0005Y4LaaEA6hLEDAX75E4HaaJA5hLH4AN73d0000800006`000100002:A000
GQ`003H0000@0000RT@005hL001H0000=000000000000000ooooooooool60000T4AN79E4HabEA6PL
UDA^7914Lab:A7<L=P000100002:A000La`005P0000d000000000000003oooooooooo`H00024A7<L
P4A^7814J1b0A6<LQ4AN78Y4GQ`m0000200001/0000@0000]D@005hL000f000040000;E4001N7000
F00003@00000000000000?oooooooooo1P000;]4GQc0A6<L`4AX7<14KQbkA7<L]DAc73H0000@0000
]D@007<L001H0000=000000000000000ooooooooool60000[dAc7:Y4KQbZA6PLZTAS7:m4GQbeA5hL
?@0000P0000K000040000>14001N7000=P000100003PA000GQ`005P0000d000000000000003ooooo
ooooo`H0003VA5hLjTAS7>Y4J1cZA6hLiTAc7>14La`f000040000>14001c7000F00003@000000000
00000?oooooooooo1P000=Y4LacEA6hLeDAX7=E4HacJA5hLh4AN73d0000800006`000100000:A@00
GQ`003H0000@00002TD005hL001H0000=000000000000000ooooooooool6000044EN71E5Ha`EAFPL
5DE^7115La`:AG<L=P000100000:A@00La`005P0000d000000000000003oooooooooo`H00004AG<L
04E^7015J1`0AF<L14EN70Y5GQ`m0000200001/0000@0000=DD005hL000f0000400003E5001N7000
F00003@00000000000000?oooooooooo1P0003]5GQa0AF<L@4EX7415KQ`kAG<L=DEc73H0000@0000
=DD007<L001H0000=000000000000000ooooooooool60000;dEc72Y5KQ`ZAFPL:TES72m5GQ`eAEhL
?@0000P0000K000040000615001N7000=P000100001PA@00GQ`005P0000d000000000000003ooooo
ooooo`H0001VAEhLJTES76Y5J1aZAFhLITEc7615La`f000040000615001c7000F00003@000000000
00000?oooooooooo1P0005Y5LaaEAFhLEDEX75E5HaaJAEhLH4EN73d0000800006`000100002:A@00
GQ`003H0000@0000RTD005hL001H0000=000000000000000ooooooooool60000T4EN79E5HabEAFPL
UDE^7915Lab:AG<L=P000100002:A@00La`005P0000d000000000000003oooooooooo`H00024AG<L
P4E^7815J1b0AF<LQ4EN78Y5GQ`m0000200001/0000@0000]DD005hL000f000040000;E5001N7000
F00003@00000000000000?oooooooooo1P000;]5GQc0AF<L`4EX7<15KQbkAG<L]DEc73H0000@0000
]DD007<L001H0000=000000000000000ooooooooool60000[dEc7:Y5KQbZAFPLZTES7:m5GQbeAEhL
?@0000P0000K000040000>15001N7000=P000100003PA@00GQ`005P0000d000000000000003ooooo
ooooo`H0003VAEhLjTES7>Y5J1cZAFhLiTEc7>15La`f000040000>15001c7000F00003@000000000
00000?oooooooooo1P000=Y5LacEAFhLeDEX7=E5HacJAEhLh4EN73d0000800006`000100000:AP00
GQ`003H0000@00002TH005hL001H0000=000000000000000ooooooooool6000044IN71E6Ha`EAVPL
5DI^7116La`:AW<L=P000100000:AP00La`005P0000d000000000000003oooooooooo`H00005AW<L
04I^7016J1`0AV<L1DIN70Y6GQ`m0000200001/0000@0000=DH005hL000f0000400003E6001N7000
F00003@00000000000000?oooooooooo1P0003]6GQa0AV<L@4IX7416KQ`kAW<L=DIc73H0000@0000
=DH007<L001H0000=000000000000000ooooooooool60000;dIc72Y6KQ`ZAVPL:TIS72m6GQ`eAUhL
?@0000P0000K000040000616001N7000=P000100001PAP00GQ`005P0000d000000000000003ooooo
ooooo`H0001VAUhLJTIS76Y6J1aZAVhLITIc7616La`f000040000616001c7000F00003@000000000
00000?oooooooooo1P0005Y6LaaEAVhLEDIX75E6HaaJAUhLH4IN73d0000800006`000100002:AP00
GQ`003H0000@0000RdH005hL001H0000=000000000000000ooooooooool60000T4IN79E6HabEAVPL
UDI^7916Lab;AW<L=P000100002:AP00La`005P0000d000000000000003oooooooooo`H00025AW<L
P4I^7816J1b0AV<LQDIN78Y6GQ`m0000200001/0000@0000]DH005hL000f000040000;E6001N7000
F00003@00000000000000?oooooooooo1P000;]6GQc0AV<L`4IX7<16KQbkAW<L]DIc73H0000@0000
]DH007<L001H0000=000000000000000ooooooooool60000[dIc7:]6KQb[AVPLZdIS7:m6GQbeAUhL
?@0000P0000K000040000>16001N7000=P000100003PAP00GQ`005P0000d000000000000003ooooo
ooooo`H0003VAUhLjdIS7>]6J1c[AVhLiTIc7>16La`f000040000>16001c7000F00003@000000000
00000?oooooooooo1P000=Y6LacEAVhLeDIX7=E6HacJAUhLh4IN73d0000800006`000100000;A`00
GQ`003H0000@00002dL005hL001H0000=000000000000000ooooooooool6000044MN71E7Ha`EAfPL
5DM^7117La`;Ag<L=P000100000;A`00La`005P0000d000000000000003oooooooooo`H00005Ag<L
04M^7017J1`0Af<L1DMN70]7GQ`m0000200001/0000@0000=DL005hL000f0000400003E7001N7000
F00003@00000000000000?oooooooooo1P0003]7GQa0Af<L@4MX7417KQ`kAg<L=DMc73H0000@0000
=DL007<L001H0000=000000000000000ooooooooool60000;dMc72]7KQ`[AfPL:dMS72m7GQ`eAehL
?@0000P0000K000040000617001N7000=P000100001PA`00GQ`005P0000d000000000000003ooooo
ooooo`H0001VAehLJdMS76]7J1a[AfhLITMc7617La`f000040000617001c7000F00003@000000000
00000?oooooooooo1P0005Y7LaaEAfhLEDMX75E7HaaJAehLH4MN73d0000800006`000100002;A`00
GQ`003H0000@0000RdL005hL001H0000=000000000000000ooooooooool60000TDMN79E7HabEAfPL
UDM^7957Lab;Ag<L=P000100002;A`00La`005P0000d000000000000003oooooooooo`H00025Ag<L
P4M^7817J1b0Af<LQDMN78]7GQ`m0000200001/0000@0000]DL005hL000f000040000;E7001N7000
F00003@00000000000000?oooooooooo1P000;]7GQc0Af<L`4MX7<17KQbkAg<L]DMc73H0000@0000
]DL007<L001H0000=000000000000000ooooooooool60000[dMc7:]7KQb[AfPLZdMS7:m7GQbeAehL
?@0000P0000K000040000>17001N7000=P000100003PA`00GQ`005P0000d000000000000003ooooo
ooooo`H0003VAehLjdMS7>]7J1c[AfhLiTMc7>17La`f000040000>17001c7000F00003@000000000
00000?oooooooooo1P000=Y7LacEAfhLeDMX7=E7HacJAehLh4MN73d0000800006`000100000;B000
GQ`003H0000@00002dP005hL001H0000=000000000000000ooooooooool600004DQN71E8Ha`EB6PL
5DQ^7158La`;B7<L=P000100000;B000La`005P0000d000000000000003oooooooooo`H00005B7<L
04Q^7018J1`0B6<L1DQN70]8GQ`m0000200001/0000@0000=DP005hL000f0000400003E8001N7000
F00003@00000000000000?oooooooooo1P0003]8GQa0B6<L@4QX7418KQ`kB7<L=DQc73H0000@0000
=DP007<L001H0000=000000000000000ooooooooool60000;dQc72]8KQ`[B6PL:dQS72m8GQ`eB5hL
?@0000P0000K000040000618001N7000=P000100001PB000GQ`005P0000d000000000000003ooooo
ooooo`H0001VB5hLJdQS76]8J1a[B6hLITQc7618La`f000040000618001c7000F00003@000000000
00000?oooooooooo1P0005Y8LaaEB6hLEDQX75E8HaaJB5hLH4QN73d0000800006`000100002;B000
GQ`003H0000@0000RdP005hL001H0000=000000000000000ooooooooool60000TDQN79E8HabEB6PL
UDQ^7958Lab;B7<L=P000100002;B000La`005P0000d000000000000003oooooooooo`H00025B7<L
P4Q^7818J1b0B6<LQDQN78]8GQ`m0000200001/0000@0000]DP005hL000f000040000;E8001N7000
F00003@00000000000000?oooooooooo1P000;]8GQc0B6<L`4QX7<18KQbkB7<L]DQc73H0000@0000
]DP007<L001H0000=000000000000000ooooooooool60000/4Qc7:]8KQb[B6PLZdQS7;18GQbeB5hL
?@0000P0000K000040000>18001N7000=P000100003PB000GQ`005P0000d000000000000003ooooo
ooooo`H0003VB5hLjdQS7>]8J1c[B6hLiTQc7>18La`f000040000>18001c7000F00003@000000000
00000?oooooooooo1P000=Y8LacEB6hLeDQX7=E8HacJB5hLh4QN73d0000800006`000100000;B@00
GQ`003H0000@00002dT005hL001H0000=000000000000000ooooooooool600004DUN71E9Ha`EBFPL
5DU^7159La`;BG<L=P000100000;B@00La`005P0000d000000000000003oooooooooo`H00005BG<L
04U^7019J1`0BF<L1DUN70]9GQ`m0000200001/0000@0000=DT005hL000f0000400003I9001N7000
F00003@00000000000000?oooooooooo1P0003]9GQa0BF<L@4UX7419KQ`kBG<L=TUc73H0000@0000
=DT007<L001H0000=000000000000000ooooooooool60000<4Uc72]9KQ`[BFPL:dUS7319GQ`eBEhL
?@0000P0000K000040000619001N7000=P000100001PB@00GQ`005P0000d000000000000003ooooo
ooooo`H0001VBEhLJdUS76]9J1a[BFhLITUc7619La`f000040000619001c7000F00003@000000000
00000?oooooooooo1P0005Y9LaaFBFhLETUX75I9HaaJBEhLH4UN73d0000800006`000100002;B@00
GQ`003H0000@0000RdT005hL001H0000=000000000000000ooooooooool60000TDUN79I9HabFBFPL
UTU^7959Lab;BG<L=P000100002;B@00La`005P0000d000000000000003oooooooooo`H00025BG<L
P4U^7819J1b0BF<LQDUN78]9GQ`m0000200001/0000@0000]TT005hL000f000040000;I9001N7000
F00003@00000000000000?oooooooooo1P000;]9GQc0BF<L`4UX7<19KQbkBG<L]TUc73H0000@0000
]TT007<L001H0000=000000000000000ooooooooool60000/4Uc7:]9KQb[BFPLZdUS7;19GQbfBEhL
?@0000P0000K000040000>19001N7000=P000100003PB@00GQ`005P0000d000000000000003ooooo
ooooo`H0003VBEhLjdUS7>]9J1c[BFhLiTUc7>19La`f000040000>19001c7000F00003@000000000
00000?oooooooooo1P000=Y9LacFBFhLeTUX7=I9HacJBEhLh4UN73d0000800006`000100000;BP00
GQ`003H0000@00002dX005hL001H0000=000000000000000ooooooooool600004DYN71I:Ha`FBVPL
5TY^715:La`;BW<L=P000100000;BP00La`005P0000d000000000000003oooooooooo`H00005BW<L
04Y^701:J1`0BV<L1DYN70]:GQ`m0000200001/0000@0000=TX005hL000f0000400003I:001N7000
F00003@00000000000000?oooooooooo1P0003a:GQa0BV<L@4YX741:KQ`lBW<L=TYc73H0000@0000
=TX007<L001H0000=000000000000000ooooooooool60000<4Yc72]:KQ`[BVPL:dYS731:GQ`fBUhL
?@0000P0000K00004000061:001N7000=P000100001PBP00GQ`005P0000d000000000000003ooooo
ooooo`H0001VBUhLJdYS76]:J1a[BVhLITYc761:La`f00004000061:001c7000F00003@000000000
00000?oooooooooo1P0005Y:LaaFBVhLETYX75I:HaaJBUhLH4YN73d0000800006`000100002;BP00
GQ`003H0000@0000RdX005hL001H0000=000000000000000ooooooooool60000TDYN79I:HabFBVPL
UTY^795:Lab;BW<L=P000100002;BP00La`005P0000d000000000000003oooooooooo`H00025BW<L
P4Y^781:J1b0BV<LQDYN78]:GQ`m0000200001/0000@0000]TX005hL000f000040000;I:001N7000
F00003@00000000000000?oooooooooo1P000;a:GQc0BV<L`4YX7<1:KQblBW<L]TYc73H0000@0000
]TX007<L001H0000=000000000000000ooooooooool60000/4Yc7:]:KQb[BVPLZdYS7;1:GQbfBUhL
?@0000P0000K000040000>1:001N7000=P000100003PBP00GQ`005P0000d000000000000003ooooo
ooooo`H0003VBUhLjdYS7>]:J1c[BVhLiTYc7>1:La`f000040000>1:001c7000F00003@000000000
00000?oooooooooo1P000=Y:LacFBVhLeTYX7=I:HacJBUhLh4YN73d0000800006`000100000;B`00
GQ`003H0000@00002d/005hL001H0000=000000000000000ooooooooool600004D]N71I;Ha`FBfPL
5T]^715;La`;Bg<L=P000100000;B`00La`005P0000d000000000000003oooooooooo`H00005Bg<L
04]^701;J1`0Bf<L1D]N70];GQ`m0000200001/0000@0000=T/005hL000f0000400003I;001N7000
F00003@00000000000000?oooooooooo1P0003a;GQa0Bf<L@4]X741;KQ`lBg<L=T]c73H0000@0000
=T/007<L001H0000=000000000000000ooooooooool60000<4]c72];KQ`[BfPL:d]S731;GQ`fBehL
?@0000P0000K00004000061;001N7000=P000100001PB`00GQ`005P0000d000000000000003ooooo
ooooo`H0001VBehLJd]S76];J1a[BfhLIT]c761;La`f00004000061;001c7000F00003@000000000
00000?oooooooooo1P0005];LaaFBfhLET]X75I;HaaKBehLH4]N73d0000800006`000100002;B`00
GQ`003H0000@0000Rd/005hL001H0000=000000000000000ooooooooool60000TD]N79I;HabFBfPL
UT]^795;Lab;Bg<L=P000100002;B`00La`005P0000d000000000000003oooooooooo`H00025Bg<L
P4]^781;J1b0Bf<LQD]N78];GQ`m0000200001/0000@0000]T/005hL000f000040000;I;001N7000
F00003@00000000000000?oooooooooo1P000;a;GQc0Bf<L`4]X7<1;KQblBg<L]T]c73H0000@0000
]T/007<L001H0000=000000000000000ooooooooool60000/4]c7:];KQb[BfPLZd]S7;1;GQbfBehL
?@0000P0000K000040000>1;001N7000=P000100003QB`00GQ`005P0000d000000000000003ooooo
ooooo`H0003VBehLjd]S7>];J1c[BfhLiT]c7>5;La`f000040000>1;001c7000F00003@000000000
00000?oooooooooo1P000=];LacFBfhLeT]X7=I;HacKBehLh4]N73d0000800006`000100000;C000
GQ`003H0000@00002d`005hL001H0000=000000000000000ooooooooool600004DaN71I<Ha`FC6PL
5Ta^715<La`;C7<L=P000100000;C000La`005P0000d000000000000003oooooooooo`H00005C7<L
0Da^705<J1`1C6<L1DaN70]<GQ`m0000200001/0000@0000=T`005hL000f0000400003I<001N7000
F00003@00000000000000?oooooooooo1P0003a<GQa1C6<L@DaX745<KQ`lC7<L=Tac73H0000@0000
=T`007<L001H0000=000000000000000ooooooooool60000<4ac72]<KQ`[C6PL:daS731<GQ`fC5hL
?@0000P0000K00004000065<001N7000=P000100001QC000GQ`005P0000d000000000000003ooooo
ooooo`H0001VC5hLJdaS76]<J1a[C6hLITac765<La`f00004000065<001c7000F00003@000000000
00000?oooooooooo1P0005]<LaaFC6hLETaX75I<HaaKC5hLHDaN73d0000800006`000100002;C000
GQ`003H0000@0000Rd`005hL001H0000=000000000000000ooooooooool60000TDaN79I<HabFC6PL
UTa^795<Lab;C7<L=P000100002;C000La`005P0000d000000000000003oooooooooo`H00025C7<L
PDa^785<J1b1C6<LQDaN78]<GQ`m0000200001/0000@0000]T`005hL000f000040000;I<001N7000
F00003@00000000000000?oooooooooo1P000;a<GQc1C6<L`DaX7<5<KQblC7<L]Tac73H0000@0000
]T`007<L001H0000=000000000000000ooooooooool60000/4ac7:]<KQb[C6PLZdaS7;1<GQbfC5hL
?@0000P0000K000040000>5<001N7000=P000100003QC000GQ`005P0000d000000000000003ooooo
ooooo`H0003WC5hLjdaS7>]<J1c[C6hLidac7>5<La`f000040000>5<001c7000F00003@000000000
00000?oooooooooo1P000=]<LacFC6hLeTaX7=I<HacKC5hLhDaN73d0000800006`000100000;C@00
GQ`003H0000@00002dd005hL001H0000=000000000000000ooooooooool600004DeN71I=Ha`FCFPL
5Te^715=La`;CG<L=P000100000;C@00La`005P0000d000000000000003oooooooooo`H00005CG<L
0De^705=J1`1CF<L1DeN70]=GQ`m0000200001/0000@0000=Td005hL000f0000400003I=001N7000
F00003@00000000000000?oooooooooo1P0003a=GQa1CF<L@DeX745=KQ`lCG<L=Tec73H0000@0000
=Td007<L001H0000=000000000000000ooooooooool60000<4ec72]=KQ`[CFPL:deS731=GQ`fCEhL
?@0000P0000K00004000065=001N7000=P000100001QC@00GQ`005P0000d000000000000003ooooo
ooooo`H0001WCEhLJdeS76]=J1a[CFhLIdec765=La`f00004000065=001c7000F00003@000000000
00000?oooooooooo1P0005]=LaaFCFhLETeX75I=HaaKCEhLHDeN73d0000800006`000100002;C@00
GQ`003H0000@0000Rdd005hL001H0000=000000000000000ooooooooool60000TDeN79I=HabFCFPL
UTe^795=Lab;CG<L=P000100002;C@00La`005P0000d000000000000003oooooooooo`H00025CG<L
PDe^785=J1b1CF<LQDeN78]=GQ`m0000200001/0000@0000]Td005hL000f000040000;I=001N7000
F00003@00000000000000?oooooooooo1P000;a=GQc1CF<L`DeX7<5=KQblCG<L]Tec73H0000@0000
]Td007<L001H0000=000000000000000ooooooooool60000/4ec7:]=KQb[CFPLZdeS7;1=GQbfCEhL
?@0000P0000K000040000>5=001N7000=P000100003QC@00GQ`005P0000d000000000000003ooooo
ooooo`H0003WCEhLjdeS7>]=J1c[CFhLidec7>5=La`f000040000>5=001c7000F00003@000000000
00000?oooooooooo1P000=]=LacFCFhLeTeX7=I=HacKCEhLhDeN73d0000800006`000100000;CP00
GQ`003H0000@00002dh005hL001H0000=000000000000000ooooooooool600004DiN71I>Ha`FCVPL
5Ti^715>La`;CW<L=P000100000;CP00La`005P0000d000000000000003oooooooooo`H00006CW<L
0Di^705>J1`1CV<L1TiN70]>GQ`m0000200001/0000@0000=Th005hL000f0000400003I>001N7000
F00003@00000000000000?oooooooooo1P0003a>GQa1CV<L@DiX745>KQ`lCW<L=Tic73H0000@0000
=Th007<L001H0000=000000000000000ooooooooool60000<4ic72]>KQ`[CVPL:diS731>GQ`fCUhL
?@0000P0000K00004000065>001N7000=P000100001QCP00GQ`005P0000d000000000000003ooooo
ooooo`H0001WCUhLJdiS76]>J1a[CVhLIdic765>La`f00004000065>001c7000F00003@000000000
00000?oooooooooo1P0005]>LaaFCVhLETiX75I>HaaKCUhLHDiN73d0000800006`000100002;CP00
GQ`003H0000@0000S4h005hL001H0000=000000000000000ooooooooool60000TDiN79I>HabFCVPL
UTi^795>Lab<CW<L=P000100002;CP00La`005P0000d000000000000003oooooooooo`H00026CW<L
PDi^785>J1b1CV<LQTiN78]>GQ`m0000200001/0000@0000]Th005hL000f000040000;I>001N7000
F00003@00000000000000?oooooooooo1P000;a>GQc1CV<L`DiX7<5>KQblCW<L]Tic73H0000@0000
]Th007<L001H0000=000000000000000ooooooooool60000/4ic7:a>KQb/CVPL[4iS7;1>GQbfCUhL
?@0000P0000K000040000>5>001N7000=P000100003QCP00GQ`005P0000d000000000000003ooooo
ooooo`H0003WCUhLk4iS7>a>J1c/CVhLidic7>5>La`f000040000>5>001c7000F00003@000000000
00000?oooooooooo1P000=]>LacFCVhLeTiX7=I>HacKCUhLhDiN73d0000800006`000100000<C`00
GQ`003H0000@000034l005hL001H0000=000000000000000ooooooooool600004DmN71I?Ha`FCfPL
5Tm^715?La`<Cg<L=P000100000<C`00La`005P0000d000000000000003oooooooooo`H00006Cg<L
0Dm^705?J1`1Cf<L1TmN70a?GQ`m0000200001/0000@0000=Tl005hL000f0000400003I?001N7000
F00003@00000000000000?oooooooooo1P0003a?GQa1Cf<L@DmX745?KQ`lCg<L=Tmc73H0000@0000
=Tl007<L001H0000=000000000000000ooooooooool60000<4mc72a?KQ`/CfPL;4mS731?GQ`fCehL
?@0000P0000K00004000065?001N7000=P000100001QC`00GQ`005P0000d000000000000003ooooo
ooooo`H0001WCehLK4mS76a?J1a/CfhLIdmc765?La`f00004000065?001c7000F00003@000000000
00000?oooooooooo1P0005]?LaaFCfhLETmX75I?HaaKCehLHDmN73d0000800006`000100002<C`00
GQ`003H0000@0000S4l005hL001H0000=000000000000000ooooooooool60000TTmN79I?HabFCfPL
UTm^799?Lab<Cg<L=P000100002<C`00La`005P0000d000000000000003oooooooooo`H00026Cg<L
PDm^785?J1b1Cf<LQTmN78a?GQ`m0000200001/0000@0000]Tl005hL000f000040000;I?001N7000
F00003@00000000000000?oooooooooo1P000;a?GQc1Cf<L`DmX7<5?KQblCg<L]Tmc73H0000@0000
]Tl007<L001H0000=000000000000000ooooooooool60000/4mc7:a?KQb/CfPL[4mS7;1?GQbfCehL
?@0000P0000K000040000>5?001N7000=P000100003QC`00GQ`005P0000d000000000000003ooooo
ooooo`H0003WCehLk4mS7>a?J1c/CfhLidmc7>5?La`f000040000>5?001c7000F00003@000000000
00000?oooooooooo1P000=]?LacFCfhLeTmX7=I?HacKCehLhDmN73d0000800006`000100000<D000
GQ`003H0000@0000350005hL001H0000=000000000000000ooooooooool600004U1N71I@Ha`FD6PL
5U1^719@La`<D7<L=P000100000<D000La`005P0000d000000000000003oooooooooo`H00006D7<L
0E1^705@J1`1D6<L1U1N70a@GQ`m0000200001/0000@0000=U0005hL000f0000400003I@001N7000
F00003@00000000000000?oooooooooo1P0003a@GQa1D6<L@E1X745@KQ`lD7<L=U1c73H0000@0000
=U0007<L001H0000=000000000000000ooooooooool60000<51c72a@KQ`/D6PL;51S731@GQ`fD5hL
?@0000P0000K00004000065@001N7000=P000100001QD000GQ`005P0000d000000000000003ooooo
ooooo`H0001WD5hLK51S76a@J1a/D6hLIe1c765@La`f00004000065@001c7000F00003@000000000
00000?oooooooooo1P0005]@LaaFD6hLEU1X75I@HaaKD5hLHE1N73d0000800006`000100002<D000
GQ`003H0000@0000S50005hL001H0000=000000000000000ooooooooool60000TU1N79I@HabFD6PL
UU1^799@Lab<D7<L=P000100002<D000La`005P0000d000000000000003oooooooooo`H00026D7<L
PE1^785@J1b1D6<LQU1N78a@GQ`m0000200001/0000@0000]U0005hL000f000040000;I@001N7000
F00003@00000000000000?oooooooooo1P000;a@GQc1D6<L`E1X7<5@KQblD7<L]U1c73H0000@0000
]U0007<L001H0000=000000000000000ooooooooool60000/E1c7:a@KQb/D6PL[51S7;5@GQbfD5hL
?@0000P0000K000040000>5@001N7000=P000100003QD000GQ`005P0000d000000000000003ooooo
ooooo`H0003WD5hLk51S7>a@J1c/D6hLie1c7>5@La`f000040000>5@001c7000F00003@000000000
00000?oooooooooo1P000=]@LacFD6hLeU1X7=I@HacKD5hLhE1N73d0000800006`000100000<D@00
GQ`003H0000@0000354005hL001H0000=000000000000000ooooooooool600004U5N71IAHa`FDFPL
5U5^719ALa`<DG<L=P000100000<D@00La`005P0000d000000000000003oooooooooo`H00006DG<L
0E5^705AJ1`1DF<L1U5N70aAGQ`m0000200001/0000@0000=U4005hL000f0000400003MA001N7000
F00003@00000000000000?oooooooooo1P0003aAGQa1DF<L@E5X745AKQ`lDG<L=e5c73H0000@0000
=U4007<L001H0000=000000000000000ooooooooool60000<E5c72aAKQ`/DFPL;55S735AGQ`fDEhL
?@0000P0000K00004000065A001N7000=P000100001QD@00GQ`005P0000d000000000000003ooooo
ooooo`H0001WDEhLK55S76aAJ1a/DFhLIe5c765ALa`f00004000065A001c7000F00003@000000000
00000?oooooooooo1P0005]ALaaGDFhLEe5X75MAHaaKDEhLHE5N73d0000800006`000100002<D@00
GQ`003H0000@0000S54005hL001H0000=000000000000000ooooooooool60000TU5N79MAHabGDFPL
Ue5^799ALab<DG<L=P000100002<D@00La`005P0000d000000000000003oooooooooo`H00026DG<L
PE5^785AJ1b1DF<LQU5N78aAGQ`m0000200001/0000@0000]e4005hL000f000040000;MA001N7000
F00003@00000000000000?oooooooooo1P000;aAGQc1DF<L`E5X7<5AKQblDG<L]e5c73H0000@0000
]e4007<L001H0000=000000000000000ooooooooool60000/E5c7:aAKQb/DFPL[55S7;5AGQbgDEhL
?@0000P0000K000040000>5A001N7000=P000100003QD@00GQ`005P0000d000000000000003ooooo
ooooo`H0003WDEhLk55S7>aAJ1c/DFhLie5c7>5ALa`f000040000>5A001c7000F00003@000000000
00000?oooooooooo1P000=]ALacGDFhLee5X7=MAHacKDEhLhE5N73d0000800006`000100000<DP00
GQ`003H0000@0000358005hL001H0000=000000000000000ooooooooool600004U9N71MBHa`GDVPL
5e9^719BLa`<DW<L=P000100000<DP00La`005P0000d000000000000003oooooooooo`H00006DW<L
0E9^705BJ1`1DV<L1U9N70aBGQ`m0000200001/0000@0000=e8005hL000f0000400003MB001N7000
F00003@00000000000000?oooooooooo1P0003eBGQa1DV<L@E9X745BKQ`mDW<L=e9c73H0000@0000
=e8007<L001H0000=000000000000000ooooooooool60000<E9c72aBKQ`/DVPL;59S735BGQ`gDUhL
?@0000P0000K00004000065B001N7000=P000100001QDP00GQ`005P0000d000000000000003ooooo
ooooo`H0001WDUhLK59S76aBJ1a/DVhLIe9c765BLa`f00004000065B001c7000F00003@000000000
00000?oooooooooo1P0005]BLaaGDVhLEe9X75MBHaaKDUhLHE9N73d0000800006`000100002<DP00
GQ`003H0000@0000S58005hL001H0000=000000000000000ooooooooool60000TU9N79MBHabGDVPL
Ue9^799BLab<DW<L=P000100002<DP00La`005P0000d000000000000003oooooooooo`H00026DW<L
PE9^785BJ1b1DV<LQU9N78aBGQ`m0000200001/0000@0000]e8005hL000f000040000;MB001N7000
F00003@00000000000000?oooooooooo1P000;eBGQc1DV<L`E9X7<5BKQbmDW<L]e9c73H0000@0000
]e8007<L001H0000=000000000000000ooooooooool60000/E9c7:aBKQb/DVPL[59S7;5BGQbgDUhL
?@0000P0000K000040000>5B001N7000=P000100003QDP00GQ`005P0000d000000000000003ooooo
ooooo`H0003WDUhLk59S7>aBJ1c/DVhLie9c7>5BLa`f000040000>5B001c7000F00003@000000000
00000?oooooooooo1P000=]BLacGDVhLee9X7=MBHacKDUhLhE9N73d0000800006`000100000<D`00
GQ`003H0000@000035<005hL001H0000=000000000000000ooooooooool600004U=N71MCHa`GDfPL
5e=^719CLa`<Dg<L=P000100000<D`00La`005P0000d000000000000003oooooooooo`H00006Dg<L
0E=^705CJ1`1Df<L1U=N70aCGQ`m0000200001/0000@0000=e<005hL000f0000400003MC001N7000
F00003@00000000000000?oooooooooo1P0003eCGQa1Df<L@E=X745CKQ`mDg<L=e=c73H0000@0000
=e<007<L001H0000=000000000000000ooooooooool60000<E=c72aCKQ`/DfPL;5=S735CGQ`gDehL
?@0000P0000K00004000065C001N7000=P000100001QD`00GQ`005P0000d000000000000003ooooo
ooooo`H0001WDehLK5=S76aCJ1a/DfhLIe=c765CLa`f00004000065C001c7000F00003@000000000
00000?oooooooooo1P0005aCLaaGDfhLEe=X75MCHaaLDehLHE=N73d0000800006`000100002<D`00
GQ`003H0000@0000S5<005hL001H0000=000000000000000ooooooooool60000TU=N79MCHabGDfPL
Ue=^799CLab<Dg<L=P000100002<D`00La`005P0000d000000000000003oooooooooo`H00026Dg<L
PE=^785CJ1b1Df<LQU=N78aCGQ`m0000200001/0000@0000]e<005hL000f000040000;MC001N7000
F00003@00000000000000?oooooooooo1P000;eCGQc2Df<L`U=X7<9CKQbmDg<L]e=c73H0000@0000
]e<007<L001H0000=000000000000000ooooooooool60000/E=c7:aCKQb/DfPL[5=S7;5CGQbgDehL
?@0000P0000K000040000>9C001N7000=P000100003RD`00GQ`005P0000d000000000000003ooooo
ooooo`H0003WDehLk5=S7>aCJ1c/DfhLie=c7>9CLa`f000040000>9C001c7000F00003@000000000
00000?oooooooooo1P000=aCLacGDfhLee=X7=MCHacLDehLhU=N73d0000800006`000100000<E000
GQ`003H0000@000035@005hL001H0000=000000000000000ooooooooool600004UAN71MDHa`GE6PL
5eA^719DLa`<E7<L=P000100000<E000La`005P0000d000000000000003oooooooooo`H00006E7<L
0UA^709DJ1`2E6<L1UAN70aDGQ`m0000200001/0000@0000=e@005hL000f0000400003MD001N7000
F00003@00000000000000?oooooooooo1P0003eDGQa2E6<L@UAX749DKQ`mE7<L=eAc73H0000@0000
=e@007<L001H0000=000000000000000ooooooooool60000<EAc72aDKQ`/E6PL;5AS735DGQ`gE5hL
?@0000P0000K00004000069D001N7000=P000100001RE000GQ`005P0000d000000000000003ooooo
ooooo`H0001XE5hLK5AS76aDJ1a/E6hLJ5Ac769DLa`f00004000069D001c7000F00003@000000000
00000?oooooooooo1P0005aDLaaGE6hLEeAX75MDHaaLE5hLHUAN73d0000800006`000100002<E000
GQ`003H0000@0000S5@005hL001H0000=000000000000000ooooooooool60000TUAN79MDHabGE6PL
UeA^799DLab<E7<L=P000100002<E000La`005P0000d000000000000003oooooooooo`H00026E7<L
PUA^789DJ1b2E6<LQUAN78aDGQ`m0000200001/0000@0000]e@005hL000f000040000;MD001N7000
F00003@00000000000000?oooooooooo1P000;eDGQc2E6<L`UAX7<9DKQbmE7<L]eAc73H0000@0000
]e@007<L001H0000=000000000000000ooooooooool60000/EAc7:aDKQb/E6PL[5AS7;5DGQbgE5hL
?@0000P0000K000040000>9D001N7000=P000100003RE000GQ`005P0000d000000000000003ooooo
ooooo`H0003XE5hLk5AS7>aDJ1c/E6hLj5Ac7>9DLa`f000040000>9D001c7000F00003@000000000
00000?oooooooooo1P000=aDLacGE6hLeeAX7=MDHacLE5hLhUAN73d0000800006`000100000<E@00
GQ`003H0000@000035D005hL001H0000=000000000000000ooooooooool600004UEN71MEHa`GEFPL
5eE^719ELa`<EG<L=P000100000<E@00La`005P0000d000000000000003oooooooooo`H00006EG<L
0UE^709EJ1`2EF<L1UEN70aEGQ`m0000200001/0000@0000=eD005hL000f0000400003ME001N7000
F00003@00000000000000?oooooooooo1P0003eEGQa2EF<L@UEX749EKQ`mEG<L=eEc73H0000@0000
=eD007<L001H0000=000000000000000ooooooooool60000<EEc72aEKQ`/EFPL;5ES735EGQ`gEEhL
?@0000P0000K00004000069E001N7000=P000100001RE@00GQ`005P0000d000000000000003ooooo
ooooo`H0001XEEhLK5ES76aEJ1a/EFhLJ5Ec769ELa`f00004000069E001c7000F00003@000000000
00000?oooooooooo1P0005aELaaGEFhLEeEX75MEHaaLEEhLHUEN73d0000800006`000100002<E@00
GQ`003H0000@0000S5D005hL001H0000=000000000000000ooooooooool60000TUEN79MEHabGEFPL
UeE^799ELab<EG<L=P000100002<E@00La`005P0000d000000000000003oooooooooo`H00027EG<L
PUE^789EJ1b2EF<LQeEN78aEGQ`m0000200001/0000@0000]eD005hL000f000040000;ME001N7000
F00003@00000000000000?oooooooooo1P000;eEGQc2EF<L`UEX7<9EKQbmEG<L]eEc73H0000@0000
]eD007<L001H0000=000000000000000ooooooooool60000/EEc7:aEKQb/EFPL[5ES7;5EGQbgEEhL
?@0000P0000K000040000>9E001N7000=P000100003RE@00GQ`005P0000d000000000000003ooooo
ooooo`H0003XEEhLk5ES7>aEJ1c/EFhLj5Ec7>9ELa`f000040000>9E001c7000F00003@000000000
00000?oooooooooo1P000=aELacGEFhLeeEX7=MEHacLEEhLhUEN73d0000800006`000100000<EP00
GQ`003H0000@00003EH005hL001H0000=000000000000000ooooooooool600004UIN71MFHa`GEVPL
5eI^719FLa`=EW<L=P000100000<EP00La`005P0000d000000000000003oooooooooo`H00007EW<L
0UI^709FJ1`2EV<L1eIN70aFGQ`m0000200001/0000@0000=eH005hL000f0000400003MF001N7000
F00003@00000000000000?oooooooooo1P0003eFGQa2EV<L@UIX749FKQ`mEW<L=eIc73H0000@0000
=eH007<L001H0000=000000000000000ooooooooool60000<EIc72eFKQ`]EVPL;EIS735FGQ`gEUhL
?@0000P0000K00004000069F001N7000=P000100001REP00GQ`005P0000d000000000000003ooooo
ooooo`H0001XEUhLKEIS76eFJ1a]EVhLJ5Ic769FLa`f00004000069F001c7000F00003@000000000
00000?oooooooooo1P0005aFLaaGEVhLEeIX75MFHaaLEUhLHUIN73d0000800006`000100002=EP00
GQ`003H0000@0000SEH005hL001H0000=000000000000000ooooooooool60000TUIN79MFHabGEVPL
UeI^799FLab=EW<L=P000100002=EP00La`005P0000d000000000000003oooooooooo`H00027EW<L
PUI^789FJ1b2EV<LQeIN78eFGQ`m0000200001/0000@0000]eH005hL000f000040000;MF001N7000
F00003@00000000000000?oooooooooo1P000;eFGQc2EV<L`UIX7<9FKQbmEW<L]eIc73H0000@0000
]eH007<L001H0000=000000000000000ooooooooool60000/EIc7:eFKQb]EVPL[EIS7;5FGQbgEUhL
?@0000P0000K000040000>9F001N7000=P000100003REP00GQ`005P0000d000000000000003ooooo
ooooo`H0003XEUhLkEIS7>eFJ1c]EVhLj5Ic7>9FLa`f000040000>9F001c7000F00003@000000000
00000?oooooooooo1P000=aFLacGEVhLeeIX7=MFHacLEUhLhUIN73d0000800006`000100000=E`00
GQ`003H0000@00003EL005hL001H0000=000000000000000ooooooooool600004eMN71MGHa`GEfPL
5eM^71=GLa`=Eg<L=P000100000=E`00La`005P0000d000000000000003oooooooooo`H00007Eg<L
0UM^709GJ1`2Ef<L1eMN70eGGQ`m0000200001/0000@0000=eL005hL000f0000400003MG001N7000
F00003@00000000000000?oooooooooo1P0003eGGQa2Ef<L@UMX749GKQ`mEg<L=eMc73H0000@0000
=eL007<L001H0000=000000000000000ooooooooool60000<EMc72eGKQ`]EfPL;EMS735GGQ`gEehL
?@0000P0000K00004000069G001N7000=P000100001RE`00GQ`005P0000d000000000000003ooooo
ooooo`H0001XEehLKEMS76eGJ1a]EfhLJ5Mc769GLa`f00004000069G001c7000F00003@000000000
00000?oooooooooo1P0005aGLaaGEfhLEeMX75MGHaaLEehLHUMN73d0000800006`000100002=E`00
GQ`003H0000@0000SEL005hL001H0000=000000000000000ooooooooool60000TeMN79MGHabGEfPL
UeM^79=GLab=Eg<L=P000100002=E`00La`005P0000d000000000000003oooooooooo`H00027Eg<L
PUM^789GJ1b2Ef<LQeMN78eGGQ`m0000200001/0000@0000]eL005hL000f000040000;MG001N7000
F00003@00000000000000?oooooooooo1P000;eGGQc2Ef<L`UMX7<9GKQbmEg<L]eMc73H0000@0000
]eL007<L001H0000=000000000000000ooooooooool60000/UMc7:eGKQb]EfPL[EMS7;9GGQbgEehL
?@0000P0000K000040000>9G001N7000=P000100003RE`00GQ`005P0000d000000000000003ooooo
ooooo`H0003XEehLkEMS7>eGJ1c]EfhLj5Mc7>9GLa`f000040000>9G001c7000F00003@000000000
00000?oooooooooo1P000=aGLacGEfhLeeMX7=MGHacLEehLhUMN73d0000800006`000100000=F000
GQ`003H0000@00003EP005hL001H0000=000000000000000ooooooooool600004eQN71MHHa`GF6PL
5eQ^71=HLa`=F7<L=P000100000=F000La`005P0000d000000000000003oooooooooo`H00007F7<L
0UQ^709HJ1`2F6<L1eQN70eHGQ`m0000200001/0000@0000=eP005hL000f0000400003QH001N7000
F00003@00000000000000?oooooooooo1P0003eHGQa2F6<L@UQX749HKQ`mF7<L>5Qc73H0000@0000
=eP007<L001H0000=000000000000000ooooooooool60000<UQc72eHKQ`]F6PL;EQS739HGQ`gF5hL
?@0000P0000K00004000069H001N7000=P000100001RF000GQ`005P0000d000000000000003ooooo
ooooo`H0001XF5hLKEQS76eHJ1a]F6hLJ5Qc769HLa`f00004000069H001c7000F00003@000000000
00000?oooooooooo1P0005aHLaaHF6hLF5QX75QHHaaLF5hLHUQN73d0000800006`000100002=F000
GQ`003H0000@0000SEP005hL001H0000=000000000000000ooooooooool60000TeQN79QHHabHF6PL
V5Q^79=HLab=F7<L=P000100002=F000La`005P0000d000000000000003oooooooooo`H00027F7<L
PUQ^789HJ1b2F6<LQeQN78eHGQ`m0000200001/0000@0000^5P005hL000f000040000;QH001N7000
F00003@00000000000000?oooooooooo1P000;eHGQc2F6<L`UQX7<9HKQbmF7<L^5Qc73H0000@0000
^5P007<L001H0000=000000000000000ooooooooool60000/UQc7:eHKQb]F6PL[EQS7;9HGQbhF5hL
?@0000P0000K000040000>9H001N7000=P000100003RF000GQ`005P0000d000000000000003ooooo
ooooo`H0003XF5hLkEQS7>eHJ1c]F6hLj5Qc7>9HLa`f000040000>9H001c7000F00003@000000000
00000?oooooooooo1P000=aHLacHF6hLf5QX7=QHHacLF5hLhUQN73d0000800006`000100000=F@00
GQ`003H0000@00003ET005hL001H0000=000000000000000ooooooooool600004eUN71QIHa`HFFPL
65U^71=ILa`=FG<L=P000100000=F@00La`005P0000d000000000000003oooooooooo`H00007FG<L
0UU^709IJ1`2FF<L1eUN70eIGQ`m0000200001/0000@0000>5T005hL000f0000400003QI001N7000
F00003@00000000000000?oooooooooo1P0003iIGQa2FF<L@UUX749IKQ`nFG<L>5Uc73H0000@0000
>5T007<L001H0000=000000000000000ooooooooool60000<UUc72eIKQ`]FFPL;EUS739IGQ`hFEhL
?@0000P0000K00004000069I001N7000=P000100001RF@00GQ`005P0000d000000000000003ooooo
ooooo`H0001XFEhLKEUS76eIJ1a]FFhLJ5Uc769ILa`f00004000069I001c7000F00003@000000000
00000?oooooooooo1P0005aILaaHFFhLF5UX75QIHaaLFEhLHUUN73d0000800006`000100002=F@00
GQ`003H0000@0000SET005hL001H0000=000000000000000ooooooooool60000TeUN79QIHabHFFPL
V5U^79=ILab=FG<L=P000100002=F@00La`005P0000d000000000000003oooooooooo`H00027FG<L
PUU^789IJ1b2FF<LQeUN78eIGQ`m0000200001/0000@0000^5T005hL000f000040000;QI001N7000
F00003@00000000000000?oooooooooo1P000;iIGQc2FF<L`UUX7<9IKQbnFG<L^5Uc73H0000@0000
^5T007<L001H0000=000000000000000ooooooooool60000/UUc7:eIKQb]FFPL[EUS7;9IGQbhFEhL
?@0000P0000K000040000>9I001N7000=P000100003RF@00GQ`005P0000d000000000000003ooooo
ooooo`H0003XFEhLkEUS7>eIJ1c]FFhLj5Uc7>9ILa`f000040000>9I001c7000F00003@000000000
00000?oooooooooo1P000=eILacHFFhLf5UX7=QIHacMFEhLhUUN73d0000800006`000100000=FP00
GQ`003H0000@00003EX005hL001H0000=000000000000000ooooooooool600004eYN71QJHa`HFVPL
65Y^71=JLa`=FW<L=P000100000=FP00La`005P0000d000000000000003oooooooooo`H00007FW<L
0UY^709JJ1`2FV<L1eYN70eJGQ`m0000200001/0000@0000>5X005hL000f0000400003QJ001N7000
F00003@00000000000000?oooooooooo1P0003iJGQa2FV<L@UYX749JKQ`nFW<L>5Yc73H0000@0000
>5X007<L001H0000=000000000000000ooooooooool60000<UYc72eJKQ`]FVPL;EYS739JGQ`hFUhL
?@0000P0000K0000400006=J001N7000=P000100001SFP00GQ`005P0000d000000000000003ooooo
ooooo`H0001XFUhLKEYS76eJJ1a]FVhLJ5Yc76=JLa`f0000400006=J001c7000F00003@000000000
00000?oooooooooo1P0005eJLaaHFVhLF5YX75QJHaaMFUhLHeYN73d0000800006`000100002=FP00
GQ`003H0000@0000SEX005hL001H0000=000000000000000ooooooooool60000TeYN79QJHabHFVPL
V5Y^79=JLab=FW<L=P000100002=FP00La`005P0000d000000000000003oooooooooo`H00027FW<L
PeY^78=JJ1b3FV<LQeYN78eJGQ`m0000200001/0000@0000^5X005hL000f000040000;QJ001N7000
F00003@00000000000000?oooooooooo1P000;iJGQc3FV<L`eYX7<=JKQbnFW<L^5Yc73H0000@0000
^5X007<L001H0000=000000000000000ooooooooool60000/UYc7:eJKQb]FVPL[EYS7;9JGQbhFUhL
?@0000P0000K000040000;iJ001>7000=P000100002nFP00CQ`005P0000d000000000000003ooooo
ooooo`H0002nFTPL`eY47<QJA1c>FT@LdeY87==JCQ`f000040000==J001>7000F00003@000000000
00000?oooooooooo1P000==JE1c>FUTLb5YI7<=JFAbnFU@L_UY>73d0000800006`000100002nFP00
91`003H0000@0000_UX002@L001H0000=000000000000000ooooooooool60000_UXN7<=J6Ac8FQTL
cUXI7==J7QcCFR@L=P000100003CFP0091`005P0000d000000000000003oooooooooo`H0003CFRXL
cUX^7<QJ;Qc3FRhL_UXZ7;iJ91`m0000200001/0000@0000_UX00?TK000f000040000;iJ003i6`00
F00003@00000000000000?oooooooooo1P000;iJla_3F^hKb5[^6liJkQ_CF_<Kde[i6cH0000@0000
deX00?TK001H0000=000000000000000ooooooooool60000de[o6liJ11c8FP@L`eX47;iJoa^nF_TK
?@0000P0000K000040000;iJ003>6`00=P000100002nFP00cQ/005P0000d000000000000003ooooo
ooooo`H0002nF/PK`e[46lQJa1_>F/@Kde[86m=JcQ/f000040000==J003>6`00F00003@000000000
00000?oooooooooo1P000==Je1_>F]TKb5[I6l=JfA^nF]@K_U[>6cd0000800006`000100002nFP00
Y1/003H0000@0000_UX00:@K001H0000=000000000000000ooooooooool60000_UZN6l=JVA_8FYTK
cUZI6m=JWQ_CFZ@K=P000100003CFP00Y1/005P0000d000000000000003oooooooooo`H0003CFZTK
cUZ^6lQJ[Q_3FZhK_UZY6kiJY1/m0000200001/0000@0000_UX007TK000f000040000;iJ001i6`00
F00003@00000000000000?oooooooooo1P000;iJLa_3FVhKb5Y^6liJKQ_CFW<KdeYi6cH0000@0000
deX007TK001H0000=000000000000000ooooooooool60000deYo6liJQ1_8FX@K`eZ46kiJOa^nFWTK
?@0000P0000K000040000;iJ001>6`00=P000100002nFP00CQ/005P0000d000000000000003ooooo
ooooo`H0002nFTPK`eY46lQJA1_>FT@KdeY86m=JCQ/f000040000==J001>6`00F00003@000000000
00000?oooooooooo1P000==JE1_>FUTKb5YI6l=JFA^nFU@K_UY>6cd0000800006`000100002nFP00
91/003H0000@0000_UX002<K001H0000=000000000000000ooooooooool60000_UXN6l=J6A_8FQTK
cUXI6m=J7Q_CFR<K=P000100003CFP0091/005P0000d000000000000003oooooooooo`H0003CFRTK
cUX^6lQJ;Q_3FRhK_UXY6kiJ91/m0000200001/0000@0000_UX00?TJ000f000040000;iJ003i6P00
F00003@00000000000000?oooooooooo1P000;iJla[3F^hJb5[^6/iJkQ[CF_<Jde[i6SH0000@0000
deX00?TJ001H0000=000000000000000ooooooooool60000de[o6/iJ0a_8FP<K`eX36kiJoaZnF_TJ
?@0000P0000K000040000;iJ003>6P00=P000100002nFP00cQX005P0000d000000000000003ooooo
ooooo`H0002nF/PJ`e[36/QJ`a[>F/<Jde[86]=JcQXf000040000==J003>6P00F00003@000000000
00000?oooooooooo1P000==Je1[>F]TJb5[I6/=JfAZnF]@J_U[>6Sd0000800006`000100002nFP00
XaX003H0000@0000_UX00:<J001H0000=000000000000000ooooooooool60000_UZN6/=JVA[8FYTJ
cUZI6]=JWQ[CFZ<J=P000100003CFP00XaX005P0000d000000000000003oooooooooo`H0003CFZTJ
cUZ^6/QJ[Q[3FZhJ_UZY6[iJXaXm0000200001/0000@0000_UX007TJ000f000040000;iJ001i6P00
F00003@00000000000000?oooooooooo1P000;iJLa[3FVhJb5Y^6/iJKQ[CFW<JdeYi6SH0000@0000
deX007TJ001H0000=000000000000000ooooooooool60000deYo6/iJPa[8FX<J`eZ36[iJOaZnFWTJ
?@0000P0000K000040000;iJ001>6P00=P000100002nFP00CQX005P0000d000000000000003ooooo
ooooo`H0002nFTPJ`eY36/QJ@a[>FT<JdeY86]=JCQXf000040000==J001>6P00F00003@000000000
00000?oooooooooo1P000==JE1[>FUTJb5YI6/=JFAZnFU@J_UY>6Sd0000800006`000100002nFP00
8aX003H0000@0000_UX002<J001H0000=000000000000000ooooooooool60000_UXM6/=J6A[8FQTJ
cUXI6]=J7A[CFR<J=P000100003CFP008aX005P0000d000000000000003oooooooooo`H0003CFRTJ
cUX^6/QJ;Q[3FRhJ_UXY6[iJ8aXm0000200001/0000@0000_UX00?TI000f000040000;iJ003i6@00
F00003@00000000000000?oooooooooo1P000;iJlaW3F^hIb5[^6LiJkQWCF_<Ide[i6CH0000@0000
deX00?TI001H0000=000000000000000ooooooooool60000de[o6LiJ0a[8FP<J`eX36[iJoaVnF_TI
?@0000P0000K000040000;iJ003>6@00=P000100002nFP00cQT005P0000d000000000000003ooooo
ooooo`H0002nF/PI`e[36LQJ`aW>F/<Ide[86M=JcQTf000040000==J003>6@00F00003@000000000
00000?oooooooooo1P000==Je1W>F]TIb5[I6L=JfAVnF]@I_U[>6Cd0000800006`000100002nFP00
XaT003H0000@0000_UX00:<I001H0000=000000000000000ooooooooool60000_UZM6L=JVAW8FYTI
cUZI6M=JWAWCFZ<I=P000100003CFP00XaT005P0000d000000000000003oooooooooo`H0003CFZTI
cUZ^6LQJ[QW3FZhI_UZY6KiJXaTm0000200001/0000@0000_UX007TI000f000040000;iJ001i6@00
F00003@00000000000000?oooooooooo1P000;iJLaW3FVhIb5Y^6LiJKQWCFW<IdeYi6CH0000@0000
deX007TI001H0000=000000000000000ooooooooool60000deYo6LiJPaW8FX<I`eZ36KiJOaVnFWTI
?@0000P0000K000040000;iJ001>6@00=P000100002nFP00CQT005P0000d000000000000003ooooo
ooooo`H0002nFTPI`eY36LQJ@aW>FT<IdeY86M=JCQTf000040000==J001>6@00F00003@000000000
00000?oooooooooo1P000==JE1W>FUTIb5YI6L=JFAVnFU@I_UY>6Cd0000800006`000100002nFP00
8aT003H0000@0000_UX002<I001H0000=000000000000000ooooooooool60000_UXM6L=J6AW8FQTI
cUXI6M=J7AWCFR<I=P000100003CFP008aT005P0000d000000000000003oooooooooo`H0003CFRTI
cUX^6LQJ;QW3FRhI_UXY6KiJ8aTm0000200001/0000@0000_UX00?TH000f000040000;iJ003i6000
F00003@00000000000000?oooooooooo1P000;iJlaS3F^hHb5[^6<iJkQSCF_<Hde[i63H0000@0000
deX00?TH001H0000=000000000000000ooooooooool60000de[n6<iJ0aW8FP<I`eX36KiJoQRnF_TH
?@0000P0000K000040000;iJ003>6000=P000100002nFP00cQP005P0000d000000000000003ooooo
ooooo`H0002nF/PH`e[36<QJ`aS>F/<Hde[86==JcQPf000040000==J003>6000F00003@000000000
00000?oooooooooo1P000==Je1S>F]THb5[I6<=JfARnF]@H_U[>63d0000800006`000100002nFP00
XaP003H0000@0000_UX00:<H001H0000=000000000000000ooooooooool60000_UZM6<=JV1S8FYPH
cUZH6==JWASCFZ<H=P000100003CFP00XaP005P0000d000000000000003oooooooooo`H0003CFZTH
cUZ^6<QJ[QS3FZhH_UZY6;iJXaPm0000200001/0000@0000_UX007PH000f000040000;iJ001h6000
F00003@00000000000000?oooooooooo1P000;iJLaS3FVhHb5Y^6<iJKQSCFW<HdeYh63H0000@0000
deX007PH001H0000=000000000000000ooooooooool60000deYn6<iJPaS8FX<H`eZ36;iJOQRnFWPH
?@0000P0000K000040000;iJ001>6000=P000100002nFP00CQP005P0000d000000000000003ooooo
ooooo`H0002nFTPH`eY36<QJ@aS>FT<HdeY86==JCQPf000040000==J001>6000F00003@000000000
00000?oooooooooo1P000==JE1S>FUPHb5YH6<=JF1RnFU@H_UY>63d0000800006`000100002nFP00
8aP003H0000@0000_UX002<H001H0000=000000000000000ooooooooool60000_UXM6<=J61S8FQPH
cUXH6==J7ASCFR<H=P000100003CFP008aP005P0000d000000000000003oooooooooo`H0003CFRTH
cUX^6<QJ;QS3FRhH_UXY6;iJ8aPm0000200001/0000@0000_UX00?PG000f000040000;iJ003h5`00
F00003@00000000000000?oooooooooo1P000;iJlaO3F^hGb5[^5liJkQOCF_<Gde[h5cH0000@0000
deX00?PG001H0000=000000000000000ooooooooool60000de[n5liJ0aS8FP<H`eX36;iJoQNnF_PG
?@0000P0000K000040000;iJ003>5`00=P000100002nFP00cQL005P0000d000000000000003ooooo
ooooo`H0002nF/PG`e[35lQJ`aO>F/<Gde[85m=JcQLf000040000==J003>5`00F00003@000000000
00000?oooooooooo1P000==Je1O>F]PGb5[H5l=Jf1NnF]@G_U[>5cd0000800006`000100002nFP00
XaL003H0000@0000_UX00:<G001H0000=000000000000000ooooooooool60000_UZM5l=JV1O8FYPG
cUZH5m=JWAOCFZ<G=P000100003CFP00XaL005P0000d000000000000003oooooooooo`H0003CFZTG
cUZ^5lQJ[QO3FZhG_UZY5kiJXaLm0000200001/0000@0000_UX007PG000f000040000;iJ001h5`00
F00003@00000000000000?oooooooooo1P000;iJLQO3FVhGb5Y^5liJKQOCFW8GdeYh5cH0000@0000
deX007PG001H0000=000000000000000ooooooooool60000deYn5liJPaO8FX<G`eZ35kiJOQNnFWPG
?@0000P0000K000040000;iJ001>5`00=P000100002nFP00CQL005P0000d000000000000003ooooo
ooooo`H0002nFTPG`eY35lQJ@aO>FT<GdeY85m=JCQLf000040000==J001>5`00F00003@000000000
00000?oooooooooo1P000==JE1O>FUPGb5YH5l=JF1NnFU@G_UY>5cd0000800006`000100002nFP00
8aL003H0000@0000_UX002<G001H0000=000000000000000ooooooooool60000_UXM5l=J61O8FQPG
cUXH5m=J7AOCFR<G=P000100003CFP008aL005P0000d000000000000003oooooooooo`H0003CFRTG
cUX^5lQJ;QO3FRhG_UXY5kiJ8aLm0000200001/0000@0000_UX00?PF000f000040000;iJ003h5P00
F00003@00000000000000?oooooooooo1P000;iJlQK3F^hFb5[^5/iJkQKCF_8Fde[h5SH0000@0000
deX00?PF001H0000=000000000000000ooooooooool60000de[n5/iJ0aO8FP<G`eX35kiJoQJnF_PF
?@0000P0000K000040000;iJ003>5P00=P000100002nFP00cQH005P0000d000000000000003ooooo
ooooo`H0002nF/PF`e[35/QJ`aK>F/<Fde[85]=JcQHf000040000==J003>5P00F00003@000000000
00000?oooooooooo1P000==Je1K>F]PFb5[H5/=Jf1JnF]@F_U[>5Sd0000800006`000100002nFP00
XaH003H0000@0000_UX00:<F001H0000=000000000000000ooooooooool60000_UZM5/=JV1K8FYPF
cUZH5]=JWAKCFZ<F=P000100003CFP00XaH005P0000d000000000000003oooooooooo`H0003CFZTF
cUZ^5/QJ[QK3FZhF_UZY5[iJXaHm0000200001/0000@0000_UX007PF000f000040000;iJ001h5P00
F00003@00000000000000?oooooooooo1P000;iJLQK3FVhFb5Y^5/iJKQKCFW8FdeYh5SH0000@0000
deX007PF001H0000=000000000000000ooooooooool60000deYn5/iJPaK8FX<F`eZ35[iJOQJnFWPF
?@0000P0000K000040000;iJ001>5P00=P000100002nFP00CQH005P0000d000000000000003ooooo
ooooo`H0002nFTPF`eY35/QJ@aK>FT<FdeY85]=JCQHf000040000==J001>5P00F00003@000000000
00000?oooooooooo1P000==JDaK>FUPFb5YH5/=JF1JnFU<F_UY>5Sd0000800006`000100002nFP00
8aH003H0000@0000_UX002<F001H0000=000000000000000ooooooooool60000_UXM5/=J61K8FQPF
cUXH5]=J7AKCFR<F=P000100003CFP008aH005P0000d000000000000003oooooooooo`H0003CFRTF
cUX^5/QJ;QK3FRhF_UXY5[iJ8aHm0000200001/0000@0000_UX00?PE000f000040000;iJ003h5@00
F00003@00000000000000?oooooooooo1P000;iJlQG3F^dEb5[]5LiJkAGCF_8Ede[h5CH0000@0000
deX00?PE001H0000=000000000000000ooooooooool60000de[n5LiJ0aK8FP<F`eX35[iJoQFnF_PE
?@0000P0000K000040000;iJ003=5@00=P000100002nFP00cAD005P0000d000000000000003ooooo
ooooo`H0002nF/PE`e[35LQJ`aG>F/<Ede[85M=JcADf000040000==J003=5@00F00003@000000000
00000?oooooooooo1P000==JdaG>F]PEb5[H5L=Jf1FnF]<E_U[=5Cd0000800006`000100002nFP00
XaD003H0000@0000_UX00:<E001H0000=000000000000000ooooooooool60000_UZM5L=JV1G8FYPE
cUZH5M=JWAGCFZ<E=P000100003CFP00XaD005P0000d000000000000003oooooooooo`H0003CFZTE
cUZ]5LQJ[AG3FZdE_UZY5KiJXaDm0000200001/0000@0000_UX007PE000f000040000;iJ001h5@00
F00003@00000000000000?oooooooooo1P000;iJLQG3FVdEb5Y]5LiJKAGCFW8EdeYh5CH0000@0000
deX007PE001H0000=000000000000000ooooooooool60000deYn5LiJPaG8FX<E`eZ35KiJOQFnFWPE
?@0000P0000K000040000;iJ001=5@00=P000100002nFP00CAD005P0000d000000000000003ooooo
ooooo`H0002nFTPE`eY35LQJ@aG>FT<EdeY85M=JCADf000040000==J001=5@00F00003@000000000
00000?oooooooooo1P000==JDaG>FUPEb5YH5L=JF1FnFU<E_UY=5Cd0000800006`000100002nFP00
8aD003H0000@0000_UX002<E001H0000=000000000000000ooooooooool60000_UXM5L=J61G8FQPE
cUXH5M=J7AGCFR<E=P000100003CFP008aD005P0000d000000000000003oooooooooo`H0003CFRTE
cUX]5LQJ;AG3FRdE_UXY5KiJ8aDm0000200001/0000@0000_UX00?PD000f000040000;iJ003h5000
F00003@00000000000000?oooooooooo1P000;iJlQC3F^dDb5[]5<iJkACCF_8Dde[h53H0000@0000
deX00?PD001H0000=000000000000000ooooooooool60000de[n5<iJ0aG8FP<E`eX35KiJoQBnF_PD
?@0000P0000K000040000;iJ003=5000=P000100002nFP00cA@005P0000d000000000000003ooooo
ooooo`H0002nF/LD`e[35<QJ`aC>F/<Dde[75==JcA@f000040000==J003=5000F00003@000000000
00000?oooooooooo1P000==JdaC>F]PDb5[H5<=Jf1BnF]<D_U[=53d0000800006`000100002nFP00
Xa@003H0000@0000_UX00:<D001H0000=000000000000000ooooooooool60000_UZM5<=JV1C8FYPD
cUZH5==JWACCFZ<D=P000100003CFP00Xa@005P0000d000000000000003oooooooooo`H0003CFZTD
cUZ]5<QJ[AC3FZdD_UZY5;iJXa@m0000200001/0000@0000_UX007PD000f000040000;iJ001h5000
F00003@00000000000000?oooooooooo1P000;iJLQC3FVdDb5Y]5<iJKACCFW8DdeYh53H0000@0000
deX007PD001H0000=000000000000000ooooooooool60000deYn5<iJPaC8FX<D`eZ35;iJOQBnFWPD
?@0000P0000K000040000;iJ001=5000=P000100002nFP00CA@005P0000d000000000000003ooooo
ooooo`H0002nFTLD`eY35<QJ@aC>FT<DdeY75==JCA@f000040000==J001=5000F00003@000000000
00000?oooooooooo1P000==JDaC>FUPDb5YH5<=JF1BnFU<D_UY=53d0000800006`000100002nFP00
8a@003H0000@0000_UX002<D001H0000=000000000000000ooooooooool60000_UXM5<=J61C8FQPD
cUXH5==J7ACCFR<D=P000100003CFP008a@005P0000d000000000000003oooooooooo`H0003CFRPD
cUX]5<QJ;AC3FRdD_UXX5;iJ8a@m0000200001/0000@0000_UX00?PC000f000040000;iJ003h4`00
F00003@00000000000000?oooooooooo1P000;iJlQ?3F^dCb5[]4liJkA?CF_8Cde[h4cH0000@0000
deX00?PC001H0000=000000000000000ooooooooool60000de[n4liJ0aC8FP<D`eX35;iJoQ>nF_PC
?@0000P0000K000040000;iJ003=4`00=P000100002nFP00cA<005P0000d000000000000003ooooo
ooooo`H0002nF/LC`e[34lQJ`a?>F/<Cde[74m=JcA<f000040000==J003=4`00F00003@000000000
00000?oooooooooo1P000==Jda?>F]PCb5[H4l=Jf1>nF]<C_U[=4cd0000800006`000100002nFP00
Xa<003H0000@0000_UX00:<C001H0000=000000000000000ooooooooool60000_UZM4l=JV1?8FYPC
cUZH4m=JWA?CFZ<C=P000100003CFP00Xa<005P0000d000000000000003oooooooooo`H0003CFZPC
cUZ]4lQJ[A?3FZdC_UZX4kiJXa<m0000200001/0000@0000_UX007PC000f000040000;iJ001h4`00
F00003@00000000000000?oooooooooo1P000;iJLQ?3FVdCb5Y]4liJKA?CFW8CdeYh4cH0000@0000
deX007PC001H0000=000000000000000ooooooooool60000deYn4liJPa?8FX<C`eZ34kiJOQ>nFWPC
?@0000P0000K000040000;iJ001=4`00=P000100002nFP00CA<005P0000d000000000000003ooooo
ooooo`H0002nFTLC`eY24lQJ@Q?>FT8CdeY74m=JCA<f000040000==J001=4`00F00003@000000000
00000?oooooooooo1P000==JDa?>FUPCb5YH4l=JF1>nFU<C_UY=4cd0000800006`000100002nFP00
8Q<003H0000@0000_UX0028C001H0000=000000000000000ooooooooool60000_UXM4l=J61?8FQPC
cUXH4m=J7A?CFR8C=P000100003CFP008Q<005P0000d000000000000003oooooooooo`H0003CFRPC
cUX]4lQJ;A?3FRdC_UXX4kiJ8Q<m0000200001/0000@0000_UX00?PB000f000040000;iJ003h4P00
F00003@00000000000000?oooooooooo1P000;iJlQ;3F^dBb5[]4/iJkA;CF_8Bde[h4SH0000@0000
deX00?PB001H0000=000000000000000ooooooooool60000de[n4/iJ0Q?8FP8C`eX24kiJoQ:nF_PB
?@0000P0000K000040000;iJ003=4P00=P000100002nFP00cA8005P0000d000000000000003ooooo
ooooo`H0002nF/LB`e[24/QJ`Q;>F/8Bde[74]=JcA8f000040000==J003=4P00F00003@000000000
00000?oooooooooo1P000==Jda;>F]PBb5[H4/=Jf1:nF]<B_U[=4Sd0000800006`000100002nFP00
XQ8003H0000@0000_UX00:8B001H0000=000000000000000ooooooooool60000_UZL4/=JV1;8FYPB
cUZH4]=JW1;CFZ8B=P000100003CFP00XQ8005P0000d000000000000003oooooooooo`H0003CFZPB
cUZ]4/QJ[A;3FZdB_UZX4[iJXQ8m0000200001/0000@0000_UX007PB000f000040000;iJ001h4P00
F00003@00000000000000?oooooooooo1P000;iJLQ;3FVdBb5Y]4/iJKA;CFW8BdeYh4SH0000@0000
deX007PB001H0000=000000000000000ooooooooool60000deYn4/iJPQ;8FX8B`eZ24[iJOQ:nFWPB
?@0000P0000K000040000;iJ001=4P00=P000100002nFP00CA8005P0000d000000000000003ooooo
ooooo`H0002nFTLB`eY24/QJ@Q;>FT8BdeY74]=JCA8f000040000==J001=4P00F00003@000000000
00000?oooooooooo1P000==JDa;>FUPBb5YH4/=JF1:nFU<B_UY=4Sd0000800006`000100002nFP00
8Q8003H0000@0000_UX0028B001H0000=000000000000000ooooooooool60000_UXL4/=J61;8FQPB
cUXH4]=J71;CFR8B=P000100003CFP008Q8005P0000d000000000000003oooooooooo`H0003CFRPB
cUX]4/QJ;A;3FRdB_UXX4[iJ8Q8m0000200001/0000@0000_UX00?PA000f000040000;iJ003h4@00
F00003@00000000000000?oooooooooo1P000;iJlQ73F^dAb5[]4LiJkA7CF_8Ade[h4CH0000@0000
deX00?PA001H0000=000000000000000ooooooooool60000de[n4LiJ0Q;8FP8B`eX24[iJoQ6nF_PA
?@0000P0000K000040000;iJ003=4@00=P000100002nFP00cA4005P0000d000000000000003ooooo
ooooo`H0002nF/LA`e[24LQJ`Q7>F/8Ade[74M=JcA4f000040000==J003=4@00F00003@000000000
00000?oooooooooo1P000==Jda7>F]PAb5[H4L=Jf16nF]<A_U[=4Cd0000800006`000100002nFP00
XQ4003H0000@0000_UX00:8A001H0000=000000000000000ooooooooool60000_UZL4L=JV178FYPA
cUZH4M=JW17CFZ8A=P000100003CFP00XQ4005P0000d000000000000003oooooooooo`H0003CFZPA
cUZ]4LQJ[A73FZdA_UZX4KiJXQ4m0000200001/0000@0000_UX007PA000f000040000;iJ001h4@00
F00003@00000000000000?oooooooooo1P000;iJLQ73FVdAb5Y]4LiJKA7CFW8AdeYh4CH0000@0000
deX007PA001H0000=000000000000000ooooooooool60000deYm4LiJPQ78FX8A`eZ24KiJOA6nFWPA
?@0000P0000K000040000;iJ001=4@00=P000100002nFP00CA4005P0000d000000000000003ooooo
ooooo`H0002nFTLA`eY24LQJ@Q7>FT8AdeY74M=JCA4f000040000==J001=4@00F00003@000000000
00000?oooooooooo1P000==JDa7>FUPAb5YH4L=JF16nFU<A_UY=4Cd0000800006`000100002nFP00
8Q4003H0000@0000_UX0028A001H0000=000000000000000ooooooooool60000_UXL4L=J6178FQPA
cUXH4M=J717CFR8A=P000100003CFP008Q4005P0000d000000000000003oooooooooo`H0003CFRPA
cUX]4LQJ;A73FRdA_UXX4KiJ8Q4m0000200001/0000@0000_UX00?P@000f000040000;iJ003h4000
F00003@00000000000000?oooooooooo1P000;iJlQ33F^d@b5[]4<iJkA3CF_8@de[h43H0000@0000
deX00?P@001H0000=000000000000000ooooooooool60000de[m4<iJ0Q78FP8A`eX24KiJoA2nF_P@
?@0000P0000K000040000;iJ003=4000=P000100002nFP00cA0005P0000d000000000000003ooooo
ooooo`H0002nF/L@`e[24<QJ`Q3>F/8@de[74==JcA0f000040000==J003=4000F00003@000000000
00000?oooooooooo1P000==Jda3>F]P@b5[H4<=Jf12nF]<@_U[=43d0000800006`000100002nFP00
XQ0003H0000@0000_UX00:8@001H0000=000000000000000ooooooooool60000_UZL4<=JUa38FYL@
cUZG4==JW13CFZ8@=P000100003CFP00XQ0005P0000d000000000000003oooooooooo`H0003CFZP@
cUZ]4<QJ[A33FZd@_UZX4;iJXQ0m0000200001/0000@0000_UX007L@000f000040000;iJ001g4000
F00003@00000000000000?oooooooooo1P000;iJLQ33FVd@b5Y]4<iJKA3CFW8@deYg43H0000@0000
deX007L@001H0000=000000000000000ooooooooool60000deYm4<iJPQ38FX8@`eZ24;iJOA2nFWL@
?@0000P0000K000040000;iJ001=4000=P000100002nFP00CA0005P0000d000000000000003ooooo
ooooo`H0002nFTL@`eY24<QJ@Q3>FT8@deY74==JCA0f000040000==J001=4000F00003@000000000
00000?oooooooooo1P000==JDa3>FUL@b5YG4<=JEa2nFU<@_UY=43d0000800006`000100002nFP00
8Q0003H0000@0000_UX0028@001H0000=000000000000000ooooooooool60000_UXL4<=J5a38FQL@
cUXG4==J713CFR8@=P000100003CFP008Q0005P0000d000000000000003oooooooooo`H0003CFRP@
cUX]4<QJ;A33FRd@_UXX4;iJ8Q0m0000200001/0000@0000_UX00?L?000f000040000;iJ003g3`00
F00003@00000000000000?oooooooooo1P000;iJl@o3F^d?b5[]3liJk@oCF_4?de[g3cH0000@0000
deX00?L?001H0000=000000000000000ooooooooool60000de[m3liJ0Q38FP8@`eX24;iJo@nnF_L?
?@0000P0000K000040000;iJ003=3`00=P000100002nFP00c@l005P0000d000000000000003ooooo
ooooo`H0002nF/L?`e[23lQJ`Po>F/8?de[73m=Jc@lf000040000==J003=3`00F00003@000000000
00000?oooooooooo1P000==Jd`o>F]L?b5[G3l=Je`nnF]<?_U[=3cd0000800006`000100002nFP00
XPl003H0000@0000_UX00:8?001H0000=000000000000000ooooooooool60000_UZL3l=JU`o8FYL?
cUZG3m=JW0oCFZ8?=P000100003CFP00XPl005P0000d000000000000003oooooooooo`H0003CFZP?
cUZ]3lQJ[@o3FZd?_UZX3kiJXPlm0000200001/0000@0000_UX007L?000f000040000;iJ001g3`00
F00003@00000000000000?oooooooooo1P000;iJL@o3FVd?b5Y]3liJK@oCFW4?deYg3cH0000@0000
deX007L?001H0000=000000000000000ooooooooool60000deYm3liJPPo8FX8?`eZ23kiJO@nnFWL?
?@0000P0000K000040000;iJ001=3`00=P000100002nFP00C@l005P0000d000000000000003ooooo
ooooo`H0002nFTL?`eY23lQJ@Po>FT8?deY73m=JC@lf000040000==J001=3`00F00003@000000000
00000?oooooooooo1P000==JD`o>FUL?b5YG3l=JE`nnFU<?_UY=3cd0000800006`000100002nFP00
8Pl003H0000@0000_UX0028?001H0000=000000000000000ooooooooool60000_UXL3l=J5`o8FQL?
cUXG3m=J70oCFR8?=P000100003CFP008Pl005P0000d000000000000003oooooooooo`H0003CFRP?
cUX]3lQJ;@o3FRd?_UXX3kiJ8Plm0000200001/0000@0000_UX00?L>000f000040000;iJ003g3P00
F00003@00000000000000?oooooooooo1P000;iJl@k3F^d>b5[]3/iJk@kCF_4>de[g3SH0000@0000
deX00?L>001H0000=000000000000000ooooooooool60000de[m3/iJ0Po8FP8?`eX23kiJo@jnF_L>
?@0000P0000K000040000;iJ003=3P00=P000100002nFP00c@h005P0000d000000000000003ooooo
ooooo`H0002nF/L>`e[23/QJ`Pk>F/8>de[73]=Jc@hf000040000==J003=3P00F00003@000000000
00000?oooooooooo1P000==JdPk>F]L>b5[G3/=Je`jnF]8>_U[=3Sd0000800006`000100002nFP00
XPh003H0000@0000_UX00:8>001H0000=000000000000000ooooooooool60000_UZL3/=JU`k8FYL>
cUZG3]=JW0kCFZ8>=P000100003CFP00XPh005P0000d000000000000003oooooooooo`H0003CFZP>
cUZ]3/QJ[@k3FZd>_UZX3[iJXPhm0000200001/0000@0000_UX007L>000f000040000;iJ001g3P00
F00003@00000000000000?oooooooooo1P000;iJL@k3FVd>b5Y]3/iJK@kCFW4>deYg3SH0000@0000
deX007L>001H0000=000000000000000ooooooooool60000deYm3/iJPPk8FX8>`eZ23[iJO@jnFWL>
?@0000P0000K000040000;iJ001=3P00=P000100002nFP00C0h005P0000d000000000000003ooooo
ooooo`H0002nFTL>`eY23/QJ@Pk>FT8>deY73]=JC0hf000040000==J001=3P00F00003@000000000
00000?oooooooooo1P000==JDPk>FUL>b5YG3/=JE`jnFU8>_UY=3Sd0000800006`000100002nFP00
8Ph003H0000@0000_UX0028>001H0000=000000000000000ooooooooool60000_UXL3/=J5`k8FQL>
cUXG3]=J70kCFR8>=P000100003CFP008Ph005P0000d000000000000003oooooooooo`H0003CFRP>
cUX/3/QJ;0k3FR`>_UXX3[iJ8Phm0000200001/0000@0000_UX00?L=000f000040000;iJ003g3@00
F00003@00000000000000?oooooooooo1P000;iJl@g3F^`=b5[/3LiJk0gCF_4=de[g3CH0000@0000
deX00?L=001H0000=000000000000000ooooooooool60000de[m3LiJ0Pk8FP8>`eX23[iJo@fnF_L=
?@0000P0000K000040000;iJ003<3@00=P000100002nFP00c0d005P0000d000000000000003ooooo
ooooo`H0002nF/L=`e[23LQJ`Pg>F/8=de[73M=Jc0df000040000==J003<3@00F00003@000000000
00000?oooooooooo1P000==JdPg>F]L=b5[G3L=Je`fnF]8=_U[<3Cd0000800006`000100002nFP00
XPd003H0000@0000_UX00:8=001H0000=000000000000000ooooooooool60000_UZL3L=JU`g8FYL=
cUZG3M=JW0gCFZ8==P000100003CFP00XPd005P0000d000000000000003oooooooooo`H0003CFZP=
cUZ/3LQJ[0g3FZ`=_UZX3KiJXPdm0000200001/0000@0000_UX007L=000f000040000;iJ001g3@00
F00003@00000000000000?oooooooooo1P000;iJL@g3FV`=b5Y/3LiJK0gCFW4=deYg3CH0000@0000
deX007L=001H0000=000000000000000ooooooooool60000deYm3LiJPPg8FX8=`eZ23KiJO@fnFWL=
?@0000P0000K000040000;iJ001<3@00=P000100002nFP00C0d005P0000d000000000000003ooooo
ooooo`H0002nFTH=`eY23LQJ@Pg>FT8=deY63M=JC0df000040000==J001<3@00F00003@000000000
00000?oooooooooo1P000==JDPg>FUL=b5YG3L=JE`fnFU8=_UY<3Cd0000800006`000100002nFP00
8Pd003H0000@0000_UX0028=001H0000=000000000000000ooooooooool60000_UXL3L=J5`g8FQL=
cUXG3M=J70gCFR8==P000100003CFP008Pd005P0000d000000000000003oooooooooo`H0003CFRP=
cUX/3LQJ;0g3FR`=_UXX3KiJ8Pdm0000200001/0000@0000_UX00?L<000f000040000;iJ003g3000
F00003@00000000000000?oooooooooo1P000;iJl@c3F^`<b5[/3<iJk0cCF_4<de[g33H0000@0000
deX00?L<001H0000=000000000000000ooooooooool60000de[m3<iJ0Pg8FP8=`eX23KiJo@bnF_L<
?@0000P0000K000040000;iJ003<3000=P000100002nFP00c0`005P0000d000000000000003ooooo
ooooo`H0002nF/H<`e[23<QJ`Pc>F/8<de[63==Jc0`f000040000==J003<3000F00003@000000000
00000?oooooooooo1P000==JdPc>F]L<b5[G3<=Je`bnF]8<_U[<33d0000800006`000100002nFP00
XP`003H0000@0000_UX00:8<001H0000=000000000000000ooooooooool60000_UZL3<=JU`c8FYL<
cUZG3==JW0cCFZ8<=P000100003CFP00XP`005P0000d000000000000003oooooooooo`H0003CFZP<
cUZ/3<QJ[0c3FZ`<_UZX3;iJXP`m0000200001/0000@0000_UX007L<000f000040000;iJ001g3000
F00003@00000000000000?oooooooooo1P000;iJL@c3FV`<b5Y/3<iJK0cCFW4<deYg33H0000@0000
deX007L<001H0000=000000000000000ooooooooool60000deYm3<iJPPc8FX8<`eZ23;iJO@bnFWL<
?@0000P0000K000040000;iJ001<3000=P000100002nFP00C0`005P0000d000000000000003ooooo
ooooo`H0002nFTH<`eY23<QJ@Pc>FT8<deY63==JC0`f000040000==J001<3000F00003@000000000
00000?oooooooooo1P000==JDPc>FUL<b5YG3<=JE`bnFU8<_UY<33d0000800006`000100002nFP00
8P`003H0000@0000_UX0028<001H0000=000000000000000ooooooooool60000_UXL3<=J5`c8FQL<
cUXG3==J70cCFR8<=P000100003CFP008P`005P0000d000000000000003oooooooooo`H0003CFRL<
cUX/3<QJ;0c3FR`<_UXW3;iJ8P`m0000200001/0000@0000_UX00?L;000f000040000;iJ003g2`00
F00003@00000000000000?oooooooooo1P000;iJl@_3F^`;b5[/2liJk0_CF_4;de[g2cH0000@0000
deX00?L;001H0000=000000000000000ooooooooool60000de[m2liJ0Pc8FP8<`eX23;iJo@^nF_L;
?@0000P0000K000040000;iJ003<2`00=P000100002nFP00c0/005P0000d000000000000003ooooo
ooooo`H0002nF/H;`e[22lQJ`P_>F/8;de[62m=Jc0/f000040000==J003<2`00F00003@000000000
00000?oooooooooo1P000==JdP_>F]L;b5[G2l=Je`^nF]8;_U[<2cd0000800006`000100002nFP00
XP/003H0000@0000_UX00:4;001H0000=000000000000000ooooooooool60000_UZL2l=JU`_8FYL;
cUZG2m=JW0_CFZ4;=P000100003CFP00XP/005P0000d000000000000003oooooooooo`H0003CFZL;
cUZ/2lQJ[0_3FZ`;_UZW2kiJXP/m0000200001/0000@0000_UX007L;000f000040000;iJ001g2`00
F00003@00000000000000?oooooooooo1P000;iJL@_3FV`;b5Y/2liJK0_CFW4;deYg2cH0000@0000
deX007L;001H0000=000000000000000ooooooooool60000deYm2liJP@_8FX4;`eZ12kiJO@^nFWL;
?@0000P0000K000040000;iJ001<2`00=P000100002nFP00C0/005P0000d000000000000003ooooo
ooooo`H0002nFTH;`eY12lQJ@@_>FT4;deY62m=JC0/f000040000==J001<2`00F00003@000000000
00000?oooooooooo1P000==JDP_>FUL;b5YG2l=JE`^nFU8;_UY<2cd0000800006`000100002nFP00
8@/003H0000@0000_UX0024;001H0000=000000000000000ooooooooool60000_UXL2l=J5`_8FQL;
cUXG2m=J70_CFR4;=P000100003CFP008@/005P0000d000000000000003oooooooooo`H0003CFRL;
cUX/2lQJ;0_3FR`;_UXW2kiJ8@/m0000200001/0000@0000_UX00?L:000f000040000;iJ003g2P00
F00003@00000000000000?oooooooooo1P000;iJl@[3F^`:b5[/2/iJk0[CF_4:de[g2SH0000@0000
deX00?L:001H0000=000000000000000ooooooooool60000de[m2/iJ0@_8FP4;`eX12kiJo@ZnF_L:
?@0000P0000l0000200003l0000H0000a@<00:/0002_1@00b@4001<0000<00000@0002D0000<0000
0000P2D0000<00001`00P2@0000T00000020@@00000000000020@@00000000000P0002P0000<0000
0`000280000<0000ooooodH0000L0000400004E=AR/4@0003000000000160000500000P00017A4U3
0`000240000800007P0001P0003<0`00[`000:X500370@00DP00070100030000kOooo`0000000000
000009010000000000008440LP1Y0640K00000000000000000000000000000000000000000000000
0000000000000000000000000000008`2P@00040002HPQ<0N0000000000HPa<0i8<C07P000200000
V88C0000000DPa<00@000000001I;[0`4P0001CId04HPa<0dj/0<9cHd058Pa<030000:Cgd054S1<0
8@00000000400000E01Q06P0K`1]0640000000005E_/dQMKR=:K0>214`1ACaEKd=>K01cBV`1DdY/0
n=6K02`0001j0000;0<009P00004PQ<0@3lEFl3EV`0001EK@=JK08244`3hdI/0000000000@010080
fCk4MgU?a7L[2PZ<G00004R24`2Lf=01;88C01_g030[2PZ<I7H02000000U0000300000<0000D0000
300000d0000B000030000040001D0000E00009L5000H0@00X`D002d100010000000P@P0084:G1@00
60400040001<00000000000000000000oooooooooom@0000D00000d0001D0000E00009/5000`0@00
X0D004D100010000000P@P0084:K1@00<0400040001<00000000000000000000oooooooooom@0000
B@0000H0001D0000E00009L500180@00X`D005d100010000000P@P0084:G1@00B0400040001<0000
0000000000000000oooooooooom@0000D`0000d0000U0000300000d0080R000030000?oooolQ0000
200001T0000<0000oooo01P0000<0000000001h0000H00006P000140003b0P00P@400280000<0000
oooooaP0000<0000000001T0000<0000oooo02D0000<00000000P2D0000<00003@00P4H0000X0000
700004M4BD<20000gP@009X100281@00_@40000000160000D00004@00015CDH[:T0002@0000H0000
0020?`00000000000020?`00000000002T00`1`0000@0000ooooo`40003O19/1Z00Q02P0000<0000
1@00024000080000HP0000`000010000900002@00000080m000000000000080m0000000000020000
9`0001P00005000000000?ooo`0000009@0000`0000500009@0000`000080020C00006@0003O1000
V`4008H5002k0@00j4d00:PI00202P0040800240l000000000000000P3l0000000000000P3l00000
00000000000000000000000000000000000002D0000<00001`00P2D0000<00000000P2@0000T0000
0020@@00000000000020@@00000000000P0004H000280000O00004E=AR/8@0h2?000030000014<3K
000005H0000000000020?`80000200000000@@8000014<3K000000000?l8@0l3;000020000014<3K
10000010003O19/1g`Bl0HL5_0671I/10041PAE03`0@0000100000h0000j0000300000P0000T0000
90000000P3d0000000000000P3d0000000000080001O0000>00000H0000h0000000003P000000000
02010100000000000000000000000000000002D0000<00001P0002D0000<00001@00P5H0000/0000
dP@008h1002C1@00b04000@0003XCJPIj4fh6fQH^1]XF:PI9@0000`0000700209@0000`000000020
900002@00000081100000000000008110000000000020000:00000`000060000>P0000`0000:0000
8P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000000004H0000D0000200004M4BD<30000
AP0002P0000L0000AdA9@`80003P0`004`4000h4002m0@00000004H0001@0000A00004E=AR/Z@000
900001P00000080o000000000000080o00000000000:@03070000100003ooooo0@000>43504/0:P0
8@0000P0001R000030000040000T000090000000P3d0000000000000P3d0000000000080000U0000
300000D0000U0000300000P0081<0000I0000>43000D0@0030@00;/10008?P00>1400<0200202P00
8@3`0000000000000020?`00000000000020?`000000000000000000000000000000000000000000
9@0000`0000700209@0000`000000020900002@00000081100000000000008110000000000020000
AP0008P0001l0000ADe6:`Q0408l0000<000004@`=/00000EP0000000000080o0P00008000000011
0P00004@`=/000000000o`Q04@</00008000004@`=/4000004000>43507Q0k`13@Bl0@d450400@61
5D0A010000040000400003X0000<0000200002@0000T00000020?@00000000000020?@0000000000
0P0005l0000h00001P0003P000000000>00000000000804040000000000000000000000000000000
9@0000`0000600009@0000`000050020EP0002`0003D0`001`4001T400380@00100000Pn>148?[PK
b42h6lQ0>14U0000300000L0080U000030000000080T000090000000P440000000000000P4400000
00000080000X0000300000H0000j0000300000X0000R000030000?oooom60000700001000015CDH[
140000`000000000AP0001@000080000AdA9@`<000160000:00001`00017A4U30P0000/4002V0@00
g@@00;8100000000AP0000@1003h0000ADe6:bY0000T000060000000P3l0000000000000P3l00000
000000Q04P:L0000T000004@`=/00000GQ0000000000080o0P000?l0000200000000@@80001H0000
0A30f`00000100000P0005IEED00000000000000000002110020?`000000000000000000000L0000
0A30f`<00000H0000P3lo`00003nooco0061004@`=/000000000o`Q04`<T00006000004@`=/20000
04000=`4[04=1:`1004001E04`0@000010000180000X0000300000D0000Q000020000680000<0000
0@0002@0000T00000020?@00000000000020?@00000000000P0005l0000h00001@0003P000000000
>000000000004P40400000000000000000000000000000009@0000`0000500009`0001P000060000
00000000000000009@0000`0000600004`0000`000020000>`0000P0000K000040000;Q=00306P00
=P000100003n@000`1X005P0000d000000000000003oooooooooo`H0003i@<0JmT2m6_I0^1[f@;@J
nD2`6_i0/1Xf000040000;Q=002`6P00F00003@00000000000000?oooooooooo1P000;e=/1[0CK@J
`4fh6/1=_AZmCL0J^4g06Sd0000800006`0001000018@@00n1X005T0000T000000000000003ooooo
ooooo`800038@;PJB45h6Sd000080000?00000P0000o0000600000/4002V0@00gP@00;41000C0000
30000040000U000030000000080U0000300000L0080T000090000000P440000000000000P4400000
00000080000X0000300000D0000R000030000?oooom60000700001000015CDH[140000`000000000
AP0001@000080000AdA9@`<000160000:00001`00017A4U30P000=d4001H0@00R0D007/100000000
AP00050000140000ADe6:bY0000T000060000000P3l0000000000000P3l00000000000Y00<0L0000
40000?ooool10000gPAI0JT08@0X0000300000H0000Q000020000680000<00000@0002@0000T0000
0020?@00000000000020?@00000000000P0002L0000H00001P000000003oool0000002D0000<0000
1P0002D0000<00002000P4`0001T0000gP@005T100261@00N@400=Q=00285@00T0X00102000Q0?00
000000000000080o000000000000080o0000000000000000000000000000000000000000000U0000
300000L0080U000030000000080T000090000000P440000000000000P44000000000008000160000
R00007`00015CDH[240D0S`0000`00000A30f`00001F000000000000P3l200000P00000004420000
0A30f`000000003o240E0b`0000P00000A30f`@00000@000gPAI0Mh4NP671GX1Q`EI0@010H4E@1D0
400000@0000D0000>P0000`000080000900002@00000080m000000000000080m0000000000020000
G`0003P000050000>0000000000h00000000000P0@0@0000000000000000000000000000000U0000
300000D0000U0000300000D0081F0000;0000=44001<0@00T`D008H100040000f4f85MQ=V1MXF9PG
J5R85BD0000<00001`00P2D0000<00000000P2@0000T00000020@@00000000000020@@0000000000
0P0002P0000<00001@0003X0000<00002P000280000<0000ooooodH0000L0000400004E=AR/4@000
3000000000160000500000P00017A4U30`0004H0000X0000700004M4BD<20000g`@0018100271@00
=@40000000160000D00004@00015CDH[:T0002@0000H00000020?`00000000000020?`0000000000
2T00`1`0000@0000ooooo`40003P11<1YP0Q024000080000HP0000`000010000900002@00000080m
000000000000080m00000000000200009@0000`0000600009@0000`000080020C00006@0003P1000
4`4008D5000c0@00n4d002PA001P2P0040800240l000000000000000P3l0000000000000P3l00000
00000000000000000000000000000000000002D0000<00001`00P2D0000<00000000P2@0000T0000
0020@@00000000000020@@00000000000P0004H000280000O00004E=AR/8@1H2?000030000014<3K
000005H0000000000020?`80000200000000@@8000014<3K000000000?l8@1L3;000020000014<3K
10000010003P11<1h0@d0HH5=0661A<10041PAE05`0@0000100001H0000j0000300000P0000T0000
90000000P3d0000000000000P3d0000000000080001O0000>00000D0000h0000000003P000000000
02010100000000000000000000000000000002D0000<00001@0002D0000<00001@00P5H0000/0000
d`@000H1002B1@00@04000@0003hCBPAn4dh4eQH>1=HF2PA9@0000`0000700209@0000`000000020
900002@00000081100000000000008110000000000020000:00000`000050000>P0000`0000:0000
8P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000000004H0000D0000200004M4BD<30000
AP0002P0000L0000AdA9@`80000D1@00VP4001H5002n0@00000004H0002X0000W00004E=AR/Z@000
900001P00000080o000000000000080o000000000008@1P2@00003@000014<3K000005h000000000
0020?`80000200000P000000044200000A30f`000000003o240I0b@0000H00000A30f`800000@000
5@FK0AD5_@400@005D0I0100000400006000024000080000HP0000`000010000900002@00000080m
000000000000080m0000000000020000G`0003P000050000>0000000000h0000000000000@0@0000
000000000000000000000000000U0000300000D0000U0000300000D0081G0000900001<5002I0@00
5PD00;h100020000B56X6DQAb1/U0000300000L0080U000030000000080T000090000000P4400000
00000000P440000000000080000X0000300000D0000R000030000?oooom60000700001000015CDH[
140000`000000000AP0001@000080000AdA9@`<000160000:00001`00017A4U30P0004`5002K0@00
CPD00;h100000000AP000:P0002L0000ADe6:bY0000T000060000000P3l0000000000000P3l00000
000000Q06P900000=000004@`=/00000GP0000000000080o0P000080000200000000@@8000014<3K
000000000?l8@1/3900001P000014<3K0P000010001=1I`1C@Fm0@01000E@1/0400000@0000J0000
8@0000P0001R000030000040000T000090000000P3d0000000000000P3d0000000000080001O0000
>00000D0000h0000000003P00000000000010100000000000000000000000000000002D0000<0000
1@0002D0000<00001@00P5L0000T0000B`D009X1001>1@00_P4000800038E;PIb5C86bD0000<0000
1`00P2D0000<00000000P2@0000T00000020@@00000000000020@@00000000000P0002P0000<0000
1@000280000<0000ooooodH0000L0000400004E=AR/4@0003000000000160000500000P00017A4U3
0`0004H0000X0000700004M4BD<20000g@@00<0000281@00h`00000000160000D00004@00015CDH[
:T0002@0000H00000020?`00000000000020?`00000000002T00`1`0000@0000ooooo`40003N1<40
Z@0Q024000080000HP0000`000010000900002@00000080m000000000000080m0000000000020000
9@0000`0000600009@0000`000080020C00006@0003N1000`@0008H5003Q0000f4d000P<002@2P00
40800240l000000000000000P3l0000000000000P3l0000000000000000000000000000000000000
000002D0000<00001`00P2D0000<00000000P2@0000T00000020@@00000000000020@@0000000000
0P0004H000280000O00004E=AR/8@1`2?000030000014<3K000005H0000000000020?`8000020000
0000@@8000014<3K000000000?l8@1d3;000020000014<3K10000010003N1<40gPCR08L5hP271L40
0041PAE07@0@0000100001`0000j0000300000P0000T000090000000P3d0000000000000P3d00000
00000080001O0000>00000D0000h0000000003P00000000002010100000000000000000000000000
000002D0000<00001@0002D0000<00001@00P5H0000/0000d@@00;@0002C1@00kP0000@0003HC@P<
f4dH3VQH60iXF0P<9@0000`0000700209@0000`000000020900002@0000008110000000000000811
0000000000020000:00000`000050000>P0000`0000:00008P0000`0003oooooAP0001`0000@0000
ADe6:`A0000<0000000004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80003_1000
X@4000`5002f0@00000004H0001@0000A00004E=AR/Z@000900001P00000080o000000000000080o
00000000000:@03070000100003ooooo0@000?04XP4K01<08@0000P0001R000030000040000T0000
90000000P3d0000000000000P3d0000000000080000U0000300000H0000U0000300000P0081<0000
I0000?04002R0@002PD00;@1003hCP0061X00;01000`0@008@3`0000000000000020?`0000000000
0020?`0000000000000000000000000000000000000000009@0000`0000700209@0000`000000020
900002@00000081100000000000008110000000000020000AP0008P0001l0000ADe6:`Q07P8l0000
<000004@`=/00000EP0000000000080o0P000080000000110P00004@`=/00000ooooo`Q07`</0000
8000004@`=/4000004000?04XP7`1;D12`Fe0@/5XP400@615D0O0100000400007P0003X0000<0000
200002@0000T00000020?@00000000000020?@00000000000P0005l0000h00001@0003P000000000
>00000000000804040000000003oool000000000000000009@0000`0000500009@0000`000050020
EP0002`0003S1000U@4001L500310@0010000?Q>61[hCTPKZ5186jQ@61XU0000300000L0080U0000
30000000080T000090000000P440000000000000P440000000000080000X0000300000D0000j0000
300000X0000R000030000?oooom60000700001000015CDH[140000`000000000AP0001@000080000
AdA9@`<0000Q0000200001h0000H0000l`@00:<100091@00]@4002D0000<00000@0002D0000<0000
0P0002D0000<00000@0002D0000<00003@00P2D0000<00000P0002D0000<00000@0001@0000<0000
3@000180000<00000@0005@0001H0000l`@00:D1003n1000]040004000000212000P@_<4002U0@00
0P0004`00000000000000000003ooooooooooe00001104T02@0000<0000U000030000080001D0000
E0000?l4002[0@000`D00;@100010000000P@P0084;o1000Z`400040001<00000000000000000000
oooooooooom@0000<`0000D0000U0000300000d0080R000030000?oooolQ0000200001T0000<0000
oooo01P0000<0000000001h0000H00006P000140003b0P00P@400280000<0000oooooaP0000<0000
000001T0000<0000oooo02D0000<00000000P2D0000<00003@00P4H0000X0000700004M4BD<20000
9@D00:4100111@00]P40000000160000D00004@00015CDH[:T0002@0000H00000020?`0000000000
0020?`00000000002T00`1`0000@0000ooooo`40000V1J816P0C024000080000HP0000`000010000
900002@00000080m000000000000080m00000000000200009@0000`0000600009@0000`000080020
C00006@0000V1@00XP4003l5002d0@00F58001PJ002P0@00<0400240l000000000000000P3l00000
00000000P3l0000000000000000000000000000000000000000002D0000<00001`00P2D0000<0000
0000P2@0000T00000020@@00000000000020@@00000000000P0004H000280000O00004E=AR/8@202
?000030000014<3K000005H0000000000020?`80000200000000@@8000014<3K00000?ooool8@243
;000020000014<3K10000010000V1J819PFe0D05]@501J810041PAE08@0@000010000200000j0000
300000P0000T000090000000P3d0000000000000P3d0000000000080001O0000>00000D0000h0000
000003P0000000000201010000000000oooo000000000000000002D0000<00001@0002D0000<0000
1@00P5H0000/00006@D009D1001<1@00`@4000@0001HDQPJF5986oQCB1_hDaPJ9@0000`000070020
9@0000`000000020900002@00000081100000000000008110000000000020000:00000`000050000
>P0000`0000:00008P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000000004H0000D0000
200004M4BD<300008@0000P0000N0000600002T5002S0@00?PD00;D1000U000030000040000U0000
30000080000U000030000040000U0000300000d0080U000030000080000U000030000040000D0000
300000d0000B000030000040001D0000F00002T5002U0@00=0D00;@100010000000P@P00848Y1@00
Y@400080001<00000000000000000000oooooooooom@0000@@1900T0000300009@0000`000020000
E00005@0000e1@00Z`4003T5002d0@000@00000084800212=@D00:/100010000C000000000000000
00000?ooooooooooD0000380000500009@0000`0000=00208P0000`0003ooooo8@0000P0000I0000
30000?ooo`0H000030000000000N0000600001X0000A0000lP800841000R000030000?oooolH0000
30000000000I000030000?ooo`0U000030000000080U0000300000d008160000:00001`00017A4U3
0P0005d5002S0@00M`D00;P100000000AP00050000140000ADe6:bY0000T000060000000P3l00000
00000000P3l00000000000Y00<0L000040000?ooool10000GPFT0AP04`0Q000020000680000<0000
0@0002@0000T00000020?@00000000000020?@00000000000P0002D0000<00001P0002D0000<0000
2000P4`0001T0000GPD00:@1001e1@00]P400=QE000h6P00P0400301000Q0?00000000000000080o
000000000000080o0000000000000000000000000000000000000000000U0000300000L0080U0000
30000000080T000090000000P440000000000000P44000000000008000160000R00007`00015CDH[
240R0S`0000`00000A30f`00001F000000000000P3l200000P000000044200000A30f`00003ooooo
240S0b`0000P00000A30f`@00000@000GPFT0Eh5]`5f1KL1MPFT0@010H4E@2<0400000@0000R0000
>P0000`000080000900002@00000080m000000000000080m0000000000020000G`0003P000050000
>0000000000h00000000000P0@0@000000000?ooo`00000000000000000U0000300000D0000U0000
300000D0081F0000;0000545002G0@00PPD00<<100040000f5Dh6]QEJ1]HEfPKF5Lh6RD0000<0000
1`00P2D0000<00000000P2@0000T00000020@@00000000000020@@00000000000P0002P0000<0000
1@0003X0000<00002P000280000<0000ooooodH0000L0000400004E=AR/4@0003000000000160000
500000P00017A4U30`000240000800007P0001P0001Q1@00Y@4007@5002g0@009@0000`000010000
9@0000`0000200009@0000`0000100009@0000`0000=00209@0000`0000200009@0000`000010000
500000`0000=00004P0000`000010000E00005P0001Q1@00Y`4006`5002f0@000@00000084800212
H@D00:L100020000C00000000000000000000?ooooooooooD0000440B@0900000`0002D0000<0000
0P0005@0001D0000K@D00:d1001a1@00]P40004000000212000P@Vd5002]0@000@0004`000000000
00000000003ooooooooooe00000a00001@0002D0000<00003@00P280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@000?8200210@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000000209@0000`0000=0020AP0002P0000L0000
AdA9@`80000V1@00GP4004<5001c0@00000004H0001@0000A00004E=AR/Z@000900001P00000080o
000000000000080o00000000000:@03070000100003ooooo0@0002L5G`4K01<08@0000P0001R0000
30000040000T000090000000P3d0000000000000P3d0000000000080000U0000300000H0000U0000
300000P0081<0000I00002L5001O0@00@@D00741001XDP00j1D00;01000`0@008@3`000000000000
0020?`00000000000020?`0000000000000000000000000000000000000000009@0000`000070020
9@0000`000000020900002@00000081100000000000008110000000000020000AP0008P0001l0000
ADe6:`Q0908l0000<000004@`=/00000EP0000000000080o0P000080000000110P00004@`=/00000
ooooo`Q09@</00008000004@`=/40000040002L5G`4W1G81@PEb0D85G`400@615D0U010000040000
900003X0000<0000200002@0000T00000020?@00000000000020?@00000000000P0005l0000h0000
1@0003P000000000>00000000000804040000000003oool000000000000000009@0000`000050000
9@0000`000050020EP0002`0000J1@00DP4004h5001n0@00100006QBj1EXDQPG65@H5aQDj1DU0000
300000L0080U000030000000080T000090000000P440000000000000P440000000000080000X0000
300000D0000j0000300000X0000R000030000?oooom60000700001000015CDH[140000`000000000
AP0001@000080000AdA9@`<0000Q0000200001h0000H0000:PD0060100101@00LP4002D0000<0000
0@0002D0000<00000P0002D0000<00000@0002D0000<00003@00P2D0000<00000P0002D0000<0000
0@0001@0000<00003@000180000<00000@0005@0001H0000:PD00681000g1@00L@40004000000212
000P@RX5001R0@000P0004`00000000000000000003ooooooooooe00001R06801`0000L0000U0000
30000080001D0000E00003P5001X0@00?0D0074100010000000P@P00848h1@00J0400040001<0000
0000000000000000oooooooooom@0000<@0000D0000U0000300000d0080R000030000?oooolQ0000
200001T0000<0000oooo01P0000<0000000001h0000H00006P000140003b0P00P@400280000<0000
oooooaP0000<0000000001T0000<0000oooo02D0000<00000000P2D0000<00003@00P4H0000X0000
700004M4BD<200008`D001T100111@00;P40000000160000D00004@00015CDH[:T0002@0000H0000
0020?`00000000000020?`00000000002T00`1`0000@0000ooooo`40000T1AX1700C024000080000
HP0000`000010000900002@00000080m000000000000080m00000000000200009@0000`000060000
9@0000`000080020C00006@0000T1@006P4003l5000/0@00>58009PA00300@00<0400240l0000000
00000000P3l0000000000000P3l0000000000000000000000000000000000000000002D0000<0000
1`00P2D0000<00000000P2@0000T00000020@@00000000000020@@00000000000P0004H000280000
O00004E=AR/8@2H2?000030000014<3K000005H0000000000020?`80000200000000@@8000014<3K
00000?ooool8@2L3;000020000014<3K10000010000T1AX190D]0D05;@501AX10041PAE09`0@0000
100002H0000j0000300000P0000T000090000000P3d0000000000000P3d0000000000080001O0000
>00000D0000h0000000003P0000000000201010000000000oooo000000000000000002D0000<0000
1@0002D0000<00001@00P5H0000/00005`D000d1001<1@00>@4000@0000hDYPA>5;84_QCb1;hDiPA
9@0000`0000700209@0000`000000020900002@00000081100000000000008110000000000020000
:00000`000050000>P0000`0000:00008P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000
000004H0000D0000200004M4BD<300008@0000P0000N0000600002L5000K0@00?PD002d1000U0000
30000040000U000030000080000U000030000040000U0000300000d0080U000030000080000U0000
30000040000D0000300000d0000B000030000040001D0000F00002L5000M0@00>0D002`100010000
000P@P00848W1@007@400080001<00000000000000000000oooooooooom@0000@P1200T000090000
9@0000`000020000E00005@0000i1@008`4003d5000/0@000@00000084800212>@D002<100010000
C00000000000000000000?ooooooooooD0000340000500009@0000`0000=00208P0000`0003ooooo
8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A0000lP800841000R0000
30000?oooolH000030000000000I000030000?ooo`0U000030000000080U0000300000d008160000
:00001`00017A4U30P0002D500340000@`D00=`000000000AP00050000140000ADe6:bY0000T0000
60000000P3l0000000000000P3l00000000000Y00<0L000040000?ooool100009PG501`05P0Q0000
20000680000<00000@0002@0000T00000020?@00000000000020?@00000000000P0002D0000<0000
1P0002D0000<00002000P4`0001T00009PD00<D000111@00fP0005QB00183000`0400601000Q0?00
000000000000080o000000000000080o0000000000000000000000000000000000000000000U0000
300000L0080U000030000000080T000090000000P440000000000000P44000000000008000160000
R00007`00015CDH[240X0S`0000`00000A30f`00001F000000000000P3l200000P00000004420000
0A30f`00003ooooo240Y0b`0000P00000A30f`@00000@0009PG502H5f`121M/0@PG500010H4E@2T0
400000@0000X0000>P0000`000080000900002@00000080m000000000000080m0000000000020000
G`0003P000050000>0000000000h00000000000P0@0@000000000?ooo`00000000000000000U0000
300000D0000U0000300000D0081F0000;00001T5002h0000CPD00>L000040000F59835QBZ0dHE:P=
65A832D0000<00001`00P2D0000<00000000P2@0000T00000020@@00000000000020@@0000000000
0P0002P0000<00001@0003X0000<00002P000280000<0000ooooodH0000L0000400004E=AR/4@000
3000000000160000500000P00017A4U30`000240000800007P0001P0000Y1@00aP000405003K0000
9@0000`0000100009@0000`0000200009@0000`0000100009@0000`0000=00209@0000`000020000
9@0000`000010000500000`0000=00004P0000`000010000E00005P0000Y1@00b00003P5003G0000
0@00000084800212:@D00<P000020000C00000000000000000000?ooooooooooD00004D0E0090000
1`0002D0000<00000P0005@0001D0000>@D00<h0000m1@00f@00004000000212000P@ST5003>0000
0@0004`00000000000000000003ooooooooooe00000b00001@0002D0000<00003@00P280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@000?8200210@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000000209@0000`0000=0020
AP0002P0000L0000AdA9@`80002@10004`400;l4000f0@00000004H0001@0000A00004E=AR/Z@000
900001P00000080o000000000000080o00000000000:@03070000100003ooooo0@000944504]0240
8@0000P0001R000030000040000T000090000000P3d0000000000000P3d0000000000080000U0000
300000H0000U0000300000P0081<0000I0000944000D0@00_@@003@10008B@00>1400=02000@0P00
8@3`0000000000000020?`00000000000020?`000000000000000000000000000000000000000000
9@0000`0000700209@0000`000000020900002@00000081100000000000008110000000000020000
AP0008P0001l0000ADe6:`Q0:P8l0000<000004@`=/00000EP0000000000080o0P00008000000011
0P00004@`=/000000000o`Q0:`</00008000004@`=/4000004000944506A13D1_P@e0Kh450400@61
5D0[010000040000:P0003X0000<0000200002@0000T00000020?@00000000000020?@0000000000
0P0005l0000h00001@0003P000000000>00000000000804040000000000000000000000000000000
9@0000`0000500009@0000`000050020EP0002`0002410001`400<X400110@00100000Q9>148BDPC
f4]84mQ;>14U0000300000L0080U000030000000080T000090000000P440000000000000P4400000
00000080000X0000300000D0000j0000300000X0000R000030000?oooom60000700001000015CDH[
140000`000000000AP0001@000080000AdA9@`<000160000:00001`00017A4U30P000904001G0@00
_`@007X100000000AP00050000140000ADe6:bY0000T000060000000P3l0000000000000P3l00000
000000Y00<0L000040000?ooool10000T@AH0Bd08@0Q000020000680000<00000@0002@0000T0000
0020?@00000000000020?@00000000000P0002D0000<00001P0002D0000<00002000P4`0001T0000
T@@005P1002m1000N04000Q9001h5@00d0800102000Q0?00000000000000080o000000000000080o
0000000000000000000000000000000000000000000U0000300000L0080U000030000000080T0000
90000000P440000000000000P44000000000008000160000R00007`00015CDH[240/0S`0000`0000
0A30f`00001F000000000000P3l200000P000000044200000A30f`000000003o240]0b`0000P0000
0A30f`@00000@000T@AH0I44N@6n17T1_PAH0@010H4E@2d0400000@0000/0000>P0000`000080000
900002@00000080m000000000000080m0000000000020000G`0003P000050000>0000000000h0000
0000000P0@0@0000000000000000000000000000000U0000300000D0000U0000300000D0081F0000
;00008@4001;0@00bP@008D10004000024Uh5@Q9R1OHBhPGf4]h5BD0000<00001`00P2D0000<0000
0000P2@0000T00000020@@00000000000020@@00000000000P0002P0000<00001@0003X0000<0000
2P000280000<0000ooooodH0000L0000400004E=AR/4@0003000000000160000500000P00017A4U3
0`0004H0000X0000700004M4BD<20000;`@001<1001[1000=P40000000160000D00004@00015CDH[
:T0002@0000H00000020?`00000000000020?`00000000002T00`1`0000@0000ooooo`40000`11@1
>P0Q024000080000HP0000`000010000900002@00000080m000000000000080m0000000000020000
9@0000`0000600009@0000`000080020C00006@0000`1000504006T4000d0@00n48003PA002P0`00
40800240l000000000000000P3l0000000000000P3l0000000000000000000000000000000000000
000002D0000<00001`00P2D0000<00000000P2@0000T00000020@@00000000000020@@0000000000
0P0004H000280000O00004E=AR/8@2h2?000030000014<3K000005H0000000000020?`8000020000
0000@@8000014<3K000000000?l8@2l3;000020000014<3K10000010000`11@1<0@e0FX4=@5Z11@1
0041PAE0;`0@0000100002h0000j0000300000P0000T000090000000P3d0000000000000P3d00000
00000080001O0000>00000D0000h0000000003P00000000002010100000000000000000000000000
000002D0000<00001@0002D0000<00001@00P5H0000/00008`@000L1001f1000@@4000@0003h@SPA
n4984iQ6B1>HASPA9@0000`0000700209@0000`000000020900002@0000008110000000000000811
0000000000020000:00000`000050000>P0000`0000:00008P0000`0003oooooAP0001`0000@0000
ADe6:`A0000<0000000004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80000_1000
E`4006/4001j0@00000004H0001@0000A00004E=AR/Z@000900001P00000080o000000000000080o
00000000000:@03070000100003ooooo0@000304F04j02408@0000P0001R000030000040000T0000
90000000P3d0000000000000P3d0000000000080000U0000300000H0000U0000300000P0081<0000
I0000304001H0@00J@@007P1003h@P00N1D00:03000@0P008@3`0000000000000020?`0000000000
0020?`0000000000000000000000000000000000000000009@0000`0000700209@0000`000000020
900002@00000081100000000000008110000000000020000AP0008P0001l0000ADe6:`Q0<08l0000
<000004@`=/00000EP0000000000080o0P000080000000110P00004@`=/000000000o`Q0<@</0000
8000004@`=/4000004000304F04`17T1JPAi0FX4F0400@615D0a010000040000<00003X0000<0000
200002@0000T00000020?@00000000000020?@00000000000P0005l0000h00001@0003P000000000
>000000000008040400000000000000000000000000000009@0000`0000500009@0000`000050020
EP0002`0000S1000B`4007H400250@0010000?Q2N1Gh@XPGV4J85iQ6N1DU0000300000L0080U0000
30000000080T000090000000P440000000000000P440000000000080000X0000300000D0000j0000
300000X0000R000030000?oooom60000700001000015CDH[140000`000000000AP0001@000080000
AdA9@`<000160000:00001`00017A4U30P000:P4000]0@00iP@005P100000000AP0000@1003h0000
ADe6:bY0000T000060000000P3l0000000000000P3l00000000000Q0<P:L0000T000004@`=/00000
GQ0000000000080o0P000?l0000200000000@@80001H00000A30f`00000100000P0005IEED000000
00000000000002110020?`000000000000000000000L00000A30f`<00000H0000P3lo`00003nooco
0061004@`=/000000000o`Q0<`<T00006000004@`=/2000004000:T4E`7Q13<1004001E0<`0@0000
10000380000X0000300000H0000Q000020000680000<00000@0002@0000T00000020?@0000000000
0020?@00000000000P0005l0000h00001P0003P000000000>000000000004P404000000000000000
00000000000000009@0000`0000600009`0001P00005000000000000000000009@0000`000050000
4`0000`000020000>`0000P0000K0000400008A:001R5@00=P000100003GC@00?a<005P0000d0000
00000000003oooooooooo`H0003KCC`Ch4dm4n9=@A?UCDDCi4e:4n1=C1<f0000400008e:001_5@00
F00003@00000000000000?oooooooooo1P0008U:LQF4BW4EPTY]5Gm:JAF0BV@EQ4YR5Cd000080000
6`000100001jC@00>1<005T0000T000000000000003oooooooooo`800008CRPC_dfT4cd000080000
?00000P0000o000060000:H4000a0@00hP@005T1000C000030000040000U000030000000080U0000
300000L0080T000090000000P440000000000000P440000000000080000X0000300000H0000R0000
30000?oooom60000700001000015CDH[140000`000000000AP0001@000080000AdA9@`<000160000
:00001`00017A4U30P000:L4003K0000i@@001<100000000AP0000@1003h0000ADe6:bY0000T0000
60000000P3l0000000000000P3l00000000000Q0=0:L0000T000004@`=/00000GQ0000000000080o
0P000?l0000200000000@@80001H00000A30f`00000100000P0005IEED0000000000000000000211
0020?`000000000000000000000L00000A30f`<00000H0000P3lo`00003nooco0061004@`=/00000
0000o`Q0=@<T00006000004@`=/2000004000:P44P7P1>00004001E0=@0@0000100003@0000Q0000
20000680000<00000@0002@0000T00000020?@00000000000020?@00000000000P0005l0000h0000
1P0003P000000000>000000000004P40400000000000000000000000000000009@0000`000060000
9@0000`0000500004`0000`000020000>`0000P0000K0000400007=:000C4@00=P000100003;C@00
5Ph005P0000d000000000000003oooooooooo`H0003?CA<>e4dC3]M=5`kJCAX>fDdO3]I=8Phf0000
400007i:000N4@00F00003@00000000000000?oooooooooo1P0007]:8A5eBR4ALdXN4G1:6a5`BQDA
LdXC4Cd0000800006`000100001^C@007Ph005T0000T000000000000003oooooooooo`80003hCOP=
a4em3Sd000080000?00000P0000o000060000:D4003N0000h@@001@1000C000030000040000U0000
30000000080U0000300000L0080T000090000000P440000000000000P440000000000080000X0000
300000H0000R000030000?oooom60000700001000015CDH[140000`000000000AP0001@000080000
AdA9@`<000160000:00001`00017A4U30P0000d4000P0@00;P@002`100000000AP0000@1003h0000
ADe6:bY0000T000060000000P3l0000000000000P3l00000000000Q0=P:L0000T000004@`=/00000
GQ0000000000080o0P000?l0000200000000@@80001H00000A30f`00000100000P0005IEED000000
00000000000002110020?`000000000000000000000L00000A30f`<00000H0000P3lo`00003nooco
0061004@`=/000000000o`Q0=`<T00006000004@`=/20000040002d49P4?12H1004001E0=`0@0000
100003H0000Q000020000680000<00000@0002@0000T00000020?@00000000000020?@0000000000
0P0005l0000h00001P0003P000000000>000000000004P4040000000000000000000000000000000
9@0000`0000600009@0000`0000500004`0000`000020000>`0000P0000K000040000<Q2001P4P00
=P000100000N@@00H18005P0000d000000000000003oooooooooo`H0000I@F0B5T5M4QI1F18F@E@B
6D5@4Qi1D18f000040000<Q2001@4P00F00003@00000000000000?oooooooooo1P000<e2D1;@@U@B
d49H4]12GA;=@V0Bb49P4Sd0000800006`000100001X@@00V18005T0000T000000000000003ooooo
ooooo`80003X@5PBJ44H4Sd000080000?00000P0000o0000600000d4000P0@00;`@002/1000C0000
30000040000U000030000000080U0000300000L0080T000090000000P440000000000000P4400000
00000080000X0000300000H0000R000030000?oooom60000700001000015CDH[140000`000000000
AP0001@000080000AdA9@`<000160000:00001`00017A4U30P0000`4001S0@00;@@006l100000000
AP0000@1003h0000ADe6:bY0000T000060000000P3l0000000000000P3l00000000000Q0>0:L0000
T000004@`=/00000GQ0000000000080o0P000?l0000200000000@@80001H00000A30f`0000010000
0P0005IEED00000000000000000002110020?`000000000000000000000L00000A30f`<00000H000
0P3lo`00003nooco0061004@`=/000000000o`Q0>@<T00006000004@`=/20000040002`4J@4>16T1
004001E0>@0@0000100003P0000Q000020000680000<00000@0002@0000T00000020?@0000000000
0020?@00000000000P0005l0000h00001P0003P000000000>000000000004P404000000000000000
00000000000000009@0000`0000600009@0000`0000500004`0000`000020000>`0000P0000K0000
40000;Q2002@5P00=P000100000>@@00T1H005P0000d000000000000003oooooooooo`H00009@I0F
1T6=5PI1R1H6@H@F2D605Pi1P1Hf000040000;Q200205P00F00003@00000000000000?oooooooooo
1P000;e2P1K0@X@F`4:85/12SAJm@Y0F^4:@5Sd0000800006`000100001H@@00b1H005T0000T0000
00000000003oooooooooo`80003H@8PFF4585Sd000080000?00000P0000o0000600000`4001S0@00
;P@006h1000C000030000040000U000030000000080U0000300000L0080T000090000000P4400000
00000000P440000000000080000X0000300000H0000R000030000?oooom60000700001000015CDH[
140000`000000000AP0001@000080000AdA9@`<000160000:00001`00017A4U30P000>43002n0000
40@00>4000000000AP00050000140000ADe6:bY0000T000060000000P3l0000000000000P3l00000
000000Y00<0L000040000?ooool10000hP>o02d08@0X0000300000D0000Q000020000680000<0000
0@0002@0000T00000020?@00000000000020?@00000000000P0002L0000H00001@000000003oool0
000002D0000<00001@0002D0000<00002000P4`0001T0000hP<00;l0000>1000g`0001Pn003X2`00
d0800102000Q0?00000000000000080o000000000000080o00000000000000000000000000000000
00000000000U0000300000L0080U000030000000080T000090000000P440000000000000P4400000
0000008000160000R00007`00015CDH[240j0S`0000`00000A30f`00001F000000000000P3l20000
0P000000044200000A30f`000000003o240k0b`0000P00000A30f`@00000@000hP>o0>83h00?1>00
3`Bo00010H4E@3/0400000@0000j0000>P0000`000080000900002@00000080m000000000000080m
0000000000020000G`0003P000060000>0000000000h00000000000P0@0@00000000000000000000
00000000000U0000300000H0000U0000300000D0081F0000;0000=D3002b00006`@00>`000040000
63kX2aPnn0gX@?P=j43X2bD0000<00001`00P2D0000<00000000P2@0000T00000020@@0000000000
0020@@00000000000P0002P0000<00001P0003X0000<00002P000280000<0000ooooodH0000L0000
400004E=AR/4@0003000000000160000500000P00017A4U30`0004H0000X0000700004M4BD<20000
;`@00;h0001Y1000h@00000000160000D00004@00015CDH[:T0002@0000H00000020?`0000000000
0020?`00000000002T00`1`0000@0000ooooo`40000`1;l0>00Q024000080000HP0000`000010000
900002@00000080m000000000000080m00000000000200009@0000`0000500009@0000`000080020
C00006@0000`1000_`0006L4003O0000n4800>P;00200`0040800240l000000000000000P3l00000
00000000P3l0000000000000000000000000000000000000000002D0000<00001`00P2D0000<0000
0000P2@0000T00000020@@00000000000020@@00000000000P0004H000280000O00004E=AR/8@3`2
?000030000014<3K000005H0000000000020?`80000200000000@@8000014<3K000000000?l8@3d3
;000020000014<3K10000010000`1;l0<0CP06P4h01X1;l00041PAE0?@0@0000100003`0000j0000
300000P0000T000090000000P3d0000000000000P3d0000000000080001O0000>00000H0000h0000
000003P00000000002010100000000000000000000000000000002D0000<00001P0002D0000<0000
1@00P5H0000/00008`@00;80001d1000k00000@0003h@^P;n4;h3GQ6n0ehA^P;9@0000`000070020
9@0000`000000020900002@00000081100000000000008110000000000020000:00000`000060000
>P0000`0000:00008P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000000004H0000D0000
200004M4BD<30000AP0002P0000L0000AdA9@`80000i1000`P0006<4003J0000000004H0001@0000
A00004E=AR/Z@000900001P00000080o000000000000080o00000000000:@03070000100003ooooo
0@0003X4``0X01H08@0000P0001R000030000040000T000090000000P3d0000000000000P3d00000
00000080000U0000300000D0000U0000300000P0081<0000I00003X400330000H@@00=P0002H@`00
:0`00802001P0@008@3`0000000000000020?`00000000000020?`00000000000000000000000000
00000000000000009@0000`0000700209@0000`000000020900002@0000008110000000000000811
0000000000020000AP0008P0001l0000ADe6:`Q0?P8l0000<000004@`=/00000EP0000000000080o
0P000080000000110P00004@`=/00000ooooo`Q0?`</00008000004@`=/40000040003X4``0j1=T0
HPCI0684``000@615D0o010000040000?P0003X0000<0000200002@0000T00000020?@0000000000
0020?@00000000000P0005l0000h00001P0003P000000000>00000000000804040000000003oool0
00000000000000009@0000`0000600009@0000`000050020EP0002`0000]1000]P0006h4003U0000
100009Q3:0bH@hP=64J83AQ6:0`U0000300000L0080U000030000000080T000090000000P4400000
00000000P440000000000080000X0000300000H0000j0000300000X0000R000030000?oooom60000
700001000015CDH[140000`000000000AP0001@000080000AdA9@`<0000Q0000200001h0000H0000
?@@00<@0001P1000f@0002D0000<00000@0002D0000<00000P0002D0000<00000@0002D0000<0000
3@00P2D0000<00000P0002D0000<00000@0001@0000<00003@000180000<00000@0005@0001H0000
?@@00<H0001<1000e@00004000000212000P@Sd4003600000P0004`00000000000000000003ooooo
oooooe00001505@02@0000L0000U000030000080001D0000H00004d4003<0000F`@00=L000010000
000P@P00849=1000c00000<0001<00000000000000000000oooooooooomD0000L`1U074000050000
1@0000D0000U0000300000d0080R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000
000001h0000H00006P000140003b0P00P@400280000<0000oooooaP0000<0000000001T0000<0000
oooo02D0000<00000000P2D0000<00003@00P4H0000X0000700004M4BD<20000=P@001P1001P1000
<040000000160000D00004@00015CDH[:T0002@0000H00000020?`00000000000020?`0000000000
2T00`1`0000@0000ooooo`40000g11T1:00F024000080000HP0000`000010000900002@00000080m
000000000000080m00000000000200009@0000`0000500009@0000`000080020C00006@0000g1000
6@4005h4000^0@00J4<008PA00200P00H0400240l000000000000000P3l0000000000000P3l00000
00000000000000000000000000000000000002D0000<00001`00P2D0000<00000000P2@0000T0000
0020@@00000000000020@@00000000000P0004H000280000O00004E=AR/8@002?000030000014<3K
000005H0000000000020?`80000200000000@@8000014<3K00000?ooool8@043;000020000014<3K
10000010000g11T1=`@_0El4;`5O11T10041PAE00@0@000010000000000j0000300000P0000T0000
90000000P3d0000000000000P3d0000000000080001O0000>00000H0000h0000000003P000000000
0201010000000000oooo000000000000000002D0000<00001P0002D0000<00001@00P5H0000/0000
:P@000`1001[1000>`4000@0001X@hPAJ4?X4^Q5j1;XAHPA9@0000`0000700209@0000`000000020
900002@00000081100000000000008110000000000020000:00000`000060000>P0000`0000:0000
8P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000000004H0000D0000200004M4BD<30000
8@0000P0000N0000600003X4000J0@00G@@002l1000U000030000040000U000030000080000U0000
30000040000U0000300000d0080U000030000080000U000030000040000D0000300000d0000B0000
30000040001D0000F00003X4000L0@00B`@002/100010000000P@P00848j100070400080001<0000
0000000000000000oooooooooom@0000@P1200T0000900009@0000`000020000E0000600001<1000
8P4005X4000]0@000@00000084800212C0@0028100030000C00000000000000000000?oooooooooo
E00007<0I@1a00001@0000D0000500009@0000`0000=00208P0000`0003ooooo8@0000P0000I0000
30000?ooo`0H000030000000000N0000600001X0000A0000lP800841000R000030000?oooolH0000
30000000000I000030000?ooo`0U000030000000080U0000300000d008160000:00001`00017A4U3
0P0003@4001L0@00GP@007@100000000AP00050000140000ADe6:bY0000T000060000000P3l00000
00000000P3l00000000000Y00<0L000040000?ooool10000=@AM0BP05P0Q000020000680000<0000
0@0002@0000T00000020?@00000000000020?@00000000000P0002D0000<00001@0002D0000<0000
2000P4`0001T0000=@@005d1001L1000LP4004Q300385@00P0800601000Q0?00000000000000080o
000000000000080o0000000000000000000000000000000000000000000U0000300000L0080U0000
30000000080T000090000000P440000000000000P44000000000008000160000R00007`00015CDH[
24020S`0000`00000A30f`00001F000000000000P3l200000P000000044200000A30f`00003ooooo
24030b`0000P00000A30f`@00000@000=@AM0CD4L`5M17<1G@AM0@010H4E@0<0400000@000020000
>P0000`000080000900002@00000080m000000000000080m0000000000020000G`0003P000060000
>0000000000h00000000000P0@0@000000000?ooo`00000000000000000U0000300000H0000U0000
300000D0081F0000;00002P4001@0@00J@@007l100040000B4?85DQ3:1O8ABPGb4G85BD0000<0000
1`00P2D0000<00000000P2@0000T00000020@@00000000000020@@00000000000P0002P0000<0000
1P0003X0000<00002P000280000<0000ooooodH0000L0000400004E=AR/4@0003000000000160000
500000P00017A4U30`000240000800007P0001P0000h1000GP4005/4001c0@009@0000`000010000
9@0000`0000200009@0000`0000100009@0000`0000=00209@0000`0000200009@0000`000010000
500000`0000=00004P0000`000010000E00005P0000h1000H04004D4001_0@000@00000084800212
>0@0060100020000C00000000000000000000?ooooooooooD0000680HP0700001`0002D0000<0000
0P0005@0001P0000AP@006H1001D1000L@40004000000212000P@TH4001V0@000`0004`000000000
00000000003ooooooooooe@0001c06D0L@0000D0000500001@0002D0000<00003@00P280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@000?8200210@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000000209@0000`0000=0020
AP0002P0000L0000AdA9@`80003R0`00FP4000`4001b0@00000004H0001@0000A00004E=AR/Z@000
900001P00000080o000000000000080o00000000000:@03070000100003ooooo0@000><3F`4X01H0
8@0000P0001R000030000040000T000090000000P3d0000000000000P3d0000000000080000U0000
300000D0000U0000300000P0081<0000I0000><3001K0@002P@00701000X?P00Z1D00802001P0@00
8@3`0000000000000020?`00000000000020?`000000000000000000000000000000000000000000
9@0000`0000700209@0000`000000020900002@00000081100000000000008110000000000020000
AP0008P0001l0000ADe6:`Q0108l0000<000004@`=/00000EP0000000000080o0P00008000000011
0P00004@`=/00000ooooo`Q01@</00008000004@`=/4000004000><3F`7S0g412`Aa0@/4F`400@61
5D05010000040000100003X0000<0000200002@0000T00000020?@00000000000020?@0000000000
0P0005l0000h00001P0003P000000000>00000000000804040000000003oool00000000000000000
9@0000`0000600009@0000`000050020EP0002`0003F0`00CP4001L4001m0@00100002PnZ1DX?PPG
Z4085jQ0Z1DU0000300000L0080U000030000000080T000090000000P440000000000000P4400000
00000080000X0000300000H0000j0000300000X0000R000030000?oooom60000700001000015CDH[
140000`000000000AP0001@000080000AdA9@`<0000Q0000200001h0000H0000iP<005`100091000
L@4002D0000<00000@0002D0000<00000P0002D0000<00000@0002D0000<00003@00P2D0000<0000
0P0002D0000<00000@0001@0000<00003@000180000<00000@0005@0001H0000iP<005h1003e0`00
K@40004000000212000P@^H3001N0@000P0004`00000000000000000003ooooooooooe00001<04h0
1`0000T0000U000030000080001D0000F0000?H3001T0@000@@006l100010000000P@P0084;f0`00
I0400080001<00000000000000000000oooooooooom@0000E01800D0000700009@0000`0000=0020
8P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A0000
lP800841000R000030000?oooolH000030000000000I000030000?ooo`0U000030000000080U0000
300000d008160000:00001`00017A4U30P000><3003300003@@00=/000000000AP00050000140000
ADe6:bY0000T000060000000P3l0000000000000P3l00000000000Y00<0L000040000?ooool10000
i0?402P05P0Q000020000680000<00000@0002@0000T00000020?@00000000000020?@0000000000
0P0002D0000<00001@0002D0000<00002000P4`0001T0000i0<00<@0000;1000f@0003Pn000h3000
P0800601000Q0?00000000000000080o000000000000080o00000000000000000000000000000000
00000000000U0000300000L0080U000030000000080T000090000000P440000000000000P4400000
0000008000160000R00007`00015CDH[24060S`0000`00000A30f`00001F000000000000P3l20000
0P000000044200000A30f`00003ooooo24070b`0000P00000A30f`@00000@000i0?40>@3fP0<1=X0
30C400010H4E@0L0400000@000060000>P0000`000080000900002@00000080m000000000000080m
0000000000020000G`0003P000060000>0000000000h00000000000P0@0@000000000?ooo`000000
00000000000U0000300000H0000U0000300000D0081F0000;0000=L3002g000060@00>H000040000
>3hh33PnV0fh@9P=^40h32D0000<00001`00P2D0000<00000000P2@0000T00000020@@0000000000
0020@@00000000000P0002P0000<00001P0003X0000<00002P000280000<0000ooooodH0000L0000
400004E=AR/4@0003000000000160000500000P00017A4U30`000240000800007P0001P0003W0`00
a@0000X4003J00009@0000`0000100009@0000`0000200009@0000`0000100009@0000`0000=0020
9@0000`0000200009@0000`000010000500000`0000=00004P0000`000010000E00005P0003W0`00
a`000?H3003F00000@00000084800212i`<00<L000020000C00000000000000000000?oooooooooo
D00004`0CP0700002@0002D0000<00000P0005@0001H0000m`<00<d000011000f000004000000212
000P@_L3003=00000P0004`00000000000000000003ooooooooooe00001505@01P0000D0000U0000
300000d0080R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H0000
6P000140003b0P00P@400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000
0000P2D0000<00003@00P4H0000X0000700004M4BD<200003@@00<X0000^1000eP00000000160000
10400?P00015CDH[:T0002@0000H00000020?`00000000000020?`000000000024080Y`0002@0000
0A30f`00001N400000000000P3l20000o`000080000000110P0005P000014<3K0000004000020000
EUEE@00000000000000000008440080o0000000000000000000001`000014<3K0`00001P00020?co
00000?koo?l00H400A30f`000000003o24090b@0000H00000A30f`800000@000;@C@00l4d0000@00
5D09010000040000200002P0000<00001@00024000080000HP0000`000010000900002@00000080m
000000000000080m0000000000020000G`0003P000050000>0000000000h00000000000B0@0@0000
000000000000000000000000000U0000300000D0000W0000600000H00000000000000000000U0000
300000H0000C000030000080000k0000200001/0000@0000b480000=000f0000400001i100003@00
F00003@00000000000000?oooooooooo1P0001U100dF@Od<5T7h31I1m0`I@O0<7T7`33H0000@0000
b4800?0<001H0000=000000000000000ooooooooool60000cD;`3=12m0c@@_P<d4;m3<e200g8@P0=
?@0000P0000K0000400006Q1000h3@00F@0002@00000000000000?oooooooooo0P000>Q0n0aX@KP<
?@0000P0000l0000200003l0000H00003@@00<X0000_1000e@0001<0000<00000@0002D0000<0000
0000P2D0000<00001`00P2@0000T00000020@@00000000000020@@00000000000P0002P0000<0000
1@000280000<0000ooooodH0000L0000400004E=AR/4@0003000000000160000500000P00017A4U3
0`0004H0000X0000700004M4BD<20000U@@001T1002c1000;P40000000160000D00004@00015CDH[
:T0002@0000H00000020?`00000000000020?`00000000002T00`1`0000@0000ooooo`40002F11X1
700C02P0000<00001P00024000080000HP0000`000010000900002@00000080m000000000000080m
00000000000200009`0001P00006000000000?ooo`0000009@0000`0000600009@0000`000080020
C00006@0002F10006P400;44000/0@00F4T009PA00300@00<0400240l000000000000000P3l00000
00000000P3l0000000000000000000000000000000000000000002D0000<00001`00P2D0000<0000
0000P2@0000T00000020@@00000000000020@@00000000000P0004H000280000O00004E=AR/8@0/2
?000030000014<3K000005H0000000000020?`80000200000000@@8000014<3K00000?ooool8@0X3
;000020000014<3K10000010002F11X1UP@]0K84;@6b11X10041PAE02P0@0000100000/0000j0000
300000P0000T000090000000P3d0000000000000P3d0000000000080001O0000>00000D0000h0000
000003P0000000000201010000000000oooo000000000000000002D0000<00001@0002D0000<0000
1@00P5H0000/0000R@@000d1002n1000>@4000@0001HBIPAF4W84QQ;b18HBiPA9@0000`000070020
9@0000`000000020900002@00000081100000000000008110000000000020000:00000`000050000
>P0000`0000:00008P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000000004H0000D0000
200004M4BD<300008@0000P0000N0000600009T4000K0@00/0@002d1000U000030000040000U0000
30000080000U000030000040000U0000300000d0080U000030000080000U000030000040000D0000
300000d0000B000030000040001D0000F00009T4000M0@00ZP@002`100010000000P@P0084:I1000
7@400080001<00000000000000000000oooooooooom@0000@P1200T0000900009@0000`000020000
E00005@0002[10008`400:l4000/0@000@00000084800212Z`@002<100010000C000000000000000
00000?ooooooooooD0000380000500009@0000`0000=00208P0000`0003ooooo8@0000P0000I0000
30000?ooo`0H000030000000000N0000600001X0000A0000lP800841000R000030000?oooolH0000
30000000000I000030000?ooo`0U000030000000080U0000300000d008160000:00001`00017A4U3
0P0009P4001L0@00]@@0074100000000AP00050000140000ADe6:bY0000T000060000000P3l00000
00000000P3l00000000000Y00<0L000040000?ooool10000V@AM0A/04`0Q000020000680000<0000
0@0002@0000T00000020?@00000000000020?@00000000000P0002D0000<00001P0002D0000<0000
2000P4`0001T0000V@@005d1002c1000K`4008Q900385@00/0400301000Q0?00000000000000080o
000000000000080o0000000000000000000000000000000000000000000U0000300000L0080U0000
30000000080T000090000000P440000000000000P44000000000008000160000R00007`00015CDH[
240<0S`0000`00000A30f`00001F000000000000P3l200000P000000044200000A30f`00003ooooo
240=0b`0000P00000A30f`@00000@000V@AM0IT4L06d1701]0AM0@010H4E@0d0400000@0000<0000
>P0000`000080000900002@00000080m000000000000080m0000000000020000G`0003P000050000
>0000000000h00000000000P0@0@000000000?ooo`00000000000000000U0000300000D0000U0000
300000D0081F0000;00008`4001@0@00`0@007`100040000R4W85HQ9n1HhBoPF>4_85BD0000<0000
1`00P2D0000<00000000P2@0000T00000020@@00000000000020@@00000000000P0002P0000<0000
1@0003X0000<00002P000280000<0000ooooodH0000L0000400004E=AR/4@0003000000000160000
500000P00017A4U30`000240000800007P0001P0002L1000GP400;84001`0@009@0000`000010000
9@0000`0000200009@0000`0000100009@0000`0000=00209@0000`0000200009@0000`000010000
500000`0000=00004P0000`000010000E00005P0002L1000H0400:T4001_0@000@00000084800212
W0@0060100020000C00000000000000000000?ooooooooooD0000680HP0700001`0002D0000<0000
0P0005@0001D0000ZP@006H1002^1000K`40004000000212000P@ZX4001V0@000@0004`000000000
00000000003ooooooooooe00000b00001@0002D0000<00003@00P280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@000?8200210@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000000209@0000`0000=0020AP0002P0000L0000
AdA9@`80003f0`00[@4000h4002l0@00000004H0001@0000A00004E=AR/Z@000900001P00000080o
000000000000080o00000000000:@03070000100003ooooo0@000?L3[P4F00d08@0000P0001R0000
30000040000T000090000000P3d0000000000000P3d0000000000080000U0000300000H0000U0000
300000P0081<0000I0000?L3002^0@0030@00;X1001X?`00f1X00601003@00008@3`000000000000
0020?`00000000000020?`0000000000000000000000000000000000000000009@0000`000070020
9@0000`000000020900002@00000081100000000000008110000000000020000AP0008P0001l0000
ADe6:`Q03P8l0000<000004@`=/00000EP0000000000080o0P000080000000110P00004@`=/00000
0000o`Q03`</00008000004@`=/4000004000?L3[P7g0k/13@Bk0@d4[P400@615D0?010000040000
3P0003X0000<0000200002@0000T00000020?@00000000000020?@00000000000P0005l0000h0000
1@0003P000000000>000000000008040400000000000000000000000000000009@0000`000050000
9@0000`000050020EP0002`0003Z0`00X@4001T400370@00100006Pof1YX?jPKb42X6lQ0f1XU0000
300000L0080U000030000000080T000090000000P440000000000000P440000000000080000X0000
300000D0000j0000300000X0000R000030000?oooom60000700001000015CDH[140000`000000000
AP0001@000080000AdA9@`<0000Q0000200001h0000H0000nP<00:l1000;1000^`400580001`0@00
1@000?Goool0000000000000002@0@000000000002110780J@1Q06`0000000000000000000000000
000000000000000000000000000000000000000000000000003@0NX700000000[8N`<7P000000000
68<C0>B34`1h0000P00009R24`00000058<C004000000000FBj`<0/0000`f=0168<C0=>[032hem01
B8<C00`0002PZ]01A8`C01`000000001000005@0H@1X06l0K@1Q0000000001EKk=8GFhSBV`3PPA<0
DDlEFm3CV`0LdY/0E=:K0?SAV`0/0000NP0002`3002H0000188C040o5E_0eI/0000EFd3FV`20Q1<0
n=6K0000000000400@020=Tna7MiClAg?PX:oe`00018PQ<0^=O@0Bb24`0Km`0`?PX:ofAf00P00000
9@0000`0000500009@0000`0000=00209@0000`000050000500000`0000=00004P0000`000010000
E00005P0003j0`00[`4000D4002j0@000@00000084800212nP<00:l100020000C000000000000000
00000?ooooooooooD0000340<00600001P0002D0000<00003@00P280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@000?8200210@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000000209@0000`0000=0020AP0002P0000L0000
AdA9@`80001l1@00[P4008P5002l0@00000004H0001@0000A00004E=AR/Z@000900001P00000080o
000000000000080o00000000000:@03070000100003ooooo0@0007d5[`4:00`08@0000P0001R0000
30000040000T000090000000P3d0000000000000P3d0000000000080000U0000300000H0000U0000
300000P0081<0000I00007d5002_0@00QPD00;X10038E`00j1X00:00003000008@3`000000000000
0020?`00000000000020?`0000000000000000000000000000000000000000009@0000`000070020
9@0000`000000020900002@00000081100000000000008110000000000020000AP0008P0001l0000
ADe6:`Q0408l0000<000004@`=/00000EP0000000000080o0P000080000000110P00004@`=/00000
0000o`Q04@</00008000004@`=/40000040007d5[`5m1K/1Q`Fk0HL5[`400@615D0A010000040000
400003X0000<0000200002@0000T00000020?@00000000000020?@00000000000P0005l0000h0000
1`0003P000000000>000000000008040400000000000000000000000000000009@0000`000070000
9@0000`000050020EP0002`0001`1@00XP4009<500370@0010000<QGj1[8EjPKJ5RX6fQHj1XU0000
300000L0080U000030000000080T000090000000P440000000000000P440000000000080000X0000
300000L0000j0000300000X0000R000030000?oooom60000700001000015CDH[140000`000000000
AP0001@000080000AdA9@`<0000Q0000200001h0000H0000P0D00;0100251@00^`4002D0000<0000
1@0002D0000<00003@00P2D0000<00001@0002D0000<00003@00P2D0000<00001@0001@0000<0000
3@000180000<00000@0005@0001D0000P0D00;0100241@00^P40004000000212000P@X05002`0@00
0@0004`00000000000000000003ooooooooooe00000a00001P0002D0000<00003@00P280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@000?8200210@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000000209@0000`0000=0020
AP0002P0000L0000AdA9@`8000121@00[P4004h5002l0@00000004H0001@0000A00004E=AR/Z@000
900001P00000080o000000000000080o00000000000:@03070000100003ooooo0@0004<5[`4:00`0
8@0000P0001R000030000040000T000090000000P3d0000000000000P3d0000000000080000U0000
300000H0000U0000300000P0081<0000I00004<5002_0@00C0D00;X1000XE000j1X00:0000300000
8@3`0000000000000020?`00000000000020?`000000000000000000000000000000000000000000
9@0000`0000700209@0000`000000020900002@00000081100000000000008110000000000020000
AP0008P0001l0000ADe6:`Q04P8l0000<000004@`=/00000EP0000000000080o0P00008000000011
0P00004@`=/000000000o`Q04`</00008000004@`=/40000040004<5[`531K/1C@Fk0Dd5[`400@61
5D0C0100000400004P0003X0000<0000200002@0000T00000020?@00000000000020?@0000000000
0P0005l0000h00001`0003P000000000>00000000000804040000000000000000000000000000000
9@0000`0000700009@0000`000050020EP0002`0000f1@00XP4005T500370@00100002QDj1XXE:PK
b5BX6lQDj1XU0000300000L0080U000030000000080T000090000000P440000000000000P4400000
00000080000X0000300000L0000j0000300000X0000R000030000?oooom60000700001000015CDH[
140000`000000000AP0001@000080000AdA9@`<0000Q0000200001h0000H0000APD00;01001;1@00
^`4002D0000<00001@0002D0000<00003@00P2D0000<00001@0002D0000<00003@00P2D0000<0000
1@0001@0000<00003@000180000<00000@0005@0001D0000APD00;01001:1@00^P40004000000212
000P@TH5002`0@000@0004`00000000000000000003ooooooooooe00000b00001P0002D0000<0000
3@00P280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J0000
4@000?8200210@008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000000020
9@0000`0000=0020AP0002P0000L0000AdA9@`8000091@00[P4001D5002l0@00000004H0001@0000
A00004E=AR/Z@000900001P00000080o000000000000080o00000000000:@03070000100003ooooo
0@0000X5[`4:00`08@0000P0001R000030000040000T000090000000P3d0000000000000P3d00000
00000080000U0000300000H0000U0000300000P0081<0000I00000X5002_0@004`D00;X1002HD000
j1X00:00003000008@3`0000000000000020?`00000000000020?`00000000000000000000000000
00000000000000009@0000`0000700209@0000`000000020900002@0000008110000000000000811
0000000000020000AP0008P0001l0000ADe6:`Q0508l0000<000004@`=/00000EP0000000000080o
0P000080000000110P00004@`=/000000000o`Q05@</00008000004@`=/40000040000X5[`4:1K/1
50Fk0A@5[`400@615D0E010000040000500003X0000<0000200002@0000T00000020?@0000000000
0020?@00000000000P0005l0000h00001`0003P000000000>0000000000080404000000000000000
00000000000000009@0000`0000700009@0000`000050020EP0002`0003m1000XP40020500370@00
100009Q@j1ZHD:PK>56X6cQAj1XU0000300000L0080U000030000000080T000090000000P4400000
00000000P440000000000080000X0000300000L0000j0000300000X0000R000030000?oooom60000
700001000015CDH[140000`000000000AP0001@000080000AdA9@`<0000Q0000200001h0000H0000
3@D00;01000B1@00^`4002D0000<00001@0002D0000<00003@00P2D0000<00001@0002D0000<0000
3@00P2D0000<00001@0001@0000<00003@000180000<00000@0005@0001D00003@D00;01000A1@00
^P40004000000212000P@Pd5002`0@000@0004`00000000000000000003ooooooooooe00000c0000
1P0002D0000<00003@00P280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@000?8200210@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000000209@0000`0000=0020AP0002P0000L0000AdA9@`80001k1@00K04008L5001j0@00
000004H0001@0000A00004E=AR/Z@000900001P00000080o000000000000080o00000000000:@030
70000100003ooooo0@0007`5K@4:00`08@0000P0001R000030000040000T000090000000P3d00000
00000000P3d0000000000080000U0000300000H0000U0000300000P0081<0000I00007`5001]0@00
Q@D007P1002hE`00b1H00:00003000008@3`0000000000000020?`00000000000020?`0000000000
000000000000000000000000000000009@0000`0000700209@0000`000000020900002@000000811
00000000000008110000000000020000AP0008P0001l0000ADe6:`Q05P8l0000<000004@`=/00000
EP0000000000080o0P000080000000110P00004@`=/000000000o`Q05`</00008000004@`=/40000
040007`5K@5l1GT1QPEi0HH5K@400@615D0G0100000400005P0003X0000<0000200002@0000T0000
0020?@00000000000020?@00000000000P0005l0000h00001`0003P000000000>000000000008040
400000000000000000000000000000009@0000`0000700009@0000`000050020EP0002`0001_1@00
H040098500250@0010000;QGb1JhEhPGF5R85eQHb1HU0000300000L0080U000030000000080T0000
90000000P440000000000000P440000000000080000X0000300000L0000j0000300000X0000R0000
30000?oooom60000700001000015CDH[140000`000000000AP0001@000080000AdA9@`<0000Q0000
200001h0000H0000O`D006h100241@00N@4002D0000<00001@0002D0000<00003@00P2D0000<0000
1@0002D0000<00003@00P2D0000<00001@0001@0000<00003@000180000<00000@0005@0001D0000
O`D006h100231@00N040004000000212000P@Wl5001^0@000@0004`00000000000000000003ooooo
oooooe00000d00001P0002D0000<00003@00P280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@000?8200210@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000000209@0000`0000=0020AP0002P0000L0000AdA9@`80001j1@00
9P4008H5000d0@00000004H0001@0000A00004E=AR/Z@000900001P00000080o000000000000080o
00000000000:@03070000100003ooooo0@0007/59`4:00`08@0000P0001R000030000040000T0000
90000000P3d0000000000000P3d0000000000080000U0000300000H0000U0000300000P0081<0000
I00007/5000W0@00Q0D00381002XE`00J1800:00003000008@3`0000000000000020?`0000000000
0020?`0000000000000000000000000000000000000000009@0000`0000700209@0000`000000020
900002@00000081100000000000008110000000000020000AP0008P0001l0000ADe6:`Q0608l0000
<000004@`=/00000EP0000000000080o0P000080000000110P00004@`=/000000000o`Q06@</0000
8000004@`=/40000040007/59`5k1C<1Q@Dc0HD59`400@615D0I010000040000600003X0000<0000
200002@0000T00000020?@00000000000020?@00000000000P0005l0000h00001`0003P000000000
>000000000008040400000000000000000000000000000009@0000`0000700009@0000`000050020
EP0002`0001^1@006P400945000o0@0010000:QGJ1:XEbPCB5PX4dQHJ18U0000300000L0080U0000
30000000080T000090000000P440000000000000P440000000000080000X0000300000L0000j0000
300000X0000R000030000?oooom60000700001000015CDH[140000`000000000AP0001@000080000
AdA9@`<0000Q0000200001h0000H0000OPD002P100231@00<`4002D0000<00001@0002D0000<0000
3@00P2D0000<00001@0002D0000<00003@00P2D0000<00001@0001@0000<00003@000180000<0000
0@0005@0001D0000OPD002P100221@00<P40004000000212000P@Wh5000X0@000@0004`000000000
00000000003ooooooooooe00000g00001P0002D0000<00003@00P280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@000?8200210@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000000209@0000`0000=0020AP0002P0000L0000
AdA9@`80002`10009@400;l4000f0@00000004H0001@0000A00004E=AR/Z@000900001P00000080o
000000000000080o00000000000:@03070000100003ooooo0@000;449P4=00l08@0000P0001R0000
30000040000T000090000000P3d0000000000000P3d0000000000080000U0000300000H0000U0000
300000P0081<0000I0000;44000V0@00_@@003@10008B`00F1800=00003`00008@3`000000000000
0020?`00000000000020?`0000000000000000000000000000000000000000009@0000`000070020
9@0000`000000020900002@00000081100000000000008110000000000020000AP0008P0001l0000
ADe6:`Q06P8l0000<000004@`=/00000EP0000000000080o0P000080000000110P00004@`=/00000
0000o`Q06`</00008000004@`=/4000004000;449P6a13D1_P@e0Kh49P400@615D0K010000040000
6P0003X0000<0000200002@0000T00000020?@00000000000020?@00000000000P0005l0000h0000
1`0003P000000000>000000000008040400000000000000000000000000000009@0000`000070000
9@0000`000050020EP0002`0002T10006@400<X400110@00100000Q;F188BdPCf4]84mQ;F18U0000
300000L0080U000030000000080T000090000000P440000000000000P440000000000080000X0000
300000L0000j0000300000X0000R000030000?oooom60000700001000015CDH[140000`000000000
AP0001@000080000AdA9@`<0000Q0000200001h0000H0000]0@002L1002l1000=@4002D0000<0000
1@0002D0000<00003@00P2D0000<00001@0001@0000<00003@000180000<00000@0005@0001D0000
]0@002L1002i1000=040004000000212000P@[@4000W0@000@0004`00000000000000000003ooooo
oooooe00000h00001P0002D0000<00003@00P280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@000?8200210@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000000209@0000`0000=0020AP0002P0000L0000AdA9@`80002b1000
J`400;l4001j0@00000004H0001@0000A00004E=AR/Z@000900001P00000080o000000000000080o
00000000000:@03070000100003ooooo0@000;<4K04;00d08@0000P0001R000030000040000T0000
90000000P3d0000000000000P3d0000000000080000U0000300000H0000U0000300000P0081<0000
I0000;<4001/0@00_@@007P1000XB`00^1H00;00003@00008@3`0000000000000020?`0000000000
0020?`0000000000000000000000000000000000000000009@0000`0000700209@0000`000000020
900002@00000081100000000000008110000000000020000AP0008P0001l0000ADe6:`Q0708l0000
<000004@`=/00000EP0000000000080o0P000080000000110P00004@`=/000000000o`Q07@</0000
8000004@`=/4000004000;<4K06c17T1_PAi0Kh4K0400@615D0M010000040000700003X0000<0000
200002@0000T00000020?@00000000000020?@00000000000P0005l0000h00001`0003P000000000
>000000000008040400000000000000000000000000000009@0000`0000700009@0000`000050020
EP0002`0002V1000G`400<X400250@00100002Q;^1HXBhPGf4^85mQ;^1HU0000300000L0080U0000
30000000080T000090000000P440000000000000P440000000000080000X0000300000L0000j0000
300000X0000R000030000?oooom60000700001000015CDH[140000`000000000AP0001@000080000
AdA9@`<0000Q0000200001h0000H0000]P@006d1002l1000N@4002D0000<00001@0002D0000<0000
3@00P2D0000<00001@0001@0000<00003@000180000<00000@0005@0001D0000]P@006d1002k1000
N040004000000212000P@[H4001]0@000@0004`00000000000000000003ooooooooooe00000e0000
1P0002D0000<00003@00P280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@000?8200210@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000000209@0000`0000=0020AP0002P0000L0000AdA9@`80001M1000904006X4000e0@00
000004H0001@0000A00004E=AR/Z@000900001P00000080o000000000000080o00000000000:@030
70000100003ooooo0@0005h49@4;00l08@0000P0001R000030000040000T000090000000P3d00000
00000000P3d0000000000080000U0000300000H0000U0000300000P0081<0000I00005h4000U0@00
J0@003<1003HA@00B1800;00003`00008@3`0000000000000020?`00000000000020?`0000000000
000000000000000000000000000000009@0000`0000700209@0000`000000020900002@000000811
00000000000008110000000000020000AP0008P0001l0000ADe6:`Q07P8l0000<000004@`=/00000
EP0000000000080o0P000080000000110P00004@`=/000000000o`Q07`</00008000004@`=/40000
040005h49@5N13@1J@@d0FT49@400@615D0O0100000400007P0003X0000<0000200002@0000T0000
0020?@00000000000020?@00000000000P0005l0000h00001`0003P000000000>000000000008040
400000000000000000000000000000009@0000`0000700009@0000`000050020EP0002`0001A1000
604007D400100@0010000=Q5B1;HACPCR4Hh4hQ6B18U0000300000L0080U000030000000080T0000
90000000P440000000000000P440000000000080000X0000300000L0000j0000300000X0000R0000
30000?oooom60000700001000015CDH[140000`000000000AP0001@000080000AdA9@`<0000Q0000
200001h0000H0000H@@002H1001W1000=04002D0000<00001@0002D0000<00003@00P2D0000<0000
1@0001@0000<00003@000180000<00000@0005@0001D0000H@@002H1001V1000<`40004000000212
000P@V44000V0@000@0004`00000000000000000003ooooooooooe00000i00001P0002D0000<0000
3@00P280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J0000
4@000?8200210@008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000000020
9@0000`0000=0020AP0002P0000L0000AdA9@`80001N1000J04006/4001j0@00000004H0001@0000
A00004E=AR/Z@000900001P00000080o000000000000080o00000000000:@03070000100003ooooo
0@0005l4J@4;01008@0000P0001R000030000040000T000090000000P3d0000000000000P3d00000
00000080000U0000300000H0000U0000300000P0081<0000I00005l4001Y0@00J@@007P1003XA@00
R1H00;0000000@008@3`0000000000000020?`00000000000020?`00000000000000000000000000
00000000000000009@0000`0000700209@0000`000000020900002@0000008110000000000000811
0000000000020000AP0008P0001l0000ADe6:`Q0808l0000<000004@`=/00000EP0000000000080o
0P000080000000110P00004@`=/000000000o`Q08@</00008000004@`=/40000040005l4J@5O17T1
JPAi0FX4J@400@615D0Q010000040000800003X0000<0000200002@0000T00000020?@0000000000
0020?@00000000000P0005l0000h00001`0003P000000000>0000000000080404000000000000000
00000000000000009@0000`0000700009@0000`000050020EP0002`0001B1000G04007H400250@00
10000>Q5R1KXAHPGV4J85iQ6R1HU0000300000L0080U000030000000080T000090000000P4400000
00000000P440000000000080000X0000300000L0000j0000300000X0000R000030000?oooom60000
700001000015CDH[140000`000000000AP0001@000080000AdA9@`<0000Q0000200001h0000H0000
HP@006X1001X1000N@4002D0000<00001@0002D0000<00003@00P2D0000<00001@0001@0000<0000
3@000180000<00000@0005@0001D0000HP@006X1001W1000M`40004000000212000P@V84001Z0@00
0@0004`00000000000000000003ooooooooooe00000f00001P0002D0000<00003@00P280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@000?8200210@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000000209@0000`0000=0020
AP0002P0000L0000AdA9@`80001K1000eP0007<4003U0000000004H0001@0000A00004E=AR/Z@000
900001P00000080o000000000000080o00000000000:@03070000100003ooooo0@0005`4e`0F00d0
8@0000P0001R000030000040000T000090000000P3d0000000000000P3d0000000000080000U0000
300000H0000U0000300000P0081<0000I00005`4003G0000L@@00><0002hA@00J0d00601003@0000
8@3`0000000000000020?`00000000000020?`000000000000000000000000000000000000000000
9@0000`0000700209@0000`000000020900002@00000081100000000000008110000000000020000
AP0008P0001l0000ADe6:`Q08P8l0000<000004@`=/00000EP0000000000080o0P00008000000011
0P00004@`=/000000000o`Q08`</00008000004@`=/40000040005`4e`1L1>@0LPCT0784e`000@61
5D0S0100000400008P0003X0000<0000200002@0000T00000020?@00000000000020?@0000000000
0P0005l0000h00001`0003P000000000>00000000000804040000000000000000000000000000000
9@0000`0000700009@0000`000050020EP0002`0001?1000bP0007h4003`000010000;Q5J0fhACP>
64Lh3QQ7J0dU0000300000L0080U000030000000080T000090000000P440000000000000P4400000
00000080000X0000300000L0000j0000300000X0000R000030000?oooom60000700001000015CDH[
140000`000000000AP0001@000080000AdA9@`<0000Q0000200001h0000H0000G`@00=P0001`1000
i00002D0000<00001@0002D0000<00003@00P2D0000<00001@0001@0000<00003@000180000<0000
0@0005@0001H0000G`@00=P0001Z1000h`00004000000212000P@Ul4003H00000P0004`000000000
00000000003ooooooooooe00000a03801P0000H0000U0000300000d0080R000030000?oooolQ0000
200001T0000<0000oooo01P0000<0000000001h0000H00006P000140003b0P00P@400280000<0000
oooooaP0000<0000000001T0000<0000oooo02D0000<00000000P2D0000<00003@00P4H0000X0000
700004M4BD<2000000@00=L0000G1000i@00000000160000D00004@00015CDH[:T0002@0000H0000
0020?`00000000000020?`00000000002T00`1`0000@0000ooooo`4000011=P05@0<024000080000
HP0000`000010000900002@00000080m000000000000080m00000000000200009@0000`000060000
9@0000`000080020C00006@000011000f00001D4003S0000240007P=001@0@00`0000240l0000000
00000000P3l0000000000000P3l0000000000000000000000000000000000000000002D0000<0000
1`00P2D0000<00000000P2@0000T00000020@@00000000000020@@00000000000P0004H000280000
O00004E=AR/8@2@2?000030000014<3K000005H0000000000020?`80000200000000@@8000014<3K
000000000?l8@2D3;000020000014<3K1000001000011=P00@CT01H4i00F1=P00041PAE09@0@0000
100002@0000j0000300000P0000T000090000000P3d0000000000000P3d0000000000080001O0000
>00000L0000h0000000003P00000000002010100000000000000000000000000000002D0000<0000
1`0002D0000<00001@00P5H0000/0000m0<00</0000R1000l00000@00008@7P=240h3UQ1>0iH@GP=
9@0000`0000700209@0000`000000020900002@00000081100000000000008110000000000020000
:00000`000070000>P0000`0000:00008P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000
000004H0000D0000200004M4BD<300008@0000P0000N0000600000@4003I000050@00>@0000U0000
300000D0000U0000300000d0080U0000300000D0000D0000300000d0000B000030000040001D0000
F00000@4003I00003`@00><000010000000P@P0084841000f@000080001<00000000000000000000
oooooooooom@0000<@0c00H0000600009@0000`0000=00208P0000`0003ooooo8@0000P0000I0000
30000?ooo`0H000030000000000N0000600001X0000A0000lP800841000R000030000?oooolH0000
30000000000I000030000?ooo`0U000030000000080U0000300000d008160000:00001`00017A4U3
0P0006l5003C0000Q`D00>8000000000AP00050000140000ADe6:bY0000T000060000000P3l00000
00000000P3l00000000000Y00<0L000040000?ooool10000L0GD01H03@0Q000020000680000<0000
0@0002@0000T00000020?@00000000000020?@00000000000P0002D0000<00001P0002D0000<0000
2000P4`0001T0000L0D00=@000251@00h0000?QF000h3@00H0400=00000Q0?00000000000000080o
000000000000080o0000000000000000000000000000000000000000000U0000300000L0080U0000
30000000080T000090000000P440000000000000P44000000000008000160000R00007`00015CDH[
240V0S`0000`00000A30f`00001F000000000000P3l200000P000000044200000A30f`000000003o
240W0b`0000P00000A30f`@00000@000L0GD0705h@261N40QPGD00010H4E@2L0400000@0000V0000
>P0000`000080000900002@00000080m000000000000080m0000000000020000G`0003P000070000
>0000000000h00000000000P0@0@0000000000000000000000000000000U0000300000L0000U0000
300000D0081F0000;00006<500370000TPD00>d000040000n5Hh3OQF20iHF0P>F5Ph3BD0000<0000
1`00P2D0000<00000000P2@0000T00000020@@00000000000020@@00000000000P0002P0000<0000
1`0003X0000<00002P000280000<0000ooooodH0000L0000400004E=AR/4@0003000000000160000
500000P00017A4U30`000240000800007P0001P0001c1@00e@0008@5003Q00009@0000`000050000
9@0000`0000=00209@0000`000050000500000`0000=00004P0000`000010000E00005P0001c1@00
e@0007h5003P00000@00000084800212L`D00=D000020000C00000000000000000000?oooooooooo
D0000340<@0600001P0002D0000<00003@00P280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@000?8200210@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000000209@0000`0000=0020AP0002P0000L0000AdA9@`80003>0`00
[`000985002b0000000004H0002/0000X00004E=AR/Z@000900001P00000080o000000000000080o
000000000008@2P2A00003P000014<3K000007h0000000000020?`80000200000P00000004420000
0P00004@`=/000000000o`Q0:@<T00006000004@`=/2000004000<l3/@2A1K00004001E0:@0@0000
100002P0000X0000300000H0000Q000020000680000<00000@0002@0000T00000020?@0000000000
0020?@00000000000P0005l0000h00001P0003P000000000>000000000004P404000000000000000
00000000000000009@0000`0000600009`0001P00007000000000000000000009@0000`000070000
4`0000`000020000>`0000P0000K000040000>Pl00002`00=P000100003X?00000/005P0000d0000
00000000003oooooooooo`H0003]?00;l3`42o0l20_a?0d;kC`@2nTl40/f000040000>Tl000@2`00
F00003@00000000000000?oooooooooo1P000>@l4@_Q?0d;h3`92n0l10_T?04;j3`02cd000080000
6`0001000008?@0000/003H0000@000023d0000;001H0000=000000000000000ooooooooool60000
3Cd02a0m10/@?@P;4Cd=2`dm40/9?A0;=P0001000009?@0040/005P0000d000000000000003ooooo
ooooo`H00004?A0;0Cd=2`0m2@/0?@@;13d02`Pm00/m0000200001/0000@0000:3d0000;000f0000
400002Pm00002`00F00003@00000000000000?oooooooooo1P0002dm00/`?@@;<Cd82c4m3@/]?A0;
:Cd@2cH0000@0000:Cd0010;001H0000=000000000000000ooooooooool6000093d@2b4m3@/P?@P;
83d42b@m00/X?@0;?@0000P0000K0000400004Pm00002`00=P0001000018?@0000/005P0000d0000
00000000003oooooooooo`H0001=?@0;D3d42e4m20]A?@d;CCd@2dTm40/f0000400004Tm000@2`00
F00003@00000000000000?oooooooooo1P0004@m40]1?@d;@Cd82d0m10]4?@0;B3d02cd000080000
6`000100001X?@0000/003H0000@0000J3d0000;001H0000=000000000000000ooooooooool60000
KCd02g0m10]a?@P;LCd<2fdm40]Y?A0;=P000100001Y?@0040/005P0000d000000000000003ooooo
ooooo`H0001T?A0;HCd=2f4m20]P?@@;I3d02fPm00/m0000200001/0000@0000R3d0000;000f0000
400008Pm00002`00F00003@00000000000000?oooooooooo1P0008dm00^@?@@;TCd82i4m30^=?A0;
RCd@2cH0000@0000RCd0010;001H0000=000000000000000ooooooooool60000Q3d@2h4m3@^1?@P;
P3d42h@m00^8?@0;?@0000P0000K000040000:Pm00002`00=P000100002X?@0000/005P0000d0000
00000000003oooooooooo`H0002]?@0;/Cd32k4m20^a?@`;[Cd@2jTm40/f000040000:Tm000@2`00
F00003@00000000000000?oooooooooo1P000:@m40^Q?@d;XCd82j0m10^T?@0;Z3d02cd000080000
6`0001000038?@0000/003H0000@0000b3d0000;001H0000=000000000000000ooooooooool60000
cCd02m4m0`_A?@P;dCd<2ldm40_9?A0;=P0001000039?@0040/005P0000d000000000000003ooooo
ooooo`H00034?A0;`Cd=2l4m20_1?@@;a3d02lPm00/m0000200001/0000@0000j3d0000;000f0000
40000>Pm00002`00F00003@00000000000000?oooooooooo1P000>dm00_a?@<;lCd82o4m30_]?A0;
jCd@2cH0000@0000jCd0010;001H0000=000000000000000ooooooooool60000i3d@2n4m30_Q?@P;
hCd42n@m00_X?@0;?@0000P0000K0000400000Pn00002`00=P0001000008?P0000/005P0000d0000
00000000003oooooooooo`H0000=?P0;4Ch32a4n20/A?P`;3Ch@2`Tn40/f0000400000Tn000@2`00
F00003@00000000000000?oooooooooo1P0000@n40/1?P`;0Ch82`4n10/4?P0;23h02cd000080000
6`000100000X?P0000/003H0000@0000:Ch0000;001H0000=000000000000000ooooooooool60000
;Ch02c4n0`/a?PP;<Ch<2bdn40/Y?Q0;=P000100000Y?P0040/005P0000d000000000000003ooooo
ooooo`H0000T?Q0;8Ch<2b4n20/Q?P<;93h02bPn00/m0000200001/0000@0000BCh0000;000f0000
400004Tn00002`00F00003@00000000000000?oooooooooo1P0004dn00]A?P<;DCh82e4n30]=?Q0;
BCh@2cH0000@0000BCh0010;001H0000=000000000000000ooooooooool60000A3h@2d4n30]1?PP;
@Ch32d@n00]9?P0;?@0000P0000K0000400006Tn00002`00=P000100001Y?P0000/005P0000d0000
00000000003oooooooooo`H0001]?P0;LCh32g4n1`]a?P`;KCh@2fTn40/f0000400006Tn000@2`00
F00003@00000000000000?oooooooooo1P0006@n40]Q?P`;HCh82f4n0`]T?P0;JCh02cd000080000
6`0001000029?P0000/003H0000@0000RCh0000;001H0000=000000000000000ooooooooool60000
SCko2Y4n0`^A?PL;TCh<2hdn3`^9?Q0;=P0001000029?P0040/005P0000d000000000000003ooooo
ooooo`H00024?Q0;PCh<2h4n20^1?P<;Q3h02hTn00/m0000200001/0000@0000ZCh00?l:000f0000
40000:Tn003o2P00F00003@00000000000000?oooooooooo1P000:dno`Za?P<;/Ch72k4n30^]?Pl;
ZCh?2cH0000@0000ZCh000l;001H0000=000000000000000ooooooooool60000Y3h@2j4n30^Q?PP;
XCh32j@n00^Y?_l:?@0000P0000K000040000<Tn003o2P00=P0001000039?P00o`X005P0000d0000
00000000003oooooooooo`H0003=?_l:dCh32m4n1`_A?P`;cCh?2lTn3`/f000040000<Tn000?2`00
F00003@00000000000000?oooooooooo1P000<@n3`_1?P`;`Ch82l4n0`_4?_l:bCko2Sd000080000
6`000100003Y?P00o`X003H0000@0000jCh00?l:001H0000=000000000000000ooooooooool60000
kCko2_4n0`_a?PL;lCh<2ndn3`_Y?Pl;=P000100003Y?P003`/005P0000d000000000000003ooooo
ooooo`H0003T?Pl;hCh<2n4n1`_Q?P<;i3ko2^Tno`Xm0000200001/0000@00002Cl00?l:000f0000
400000To003o2P00F00003@00000000000000?oooooooooo1P0000doo`XA?`<;4Cl72a4o30/=?`l;
2Cl?2cH0000@00002Cl000l;001H0000=000000000000000ooooooooool6000013l?2`4o30/1?`L;
0Cl32`@oo`X9?ol:?@0000P0000K0000400002To003o2P00=P000100000Y?`00o`X005P0000d0000
00000000003oooooooooo`H0000]?ol:<Cl32c4o1`/a?`/;;Cl?2bTo3`/f0000400002To000?2`00
F00003@00000000000000?oooooooooo1P0002@o3`/Q?``;8Cl72b4o0`/T?ol::Coo2Sd000080000
6`0001000019?`00o`X003H0000@0000BCl00?l:001H0000=000000000000000ooooooooool60000
CCoo2U4o0`]A?`L;DCl;2ddo3`]9?`l;=P0001000019?`003`/005P0000d000000000000003ooooo
ooooo`H00014?`l;@Cl<2d4o1`]1?`<;A3oo2TToo`Xm0000200001/0000@0000JCl00?l:000f0000
400006To003o2P00F00003@00000000000000?oooooooooo1P0006doo`Ya?`8;LCl72g4o2`]]?`l;
JCl?2cH0000@0000JCl000l;001H0000=000000000000000ooooooooool60000I3l?2f4o30]Q?`L;
HCl32f@oo`YY?ol:?@0000P0000K0000400008To003o2P00=P0001000029?`00o`X005P0000d0000
00000000003oooooooooo`H0002=?ol:TCl22i4o1`^A?`/;SCl?2hTo3`/f0000400008To000?2`00
F00003@00000000000000?oooooooooo1P0008@o3`^1?``;PCl72h4o0`^4?ol:RCoo2Sd000080000
6`000100002Y?`00o`X003H0000@0000ZCl00?l:001H0000=000000000000000ooooooooool60000
[Coo2[4o0P^a?`L;/Cl;2jdo3`^Y?`l;=P000100002Y?`003`/005P0000d000000000000003ooooo
ooooo`H0002U?`l;XCl;2j4o1`^Q?`<;Y3oo2ZToo`Xm0000200001/0000@0000bCl00?l:000f0000
40000<To003o2P00F00003@00000000000000?oooooooooo1P000<doo`[A?`8;dCl72m4o2`_=?`l;
bCl?2cH0000@0000bCl000l;001H0000=000000000000000ooooooooool60000aCl?2l4o2`_1?`L;
`Cl32l@oo`[9?ol:?@0000P0000K000040000>To003o2P00=P000100003Y?`00o`X005P0000d0000
00000000003oooooooooo`H0003]?ol:lCl22o4o1`_a?`/;kCl?2nTo3`/f000040000>To000?2`00
F00003@00000000000000?oooooooooo1P000>Do3`_Q?`/;hCl72n4o0P_T?ol:jCoo2Sd000080000
6`0001000009@000o`X003H0000@00002D000?l:001H0000=000000000000000ooooooooool60000
3D3o2Q500P/A@0L;4D0;2`e03`/9@0l;=P0001000009@0003`/005P0000d000000000000003ooooo
ooooo`H00005@0l;0D0;2`501`/1@08;143o2PU0o`Xm0000200001/0000@0000:D000?l:000f0000
400002U0003o2P00F00003@00000000000000?oooooooooo1P0002e0o`Xa@08;<D062c502`/]@0l;
:D0?2cH0000@0000:D0000l;001H0000=000000000000000ooooooooool600009D0?2b502`/Q@0L;
8D022bA0o`XY@?l:?@0000P0000K0000400004U0003o2P00=P0001000019@000o`X005P0000d0000
00000000003oooooooooo`H0001=@?h:DD022e501P]A@0/;CD0>2dU03`/f0000400004U0000?2`00
F00003@00000000000000?oooooooooo1P0004E03`]1@0/;@D072d500P]4@?l:BD3o2Sd000080000
6`000100001Y@000oPX003H0000@0000JD000?h:001H0000=000000000000000ooooooooool60000
KD3n2W500P]a@0H;LD0;2fe03P]Y@0h;=P000100001Y@0003P/005P0000d000000000000003ooooo
ooooo`H0001U@0l;HD0;2f501`]Q@08;I43o2VU0oPXm0000200001/0000@0000RD000?h:000f0000
400008U0003n2P00F00003@00000000000000?oooooooooo1P0008e0oPZA@08;TD062i502`^=@0h;
RD0>2cH0000@0000RD0000h;001H0000=000000000000000ooooooooool60000QD0>2h502`^1@0L;
PD022hA0oPZ9@?h:?@0000P0000K000040000:U0003n2P00=P000100002Y@000oPX005P0000d0000
00000000003oooooooooo`H0002]@?h:/D022k501P^a@0/;[D0>2jU03P/f000040000:U0000>2`00
F00003@00000000000000?oooooooooo1P000:E03P^Q@0/;XD062j500P^T@?h:ZD3n2Sd000080000
6`0001000039@000oPX003H0000@0000bD000?h:001H0000=000000000000000ooooooooool60000
cD3n2]500P_A@0H;dD0;2le03P_9@0h;=P0001000039@0003P/005P0000d000000000000003ooooo
ooooo`H00035@0h;`D0;2l501P_1@08;a43n2/U0oPXm0000200001/0000@0000jD000?h:000f0000
40000>U0003n2P00F00003@00000000000000?oooooooooo1P000>e0oP[a@08;lD062o502P_^@0h;
jD0>2cH0000@0000jD0000h;001H0000=000000000000000ooooooooool60000iD0>2n502`_Q@0H;
hD022nA0oP[Y@?h:?@0000P0000K0000400000U1003n2P00=P0001000009@@00oPX005P0000d0000
00000000003oooooooooo`H0000=@Oh:4D422a511P/A@@X;3T4>2`U13P/f0000400000U1000>2`00
F00003@00000000000000?oooooooooo1P0000E13P/1@@/;0D462`510P/4@Oh:2D7n2Sd000080000
6`000100000Y@@00oPX003H0000@0000:D400?h:001H0000=000000000000000ooooooooool60000
;D7n2S510@/a@@H;<D4:2bi13P/Y@@h;=P000100000Y@@003P/005P0000d000000000000003ooooo
ooooo`H0000U@@h;8D4;2b511P/Q@@8;947n2RU1oPXm0000200001/0000@0000BD400?h:000f0000
400004U1003n2P00F00003@00000000000000?oooooooooo1P0004e1oPYA@@4;DD462e512P]>@@h;
BD4>2cH0000@0000BD4000h;001H0000=000000000000000ooooooooool60000AD4>2d512`]1@@H;
@D422dA1oPY9@Oh:?@0000P0000K0000400006U1003n2P00=P000100001Y@@00oPX005P0000d0000
00000000003oooooooooo`H0001]@Oh:LD412g511P]a@@X;KT4>2fU13P/f0000400006U1000>2`00
F00003@00000000000000?oooooooooo1P0006E13P]Q@@X;HD462f510P]T@Oh:JD7n2Sd000080000
6`0001000029@@00oPX003H0000@0000RD400?h:001H0000=000000000000000ooooooooool60000
SD7n2Y510@^A@@H;TD4:2hi13P^9@@h;=P0001000029@@003P/005P0000d000000000000003ooooo
ooooo`H00025@@h;PD4:2h511P^1@@8;Q47n2XU1oPXm0000200001/0000@0000ZD400?h:000f0000
40000:U1003n2P00F00003@00000000000000?oooooooooo1P000:e1oPZa@@4;/D462k512P^^@@h;
ZD4>2cH0000@0000ZD4000h;001H0000=000000000000000ooooooooool60000YD4>2j512P^Q@@H;
XD412jE1oPZY@Oh:?@0000P0000K000040000<U1003n2P00=P0001000039@@00oPX005P0000d0000
00000000003oooooooooo`H0003=@Oh:dD412m511P_A@@X;cT4>2lU13P/f000040000<U1000>2`00
F00003@00000000000000?oooooooooo1P000<E13P_1@@X;`D462l510@_5@Oh:bD7n2Sd000080000
6`000100003Y@@00oPX003H0000@0000jD400?h:001H0000=000000000000000ooooooooool60000
kD7n2_510@_a@@D;lD4:2ni13P_Y@@h;=P000100003Y@@003P/005P0000d000000000000003ooooo
ooooo`H0003U@@h;hD4:2n511P_Q@@4;iD7n2^U1oPXm0000200001/0000@00002D800?h:000f0000
400000U2003n2P00F00003@00000000000000?oooooooooo1P0000e2o@XA@P4;4D852a522P/>@Pd;
2D8>2cH0000@00002D8000h;001H0000=000000000000000ooooooooool600001D8>2`522P/1@PH;
0D812`E2oPX9@_h:?@0000P0000K0000400002U2003m2P00=P000100000Y@P00o@X005P0000d0000
00000000003oooooooooo`H0000]@_d:<D812c521@/a@PX;;T8=2bU23@/f0000400002U2000=2`00
F00003@00000000000000?oooooooooo1P0002E23P/Q@PX;8D862b520@/U@_h::D;m2Sd000080000
6`0001000019@P00o@X003H0000@0000BD800?d:001H0000=000000000000000ooooooooool60000
CD;m2U520@]A@PD;DD8:2di23@]9@Pd;=P0001000019@P003@/005P0000d000000000000003ooooo
ooooo`H00015@Pd;@D8:2d521P]1@P4;AD;m2TU2o@Xm0000200001/0000@0000JD800?d:000f0000
400006U2003m2P00F00003@00000000000000?oooooooooo1P0006e2o@Ya@P4;LD852g522P]^@Pd;
JD8=2cH0000@0000JD8000d;001H0000=000000000000000ooooooooool60000ID8=2f522P]Q@PD;
HD812fE2o@YY@_d:?@0000P0000K0000400008U2003m2P00=P0001000029@P00o@X005P0000d0000
00000000003oooooooooo`H0002=@_d:TD812i521@^A@PX;ST8=2hU23@/f0000400008U2000=2`00
F00003@00000000000000?oooooooooo1P0008E23@^1@PX;PD852h520@^5@_d:RD;m2Sd000080000
6`000100002Y@P00o@X003H0000@0000ZD800?d:001H0000=000000000000000ooooooooool60000
[D;m2[520@^a@PD;/D892ji23@^Y@Pd;=P000100002Y@P003@/005P0000d000000000000003ooooo
ooooo`H0002U@Pd;XD8:2j521@^Q@P4;YD;m2ZU2o@Xm0000200001/0000@0000bD800?d:000f0000
40000<U2003m2P00F00003@00000000000000?oooooooooo1P000<e2o@[A@P4;dD852m522@_>@Pd;
bD8=2cH0000@0000bD8000d;001H0000=000000000000000ooooooooool60000aD8=2l522P_1@PD;
`D812lE2o@[9@_d:?@0000P0000K000040000>U2003m2P00=P000100003Y@P00o@X005P0000d0000
00000000003oooooooooo`H0003^@_d:lD802o521@_a@PT;kT8=2nU23@/f000040000>U2000=2`00
F00003@00000000000000?oooooooooo1P000>E23@_Q@PX;hD852n520@_U@_d:jD;m2Sd000080000
6`0001000009@`00o@X003H0000@00002D<00?d:001H0000=000000000000000ooooooooool60000
3T?m2Q5300/A@`D;4D<92`i33@/9@`d;=P0001000009@`003@/005P0000d000000000000003ooooo
ooooo`H00005@`d;0D<:2`531@/1@`4;1D?m2PU3o@Xm0000200001/0000@0000:D<00?d:000f0000
400002U3003m2P00F00003@00000000000000?oooooooooo1P0002i3o@Xa@`0;<D<52c532@/^@`d;
:D<=2cH0000@0000:D<000d;001H0000=000000000000000ooooooooool600009D<=2b532@/Q@`D;
8D<12bE3o@XY@od:?@0000P0000K0000400004U3003m2P00=P0001000019@`00o@X005P0000d0000
00000000003oooooooooo`H0001>@od:DD<02e531@]A@`T;CT<=2dU33@/f0000400004U3000=2`00
F00003@00000000000000?oooooooooo1P0004E33@]1@`T;@D<52d530@]5@od:BD?m2Sd000080000
6`000100001Y@`00o@X003H0000@0000JD<00?d:001H0000=000000000000000ooooooooool60000
KT?m2W5300]a@`D;LD<92fi33@]Y@`d;=P000100001Y@`003@/005P0000d000000000000003ooooo
ooooo`H0001U@`d;HD<92f531@]Q@`0;ID?m2VU3o@Xm0000200001/0000@0000RD<00?d:000f0000
400008U3003m2P00F00003@00000000000000?oooooooooo1P0008i3o@ZA@`0;TD<52i532@^>@`d;
RD<=2cH0000@0000RD<000d;001H0000=000000000000000ooooooooool60000QD<=2h532@^1@`D;
PD<02hE3o@Z9@od:?@0000P0000K000040000:U3003m2P00=P000100002Y@`00o@X005P0000d0000
00000000003oooooooooo`H0002^@od:/D<02k5310^a@`T;[T<=2jU33@/f000040000:U3000=2`00
F00003@00000000000000?oooooooooo1P000:E33@^Q@`T;XD<52j5300^U@od:ZD?m2Sd000080000
6`0001000039@`00o@X003H0000@0000bD<00?d:001H0000=000000000000000ooooooooool60000
cT?l2]5300_A@`@;dD<92li330_9@`d;=P0001000039@`003@/005P0000d000000000000003ooooo
ooooo`H00035@`d;`D<92l531@_1@`0;aD?m2/U3o@Xm0000200001/0000@0000jD<00?`:000f0000
40000>U3003l2P00F00003@00000000000000?oooooooooo1P000>i3o0[a@`0;lD<42o532@_^@``;
jD<<2cH0000@0000jD<000`;001H0000=000000000000000ooooooooool60000iD<=2n532@_Q@`D;
hD<02nE3o@[Y@o`:?@0000P0000K0000400000U4003l2P00=P0001000009A000o0X005P0000d0000
00000000003oooooooooo`H0000>A?`:4D@02a5410/AA0T;3T@<2`U430/f0000400000U4000<2`00
F00003@00000000000000?oooooooooo1P0000E430/1A0T;0D@52`5400/5A?`:2DCl2Sd000080000
6`000100000YA000o0X003H0000@0000:D@00?`:001H0000=000000000000000ooooooooool60000
;TCl2S5400/aA0@;<D@92bi430/ZA0`;=P000100000YA00030/005P0000d000000000000003ooooo
ooooo`H0000UA0`;8D@92b5410/QA00;9DCl2RU4o0Xm0000200001/0000@0000BD@00?`:000f0000
400004U4003l2P00F00003@00000000000000?oooooooooo1P0004i4o0YAA00;DD@42e542@]>A0`;
BT@<2cH0000@0000BT@000`;001H0000=000000000000000ooooooooool60000AD@<2d542@]1A0@;
@D@02dE4o0Y9A?`:?@0000P0000K0000400006U4003l2P00=P000100001YA000o0X005P0000d0000
00000000003oooooooooo`H0001^A?`:LD@02g5410]aA0P;KT@<2fY430/f0000400006Y4000<2`00
F00003@00000000000000?oooooooooo1P0006E430]QA0T;HD@42f5400]UA?`:JDCl2Sd000080000
6`0001000029A000o0X003H0000@0000RD@00?`:001H0000=000000000000000ooooooooool60000
STCl2Y5400^AA0@;TD@82hi430^:A0`;=P000100002:A00030/005P0000d000000000000003ooooo
ooooo`H00025A0`;PD@92h5410^1A00;QDCl2XU4o0Xm0000200001/0000@0000ZD@00?`:000f0000
40000:U4003l2P00F00003@00000000000000?oooooooooo1P000:i4o0ZaA?l:/D@42k9420^^A0`;
ZT@<2cH0000@0000ZT@000`;001H0000=000000000000000ooooooooool60000YD@<2j542@^QA0@;
XD@02jE4o0ZYA?`:?@0000P0000K000040000<U4003l2P00=P0001000039A000o0X005P0000d0000
00000000003oooooooooo`H0003>A?`:dDCo2]5410_BA0P;cT@<2lY430/f000040000<Y4000<2`00
F00003@00000000000000?oooooooooo1P000<E430_2A0T;`D@42l5400_5A?`:bDCl2Sd000080000
6`000100003YA000o0X003H0000@0000jD@00?`:001H0000=000000000000000ooooooooool60000
kTCl2_54o`[aA0@;lT@82ni430_ZA0`;=P000100003ZA00030/005P0000d000000000000003ooooo
ooooo`H0003UA0`;hT@82n5410_QA00;iDCl2^U4o0Xm0000200001/0000@00002DD00?`:000f0000
400000U5003l2P00F00003@00000000000000?oooooooooo1P0000i5o0XAAOl:4DD42a9520/>A@`;
2TD<2cH0000@00002TD000`;001H0000=000000000000000ooooooooool600001DD<2`9520/1A@@;
0DD02`E5o0X9AO`:?@0000P0000K0000400002U5003l2P00=P000100000YA@00o0X005P0000d0000
00000000003oooooooooo`H0000^AO`:<DGo2S9510/bA@P;;TD<2bY530/f0000400002Y5000<2`00
F00003@00000000000000?oooooooooo1P0002E530/RA@P;8DD42b55o`XUAO`::DGl2Sd000080000
6`0001000019A@00o0X003H0000@0000BDD00?`:001H0000=000000000000000ooooooooool60000
CTGl2U55o`YBA@@;DTD82di530]:A@`;=P000100001:A@0030/005P0000d000000000000003ooooo
ooooo`H00015A@`;@TD82d9510]1AOl:ADGl2TU5o0Xm0000200001/0000@0000JDD00?`:000f0000
400006U5003l2P00F00003@00000000000000?oooooooooo1P0006i5o0YaAOl:LTD32g9520]^A@`;
JTD<2cH0000@0000JTD000`;001H0000=000000000000000ooooooooool60000IDD<2f9520]RA@@;
HDGo2VE5o0YYAO`:?@0000P0000K0000400008U5003l2P00=P0001000029A@00o0X005P0000d0000
00000000003oooooooooo`H0002>AO/:TDGo2Y950`^BA@P;STD;2hY530/f0000400008Y5000<2`00
F00003@00000000000000?oooooooooo1P0008E530^2A@P;PTD42h55o`Z5AO`:RDGl2Sd000080000
6`000100002YA@00n`X003H0000@0000ZDD00?/:001H0000=000000000000000ooooooooool60000
[TGk2[55o`ZbA@<;/TD82ji52`^ZA@/;=P000100002ZA@002`/005P0000d000000000000003ooooo
ooooo`H0002UA@`;XTD82j9510^QAOl:YDGl2ZU5n`Xm0000200001/0000@0000bDD00?/:000f0000
40000<U5003k2P00F00003@00000000000000?oooooooooo1P000<i5n`[BAOl:dTD32m9520_>A@/;
bTD;2cH0000@0000bTD000/;001H0000=000000000000000ooooooooool60000aDD;2l9520_2A@@;
`DGo2/E5n`[9AO/:?@0000P0000K000040000>U5003k2P00=P000100003YA@00n`X005P0000d0000
00000000003oooooooooo`H0003^AO/:lTGo2_950`_bA@P;kTD;2nY52`/f000040000>Y5000;2`00
F00003@00000000000000?oooooooooo1P000>E52`_RA@P;hTD32n95o`[UAO/:jDGk2Sd000080000
6`0001000009AP00n`X003H0000@00002DH00?/:001H0000=000000000000000ooooooooool60000
3TKk2Q96o`XBAP<;4TH82`i62`/:AP/;=P000100000:AP002`/005P0000d000000000000003ooooo
ooooo`H00005AP/;0TH82`960`/2A_l:1DKk2PU6n`Xm0000200001/0000@0000:DH00?/:000f0000
400002Y6003k2P00F00003@00000000000000?oooooooooo1P0002i6n`XbA_l:<TH32c961`/^AP/;
:TH;2cH0000@0000:TH000/;001H0000=000000000000000ooooooooool600009DH;2b9620/RAP<;
8TKo2RE6n`XYA_/:?@0000P0000K0000400004Y6003k2P00=P000100001:AP00n`X005P0000d0000
00000000003oooooooooo`H0001>A_/:DTKo2U960`]BAPL;CTH;2dY62`/f0000400004Y6000;2`00
F00003@00000000000000?oooooooooo1P0004E62`]2APP;@TH32d96o`Y5A_/:BTKk2Sd000080000
6`000100001ZAP00n`X003H0000@0000JTH00?/:001H0000=000000000000000ooooooooool60000
KTKk2W96oPYbAP<;LTH72fi62`]ZAP/;=P000100001ZAP002`/005P0000d000000000000003ooooo
ooooo`H0001UAP/;HTH82f960`]RA_l:IDKk2VY6n`Xm0000200001/0000@0000RTH00?/:000f0000
400008Y6003k2P00F00003@00000000000000?oooooooooo1P0008i6n`ZBA_h:TTH32i961`^>AP/;
RTH;2cH0000@0000RTH000/;001H0000=000000000000000ooooooooool60000QDH;2h9620^2AP<;
PTKo2XE6n`Z:A_/:?@0000P0000K000040000:Y6003k2P00=P000100002ZAP00n`X005P0000d0000
00000000003oooooooooo`H0002^A_/:/TKn2[960`^bAPL;[TH;2jY62`/f000040000:Y6000;2`00
F00003@00000000000000?oooooooooo1P000:E62`^RAPL;XTH32j96o`ZUA_/:ZTKk2Sd000080000
6`000100003:AP00n`X003H0000@0000bTH00?/:001H0000=000000000000000ooooooooool60000
cTKk2]96oP[BAP<;dTH72li62`_:AP/;=P000100003:AP002`/005P0000d000000000000003ooooo
ooooo`H00035AP/;`TH72l960`_2A_l:aDKk2/Y6n`Xm0000200001/0000@0000jTH00?/:000f0000
40000>Y6003k2P00F00003@00000000000000?oooooooooo1P000>i6n`[bA_h:lTH32o961`_^AP/;
jTH;2cH0000@0000jTH000/;001H0000=000000000000000ooooooooool60000iDH;2n961`_RAP<;
hTKn2^E6n`[ZA_/:?@0000P0000K0000400000Y7003k2P00=P000100000:A`00n`X005P0000d0000
00000000003oooooooooo`H0000>Ao/:4TOn2Q970`/BA`L;3TL;2`Y72`/f0000400000Y7000;2`00
F00003@00000000000000?oooooooooo1P0000E72`/2A`L;0TL32`97oPX5Ao/:2TOk2Sd000080000
6`000100000ZA`00n`X003H0000@0000:TL00?/:001H0000=000000000000000ooooooooool60000
;TOk2S97oPXbA`8;<TL72bi72`/ZA`/;=P000100000ZA`002`/005P0000d000000000000003ooooo
ooooo`H0000UA`/;8TL72b970`/RAoh:9DOk2RY7n`Xm0000200001/0000@0000BTL00?/:000f0000
400004Y7003k2P00F00003@00000000000000?oooooooooo1P0004i7nPYBAoh:DTL22e971`]>A`X;
BTL;2cH0000@0000BTL000/;001H0000=000000000000000ooooooooool60000ADL;2d971`]2A`<;
@TOn2TE7n`Y:Ao/:?@0000P0000K0000400006Y7003j2P00=P000100001ZA`00nPX005P0000d0000
00000000003oooooooooo`H0001^AoX:LTOn2W970P]bA`L;KTL:2fY72P/f0000400006Y7000:2`00
F00003@00000000000000?oooooooooo1P0006E72`]RA`L;HTL32f97oPYUAo/:JTOj2Sd000080000
6`000100002:A`00nPX003H0000@0000RTL00?X:001H0000=000000000000000ooooooooool60000
STOj2Y97oPZBA`8;TTL72hi72P^:A`X;=P000100002:A`002P/005P0000d000000000000003ooooo
ooooo`H00025A`X;PTL72h970`^2Aoh:QDOj2XY7nPXm0000200001/0000@0000ZTL00?X:000f0000
40000:Y7003j2P00F00003@00000000000000?oooooooooo1P000:i7nPZbAoh:/TL22k971`^^A`X;
ZTL:2cH0000@0000ZTL000X;001H0000=000000000000000ooooooooool60000YTL:2j971`^RA`8;
XTOn2ZE7nPZZAoX:?@0000P0000K000040000<Y7003j2P00=P000100003:A`00nPX005P0000d0000
00000000003oooooooooo`H0003>AoX:dTOn2]970P_BA`L;cTL:2lY72P/f000040000<Y7000:2`00
F00003@00000000000000?oooooooooo1P000<I72P_2A`L;`TL22l97oP[5AoX:bTOj2Sd000080000
6`000100003ZA`00nPX003H0000@0000jTL00?X:001H0000=000000000000000ooooooooool60000
kTOj2_97oP[bA`8;lTL62ni72P_ZA`X;=P000100003ZA`002P/005P0000d000000000000003ooooo
ooooo`H0003VA`X;hTL72n970P_RAoh:iDOj2^Y7nPXm0000200001/0000@00002TP00?X:000f0000
400000Y8003j2P00F00003@00000000000000?oooooooooo1P0000i8nPXBB?h:4TP22a981P/>B0X;
2TP:2cH0000@00002TP000X;001H0000=000000000000000ooooooooool600001TP:2`981`/2B08;
0TSn2PE8nPX:B?X:?@0000P0000K0000400002Y8003j2P00=P000100000ZB000nPX005P0000d0000
00000000003oooooooooo`H0000^B?X:<TSn2S980P/bB0H;;TP:2bY82P/f0000400002Y8000:2`00
F00003@00000000000000?oooooooooo1P0002I82P/RB0L;8TP22b98oPXUB?X::TSj2Sd000080000
6`000100001:B000nPX003H0000@0000BTP00?X:001H0000=000000000000000ooooooooool60000
CTSj2U98o@YBB08;DTP62di82P]:B0X;=P000100001:B0002P/005P0000d000000000000003ooooo
ooooo`H00016B0X;@TP72d980P]2B?h:ADSj2TY8nPXm0000200001/0000@0000JTP00?X:000f0000
400006Y8003j2P00F00003@00000000000000?oooooooooo1P0006i8nPYbB?d:LTP22g981P]^B0X;
JTP:2cH0000@0000JTP000X;001H0000=000000000000000ooooooooool60000ITP:2f981P]RB08;
HTSn2VE8nPYZB?X:?@0000P0000K0000400008Y8003j2P00=P000100002:B000nPX005P0000d0000
00000000003oooooooooo`H0002>B?X:TTSm2Y980P^BB0H;STP:2hY82P/f0000400008Y8000:2`00
F00003@00000000000000?oooooooooo1P0008I82P^2B0H;PTP22h98oPZ5B?X:RTSj2Sd000080000
6`000100002ZB000nPX003H0000@0000ZTP00?X:001H0000=000000000000000ooooooooool60000
[TSj2[98o@ZbB08;/TP62ji82P^ZB0X;=P000100002ZB0002P/005P0000d000000000000003ooooo
ooooo`H0002VB0X;XTP62j980P^RB?d:YDSj2ZY8nPXm0000200001/0000@0000bTP00?X:000f0000
40000<Y8003j2P00F00003@00000000000000?oooooooooo1P000<i8nP[BB?d:dTP22m981P_>B0X;
bTP:2cH0000@0000bTP000X;001H0000=000000000000000ooooooooool60000aTP:2l981P_2B08;
`TSm2/E8nP[:B?X:?@0000P0000K000040000>Y8003j2P00=P000100003ZB000nPX005P0000d0000
00000000003oooooooooo`H0003^B?X:lTSm2_980@_bB0H;kdP:2nY82P/f000040000>Y8000:2`00
F00003@00000000000000?oooooooooo1P000>I82P_RB0H;hTP22n98o@[UB?X:jTSj2Sd000080000
6`000100000:B@00nPX003H0000@00002TT00?X:001H0000=000000000000000ooooooooool60000
3TWi2Q99o@XBB@4;4TT62`m92@/:B@X;=P000100000:B@002P/005P0000d000000000000003ooooo
ooooo`H00006B@X;0TT62`990P/2BOd:1DWj2PY9nPXm0000200001/0000@0000:TT00?T:000f0000
400002Y9003i2P00F00003@00000000000000?oooooooooo1P0002i9n@XbBOd:<TT12c991P/_B@T;
:TT92cH0000@0000:TT000T;001H0000=000000000000000ooooooooool600009TT:2b991P/RB@8;
8TWm2RE9nPXZBOT:?@0000P0000K0000400004Y9003i2P00=P000100001:B@00n@X005P0000d0000
00000000003oooooooooo`H0001>BOT:DTWm2U990@]BB@H;CdT92dY92@/f0000400004Y900092`00
F00003@00000000000000?oooooooooo1P0004I92@]2B@H;@TT22d99o@Y5BOT:BTWi2Sd000080000
6`000100001ZB@00n@X003H0000@0000JTT00?T:001H0000=000000000000000ooooooooool60000
KTWi2W99o@YbB@4;LTT62fm92@]ZB@T;=P000100001ZB@002@/005P0000d000000000000003ooooo
ooooo`H0001VB@T;HTT62f990@]RBOd:IDWi2VY9n@Xm0000200001/0000@0000RTT00?T:000f0000
400008Y9003i2P00F00003@00000000000000?oooooooooo1P0008i9n@ZBBOd:TTT12i991P^?B@T;
RTT92cH0000@0000RTT000T;001H0000=000000000000000ooooooooool60000QTT92h991P^2B@4;
PTWm2XE9n@Z:BOT:?@0000P0000K000040000:Y9003i2P00=P000100002ZB@00n@X005P0000d0000
00000000003oooooooooo`H0002^BOT:/TWm2[990@^bB@D;[dT92jY92@/f000040000:Y900092`00
F00003@00000000000000?oooooooooo1P000:I92@^RB@H;XTT12j99o@ZVBOT:ZTWi2Sd000080000
6`000100003:B@00n@X003H0000@0000bTT00?T:001H0000=000000000000000ooooooooool60000
cTWi2]99o@[BB@4;dTT52lm92@_:B@T;=P000100003:B@002@/005P0000d000000000000003ooooo
ooooo`H00036B@T;`TT62l990@_2BOd:aTWi2/Y9n@Xm0000200001/0000@0000jTT00?T:000f0000
40000>Y9003i2P00F00003@00000000000000?oooooooooo1P000>i9n@[bBOd:lTT12o991@__B@T;
jTT92cH0000@0000jTT000T;001H0000=000000000000000ooooooooool60000iTT92n991P_RB@4;
hTWm2^I9n@[ZBOT:?@0000P0000K0000400000Y:003i2P00=P000100000:BP00n@X005P0000d0000
00000000003oooooooooo`H0000>B_T:4T[l2Q9:0@/BBPD;3dX92`Y:2@/f0000400000Y:00092`00
F00003@00000000000000?oooooooooo1P0000I:2@/2BPH;0TX12`9:o@X6B_T:2T[i2Sd000080000
6`000100000ZBP00n@X003H0000@0000:TX00?T:001H0000=000000000000000ooooooooool60000
;T[i2S9:o0XbBP4;<TX52bm:2@/ZBPT;=P000100000ZBP002@/005P0000d000000000000003ooooo
ooooo`H0000VBPT;8TX52b9:0@/RB_d:9T[i2RY:n@Xm0000200001/0000@0000BTX00?T:000f0000
400004Y:003i2P00F00003@00000000000000?oooooooooo1P0004i:n@YBB_`:DTX12e9:1@]?BPT;
BTX92cH0000@0000BTX000T;001H0000=000000000000000ooooooooool60000ATX92d9:1@]2BP4;
@T[m2TI:n@Y:B_T:?@0000P0000K0000400006Y:003i2P00=P000100001ZBP00n@X005P0000d0000
00000000003oooooooooo`H0001^B_T:LT[l2W9:0@]bBPD;KdX92fY:2@/f0000400006Y:00092`00
F00003@00000000000000?oooooooooo1P0006I:2@]RBPD;HTX12f9:o0YVB_T:JT[i2Sd000080000
6`000100002:BP00n@X003H0000@0000RTX00?T:001H0000=000000000000000ooooooooool60000
ST[i2Y9:o0ZBBP4;TTX52hm:2@^:BPT;=P000100002:BP002@/005P0000d000000000000003ooooo
ooooo`H00026BPT;PTX52h9:0@^2B_`:QT[i2XY:n@Xm0000200001/0000@0000ZTX00?T:000f0000
40000:Y:003i2P00F00003@00000000000000?oooooooooo1P000:i:n@ZbB_`:/TX02k9:1@^_BPT;
ZTX92cH0000@0000ZTX000T;001H0000=000000000000000ooooooooool60000YTX92j9:1@^RBP4;
XT[l2ZI:n@ZZB_T:?@0000P0000K000040000<Y:003i2P00=P000100003:BP00n@X005P0000d0000
00000000003oooooooooo`H0003>B_P:dT[l2]9:00_BBPD;cdX82lY:2@/f000040000<Y:00092`00
F00003@00000000000000?oooooooooo1P000<I:2@_2BPD;`TX12l9:o0[6B_T:bT[i2Sd000080000
6`000100003ZBP00n0X003H0000@0000jTX00?P:001H0000=000000000000000ooooooooool60000
kd[h2_9:o0[bBP0;lTX52nm:20_ZBPP;=P000100003ZBP0020/005P0000d000000000000003ooooo
ooooo`H0003VBPT;hTX52n9:0@_RB_`:iT[i2^Y:n0Xm0000200001/0000@00002T/00?P:000f0000
400000Y;003h2P00F00003@00000000000000?oooooooooo1P0000m;n0XBBo`:4T/02a9;1@/?B`P;
2T/82cH0000@00002T/000P;001H0000=000000000000000ooooooooool600001T/82`9;1@/2B`4;
0T_l2PI;n0X:BoP:?@0000P0000K0000400002Y;003h2P00=P000100000ZB`00n0X005P0000d0000
00000000003oooooooooo`H0000_BoP:<T_l2S9;00/bB`D;;d/82bY;20/f0000400002Y;00082`00
F00003@00000000000000?oooooooooo1P0002I;20/RB`D;8T/02b9;o0XVBoP::T_h2Sd000080000
6`000100001:B`00n0X003H0000@0000BT/00?P:001H0000=000000000000000ooooooooool60000
Cd_h2U9;o0YBB`0;DT/52dm;20]:B`P;=P000100001:B`0020/005P0000d000000000000003ooooo
ooooo`H00016B`P;@T/52d9;00]2Bo`:AT_h2TY;n0Xm0000200001/0000@0000JT/00?P:000f0000
400006Y;003h2P00F00003@00000000000000?oooooooooo1P0006m;n0YbBo`:LT/02g9;10]_B`P;
JT/82cH0000@0000JT/000P;001H0000=000000000000000ooooooooool60000IT/82f9;1@]RB`0;
HT_l2VI;n0YZBoP:?@0000P0000K0000400008Y;003h2P00=P000100002:B`00n0X005P0000d0000
00000000003oooooooooo`H0002?BoP:TT_l2Y9;00^BB`@;Sd/82hY;20/f0000400008Y;00082`00
F00003@00000000000000?oooooooooo1P0008I;20^2B`D;PT/02h9;o0Z6BoP:RT_h2Sd000080000
6`000100002ZB`00n0X003H0000@0000ZT/00?P:001H0000=000000000000000ooooooooool60000
[d_h2[9;o0ZbB`0;/T/42jm;20^ZB`P;=P000100002ZB`0020/005P0000d000000000000003ooooo
ooooo`H0002VB`P;XT/52j9;00^RBo`:YT_h2ZY;n0Xm0000200001/0000@0000bT/00?P:000f0000
40000<Y;003h2P00F00003@00000000000000?oooooooooo1P000<m;n0[BBo/:dT/02m9;10_?B`P;
bT/82cH0000@0000bT/000P;001H0000=000000000000000ooooooooool60000aT/82l9;1@_2B`0;
`T_l2/I;n0[:BoP:?@0000P0000K000040000>Y;003h2P00=P000100003ZB`00n0X005P0000d0000
00000000003oooooooooo`H0003_BoP:lT_k2_9;00_bB`@;kd/82nY;20/f000040000>Y;00082`00
F00003@00000000000000?oooooooooo1P000>I;20_RB`@;hT/02n9;o0[VBoP:jT_h2Sd000080000
6`000100000:C000n0X003H0000@00002T`00?P:001H0000=000000000000000ooooooooool60000
3dch2Q9<n`XBC00;4T`42`m<20/:C0P;=P000100000:C00020/005P0000d000000000000003ooooo
ooooo`H00006C0P;0T`42`9<00/2C?`:1Tch2PY<n0Xm0000200001/0000@0000:T`00?P:000f0000
400002Y<003h2P00F00003@00000000000000?oooooooooo1P0002m<n0XbC?/:<T`02c9<10/_C0P;
:d`82cH0000@0000:T`000P;001H0000=000000000000000ooooooooool600009T`82b9<10/RC00;
8Tck2RI<n0XZC?P:?@0000P0000K0000400004Y<003h2P00=P000100001:C000n0X005P0000d0000
00000000003oooooooooo`H0001?C?P:DTck2U9<00]BC0@;Cd`82d]<20/f0000400004]<00082`00
F00003@00000000000000?oooooooooo1P0004I<20]2C0@;@T`02d9<n`Y6C?P:BTch2Sd000080000
6`000100001ZC000n0X003H0000@0000JT`00?P:001H0000=000000000000000ooooooooool60000
Kdch2W9<n`YbC?l:LT`42fm<20][C0P;=P000100001[C00020/005P0000d000000000000003ooooo
ooooo`H0001VC0P;HT`42f9<00]RC?/:ITch2VY<n0Xm0000200001/0000@0000RT`00?P:000f0000
400008Y<003h2P00F00003@00000000000000?oooooooooo1P0008m<m`ZBC?/:TTco2Y9<10^?C0L;
Rd`82cH0000@0000Rd`000P;001H0000=000000000000000ooooooooool60000QT`82h9<10^2C00;
PTck2XI<n0Z:C?P:?@0000P0000K000040000:Y<003g2P00=P000100002ZC000m`X005P0000d0000
00000000003oooooooooo`H0002_C?L:/Tck2[9<o`ZcC0@;[d`72j]<1`/f000040000:]<00072`00
F00003@00000000000000?oooooooooo1P000:I<20^RC0@;XT`02j9<n`ZVC?P:ZTcg2Sd000080000
6`000100003:C000m`X003H0000@0000bT`00?L:001H0000=000000000000000ooooooooool60000
cdcg2]9<n`[BC?l:dd`42lm<1`_;C0L;=P000100003;C0001`/005P0000d000000000000003ooooo
ooooo`H00036C0L;`d`42l9<00_2C?/:aTcg2/Y<m`Xm0000200001/0000@0000jT`00?L:000f0000
40000>Y<003g2P00F00003@00000000000000?oooooooooo1P000>m<m`[bC?/:lTco2_=<10__C0L;
jd`72cH0000@0000jd`000L;001H0000=000000000000000ooooooooool60000iT`72n=<10_RC?l:
hTck2^I<m`[ZC?L:?@0000P0000K0000400000Y=003g2P00=P000100000:C@00m`X005P0000d0000
00000000003oooooooooo`H0000?COL:4Tgk2Q9=o`XCC@@;3dd72`]=1`/f0000400000]=00072`00
F00003@00000000000000?oooooooooo1P0000I=1`/3C@@;0Tgo2P9=n`X6COL:2Tgg2Sd000080000
6`000100000ZC@00m`X003H0000@0000:Td00?L:001H0000=000000000000000ooooooooool60000
;dgg2S9=n`XcCOl:<dd32bm=1`/[C@L;=P000100000[C@001`/005P0000d000000000000003ooooo
ooooo`H0000VC@L;8dd42b9=o`XRCO/:9Tgg2RY=m`Xm0000200001/0000@0000BTd00?L:000f0000
400004Y=003g2P00F00003@00000000000000?oooooooooo1P0004m=m`YBCO/:Ddgo2U==0`]?C@L;
Bdd72cH0000@0000Bdd000L;001H0000=000000000000000ooooooooool60000ATd72d==10]3COl:
@Tgk2TI=m`Y:COL:?@0000P0000K0000400006Y=003g2P00=P000100001ZC@00m`X005P0000d0000
00000000003oooooooooo`H0001_COL:LTgk2W==o`YcC@<;Kdd72f]=1`/f0000400006]=00072`00
F00003@00000000000000?oooooooooo1P0006I=1`]SC@@;Hdgo2V9=n`YVCOL:JTgg2Sd000080000
6`000100002:C@00m`X003H0000@0000RTd00?L:001H0000=000000000000000ooooooooool60000
Sdgg2Y9=nPZCCOl:Tdd32hm=1`^;C@L;=P000100002;C@001`/005P0000d000000000000003ooooo
ooooo`H00026C@L;Pdd42h==o`Z2CO/:QTgg2XY=m`Xm0000200001/0000@0000ZTd00?L:000f0000
40000:Y=003g2P00F00003@00000000000000?oooooooooo1P000:m=m`ZbCOX:/dgo2[==0`^_C@L;
Zdd72cH0000@0000Zdd000L;001H0000=000000000000000ooooooooool60000YTd72j==0`^SCOl:
XTgk2ZI=m`ZZCOL:?@0000P0000K000040000<Y=003g2P00=P000100003:C@00m`X005P0000d0000
00000000003oooooooooo`H0003?COL:ddgj2]==o`[CC@<;cdd72l]=1`/f000040000<]=00072`00
F00003@00000000000000?oooooooooo1P000<I=1`_3C@<;`dgo2/9=n`[6COL:bTgg2Sd000080000
6`000100003ZC@00m`X003H0000@0000jTd00?L:001H0000=000000000000000ooooooooool60000
kdgg2_==nP[cCOl:ldd32nm=1`_[C@L;=P000100003[C@001`/005P0000d000000000000003ooooo
ooooo`H0003VC@L;hdd32n==o`[SCOX:iTgg2^Y=m`Xm0000200001/0000@00002Th00?L:000f0000
400000Y>003g2P00F00003@00000000000000?oooooooooo1P0000m>m`XCC_X:4dko2Q=>0`/?CPL;
2dh72cH0000@00002dh000L;001H0000=000000000000000ooooooooool600001Th72`=>0`/3C_l:
0dkj2PI>m`X:C_L:?@0000P0000K0000400002Y>003g2P00=P000100000[CP00m`X005P0000d0000
00000000003oooooooooo`H0000_C_L:<dkj2S=>oPXcCP<;;dh72b]>1`/f0000400002]>00072`00
F00003@00000000000000?oooooooooo1P0002I>1`/SCP<;8dko2R=>nPXVC_L::Tkg2Sd000080000
6`000100001;CP00m`X003H0000@0000Bdh00?L:001H0000=000000000000000ooooooooool60000
Cdkf2U=>nPYCC_h:Ddh32dm>1P];CPL;=P000100001;CP001`/005P0000d000000000000003ooooo
ooooo`H00016CPL;@dh32d=>o`Y3C_X:ATkg2T]>m`Xm0000200001/0000@0000Jdh00?H:000f0000
400006]>003f2P00F00003@00000000000000?oooooooooo1P0006m>mPYcC_X:Ldkn2W=>0`]_CPH;
Jdh62cH0000@0000Jdh000H;001H0000=000000000000000ooooooooool60000ITh72f=>0`]SC_l:
Hdkj2VI>m`Y[C_H:?@0000P0000K0000400008]>003f2P00=P000100002;CP00mPX005P0000d0000
00000000003oooooooooo`H0002?C_H:Tdkj2Y=>oPZCCP<;Sdh62h]>1P/f0000400008]>00062`00
F00003@00000000000000?oooooooooo1P0008I>1P^3CP<;Pdko2X=>nPZ6C_H:Rdkf2Sd000080000
6`000100002[CP00mPX003H0000@0000Zdh00?H:001H0000=000000000000000ooooooooool60000
[dkf2[=>nPZcC_h:/dh32jm>1P^[CPH;=P000100002[CP001P/005P0000d000000000000003ooooo
ooooo`H0002VCPH;Xdh32j=>oPZSC_X:YTkf2Z]>mPXm0000200001/0000@0000bdh00?H:000f0000
40000<]>003f2P00F00003@00000000000000?oooooooooo1P000<m>mP[CC_X:ddkn2]=>0`_?CPH;
bdh62cH0000@0000bdh000H;001H0000=000000000000000ooooooooool60000aTh62l=>0`_3C_h:
`dkj2/I>mP[;C_H:?@0000P0000K000040000>]>003f2P00=P000100003[CP00mPX005P0000d0000
00000000003oooooooooo`H0003_C_H:ldkj2_=>oP[cCP8;kdh62n]>1P/f000040000>]>00062`00
F00003@00000000000000?oooooooooo1P000>I>1P_SCP<;hdkn2^=>nP[VC_H:jdkf2Sd000080000
6`000100000;C`00mPX003H0000@00002dl00?H:001H0000=000000000000000ooooooooool60000
3dof2Q=?nPXCCoh:4dl22`m?1P/;C`H;=P000100000;C`001P/005P0000d000000000000003ooooo
ooooo`H00006C`H;0dl32`=?oPX3CoX:1Tof2P]?mPXm0000200001/0000@0000:dl00?H:000f0000
400002]?003f2P00F00003@00000000000000?oooooooooo1P0002m?mPXcCoX:<don2S=?0P/_C`H;
:dl62cH0000@0000:dl000H;001H0000=000000000000000ooooooooool600009Tl62b=?0`/SCoh:
8doj2RI?mPX[CoH:?@0000P0000K0000400004]?003f2P00=P000100001;C`00mPX005P0000d0000
00000000003oooooooooo`H0001?CoH:Ddoi2U=?oPYCC`8;Cdl62d]?1P/f0000400004]?00062`00
F00003@00000000000000?oooooooooo1P0004I?1P]3C`<;@don2T=?nPY6CoH:Bdof2Sd000080000
6`000100001[C`00mPX003H0000@0000Jdl00?H:001H0000=000000000000000ooooooooool60000
Kdof2W=?n@YcCoh:Ldl22fm?1P][C`H;=P000100001[C`001P/005P0000d000000000000003ooooo
ooooo`H0001VC`H;Hdl22f=?oPYSCoX:ITof2V]?mPXm0000200001/0000@0000Rdl00?H:000f0000
400008]?003f2P00F00003@00000000000000?oooooooooo1P0008m?mPZCCoT:Tdon2Y=?0P^?C`H;
Rdl62cH0000@0000Rdl000H;001H0000=000000000000000ooooooooool60000QTl62h=?0P^3Coh:
Pdoj2XI?mPZ;CoH:?@0000P0000K000040000:]?003f2P00=P000100002[C`00mPX005P0000d0000
00000000003oooooooooo`H0002_CoH:/doi2[=?oPZcC`8;[dl62j]?1P/f000040000:]?00062`00
F00003@00000000000000?oooooooooo1P000:M?1P^SC`8;Xdon2Z=?n@ZVCoH:Zdof2Sd000080000
6`000100003;C`00mPX003H0000@0000bdl00?H:001H0000=000000000000000ooooooooool60000
cdof2]=?n@[CCoh:ddl22lm?1P_;C`H;=P000100003;C`001P/005P0000d000000000000003ooooo
ooooo`H00037C`H;`dl22l=?oP[3CoT:aTof2/]?mPXm0000200001/0000@0000jdl00?H:000f0000
40000>]?003f2P00F00003@00000000000000?oooooooooo1P000>m?mP[cCoT:ldon2_=?0P__C`H;
jdl62cH0000@0000jdl000H;001H0000=000000000000000ooooooooool60000idl62n=?0P_SCoh:
hdoi2^I?mP[[CoH:?@0000P0000K0000400000]@003f2P00=P000100000;D000mPX005P0000d0000
00000000003oooooooooo`H0000?D?D:4e3i2Q=@o@XCD08;3e052`]@1P/f0000400000]@00062`00
F00003@00000000000000?oooooooooo1P0000M@1P/3D08;0e3n2P=@n@X6D?H:2e3f2Sd000080000
6`000100000[D000m@X003H0000@0000:e000?D:001H0000=000000000000000ooooooooool60000
;e3e2S=@n@XcD?d:<e022bm@1@/[D0D;=P000100000[D0001@/005P0000d000000000000003ooooo
ooooo`H0000WD0H;8e022b=@oPXSD?T:9U3f2R]@m@Xm0000200001/0000@0000Be000?D:000f0000
400004]@003e2P00F00003@00000000000000?oooooooooo1P0004m@m@YCD?T:De3m2U=@0P]?D0D;
Be052cH0000@0000Be0000D;001H0000=000000000000000ooooooooool60000Ae052d=@0P]3D?h:
@e3i2TI@m@Y;D?D:?@0000P0000K0000400006]@003e2P00=P000100001[D000m@X005P0000d0000
00000000003oooooooooo`H0001_D?D:Le3i2W=@o@YcD08;Ke052f]@1@/f0000400006]@00052`00
F00003@00000000000000?oooooooooo1P0006M@1@]SD08;He3m2V=@n@YVD?D:Je3e2Sd000080000
6`000100002;D000m@X003H0000@0000Re000?D:001H0000=000000000000000ooooooooool60000
Se3e2Y=@n@ZCD?d:Te022hm@1@^;D0D;=P000100002;D0001@/005P0000d000000000000003ooooo
ooooo`H00027D0D;Pe022h=@o@Z3D?T:QU3e2X]@m@Xm0000200001/0000@0000Ze000?D:000f0000
40000:]@003e2P00F00003@00000000000000?oooooooooo1P000:m@m@ZcD?T:/e3m2[=@0@^_D0D;
Ze052cH0000@0000Ze0000D;001H0000=000000000000000ooooooooool60000Ye052j=@0P^SD?d:
Xe3i2ZI@m@Z[D?D:?@0000P0000K000040000<]@003e2P00=P000100003;D000m@X005P0000d0000
00000000003oooooooooo`H0003?D?D:de3i2]=@o@[CD04;ce052l]@1@/f000040000<]@00052`00
F00003@00000000000000?oooooooooo1P000<M@1@_3D08;`e3m2/=@n@[6D?D:be3e2Sd000080000
6`000100003[D000m@X003H0000@0000je000?D:001H0000=000000000000000ooooooooool60000
ke3e2_=@n@[cD?d:le012o1@1@_[D0D;=P000100003[D0001@/005P0000d000000000000003ooooo
ooooo`H0003WD0D;he022n=@o@[SD?T:iU3e2^]@m@Xm0000200001/0000@00002e400?D:000f0000
400000]A003e2P00F00003@00000000000000?oooooooooo1P0000mAm@XCDOP:4e7m2Q=A0@/@D@D;
2e452cH0000@00002e4000D;001H0000=000000000000000ooooooooool600001e452`=A0P/3DOd:
0e7i2PIAm@X;DOD:?@0000P0000K0000400002]A003e2P00=P000100000[D@00m@X005P0000d0000
00000000003oooooooooo`H0000_DOD:<e7h2S=Ao@XcD@4;<5452b]A1@/f0000400002]A00052`00
F00003@00000000000000?oooooooooo1P0002MA1@/SD@4;8e7m2R=An@XVDOD::e7e2Sd000080000
6`000100001;D@00m@X003H0000@0000Be400?D:001H0000=000000000000000ooooooooool60000
Ce7e2U=An0YCDOd:De412e1A1@];D@D;=P000100001;D@001@/005P0000d000000000000003ooooo
ooooo`H00017D@D;@e412d=Ao@Y3DOT:AU7e2T]Am@Xm0000200001/0000@0000Je400?D:000f0000
400006]A003e2P00F00003@00000000000000?oooooooooo1P0006mAm@YcDOP:Le7m2W=A0@]`D@D;
Je452cH0000@0000Je4000D;001H0000=000000000000000ooooooooool60000Ie452f=A0@]SDOd:
He7h2VIAm@Y[DOD:?@0000P0000K0000400008]A003e2P00=P000100002;D@00m@X005P0000d0000
00000000003oooooooooo`H0002?DOD:Te7h2Y=Ao@ZCD@4;T5452h]A1@/f0000400008]A00052`00
F00003@00000000000000?oooooooooo1P0008MA1@^3D@4;Pe7m2X=An0Z6DOD:Re7e2Sd000080000
6`000100002[D@00m@X003H0000@0000Ze400?D:001H0000=000000000000000ooooooooool60000
[e7e2[=An0ZcDOd:/e412k1A1@^[D@D;=P000100002[D@001@/005P0000d000000000000003ooooo
ooooo`H0002WD@D;Xe412j=Ao@ZSDOP:Ye7e2Z]Am@Xm0000200001/0000@0000be400?D:000f0000
40000<]A003e2P00F00003@00000000000000?oooooooooo1P000<mAm0[CDOP:de7l2]=A0@_@D@@;
be452cH0000@0000be4000D;001H0000=000000000000000ooooooooool60000ae452l=A0@_3DOd:
`e7h2/MAm@[;DOD:?@0000P0000K000040000>]A003d2P00=P000100003[D@00m0X005P0000d0000
00000000003oooooooooo`H0003_DO@:le7h2_=Ao0[cD@4;l5442n]A10/f000040000>]A00042`00
F00003@00000000000000?oooooooooo1P000>MA1@_SD@4;he7m2^=An0[WDOD:je7d2Sd000080000
6`000100000;DP00m0X003H0000@00002e800?@:001H0000=000000000000000ooooooooool60000
3e;d2Q=Bn0XCD_`:4e812a1B10/;DP@;=P000100000;DP0010/005P0000d000000000000003ooooo
ooooo`H00007DP@;0e812`=Bo@X3D_P:1e;d2P]Bm0Xm0000200001/0000@0000:e800?@:000f0000
400002]B003d2P00F00003@00000000000000?oooooooooo1P0002mBm0XcD_P:<e;l2S=B0@/`DP@;
:e842cH0000@0000:e8000@;001H0000=000000000000000ooooooooool600009e842b=B0@/SD_`:
8e;h2RMBm0X[D_@:?@0000P0000K0000400004]B003d2P00=P000100001;DP00m0X005P0000d0000
00000000003oooooooooo`H0001?D_@:De;h2U=Bo0YCDP4;D5842d]B10/f0000400004]B00042`00
F00003@00000000000000?oooooooooo1P0004MB10]3DP4;@e;l2T=Bn0Y7D_@:Be;d2Sd000080000
6`000100001[DP00m0X003H0000@0000Je800?@:001H0000=000000000000000ooooooooool60000
Ke;d2W=Bn0YcD_`:Le812g1B10][DP@;=P000100001[DP0010/005P0000d000000000000003ooooo
ooooo`H0001WDP@;He812f=Bo0YSD_P:Ie;d2V]Bm0Xm0000200001/0000@0000Re800?@:000f0000
400008]B003d2P00F00003@00000000000000?oooooooooo1P0008mBm0ZCD_P:Te;l2Y=B00^@DP@;
Re842cH0000@0000Re8000@;001H0000=000000000000000ooooooooool60000Qe842h=B0@^3D_`:
Pe;h2XMBm0Z;D_@:?@0000P0000K000040000:]B003d2P00=P000100002[DP00m0X005P0000d0000
00000000003oooooooooo`H0002_D_@:/e;h2[=Bo0ZcDP0;/5842j]B10/f000040000:]B00042`00
F00003@00000000000000?oooooooooo1P000:MB10^SDP4;Xe;l2Z=Bn0ZWD_@:Ze;d2Sd000080000
6`000100003;DP00m0X003H0000@0000be800?@:001H0000=000000000000000ooooooooool60000
ce;d2]=Bm`[CD_`:de802m1B10_;DP@;=P000100003;DP0010/005P0000d000000000000003ooooo
ooooo`H00037DP@;`e812l=Bo0[3D_P:ae;d2/]Bm0Xm0000200001/0000@0000je800?@:000f0000
40000>]B003d2P00F00003@00000000000000?oooooooooo1P000?1Bm0[cD_L:le;l2_=B00_`DP@;
je842cH0000@0000je8000@;001H0000=000000000000000ooooooooool60000ie842n=B00_SD_`:
he;h2^MBm0[[D_@:?@0000P0000K0000400000]C003d2P00=P000100000;D`00m0X005P0000d0000
00000000003oooooooooo`H0000@Do@:4e?g2Q=Co0XCD`0;45<42`]C10/f0000400000]C00042`00
F00003@00000000000000?oooooooooo1P0000MC10/3D`0;0e?l2P=Cn0X7Do@:2e?d2Sd000080000
6`000100000[D`00m0X003H0000@0000:e<00?@:001H0000=000000000000000ooooooooool60000
<5?d2S=Cm`XcDo`:<e<02c1C10/[D`@;=P000100000[D`0010/005P0000d000000000000003ooooo
ooooo`H0000WD`@;8e<02b=Co0XSDoL:9e?d2R]Cm0Xm0000200001/0000@0000Be<00?@:000f0000
400004]C003d2P00F00003@00000000000000?oooooooooo1P00051Cm0YCDoL:De?l2U=C00]@D`@;
Be<42cH0000@0000Be<000@;001H0000=000000000000000ooooooooool60000Ae<42d=C00]3Do`:
@e?g2TMCm0Y;Do@:?@0000P0000K0000400006]C003d2P00=P000100001[D`00m0X005P0000d0000
00000000003oooooooooo`H0001`Do@:Le?g2W=Co0YcD`0;L5<42f]C10/f0000400006]C00042`00
F00003@00000000000000?oooooooooo1P0006MC10]SD`0;He?l2V=Cm`YWDo@:Je?d2Sd000080000
6`000100002;D`00m0X003H0000@0000Re<00?@:001H0000=000000000000000ooooooooool60000
T5?d2Y=Cm`ZCDo/:Te<02i1C0`^;D`@;=P000100002;D`0010/005P0000d000000000000003ooooo
ooooo`H00027D`@;Pe<02h=Co0Z3DoL:Qe?d2X]Cm0Xm0000200001/0000@0000Ze<00?<:000f0000
40000:]C003c2P00F00003@00000000000000?oooooooooo1P000;1Cl`ZcDoL:/e?k2[=C00^`D`<;
Ze<32cH0000@0000Ze<000<;001H0000=000000000000000ooooooooool60000Ye<42j=C00^SDo`:
Xe?g2ZMCm0Z[Do<:?@0000P0000K000040000<]C003c2P00=P000100003;D`00l`X005P0000d0000
00000000003oooooooooo`H0003@Do<:de?g2]=Cn`[CD`0;d5<32l]C0`/f000040000<]C00032`00
F00003@00000000000000?oooooooooo1P000<MC0`_3D`0;`e?l2/=Cm`[7Do<:be?c2Sd000080000
6`000100003[D`00l`X003H0000@0000je<00?<:001H0000=000000000000000ooooooooool60000
l5?c2_=Cm`[cDo/:le<02o1C0`_[D`<;=P000100003[D`000`/005P0000d000000000000003ooooo
ooooo`H0003WD`<;he<02n=Cn`[SDoL:ie?c2^]Cl`Xm0000200001/0000@00002e@00?<:000f0000
400000]D003c2P00F00003@00000000000000?oooooooooo1P00011Dl`XCE?L:4eCk2Q=D00/@E0<;
2e@32cH0000@00002e@000<;001H0000=000000000000000ooooooooool600001e@32`=D00/3E?/:
0eCg2PMDl`X;E?<:?@0000P0000K0000400002]D003c2P00=P000100000[E000l`X005P0000d0000
00000000003oooooooooo`H0000`E?<:<eCg2S=Dn`XcE00;<5@32baD0`/f0000400002]D00032`00
F00003@00000000000000?oooooooooo1P0002MD0`/SE00;8eCk2R=Dm`XWE?<::eCc2Sd000080000
6`000100001;E000l`X003H0000@0000Be@00?<:001H0000=000000000000000ooooooooool60000
D5Cc2U=Dm`YCE?/:DeCo2U1D0`]<E0<;=P000100001<E0000`/005P0000d000000000000003ooooo
ooooo`H00017E0<;@e@02d=Dn`Y3E?L:AeCc2T]Dl`Xm0000200001/0000@0000Je@00?<:000f0000
400006]D003c2P00F00003@00000000000000?oooooooooo1P00071Dl`YcE?L:LeCk2W=Do`Y`E0<;
K5@32cH0000@0000K5@000<;001H0000=000000000000000ooooooooool60000Ie@32f=D00]SE?/:
HeCg2VMDl`Y[E?<:?@0000P0000K0000400008]D003c2P00=P000100002;E000l`X005P0000d0000
00000000003oooooooooo`H0002@E?<:TeCf2Y=Dn`ZDE?l:T5@32haD0`/f0000400008aD00032`00
F00003@00000000000000?oooooooooo1P0008MD0`^3E00;PeCk2X=Dm`Z7E?<:ReCc2Sd000080000
6`000100002[E000l`X003H0000@0000Ze@00?<:001H0000=000000000000000ooooooooool60000
/5Cc2[=DmPZcE?/:]5Co2[1D0`^/E0<;=P000100002/E0000`/005P0000d000000000000003ooooo
ooooo`H0002WE0<;Y5Co2Z=Dn`ZSE?L:YeCc2Z]Dl`Xm0000200001/0000@0000be@00?<:000f0000
40000<]D003c2P00F00003@00000000000000?oooooooooo1P000=1Dl`[CE?H:deCk2]ADo`[@E0<;
c5@32cH0000@0000c5@000<;001H0000=000000000000000ooooooooool60000ae@32lADo`[3E?/:
`eCg2/MDl`[;E?<:?@0000P0000K000040000>]D003c2P00=P000100003[E000l`X005P0000d0000
00000000003oooooooooo`H0003`E?<:leCf2_=Dn`[dE?l:l5@32naD0`/f000040000>aD00032`00
F00003@00000000000000?oooooooooo1P000>MD0`_TE?l:heCk2^=DmP[WE?<:jeCc2Sd000080000
6`000100000;E@00l`X003H0000@00002eD00?<:001H0000=000000000000000ooooooooool60000
45Gc2Q=EmPXDEO/:55Go2Q1E0`/<E@<;=P000100000<E@000`/005P0000d000000000000003ooooo
ooooo`H00007E@<;15Go2P=En`X3EOH:1eGc2P]El`Xm0000200001/0000@0000:eD00?<:000f0000
400002]E003c2P00F00003@00000000000000?oooooooooo1P00031El`XcEOH:=5Gk2SAEo`X`E@<;
;5D32cH0000@0000;5D000<;001H0000=000000000000000ooooooooool600009eD32bAEo`XTEO/:
8eGf2RMEl`X[EO<:?@0000P0000K0000400004]E003c2P00=P000100001;E@00l`X005P0000d0000
00000000003oooooooooo`H0001@EO<:DeGf2UAEnPYDEOl:D5D32daE0`/f0000400004aE00032`00
F00003@00000000000000?oooooooooo1P0004ME0`]4EOl:A5Gk2T=EmPY7EO<:BeGc2Sd000080000
6`000100001[E@00l`X003H0000@0000JeD00?<:001H0000=000000000000000ooooooooool60000
L5Gb2W=EmPYdEOX:M5Go2W1E0P]/E@<;=P000100001/E@000`/005P0000d000000000000003ooooo
ooooo`H0001WE@<;I5Go2VAEn`YSEOH:IeGc2V]El`Xm0000200001/0000@0000ReD00?8:000f0000
400008]E003b2P00F00003@00000000000000?oooooooooo1P00091ElPZDEOH:U5Gj2YAEo`Z@E@8;
S5D22cH0000@0000S5D0008;001H0000=000000000000000ooooooooool60000QeD32hAEo`Z4EO/:
PeGf2XMEl`Z;EO8:?@0000P0000K000040000:]E003b2P00=P000100002[E@00lPX005P0000d0000
00000000003oooooooooo`H0002`EO8:]5Gf2[AEnPZdEOl:/5D22jaE0P/f000040000:aE00022`00
F00003@00000000000000?oooooooooo1P000:ME0P^TEOl:Y5Gj2ZAEmPZWEO8:ZeGb2Sd000080000
6`000100003;E@00lPX003H0000@0000beD00?8:001H0000=000000000000000ooooooooool60000
d5Gb2]AEmP[DEOX:e5Go2]1E0P_<E@8;=P000100003<E@000P/005P0000d000000000000003ooooo
ooooo`H00037E@8;a5Go2/AEnP[4EOH:aeGb2/]ElPXm0000200001/0000@0000jeD00?8:000f0000
40000>aE003b2P00F00003@00000000000000?oooooooooo1P000?1ElP[dEOH:m5Gj2_AEo`[`E@8;
k5D22cH0000@0000k5D0008;001H0000=000000000000000ooooooooool60000ieD22nAEo`[TEOX:
i5Gf2^MElP[[EO8:?@0000P0000K0000400000aF003b2P00=P000100000<EP00lPX005P0000d0000
00000000003oooooooooo`H0000@E_8:55Kf2QAFnPXDE_h:45H22`aF0P/f0000400000aF00022`00
F00003@00000000000000?oooooooooo1P0000MF0P/4E_l:15Kj2PAFmPX7E_8:35Kb2Sd000080000
6`000100000/EP00lPX003H0000@0000;5H00?8:001H0000=000000000000000ooooooooool60000
<5Kb2SAFmPXdE_X:=5Kn2S1F0P//EP8;=P000100000/EP000P/005P0000d000000000000003ooooo
ooooo`H0000WEP8;95Ko2RAFnPXTE_H:9eKb2RaFlPXm0000200001/0000@0000C5H00?8:000f0000
400004aF003b2P00F00003@00000000000000?oooooooooo1P00051FlPYDE_D:E5Kj2UAFoPY@EP8;
C5H22cH0000@0000C5H0008;001H0000=000000000000000ooooooooool60000AeH22dAFo`Y4E_X:
A5Kf2TMFlPY<E_8:?@0000P0000K0000400006aF003b2P00=P000100001/EP00lPX005P0000d0000
00000000003oooooooooo`H0001`E_8:M5Ke2WAFnPYdE_h:L5H22faF0P/f0000400006aF00022`00
F00003@00000000000000?oooooooooo1P0006MF0P]TE_h:I5Kj2VAFmPYWE_8:K5Kb2Sd000080000
6`000100002<EP00lPX003H0000@0000S5H00?8:001H0000=000000000000000ooooooooool60000
T5Kb2YAFm@ZDE_X:U5Kn2Y1F0P^<EP8;=P000100002<EP000P/005P0000d000000000000003ooooo
ooooo`H00027EP8;Q5Kn2XAFnPZ4E_H:QeKb2XaFlPXm0000200001/0000@0000[5H00?8:000f0000
40000:aF003b2P00F00003@00000000000000?oooooooooo1P000;1FlPZdE_D:]5Kj2[AFoPZ`EP8;
[5H22cH0000@0000[5H0008;001H0000=000000000000000ooooooooool60000YeH22jAFoPZTE_X:
Y5Kf2ZMFlPZ/E_8:?@0000P0000K000040000<aF003b2P00=P000100003<EP00lPX005P0000d0000
00000000003oooooooooo`H0003@E_8:e5Ke2]AFnP[DE_h:d5H22laF0P/f000040000<aF00022`00
F00003@00000000000000?oooooooooo1P000<MF0P_4E_h:a5Kj2/AFm@[7E_8:c5Kb2Sd000080000
6`000100003/EP00lPX003H0000@0000k5H00?8:001H0000=000000000000000ooooooooool60000
l5Kb2_AFm@[dE_X:m5Kn2_1F0P_/EP8;=P000100003/EP000P/005P0000d000000000000003ooooo
ooooo`H0003WEP8;i5Kn2^AFnP[TE_D:ieKb2^aFlPXm0000200001/0000@000035L00?8:000f0000
400000aG003b2P00F00003@00000000000000?oooooooooo1P00011GlPXDEoD:55Oi2QAGoPX@E`8;
35L22cH0000@000035L0008;001H0000=000000000000000ooooooooool600001eL22`AGoPX4EoX:
15Oe2PMGlPX<Eo8:?@0000P0000K0000400002aG003b2P00=P000100000/E`00lPX005P0000d0000
00000000003oooooooooo`H0000`Eo4:=5Oe2SAGn@XdEoh:<5L12baG0P/f0000400002aG00022`00
F00003@00000000000000?oooooooooo1P0002MG0P/TEoh:95Oj2RAGm@XWEo8:;5Ob2Sd000080000
6`000100001<E`00l@X003H0000@0000C5L00?4:001H0000=000000000000000ooooooooool60000
D5Oa2UAGm@YDEoT:E5On2U1G0@]<E`4;=P000100001<E`000@/005P0000d000000000000003ooooo
ooooo`H00018E`8;A5On2TAGnPY4EoD:AeOb2TaGl@Xm0000200001/0000@0000K5L00?4:000f0000
400006aG003a2P00F00003@00000000000000?oooooooooo1P00071Gl@YdEoD:M5Oi2WAGoPY`E`4;
K5L12cH0000@0000K5L0004;001H0000=000000000000000ooooooooool60000J5L12fAGoPYTEoT:
I5Oe2VMGl@Y/Eo4:?@0000P0000K0000400008aG003a2P00=P000100002<E`00l@X005P0000d0000
00000000003oooooooooo`H0002@Eo4:U5Oe2YAGn@ZDEoh:T5L12haG0@/f0000400008aG00012`00
F00003@00000000000000?oooooooooo1P0008QG0@^4Eoh:Q5Oi2XAGm@Z7Eo4:S5Oa2Sd000080000
6`000100002/E`00l@X003H0000@0000[5L00?4:001H0000=000000000000000ooooooooool60000
/5Oa2[AGm@ZdEoT:]5On2[1G0@^/E`4;=P000100002/E`000@/005P0000d000000000000003ooooo
ooooo`H0002XE`4;Y5On2ZAGn@ZTEoD:YeOa2ZaGl@Xm0000200001/0000@0000c5L00?4:000f0000
40000<aG003a2P00F00003@00000000000000?oooooooooo1P000=1Gl@[DEoD:e5Oi2]AGo@[@E`4;
c5L12cH0000@0000c5L0004;001H0000=000000000000000ooooooooool60000b5L12lAGoP[4EoT:
a5Oe2/MGl@[<Eo4:?@0000P0000K000040000>aG003a2P00=P000100003/E`00l@X005P0000d0000
00000000003oooooooooo`H0003`Eo4:m5Oe2_AGn@[dEod:l5L12naG0@/f000040000>aG00012`00
F00003@00000000000000?oooooooooo1P000>QG0@_TEoh:i5Oi2^AGm@[WEo4:k5Oa2Sd000080000
6`000100000<F000l@X003H0000@000035P00?4:001H0000=000000000000000ooooooooool60000
45Sa2QAHm0XDF?T:55Sm2Q1H0@/<F04;=P000100000<F0000@/005P0000d000000000000003ooooo
ooooo`H00008F04;15Sn2PAHn@X4F?D:1eSa2PaHl@Xm0000200001/0000@0000;5P00?4:000f0000
400002aH003a2P00F00003@00000000000000?oooooooooo1P00031Hl@XdF?@:=5Si2SAHo@X`F04;
;5P12cH0000@0000;5P0004;001H0000=000000000000000ooooooooool60000:5P12bAHo@XTF?T:
95Se2RMHl@X/F?4:?@0000P0000K0000400004aH003a2P00=P000100001<F000l@X005P0000d0000
00000000003oooooooooo`H0001@F?4:E5Sd2UAHn@YDF?d:DEP12daH0@/f0000400004aH00012`00
F00003@00000000000000?oooooooooo1P0004QH0@]4F?d:A5Si2TAHm@Y7F?4:C5Sa2Sd000080000
6`000100001/F000l@X003H0000@0000K5P00?4:001H0000=000000000000000ooooooooool60000
L5Sa2WAHm0YdF?T:M5Sm2W5H0@]/F04;=P000100001/F0000@/005P0000d000000000000003ooooo
ooooo`H0001XF04;I5Sm2VAHn@YTF?D:IeSa2VaHl@Xm0000200001/0000@0000S5P00?4:000f0000
400008aH003a2P00F00003@00000000000000?oooooooooo1P00091Hl@ZDF?@:U5Si2YAHo@ZAF04;
S5P12cH0000@0000S5P0004;001H0000=000000000000000ooooooooool60000R5P12hAHo@Z4F?T:
Q5Sd2XMHl@Z<F?4:?@0000P0000K000040000:aH003a2P00=P000100002/F000l@X005P0000d0000
00000000003oooooooooo`H0002`F?4:]5Sd2[AHn@ZdF?d:/EP12jaH0@/f000040000:aH00012`00
F00003@00000000000000?oooooooooo1P000:QH0@^TF?d:Y5Si2ZAHm0ZWF?4:[5Sa2Sd000080000
6`000100003<F000l@X003H0000@0000c5P00?4:001H0000=000000000000000ooooooooool60000
d5Sa2]AHm0[DF?P:e5Sm2]5H0@_<F04;=P000100003<F0000@/005P0000d000000000000003ooooo
ooooo`H00038F04;a5Sm2/AHn@[4F?@:aeSa2/aHl@Xm0000200001/0000@0000k5P00?4:000f0000
40000>aH003a2P00F00003@00000000000000?oooooooooo1P000?1Hl0[dF?@:m5Sh2_AHo@[aF00;
k5P12cH0000@0000k5P0004;001H0000=000000000000000ooooooooool60000j5P12nAHo@[TF?T:
i5Sd2^QHl@[/F?4:?@0000P0000l0000200003l0000H0000c0<00:d0002A1@00/`0001<0000<0000
0@0002D0000<00000000P2D0000<00001`00P2@0000T00000020@@00000000000020@@0000000000
0P0002P0000<00001P000280000<0000ooooodH0000L0000400004E=AR/4@0003000000000160000
500000P00017A4U30`0004H0000X0000700004M4BD<20000;@D00>00000i1@005040000000160000
10400?P00015CDH[:T0002@0000H00000020?`00000000000020?`0000000000240Z0Y`0002@0000
0A30f`00001N400000000000P3l20000o`000080000000110P0005P000014<3K0000004000020000
EUEE@00000000000000000008440080o0000000000000000000001`000014<3K0`00001P00020?co
00000?koo?l00H400A30f`000000003o240[0b@0000H00000A30f`800000@000<`DC0C<5hP000@00
5D0[010000040000:P00024000080000HP0000`000010000900002@00000080m000000000000080m
0000000000020000G`0003P000060000>0000000000h00000000000B0@0@00000000000000000000
00000000000U0000300000H0000U0000300000L0000C000030000080000k0000200001/0000@0000
85<002PA000f00004000021C001>3P00F00003@00000000000000?oooooooooo1P00021CB@hTDdH>
:5=63ReCAPh`DdT><5=>3SH0000@0000<5<002PA001H0000=000000000000000ooooooooool60000
<5<]4BeC<14XDc0A95<`4B1C;A4PDbPA?@0000P0000K000040000>QB002H3P00F@0002@000000000
00000?oooooooooo0P0002QC60iXDiP>?@0000P0000l0000200003l0000H0000;@D00>00000h1@00
5@4001<0000<00000@0002D0000<00000000P2D0000<00001`00P2@0000T00000020@@0000000000
0020@@00000000000P0002P0000<00001P000280000<0000ooooodH0000L0000400004E=AR/4@000
3000000000160000500000P00017A4U30`0004H0000X0000700004M4BD<20000:`D00381000g1@00
F`4000000016000010400?P00015CDH[:T0002@0000H00000020?`00000000000020?`0000000000
240/0Y`0002@00000A30f`00001N400000000000P3l20000o`000080000000110P0005P000014<3K
0000004000020000EUEE@00000000000000000008440080o0000000000000000000001`000014<3K
0`00001P00020?co00000?koo?l00H400A30f`000000003o240]0b@0000H00000A30f`800000@000
<@EJ0C45=0400@005D0]010000040000;000024000080000HP0000`000010000900002@00000080m
000000000000080m0000000000020000G`0003P000060000>0000000000h00000000000B0@0@0000
000000000000000000000000000U0000300000H0000U0000300000L0000C000030000080000k0000
200001/0000@000005<009PE000f00004000001C001^4`00F00003@00000000000000?oooooooooo
1P00001CJA<4DfHC25=V4`eCIQ<@DfTC45=^4cH0000@000045<009PE001H0000=000000000000000
ooooooooool6000045>M5@eCX1D8Dj0E15>P5@1CWAD0DiPE?@0000P0000K000040000<QB002h4`00
F@0002@00000000000000?oooooooooo0P0000QC>1=8DkPC?@0000P0000l0000200003l0000H0000
:`D00381000f1@00G04001<0000<00000@0002D0000<00000000P2D0000<00001`00P2@0000T0000
0020@@00000000000020@@00000000000P0002P0000<00001P000280000<0000ooooodH0000L0000
400004E=AR/4@0003000000000160000500000P00017A4U30`0004H0000X0000700004M4BD<20000
m@@007H100011@00W@4000000016000010400?P00015CDH[:T0002@0000H00000020?`0000000000
0020?`0000000000240^0Y`0002@00000A30f`00001N400000000000P3l20000o`00008000000011
0P0005P000014<3K0000004000020000EUEE@00000000000000000008440080o0000000000000000
000001`000014<3K0`00001P00020?co00000?koo?l00H400A30f`000000003o240_0b@0000H0000
0A30f`800000@000n`BL0O/4N0400@005D0_010000040000;P00024000080000HP0000`000010000
900002@00000080m000000000000080m0000000000020000G`0003P000060000>0000000000h0000
0000000B0@0@0000000000000000000000000000000U0000300000H0000U0000300000L0000C0000
30000080000k0000200001/0000@0000X4l00;PI000f000040000:1?002^5`00F00003@000000000
00000?oooooooooo1P000:1?ZANTCjHGZ4nV5je?YQN`CjTG/4n^5cH0000@0000/4l00;PI001H0000
=000000000000000ooooooooool60000/4nm6Je?`1VXCl0IY4o06J1?_AVPCkPI?@0000P0000K0000
400006Q?003h5`00F@0002@00000000000000?oooooooooo0P000:Q?N1OXCoPG?@0000P0000l0000
200003l0000H0000m@@007H100001@00WP4001<0000<00000@0002D0000<00000000P2D0000<0000
1`00P2@0000T00000020@@00000000000020@@00000000000P0002P0000<00001P000280000<0000
ooooodH0000L0000400004E=AR/4@0003000000000160000500000P00017A4U30`0004H0000X0000
700004M4BD<20000:PD007H1000f1@00W@4000000016000010400?P00015CDH[:T0002@0000H0000
0020?`00000000000020?`0000000000240`0Y`0002@00000A30f`00001N400000000000P3l20000
o`000080000000110P0005P000014<3K0000004000020000EUEE@00000000000000000008440080o
0000000000000000000001`000014<3K0`00001P00020?co00000?koo?l00H400A30f`000000003o
240a0b@0000H00000A30f`800000@000<0FL0C05N0400@005D0a010000040000<000024000080000
HP0000`000010000900002@00000080m000000000000080m0000000000020000G`0003P000060000
>0000000000h00000000000B0@0@0000000000000000000000000000000U0000300000H0000U0000
300000L0000C000030000080000k0000200001/0000@0000l5800;PI000f000040000?1B002^5`00
F00003@00000000000000?oooooooooo1P000?1BZAOdDZHGn5:V5oeBYQL0DjTG05>^5cH0000@0000
05<00;PI001H0000=000000000000000ooooooooool6000005>m6OeB`1WhD/0Im5;06O1B_AW`D[PI
?@0000P0000K000040000;QB003h5`00F@0002@00000000000000?oooooooooo0P000?QBN1LhDoPG
?@0000P0000l0000200003l0000H0000:PD007H1000e1@00WP4001<0000<00000@0002D0000<0000
0000P2D0000<00001`00P2@0000T00000020@@00000000000020@@00000000000P0002P0000<0000
1P000280000<0000ooooodH0000L0000400004E=AR/4@0003000000000160000500000P00017A4U3
0`0004H0000X0000700004M4BD<20000H`D007H1001_1@00W@4000000016000010400?P00015CDH[
:T0002@0000H00000020?`00000000000020?`0000000000240b0Y`0002@00000A30f`00001N4000
00000000P3l20000o`000080000000110P0005P000014<3K0000004000020000EUEE@00000000000
000000008440080o0000000000000000000001`000014<3K0`00001P00020?co00000?koo?l00H40
0A30f`000000003o240c0b@0000H00000A30f`800000@000J@FL0FT5N0400@005D0c010000040000
<P00024000080000HP0000`000010000900002@00000080m000000000000080m0000000000020000
G`0003P000060000>0000000000h00000000000B0@0@0000000000000000000000000000000U0000
300000H0000U0000300000L0000C000030000080000k0000200001/0000@0000P5H00;PI000f0000
4000081F002^5`00F00003@00000000000000?oooooooooo1P00081FZAN4EZHGR5JV5heFYQN@EZTG
T5J^5cH0000@0000T5H00;PI001H0000=000000000000000ooooooooool60000T5Jm6HeF`1V8E/0I
Q5K06H1F_AV0E[PI?@0000P0000K0000400004QF003h5`00F@0002@00000000000000?oooooooooo
0P0008QFN1O8E_PG?@0000P0000l0000200003l0000H0000H`D007H1001^1@00WP4001<0000<0000
0@0002D0000<00000000P2D0000<00001`00P2@0000T00000020@@00000000000020@@0000000000
0P0002P0000<00001P000280000<0000ooooodH0000L0000400004E=AR/4@0003000000000160000
500000P00017A4U30`0004H0000X0000700004M4BD<200006`D008H0001T1@00TP00000000160000
10400?P00015CDH[:T0002@0000H00000020?`00000000000020?`0000000000240d0Y`0002@0000
0A30f`00001N400000000000P3l20000o`000080000000110P0005P000014<3K0000004000020000
EUEE@00000000000000000008440080o0000000000000000000001`000014<3K0`00001P00020?co
00000?koo?l00H400A30f`000000003o240e0b@0000H00000A30f`800000@00070F<0685S0000@00
5D0e010000040000=000024000080000HP0000`000010000900002@00000080m000000000000080m
0000000000020000G`0003P000060000>0000000000h00000000000B0@0@00000000000000000000
00000000000U0000300000H0000U0000300000L0000C000030000080000k0000200001/0000@0000
^5400;08000f000040000>=E002`2000F00003@00000000000000?oooooooooo1P000>QE/0S[EK@8
jeFh2>]E_@SXEL08heG023H0000@0000^5400<08001H0000=000000000000000ooooooooool60000
]5702;1A_@R`DKP8/56d2;AA/0RhDK08?@0000P0000K0000400009QE001h2000F@0002@000000000
00000?oooooooooo0P0001QF^0RHEOP8?@0000P0000l0000200003l0000H00006@D008H0001S1@00
T@0001<0000<00000@0002D0000<00000000P2D0000<00001`00P2@0000T00000020@@0000000000
0020@@00000000000P0002P0000<00001P000280000<0000ooooodH0000L0000400004E=AR/4@000
3000000000160000500000P00017A4U30`0004H0000X0000700004M4BD<20000a@@007L0003W1000
UP00000000160000/0000:@00015CDH[:T0002@0000H00000020?`00000000000020?`0000000000
240f0f`0001P00000A30f`T0000000000:2LA06g34=EEI]4ZVd4@eEEVdAFTPQ3Z`ZJA5JB24>[2YY4
003`@P30V4@00?120<2HA5GK44=EEI]4EM/@@eEEVd@001E300410@410@610000540fP10000040000
ooooobP0000<00001`00024000080000HP0000`000010000900002@00000080m000000000000080m
00000000000200009`0001P00007000000000?ooo`0000009@0000`0000700004`0000`000010000
9@0000`000080020EP00040000351000M`000>D4002E00002@0004Q>a0RSCCl8Xdf22?i<PPSnC7P7
F4ah1eQ<1PVSC@H9Xde82BD0000<00001`00P1<0000<00000@0002D0000<00000000P2@0000T0000
0020@@00000000000020@@00000000000P0004H0001P0000E00004E=AR/8@3L2@00003@000014<3K
000005h0000000000020?`80000200000P000000044200000A30f`000000003o5D0f010000040000
=`0002@0000T00000020?@00000000000020?@00000000000P0005l0000h00001P0003P000000000
>000000000000040400000000000000000000000000000009@0000`0000600009@0000`000050020
EP00040000341000MP000>H4002F00002@0004Q>a0RSCCl8Xdf22?i<PPSnC7P7F4ah1eQ<1PVSC@H9
Xde82BD0000<00001`00P2D0000<00000000P2@0000T00000020@@00000000000020@@0000000000
0P0002P0000<00001P000280000<0000ooooodH0000L0000400004E=AR/4@0003000000000160000
500000P00017A4U30`0004H0000X0000700004M4BD<20000/`@007L0003>1000/000000000160000
W00009000015CDH[:T0002@0000H00000020?`00000000000020?`0000000000240h0eP0001<0000
0A30f`L0000000000:2FA0108D<0F9M4040Q@`1HUd@00?120<RHA000l480b9Q4040Q@`20VD@0@253
012HA000;d<00@410@6101A0>80@000010000?oooolQ000020000680000<00000@0002@0000T0000
0020?@00000000000020?@00000000000P0002D0000<00001`0001<0000<00000@0002D0000<0000
2000P5H0000h0000]0@007L0003<1000[`0000L00018B``:Y4/<2ZA;N0MLC7P7G4`<2[Q<30X0C>P:
9@0000`0000700204`0000`0000100009@0000`000000020900002@0000008110000000000000811
0000000000020000AP000600001D0000ADe6:`Q0>@900000=000004@`=/00000GP0000000000080o
0P000080000200000000@@8000014<3K000000000?lE@3P0400000@0000i0000900002@00000080m
000000000000080m0000000000020000G`0003P000060000>0000000000h0000000000000@0@0000
000000000000000000000000000U0000300000H0000U0000300000D0081F0000>0000;<4001f0000
c@@00;0000070000B4/<2ZA;30ZTBgP7G4ah1ea<30ZhC0`:04cX2RD0000<00001`00P2D0000<0000
0000P2@0000T00000020@@00000000000020@@00000000000P0002P0000<00001P000280000<0000
ooooodH0000L0000400004E=AR/4@0003000000000160000500000P00017A4U30`0004H0000X0000
700004M4BD<20000Q0D00=4000321@001P80000000160000304000010015CDH[:T0002@0000H0000
0020?`00000000000020?`0000000000240j0Y`0002@00000A30f`00001N400000000000P3l20000
o`000080000000110P0005P000014<3K0000004000020000EUEE@00000000000000000008440080o
0000000000000000000001`000014<3K0`00001P00020?co00000?koo?l00H400A30f`000000003o
240k0b`0000P00000A30f`@00000@000Q`GB0<45dP311@02QPD00P010@4E@3/0400000@0000j0000
:00000`0000700008@0000P0001R000030000040000T000090000000P3d0000000000000P3d00000
00000080001O0000>00000L0000h0000000003P00000000001810100000000000000000000000000
000002D0000<00001`0002L0000H00001P00000000000000000002D0000<00001P0001<0000<0000
0P0003/0000800006`000100001XF00040d003H0000@000025`0010=001H0000:000000000000000
ooooooooool300003E`@3A1L50d@G1P==P000100000@G000n1l005P0000X000000000000003ooooo
ooooo`<0000@G?dO3E`080QL020f0000400008iH00008000F00003@00000000000000?oooooooooo
1P0008UH0226F?dOQUSh7hIHm1n9F?0OSUS`7eT0000`000000000000003oooooooooo`D00008G?0O
05ch7`1L60d8G20=J5PP3EP0000d000000000000003oooooooooo`H0001TF20=H5PM3F1H60ePF1@=
I5P@3FQH40dm0000200001/0000@0000f5P003PP001I00009000000000000000ooooooooool20000
F5Sh7mQH^1lm0000200003`000080000?`0001P000241@00c`000<<500050P004`0000`000010000
9@0000`0000000209@0000`000070020900002@00000081100000000000008110000000000020000
:00000`0000700008P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000000004H0000D0000
200004M4BD<30000AP0002P0000L0000AdA9@`8000061000k`4005/4000A0P00000004H0001@0000
A00004E=AR/Z@000900001P00000080o000000000000080o00000000000:@030700001000030`<3o
0@0000L4l05C0200:00000`0000600008@0000P0001R000030000040000T000090000000P3d00000
00000000P3d0000000000080000W0000600000H000000000`<300000000U0000300000H0000U0000
300000P0081<0000I00000L4003`0@00F@@000l2001X@000n1h0030500000P008@3`000000000000
0020?`00000000000020?`0000000000000000000000000000000000000000009@0000`000070020
9@0000`000000020900002@00000081100000000000008110000000000020000AP0008P0001l0000
ADe6:`Q0?08l0000<000004@`=/00000EP0000000000080o0P000080000000110P00004@`=/00000
0000o`Q0?@</00008000004@`=/40000040000L4l0471102FP@@0UX4l0400@615D0m010000040000
?00003X0000<0000200002@0000T00000020?@00000000000020?@00000000000P0005l0000h0000
1`0003P000000000>000000000008040400000000000000000000000000000009@0000`000070000
9@0000`000050020EP0002`0003j0`00h`4006H4000L0P00100006Q0n1iX@?PPV4Gh89Q5n1hU0000
300000L0080U000030000000080T000090000000P440000000000000P440000000000080000X0000
300000L0000j0000300000X0000R000030000?oooom60000700001000015CDH[140000`000000000
AP0001@000080000AdA9@`<0000Q0000200001h0000H00002P@00?41001H1000408002D0000<0000
100002D0000<00003@00P2D0000<0000100001@0000<00003@000180000<00000@0005@0002D0000
3P@00?P1001G10001`80004000000212000P@Ph4003h0@00300004`00000000000000000003ooooo
ooooof@0001206l0I01i0200IP1/07D0J@1T07<080090000200000P000070000100000@000040000
200000@0000800001P0000@0000U0000300000d0080R000030000?oooolQ0000200001T0000<0000
oooo01P0000<0000000001h0000H00006P000140003b0P00P@400280000<0000oooooaP0000<0000
000001T0000<0000oooo02D0000<00000000P2D0000<00003@00P4H0000X0000700004M4BD<20000
/@@005d0003L1000N000000000160000D00004@00015CDH[:T0002@0000H00000020?`0000000000
0020?`00000000002T00`1`0000@0000ooooo`40002b15h0:@0I02P0000<00001P00024000080000
HP0000`000010000900002@00000080m000000000000080m00000000000200009`0001P000060000
00000?ooo`0000009@0000`0000600009@0000`000080020C00006@0002b1000GP000=X4001f0000
64/00=P5002@0P00T0400240l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000002D0000<00001`00P2D0000<00000000P2@0000T00000020@@0000000000
0020@@00000000000P0004H000280000O00004E=AR/8@3h2?000030000014<3K000005H000000000
0020?`80000200000000@@8000014<3K00000?ooool8@3l3;000020000014<3K10000010002b15h0
/PAg0=/4M`3K15h00041PAE0?`0@0000100003h0000j0000300000P0000T000090000000P3d00000
00000000P3d0000000000080001O0000>00000L0000h0000000003P0000000000201010000000000
oooo000000000000000002D0000<00001`0002D0000<00001@00P5H0000/0000Y@@00540003W1000
P`0000@0000HBmP564]X1jQ=J0NXCMP59@0000`0000700209@0000`000000020900002@000000811
00000000000008110000000000020000:00000`000070000>P0000`0000:00008P0000`0003ooooo
AP0001`0000@0000ADe6:`A0000<0000000004H0000D0000200004M4BD<300008@0000P0000N0000
60000;H4001O0000f0@007L0001B0000L04000L0003`oooo0000000000000000_08000000000000P
@@1b06T0H@1/00000000000000000000000000000000000000000000000000000000000000000000
000000000S0:10000@0009R24`1h0000000001R34`3TPa<0N0000800002HPQ<0000001B34`010000
000005T^/30?0000S:3@0AR34`3CZ`0`5:3@0DR34`0<0000Z>O@0DB<4`0P000000000@00001D0640
J01_06d0H@000000000EFncB5e^8dY/0h84C055?5E_@di/07=:K05CBV`3hdI/0;00007X0000/0`00
V00000B24`10?aEK`=FK00005E]0eY/0P8@C0?SAV`000000000100400P3I?/AgNDo4Mb/:2X]L0000
B88C01BPd04/PQ<06oL0<2/:2X]TMP08000002D0000<00001`000580001`0@0020000?3oool00000
00000000002@0@000000000002110780J@1Q06`00000000000000000000000000000000000000000
000000000000000000000000000000000002<0X400010000V88C07P00000000068<C0>B34`1h0000
P0000>X7000<93@a58<C004000000000FBj`<0l00030fm0168<C0=>[0318fm01B8<C00`0000<nM01
A8`C02@000000001000005@0H@1X06l0K@1Q0000000001EKk=8GFhSBV`3PPA<0DDlEFm3CV`0LdY/0
E=:K0?SAV`0/0000NP0002`3002H0000188C040o5E_0eI/0000EFd3FV`20Q1<0n=6K000000000040
0@020=Tna7MiClAg:`X:Se`00018PQ<0B=_@0Bb24`0Km`0`:`X:SfAf00P000009@0000`000080000
DP00070100090000l?ooo`0000000000000009010001000000008440LP1Y0640K000000000000000
000000000000000000000000000000000000000000000000000000000000008`2P@00040002HPQ<0
N0000000000HPa<0i8<C07P000200000V88C0000000DPa<00@000000001I;[0`40000=0:h@4HPa<0
dj/0<5P:h@58Pa<03000053Qh@54S1<09@00000000400000E01Q06P0K`1]0640000000005E_/dQMK
R=:K0>214`1ACaEKd=>K01cBV`1DdY/0n=6K02`0001j0000;0<009P00004PQ<0@3lEFl3EV`0001EK
@=JK08244`3hdI/0000000000@010080fCk4MgU?a7L[2PZ@G00004R24`1H2^41;88C01_g030[2PZ@
I7H02000000U0000300000T0000U0000300000P0000U0000300000L0000U0000300000d0080U0000
300000P0000U0000300000L0000D0000300000d0000B000030000040001D0000E0000;H4001P0000
_`@0078000010000000P@P0084:f1000H0000040001<00000000000000000000oooooooooom@0000
HP0000X0000U0000300000P0001D0000E0000<04001P0000a0@0074000010000000P@P0084;01000
H0000040001<00000000000000000000oooooooooom@0000:00000D0000U0000300000T0001D0000
E0000<D4001O0000b0@0074000010000000P@P0084;51000G`000040001<00000000000000000000
oooooooooom@0000M00000@0000U0000300000P0001D0000E0000<`4001P0000d0@0074000010000
000P@P0084;<1000H0000040001<00000000000000000000oooooooooom@0000:@0000D0000U0000
300000d0080R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H0000
6P000140003b0P00P@400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000
0000P2D0000<00003@00P4H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`8000301000
b@400=D4000l0P00000004H0002L0000T00004E=AR/Z@000900001P00000080o000000000000080o
000000000008@003F00004`000014<3K1`0000000000@9Q40;07A038V4@0/0M40<RHA000iD<0f9U4
003U@`3HVD@0/0M4062JA02`1d@0D9U40<0>A0010@410H405400P10000040000ooooob4000080000
HP0000`000010000900002@00000080m000000000000080m00000000000200009@0000`000060000
4`0000`0000100009@0000`000080020EP0003P000311000b@400=<4000k0P001`0001Q<i25LC>@Q
G4bH7>A<V1cTC>@Q:4gT8J1<Z2<U0000300000L0080C000030000040000U000030000000080T0000
90000000P440000000000000P44000000000008000160000K00006000015CDH[24010T`000100000
0A30f`00001N0@0000000000P3l200000P000080000000110P000080000008100010@04@`=/00000
0000oaE0000@000010000040000X0000300000H0000T000090000000P3d0000000000000P3d00000
00000080001O0000>00000H0000h0000000003P00000000001810100000000000000000000000000
000002D0000<00001P0002L0000H00002P00000000000000000002D0000<00002P0001<0000<0000
0P0003/0000800006`000100002DC000Vb<003H0000@0000QT`006dS001H0000=000000000000000
ooooooooool60000QDaY8hM<IB><C6@ST4aR8iA<IB>FC6TS=P000100002TC000Ub<005P0000d0000
00000000003oooooooooo`H0002UC9/SXTbP8ii<XB>JC:8SUDbP8iA<Vb<m0000200001/0000@0000
M4`0030S000f0000400006I<00028`00F00003@00000000000000?oooooooooo1P0006E<oR9WC?XR
Jdch8W1<mb9dC?TRMDcn8SH0000@0000Pd`002`S001H0000=000000000000000ooooooooool60000
QD``8h9<=2=nC3HSNT`g8gE<=2=dC30S?@0000P0000K0000400005A<00358P00=P0001000016C000
Ub8005P0000d000000000000003oooooooooo`H00015C9<RAdb>8T]<SB9?C8`RE4b>8UE<TR8f0000
400006=<00308P00F00003@00000000000000?oooooooooo1P0006A<aB9RC<TRGTc:8UU<c29EC<TR
E4c58Sd0000800006`000100000cC000FR8003H0000@00009T`002`R001H0000=000000000000000
ooooooooool6000094`X8RM<8b8[C28R;d`P8SA<8b8eC2LR=P0001000013C000EB8005P0000d0000
00000000003oooooooooo`H00014C5TR@TaN8Se<Gb8iC60R=DaN8S=<FR8m0000200001/0000@0000
4d`00>hQ000f00004000015<003W8@00F00003@00000000000000?oooooooooo1P00011<i24AC>8Q
4TcP8AA<gR4FC=`Q64cL8CH0000@0000@4`00=`Q001H0000=000000000000000ooooooooool60000
ADcL8DQ<h258C>@QB4cY8DE<k250C>`QF@0002P00000000000000?oooooooooo0`0001Q<k24PC>8Q
8TcZ8EP0000d000000000000003oooooooooo`H0000TC>hQ8Dcc8Ae<m24IC?DQ54cc8A=<kR4m0000
200001/0000@0000E4`00<0Q000f0000400005A<002@8@00F00003@00000000000000?oooooooooo
1P0005A<S25HC8PQG4b88F5<R25TC8`QI4b@8CH0000@0000I4`00<0Q001H0000=000000000000000
ooooooooool60000I4c58F5<b25LC<PQF4c88EA<aB5DC<0Q?@0000P0000K0000400005A<001@8@00
=P000100001DC000824005P0000d000000000000003oooooooooo`H0001DC1`QF4`H8Ea<625QC1PQ
I4`L8FA<824f0000400006A<001@8@00F00003@00000000000000?oooooooooo1P0006A<EB5QC5PQ
G4aH8EQ<F25DC5DQE4a@8Cd0000800006`000100001DC000h20003H0000@0000E4`00;0P001H0000
=000000000000000ooooooooool60000E4b/85Q<Z21LC:PPHDbX86A<[21TC;0P=P000100001TC000
h20005P0000d000000000000003oooooooooo`H0001TC>DPHDcX85a<j21HC>PPE4cU85A<h20m0000
200001/0000@0000E4`0070P000f0000400005A<00108000F00003@00000000000000?oooooooooo
1P0005A<?21HC3PPG4`h865<>21TC3`PI4a083H0000@0000I4`0070P001H0000=000000000000000
ooooooooool60000I4ae865<N21LC7PPF4ah85A<MB1DC70P?@0000P0000K0000400005A<00008000
=P000100001DC000d1l005P0000d000000000000003oooooooooo`H0001DC<`OF4c87ea<b1mQC<PO
I4c<7fA<d1lf0000400006A<00008000F00003@00000000000000?oooooooooo1P0006A<1B1QC0PP
G4`885Q<221DC0DPE4`083d0000800006`000100001DC000T1l003H0000@0000E4`0060O001H0000
=000000000000000ooooooooool60000E4aL7eQ<F1mLC5POHDaH7fA<G1mTC60O=P000100001TC000
T1l005P0000d000000000000003oooooooooo`H0001TC9DOHDbH7ea<V1mHC9POE4bE7eA<T1lm0000
200001/0000@0000E4`0020O000f0000400005A<003`7P00F00003@00000000000000?oooooooooo
1P0005A<k1iHC>PNG4cX7V5<j1iTC>`NI4c`7SH0000@0000I4`0020O001H0000=000000000000000
ooooooooool60000I4`U7f5<:1mLC2POF4`X7eA<9AmDC20O?@0000P0000K0000400005A<002`7P00
=P000100001DC000P1h005P0000d000000000000003oooooooooo`H0001DC7`NF4ah7Ua<N1iQC7PN
I4al7VA<P1hf0000400006A<002`7P00F00003@00000000000000?oooooooooo1P0006A<]AiQC;PN
G4bh7UQ<^1iDC;DNE4b`7Sd0000800006`000100001DC000@1h003H0000@0000E4`0010N001H0000
=000000000000000ooooooooool60000E4`<7UQ<21iLC0PNHD`87VA<31iTC10N=P000100001TC000
@1h005P0000d000000000000003oooooooooo`H0001TC4DNHDa87Ua<B1iHC4PNE4a57UA<@1hm0000
200001/0000@0000E4`00=0M000f0000400005A<002P7@00F00003@00000000000000?oooooooooo
1P0005A<W1eHC9PMG4bH7F5<V1eTC9`MI4bP7CH0000@0000I4`00=0M001H0000=000000000000000
ooooooooool60000I4cE7F5<f1eLC=PMF4cH7EA<eAeDC=0M?@0000P0000K0000400005A<001P7@00
=P000100001DC000<1d005P0000d000000000000003oooooooooo`H0001DC2`MF4`X7Ea<:1eQC2PM
I4`/7FA<<1df0000400006A<001P7@00F00003@00000000000000?oooooooooo1P0006A<IAeQC6PM
G4aX7EQ<J1eDC6DME4aP7Cd0000800006`000100001DC000l1`003H0000@0000E4`00<0L001H0000
=000000000000000ooooooooool60000E4bl75Q<^1aLC;PLHDbh76A<_1aTC<0L=P000100001TC000
l1`005P0000d000000000000003oooooooooo`H0001TC?DLHDch75a<n1aHC?PLE4ce75A<l1`m0000
200001/0000@0000M4`0090L000f000040000:A<002@7000F00003@00000000000000?oooooooooo
1P000:U<T1b/C9@L[4bH7:a<WAbYC:0LY4bP73H0000@0000M4`00:0L001H0000=000000000000000
ooooooooool60000L4bP76a<WAa/C9PLK4bD771<T1adC90L?@0000P0000K000040000>A<002@7000
=P000100003TC000T1`005P0000X000000000000003oooooooooo`<0003YC90Lk4bD7>a<V1`f0000
40000>a<00387000F00003@00000000000000?oooooooooo1P000>a<cAcYC=0Li4c@7>1<d1cLC<dL
g4c875T0000X000000000000003oooooooooo`<0003LC9PLi4bP7>A<X1aH0000=000000000000000
ooooooooool60000h4bP7=a<WAcLC9PLg4bD7>1<T1cTC90L?@0000P0000K000040000>a<00087@00
=P000100003/C000>1d005P0000d000000000000003oooooooooo`H0003/C3dMjDa07NA<@1gPC40M
g4`m7Ma<>1df000040000=a<00087@00F00003@00000000000000?oooooooooo1P000=a<11gPC00M
i4`07NU<01g/C0@Mk4`87Cd0000800006`000100003/C000N1d003H0000@0000k4`00:PM001H0000
=000000000000000ooooooooool60000k4b]7NU</1gTC;0Mh4b`7Ma<[AgLC:PM=P000100003LC000
N1d005P0000d000000000000003oooooooooo`H0003LC7@Mh4a`7NA<L1gYC70Mk4ad7Na<N1dm0000
200001/0000@0000k4`00>PM000f000040000>a<000H7P00F00003@00000000000000?oooooooooo
1P000>a<7AkYC20Ni4`P7^1<81kLC1dNg4`H7SH0000@0000g4`00>PM001H0000=000000000000000
ooooooooool60000g4cT7N1<h1gTC>0MjDcP7Na<i1g/C>PM?@0000P0000K000040000>a<001H7P00
=P000100003/C000R1h005P0000d000000000000003oooooooooo`H0003/C8dNjDb@7^A<T1kPC90N
g4b=7]a<R1hf000040000=a<001H7P00F00003@00000000000000?oooooooooo1P000=a<E1kPC50N
i4a@7^U<D1k/C5@Nk4aH7Sd0000800006`000100003/C000b1h003H0000@0000k4`00?PN001H0000
=000000000000000ooooooooool60000k4cm7^U<01oTC00Oh4`07ma<oAkLC?PN=P000100003LC000
b1h005P0000d000000000000003oooooooooo`H0003LC<@Nh4c07^A<`1kYC<0Nk4c47^a<b1hm0000
200001/0000@0000k4`003PO000f000040000>a<001X7`00F00003@00000000000000?oooooooooo
1P000>a<KAoYC70Oi4a`7n1<L1oLC6dOg4aX7cH0000@0000g4`003PO001H0000=000000000000000
ooooooooool60000g4`d7n1<<1oTC30OjD``7na<=1o/C3PO?@0000P0000K000040000>a<002X7`00
=P000100003/C000f1l005P0000d000000000000003oooooooooo`H0003/C=dOjDcP7nA<h1oPC>0O
g4cM7ma<f1lf000040000=a<002X7`00F00003@00000000000000?oooooooooo1P000=a<Y1oPC:0O
i4bP7nU<X1o/C:@Ok4bX7cd0000800006`000100003/C000620003H0000@0000k4`004PP001H0000
=000000000000000ooooooooool60000k4a=8>U<D23TC50Ph4a@8=a<CB3LC4PP=P000100003LC000
620005P0000d000000000000003oooooooooo`H0003LC1@Ph4`@8>A<423YC10Pk4`D8>a<620m0000
200001/0000@0000k4`008PP000f000040000>a<002h8000F00003@00000000000000?oooooooooo
1P000>a<_B3YC<0Pi4c08>1<`23LC;dPg4bh83H0000@0000g4`008PP001H0000=000000000000000
ooooooooool60000g4b48>1<P23TC80PjDb08>a<Q23/C8PP?@0000P0000K000040000>a<003h8000
=P000100003/C000:24005P0000d000000000000003oooooooooo`H0003/C2dQjD``8NA<<27PC30Q
g4`]8Ma<:24f000040000=a<003h8000F00003@00000000000000?oooooooooo1P000=a<m23PC?0P
i4c`8>U<l23/C?@Pk4ch83d0000800006`000100003/C000J24003H0000@0000k4`009PQ001H0000
=000000000000000ooooooooool60000k4bM8NU<X27TC:0Qh4bP8Ma<WB7LC9PQ=P000100003LC000
J24005P0000d000000000000003oooooooooo`H0003LC6@Qh4aP8NA<H27YC60Qk4aT8Na<J24m0000
200001/0000@0000k4`00=PQ001I0000:000000000000000ooooooooool30000k4cT8NA<g248CM`Q
F00003@00000000000000?oooooooooo1P0000e=g24@CN0Q44gT8A1=jB4=CN`Q24g/8CH0000@0000
i4`00>`Q001H0000:000000000000000ooooooooool30000h4c/8Ma<jB7LC>@Q=P000100003LC000
f24005P0000d000000000000003oooooooooo`H0003LC=@Qh4c@8NA<d27YC=0Qk4cD8Na<f24m0000
200001/0000@00009dd000DR000f0000400001U=000c8P00F00003@00000000000000?oooooooooo
1P0001Q=>28CCCXR3ddi8P]==b88CC<R2Td_8SH0000@000064d0004R001H0000=000000000000000
ooooooooool600006Dgm8Ae=nR4RCO/Q9Tgm8BQ=0B8WC@DR?@0000P0000K0000400000M=001a8P00
=P000100003iC000Wb8005P0000d000000000000003oooooooooo`H0003hC:<RldbU8^m<Y2;[C:<R
j4bN8^U<VR8f000040000?M<001/8P00F00003@00000000000000?oooooooooo1P000?U<J2;mC6DR
0DeW8PI=J288CF`R1dea8Sd0000800006`000100003VC000g28003H0000@0000fD`000XS001H0000
=000000000000000ooooooooool60000ed`>8m=<42??C0lSbT`>8lQ<2B?9C0DS=P000100003GC000
eb8005P0000d000000000000003oooooooooo`H0003HC=<RgDcA8^5<dR;UC=<Rj4cH8^I<g28m0000
200001/0000@0000aT`004LS000f000040000;Q<001e8`00F00003@00000000000000?oooooooooo
1P000;M<NB>cC7`S[Taj8jY<NB>XC7DSZDaa8cH0000@0000]d`004<S001H0000=000000000000000
ooooooooool60000^4`n8ke<?2?1C3dSaD`n8lM<@b?6C4LS?@0000P0000l0000200003l0000H0000
_`@00<L1003D1000?08001<0000<00000@0002D0000<00000000P2D0000<00001`00P2@0000T0000
0020@@00000000000020@@00000000000P0002P0000<00001P000280000<0000ooooodH0000L0000
400004E=AR/4@0003000000000160000500000P00017A4U30`0004H0000X0000700004M4BD<20000
k`<003/2002[1@00G@80000000160000D00004@00015CDH[:T0002@0000H00000020?`0000000000
0020?`00000000002T00`1`0000@0000ooooo`40003`0c`2^P4P02P0000<00002P00024000080000
HP0000`000010000900002@00000080m000000000000080m00000000000200009`0001P0000:0000
00000?ooo`0000009@0000`0000:00009@0000`000080020C00006@0003`0`00?0800:T5001K0P00
n3h00;PS002P6`0000800240l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000002D0000<00001`00P2D0000<00000000P2@0000T00000020@@0000000000
0020@@00000000000P0004H000280000O00004E=AR/8@082?000030000014<3K000005H000000000
0020?`80000200000000@@8000014<3K000000000?l8@0<3;000020000014<3K10000010003`0c`2
l0=L0ZX5G0:Z1C`20041PAE00`0@000010000080000j0000300000P0000T000090000000P3d00000
00000000P3d0000000000080001O0000>00000H0000h0000000003P0000000000201010000000000
0000000000000000000002D0000<00001P0002D0000<00001@00P5H0000/0000h`<002l2002f1@00
J08000@0003h?[PSn3jh9IQJ^2FHF[PS9@0000`0000700209@0000`000000020900002@000000811
00000000000008110000000000020000:00000`000060000>P0000`0000:00008P0000`0003ooooo
AP0001`0000@0000ADe6:`A0000<0000000004H0000D0000200004M4BD<300008@0000P0000N0000
60000?@3000m0P00Y`D005`2000U0000300000<0000U0000300000d0080U0000300000<0000D0000
300000d0000B000030000040001D0000H0000;X4000n0P00g`@005<200010000000P@P0084:j1000
?P8000<0001<00000000000000000000oooooooooomD0000D01D04D0000=0000300000d0000U0000
300000d0080R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H0000
6P000140003b0P00P@400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000
0000P2D0000<00003@00P4H0000X0000700004M4BD<20000:0@000l2000g1000?@80000000160000
W00009000015CDH[:T0002@0000H00000020?`00000000000020?`000000000024040eP0001<0000
0A30f`L0000000000425A03`1T@0V8E40?06A02HQD@000m404R6A0003d@0B8I40?06A02PQT@0l0I4
0?25A01014@00@410@6101A0180@000010000?oooolQ000020000680000<00000@0002@0000T0000
0020?@00000000000020?@00000000000P0002D0000<00002P0001<0000<00000@0002D0000<0000
2000P5H0000h0000:@@00102000e1000?08000L0002H@[@Qa4:d8LA2^2<L@kPS74>d8DQ3]27`@PPQ
9@0000`0000700204`0000`0000100009@0000`000000020900002@0000008110000000000000811
0000000000020000AP000600001D0000ADe6:`Q01@900000=000004@`=/00000GP0000000000080o
0P000080000200000000@@8000014<3K000000000?lE@0@0400000@000050000900002@00000080m
000000000000080m0000000000020000G`0003P000060000>0000000000h0000000000000@0@0000
000000000000000000000000000U0000300000H0000U0000300000D0081F0000>00002P4000?0P00
=P@003d200070000V4:d8LA2]274@[PS74>h8aa3]258@k@Ql4888BD0000<00001`00P2D0000<0000
0000P2@0000T00000020@@00000000000020@@00000000000P0002P0000<00001P000280000<0000
ooooodH0000L0000400004E=AR/4@0003000000000160000500000P00017A4U30`0004H0000X0000
700004M4BD<20000F@D000l2001U1@00>`8000000016000010400?P00015CDH[:T0002@0000H0000
0020?`00000000000020?`000000000024060Y`0002@00000A30f`00001N400000000000P3l20000
o`000080000000110P0005P000014<3K0000004000020000EUEE@00000000000000000008440080o
0000000000000000000001`000014<3K0`00001P00020?co00000?koo?l00H400A30f`000000003o
24070b@0000H00000A30f`800000@000G`Dj0Ul54@800@005D070100000400001P0002P0000<0000
2P00024000080000HP0000`000010000900002@00000080m000000000000080m0000000000020000
G`0003P0000:0000>0000000000h00000000000B0@0@0000000000000000000000000000000U0000
300000X0000W0000600000H00000000000000000000U0000300000H0000C000030000080000k0000
200001/0000@0000h5D009PS000f000040000>1E000n8@00F00003@00000000000000?oooooooooo
1P000>1E>B7TECHQj5Df8NeE=R7`ECTQl5Dn8CH0000@0000l5D009PS001H0000=000000000000000
ooooooooool60000l5FM8neEX2?XEJ0Si5FP8n1EWB?PEIPS?@0000P0000K000040000:QE00288@00
F@0002@00000000000000?oooooooooo0P000>QE224XEXPQ?@0000P0000l0000200003l0000H0000
F@D000l2001T1@00?08001<0000<00000@0002D0000<00000000P2D0000<00001`00P2@0000T0000
0020@@00000000000020@@00000000000P0002P0000<00002P000280000<0000ooooodH0000L0000
400004E=AR/4@0003000000000160000500000P00017A4U30`0004H0000X0000700004M4BD<20000
=`@001P2001J1000<080000000160000D00004@00015CDH[:T0002@0000H00000020?`0000000000
0020?`00000000002T00`1`0000@0000ooooo`40000h11T28@0F02P0000<00001P00024000080000
HP0000`000010000900002@00000080m000000000000080m00000000000200009`0001P000060000
00000?ooo`0000009@0000`0000600009@0000`000080020C00006@0000h10006@8005P4000^0P00
N4<008PQ000@0P00H0400240l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000002D0000<00001`00P2D0000<00000000P2@0000T00000020@@0000000000
0020@@00000000000P0004H000280000O00004E=AR/8@0P2?000030000014<3K000005H000000000
0020?`80000200000000@@8000014<3K00000?ooool8@0T3;000020000014<3K10000010000h11T2
>0@_0UT4;`9I11T20041PAE02@0@0000100000P0000j0000300000P0000T000090000000P3d00000
00000000P3d0000000000080001O0000>00000X0000h0000000003P0000000000201010000000000
oooo000000000000000002D0000<00002P0002D0000<00001@00P5H0000/0000:`@000`2001U1000
>`8000@0001h@hPQN4?X8XQ5j2:8AHPQ9@0000`0000700209@0000`000000020900002@000000811
00000000000008110000000000020000:00000`0000:0000>P0000`0000:00008P0000`0003ooooo
AP0001`0000@0000ADe6:`A0000<0000000004H0000D0000200004M4BD<300008@0000P0000N0000
600003/4000J0P00E`@002l2000U000030000040000U000030000080000U000030000040000U0000
300000d0080U000030000080000U000030000040000D0000300000d0000B000030000040001D0000
E00003/4000L0P00@@@002/200010000000P@P00848k100070800040001<00000000000000000000
oooooooooom@0000L`0000L0000U000030000080001D0000E0000444000R0P00A0@002d200010000
000P@P00849210008P800040001<00000000000000000000oooooooooom@0000M00000<0000U0000
300000d0080R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H0000
6P000140003b0P00P@400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000
0000P2D0000<00003@00P4H0000D0000200004M4BD<30000600000`0000000006@0000`0003oool0
9@0000`0000000209@0000`0000=00208P0000`0003oooooAP0003@0000X0000ADe6:bY0000T0000
60000000P3l000200000P000P3l000200000P24000080000HP0000`000010000C00006@000320`00
G@000<H5001L0P00`P<005d000050P00008002T0ZP00000000000000P3l0000000000000P3l00000
0000000000000000000000000000000000000280000<0000ooooodH0000L0000400004E=AR/2@000
30000000000>000050000000000@00005000
\>"], "Text",
  ImageSize->{392, 406.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Figure 1:",
    FontWeight->"Bold"],
  " Respiratory tract model (ICRP66). "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Model for gastrointestinal (GI) tract ", "SubsubsectionIcon"],

Cell[TextData[{
  "Material may reach the GI tract either directly by ingestion or indirectly \
by transfer from the respiratory tract (ET2 compartment) as appears in figure \
1, or by transfer from other body organs. According to ICRP 30 and 78, the GI \
tract is represented by four compartment (figure 2). In this model, the small \
intestine (SI)  is the only side of absorption from GI to body fluids. The \
rate transfer is called ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_B\)]],
  " by this equation where f1  are values characteristic values for each \
element. They can be obtained from the Annex of ICRP 78. For f1 =1 is assumed \
a direct transference from ST to transfer compartment (B) with a rate \
transfer of 24 ",
  Cell[BoxData[
      \(TraditionalForm\`d\^\(-1\)\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{"\[IndentingNewLine]", 
      RowBox[{
        FormBox[\(\[Lambda]\_B\),
          "TraditionalForm"], " ", "=", 
        " ", \(\(f\_1\/\(1\  - \ 
                f\_1\)\) \[Lambda]\_SI\)}]}]], "NumberedEquation"],

Cell["\<\
ICRP 78 expands ICRP 66 to include the biokinetic model for several \
radionuclides belonging to the Respiratory Tract. ICRP 78 gives specific \
models for selected radionuclides (in fact ICRP 78 summarize ICRP 67, 69 and \
71), also it describe the models to be applied for ingestion and for \
injection. In fact, mathematically ingestion and injection are particular \
case of inhalation. For model not included in ICRP 78 is used ICRP 30.\
\>", "Text",
  CellTags->"ICRP 78"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0007g/0@0006`0000e0P00<0000883001d0@00
B5P00807001hS000B3X00215CDH00040k7d00?82000;0000000000000000000080<005P200100@00
l0000000000000000000003R1020Z@<0AP0002`0000P0000ADe6:`500@0L00004000004@`=/10000
H000060000160000G00005000015CDH[8T0400`0000000007T0100`000000000940100`000000000
8D0700`000000000<4020100000400000020?`A0000<0000000001P0000<0000000001T0000<0000
oooo01@0000<00003@000180000<00000P00024000080000500000`0000=0000<00000`0000?0020
AP0002P0000L0000AdA9@`80000d0P00;`0008@3001f0@00000004H0002h;@00[2d004E=AR/Z@000
900001P00000080o000000000000080o00000000000Q@0D030000000000U@000400000@000000000
;40002@0000H000030:[?P0008000020IVJV?_lo3DCoocm224001O@/003X;0000A30f`8000020000
`2`00=O=aYX002@1R@5a0/P2H0000000IEL000402@000f0F000<02d0000000D000090P0000050000
0@;oool01@0000@13@0000D000020@8000050000308o0Dd10`0001h01@0000/2R@4T0@D0000<0Sl1
C@450000104=0000;@000?L000<D0000002000000800082000000800P0200020P030`<00`=c00:K:
l03ono00X:2T0820P03o00000?l00?oo00000?l0o`3o003oo`3oool0100003@2000@00009PH?01H0
ooooo`00904008T1001a0P00b08000L0003l0P00oooo0000100002d10@080000nP800040003oool2
100002d10P0700006`BS0G42R@4f0PL0003l0P00oooo0000100002d10`040000l04100P0003j0P00
0000000000040000;@4100@0003`0@800`0001h01`0001H4XP5^0XX1>@8L0000n`;ao`0000000901
000000000211LVUQK0000<<42UFUQneg[XO]Mm1WkgO310YE000:00@0000]0@80100002d10P050000
0P4100004`00038:R`4i0PP00017BB1dLV5SM0/00`0400@01@0800P0100400009`7oo`<0000N00D0
00010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0
100002d10`0@00009PH?01H0ooooo`00=P800:@1001^0P00XP8000P0003j0PD00@00000000040000
;@4400L0003l0P00oooo0000100002d11@040000;@4500T0000M1R40l03f0300Z04j0P@0000]0@D0
100002d10@040000;@4300@0003`0@D0100002d110070000o0800000000000@0000]0@D01@0000H1
0P0001P0000T0`X0>`:X0CX2Z04j0ZT1?@:Y0Cd2Z04j0ZP1>P:X0CX2Z04j0[01>`:`0@`0000T0`@0
>`:c0CX2/`4j0[@1>`:d0@`0000T0`@0>`:g0CX2]`4j0[l1>`:o0@`0000T0`@0>`;20CX2`P4j0/<1
>`;30@`0000T0`@0>`;60CX2aP4j0/h1>`;>0@`0000T0`@0>`;A0CX2d@4j0]81>`;B0@`0000T0`@0
>`;E0CX2e@4j0]d1>`;M0@`0000T0`@0>`;P0CX2h04j0^41>`;Q0@`0000T0`@0>`;T0CX2i04j0^`1
>`;/0@`0000T0`@0>`;_0CX2k`4j0_01>`;`0@`0000T0`@0>`;c0CX2l`4j0_/1>`;k0@`0000T0`@0
>`;n0CX2oP4j0_l1>`;o0@`0000T0`@0>`820SX20P8j0PX2>`8:0P`0000T0`@0>`8=0SX23@8j0Ph2
>`8>0P`0000T0`@0>`8A0SX24@8j0QT2>`8I0P`0000T0`@0>`8L0SX2708j0Qd2>`8M0P`0000T0`@0
>`8P0SX2808j0RP2>`8X0P`0000T0`@0>`8[0SX2:`8j0R`2>`8/0P`0000T0`@0>`8_0SX2;`8j0SL2
>`8g0P`0000T0`@0>`8j0SX2>P8j0S/2>`8k0P`0000T0`@0>`8n0SX2?P8j0TH2>`960P`0000T0`@0
>`990SX2B@8j0TX2>`9:0P`0000T0`@0>`9=0SX2C@8j0UD2>`9E0P`0000T0`@0>`9H0SX2F08j0UT2
>`9I0P`0000T0`@0>`9L0SX2G08j0V@2>`9T0P`0000T0`@0>`9W0SX2I`8j0VP2>`9X0P`0000T0`@0
>`9[0SX2J`8j0W<2>`9c0P`0000T0`@0>`9f0SX2MP8j0WL2>`9g0P`0000T0`@0>`9j0SX2NP8j0X82
>`:20P`0000T0`@0>`:50SX2Q@8j0XH2>`:60P`0000T0`@0>`:90SX2R@8j0Y42>`:A0P`0000T0`@0
>`:D0SX2U08j0YD2>`:E0QP0000T0`X0>`:H0SX2V08j0Yh2>P:N0SX2W`8l0Yl2?0:N0SX2WP8j0Yh2
>`:N0P`0000T0`@0?`:N0Sl2W`900Yl2@0:N0P`0000T0`@0@`:N0T<2W`9;0Yl2B`:N0P`0000T0`@0
CP:N0Th2W`9?0Yl2C`:N0P`0000T0`@0DP:N0U82W`9J0Yl2FP:N0P`0000T0`@0G@:N0Ud2W`9N0Yl2
GP:N0P`0000T0`@0H@:N0V42W`9Y0Yl2J@:N0P`0000T0`@0JP:L0V/2W09[0Y/2JP:K0P`0000T0`@0
JP:H0V/2V09[0Y02JP:@0P`0000T0`@0JP:=0V/2S@9[0X`2JP:<0P`0000T0`@0JP:90V/2R@9[0X42
JP:10P`0000T0`@0JP9n0V/2OP9[0Wd2JP9m0P`0000T0`@0JP9j0V/2NP9[0W82JP9b0P`0000T0`@0
JP9_0V/2K`9[0Vh2JP9^0P`0000T0`@0JP9[0V/2J`9[0V<2JP9S0P`0000T0`@0JP9P0V/2H09[0Ul2
JP9O0P`0000T0`@0JP9L0V/2G09[0U@2JP9D0P`0000T0`@0JP9A0V/2D@9[0U02JP9@0P`0000T0`@0
JP9=0V/2C@9[0TD2JP950P`0000T0`@0JP920V/2@P9[0T42JP910P`0000T0`@0JP8n0V/2?P9[0SH2
JP8f0P`0000T0`@0JP8c0V/2<`9[0S82JP8b0P`0000T0`@0JP8_0V/2;`9[0RL2JP8W0P`0000T0`@0
JP8T0V/2909[0R<2JP8S0P`0000T0`@0JP8P0V/2809[0QP2JP8H0P`0000T0`@0JP8E0V/25@9[0Q@2
JP8D0P`0000T0`@0JP8A0V/24@9[0PT2JP890P`0000T0`@0JP860V/21P9[0PD2JP850P`0000T0`@0
JP820V/20P9[0_X1JP;j0@`0000T0`@0JP;g0F/2m`5[0_H1JP;f0@`0000T0`@0JP;c0F/2l`5[0^/1
JP;[0@`0000T0`@0JP;X0F/2j05[0^L1JP;W0@`0000T0`@0JP;T0F/2i05[0]`1JP;L0@`0000T0`@0
JP;I0F/2f@5[0]P1JP;H0@`0000T0`@0JP;E0F/2e@5[0/d1JP;=0@`0000T0`@0JP;:0F/2bP5[0/T1
JP;90@`0000T0`@0JP;60F/2aP5[0[h1JP:n0@`0000T0`@0JP:k0F/2^`5[0[X1JP:j0@`0000T0`@0
JP:g0F/2]`5[0Zl1JP:_0@`0000T0`@0JP:/0F/2[05[0Z/1JP:[0@`0000T0`@0JP:Y0FX2Z05R0ZP1
HP:Y0@`0000T0`@0G`:Y0El2Z05N0ZP1GP:Y0@`0000T0`@0F`:Y0E/2Z05C0ZP1D`:Y0@`0000T0`@0
D0:Y0E02Z05?0ZP1C`:Y0@`0000T0`@0C0:Y0D`2Z0540ZP1A0:Y0@`0000T0`@0@@:Y0D42Z0500ZP1
@0:Y0@D000060@4000040000;@4100@0000]0@<010000?011@0800009PH?00H0ooooo`401`000?`2
003oool000040000;@4500P0003j0P000@00000000840000;@4600L0000K12X20P;50F<1100002d1
0`040000l04500@0000]0@4010000?011P070000o0800<30`00000@0000]0@D020000?X200010000
00000P@0000]0@H01`0001P4K@;50DH2WP440000;@4300@0003`0@D0100002d10@040000l04600<0
000N00L0000F16H2_05=0ZL170000?/2lol00000002@0@0000000000@G9YHF`0001@10[SYHO]Mjj7
kGO@InmgD0@:h`002P040000;@4501`0003k0_7o00000000_08000000000845bJF5/00006PD:eZF7
kGN^Qnegd6O_MaX52]H000X0100002d11P040000;@4500@0000]0@H0100002d11@050000104=0000
1@0000810@0000T0000b2Tl2Y`410000800400@0000]0@H02@00038:CP:[0@40001200/0100002L1
ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@800000
1@000042oooo00@0000]0@<01`000?`2003oool000040000;@4700P0003j0P000@00000000840000
;@4800L0000K19P2109g0V<1100002d10`040000l04700@0000]0@4010000?0120070000o0800<30
`00000@0000]0@L020000?X20001000000000P@0000]0@P01`0001P4h`5T0/41@0840000;@4300@0
003`0@L0100002d10@040000l04800L0003l0P00oooo0000100002d11`080000nP80004000000002
100002d12007000060@O0V@2o@500P@0000]0@<010000?011`040000;@4100@0003`0@P01`000?`2
003oool000040000;@4700P0003j0P000@00000000840000;@4800L0000H15d2IP8k0T82100002d1
0`040000l04700@0000]0@4010000?0120070000o0800?ooo`0000@0000]0@L020000?X200010000
00000P@0000]0@P01`0001P4U`9V0WD2@P840000;@4300@0003`0@L0100002d10@040000l0480100
000V1Pl05P3ooooo000i0@00kP4006<100010P0020000?X200010000000000@0000]0@L01`000?`2
003oool000040000;@480180000T0`L0E`7_0EL1l`4j0O<1>P7k0EL1n`5G0Ol1H@7g0@@0000]0@40
10000?011`040000;@4300@0003`0@P0200002H63`060?ooool10100000V1Pl05P3ooooo002^0@00
X`400;L100340@0020000?X200010000000000@0000]0@L01`000?`20@00000000040000;@4800P0
000U0`80/P720K81[0440000;@4400@0003`0@L01`000?`20000000000040000;@4700X0000T0`<0
]P6_0K81Y06_0Jl1100002d10@040000;@4300@0003`0@L0200002H63`060?ooool10100000V1Pl0
5P3ooooo002Z0@00:@800;X100190P0020000?X200010000000000@0000]0@L01`000?`2003oool0
00040000;@490180000T0`L0Z`500Zh1@0:^0BX2]@4Z0[D1@0:h0D02/@570P@0000]0@4010000?01
1`040000;@4300@0003`0@T0200002H63`060?ooool10100000V1Pl05P3ooooo001o0@00D`8009l1
001h0P00100002d110070000o0800?ooo`0000@0000]0@L0900002@3402L0Ed2U05D0Y@1F0:@0EP2
RP5I0XD1G@:10F42P05W0X01M@:80GD2R05W0XT1I@:;0F<2T05R0Y@1HP:D0FL2100002d10@040000
;@4300@0003`0@L0100002d110070000o0800000000000@0000]0@L01@0000H10P0001@0000T0`P0
W05M0Y/1G@:L0Eh2W05M0Yd1G@:J0EX2V@5J0YT1FP8@000090<609L1F0:G0EP2V05H0YD1E@:E0E@2
U05E0Q`0000T0``0U@5F0Y@1E@:D0EH2U05H0Y@1F0:D0EP2TP5H0Y81F0:B0ET2U05I0Y@1F0:E0EP2
400002@31P2?0ET2T05H0Xl1F0:;0EP2R`5I0X/1F@8@000090<608P1F`:90EX2R05J0XD1G0:50E`2
Q@5M0Q@0000T0`P0Q05O0X<1GP:30El2P@5Q0X41HP:10F82PP5R0X81H@8D000090<80841I@:00F@2
P05U0X01I`:00FT2P05Y0X41J@:10FL2400002@31P210F`2P05[0X01K0:00G02P05`0X41L08J0000
90<;0841L`:00G82P05c0X01M@:00GH2PP5f0X81M@:20GD2P05e0X01M@:10GD26P0002@32`250GD2
Q05e0XD1MP:80GH2R@5e0XT1M0:80G@2R05d0XP1M@:80GD2R05e0Q00000T0`H0R05a0XP1LP:90G42
R@5]0XP1K@:80Fd2500002@320280FX2R05[0XT1JP:90FL2R@5V0XP1IP:80FH2R05W0Q@0000T0`P0
RP5S0XT1I0::0F@2R`5T0Xh1H`:>0F<2SP5R0X/1H`8J000090<;0941HP:@0F82T@5S0Y@1H`:D0F82
U05R0Y@1H`:D0F<2U@5S0YD1HP:D0F82700002@3302E0FH2U05U0Y@1IP:D0FL2U05W0YD1I`:F0FD2
UP5T0YD1I@:D0FL2U05W0YD1I`8@000090<609L1H`:G0F<2V05S0YX1H0:J0El2V@5P0PD000060@40
00040000;@4100@0000]0@<010000?011`0800009PH?00H0ooooo`40400002H63`0F0?ooool00<81
001H0P00i`4007T200080000nP80004000000000100002d11`070000o0800?ooo`0000@0000]0@T0
900002@3403J0GH2i05_0]l1KP;O0F/2g`5U0]`1G`;H0E/2dP5J0/@1F@;30F42dP5R0]@1H`;E0FD2
eP5Z0]H1KP;A0Fd2100002d10@040000l04700@0000]0@<010000?012@0800009PH?00H0ooooo`40
400002H63`0F0?ooool00;D1000J0P00C`8004/200080000nP80004000000000100002d11`040000
;@4800`0000U0`@0C@8K0Td2;`:i0Bl2^@510P@0000]0@@010000?011`070000o0800000000000@0
000]0@L02P0002@30`2f0Cl2^P5:0[d1?`840000;@4100@0000]0@<010000?011`0800009PH?00H0
ooooo`40400002H63`0F0?ooool004l2000N0P00F08003h200080000nP80004000000000100002d1
1`040000;@4800P0000U0`80D`8O0U<2=0840000;@4400@0003`0@L01`000?`20000000000040000
;@4700X0000T0`<0D08b0U@2?09G0S82100002d10@040000;@4300@0003`0@L0200002H63`060?oo
ool10100000V1Pl05P3ooooo001>0P00G08005L2001h0P0020000?X200010000000000@0000]0@L0
100002d1200800009@<20582G@9B0Vh2100002d110040000l04700L0003l0P0000000000100002d1
1`0:000090<304l2K09B0WH2EP9/0P@0000]0@40100002d10`040000l04700P0000V1Pl01P3ooooo
0@0@00009PH?01H0ooooo`00CP800>01001G0P00oP4000P0003j0P000@00000000040000;@4700@0
000]0@P0200002D30P1B0^41DP;d0@@0000]0@@010000?011`070000o0800000000000@0000]0@L0
2P0002@30`1?0_81DP;l0EH2lP440000;@4100@0000]0@<010000?011`0800009PH?00H0ooooo`40
400002H63`0F0?ooool000<2003>0@00@0800=L100080000nP80004000000000100002d11`040000
;@4800P0000U0`8010;B0CH2dP440000;@4400@0003`0@L01`000?`20000000000040000;@4700X0
000T0`<0=0;F0Ch2dP4d0/l1100002d10@040000;@4300@0003`0@L0200002H63`060?ooool100L0
003l0P00oooo0000100002d11`080000nP800040003oool2100002d12@0700006`@60_`1kP5X0@@0
000]0@<010000?011`040000;@4100@0003`0@T00`0001h01`0001H41@;i0Nl1J`440000;@4200@0
000]0@801@0000@13@0000D000020@40000X0000<P[`0F/15P00059ULg1YLV5dKg9i87AbHF=d82QB
E2T;00P0200800<01@0800@0200500L0100400D0200800@0100500/02@0500@0000W0Ooo0`0001h0
1@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D000010_oo
o`040000;@4300L0003l0P00oooo0000100002d11`080000nP800040003oool2100002d12@070000
6`BE0_L1O@9c0@@0000]0@<010000?011`040000;@4100@0003`0@T00`0001h01`0001H4U0;d0Gh2
MP440000;@4500@0000]0@D01@0000@13@0000D000020@40000W0000<PYn0WH15@00059ULg@PKfHP
M6QU869_I7TP:592:@8900L01`0400@01`0300@0100700L0100700L01`0700@0100900T010040000
9`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00
000500000@;oool0100002d10`070000o0800<30`00000@0000]0@L020000?X200010000`<300P@0
000]0@T01`0001/4f@5O0/P1B0840000;@4300@0003`0@L0100002d10@040000l04900<0000N00L0
000F1=P1G0;90D/270000?/2mOl00000002l0P000000000P@G9YHF`0000A10XZYHO]Mjj7kGO@Inmg
4@@::P002P040000;@4700@0000]0@L01@0000@13@0000D000020@40000:0000<P[90D/20P0005=D
1`0700@0000W0Ooo0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo
1@0000T2000000D000010_ooo`040000;@4300L0003l0P00oooo0000100002d12@080000nP800040
003oool2100002d12P0700006`@H0Ul20`990P@0000]0@<010000?012@040000;@4100@0003`0@X0
0`0001h01`0001H45`9L0P@2C08L0000n`;eo`0000000901000000000211LVUQK0000?<42[>UQneg
[XO]Mm1WkgOc10Zc000:00@0000]0@T0100002d12@050000104=00001@0000810@0000X0000b2P@2
C0820000DdT70080100002L1ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0
100002L1ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool000040000;@4:00P0
003j0P000@000?ooo`840000;@4;00L0000K15T2GP940TP2100002d10`040000l04:00@0000]0@40
10000?012`0300007P0700005PAH0U/2A@9;0P@0000]0@T0100002d12@050000104=00001@000081
0@0000`0000b2TD2B`830000EDa9=`L01P0200@0000W0Ooo0`0001h01@000042oooo00D000090P00
000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D000010_ooo`040000;@4300L0003l0P00
oooo0000100002d12P080000nP800040003oool2100002d12`0700006`BA0Ul2O0990P@0000]0@<0
10000?012P040000;@4100@0003`0@/00`0001h01`0001H4T09L0Wd2C0840000;@4900@0000]0@T0
1@0000@13@0000D000020@40000<0000<PYm0T`20`0004a<BCP600H00P0400009`7oo`<0000N00D0
00010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0
100002d10`0@00009PH?01H0ooooo`00C`4004h2002M0@00E`8000@0000]0@@01`000?`200000000
00040000;@4:00D000060@80000@000090<609/1D`:K0E82V`5B0YL1DP:G0E82U`5C0Q00000T0`H0
U05C0Y@1DP:D0E82T05B0Y01DP:@0E<2400002@31P2=0E<2S@5B0Xd1DP:90E82R@5B0XT1D`8@0000
90<608H1D`:60E82QP5B0X81DP:20E82PP5C0Q00000T0`H0O`5C0Wl1DP9o0E82N`5B0W/1DP9k0E<2
400002@31P1h0E<2N05B0WP1DP9d0E82M05B0W@1D`8@000090<60741D`9a0E82L@5B0Vd1DP9]0E82
K@5C0Q00000T0`H0JP5C0VX1DP9Z0E82IP5B0VH1DP9V0E<2400002@31P1S0E<2H`5B0V<1DP9O0E82
G`5B0Ul1D`8@000090<605`1D`9L0E82G05B0UP1DP9H0E82F05C0PD000060@40000:000090<305/1
C`9@0E82F`5F0P@0000]0@40100002d10`040000l04:00P0000V1Pl01P3ooooo0@0@00009PH?01H0
ooooo`00CP8009D2001G0P00/08000P0003j0P000@00000000040000;@4:00@0000]0@P0200002D3
0P1C0YH2DP:V0P@0000]0@@010000?012P070000o0800000000000@0000]0@X02P0002@30`1?0Z@2
DP:^0UH2Y0840000;@4100@0000]0@<010000?012P0800009PH?00H0ooooo`401`000?`2003oool0
00040000;@4:00P0003j0P000@000?ooo`840000;@4;00L0000K15d2BP5;0R@1100002d10`040000
l04:00@0000]0@4010000?012`0300007P0700005PAL0TL1C08W0@@0000]0@D0100002d11@050000
104=00001@0000810@0000l0000b2T`29`450000EG9YKVD02@0400<01`0700@0000W0Ooo0`0001h0
1@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D000010_oo
o`040000;@4300L0003l0P00oooo0000100002d12P080000nP800040003oool2100002d12`070000
6`C80V/2/`8h0P@0000]0@<010000?012P040000;@4100@0003`0@/00`0001h01`0001H4a`9X0[@2
>`840000;@4500@0000]0@D01@0000@13@0000D000020@40000@0000<PZd0S/21P0004IQIF=UL`P0
1`0700L01`0700@0000W0Ooo0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0
000W0Ooo1@0000T2000000D000010_ooo`040000;@4300L0003l0P00oooo0000100002d12P080000
nP800040003oool2100002d12`0700006`BT0N@1T`6:0@@0000]0@<010000?012P040000;@4100@0
003`0@/00`0001h01`0001H4X`7Q0I@1S@440000;@4500@0000]0@D01@0000@13@0000D000020@40
000H0000<PZD0Hd12`0004E^MVUbKfi]IFid0@T01`0500<0100700L02`0700L0100400009`7oo`<0
000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P0000050000
0@;oool0100002d10`0@00009PH?01H0ooooo`00_@4004P200140P00D@8000P0003j0P000@000000
00040000;@4:00@0000]0@P0200002D30P2n0D`2>P9<0P@0000]0@@010000?012P070000o0800000
000000@0000]0@X02P0002@30`0h0U02@P9<0SP2B@840000;@4100@0000]0@<010000?012P080000
9PH?00H0ooooo`40400002H63`0F0?ooool00082001C0P00BP8008T200040000;@4400L0003l0P00
00000000100002d12P0500001P420000400002@31P030XL20`:70P<2R0870XP21`:70PL2Q`8@0000
90<600X2Q`890XL22P:80Ph2R08>0XL23P:70Q00000T0`H04@:70Q02Q`8A0XP25@:80QD2Q`8E0XL2
400002@31P0H0XL25`:70QP2R08L0XP270:70Q`2Q`8@000090<601l2Q`8N0XL27`:80R<2R08S0XL2
8`:70Q00000T0`H09@:60RD2QP8V0XH29P:20RD2PP8U0X82400002@31P0U0Wl29@9o0RH2O`8V0W/2
9@9k0RD2N`8@000090<602D2N08U0WP29P9h0RH2M08U0W@29@9d0Q00000T0`H09@9a0RD2L@8V0W42
9P9]0RD2K@8U0Vd2400002@31P0U0VX29@9Z0RH2JP8V0VH29@9V0RD2IP8@000090<602D2H`8U0V<2
9P9S0RH2G`8U0Ul29@9O0Q00000T0`H09@9L0RD2G08V0U`29P9H0RD2F08U0UP2400002@31P0W0UL2
9P9G0RL2F08[0UP2:`9G0R/2E`8@000090<602h2E`8]0UL2;P9H0S82F08b0UL2<P9G0Q00000T0`H0
=@9G0S@2E`8e0UP2>@9H0ST2E`8i0UL2400002@31P0l0UL2>`9G0S`2F0900UP2@09G0T02E`850000
1P4100002P0002@30`0n0U/2B09H0Sh2E0840000;@4100@0000]0@<010000?012P0800009PH?00H0
ooooo`40400002H63`0F0?ooool002@2000:0P00@`8005T200040000;@4400L0003l0P0000000000
100002d12P0500001P420000400002@31P0U0UL29@9G0RH2E`8V0U<29@9C0RD2D`8@000090<602D2
D08U0U029P9@0RH2C08U0T`29@9<0Q00000T0`H09@990RD2B@8V0TT29P950RD2A@8U0TD2400002@3
1P0U0T829@920RH2@P8V0Sh29@8n0RD2?P8@000090<602D2>`8U0S/29P8k0RH2=`8U0SL29@8g0Q00
000T0`H09@8d0RD2=08V0S@29P8`0RD2<08U0S02400002@31P0U0Rd29@8]0RH2;@8V0RT29@8Y0RD2
:@8@000090<602D29P8U0RH29P8V0RH28P8U0R829@8R0Q00000T0`H09@8O0RD27`8V0Ql29P8K0RD2
6`8U0Q/2400002@31P0U0QP29@8H0RH2608V0Q@29@8D0RD2508L000090<<02D24@8U0Q429P8A0RH2
3P8U0Ph29@8?0RH23`8V0Ph29P8>0RD23P8U0Ph29@8>0Q00000T0`H0:@8>0RP23P8Y0Pl2;@8?0Rd2
3P8]0Ph2400002@31P0`0Ph2;`8>0S023`8d0Pl2=08>0S@23P8@000090<603L23P8f0Ph2=`8?0ST2
3`8i0Ph2>@8>0PD000060@40000:000090<303L24P920Ph2=`8;0P@0000]0@40100002d10`040000
l04:00P0000V1Pl01P3ooooo0@0@00009PH?01H0ooooo`00<`4005/2001U0@00R@8000@0000]0@@0
1`000?`20000000000040000;@4:00D000060@80000@000090<606<1R09S0HL2H`670Ul1Q`9O0HL2
G`680Q00000T0`H0G0680U`1Q`9L0HL2F0670UP1Q`9H0HP2400002@31P1E0HP2E@670UD1Q`9A0HL2
D@670U41R08@000090<604h1R09>0HL2CP670TX1Q`9:0HL2BP680Q00000T0`H0A`680TL1Q`970HL2
@`670T<1Q`930HP2400002@31P100HP2@0670T01Q`8l0HL2?0670S`1R08J000090<;03T1R08i0HL2
>@670SL1Q`8g0HL2>0670SP1Q@8g0HD2=`650SL1Q`8g0HP2400002@31P0g0H82=`620SP1PP8h0Gh2
=`5n0SL1OP8@000090<603L1N`8g0G/2>05k0SP1M`8g0GL2=`5g0Q00000T0`H0=`5d0SL1M08h0G@2
>05`0SL1L08g0G02400002@31P0g0Fd2=`5]0SP1K@8h0FT2=`5Y0SL1J@8@000090<603L1IP8g0FH2
>05V0SP1I08g0F@2=`5T0PD000060@40000:000090<303/1I`8h0E`2=05W0P@0000]0@40100002d1
0`040000l04:00P0000V1Pl01P3ooooo0@0800009PH?00H0ooooo`401@0000T2000000D000010_oo
o`040000;@4300@0000W0Ooo0`000000240122@0000H00000A30f`40000300000000000000000000
6T00@2`0000P00000@000080000009930834@`20YT<0P9m300000>P3j0<Q000020000680000<0000
0@00024000080000HP0000`0000100004@0000`0000800002P000100000T0@00R@4000T0000@0000
C@4003l1000<0000400003D2000`00002`000100001>0@00A@400240000800009@0000`000070020
9@0000`0000000205P0000`000000000600000`0000000006@0000`0003oool0500000`0000=0000
DP00070100010000400000L00000000000000;`2000000001`828U<0N@1c07@0I@1]000000000000
0000000000000000000000000000000000000000000000000000000000000000/R`02040002@cQ<0
EOo5MjH:0Jc`cQ<000000000000hKLEg0000058:8ATI0;01000@0705P@9HKSP2YPX1[5Q^>0;k0P00
300005XL00Slj/``FQ`02=3?4`000000@@1b0040003@ca<000000=3?4`3oool0V<hC000000010000
00000040003XcQ<0Y4[;<:H:0JaHKSP29`4000`0003@ca<0T4C;<50000=@00030P0000P000000000
00000000003@ca<0/<h100005@0dcQ<08Adb<BS?4`05T?Igb=GeMooooomZ5_Agbf3UM`005@000000
I7H02000000U000030000040000H000030000000000I000030000?ooo`0D0000300000d0000B0000
30000080000:000040000000000000002@000100001=0@00?`400240000800002P000100000T0@00
R@4000T0000@0000C@4003l1000D0000300000d0000W00006000008000000000oooo0000000U0000
30000080000V0000700000<0000000000@000000003oool09@0000`000030000:`0001P0000f0P00
R@400702002R0@009`0001P00004000000000?ooo`0000009@0000`000040000:00000`000020000
9P0001`0000200000000000000000000000002D0000<00000P0002P0000<00000`00024000080000
7P0001P0000i0P00RP4006h2002R0@00DP00070100030000lOooo`00000000000000090100000000
1`008440LP1Y0640K000000000000000000000000000000000000000000000000000000000000000
00000000000001<0Y4[;<58:8AUHKSP26`@006S>4`000000T1KdMmPd>P9>5_AgB0LE06XFm7M52S0D
h3@j0^0d>P:b;0080@00093>4`1EolEgYPX1[?3>4`000000000003Q]aGL00000DPXQ6AT0/0400100
L0F10UQ^>0:V2P6/F6hh0P004`000000T1KdMo0m>P9>5_Agn0PE06XFm7MD?SX2`P002?Pm>P800000
d<lC0?ooo`2HcQ<010000200000000000@000>S>4`2TBP40000E0:c=4`0W0@00X<hC00F@mWO8eOEg
ooooofXFm7O;H>Eg000E0000003NH>EgI7H02000000U0000300000<0000U0000300000<0000B0000
30000040001D0000O00004/3000b0000NP<004800001000007/P@VL28d8i0P00R`4000P0001<0000
0000000000000000oooooooooomL0000A`190200M01b0640H`1d00/000030000100000@000050000
200000P0000400008P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
600001X0000A00003@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000
300000@0000U0000300000P0080W0000600000D000000000oooo0000000U0000300000D0000U0000
300000D0001<0000I00004`3001@0000N`<004T1000j0P00Z0400300003f00008@3`000000000000
0020?`00000000000020?`0000000000000000000000000000000000000000009@0000`000050000
9@0000`0000200009@0000`000040000:00000`0000500009@0000`0000800209`0001P000050000
00000000000000009@0000`0000500004`0000`000020000EP0004@0001<0`00D00004l3001H0000
2P0003/2Z04j0ZP1>P:Y0Cd2Z@4m0ZP1>P:X0CX2Z04j0ZP1>P:`0C/2/05F0000;00004`3001K0000
C@<005`000040000>`:c0CX2/`4j0[@1>`:d0EH0000/0000C0<005l0001=0`00I`0000@0000k0[L1
>P:g0CX2_`4k0[l1EP0002`0001<0`00JP0004d3001[0000100003/2`P4j0/81>P;30C/2``5F0000
;00004`3001^0000C@<007H000040000>`;60CX2aP4j0/h1>`;>0EH0000/0000C0<007T0001=0`00
NP0000@0000k0]41>P;A0CX2dP4k0]81EP0002`0001<0`00O@0004d300260000100003/2e@4j0]D1
>P;M0C/2g@5F0000;00004`300290000C@<008X000040000>`;P0CX2h04j0^41>`;Q0EH0000/0000
C0<008d0001=0`00U@0000@0000k0^@1>P;T0CX2k04k0^`1EP0002`0001<0`00V00004d3002I0000
100003/2k`4j0^l1>P;`0C/2l05F0000;00004`3002L0000C@<00:@000040000>`;c0CX2l`4j0_/1
>`;k0EH0000/0000C0<00:L0001=0`00Z00000@0000k0_h1>P;n0CX2o`4k0_l1EP0002`0001<0`00
Z`0004d3002c0000100003/20P8j0P82>P8:0S/22P9F0000;00004`3002g0000C@<00;P000040000
>`8=0SX23@8j0Ph2>`8>0UH0000/0000C0<00;/0001=0`00``0000@0000k0Q42>P8A0SX26@8k0QT2
EP0002`0001<0`00aP0004d300370000100003/2708j0Q`2>P8M0S/27@9F0000;00004`3003:0000
C@<00=8000040000>`8P0SX2808j0RP2>`8X0UH0000/0000C0<00=D0001=0`00eP0000@0000k0R/2
>P8[0SX2;08k0R`2EP0002`0001<0`00f@0004d3003Q0000100003/2;`8j0Rl2>P8g0S/2=`9F0000
;00004`3003T0000C@<00>D000040000>`8j0SX2>P8j0S/2>`8k0UH0000/0000C0<00>P0001=0`00
l@0000@0000k0Sh2>P8n0SX2AP8k0TH2EP0002`0001<0`00m00004d3003e0000100003/2B@8j0TT2
>P9:0S/2BP9F0000;00004`3003h0000C@<0000100040000>`9=0SX2C@8j0UD2>`9E0UH0000/0000
C0<000<1001=0`00104000@0000k0UP2>P9H0SX2F@8k0UT2EP0002`0001<0`001`4004d3000?0@00
100003/2G08j0U`2>P9T0S/2I09F0000;00004`3000B0@00C@<001<100040000>`9W0SX2I`8j0VP2
>`9X0UH0000/0000C0<001H1001=0`007P4000@0000k0V/2>P9[0SX2L`8k0W<2EP0002`0001<0`00
8P4004d3000S0@00100003/2MP8j0WH2>P9g0S/2M`9F0000;00004`3000V0@00C@<002h100040000
>`9j0SX2NP8j0X82>`:20UH0000/0000C0<00341001=0`00<P4000@0000k0XD2>P:50SX2QP8k0XH2
EP0002`0001<0`00=@4004d3000m0@00100003/2R@8j0XT2>P:A0S/2T@9F0000;00004`300100@00
C@<0044100040000>`:D0SX2U08j0YD2>`:E0UH000140000C0<004@1001>0`00B`4000X0000k0YP2
>P:H0SX2WP8j0Yh2>P:O0S`2W`8l0Yh2>P:N0SX2WP8k0Yh2EP0002`0001A0`00BP400583001;0@00
100003l2WP8o0Yl2@0:O0T02WP9F0000;00005D3001:0@00G@<004/100040000@`:N0T<2W`9;0Yl2
B`:N0UH0000/0000H0<004X1001Q0`00B`4000@0001>0Yh2CP:O0Tl2W`9?0Yh2EP0002`0001T0`00
BP4006`3001;0@0010000582WP9B0Yl2FP:O0UX2WP9F0000;00006l3001:0@00L0<004/100040000
G@:N0Ud2W`9N0Yl2GP:N0UH0000/0000L`<004X1001k0`00B`4000@0001Q0Yh2H@:O0VT2W`9Y0Yh2
EP0002`0001l0`00A`4007d300180@00100006X2W09[0Y`2J`:K0VX2V`9F0000;00007`3000l0@00
O@<004@100040000JP:H0V/2V09[0Y02JP:@0UH0000/0000O0<003P1001m0`00>@4000@0001Z0Xd2
J`:=0V/2S09Z0X`2EP0002`0001l0`00;@4007d3000e0@00100006X2R@9[0XT2J`:10VX2P@9F0000
;00007`3000Y0@00O@<002X100040000JP9n0V/2OP9[0Wd2JP9m0UH0000/0000O0<001d1001m0`00
9P4000@0001Z0WX2J`9j0V/2LP9Z0W82EP0002`0001l0`006@4007d3000J0@00100006X2K`9[0Vl2
J`9^0VX2KP9F0000;00007`3000>0@00O@<001H100040000JP9[0V/2J`9[0V<2JP9S0UH0000/0000
O0<000X1001m0`002`4000@0001Z0V02J`9P0V/2G`9Z0Ul2EP0002`0001l0`00o`0007d300070@00
100006X2G09[0U`2J`9D0VX2E09F0000;00007`3003k0000O@<00?`000040000JP9A0V/2D@9[0U02
JP9@0UH0000/0000O0<00?00001m0`00n00000@0001Z0Td2J`9=0V/2A@9Z0TD2EP0002`0001l0`00
k00007d3003]0000100006X2@P9[0T82J`910VX2@@9F0000;00007`3003P0000O@<00>P000040000
JP8n0V/2?P9[0SH2JP8f0UH0000/0000O0<00=`0001m0`00g@0000@0001Z0S<2J`8c0V/2<P9Z0S82
EP0002`0001l0`00d@0007d3003I0000100006X2;`9[0Rl2J`8W0VX29`9F0000;00007`3003=0000
O@<00<h000040000JP8T0V/2909[0R<2JP8S0UH0000/0000O0<00<80001m0`00bP0000@0001Z0R02
J`8P0V/2609Z0QP2EP0002`0001l0`00_P0007d3002o0000100006X25@9[0QD2J`8D0VX2509F0000
;00007`3002b0000O@<00;/000040000JP8A0V/24@9[0PT2JP890UH0000/0000O0<00:h0001m0`00
[`0000@0001Z0PH2J`860V/21@9Z0PD2EP0002`0001l0`00X`0007d3002[0000100006X20P9[0P82
J`;j0FX2nP5F0000;00007`3002O0000O@<00:0000040000JP;g0F/2m`5[0_H1JP;f0EH0000/0000
O0<009@0001m0`00W00000@0001Z0_<1J`;c0F/2j`5Z0^/1EP0002`0001l0`00T00007d3002A0000
100006X2j05[0^P1J`;W0FX2i`5F0000;00007`300250000O@<008d000040000JP;T0F/2i05[0]`1
JP;L0EH0000/0000O0<00840001m0`00PP0000@0001Z0]T1J`;I0F/2f05Z0]P1EP0002`0001l0`00
M@0007d3001m0000100006X2e@5[0]D1J`;=0FX2c@5F0000;00007`3001a0000O@<0078000040000
JP;:0F/2bP5[0/T1JP;90EH0000/0000O0<006H0001m0`00KP0000@0001Z0/H1J`;60F/2_P5Z0[h1
EP0002`0001l0`00HP0007d3001S0000100006X2^`5[0[/1J`:j0FX2^P5F0000;00007`3001G0000
O@<005l000040000JP:g0F/2]`5[0Zl1JP:_0EH0000/0000O0<005<0001m0`00E00000@0001Z0Z`1
J`:/0F/2Z`5Z0Z/1EP0002`0001d0`00D00007`3001A0000100006X2Z@5Z0ZP1HP:X0F82Z@5F0000
;0000703001@0000L@<0054000040000G`:Y0El2Z05N0ZP1GP:Y0EH0000/0000I@<00500001]0`00
D@0000@0001K0ZT1F`:X0E<2Z05C0ZT1EP0002`0001Q0`00D0000683001A000010000502Z@5@0ZP1
C`:X0Dl2Z@5F0000;00005H3001@0000GP<0054000040000C0:Y0D`2Z0540ZP1A0:Y0EH0000/0000
DP<00500001C0`00D@0000@000110ZT1@@:X0D02Z0500ZT14`0000`0000100009@0000`000020000
9@0000`000040000:00000`0000500009`0001P00005000000000?ooo`0000009@0000`000050000
9P0001`0000600000000004000000000000002D0000<00001P0002/0000H0000H`400<D100010P00
:@8002D0000<0000100002P0000<00001@0002D0000<00000P0002P0000<00001P0002L0000H0000
1P0000000030`<00000002D0000<00001P0002H0000L00001@0000000001000000000000000U0000
300000D0000Z0000600009h100160P00a04006`2000U0000300000@0000X0000300000H0000U0000
30000080000X0000300000D0000Q0000200001h0000H0000Y`4004d2002l0@00IP800580001`0@00
1@000??oool0000000000000002@0@00000000L000110780J@1Q06`0000000000000000000000000
000000000000000000000000000000000000000000000000000C0:A:bc1B2R4IF6hh0Q/4001XcQ<0
0000090Fm7NP4cT2CQKdMdP75@1Z5_Ag?`X`TjPC>@:X4cT2=g_5Mk3I6@0j0P00Z0400300003f0000
8@3`0000000000007<c7M`000000000000000000000000000000004H000001<00000090Fm7N`V3X2
CQKdMgP75@1Z5_Ag10000000002hV3X22<000=3?4`3oool0V<hC00@0000P0000000000005@2<c1<0
0@0100005@2/cA<0XOCdMj3>4`05T?Igb=GeMooooomZ5_Agbf3UM`005@000000gV3UMfAf00P00000
9@0000`000050000DP00070100060000lOooo`000000000000000;`2000000001`008440LP1Y0640
K0000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000016000000C0000002@5_Ag/9Pj0ThFm7Mh1aD0JQKdM`@000000000
^9Pj0PS0003@ca<0oooo09S>4`04000080000000000001D0S<`C00400@0001D0[<dC0:7dm7NPcQ<0
1I3fM`00mGOoooooJQKdMl]PiGL001D000000=iPiGMTMP0800000;RH>P88`000d<lC0?ooo`2HcQ<0
1000020000000000000E08c<4`010040000E0:c=4`2Qm?AgX<hC00F@mWO8eOEgooooofXFm7O;H>Eg
000E0000003NH>EgI7H02000000U0000300000H0000U0000300000D0000U0000300000H0000U0000
300000D0000D0000300000d0000B000030000040001D0000E0000;P2003j0000^`8000T100010000
07/P@VL28d:W0@00C`800040001<00000000000000000000oooooooooom@0000800000@0000U0000
300000H0001D0000E0000;`2003i0000a`8000X10001000007/P@VL28d:[0@00CP800040001<0000
0000000000000000oooooooooom@0000@P0000/0000R000030000?oooolQ0000200001T0000<0000
oooo01P0000<0000000001h0000H00006P000140000=0`00S0400280000<0000oooooaP0000<0000
000001T0000<0000oooo02D0000<0000100002L0000H00001`000000003oool0000002D0000<0000
1`0002H0000L0000200000000001000000000000000U0000300000P0000[0000600006<1001g0P00
0`8009L2000U0000300000@0000X0000300000L0000U000030000080000X0000300000P0000W0000
600000P000000000`<300000000U0000300000P0000V0000700000L0000000000@00000000000000
9@0000`000070000:P0001P000100P00`@4006<2003R0@009@0000`000040000:00000`000080000
9@0000`000020000:00000`0000700009`0001P00007000000000?ooo`0000009@0000`000070000
9P0001`0000800000000004000000000000002D0000<0000200002X0000H0000@0800?d1001S0P00
7P8002D0000<0000100002P0000<00001`0002D0000<00000P0002P0000<0000200002L0000H0000
20000000003oool0000002D0000<0000200002H0000L00001`0000000001000000000000000U0000
300000L0000Z000060000482000k0P00I@8005`2000U0000300000@0000X0000300000P0000U0000
30000080000X0000300000L0000W0000600000L000000000oooo0000000U0000300000L0000V0000
700000P0000000000@000000000000009@0000`000080000:P0001P000120P00M@8006D2002F0P00
9@0000`000040000:00000`0000700009@0000`000020000:00000`0000800009P0001`000080000
0000004000000000000002D0000<0000200002L0000H00001`000000003oool0000002D0000<0000
1`0005H0000h0000B`8009P0001b0P00Z00000L0001G0Nl1E`7c0CX1l`4j0O/1E`7k0EL1o`5Q0OL1
9@0000`000020000:00000`0000800009@0000`000040000:00000`0000700009P0001`000070000
0000004000000000000002D0000<00001`0002D0000<00001@00P5L0000T0000``8005@000330P00
JP000080002b0L81/P6/0BD0000<00002000P2P0000<00001`0002L0000H00001`00000000000000
000002D0000<00001`0005H0000X0000`08004`000370P00E`0000<0002f0Jl1/P6T0Jl1[`4U0000
30000080000U0000300000@0000X0000300000L0000V0000700000L0000000000@00000000000000
9@0000`0000700009`0001P00008000000000?ooo`0000009@0000`000080000EP0003P0002l0P00
e0000<T2003b00001`000:/1@0:^0D02[P4Z0[D1:P:e0D02^0500[41A`8U000030000080000X0000
300000L0000U0000300000@0000X0000300000P0000U0000300000P0080W0000600000P000000000
oooo0000000U0000300000P0001F0000G0000942003o0000[@800201000@0000W05M0Y@1E0:D0EP2
T05H0XX1F@:50Ed2P@5Q0X01I`:00GD2R05e0XP1I`:90FD2R`5S0Y01HP:D0F82U05W0RD0000<0000
0P0002D0000<0000100002P0000<0000200002D0000<00002000P2L0000H00002000000000000000
000002D0000<0000200001<0000<00000P0005H0000l0000ZP8000D1002^0P002@4000P0002L0Ed2
V`5M0Y`1GP:L0Ed2W@5M0YX1FP:I0EX2V@5J0UH0000d0000Y@800?l0002Y0P000`4000H0002G0EP2
U`5H0YP1F0:E0ED2U@5D0Y@1E@9F0000C0000:<200000@00YP8000@1000<0000U@5F0Y@1E@:D0EH2
U05H0Y@1F0:D0EP2TP5H0Y81F0:B0ET2U05I0Y@1F0:E0EP2EP0003@0002L0P000`400:4200040@00
1P0008l1F@:@0EP2S`5H0X/1F0:;0ET2R`5I0UH0000d0000UP8000D1002J0P00204000H000280E/2
R@5J0XP1FP:50E`2Q@5L0XD1G@9F0000?000098200090@00U@8000d100080000Q05O0X<1GP:30El2
P@5Q0X41HP:10F82PP5R0X81H@9F0000?0000942000?0@00TP8001@100080000P@5U0X01I0:00FD2
P05W0X01J@:00FT2P@5Y0X41I`9F0000=0000942000F0@00TP8001/100060000P@5/0X01J`:00F`2
P05`0X01L0:10G02EP0004P0002A0P007@4009<2000R0@002`000841L`:00G82P05c0X01M@:00GH2
PP5f0X81M@:20GD2P05e0X01M@:10GD2EP0004P0002E0P007`4009X2000R0@002`0008D1M@:40GD2
Q@5f0XP1MP:90GD2R@5d0XP1M0:80G@2R05e0XP1M@:80GD2EP0003@0002I0P00604009X2000M0@00
1P0008P1L@:80G82R@5a0XT1K@:80Fd2R05]0UH0000l0000V@800141002J0P005P4000P000280FX2
R05[0XT1JP:90FL2R@5V0XP1IP:80FH2R05W0UH0000l0000VP8000d1002O0P003`4000P0002:0F<2
R@5T0XX1I0:;0F@2SP5S0Xh1H`:>0F82R`5S0UH000180000X@8000d1002V0P003P4000/0002A0F82
T05R0Y41H`:D0F<2U05R0Y@1HP:D0F<2U05S0YD1H`:E0F82U05R0UH0001<0000Y@8000l1002W0P00
4P4000`0002E0FH2U05U0Y@1IP:D0FL2U05W0YD1I`:F0FD2UP5T0YD1I@:D0FL2U05W0YD1I`9F0000
=0000:P2000:0@00Z`8000h100060000U`5S0YL1H`:H0F<2VP5P0YX1G`:I0F024`0000`000010000
9@0000`0000200009@0000`000040000:00000`0000800009P0001`0000800000000004000000000
000002D0000<0000200002L0000H00001`000000003oool0000002D0000<00001`0005H0001L0000
e@8000@1003f0P008P400100003J0GH2i05_0]l1KP;O0F/2g`5U0]`1G`;H0E/2dP5J0/@1F@;30F42
dP5R0]@1H`;E0FD2eP5Z0]H1KP;A0Fd29@0000`000020000:00000`0000800009@0000`000040000
:00000`0000700009P0001`0000700000000004000000000000002D0000<00001`0002D0000<0000
1@00P5L0000/0000bP800<D0001O0`00j`0000@0001=0Q/2C@8_0[T1;`:i0D429@0000`000080020
:00000`0000700009`0001P00007000000000000000000009@0000`000070000EP0002P000370P00
j@000<h2003e00000`000;H1?`:j0DX2_@4o0RD0000<00000P0002D0000<0000100002P0000<0000
1`0002H0000L00001`0000000001000000000000000U0000300000L0000U0000300000D0081G0000
900006D300390000I@<00=h000020000D`8O0U<2=08U0000300000P0080X0000300000L0000W0000
600000L00000000000000000000U0000300000L0001F0000:0000683003L0000J@<00>H000030000
D08b0U@2?09G0S829@0000`0000200009@0000`000040000:00000`0000700009P0001`000070000
0000004000000000000002D0000<00001`0002D0000<00001@00P5L0000T0000I0<000P1001T0`00
6@400080001B0Ud2DP9^0RD0000<00002000P2P0000<00001`0002L0000H00001`00000000000000
000002D0000<00001`0005H0000X0000H@<001L1001X0`008P4000<0001?0V`2DP9f0UH2K08U0000
30000080000U0000300000@0000X0000300000L0000V0000700000L0000000000@00000000000000
9@0000`0000700009@0000`000050020E`0002@0001T0`00RP0006@3002M00000P000582h@5B0_@1
9@0000`000080020:00000`0000700009`0001P00007000000000000000000009@0000`000070000
EP0002P0001Q0`00V`0006P3002U00000`0004l2lP5B0_`1EP;b0BD0000<00000P0002D0000<0000
100002P0000<00001`0002H0000L00001`0000000001000000000000000U0000300000L0000U0000
300000D0081G0000900001H3001j0000B0<007X00002000010;B0CH2dP4U0000300000P0080X0000
300000L0000W0000600000L00000000000000000000U0000300000L0001F0000:00004H3001g0000
D0<007h000030000=0;F0Ch2dP4d0/l19@0000`0000200009@0000`000040000:00000`000070000
9`0001P00007000000000?ooo`0000009@0000`0000700009P0001`0000800000000004000000000
oooo02D0000<0000200002/0000H0000J0400>h1003k0@001@8002D0000<0000100002P0000<0000
1`0002D0000<00000P0002P0000<000020000240000800007P0001P0001[0@00k`400?T100050P00
9@0000`0000300009@0000`000030000500000`0000=00004P0000`000010000E0000=00001l0P00
V@0000X3002Y00000@00001k849W0R=2J`400?01000F0000C00000000000000000000?oooooooooo
N0000580I@1c0700J@1b0640M01_0780N@0P07@0LP1Q06<0M00P02P0DP1D02T02`0000P000080000
200000<000050000200000@0000800001@0000L000040000100000D000080000200000@000040000
1@0000/0000900001@000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000400009`0001P00008000000000?ooo`0000009@0000`0000800009P0001`000070000
0000004000000000oooo02D0000<00001`0002/0000H0000L`4007d2003f0@00U08002D0000<0000
100002P0000<0000200002D0000<00000P0002P0000<00001`000240000800007P0001P0001f0@00
OP800?@1002D0P009@0000`0000500009@0000`000050000500000`0000=00004P0000`000010000
E0000<`000270P00:P4000@3000i0@000@00001k849W0R=2MP4007h2000E0000C000000000000000
00000?ooooooooooN0000580I@1c07@0801_06H0801d06P0I@0P0680K`1T07T0800X0580@P0Y0000
2@0000L000070000100000@0000700000`0000@0000400001`0000L0000400001`0000L000070000
1`0000@0000400002@0000T0000400008P0000`0003ooooo8@0000P0000I000030000?ooo`0H0000
30000000000N0000600001X0000A00003@<008`1000R000030000?oooolH000030000000000I0000
30000?ooo`0U0000300000@0000W0000600000L000000000`<300000000U0000300000L0000V0000
700000P0000000000@0000000030`<009@0000`000080000:`0001P000180P00b04005h2003H0@00
9@0000`000040000:00000`0000700009@0000`000020000:00000`0000800008@0000P0000N0000
600004/200390@00G0800=P1001B0000L04000P0003eoooo0000000000000000_08000000007000P
@@1b06T0H@1/00000000000000000000000000000000000000000000000000000000000000000000
000000004`2TB//`DPXQ6EQ^>08K1000J<hC0000002@5_Agj5lE04hFm7M81aD0JQKdMj/:<3C`GaD0
l5lE0000002hV3X22<000=3?4`1B06D0L`1d0200K`1V0200M01X06D0801R06l0I01i0200:01B0480
:@0Y0:3>4`05T?Ig000C0000002@5_AgN><i0ThFm7O821D0JQKdMc8J00R0hcT2P><i0PS0003@ca<0
oooo09S>4`04000080000000002U7lAgYAo4MlC`0@0001D0[<dC0:DOa7NU7lAga?3mO`3PoGl00000
0000000000000000`Sg4M`80001TMP08000002D0000<0000200002D0000<0000200001@0000<0000
3@000180000<00000@0005@0001H0000G@<00740001[0`00OP0000400000Nb12I`8S@T/200390@00
0P0004`00000000000000000003ooooooooooe00001C05@01`0000L0000R000030000?oooolQ0000
200001T0000<0000oooo01P0000<0000000001h0000H00006P000140000=0`00S0400280000<0000
oooooaP0000<0000000001T0000<0000oooo02D0000<0000100002L0000H00001`000000003oool0
000002D0000<00001`0002H0000L00002@0000000001000000000?ooo`0U0000300000T0000[0000
600004T200030P00GP8001L2000U0000300000@0000X0000300000L0000U000030000080000X0000
300000T0000Q0000200001h0000H0000C08000@2001L0P005`800580001`0@002@000?Goool00000
00000000002@0@00000000L002110780J@1Q06`00000000000000000000000000000000000000000
00000000000000000000000000000000000C0:A:bc1B2R4IF6hh0Q/4001XcQ<00000090Fm7L8H1D0
CQKdMdP75@1Z5_AgZ`X`=a1P5@0@H1D0P><i0X3S>@88`000d<lC05<0E02HcQ<01000020000000000
YAo4MjDOa7O4l040000E0:c=4`2U7lAgYAo4MlC`oGl001<00000090Fm7M`/cP2CQKdMnP65@1Z5_Ag
S1/027Rc>09h/cP22<000=3?4`3oool0V<hC00@0000P000000000:DOa7NU7lAga?0100005@2/cA<0
YAo4MjDOa7O4l?eo0>3mO`0000000000000000000032?LAg0P0006Af00P000009@0000`000090000
9@0000`000090000500000`0000=00004P0000`000010000E00005P0001N0`00[@0006H3002j0000
0@00001k849W0R=2C08000@200020000C00000000000000000000?ooooooooooD00005<0B@070000
0P000280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J0000
4@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000040000
9`0001P00007000000000?ooo`0000009@0000`0000700009P0001`0000:00000000004000000000
oooo02D0000<00002P0002/0000H0000B08004@2001M0P00F08002D0000<0000100002P0000<0000
1`0002D0000<00000P0002P0000<00002P000240000800007P0001P0001;0P00A@8005/2001H0P00
9@0000`0000900009@0000`000090000500000`0000=00004P0000`000010000E0000600001M0`00
l00006`3003m00000@00001k849W0R=2B`8004D200030000C00000000000000000000?oooooooooo
E00005D0C01900001`0000H0000200008P0000`0003ooooo8@0000P0000I000030000?ooo`0H0000
30000000000N0000600001X0000A00003@<008`1000R000030000?oooolH000030000000000I0000
30000?ooo`0U0000300000@0000W0000600000X000000000oooo0000000U0000300000X0000V0000
700000L0000000000@000000003oool09@0000`000070000:`0001P000190P00O08005h2002@0P00
9@0000`000040000:00000`0000:00009@0000`000020000:00000`0000700008@0000P0000N0000
600004`2001m0P00G0800902000U0000300000T0000U0000300000T0000D0000300000d0000B0000
30000040001D0000H00005h3000Y0@00K0<003H10001000007/P@VL28d9<0P00O@8000<0001<0000
0000000000000000oooooooooomD0000C01<04T0000600001P000080000R000030000?oooolQ0000
200001T0000<0000oooo01P0000<0000000001h0000H00006P000140000=0`00S0400280000<0000
oooooaP0000<0000000001T0000<0000oooo02D0000<0000100002D0000<00002000P2L0000H0000
1`00000000000000000002D0000<00001`0001<0000<00000P0005H0000d0000Z0800?d0002/0P00
oP0000H0002K0E<2V`5B0Y/1DP:G0E82U`5B0YL1D`9F0000=0000:42003m0000Y@800?h000060000
U05C0Y@1DP:D0E82T05B0Y01DP:@0E<2EP0003@0002J0P00o@0009h2003n00001P0008d1D`:=0E82
S@5B0XT1DP:90E82R@5C0UH0000d0000T`800?d0002G0P00oP0000H000260E<2QP5B0XH1DP:20E82
PP5B0X81D`9F0000=00008`2003m0000T0800?h000060000O`5C0Wl1DP9o0E82N`5B0W/1DP9k0E<2
EP0003@000250P00o@0008T2003n00001P0007P1D`9h0E82N05B0W@1DP9d0E82M05C0UH0000d0000
OP800?d000220P00oP0000H0001a0E<2L@5B0W41DP9]0E82K@5B0Vd1D`9F0000=00007L2003m0000
N`800?h000060000JP5C0VX1DP9Z0E82IP5B0VH1DP9V0E<2EP0003@0001`0P00o@0007@2003n0000
1P0006<1D`9S0E82H`5B0Ul1DP9O0E82G`5C0UH0000d0000J@800?d0001]0P00oP0000H0001L0E<2
G05B0U`1DP9H0E82F05B0UP1D`8C000030000040001F0000:0000642003j0000K080004100030000
F`5?0U01DP9K0EH29@0000`0000200009@0000`000040000:00000`0000700009P0001`000070000
0000004000000000000002D0000<00001`0002D0000<00001@00P5L0000T0000I0<00481001U0`00
DP400080001C0YH2DP:V0RD0000<00002000P2P0000<00001`0002L0000H00001`00000000000000
000002D0000<00001`0005H0000X0000H@<00501001X0`00F`4000<0001?0Z@2DP:^0UH2Y08U0000
30000080000U0000300000@0000X0000300000L0000W0000600000L000000000oooo0000000U0000
300000L0000V0000700000X0000000000@000000003oool09@0000`0000:0000:`0001P0000T0@00
B`8004T1001L0P009@0000`000040000:00000`0000700009@0000`000020000:00000`0000:0000
8@0000P0000N0000600002L1001<0P00A`4005`2000U0000300000D0000U0000300000D0000D0000
300000d0000B000030000040001D0000K00003P2003g0000EP8000H10001000007/P@VL28d8W0@00
C08000D0001<00000000000000000000oooooooooomH0000E@1b06T0KP1U00002@0000@000030000
1`0000L0000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H0000
6P000140000=0`00S0400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000
100002L0000H00002P000000003oool0000002D0000<00002P0002H0000L00001`00000000010000
00000?ooo`0U0000300000L0000[0000600003P2002c0P00JP800<L2000U0000300000@0000X0000
300000X0000U000030000080000X0000300000L0000Q0000200001h0000H0000>`800;@2001X0P00
a`8002D0000<00001@0002D0000<00001@0001@0000<00003@000180000<00000@0005@0001`0000
C@<00641001h0`00L04000400000Nb12I`8S@S/2002d0P001P0004`00000000000000000003ooooo
oooooeP000160640I@1S06D0L`0800001`0000L0000700001`0000L0000R000030000?oooolQ0000
200001T0000<0000oooo01P0000<0000000001h0000H00006P000140000=0`00S0400280000<0000
oooooaP0000<0000000001T0000<0000oooo02D0000<0000100002L0000H00001`000000003oool0
000002D0000<00001`0002H0000L00002P0000000001000000000?ooo`0U0000300000X0000[0000
600008X1002C0@00h`400:<1000U0000300000@0000X0000300000L0000U000030000080000X0000
300000X0000Q0000200001h0000H0000S@4009@1003Q0@00X`4002D0000<00001@0002D0000<0000
1@0001@0000<00003@000180000<00000@0005@0002@0000WP8003/0003U0P00BP0000400000Nb12
I`8S@Xd1002D0@002`0004`00000000000000000003oooooooooof@0001506h0MP1Y0780K`1^06d0
I@1^07@0000900001`0000D000030000100000L0000700002`0000L00007000010000280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000400009P0001`0000:0000
0000004000000000000002D0000<00002P0002D0000<00001@00P5L0000T0000c`800?L0001<0`00
m`000080002n0D`2>P9<0RD0000<00002000P2P0000<00002P0002L0000H00002P00000000000000
000002D0000<00002P0005H0000X0000BP<00?@0001D0`00n`0000<0000h0U02@P9<0SP2B@8U0000
30000080000U0000300000@0000X0000300000X0000U0000300000P0080W0000600000X000000000
00000000000U0000300000X0000C000030000080001F0000=00001D3000c0@006@<003@100060000
0`:70P<2Q`830XP21`:80PL2Q`870XL2EP0003@0000K0`00<`400203000d0@001P0000X2Q`890XL2
2P:80Ph2R08>0XL23P:70UH0000d00008P<003<1000W0`00=04000H0000A0XL240:70Q42R08E0XP2
5@:70QD2Q`9F0000=00002T3000c0@00;P<003@10006000060:70QL2Q`8H0XP270:80Q`2Q`8L0XL2
EP0003@0000`0`00<`4003D3000d0@001P0001l2Q`8N0XL27`:80R<2R08S0XL28`:70UH0000d0000
=`<002h1000h0`00<P4000H0000U0XH29@:60RH2QP8V0X829@:20RD2PP9F0000=00003L3000W0@00
>0<002/1000600009@9o0RD2O`8V0Wl29P9k0RD2N`8U0W/2EP0003@0000g0`007`4003P3000T0@00
1P0002D2N08U0WP29P9h0RH2M08U0W@29@9d0UH0000d0000=`<001P1000h0`00704000H0000U0W42
9@9a0RH2L@8V0Vd29@9]0RD2K@9F0000=00003L3000A0@00>0<001D1000600009@9Z0RD2JP8V0VX2
9P9V0RD2IP8U0VH2EP0003@0000g0`002P4003P3000>0@001P0002D2H`8U0V<29P9S0RH2G`8U0Ul2
9@9O0UH0000d0000=`<000<1000h0`001`4000H0000U0U`29@9L0RH2G08V0UP29@9H0RD2F09F0000
=00003P300020@00?@<000<1000600009`9G0RH2E`8W0UP2:`9H0R/2E`8[0UL2EP0003@0000o0`00
0P4004@300030@001P0002h2E`8]0UL2;P9H0S82F08b0UL2<P9G0UH0000d0000AP<00081001;0`00
0`4000H0000e0UL2=09G0SD2F08i0UP2>@9G0ST2E`9F0000=00004d300020@00DP<000<100060000
?09G0S/2E`8l0UP2@09H0T02E`900UL24`0000`000010000EP0002P0001@0`00o`0005X300060@00
0`0003h2F`980UP2?P9D0RD0000<00000P0002D0000<0000100002P0000<00002P0002D0000<0000
2000P2L0000H00002P00000000000000000002D0000<00002P0001<0000<00000P0005H0000d0000
=`<00?h0000h0`000P4000H0000U0UL29@9G0RH2E`8V0U<29@9C0RD2D`9F0000=00003L3003g0000
>0<00?/0000600009@9@0RD2D08V0U029P9<0RD2C08U0T`2EP0003@0000g0`00l00003P3003d0000
1P0002D2B@8U0TT29P990RH2A@8U0TD29@950UH0000d0000=`<00>P0000h0`00k@0000H0000U0T82
9@920RH2@P8V0Sh29@8n0RD2?P9F0000=00003L3003Q0000>0<00>D0000600009@8k0RD2>`8V0S/2
9P8g0RD2=`8U0SL2EP0003@0000g0`00fP0003P3003N00001P0002D2=08U0S@29P8d0RH2<08U0S02
9@8`0UH0000d0000=`<00=<0000h0`00e`0000H0000U0Rd29@8]0RH2;@8V0RT29@8Y0RD2:@9F0000
=00003L3003<0000>0<00=00000600009@8V0RD29P8V0RH29P8R0RD28P8U0R82EP0003@0000g0`00
a@0003P3003900001P0002D27`8U0Ql29P8O0RH26`8U0Q/29@8K0UH0000d0000=`<00;h0000h0`00
`P0000H0000U0QP29@8H0RH2608V0Q@29@8D0RD2509F0000C00003L3002h0000>0<00;/0000<0000
9@8A0RD24@8V0Q429P8>0RD23P8U0Pl29P8?0RH23P8V0Ph29@8>0RD23P8U0Ph2EP0003@0000j0`00
^00003l3002i00001P0002T23P8X0Ph2:@8?0Rd23`8]0Ph2;@8>0UH0000d0000@@<00;P000160`00
^@0000H0000`0Ph2;`8>0S023`8d0Pl2=08>0S@23P9F0000=00004P3002h0000B`<00;T000060000
=`8>0SH23P8g0Pl2>@8?0ST23P8i0Ph24`0000`000010000EP0002P000190`00]00005@3002l0000
0`0003L24P920Ph2=`8;0RD0000<00000P0002D0000<0000100002P0000<00002P0002D0000<0000
2000P2L0000H00002P00000000000000000002D0000<00002P0001<0000<00000P0005H0000d0000
L08003<1001d0P00=04000H0001S0HP2H`670V<1Q`9O0HL2G`670Ul1R09F0000=00006T2000c0@00
K@8003@100060000G0680U`1Q`9L0HL2F0670UP1Q`9H0HP2EP0003@0001R0P00<`4006H2000d0@00
1P0005D1R09E0HL2E@670U41Q`9A0HL2D@680UH0000d0000F`8003<1001O0P00=04000H0001>0HP2
CP670Th1Q`9:0HL2BP670TX1R09F0000=00005@2000c0@00F08003@100060000A`680TL1Q`970HL2
@`670T<1Q`930HP2EP0003@0001=0P00<`400542000d0@001P000401R0900HL2@0670S`1Q`8l0HL2
?0680UH000180000B0800341001:0P00=04000/0000i0HP2>@670ST1Q`8g0HL2=`670SP1Q`8h0HD2
=`650SL1Q@8g0HL2=`680UH0000d0000B08002X100190P00;P4000H0000g0H82=`620SP1PP8h0Gh2
=`5n0SL1OP9F0000=00004P2000S0@00B@8002L100060000=`5k0SL1N`8h0G/2>05g0SL1M`8g0GL2
EP0003@000180P006`4004T2000O0@001P0003L1M08g0G@2>05d0SP1L08g0G02=`5`0UH0000d0000
B08001@100190P00604000H0000g0Fd2=`5]0SP1K@8h0FT2=`5Y0SL1J@9F0000=00004P2000?0@00
B@80014100060000=`5V0SL1IP8h0FH2>05T0SL1I08g0F@24`0000`000010000EP0002P000150P00
1`4004`2000B0@000`0003/1I`8h0E`2=05W0RD0000<00000P0002D0000<0000100002P0000<0000
2P0001P0000<0000000001T0000<0000oooo02D0000<000010000280000<0000ooooobD0000<0000
1`00P2D0000<00000000P300000<00003`00P2D0000<00003@00P4/0000@0000000000D0000X0000
30000080000X0000300000<0000X0000300000@0000X0000300000D0000X0000300000H0000X0000
300000P0000X0000300000T0000U000030000000080U0000300000L0080R000030000?oooolU0000
300000d0080X000030000040000R000030000?oooolR000030000?oooom60000>00002`00015CDH[
9T00010000040000000002501`0<0000000000A0000<0000000004H0000D0000200004M4BD<30000
600000`0000000006@0000`0003oool09@0000`0000000209@0000`0000=00208P0000`0003ooooo
AP0003@0000X0000ADe6:bY0000T000060000000P3l000200000P000P3l000200000P24000080000
HP0000`000010000C00006@0000e0P00<0000883001d0@00=@800300001>0@00A@4002T0ZP000000
00000000P3l0000000000000P3l000000000000000000000000000000000000000000280000<0000
ooooodH0000L0000400004E=AR/2@00030000000000>000050000000000@00005000
\>"], "Text",
  ImageSize->{333, 324},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Figure 2:",
    FontWeight->"Bold"],
  " General  model (ICRP78 and GI tract, according ICRP 30). "
}], "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Downloading and starting the package", "SubsectionIcon"],

Cell[BoxData[
    \(Off[General::spell1]; Off[General::spell];\)], "Input",
  CellLabel->"In[2]:="],

Cell[TextData[{
  "This loads the package (it is also autoloaded the packages ",
  StyleBox["Master",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Resptract",
    FontSlant->"Italic"],
  " and ",
  StyleBox["SysModel",
    FontSlant->"Italic"],
  ")."
}], "MathCaption",
  CellTags->"Introduction"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Needs["\<Biokmod`Humorap3`\>"]\)], "Input",
  CellLabel->"In[3]:=",
  CellTags->"Introduction"],

Cell[BoxData[
    \("Resptract 1.2 b1 2005-05-16"\)], "Print",
  CellLabel->"From In[3]:=",
  CellTags->"Introduction"],

Cell[BoxData[
    \("SysModel, guillermo@usal.es, version 1.3.   2005-08-24"\)], "Print",
  CellLabel->"From In[3]:=",
  CellTags->"Introduction"],

Cell[BoxData[
    \("Humorap 3.3 b1 2005-06-17"\)], "Print",
  CellLabel->"From In[3]:=",
  CellTags->"Introduction"]
}, Open  ]],

Cell["\<\
 Help can be obtained as usual, or  via \
toolbar\[Rule]Help\[Rule]AddOns\[Rule]Biokmod  \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?"\<Biokmod`Humorap3`*\>"\)\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[GridBox[{
        {
          StyleBox["Biokmod`Humorap3`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["BioassayReport",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345388266-8160970", 
                    "Biokmod`Humorap3`BioassayReport"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Humorap3`"], 
                ButtonBox[
                  StyleBox["qGI",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345388266-8160970", 
                    "Biokmod`Humorap3`qGI"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Humorap3`"], 
                ButtonBox[
                  StyleBox["qInhalationE",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345388266-8160970", 
                    "Biokmod`Humorap3`qInhalationE"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Humorap3`"], 
                ButtonBox[
                  StyleBox["qRT",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345388266-8160970", 
                    "Biokmod`Humorap3`qRT"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Humorap3`"], ""},
              {
                ButtonBox[
                  StyleBox["BioassayReportE",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345388266-8160970", 
                    "Biokmod`Humorap3`BioassayReportE"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Humorap3`"], 
                ButtonBox[
                  StyleBox["qIngestion",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345388266-8160970", 
                    "Biokmod`Humorap3`qIngestion"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Humorap3`"], 
                ButtonBox[
                  StyleBox["qInjection",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345388266-8160970", 
                    "Biokmod`Humorap3`qInjection"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Humorap3`"], 
                ButtonBox[
                  StyleBox["qRTandGI",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345388266-8160970", 
                    "Biokmod`Humorap3`qRTandGI"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Humorap3`"], ""},
              {
                ButtonBox[
                  StyleBox["icrp30Model",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345388266-8160970", 
                    "Biokmod`Humorap3`icrp30Model"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Humorap3`"], 
                ButtonBox[
                  StyleBox["qIngestionE",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345388266-8160970", 
                    "Biokmod`Humorap3`qIngestionE"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Humorap3`"], 
                ButtonBox[
                  StyleBox["qInjectionE",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345388266-8160970", 
                    "Biokmod`Humorap3`qInjectionE"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Humorap3`"], 
                ButtonBox[
                  StyleBox["qWholebody",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345388266-8160970", 
                    "Biokmod`Humorap3`qWholebody"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Humorap3`"], ""},
              {
                ButtonBox[
                  StyleBox["qContinuous",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345388266-8160970", 
                    "Biokmod`Humorap3`qContinuous"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Humorap3`"], 
                ButtonBox[
                  StyleBox["qInhalation",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345388266-8160970", 
                    "Biokmod`Humorap3`qInhalation"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Humorap3`"], 
                ButtonBox[
                  StyleBox["qRandom",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345388266-8160970", 
                    "Biokmod`Humorap3`qRandom"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Humorap3`"], 
                ButtonBox[
                  StyleBox["qWholebodyE",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345388266-8160970", 
                    "Biokmod`Humorap3`qWholebodyE"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Humorap3`"], ""}
              },
            RowMinHeight->{1, 1, 1, 1.05}]}
        },
      RowSpacings->{2, 3},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->RGBColor[0.964706, 0.929412, 0.839216],
  ButtonBoxOptions->{Active->True},
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Open  ]],

Cell[TextData[{
  "Specific information about package functions can be obtained from Help \
browser or with ",
  StyleBox["?Function .", "Input"],
  " For example:"
}], "MathCaption",
  CellTags->"Introduction"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?qContinuous\)\)], "Input",
  CellLabel->"In[5]:=",
  CellTags->"Introduction"],

Cell[BoxData[
    \("qContinuous[continuous,input-inpulse,t,t1] gives the  amount \
(activity, mass, etc) in one compartment or region (i.e Lungs) of  \
ICRP66-Extended system for a continuous intake b(t) during a time t1 where is \
 known the retention function for a single intake 1 in t=0 (it can be  \
calculated using AcuteInput)."\)], "Print",
  CellTags->{"Info3345388266-5846447", "Introduction"}]
}, Open  ]],

Cell["\<\
Information about options,  including the default values, can be shown.\
\>", "MathCaption",
  CellTags->"Introduction"],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(Options[qInjection]\),
      "Input"]], "Input",
  CellLabel->"In[6]:=",
  CellTags->"Introduction"],

Cell[BoxData[
    \({IntakeType \[Rule] "Acute", k\_ULI \[Rule] 1.8`, 
      k\_LLI \[Rule] 1}\)], "Output",
  CellLabel->"Out[6]=",
  CellTags->"Introduction"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(Options[qRT]\),
      "Input"]], "Input",
  CellLabel->"In[7]:=",
  CellTags->"Introduction"],

Cell[BoxData[
    \({fAI1 \[Rule] 0.3`, fAI2 \[Rule] 0.6`, fAI3 \[Rule] 0.1`, 
      fbs \[Rule] 0.007`, fBs \[Rule] 0.007`, fet2 \[Rule] 0.9995`, 
      k\_"AI1,bb1" \[Rule] 0.02`, k\_"AI2,bb1" \[Rule] 0.001`, 
      k\_"AI3,bb1" \[Rule] 0.0001`, k\_"AI3,TH" \[Rule] 0.00002`, 
      k\_"bb1,BB1" \[Rule] 2, k\_"bb2,BB1" \[Rule] 0.03`, 
      k\_"bbseq,TH" \[Rule] 0.01`, k\_"BB1,ET2" \[Rule] 10, 
      k\_"BB2,ET2" \[Rule] 0.03`, k\_"BBseq,TH" \[Rule] 0.01`, 
      k\_"ET2,ST" \[Rule] 100, k\_"ETseq,ET" \[Rule] 0.001`, 
      k\_Env \[Rule] 1}\)], "Output",
  CellLabel->"Out[7]=",
  CellTags->"Introduction"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?fAI1\)\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \("Fraction of deposition factor fAI1 = AI1/AI"\)], "Print",
  CellTags->"Info3345388266-7899843"]
}, Open  ]],

Cell["It is applied the follow notation", "MathCaption",
  CellTags->"Introduction"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        StyleBox[\(I\_0\),
          "Input"], TextForm]]],
  "\tSingle intake, in units of activity or mass,  in ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " = 0 of a specific nuclide.\n",
  StyleBox["\[Lambda]", "Input"],
  StyleBox["\t ", "Input",
    FontWeight->"Plain"],
  "Nuclear decay constant of the nuclide , ",
  Cell[BoxData[
      \(TextForm\`in\ days\^\(-1\)\)]],
  ".\n",
  StyleBox["t",
    FontWeight->"Bold"],
  "\tTime  in days."
}], "DefinitionBox3Col",
  CellTags->"Introduction"]
}, Closed]],

Cell[CellGroupData[{

Cell["Package functions", "SubsectionIcon"],

Cell[TextData[{
  "The first step for solving any compartmental model is to define the \
compartmental matrix. It can be built by the user or loading the package ",
  StyleBox["Biokdata", "Input"],
  " (see Help) where are included the compartmental matrix for a almost all \
Current ICRP elements. "
}], "Text"],

Cell[TextData[{
  "The compartment matrix can be made by users with ",
  StyleBox["CompartMatrix", "Input"],
  " function of package ",
  StyleBox["SysModel", "Input"],
  " (it is autoloaded with ",
  StyleBox["Humorap", "Input"],
  ", see Help). "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?CompartMatrix\)\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \("CompartMatrix[n,{transcoeff},lambda], gives the matrix of \
coefficients,also called  constant transfer coefficients matrix.  Where n \
isthe number of compartments and transcoeff are the transfer coefficients, \
also  called clearance coeffs. or dissolution rates. They are given as  \
{{..{i,j,kij},{..},...} where kij is the transfer coeff., in \!\(t\^-1\),.  \
from compartment i to compartment j (By default kij = 0); lambda is the  \
radioactive decay constant, in the same unit as the trans. coef. (by default \
lambda = 0, which  means thatit is not a radioactive substance.)"\)], "Print",\

  CellTags->"Info3345388266-2320785"]
}, Open  ]],

Cell["\<\
For defining compartmental matrix  for all body usually should be applied the \
ICRP 78 models adding  the compartments ULI\[Rule]LLI\[Rule]FEC (ICRP 30).   \
It is included all the GI Tract system, it can be two situation (depending of \
the element modeled). a) There are not recycling throw SI  or b) There are \
recycling throw SI.\
\>", "Text"],

Cell[TextData[{
  "For more details read the author paper: Sanchez G and Lopez-Fidalgo J.,  \
",
  StyleBox["Mathematical",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" techniques for solving analytically large compartmental systems",
    
    FontSlant->"Italic"],
  ". Health Phys. 85 (2). August 2003."
}], "Text"],

Cell[TextData[{
  "The compartmental matrix mush be defined as it shows in Fig. 3 . In theses \
cases it can be applied ",
  StyleBox["qInhalation, qIngestion ", "Input"],
  "and",
  StyleBox[" qInjection ", "Input"],
  StyleBox["to obtain the retention in each compartment of the model as \
function of time t, in days. If you are interested in the Lung retention, \
daily urine and faecal excretion the function ",
    FontWeight->"Plain"],
  StyleBox["BioassayReport", "Input"],
  StyleBox[" should be applied.(see Humorap Help)",
    FontWeight->"Plain"]
}], "Text"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0003:X0@0006@000000000000000d1002m0000
00000000000`:P00/1d00215CDH00040Z3800>0100060000000000000000000080<005P200100@00
l000000000000000000001P0000<0000000001T0000<0000oooo01@0000<00003@000180000<0000
0P000240000800002P000100001A1@00cP0000T0000@00003P400;h0000D0000300000d0000`0000
300000l008160000:00001`00017A4U30P000545003>0000G`H008`1000000009`0001P000010000
00000?ooo`0000009@0000`0000100009P0001`0000200000000004000000000oooo0RD0000<0000
0P0002/0000H000090H00<h0001N1P00i`0002D0000<00000000P2P0000<00000@0002D0000<0000
1`00P2P0000<00000P000240000800007P0001P0000W1P00c`0005`6003W0000DP0004`100020000
lOooo`0000000000000009010000000000008440LP1Y0640K0000000000000000000000000000000
000000000000000000000000000000000000000000000?oo0000000000000000T04000000000000P
@@1b06T0H@1/00000000000000000000000000000000000000000000000000000000000000000000
0000013<lgOooooo00290S1?eS00<020cR7aMfONSC2407/07E[]M`002S1L0000D;PB03Bh4P1b904`
J0<:<5`0001@^180B;TB064000247P00lOooo`L00000000000000901000000000000000000000000
0000000000010@410@410@410C0U000030000080000U000030000080000B000030000040001D0000
O0000=H0000200001040018000010000000P@P00848W1P00d00000P0001<00000000000000000000
oooooooooomL0000A`190200M01b0640H`1d00/000030000100000@000050000200000P000040000
8P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A0000
3@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U00003000000008160000
:00001`00017A4U30P0002D6003[0000G0H006T1000000009@0000`0000800209`0001P000010000
00000?ooo`0000009@0000`0000100009@0000`000010000C00006@0003H00008@0000H1002F0000
:@H00>l0000_0000MP000240l000000000000000P3l0000000000000P3l000000000000000000000
0000000000000000000002D0000<00000@0002D0000<00001`00P2D0000<00000000P2P0000<0000
0@0002D0000<00002000P2L0000H00000@00000000000000000002D0000<00000@0001<0000<0000
0P0005H0000/0000f0000240003I0000:@0000@0000Z1^l0:@K_02T6m`0Z1_L0EP0002`0003H0000
;0000=T0000]0000100002X6nP0Y1_X0:@Kk02X6n`1F0000;0000=P0000`0000f@0003P000040000
:PKn02T6oP0Y1PH1:PH60EH0000/0000f00003/0003I0000?00000@0000Z1PT1:@H90BT62P4Z1PX1
EP0002`0003H0000?`000=T000170000100002X63@4Y1Pd1:@HE0BX65@5F0000;0000=P0001:0000
f@0004/000040000:PHH0BT6604Y1QT1:PHI0EH0000/0000f00004h0003I0000EP0000@0000Z1Q`1
:@HL0BT6904Z1R@1EP0002`0003H0000F@000=T0001J0000100002X69`4Y1RL1:@HX0BX6:05F0000
;0000=P0001M0000f@0006D000040000:PH[0BT6:`4Y1S<1:PHc0EH0000/0000f00006P0003I0000
J@0000@0000Z1SH1:@Hf0BT6=`4Z1SL1EP0002`0003H0000K0000=T0001d0000100002X6>P4Y1SX1
:@I20BX6@P5F0000;0000=P0001g0000f@0007P000040000:PI50BT6A@4Y1TH1:PI60EH0000/0000
f00007/0003I0000P`0000@0000Z1TT1:@I90BT6D@4Z1U41EP0002`0003H0000QP000=T000270000
100002X6E04Y1U@1:@IE0BX6E@5F0000;0000=P0002:0000f@00098000040000:PIH0BT6F04Y1V01
:PIP0EH0000/0000f00009D0003I0000UP0000@0000Z1V<1:@IS0BT6I04Z1V@1EP0002`0003J0000
U`000>80002H0000100002/6I@4[1VH1<`IV0C<6I@5F0000;0000>D0002G0000iP0009P000040000
=PIU0CH6IP4g1VH1=`IU0EH0000/0000j@0009L0003a0000V00000@0000j1VD1>PIV0D86IP521VD1
EP0002`0003d0000U`000?D0002H0000100004D6I@551VH1APIV0DH6I@5F0000;0000?P0002G0000
004009P000040000B@IU0DT6IP5A1VH1D@IU0EH0000/00000`4009L000040@00V00000@0001D1VD1
E0IV0ED6IP5E1VD1EP0002`000070@00S`0000P1002G0000100005P6I@5I1VD1F@IM0EP6G@5F0000
;00000L1002;0000204008`000040000F0IJ0ET6FP5I1UT1F0II0EH0000/00001`40080000080@00
R00000@0001H1UH1F@IF0ET6CP5H1Th1EP0002`000070@00O00000P1001m0000100005P6B`5I1T/1
F@I:0EP6BP5F0000;00000L1001a0000204007T000040000F0I70ET6A`5I1Sl1F0Ho0EH0000/0000
1`4006d000080@00KP0000@0001H1S`1F@Hl0ET6>`5H1S/1EP0002`000070@00HP0000P1001Z0000
100005P6>05I1SP1F@H`0EP6<05F0000;00000L1001N0000204005l000040000F0H]0ET6;@5I1R`1
F0H/0EH0000/00001`4005<000080@00F`0000@0001H1RT1F@HY0ET68@5H1R41EP0002`000070@00
C`0000P1001@0000100005P67P5I1Qh1F@HM0EP67@5F0000;00000L100140000204004`000040000
F0HJ0ET66P5I1Q81F0HB0EH0000/00001`40040000080@00@@0000@0001H1Pl1F@H?0ET63P5H1Ph1
EP0002`000070@00=@0000P1000m0000100005P62`5I1P/1F@H30EP60`5F0000;00000L1000a0000
2040038000040000F0H00ET6005I1_l0F0Ko05H0000/00001`4002H000080@00;P0000@0001H1_`0
F@Kl05T6m01H1_@0EP0002`000070@008P0000P1000S0000100005P6l@1I1_40F@K`05P6l01F0000
;0000?d0000Q00001@40028000040000EPK`05H6k`1>1^l0CPK`05H0000/0000n@000240003j0000
8P0000@0001;1_00B`K_04X6k`1:1_00EP0002`0003^00008@000?H0000R0000100004L6l0171^l0
?`K_03l6l01F0000;0000>X0000Q0000j`00028000040000?0K`03`6k`0k1^l0>`K`05H0000/0000
g`000240003W00008P0000@0000h1_00>0K_0306k`0`1_00EP0002`0003K00008@000=`0000R0000
100002d6l00]1^l0;0K_02`6l00C000030000040000U0000300000L0080U000030000000080X0000
3000004000160000500000P00017A4U30`0002L0000H00000@000000003oool0000002D0000<0000
0@0002H0000L00000`0000000001000000000000008U0000300000<0000Z0000600008`5000:0@00
/PD00301000U000030000000080X000030000040000U0000300000L0080X0000300000<0000Q0000
200001h0000H0000U@D00141002Z1@00:P400580001<0@000`000??oool0000000000000002@0@00
0000000000110780J@1Q06`000000000000000000000000000000000000000000000000000000000
0000000000000000003oo`000000000000000;`20000000000000440LP1Y0640K000000000000000
00000000000000000000000000000000000000000000000000000000000600008`000000000@0000
3@0000<000030000000001eJkGL000[mG00006c]4P1@kA80LR@1<=T32_eL0000K>dB0840001lka80
0000073^4P050000I0800000003B9^eg000000000000000000000000000000000@410@410@410@4`
9@0000`0000300009@0000`0000200009@0000`0000300009@0000`0000200009@0000`000030000
500000`0000=00004P0000`000010000E00005@000140000A@0004L0001D00000@00000084800212
U@D001<100010000C00000000000000000000?ooooooooooD0000200000400009@0000`000020000
E00005@000180000A0000540001D00000@00000084800212V@D0018100010000C000000000000000
00000?ooooooooooD0000480000:00008P0000`0003ooooo8@0000P0000I000030000?ooo`0H0000
30000000000N0000600001X0000A00003@<008`1000R000030000?oooolH000030000000000I0000
30000?ooo`0U000030000000080W00006000004000000000oooo0000000U000030000040000V0000
700000@0000000000@000000000000029@0000`000040000:`0001P0001A1@00>`400?45001K0@00
9@0000`000000020:00000`0000100009@0000`000070020:00000`0000400009`0001P000040000
00000?ooo`0000009@0000`0000400009P0001`000010000000000400000000000000RD0000<0000
0@0002X0000H0000<0H00?l0001C1P00804002D0000<00000000P2P0000<0000100002D0000<0000
1`00P2P0000<00000@0002L0000H00000@000000003oool0000002D0000<00000@0002H0000L0000
100000000001000000000000008U0000300000@0000Z000060000306000i0@00D`H005X1000U0000
30000000080X000030000040000U0000300000L0080X0000300000@000160000:00001`00017A4U3
0P0009P5003]0000Z0D000d100000000G`0003@000040000=0000000000d0000000000000@010000
0000000000000000000002D0000<0000100002L0000H00000@000000003oool0000002D0000<0000
0@0005H0000h0000AP0001h0001G0000?`0000L0002I1@@1W0D40I`5kP2S1Nh0X`D40JH5106O1@/1
9@0000`000070020:00000`0000400009@0000`000000020:00000`000010000AP0001@000080000
AdA9@`<000160000:00001`00017A4U30P0006d5000G0@00S@D003`1000000009@0000`000080020
9`0001P00001000000000?ooo`0000009@0000`000010000>`0000P0000K0000400008X5000Q0@00
F@0002P00000000000000?oooooooooo0`00088560621A`1OPDL0EP0000X000000000000003ooooo
ooooo`<0001e1A`1KPDS0Fh5:`5I0000:000000000000000ooooooooool30000KPDi0GH5>@5f1B/1
F00002P00000000000000?oooooooooo0`0007H5:05j1BH1OPDV0ET0000T000000000000003ooooo
ooooo`8000221BH1PPD[0Cd000080000?00000P0000n0000600001d0001:0000>@0006/0000U0000
300000L0080U000030000000080X000030000040000U0000300000P0080W00006000004000000000
00000000000U000030000040000C000030000080001F0000?00003H0001@0000>P0005@000080000
RPDQ0HT58@6:1B81RPDQ0H/58@681Ah1Q`DN0HL57P5F0000=0000340001:0000=@0004h000060000
Q@DL0HD570661A`1P`DI0H<560621AT1EP0004`0000_0000B`000380001?0000300008<56P621AT1
PPDJ0H8570621A`1PPDL0H0570601A`1P0DM0H857@621A`1P`DL0EH0000d0000:00004h0000]0000
C`0000H0001m1Ad1OPDL0Gd5705i1A`1N@DM0GT57@5F0000=0000280001@00009P0005<000060000
MPDO0GL57P5f1Ah1L`DP0G<5805c1B41EP0003`0000N0000E0000240001H0000200007858`5a1B81
L@DS0Fl59@5_1BH1K`DV0G059P5`1BD1EP0003`0000M0000FP0001h0001O0000200006l5:@5^1BP1
KPDY0Fh5:`5^1Bd1KPD]0Fl5;@5_1B/1EP0003@0000M0000H@0001h0001V00001P0006l5<05^1Bl1
KPD`0Fh5=05^1C@1K`Dd0EH0001800007@0006P0000O0000K00000/0001_1CL1KPDf0Fh5=`5^1CT1
KPDj0G05>P5`1CT1L0Di0Fh5>@5^1CT1K`Di0EH0001800008@0006X0000V0000K00000/0001c1CT1
LPDi0G<5>P5f1CX1M`Di0GL5>05f1CP1MPDh0GH5>@5f1CT1MPDi0EH0000d00009@0006<0000V0000
J00000H0001f1CD1MPDf0GL5=@5g1C41MPDa0GH5<@5F0000?00002D0001L00009P00064000080000
MPD^0GH5;`5g1Bh1M`D[0GL5:P5f1BX1MPDZ0GH5:`5F0000?00002H0001H0000:`0005X000080000
N0DW0GL5:05h1BP1N@DX0G`59`5l1BL1O0DV0GT59`5F0000B00002d0001H0000<P0005T0000;0000
O`DV0Gh59P5o1BL1PPDW0H859P621BH1PPDW0H859`631BL1P`DV0H859P5F0000C0000340001J0000
<`0005d0000<0000P`DZ0H85:@621BX1PPD[0H85:`631B/1Q0DY0H@5:0631BT1PPD[0H85:`631B/1
EP0003@0000d0000E@0003L0001I00001P0008D59`651BL1QPDW0HP590681B<1Q`DT0A<0000<0000
0@0002D0000<00001`00P2D0000<00000000P2P0000<00000@0004H0000D0000200004M4BD<30000
AP0002P0000L0000AdA9@`80002`1@0070400=D5000m0@00000005l0000d00000@0003@000000000
=0000000000000400@0000000000000000000000000U000030000040000W0000600000@000000000
oooo0000000U0000300000@0000k0000200001/0000@0000b0D003X1001I0000:000000000000000
ooooooooool30000dPDc0Ld5<P7=1Bl1F00002P00000000000000?oooooooooo0`000<h59P781Ah1
`0DN0ET0000X000000000000003oooooooooo`<0002b1Ad1/@DU0L059P5H0000:000000000000000
ooooooooool30000`PDV0L@5:P741Bh1F@0002@00000000000000?oooooooooo0P000<@5<P6o1C41
?@0000P0000l0000200003l0000H0000GP0004d000230000KP0002D0000<00001`00P2P0000<0000
0@0002D0000<00000000P2P0000<0000100004H0000D0000200004M4BD<30000AP0002P0000L0000
AdA9@`80000l1P00804004D6000l0@00000005l0000d0000100003@000000000=000000000000040
0@0000000000000000000000000U0000300000@0000U0000300000D0081G000090000>d0001A0000
l@0006H000020000@0HQ0D06<P4U0000300000P0080X0000300000@0000W0000600000@000000000
00000000000U0000300000@0001F0000:0000>`0001R0000l`0006`000030000?@H`0D06>P541S01
9@0000`0000700209@0000`000000020:00000`000040000AP0001@000080000AdA9@`<0000W0000
600000@000000000oooo0000000U0000300000@0000V000070000040000000000@000000003oool2
9@0000`000010000:`0001P0001Q1@00@@400>@5001H0@009@0000`000000020:00000`000040000
9@0000`000070020:00000`0000100008@0000P0000N0000600006@500120@00hPD005P1000U0000
300000<0000U0000300000<0000D0000300000d0000B000030000040001D0000c00001<0001d0000
S`0008<000010000000P@P00849T1@00@P4001D0001<00000000000000000000oooooooooomh0000
DP1U07<0M00P06l0IP0P07@0J01U0200HP1_06@0N@0P02P0DP1202T0000900001`0000L000040000
100000L000030000100000@0000700001`0000@0000700001`0000L000070000100000@000090000
2@0000@0000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H0000
6P000140000=0`00S0400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000
0000P2L0000H00000@000000003oool0000002D0000<00000@0002H0000L00001000000000010000
00000?ooo`8U0000300000@0000[0000600003H600080@00B`H001`1000U000030000000080X0000
30000040000U0000300000L0080X0000300000@0000Q0000200001h0000H0000>@H000T100191P00
70400580001<0@0010000?Goool0000000000000002@0@000000000002110780J@1Q06`000000000
0000000000000000000000000000000000000000000000000000000000000000003oo`0000000000
000009010000000000008440LP1Y0640K00000000000000000000000000000000000000000000000
00000000000000000000000000160000S;XB072h4P0`^180S;PB0000000dPF42j;LB01eJkGL000Y>
G000052h4P0d^180LR@1<8P32TiL0000D;PB04Ri4P0=000090H00?Goool5000000000000002@0@00
000000000000000000000000000000000@410@410@410@4`9@0000`0000400009@0000`000040000
500000`0000=00004P0000`000010000E0000600003X0000>`000?H0001800000@00000084800212
>@H000T100030000C00000000000000000000?ooooooooooE00005D0C01900001`0000H000020000
8P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A0000
3@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U000030000000080W0000
6000004000000000oooo0000000U000030000040000V0000700000D0000000000@000000003oool2
9@0000`000050000:`0001P0000g1P00@04004`6001D0@009@0000`000000020:00000`000010000
9@0000`000070020:00000`0000500008@0000P0000N0000600003X600110@00BPH005@1000U0000
300000@0000U0000300000@0000D0000300000d0000B000030000040001D0000H0000>T0001c0000
mP00080000010000000P@P00848j1P00@@4000<0001<00000000000000000000oooooooooomD0000
C01<04T0000600001P000080000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000
000001h0000H00006P000140000=0`00S0400280000<0000oooooaP0000<0000000001T0000<0000
oooo02D0000<00000000P4H0000X0000700004M4BD<20000W@D005/1002V1@00M`400000000B0000
30000040001O0000=00000D0000d0000000003@0000000000P010040000000000000000000000000
9@0000`0000500009@0000`000050020E`0002@0001=0000S0000580002Q00000P000:05G06Q1Fd1
9@0000`000080020:00000`0000500009`0001P00005000000000000000000009@0000`000050000
EP0002P0001=0000W@0005@0002X00000`0009h5J`6R1GH1Y@E[0BD0000<00001`00P2D0000<0000
0000P2P0000<00001@0004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80000l1P00
F@4004D6001e0@0000000180000<00000@0005l0000d00001@0003@000000000=000000000020040
0@0000000000000000000000000U0000300000D0000U0000300000D0081G000090000>d0002:0000
lP0009l000020000@@IJ0D06J`4U0000300000P0080X0000300000D0000W0000600000D000000000
00000000000U0000300000D0001F0000:0000>`0002K0000l`000:H000030000?@IY0D06M0541VT1
9@0000`0000700209@0000`000000020:00000`000050000AP0001@000080000AdA9@`<0000W0000
600000D000000000oooo0000000U0000300000D0000V000070000040000000000@000000003oool2
9@0000`000010000:`0001P0002@1@00NP400;D5002;0@009@0000`000000020:00000`000050000
9@0000`000070020:00000`0000100008@0000P0000N0000600009<5001k0@00/`D008/1000U0000
300000<0000U0000300000<0000D0000300000d0000B000030000040001D0000K0000480002]0000
G`000;`000010000000P@P0084:C1@00N`4000D0001<00000000000000000000oooooooooomH0000
E@1b06T0KP1U00002@0000@0000300001`0000L0000R000030000?oooolQ0000200001T0000<0000
oooo01P0000<0000000001h0000H00006P000140000=0`00S0400280000<0000oooooaP0000<0000
000001T0000<0000oooo02D0000<00000000P2L0000H00000@000000003oool0000002D0000<0000
0@0002H0000L00001@0000000001000000000?ooo`8U0000300000D0000[0000600002H6001g0@00
F0H008/1000U000030000000080X000030000040000U0000300000L0080X0000300000D0000Q0000
200001h0000H0000:@H007P1001F1P00R`4002D0000<00000`0002D0000<00000`0001@0000<0000
3@000180000<00000@0005@0001`0000f0000:X000020@00^@00004000000212000P@RT6001h0@00
1P0004`00000000000000000003ooooooooooeP000160640I@1S06D0L`0800001`0000L000070000
1`0000L0000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H0000
6P000140000=0`00S0400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000
0000P4H0000X0000700004M4BD<20000Z`D000`1000b1P005@400000001O0000=00000D0000d0000
000003@000000000000100400000000000000000000000009@0000`0000500009@0000`000050020
E`0002@0001I0000@0000=T0001400000P000:`5404X1Q019@0000`000080020:00000`000050000
9`0001P00005000000000000000000009@0000`000050000EP0002P0003E0000?`000=l000160000
0`0002H6504`1Q019PH=0BD0000<00001`00P2D0000<00000000P2P0000<00001@0004H0000D0000
200004M4BD<30000AP0002P0000L0000AdA9@`80003`1@005`4003P6001=0@00000002D0000<0000
2000P2L0000H00001@00000000000000000002D0000<00001@0001<0000<00000P0005H0000d0000
X00007d0002T0000OP0000H0003a1D/1l@E;0O45C07e1D`1m@E;0OD5B`5F0000=0000:H0001m0000
Z`0007h000060000n0E;0OL5B`7h1D`1o0E<0O`5B`7l1D/1EP0003@0002]0000O@000;80001n0000
1P000?l5B`7n1D/1o`E<0@<6C0431T/10`I;0EH0000d0000]00007d0002i0000OP0000H000061T/1
1@I;0@H6C04:1T`12PI;0@X6B`5F0000=0000;/0001m0000`00007h0000600003@I;0@`6B`4=1T`1
4@I<0A46B`4A1T/1EP0003@000320000N0000<<0001l00001P0001<6BP4C1TX150I:0A@6AP4C1TH1
4`I60EH0000d0000`P00074000330000M@0000H0000C1T<14`I30A@6@`4D1Sl14`Ho0A<6?`5F0000
=0000<80001Z0000``0006h0000600004`Hl0A<6?04D1S`150Hh0A<6>04C1SP1EP0003@000320000
H`000<<0001W00001P0001<6=@4C1SD150He0A@6<@4C1S414`Ha0EH0000d0000`P0005`000330000
H00000H0000C1Rh14`H^0A@6;P4D1RX14`HZ0A<6:P5F0000=0000<80001E0000``0005T000060000
4`HW0A<69`4D1RL150HS0A<68`4C1R<1EP0003@000320000CP000<<0001B00001P0001<6804C1R01
50HP0A@6704C1Q`14`HL0EH0000d0000``0004d000380000CP0000H0000E1Q/150HK0AD6704I1Q`1
6@HK0AT66`5F0000=0000<X0001=0000c`0004h00006000070HK0A/66`4L1Q`180HL0B066`4P1Q/1
EP0003@0003A0000C@000=H0001>00001P0002<66`4R1Q/18`HL0BL6704W1Q/19`HK0EH0000d0000
f00004d0003M0000CP0000H0000Z1Q/1:@HK0BX6704^1Q`1;PHK0Bh66`4C000030000040001F0000
:0000=/0001:0000i@00054000030000;0HO0CH6704/1QP19@0000`0000700209@0000`000000020
:00000`000050000AP0001@000080000AdA9@`<0000W0000600000D000000000oooo0000000U0000
300000D0000V000070000040000000000@000000003oool29@0000`000010000:`0001P0002>1@00
e0000;85003[00009@0000`000000020:00000`0000500009@0000`000070020:00000`000010000
8@0000P0000N000060000945003E0000/0D00>/0000U0000300000<0001B0000C0400040003goooo
0000000000000000T04000000000000P@@1b06T0H@1/000000000000000000000000000000000000
0000000000000000000000000000000000000000ool0000000000000002@0@000000000002110780
J@1Q06`0000000000000000000000000000000000000000000000000000000000000000000000000
AP0008bj4P1`^180<;PB08bh4P000000h3C80^Rg4P0MF^eg000:55`0001@^180=;PB078T0C321@XD
G000052h4P0D0bL0O@000?3oooogoooo1000000000000000T0400000000000000000000000000000
000000410@410@410@41<2D0000<00000@0002D0000<00000`0002D0000<00000`0001@0000<0000
3@000180000<00000@0005@0001D0000@00000T0001600006000004000000212000P@Y45003G0000
0@0004`00000000000000000003ooooooooooe00001R00001`0002D0000<00000@0005@0001D0000
A`0000l0001<00006P00004000000212000P@YP5003M00000@0004`00000000000000000003ooooo
oooooe00001200001P0002D0000<00000`0005@0001P0000C@0000T0001H00006000004000000212
000P@Yh5003G00000`0004`00000000000000000003ooooooooooe@0000X07@0:@0000@000040000
10000280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J0000
4@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000000020
AP0001@000080000AdA9@`<0000<00004000000000000000600000`0000000006@0000`0003oool0
9@0000`0000000208P0000`0003ooooo3P0001@000000000400001@0
\>"], "Graphics",
  ImageSize->{269, 189},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Figure 3: ",
    FontWeight->"Bold"],
  " ",
  StyleBox["qInhalation ",
    FontWeight->"Bold"],
  " ",
  StyleBox["qIngestion",
    FontWeight->"Bold"],
  ", ",
  StyleBox["qInjection",
    FontWeight->"Bold"],
  " and ",
  StyleBox["BioassayReport ", "Input"],
  "required that the compartmental matrix be defined  as appeared in the \
figure. \"Rest of body\" is described in ICRP 78. It is  specific of the \
isotope. They are applied where there are not recycling throw SI. "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      RowBox[{
        StyleBox["qInjection",
          "Text"], 
        StyleBox["[",
          "Text"], 
        StyleBox[
          RowBox[{
            StyleBox[\(Compartmental\ Matrix\),
              "Text"], 
            StyleBox[",",
              "Text"], 
            StyleBox[" ",
              "Text"], "I", ",", " ", "t", ",", " ", "\[Lambda]", ",", " ", 
            "options"}],
          FontWeight->"Plain",
          FontSlant->"Italic"], 
        StyleBox["]",
          "Text"]}]], "Input"],
  " for one specific nuclide, gives the retention in the compartments of the  \
model as function of time  ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " for  an intake",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(I\)\)\)]],
  " by injection. By default  an acute intake is assumed. Other type of \
intake can be chosen with Options. For each type of intake mush be used a \
format for intake data input. "
}], "DefinitionBox"],

Cell[TextData[{
  Cell[BoxData[
      RowBox[{
        StyleBox["qIngestion",
          "Text"], 
        StyleBox["[",
          "Text"], 
        StyleBox[
          RowBox[{
            StyleBox[\(Compartmental\ Matrix\),
              "Text"], 
            StyleBox[",",
              "Text"], 
            StyleBox[" ",
              "Text"], "I", ",", " ", "f1", ",", " ", "t", ",", " ", 
            "\[Lambda]", ",", " ", "options"}],
          FontWeight->"Plain",
          FontSlant->"Italic"], 
        StyleBox["]",
          "Text"]}]], "Input"],
  " for one specific nuclide, gives the retention in the compartments of the  \
model as function of time  ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " for  an intake",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(I\)\)\)]],
  " by ingestion. By default  an acute intake is assumed. Other type of \
intake can be chosen with Options. For each type of intake mush be used a \
format for intake data input. "
}], "DefinitionBox"],

Cell[TextData[{
  Cell[BoxData[
      RowBox[{
        StyleBox["qInhalation",
          "Text"], 
        StyleBox["[",
          "Text"], 
        StyleBox[
          RowBox[{
            StyleBox[\(Compartmental\ Matrix\),
              "Text"], 
            StyleBox[",",
              "Text"], 
            StyleBox[" ",
              "Text"], \(I\_0\), ",", " ", "IFD", ",", " ", "FRA", ",", " ", 
            "f1", ",", "  ", "t1", ",", " ", "\[Lambda]", ",", " ", 
            "options"}],
          FontWeight->"Plain",
          FontSlant->"Italic"], 
        StyleBox["]",
          "Text"]}]], "Input"],
  "for one specific nuclide, gives the retention in the compartments of the  \
model as function of time  ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " for  an intake",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(I\)\)\)]],
  " by inhalation. By default  an acute intake is assumed. Other type of \
intake can be chosen with Options. For each type of intake mush be used a \
format for intake data input."
}], "DefinitionBox"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " always in days. \n\n",
  StyleBox["Compartmental Matrix",
    FontWeight->"Bold"],
  ": Compartmental Matrix of the element, it can be made sing ",
  StyleBox["CompartMatrix", "Input"],
  " function\n\n",
  StyleBox["Intake",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  ": ",
  Cell[BoxData[
      \(TraditionalForm\`I\_0\)]],
  " for Acute input (Bq);",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`I\_d\)]],
  " for Constant input (Bq/day); ",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`{I(t), \ t}\)]],
  " for continuous input; ",
  Cell[BoxData[
      RowBox[{
        StyleBox["I",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], "=", 
        RowBox[{
          StyleBox["{",
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False,
            "StrikeThrough"->False,
            "Masked"->False,
            "CompatibilityType"->0,
            "RotationAngle"->0}], 
          RowBox[{
            RowBox[{
              StyleBox["{",
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              RowBox[{
                StyleBox[\(I\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], ",", " ", "0"}], "}"}], ",", " ", 
            RowBox[{"{", 
              StyleBox[\(I\_1, \[Tau]\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["}",
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}]}], 
            StyleBox[",",
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False,
              "StrikeThrough"->False,
              "Masked"->False,
              "CompatibilityType"->0,
              "RotationAngle"->0}], 
            StyleBox[" ",
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False,
              "StrikeThrough"->False,
              "Masked"->False,
              "CompatibilityType"->0,
              "RotationAngle"->0}], 
            StyleBox["...",
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False,
              "StrikeThrough"->False,
              "Masked"->False,
              "CompatibilityType"->0,
              "RotationAngle"->0}], 
            StyleBox[",",
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False,
              "StrikeThrough"->False,
              "Masked"->False,
              "CompatibilityType"->0,
              "RotationAngle"->0}], 
            StyleBox[" ",
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False,
              "StrikeThrough"->False,
              "Masked"->False,
              "CompatibilityType"->0,
              "RotationAngle"->0}], 
            RowBox[{
              StyleBox["{",
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              RowBox[{
                StyleBox[\(I\_n\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], ",", " ", 
                StyleBox[\(\[Tau]\_n\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}]}], 
              StyleBox["}",
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}]}]}], 
          StyleBox["}",
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False,
            "StrikeThrough"->False,
            "Masked"->False,
            "CompatibilityType"->0,
            "RotationAngle"->0}]}]}]]],
  " \n\n",
  StyleBox["\[Lambda]",
    FontWeight->"Bold"],
  ": Radioactive Decay constant in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(day\)\(\ \)\)\^\(-1\)\)]],
  "\n\n",
  StyleBox["IFD",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" (only by Inhalation): Initial fractional  deposition values ",
    FontSlant->"Italic"],
  StyleBox["as function of AMAD. Write AMADxx, being xx=05, 07, 1, 3, 4, 5, \
7, 10, 15, 20 {see HUMORAP Help) ",
    FontVariations->{"CompatibilityType"->0}],
  "\n\n",
  StyleBox["FRA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" (only by Inhalation): Fractional rate of absorption. ",
    FontSlant->"Italic"],
  "Write F or M or S.\n\n",
  StyleBox["f1",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " fraction uptake of element from GI (SI) to Blood f1\[LessEqual]1 or  \
f1<1(if recycling GI to B) \n\n",
  StyleBox["Options",
    FontWeight->"Bold"],
  ": ",
  StyleBox["IntakeType",
    FontFamily->"Courier New"],
  "\[Rule] \"Acute\" or  ",
  StyleBox["IntakeType",
    FontFamily->"Courier New"],
  "\[Rule]\"Constant\" or IntakeType\[Rule]\"Continuous\"or IntakeType\[Rule] \
\"MultiInputs\"  (not for inhalation); by default it is aplied a acute \
intake. \n\"Acute\" means an single intake ",
  Cell[BoxData[
      \(TraditionalForm\`I\_0\)]],
  " in t = 0;\n\"Constant\" means an constant (Chronic)  ntake ",
  Cell[BoxData[
      \(TraditionalForm\`I\_d\)]],
  " (Bq/day);\n\"Continuous\" means an variable input in the time I(t), ej.: \
0.3 Exp[-0.02 t]\n\"MultiInputs\" means multi single (acute) inputs  {",
  Cell[BoxData[
      \(I\_0\)]],
  ", ..., ",
  Cell[BoxData[
      \(I\_n\)]],
  "} at time 0<",
  Cell[BoxData[
      \(\[Tau]\_1\)]],
  "< ...<",
  Cell[BoxData[
      \(\[Tau]\_n\)]],
  ", the retention and excretion are given as function of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " after the last intake ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{
          StyleBox[\(I\_n\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False,
            "StrikeThrough"->False,
            "Masked"->False,
            "CompatibilityType"->0,
            "RotationAngle"->0}], ",", " ", 
          StyleBox[\(\[Tau]\_n\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False,
            "StrikeThrough"->False,
            "Masked"->False,
            "CompatibilityType"->0,
            "RotationAngle"->0}]}], 
        StyleBox["}",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}]}]]],
  "; \n\nThe parameter options by default are that follows:"
}], "Commentary",
  CellDingbat->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[qInjection]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \({IntakeType \[Rule] "Acute", k\_ULI \[Rule] 1.8`, 
      k\_LLI \[Rule] 1}\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[qIngestion]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \({IntakeType \[Rule] "Acute", k\_ST \[Rule] 24, 
      f\_B \[Rule] f1\/\(1 - f1\), k\_SI \[Rule] 6, k\_ULI \[Rule] 1.8`, 
      k\_LLI \[Rule] 1}\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[qInhalation]\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \({IntakeType \[Rule] "Acute", fAI1 \[Rule] 0.3`, fAI2 \[Rule] 0.6`, 
      fAI3 \[Rule] 0.1`, fbs \[Rule] 0.007`, fBs \[Rule] 0.007`, 
      fet2 \[Rule] 0.9995`, k\_"AI1,bb1" \[Rule] 0.02`, 
      k\_"AI2,bb1" \[Rule] 0.001`, k\_"AI3,bb1" \[Rule] 0.0001`, 
      k\_"AI3,TH" \[Rule] 0.00002`, k\_"bb1,BB1" \[Rule] 2, 
      k\_"bb2,BB1" \[Rule] 0.03`, k\_"bbseq,TH" \[Rule] 0.01`, 
      k\_"BB1,ET2" \[Rule] 10, k\_"BB2,ET2" \[Rule] 0.03`, 
      k\_"BBseq,TH" \[Rule] 0.01`, k\_"ET2,ST" \[Rule] 100, 
      k\_"ETseq,ET" \[Rule] 0.001`, k\_Env \[Rule] 1, k\_ST \[Rule] 24, 
      f\_B \[Rule] f1\/\(1 - f1\), k\_SI \[Rule] 6, k\_ULI \[Rule] 1.8`, 
      k\_LLI \[Rule] 1}\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      RowBox[{"BioassayReport", "[", 
        StyleBox[
          RowBox[{
            StyleBox[\(Compartmental\ Matrix\),
              "Text"], 
            StyleBox[",",
              "Text"], 
            StyleBox[" ",
              "Text"], "I", ",", " ", "IFD", ",", " ", "FRA", ",", " ", "f1", 
            ",", " ", "t", ",", " ", "\[Lambda]", ",", " ", "options"}],
          FontWeight->"Plain",
          FontSlant->"Italic"], 
        StyleBox["]",
          "Text"]}]], "Input"],
  " \nfor one specific nuclide and an intake by inhalation gives as function \
of the time  (depending on the option chosen): the lung and whole body \
retention, daily urine and faecal excretion, the content and total \
disintegration en each compartment ",
  StyleBox["\n",
    FontSlant->"Italic"],
  "\n",
  Cell[BoxData[
      RowBox[{"BioassayReport", "[", 
        StyleBox[
          RowBox[{
            StyleBox[\(Compartmental\ Matrix\),
              "Text"], 
            StyleBox[",",
              "Text"], 
            StyleBox[" ",
              "Text"], "I", ",", "  ", "f1", ",", " ", "t", ",", " ", 
            "\[Lambda]", ",", " ", "options"}],
          FontWeight->"Plain",
          FontSlant->"Italic"], 
        StyleBox["]",
          "Text"]}]], "Input"],
  "  \nfor one specific nuclide and an intake by ingestion gives as function \
of the time  (depending on the option chosen): the lung and whole body \
retention, daily urine and faecal excretion, the content and total \
disintegration en each compartment \n\n",
  Cell[BoxData[
      RowBox[{"BioassayReport", "[", 
        StyleBox[
          RowBox[{
            StyleBox[\(Compartmental\ Matrix\),
              "Text"], 
            StyleBox[",",
              "Text"], 
            StyleBox[" ",
              "Text"], "I", ",", " ", "t", ",", " ", "\[Lambda]", ",", " ", 
            "options"}],
          FontWeight->"Plain",
          FontSlant->"Italic"], 
        StyleBox["]",
          "Text"]}]], "Input"],
  " \nfor one specific nuclide and an intake by injection gives as function \
of the time  (depending on the option chosen): the lung and whole body \
retention, daily urine and faecal excretion, the content and total \
disintegration en each compartment "
}], "DefinitionBox"],

Cell[TextData[{
  "Options:\n",
  StyleBox["IntakeWay",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  " options are: IntakeWay\[Rule]\"Inhalation\" (by default) or IntakeWay\
\[Rule]\"Ingestion\" or IntakeWay\[Rule]\"Injection\";\n\n",
  StyleBox["IntakeType",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  " options are: IntakeType\[Rule]\"Acute\" or IntakeType\[Rule]\"Constant\"  \
or IntakeType\[Rule]\"Continuous\" or IntakeType\[Rule]\"MultiInputs\" (not \
for inhalation);\n\n",
  StyleBox["ShowReport",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  " options are:  ShowReport \[Rule]\"Automatic\" (by default) or  ShowReport \
\[Rule] \"BioassayTable\", or  ShowReport \[Rule]\"GraphicsReport\"  or  \
ShowReport \[Rule]\"FullReport\" or  ShowReport \
\[Rule]\"CompartmentContent\", or  ShowReport \[Rule]\"Disintegrations\" . \n\
\n\"Automatic\".- Gives the Lungs (only by inhation) and whole body retention \
, daily urine and faecal excretion as function of t.\n\"BioassayTable\".- \
Gives the Lungs (only by inhalation) and whole body retention , daily urine \
and faecal excretion for different days.\n\"GraphicsReport\".- Graphics \
representation as function of time of  the Lungs (only by inhalation) and \
whole body retention , and the daily urine and faecal excretion, from 0 to t.\
\n\"FullReport\".- Includes \"Automatic\", \"BioassayTable\", \
\"GraphicsReport\".\n\"CompartmentContent\".- ",
  StyleBox["\[CenterDot]\t",
    FontFamily->"Symbol"],
  "Gives the retention in each compartment of the model as function of t.\n\
\"Disintegrations\".- Gives the total disintegration accumulated at time t, \
that is Us or SA values.\n\nThe parameter options by default are that \
follows:"
}], "Commentary"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[BioassayReport]\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \({IntakeWay \[Rule] "Inhalation", IntakeType \[Rule] "Acute", 
      ShowReport \[Rule] "Automatic", fAI1 \[Rule] 0.3`, fAI2 \[Rule] 0.6`, 
      fAI3 \[Rule] 0.1`, fbs \[Rule] 0.007`, fBs \[Rule] 0.007`, 
      fet2 \[Rule] 0.9995`, k\_"AI1,bb1" \[Rule] 0.02`, 
      k\_"AI2,bb1" \[Rule] 0.001`, k\_"AI3,bb1" \[Rule] 0.0001`, 
      k\_"AI3,TH" \[Rule] 0.00002`, k\_"bb1,BB1" \[Rule] 2, 
      k\_"bb2,BB1" \[Rule] 0.03`, k\_"bbseq,TH" \[Rule] 0.01`, 
      k\_"BB1,ET2" \[Rule] 10, k\_"BB2,ET2" \[Rule] 0.03`, 
      k\_"BBseq,TH" \[Rule] 0.01`, k\_"ET2,ST" \[Rule] 100, 
      k\_"ETseq,ET" \[Rule] 0.001`, k\_Env \[Rule] 1, k\_ST \[Rule] 24, 
      f\_B \[Rule] f1\/\(1 - f1\), k\_SI \[Rule] 6, k\_ULI \[Rule] 1.8`, 
      k\_LLI \[Rule] 1}\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell[TextData[{
  "In order to apply the previous functions is compulsory numbering the \
compartments as follow:  compartment 1 much be the plasma (or blood), \
compartment ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is FEC (where ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is the total of compartments of the system) ,  compartment ",
  Cell[BoxData[
      \(TraditionalForm\`n - 1\)]],
  " LLI, compartment ",
  Cell[BoxData[
      \(TraditionalForm\`n - 2\)]],
  " ULI and compartment ",
  Cell[BoxData[
      \(TraditionalForm\`n - 3\)]],
  " URI. (urine). The other compartments can be numbering  in any  order. You \
realize that compartment URI, that represents the urine, and FEC, that \
represents faeces, they are trap compartments (without consider the \
radioactive decay). The rate transfers from bladder to urine is 12 ",
  Cell[BoxData[
      \(TraditionalForm\`d\^\(-1\)\)]],
  "."
}], "Text"],

Cell["\<\
 Summary: All ICRP 78  biokinetic will be apply numbering as follow \
\>", "Text"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"Bladder (n-4) to urine(n-3)\"\>", "\<\"k[n-4,n-3]->\"\>", 
            "12"},
          {"\<\"ULI (n-2) to LLI (n-1)\"\>", "\<\"k[n-2,n-1]->\"\>", \(k\_ULI\
\)},
          {"\<\"LLI (n-1) to FEC(n)\"\>", "\<\"k[n-1,n]->\"\>", \(k\_LLI\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Text"],

Cell[TextData[{
  Cell[BoxData[
      RowBox[{
      "BioassayReport", 
        "[", \(\(...\)\(,\)\(IntakeWay \[Rule] \
"\<Injection\>"\)\(,\)\(ShowReport \[Rule] "\<Automatic\>"\)\), " ", 
        StyleBox["]",
          "Text"]}]], "Input"],
  " gives the same solution that ",
  StyleBox["qInjection",
    FontWeight->"Bold"],
  " \n",
  Cell[BoxData[
      RowBox[{
      "BioassayReport", 
        "[", \(\(...\)\(,\)\(IntakeWay \[Rule] \
"\<Ingestion\>"\)\(,\)\(ShowReport \[Rule] "\<Automatic\>"\)\), " ", 
        StyleBox["]",
          "Text"]}]], "Input"],
  " gives the same solution that ",
  StyleBox["qIngestion",
    FontWeight->"Bold"],
  " \n",
  Cell[BoxData[
      RowBox[{
      "BioassayReport", 
        "[", \(\(...\)\(,\)\(IntakeWay \[Rule] \
"\<Inhalation\>"\)\(,\)\(ShowReport \[Rule] "\<Automatic\>"\)\), " ", 
        StyleBox["]",
          "Text"]}]], "Input"],
  " gives the same solution that ",
  StyleBox["qInhalation",
    FontWeight->"Bold"]
}], "DefinitionBox3Col"]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "SubsectionIcon"],

Cell[TextData[{
  "International Commission on Radiological Protection. Human respiratory \
tract model for radiological protection.Oxford: Pergamon Press; ICRP \
Publication 66; 1994.\nInternational Commission on Radiological Protection. \
Individual monitoring for internal exposure of workers.Oxford: Pergamon \
Press; ICRP Publication 78; 1997.\nInternational Commission on Radiological \
Protection. ICRP Database of Dose Coefficients: Workers and Members of the \
Public v. 2.0.1 (CD-ROM)\nPolig,E., Modeling the distribution and dosimetry \
of internal emitters: A review of mathematical procedures using Matrix \
Methods.Health Phys 81:492-501;2001.\nSanchez G and Lopez-Fidalgo J.,  ",
  StyleBox["Mathematical",
    FontVariations->{"CompatibilityType"->0}],
  " techniques for solving analytically large compartmental systems. Health \
Phys. 85 (2). August 2003.\nSanchez G.  (In Spanish) Humorap: A program for \
solving the compartmental models of ICRP 66 and 78. \
In:Radioprotecci\[OAcute]n Extra-2002. Proceedings of the IX Meeting of \
Spanish Society of Radioprotection; 2002:365-368. \nSanchez G. (In Spanish)  \
Resoluci\[OAcute]n anal\[IAcute]tica de modelos biocin\[EAcute]ticos con gran \
n\[UAcute]mero de compartimentos. Radioprotecci\[OAcute]n 35: 14-18; 2003.\n\n\
"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsection"],

Cell[TextData[{
  StyleBox["Biokmod ",
    FontWeight->"Bold"],
  "includes almost all current ICRP models in the package ",
  StyleBox["Biokdata", "Input"],
  ", however for tutorial purposes here is described  how can be built a \
model (for Iodine).   "
}], "Commentary"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The model", "SubsectionIcon"],

Cell[TextData[{
  "The figure 4 shows the model of iodine (as appeared in ICRP 78). \
Compartment 1 represents the blood, compartment 2 the thyroid, 3 \"rest of \
body\", and 4 the bladder, ",
  Cell[BoxData[
      \(TraditionalForm\`k\_40\)]],
  " means the rate transfer out of system  (via urine) and ",
  Cell[BoxData[
      \(TraditionalForm\`k\_30\)]],
  "means the rate transfer out of system  to ULI in GI system (see fig 3.). "
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .90909 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 0.17316 0.627706 0.17316 [
[ 0 0 0 0 ]
[ 1 .90909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .90909 L
0 .90909 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125  moveto 0 0 lineto 
-0.05 -0.0125  lineto stroke
} ifelse
grestore
} def
/MAarrowhead2 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.11039 .88745 m
.11039 .71429 L
s
% Start of user PostScript
0 1.5 0 0.5 MAarrowhead1
% End of user PostScript
gsave
.04113 .80087 -80.3438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
75.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.688 12.813 moveto
(H) show
85.688 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 12.813 moveto
(L) show
97.688 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.11039 .62771 .08658 0 365.73 arc
s
gsave
.11039 .62771 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.19697 .62771 m
.62987 .62771 L
s
% Start of user PostScript
0.5 0 3. 0 MAarrowhead2
% End of user PostScript
newpath
.11039 .28139 .08658 0 365.73 arc
s
gsave
.11039 .28139 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .19481 m
.11039 .02165 L
s
% Start of user PostScript
0 -2.5 0 -3.5 MAarrowhead2
% End of user PostScript
gsave
.16234 .14286 -70.4375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.41342 .69697 -70.4375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .54113 m
.11039 .36797 L
s
% Start of user PostScript
0 -0.5 0 -1.5 MAarrowhead2
% End of user PostScript
gsave
.16234 .48918 -70.4375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.71645 .62771 .08658 0 365.73 arc
s
gsave
.71645 .62771 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.71645 .54113 m
.71645 .36797 L
s
% Start of user PostScript
3.5 -0.5 3.5 -1.5 MAarrowhead2
% End of user PostScript
gsave
.6645 .45455 -70.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.71645 .28139 .08658 0 365.73 arc
s
gsave
.71645 .28139 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.62987 .31602 m
.17965 .57576 L
s
% Start of user PostScript
3. -1.8 0.4 -0.3 MAarrowhead2
% End of user PostScript
gsave
.45671 .45455 -70.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(31) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.80303 .28139 m
.97619 .28139 L
s
% Start of user PostScript
4. -2. 5. -2. MAarrowhead2
% End of user PostScript
gsave
.85498 .28139 -70.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[15]:=",
  ImageSize->{288, 261.75},
  ImageMargins->{{1, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001R2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00;`3oool00`000000oooo0?oo
o`3o0?ooogl0oooo000_0?ooo`030000003oool0oooo0?l0ooooO`3oool002l0oooo0P00003o0?oo
oh00oooo000^0?ooo`<00000o`3ooon00?ooo`00;P3oool300000?l0ooooP03oool002h0oooo0`00
003o0?oooh00oooo000^0?ooo`@00000o`3ooomo0?ooo`00;@3oool500000?l0ooooO`3oool002d0
oooo1@00003o0?ooogl0oooo000]0?ooo`D00000o`3ooomo0?ooo`00;@3oool600000?l0ooooOP3o
ool002`0oooo1`00003o0?ooogh0oooo000/0?ooo`L00000o`3ooomn0?ooo`00;03oool800000?l0
ooooO@3oool002`0oooo2000003o0?ooogd0oooo000/0?ooo`P00000o`3ooomm0?ooo`00:`3oool9
00000?l0ooooO@3oool002/0oooo2P00003o0?ooog`0oooo000[0?ooo`X00000o`3oooml0?ooo`00
:`3oool:00000?l0ooooO03oool002X0oooo2`00003o0?ooog`0oooo000Z0?ooo``00000o`3ooomk
0?ooo`00:P3oool<00000?l0ooooN`3oool002l0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00
;`3oool00`000000oooo0?ooo`3o0?ooogl0oooo000_0?ooo`030000003oool0oooo0?l0ooooO`3o
ool002l0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00;`3oool00`000000oooo0?ooo`3o0?oo
ogl0oooo000_0?ooo`030000003oool0oooo0?l0ooooO`3oool002l0oooo00<000000?ooo`3oool0
o`3ooomo0?ooo`00;`3oool00`000000oooo0?ooo`3o0?ooogl0oooo000_0?ooo`030000003oool0
oooo0?l0ooooO`3oool002l0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00;`3oool00`000000
oooo0?ooo`3o0?ooogl0oooo000_0?ooo`030000003oool0oooo0?l0ooooO`3oool002l0oooo00<0
00000?ooo`3oool0o`3ooomo0?ooo`00;`3oool00`000000oooo0?ooo`3o0?ooogl0oooo000_0?oo
o`030000003oool0oooo0?l0ooooO`3oool002l0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00
;`3oool00`000000oooo0?ooo`3o0?ooogl0oooo000_0?ooo`030000003oool0oooo0?l0ooooO`3o
ool002l0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00;`3oool00`000000oooo0?ooo`3o0?oo
ogl0oooo000_0?ooo`030000003oool0oooo0?l0ooooO`3oool002l0oooo00<000000?ooo`3oool0
o`3ooomo0?ooo`00;`3oool00`000000oooo0?ooo`3o0?ooogl0oooo000_0?ooo`030000003oool0
oooo0?l0ooooO`3oool002l0oooo00<000000?ooo`3oool0503oool3000000<0oooo0`00003o0?oo
of80oooo000_0?ooo`030000003oool0oooo01D0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0?l0ooooG`3oool002l0oooo00<000000?ooo`3oool04P3oool500000080
oooo00D000000?ooo`3oool0oooo0000003o0?ooof40oooo000_0?ooo`030000003oool0oooo00T0
oooo0P0000020?ooo`<000000P3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo
0?ooo`000000o`3ooomQ0?ooo`00;`3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000?l0ooooH@3o
ool002l0oooo00<000000?ooo`3oool02P3oool00`000000oooo000000070?ooo`8000000`3oool0
1@000000oooo0?ooo`3oool000000?l0ooooH@3oool002l0oooo00<000000?ooo`3oool02P3oool3
000000P0oooo00<000000?ooo`3oool00P3oool300000?l0ooooHP3oool002l0oooo00<000000?oo
o`3oool02P3oool010000000oooo0?ooo`00003o0?ooog40oooo000_0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`0000000P00003o0?ooog00oooo000_0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0o`3ooomb0?ooo`00;`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0?l0ooooLP3oool002l0oooo00<000000?ooo`3oool02@3oool200000?l0ooooM03o
ool002l0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00;`3oool00`000000oooo0?ooo`3o0?oo
ogl0oooo000_0?ooo`030000003oool0oooo0?l0ooooO`3oool002l0oooo00<000000?ooo`3oool0
o`3ooomo0?ooo`00;`3oool00`000000oooo0?ooo`3o0?ooogl0oooo000_0?ooo`030000003oool0
oooo0?l0ooooO`3oool002l0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00;`3oool00`000000
oooo0?ooo`3o0?ooogl0oooo000_0?ooo`030000003oool0oooo0?l0ooooO`3oool002l0oooo00<0
00000?ooo`3oool0o`3ooomo0?ooo`00;`3oool00`000000oooo0?ooo`3o0?ooogl0oooo000_0?oo
o`030000003oool0oooo0?l0ooooO`3oool002l0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00
;`3oool00`000000oooo0?ooo`3o0?ooogl0oooo000_0?ooo`030000003oool0oooo0?l0ooooO`3o
ool002l0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00:@3oool>00000?L0oooo3P00001d0?oo
o`009@3oool4000000h0oooo0`00003`0?ooo`@000003P3oool300000740oooo000R0?ooo`<00000
5@3oool400000>T0oooo0`00000E0?ooo`@00000K@3oool00200oooo0P00000L0?ooo`800000i@3o
ool2000001`0oooo0P00001[0?ooo`007P3oool200000200oooo00<000000?ooo`3oool0h03oool2
00000200oooo00<000000?ooo`3oool0J03oool001d0oooo00<000000?ooo`3oool08@3oool20000
0=l0oooo00<000000?ooo`3oool08@3oool2000006P0oooo000K0?ooo`8000009P3oool00`000000
oooo0?ooo`3J0?ooo`8000009P3oool00`000000oooo0?ooo`1U0?ooo`006@3oool2000002T0oooo
0P00003H0?ooo`800000:@3oool2000006D0oooo000G0?ooo`800000;@3oool00`000000oooo0?oo
o`3D0?ooo`030000003oool0oooo02/0oooo0P00001S0?ooo`005P3oool00`000000oooo0?ooo`0^
0?ooo`800000d`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0600oooo000E0?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo05l0oooo000E0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool0c@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo05h0oooo000D0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo05d0oooo000C0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0b@3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo05`0oooo000B0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo05/0oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0a`3oool00`00
0000oooo0?ooo`0h0?ooo`030000003oool0oooo05/0oooo000@0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0a03oool2000003`0oooo00<000000?ooo`3oool0FP3oool000l0oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0FP3oool000l0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`320?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0F@3oool000h0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo03l0oooo00<00000
0?ooo`3oool0F03oool000h0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`300?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool0F03oool000h0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool0E`3oool000d0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`2n0?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool0E`3oool000d0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0EP3o
ool000`0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool0EP3oool000`0oooo00<000000?ooo`3oool0@`3oool00`00
0000oooo0?ooo`2l0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0EP3oool000`0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool0E@3oool000/0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`2j0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0E@3oool000/0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool0E@3oool000/0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`2j
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0E@3oool000/0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool0E03oool000X0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`2h0?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0E03oool000X0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0
<`3oool3000001h0oooo000:0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0^03o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo03<0oooo1`00000J0?ooo`002P3oool0
0`000000oooo0?ooo`0Q0?ooo`@000008P3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0
oooo0200oooo1000000S0?ooo`030000003oool0oooo03<0oooo2`00000F0?ooo`002P3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0^03oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0c0?ooo`l000004P3oool000X0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo03<0oooo4`00000>0?ooo`002P3oool00`000000oooo
0?ooo`0O0?ooo`H000008P3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool08@3ooom;000000/0oooo000:0?ooo`030000003oool0oooo0200oooo00@0
00000?ooo`3oool000008`3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo0280oooo
0P00000S0?ooo`030000003oool0oooo03<0oooo5000000=0?ooo`002P3oool00`000000oooo0?oo
o`0P0?ooo`040000003oool0oooo000002<0oooo00<000000?ooo`3oool0^03oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0<`3oool@00000140oooo
000:0?ooo`030000003oool0oooo0240oooo00<000000?ooo`0000008`3oool00`000000oooo0?oo
o`2h0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0c0?ooo`d00000503oool000X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0000000S
0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0503oool3000000@0oooo0`00000E
0?ooo`T00000603oool000X0oooo00<000000?ooo`3oool08P3oool2000002<0oooo00<000000?oo
o`3oool0^03oool00`000000oooo0?ooo`0P0?ooo`@000008`3oool00`000000oooo0?ooo`0C0?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000001@0oooo1P00
000K0?ooo`002P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0;P0oooo00<00000
0?ooo`3oool0A`3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool04P3oool2000001l0oooo000;0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0^@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00X0oooo0P000002
0?ooo`<00000103oool2000000<0oooo00D000000?ooo`3oool0oooo0000000e0?ooo`002`3oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0c0?ooo`002`3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo0;X0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`00
0000=@3oool000/0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`2j0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool0303oool3000000H0oooo0`0000040?ooo`<00000
=P3oool000`0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`2k0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`0000150?ooo`00303o
ool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000800000A03oool000`0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo04<0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`160?ooo`00303oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo0;`0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo04H0oooo000=0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool0^P3oool010000000oooo0?ooo`0000140?ooo`030000003oool0oooo00`0oooo0P0000180?oo
o`003P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0;T0oooo0P0000040?ooo`03
0000003oool0oooo0400oooo00<000000?ooo`3oool0E`3oool000h0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`2h0?ooo`8000001P3oool00`000000oooo0?ooo`0o0?ooo`030000
003oool0oooo05P0oooo000>0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0]P3o
ool2000000P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`1H0?ooo`003P3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo05T0oooo000?0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0]03oool2000000`0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`1I0?ooo`00403oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0;<0
oooo0P00000?0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0FP3oool00100oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`1K0?ooo`004@3oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo0;40oooo0P00000D0?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool0F`3oool00180oooo0P00000h0?ooo`030000003oool0oooo0;00oooo0P00000G
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0G03oool001@0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`2_0?ooo`8000006P3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo05d0oooo000E0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool0[`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool0GP3oool001D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2^0?ooo`800000
7`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo05l0oooo000F0?ooo`030000003o
ool0oooo02h0oooo0P00002_0?ooo`8000008P3oool00`000000oooo0?ooo`0]0?ooo`800000HP3o
ool001L0oooo0P00000]0?ooo`030000003oool0oooo0:d0oooo0P00000U0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool0HP3oool001T0oooo00<000000?ooo`3oool0:03oool20000
0:l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0X0?ooo`800000I@3oool001X0
oooo0P00000W0?ooo`030000003oool0oooo0:d0oooo0P00000Z0?ooo`8000009`3oool00`000000
oooo0?ooo`1U0?ooo`00703oool2000002@0oooo00<000000?ooo`3oool0[03oool2000002h0oooo
0P00000T0?ooo`030000003oool0oooo06H0oooo000N0?ooo`030000003oool0oooo01l0oooo0P00
002]0?ooo`800000<P3oool00`000000oooo0?ooo`0O0?ooo`800000J@3oool001l0oooo0P00000N
0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0<`3oool2000001h0oooo00<00000
0?ooo`3oool0J@3oool00240oooo0`00000G0?ooo`@00000[@3oool2000003P0oooo0`00000G0?oo
o`@00000K03oool002@0oooo1000000?0?ooo`@00000[`3oool2000003d0oooo1000000@0?ooo`<0
0000L03oool002P0oooo3`00002b0?ooo`030000003oool0oooo0440oooo4000001c0?ooo`00;`3o
ool00`000000oooo0?ooo`2e0?ooo`800000B`3oool00`000000oooo0?ooo`1i0?ooo`00;`3oool2
00000;@0oooo0P00001=0?ooo`800000NP3oool002h0oooo0`00002b0?ooo`800000CP3oool30000
07X0oooo000^0?ooo`<00000/@3oool00`000000oooo0?ooo`1>0?ooo`<00000NP3oool002h0oooo
0`00002_0?ooo`800000D@3oool3000007X0oooo000^0?ooo`@00000[03oool2000005<0oooo1000
001i0?ooo`00;@3oool500000:X0oooo0P00001D0?ooo`D00000N@3oool002d0oooo1@00002Y0?oo
o`030000003oool0oooo05@0oooo1@00001i0?ooo`00;@3oool500000:L0oooo0P00001G0?ooo`D0
0000N@3oool002d0oooo1P00002T0?ooo`800000F@3oool6000007P0oooo000/0?ooo`L00000XP3o
ool2000005X0oooo1`00001h0?ooo`00;03oool700000:40oooo00<000000?ooo`3oool0FP3oool7
000007P0oooo000/0?ooo`P00000WP3oool2000005d0oooo2000001g0?ooo`00;03oool8000009`0
oooo0P00001O0?ooo`P00000M`3oool002`0oooo2000002K0?ooo`030000003oool0oooo05l0oooo
2000001g0?ooo`00:`3oool9000009T0oooo0P00001Q0?ooo`T00000M`3oool002/0oooo2P00002F
0?ooo`800000H`3oool:000007H0oooo000[0?ooo`X00000U03oool2000006D0oooo2P00001f0?oo
o`00:`3oool:000009<0oooo00<000000?ooo`3oool0I@3oool:000007H0oooo000Z0?ooo`/00000
T@3oool2000006L0oooo2`00001f0?ooo`00:P3oool<000008h0oooo0P00001Y0?ooo``00000M@3o
ool002X0oooo3000002<0?ooo`800000J`3oool<000007D0oooo000_0?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1i0?ooo`00;`3oool00`000000
oooo0?ooo`2=0?ooo`800000L`3oool00`000000oooo0?ooo`1i0?ooo`00;`3oool00`000000oooo
0?ooo`2;0?ooo`800000M@3oool00`000000oooo0?ooo`1i0?ooo`00;`3oool00`000000oooo0?oo
o`290?ooo`800000M`3oool00`000000oooo0?ooo`1i0?ooo`00;`3oool00`000000oooo0?ooo`28
0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0N@3oool002l0oooo00<000000?oo
o`3oool0QP3oool2000007X0oooo00<000000?ooo`3oool0N@3oool002l0oooo00<000000?ooo`3o
ool0Q03oool2000007`0oooo00<000000?ooo`3oool0N@3oool002l0oooo00<000000?ooo`3oool0
P`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo07T0oooo000_0?ooo`030000003o
ool0oooo0840oooo0P00001o0?ooo`030000003oool0oooo07T0oooo000_0?ooo`030000003oool0
oooo07l0oooo0P0000210?ooo`030000003oool0oooo07T0oooo000_0?ooo`030000003oool0oooo
07d0oooo0P0000230?ooo`030000003oool0oooo07T0oooo000_0?ooo`030000003oool0oooo07`0
oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`1i0?ooo`00;`3oool00`000000oooo
0?ooo`1j0?ooo`800000QP3oool00`000000oooo0?ooo`1i0?ooo`00;`3oool00`000000oooo0?oo
o`1h0?ooo`800000R03oool00`000000oooo0?ooo`1i0?ooo`00;`3oool00`000000oooo0?ooo`1f
0?ooo`800000RP3oool00`000000oooo0?ooo`1i0?ooo`00;`3oool00`000000oooo0?ooo`1e0?oo
o`030000003oool0oooo08X0oooo00<000000?ooo`3oool0N@3oool002l0oooo00<000000?ooo`3o
ool0L`3oool2000008d0oooo00<000000?ooo`3oool0N@3oool002l0oooo00<000000?ooo`3oool0
L@3oool2000008l0oooo00<000000?ooo`3oool0N@3oool002l0oooo00<000000?ooo`3oool0L03o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo07T0oooo000_0?ooo`030000003oool0
oooo06h0oooo0P00000R0?ooo`<000000`3oool5000004h0oooo1@0000030?ooo`<00000303oool0
0`000000oooo0?ooo`1i0?ooo`00;`3oool00`000000oooo0?ooo`1/0?ooo`8000008`3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`04
0?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`1i0?ooo`00;`3oool0
0`000000oooo0?ooo`1Z0?ooo`800000703oool200000080oooo0`0000060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0A@3oool200000080oooo0`0000030?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1i0?ooo`00;`3oool00`00
0000oooo0?ooo`1Y0?ooo`030000003oool0oooo01d0oooo00@000000?ooo`3oool000001P3oool2
000000D0oooo00<000000?ooo`3oool0AP3oool010000000oooo0?ooo`0000060?ooo`030000003o
ool0oooo00@0oooo0P00000<0?ooo`030000003oool0oooo07T0oooo000_0?ooo`030000003oool0
oooo06L0oooo0P00000P0?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo07T0oooo000_0?ooo`030000003oool0oooo
06D0oooo0P00000R0?ooo`<000001@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool0AP3oool3000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`1i0?ooo`00;`3oool00`000000oooo0?oo
o`0B0?ooo`D00000103oool3000004D0oooo0P00000T0?ooo`040000003oool0oooo000000D0oooo
0`0000040?ooo`800000B03oool010000000oooo0?ooo`0000050?ooo`<00000103oool3000000`0
oooo00<000000?ooo`3oool0N@3oool002l0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0903oool00`000000oooo
00000002000005D0oooo00<000000?ooo`0000000P00000J0?ooo`030000003oool0oooo07T0oooo
000_0?ooo`030000003oool0oooo00T0oooo0P0000020?ooo`<00000103oool00`000000oooo0?oo
o`020?ooo`D00000@P3oool2000002L0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo07T0oooo000_0?ooo`030000003oool0oooo00X0oooo00@00000
0?ooo`3oool000001P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000440oooo
0P00000Y0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`1i0?ooo`00;`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0000000o0?ooo`800000:P3oool2000005P0oooo0P00
000N0?ooo`030000003oool0oooo07T0oooo000_0?ooo`030000003oool0oooo00X0oooo0`000007
0?ooo`030000003oool0oooo00@0oooo0P00000n0?ooo`030000003oool0oooo0:@0oooo00<00000
0?ooo`3oool0N@3oool002l0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000005
0?ooo`8000001`3oool00`000000oooo0?ooo`0j0?ooo`800000Y`3oool00`000000oooo0?ooo`1i
0?ooo`00;`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000800000B03oool20000
0:T0oooo00<000000?ooo`3oool0N@3oool002l0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0N@3oool002l0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`170?ooo`800000[03oool00`000000oooo
0?ooo`1i0?ooo`00;`3oool00`000000oooo0?ooo`090?ooo`800000A`3oool200000:h0oooo00<0
00000?ooo`3oool0N@3oool002l0oooo00<000000?ooo`3oool0D03oool200000;00oooo00<00000
0?ooo`3oool0N@3oool002l0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`2`0?oo
o`030000003oool0oooo07T0oooo000_0?ooo`030000003oool0oooo04d0oooo0P00002c0?ooo`03
0000003oool0oooo07T0oooo000_0?ooo`030000003oool0oooo04/0oooo0P00002e0?ooo`030000
003oool0oooo07T0oooo000_0?ooo`030000003oool0oooo04T0oooo0P00002g0?ooo`030000003o
ool0oooo07T0oooo000_0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0]`3oool0
0`000000oooo0?ooo`1i0?ooo`00;`3oool00`000000oooo0?ooo`160?ooo`800000^P3oool00`00
0000oooo0?ooo`1i0?ooo`00;`3oool00`000000oooo0?ooo`140?ooo`800000_03oool00`000000
oooo0?ooo`1i0?ooo`00;`3oool00`000000oooo0?ooo`120?ooo`800000_P3oool00`000000oooo
0?ooo`1i0?ooo`00;`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0;h0oooo00<0
00000?ooo`3oool0N@3oool002l0oooo00<000000?ooo`3oool0?`3oool200000<40oooo00<00000
0?ooo`3oool0N@3oool002l0oooo00<000000?ooo`3oool0?@3oool200000<<0oooo00<000000?oo
o`3oool0N@3oool002l0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`330?ooo`03
0000003oool0oooo07T0oooo000_0?ooo`030000003oool0oooo03X0oooo0P0000360?ooo`030000
003oool0oooo07T0oooo000_0?ooo`030000003oool0oooo03P0oooo0P0000380?ooo`030000003o
ool0oooo07T0oooo000_0?ooo`030000003oool0oooo03H0oooo0P00003:0?ooo`030000003oool0
oooo07T0oooo000[0?ooo`X00000:03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0<H0oooo2P00001f0?ooo`009@3oool6000000X0oooo1@00000R0?ooo`<000001P3oool200000<<0
oooo1P00000:0?ooo`D00000L@3oool002<0oooo0P00000E0?ooo`8000007`3oool4000000@0oooo
0P0000330?ooo`8000005@3oool2000006l0oooo000P0?ooo`<000006@3oool4000001X0oooo1P00
00000`3oool00000000000320?ooo`<000006@3oool4000006/0oooo000N0?ooo`800000803oool0
0`000000oooo0?ooo`0F0?ooo`P00000`P3oool200000200oooo00<000000?ooo`3oool0J03oool0
01d0oooo00<000000?ooo`3oool08@3oool2000001D0oooo2@0000310?ooo`030000003oool0oooo
0240oooo0P00001X0?ooo`006`3oool2000002H0oooo00<000000?ooo`3oool04@3oool:00000;l0
oooo0P00000V0?ooo`030000003oool0oooo06D0oooo000I0?ooo`800000:@3oool200000100oooo
3000002l0?ooo`800000:@3oool2000006D0oooo000G0?ooo`800000;@3oool00`000000oooo0?oo
o`0;0?ooo`h00000^`3oool00`000000oooo0?ooo`0[0?ooo`800000H`3oool001H0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`090?oooa000000^@3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo0600oooo000E0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool01`3oool?00000;X0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1P0?oo
o`005@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00D0oooo3000002m0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0G`3oool001@0oooo00<000000?ooo`3oool0
<`3oool2000000@0oooo2P00002o0?ooo`030000003oool0oooo03<0oooo0P00001O0?ooo`004`3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00L00000`P3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo05`0oooo000B0?ooo`030000003oool0oooo03P0oooo1P000035
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0F`3oool00140oooo00<000000?oo
o`3oool0>@3oool200000<P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1K0?oo
o`00403oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0<@0oooo0P00000l0?ooo`03
0000003oool0oooo05X0oooo000?0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
``3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo05X0oooo000?0?ooo`030000003o
ool0oooo03d0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo05T0oooo000>0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0`03oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo05P0oooo000>0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
05P0oooo000>0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0_`3oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo05L0oooo000=0?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo05L0oooo
000=0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo05H0oooo000<0?ooo`030000003oool0oooo04<0oooo00<00000
0?ooo`3oool0_03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo05H0oooo000<0?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo05H0oooo000<0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool0^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo05D0oooo000;0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo05D0oooo000;0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0^P3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo05D0oooo000;0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo05D0oooo000;0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0^@3oool00`00
0000oooo0?ooo`160?ooo`030000003oool0oooo05@0oooo000:0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo05@0
oooo000:0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0XP3oool3000001<0oooo
00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1D0?ooo`002P3oool00`000000oooo0?oo
o`170?ooo`030000003oool0oooo0:80oooo1`00000?0?ooo`030000003oool0oooo04L0oooo00<0
00000?ooo`3oool0E03oool000X0oooo00<000000?ooo`3oool07`3oool700000240oooo00<00000
0?ooo`3oool0XP3oool;000000/0oooo00<000000?ooo`3oool07`3oool600000280oooo00<00000
0?ooo`3oool0E03oool000X0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo0:80oooo400000060?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo05@0oooo000:0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`2R0?oooa@0
00000P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0E03oool000X0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0R0?oook`00000
8`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo05<0oooo000:0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`2R0?oooaD0000000<0
oooo0000003oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo05@0oooo000:
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`2R
0?oooa4000001@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0E03oool000X0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo0:80oooo3@0000090?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo05@0oooo000:0?ooo`03
0000003oool0oooo0200oooo0`00000T0?ooo`030000003oool0oooo0:80oooo2P00000<0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo05@0oooo000:0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`2R0?ooo`H00000403oool00`000000oooo0?ooo`0P0?ooo`@00000
8`3oool00`000000oooo0?ooo`1D0?ooo`002P3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo0:80oooo0P00000D0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0E03o
ool000X0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool0E03oool000/0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`2i0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0E03oool000/0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool0E@3oool000/0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`2j0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0E@3oool000`0oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool0E@3oool000`0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2l
0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0EP3oool000`0oooo00<000000?oo
o`3oool0@`3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool0EP3oool000`0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2l0?ooo`03
0000003oool0oooo04<0oooo00<000000?ooo`3oool0EP3oool000d0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
EP3oool000h0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2o0?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool0E`3oool000h0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`300?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0F03oool0
00h0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool0F03oool000h0oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`310?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0F@3oool000l0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo03d0oooo
00<000000?ooo`3oool0F@3oool00100oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`340?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0FP3oool00100oooo00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool0F`3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`370?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0F`3oool00180oooo00<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0G03oool001<0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`1S0?ooo`D00000
0P3oool5000005/0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`1M0?ooo`00503o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0GP3o
ool001D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1L0?ooo`8000000P3oool3
000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1N0?ooo`800000<P3oool0
0`000000oooo0?ooo`1O0?ooo`005P3oool00`000000oooo0?ooo`0^0?ooo`800000H03oool01000
0000oooo0?ooo`0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0G`3oool0
0`000000oooo0?ooo`0]0?ooo`800000HP3oool001L0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`1P0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1O0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0HP3oool001P0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1Q0?ooo`<000001`3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000H03oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo06<0oooo000I0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0HP3oool010000000oooo0?ooo`0000050?ooo`8000001@3oool300000680oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`1T0?ooo`006P3oool2000002L0oooo00<000000?ooo`3o
ool0H`3oool00`000000oooo0000000200000740oooo0P00000W0?ooo`030000003oool0oooo06D0
oooo000L0?ooo`<000008@3oool3000006H0oooo00<000000?ooo`3oool0M@3oool300000240oooo
0`00001X0?ooo`007`3oool2000001h0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?oo
o`1h0?ooo`8000007P3oool00`000000oooo0?ooo`1Y0?ooo`008@3oool2000001X0oooo0P00001Y
0?ooo`800000O03oool2000001X0oooo0P00001/0?ooo`008`3oool3000001<0oooo1000003[0?oo
o`<000004`3oool4000006h0oooo000V0?ooo`L000001@3oool700000?80oooo1`0000050?ooo`L0
0000LP3oool002d0oooo1@00003o0?ooo`40oooo1@00001i0?ooo`00;`3oool00`000000oooo0?oo
o`3o0?ooogl0oooo000_0?ooo`800000o`3ooon00?ooo`00;P3oool300000?l0ooooP03oool002h0
oooo0`00003o0?oooh00oooo000^0?ooo`<00000o`3ooon00?ooo`00;P3oool2000000030?ooo`00
0000oooo0?l0ooooOP3oool002d0oooo00D000000?ooo`000000oooo0000003o0?ooogl0oooo000]
0?ooo`050000003oool000000?ooo`000000o`3ooomo0?ooo`00;@3oool00`000000oooo00000002
0?ooo`030000003oool0oooo0?l0ooooO03oool002d0oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`3o0?ooog`0oooo000/0?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0o`3oooml0?ooo`00;03oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0?l0ooooO03oool002`0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`3o0?oo
og/0oooo000/0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0o`3ooomk0?oo
o`00:`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0o`3ooomk0?oo
o`00:`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0o`3ooomj0?oo
o`00:`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0o`3ooomj0?oo
o`00:`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0o`3ooomj0?oo
o`00:P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0o`3ooomj0?ooo`00:P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0o`3ooomi0?ooo`00:P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0o`3ooomi0?ooo`00;`3oool00`000000oooo0?ooo`3o
0?ooogl0oooo000_0?ooo`030000003oool0oooo0?l0ooooO`3oool002l0oooo00<000000?ooo`3o
ool0o`3ooomo0?ooo`00;`3oool00`000000oooo0?ooo`3o0?ooogl0oooo000_0?ooo`030000003o
ool0oooo0?l0ooooO`3oool002l0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00;`3oool00`00
0000oooo0?ooo`3o0?ooogl0oooo000_0?ooo`030000003oool0oooo0?l0ooooO`3oool002l0oooo
00<000000?ooo`3oool0o`3ooomo0?ooo`00;`3oool00`000000oooo0?ooo`3o0?ooogl0oooo000_
0?ooo`030000003oool0oooo0?l0ooooO`3oool002l0oooo00<000000?ooo`3oool0o`3ooomo0?oo
o`00;`3oool00`000000oooo0?ooo`3o0?ooogl0oooo000_0?ooo`030000003oool0oooo0?l0oooo
O`3oool002l0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00;`3oool00`000000oooo0?ooo`3o
0?ooogl0oooo000_0?ooo`030000003oool0oooo0?l0ooooO`3oool002l0oooo00<000000?ooo`3o
ool0o`3ooomo0?ooo`00;`3oool00`000000oooo0?ooo`3o0?ooogl0oooo000:0?ooo`D000001`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3o
oomo0?ooo`00303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooogl0oooo000<0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0?l0ooooO`3oool000040?ooo`00000000000?ooo`<000001@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo100000050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0o`3ooomo0?ooo`000P3oool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`3o0?ooogl0oooo00020?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool0oooo0P0000070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooO`3oool00080oooo0P00
00030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`000P3oool0
0`000000oooo00000002000000d0oooo00<000000?ooo`3oool00`3oool7000000D0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooogl0oooo00020?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`000P3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0?l0ooooO`3oool000030?ooo`000000000001<0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooO`3oool002l0oooo00<0
00000?ooo`3oool0o`3ooomo0?ooo`00;`3oool00`000000oooo0?ooo`3o0?ooogl0oooo000_0?oo
o`030000003oool0oooo0?l0ooooO`3oool002l0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00
;`3oool00`000000oooo0?ooo`3o0?ooogl0oooo000_0?ooo`030000003oool0oooo0?l0ooooO`3o
ool002l0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00;`3oool00`000000oooo0?ooo`3o0?oo
ogl0oooo000_0?ooo`030000003oool0oooo0?l0ooooO`3oool002l0oooo00<000000?ooo`3oool0
o`3ooomo0?ooo`00;`3oool00`000000oooo0?ooo`3o0?ooogl0oooo000_0?ooo`030000003oool0
oooo0?l0ooooO`3oool002l0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00;`3oool00`000000
oooo0?ooo`3o0?ooogl0oooo000_0?ooo`030000003oool0oooo0?l0ooooO`3oool002l0oooo00<0
00000?ooo`3oool0o`3ooomo0?ooo`00;`3oool00`000000oooo0?ooo`3o0?ooogl0oooo000_0?oo
o`030000003oool0oooo0?l0ooooO`3oool002l0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00
;`3oool00`000000oooo0?ooo`3o0?ooogl0oooo000_0?ooo`030000003oool0oooo0?l0ooooO`3o
ool002l0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {391.625, 0}} -> {-0.638953, -3.62503, \
0.0201087, 0.0201087}}],

Cell["\<\
Fig. 4.- Biokinetic data for iodine (taken from Publication 78/56): \
\>", "Text"],

Cell["\<\
The first step is to define the compartmental matrix for iodine.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CompartMatrix[
        4, {{1, 2, \ k\_12}, {1, 4, k\_14}, {2, 3, k\_23}\ , {3, 0, 
            k\_30}\ , {3, 1, k\_31}, {4, 0, k\_40}}] // MatrixForm\)], "Input",\

  CellLabel->"In[14]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(-k\_12\) - k\_14\), "0", \(k\_31\), "0"},
            {\(k\_12\), \(-k\_23\), "0", "0"},
            {"0", \(k\_23\), \(\(-k\_30\) - k\_31\), "0"},
            {\(k\_14\), "0", "0", \(-k\_40\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[14]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "The halt-life of  the blood is 0.25 days, the uptake to thyroid is 30% and \
to the bladder is  70%,  the halt-life of Thyroid is 80 days, and the \
halt-life of \"Rest of Body\" is 12 days to 20 % faecal excretion and 80% to \
blood, therefore the rate transfer are, in ",
  Cell[BoxData[
      \(TraditionalForm\`d\^\(-1\)\)]],
  ": Blood (Log[2]/0.25), compartment 1, Thyroid (Log[2]/80), compartment 2 \
and Rest of body (Log[2]/12, compartment 4. As usual, the rate transfers from \
bladder is 12 ",
  Cell[BoxData[
      \(TraditionalForm\`d\^\(-1\)\)]],
  ", also it mush be added URI (compartment 5), ULI(compartment 6), LLI \
(Compartment 7) and FEC (compartment 8) . So, the rate transfer coefficients \
are:"
}], "Text"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"From\"\>", "\<\"to\"\>", "\<\"Rate \
transfer(\\!\\(days\\^\\(-1\\)\\))\"\>"},
          {"1", "2", "0.8317766166719344`"},
          {"1", "4", "1.9408121055678467`"},
          {"2", "3", \(Log[2]\/80\)},
          {"3", "6", "0.011552453009332421`"},
          {"3", "1", "0.046209812037329684`"},
          {"4", "5", "12"},
          {"6", "7", \(k\_ULI\)},
          {"7", "8", \(k\_LLI\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"From", "to", 
          "Rate transfer(\!\(days\^\(-1\)\))"}}]]]], "Output"],

Cell["\<\
Now it can be built the compartmental matrix for iodine adding GI System \
compartments and the rate transfer values\
\>", "MathCaption"],

Cell[BoxData[
    \(\(iodineMatrix\  = 
        CompartMatrix[
          8, {{1, 2, 0.83}, {1, 4, 1.94}, {2, 3, Log[2]\/80}, {3, 6, 
              0.01155}, {3, 1, 0.0462}, {4, 5, 12}, {6, 7, k\_ULI}, {7, 8, 
              k\_LLI}}];\)\)], "Input",
  CellLabel->"In[15]:="],

Cell["Here it is shown in matrix form  ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(iodineMatrix\  // MatrixForm\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-2.77`\), "0", "0.0462`", "0", "0", "0", "0", "0"},
            {"0.83`", \(-\(Log[2]\/80\)\), "0", "0", "0", "0", "0", "0"},
            {"0", \(Log[2]\/80\), \(-0.057749999999999996`\), "0", "0", "0", 
              "0", "0"},
            {"1.94`", "0", "0", \(-12\), "0", "0", "0", "0"},
            {"0", "0", "0", "12", "0", "0", "0", "0"},
            {"0", "0", "0.01155`", "0", "0", \(-k\_ULI\), "0", "0"},
            {"0", "0", "0", "0", "0", \(k\_ULI\), \(-k\_LLI\), "0"},
            {"0", "0", "0", "0", "0", "0", \(k\_LLI\), "0"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[16]//MatrixForm="]
}, Open  ]],

Cell["\<\
Here are supposed inputs Acute, Constant, Continuos and MultiInputs of iodine \
131 retention (half-life = 8.0 days), it is modeling taken  f1 = 1.\
\>", "MathCaption"],

Cell["\<\
We will suppose the following inputs for continuous and multiinputs \
examples\
\>", "Text"],

Cell[TextData[{
  "The input format fot continuous intake is as follows ",
  Cell[BoxData[
      \(TraditionalForm\`{f(t), \ t\ }\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " =  and intput fnction varaible in the time , ej.:1.2 Exp[-0.3 t], t is \
the variable."
}], "Text"],

Cell[BoxData[
    \(\(inputs1\  = {1.2\ Exp[\(-0.3\)\ t], t};\)\)], "Input",
  CellLabel->"In[17]:="],

Cell[TextData[{
  "The input format fot multiple single intakes  is as follow ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              FormBox[
                RowBox[{" ", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{
                        FormBox[\(I\_1\),
                          "TraditionalForm"], ",", " ", \(t\_1\)}], "}"}], 
                    ",", \(\(...\)\(.\)\), ",", " "}]}],
                "TraditionalForm"], \({I\_j, \ \ t\_j}\)}], ",", " ", "...", 
            ",", \({I\_n, \ \ t\_n}\)}], " ", "}"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`I\_j\)]],
  " = intake de day ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ": {{1,0}, {3,4}, {7, 6}}.  "
}], "Text"],

Cell[BoxData[
    \(\(inputs2\  = \ {{1, 0}, {3, 4}, {7, 6}};\)\)], "Input",
  CellLabel->"In[18]:="],

Cell[TextData[{
  "All examples about inhalation are assumed AMAD 5 for reference workers, \
for this reason it is used ",
  StyleBox["AMADAdultW[5]", "Input"]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Injection", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Injection\",ShowReport\[Rule] \"Automatic\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, t1, Log[2]/8.0, 
        IntakeWay \[Rule] \ "\<Injection\>", 
        IntakeType \[Rule] \ "\<Acute\>"] // TableForm\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(qDailyUrine[
                t1] \[Rule] \(-34208.26392060307`\)\ \
\[ExponentialE]\^\(\(-12.086643397569993`\)\ t1\) + 
                13.620461945768044`\ \
\[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) - 
                0.0016898383851086766`\ \
\[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) + 
                0.0015742244292819008`\ \
\[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\) + 
                0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\)\)},
          {\(qDailyFaecal[t1] \[Rule] 
              0.00006279594703397945`\ \
\[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) - 
                0.00017320288018635911`\ \
\[ExponentialE]\^\(\(-1.8866433975699932`\)\ t1\) + 
                0.00019426725625175197`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) - 
                0.0006463076424387312`\ \
\[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) + 
                0.0005659109024308273`\ \
\[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\) + 
                0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\)\)},
          {\(qWholebody[
                t1] \[Rule] \(-0.2101841291828041`\)\ \
\[ExponentialE]\^\(\(-12.086643397569993`\)\ t1\) + 
                0.9105891213461222`\ \
\[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) - 
                0.00003429999448614876`\ \
\[ExponentialE]\^\(\(-1.8866433975699932`\)\ t1\) + 
                0.00011305901804593418`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) - 
                0.037693823374029656`\ \
\[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) + 
                0.3372100721871517`\ \
\[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\) + 
                0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {qDailyUrine[ t1] -> Plus[ 
          Times[ -34208.263920603073, 
            Power[ E, 
              Times[ -12.086643397569993, t1]]], 
          Times[ 13.620461945768044, 
            Power[ E, 
              Times[ -2.8565990345907886, t1]]], 
          Times[ -.0016898383851086766, 
            Power[ E, 
              Times[ -.14677556138819206, t1]]], 
          Times[ .0015742244292819008, 
            Power[ E, 
              Times[ -.09296993648799734, t1]]], 
          Times[ 0.0, 
            Power[ E, 
              Times[ -.086643397569993161, t1]]]], qDailyFaecal[ t1] -> Plus[ 
        
          Times[ .000062795947033979446, 
            Power[ E, 
              Times[ -2.8565990345907886, t1]]], 
          Times[ -.00017320288018635911, 
            Power[ E, 
              Times[ -1.8866433975699932, t1]]], 
          Times[ .00019426725625175197, 
            Power[ E, 
              Times[ -1.0866433975699932, t1]]], 
          Times[ -.00064630764243873116, 
            Power[ E, 
              Times[ -.14677556138819206, t1]]], 
          Times[ .00056591090243082731, 
            Power[ E, 
              Times[ -.09296993648799734, t1]]], 
          Times[ 0.0, 
            Power[ E, 
              Times[ -.086643397569993161, t1]]]], qWholebody[ t1] -> Plus[ 
          Times[ -.2101841291828041, 
            Power[ E, 
              Times[ -12.086643397569993, t1]]], 
          Times[ .91058912134612224, 
            Power[ E, 
              Times[ -2.8565990345907886, t1]]], 
          Times[ -.000034299994486148757, 
            Power[ E, 
              Times[ -1.8866433975699932, t1]]], 
          Times[ .00011305901804593418, 
            Power[ E, 
              Times[ -1.0866433975699932, t1]]], 
          Times[ -.037693823374029656, 
            Power[ E, 
              Times[ -.14677556138819206, t1]]], 
          Times[ .33721007218715171, 
            Power[ E, 
              Times[ -.09296993648799734, t1]]], 
          Times[ 0.0, 
            Power[ E, 
              Times[ -.086643397569993161, t1]]]]}]]], "Output",
  CellLabel->"Out[19]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, t1, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Injection\>", 
      IntakeType \[Rule] \ "\<Constant\>"]\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({qDailyUrine[
          t1] \[Rule] \(\(0.65137135223834`\)\(\[InvisibleSpace]\)\) + 
          2830.253428961148`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t1\
\) - 4.768069225269898`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) + 
          0.011513077307463954`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\
\ t1\) - 0.016932618099455787`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ \
t1\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\), 
      qDailyFaecal[
          t1] \[Rule] \(\(0.001792119983092151`\)\(\[InvisibleSpace]\)\) - 
          0.000021982765615187233`\ \[ExponentialE]\^\(\(-2.8565990345907886`\
\)\ t1\) + 
          0.00009180477901093835`\ \
\[ExponentialE]\^\(\(-1.8866433975699932`\)\ t1\) - 
          0.0001787773769078082`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\
\ t1\) + 0.004403373670153296`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ \
t1\) - 0.006087031182428371`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ \
t1\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\), 
      qWholebody[
          t1] \[Rule] \(\(3.6717375376454906`\)\(\[InvisibleSpace]\)\) + 
          0.017389784927803978`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t1\) - 0.31876686588482495`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ \
t1\) + 0.000018180433318944818`\ \[ExponentialE]\^\(\(-1.8866433975699932`\)\ \
t1\) - 0.00010404426907554259`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ \
t1\) + 0.25681266702388567`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\
\) - 3.627087259876599`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ \
t1\)}\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs1, t, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Injection\>", 
      IntakeType \[Rule] \ "\<Continuous\>"]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \({qDailyUrine[t] \[Rule] 
        3482.748677472231`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t\) \
- 6.393084763695755`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ t\) + 
          1.037606457710016`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.013234220862559876`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\
\ t\) + 0.009124613513094015`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ \
t\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999317`\)\ t\), 
      qDailyFaecal[
          t] \[Rule] \(-0.0000294747574497292`\)\ \
\[ExponentialE]\^\(\(-2.8565990345907886`\)\ t\) + 
          0.00013099569603475575`\ \
\[ExponentialE]\^\(\(-1.8866433975699932`\)\ t\) - 
          0.0002963486482213309`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\
\ t\) + 0.0019757009662402514`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.00506165451120609`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ \
t\) + 0.0032801665197655927`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ t\
\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999317`\)\ t\), 
      qWholebody[t] \[Rule] 
        0.02139887892691861`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t\) - 0.427406461017555`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ t\) + 
          0.000025941552743620058`\ \[ExponentialE]\^\(\(-1.8866433975699932`\
\)\ t\) - 
          0.00017246801037702658`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t\) - 
          1.2531982319276416`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.2952047888615976`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ \
t\) + 1.9545571293375088`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ t\)}\
\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs2, t, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Injection\>", 
      IntakeType \[Rule] \ "\<MultiInputs\>"]\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \({qDailyUrine[
          t] \[Rule] \(-239457.84744747943`\)\ \
\[ExponentialE]\^\(\(-12.086643397569993`\)\ t\) + 
          95.4781623013745`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ t\) \
- 0.016309213767230053`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ t\) + 
          0.01584209173017903`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ \
t\) + 3.3306690738754696`*^-16\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ \
t\), qDailyFaecal[t] \[Rule] 
        0.0004401937061056645`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ \
t\) - 0.0012243610086839836`\ \[ExponentialE]\^\(\(-1.8866433975699932`\)\ \
t\) + 0.0014264816825780913`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ \
t\) - 0.006237738231546836`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ \
t\) + 0.005695002733191706`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ \
t\) + 4.163336342344337`*^-17\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ \
t\), qWholebody[
          t] \[Rule] \(-1.4712889042996455`\)\ \
\[ExponentialE]\^\(\(-12.086643397569993`\)\ t\) + 
          6.383144438413431`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ \
t\) - 0.0002424646507132599`\ \[ExponentialE]\^\(\(-1.8866433975699932`\)\ \
t\) + 0.0008301791120362134`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ \
t\) - 0.36379610531318674`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ t\) \
+ 3.3934887532942035`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ t\) + 
          0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t\)}\)], "Output",\

  CellLabel->"Out[22]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Injection\",ShowReport\[Rule] \"BioassayTable\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, 180, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Injection\>", 
      IntakeType \[Rule] \ "\<Acute\>", \ 
      ShowReport \[Rule] \ "\<BioassayTable\>"]\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nstart intake"\), \("Urine\n24 hours"\), \("Faecal\n\
24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "0.5899211302482801`", "4.810149685688094`*^-7", 
            "0.3270824319414226`"},
          {"2", "0.04502213089115897`", "6.330940435164317`*^-6", 
            "0.2549074507199071`"},
          {"3", "0.002687607281144743`", "0.00001892991335419267`", 
            "0.2310446257586514`"},
          {"4", "0.00029440218980415056`", "0.00003327958927993056`", 
            "0.21154117420230936`"},
          {"5", "0.0001863119971057069`", "0.00004610086338463068`", 
            "0.19375169918729102`"},
          {"6", "0.0002012061574181184`", "0.00005634097869891433`", 
            "0.17741354439640403`"},
          {"7", "0.0002163596346389766`", "0.00006396417237252404`", 
            "0.16240861372376245`"},
          {"8", "0.00022599813555836124`", "0.00006927242376895959`", 
            "0.1486340848766285`"},
          {"9", "0.00023086240174713906`", "0.00007263855485319711`", 
            "0.13599455583329428`"},
          {"10", "0.00023189293551307755`", "0.00007441659556428531`", 
            "0.12440124802187691`"},
          {"20", "0.0001554746100638569`", "0.00005382858526160801`", 
            "0.05052427534763946`"},
          {"30", "0.00007609896611510413`", "0.000026881239289705515`", 
            "0.020269270014819953`"},
          {"40", "0.00003343028346837647`", "0.000011908188344632569`", 
            "0.00807547489383981`"},
          {"50", "0.000013976618811377451`", "4.999155390371396`*^-6", 
            "0.0032046236546888593`"},
          {"60", "5.69653131926705`*^-6", "2.0420049506927214`*^-6", 
            "0.0012687991698895837`"},
          {"70", "2.2898227776797783`*^-6", "8.218179883263365`*^-7", 
            "0.0005016869747537112`"},
          {"80", "9.133067616965394`*^-7", "3.2801173427405547`*^-7", 
            "0.0001982156017475489`"},
          {"90", "3.626638737456137`*^-7", "1.3030124711359005`*^-7", 
            "0.00007827944499739606`"},
          {"100", "1.436419762437113`*^-7", "5.1620811880473595`*^-8", 
            "0.00003090607647085964`"},
          {"180", "8.497636970621115`*^-11", "3.054764483612677`*^-11", 
            "1.8203631953369417`*^-8"},
          {"200", "1.3237033883890542`*^-11", "4.758515208398531`*^-12", 
            "2.8355246603456273`*^-9"},
          {"300", "1.2138568744312575`*^-15", "4.363639782546538`*^-16", 
            "2.600168026130205`*^-13"},
          {"400", "1.1131007812287835`*^-19", "4.001436236569797`*^-20", 
            "2.3843410632580736`*^-17"},
          {"500", "1.0207078334904261`*^-23", "3.669296959342583`*^-24", 
            "2.1864287951048615`*^-21"},
          {"600", "9.359839633748046`*^-28", "3.3647269062889567`*^-28", 
            "2.0049442378403972`*^-25"},
          {"700", "8.582925994573265`*^-32", "3.0854376953746164`*^-32", 
            "1.838523809166947`*^-29"},
          {"800", "7.870500084500151`*^-36", "2.8293308898993107`*^-36", 
            "1.6859171108492526`*^-33"},
          {"900", "7.217209098538441`*^-40", "2.59448223392703`*^-40", 
            "1.5459775339772129`*^-37"},
          {"1000", "6.618144541362424`*^-44", "2.379127194416989`*^-44", 
            "1.417653643931711`*^-41"},
          {"2000", "0", "0", "0"},
          {"3000", "0", "0", "0"},
          {"4000", "0", "0", "0"},
          {"5000", "0", "0", "0"},
          {"6000", "0", "0", "0"},
          {"7000", "0", "0", "0"},
          {"8000", "0", "0", "0"},
          {"9000", "0", "0", "0"},
          {"10000", "0", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nstart intake", 
          "Urine\n24 hours", "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
  CellLabel->"Out[23]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, 180, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Injection\>", 
      IntakeType \[Rule] \ "\<Constant\>", \ 
      ShowReport \[Rule] \ "\<BioassayTable\>"]\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nstart intake"\), \("Urine\n24 hours"\), \("Faecal\n\
24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "0.3878381364291901`", "9.176329629489999`*^-8", 
            "0.5700646140671561`"},
          {"2", "0.6301515503002093`", "2.8105019333558417`*^-6", 
            "0.8505000374449936`"},
          {"3", "0.6450676681606259`", "0.000015081470603107844`", 
            "1.092732065711199`"},
          {"4", "0.6460459193330201`", "0.00004122102844203301`", 
            "1.313855424294744`"},
          {"5", "0.6462575759906037`", "0.00008110597088585591`", 
            "1.5163748965628239`"},
          {"6", "0.6464503124675542`", "0.0001325520334276859`", 
            "1.7018418889208373`"},
          {"7", "0.6466595472772503`", "0.0001929123908891928`", 
            "1.8716462756269845`"},
          {"8", "0.646881165376568`", "0.0002597081499848272`", 
            "2.027069170932001`"},
          {"9", "0.6471099524601445`", "0.000330810146859817`", 
            "2.169292705252825`"},
          {"10", "0.6473416139303265`", "0.00040445640415035845`", 
            "2.2994069535364083`"},
          {"20", "0.6493452070894579`", "0.0010778007392985445`", 
            "3.1203973890744465`"},
          {"30", "0.6504712808043402`", "0.001471795181072693`", 
            "3.451899110900291`"},
          {"40", "0.6509929807091979`", "0.0016568470315002984`", 
            "3.584457265050772`"},
          {"50", "0.6512166874382217`", "0.0017366921671216028`", 
            "3.6371714908158403`"},
          {"60", "0.6513090815967448`", "0.0017697742111109568`", 
            "3.6580678668007693`"},
          {"70", "0.6513464925888579`", "0.0017831924295473797`", 
            "3.6663361806215087`"},
          {"80", "0.6513614755726529`", "0.001788571568799132`", 
            "3.66960431593598`"},
          {"90", "0.6513674391552948`", "0.00179071377123503`", 
            "3.670895278630271`"},
          {"100", "0.651369804387695`", "0.0017915636649190742`", 
            "3.671405044014441`"},
          {"180", "0.6513713513242969`", "0.0017921196545080745`", 
            "3.671737341843718`"},
          {"200", "0.6513713520959596`", "0.0017921199319083196`", 
            "3.671737507146092`"},
          {"300", "0.6513713522383267`", "0.001792119983087457`", 
            "3.6717375376426937`"},
          {"400", "0.65137135223834`", "0.0017921199830921546`", 
            "3.67173753764549`"},
          {"500", "0.65137135223834`", "0.001792119983092151`", 
            "3.6717375376454906`"},
          {"600", "0.65137135223834`", "0.001792119983092151`", 
            "3.6717375376454906`"},
          {"700", "0.65137135223834`", "0.001792119983092151`", 
            "3.6717375376454906`"},
          {"800", "0.65137135223834`", "0.001792119983092151`", 
            "3.6717375376454906`"},
          {"900", "0.65137135223834`", "0.001792119983092151`", 
            "3.6717375376454906`"},
          {"1000", "0.65137135223834`", "0.001792119983092151`", 
            "3.6717375376454906`"},
          {"2000", "0.65137135223834`", "0.001792119983092151`", 
            "3.6717375376454906`"},
          {"3000", "0.65137135223834`", "0.001792119983092151`", 
            "3.6717375376454906`"},
          {"4000", "0.65137135223834`", "0.001792119983092151`", 
            "3.6717375376454906`"},
          {"5000", "0.65137135223834`", "0.001792119983092151`", 
            "3.6717375376454906`"},
          {"6000", "0.65137135223834`", "0.001792119983092151`", 
            "3.6717375376454906`"},
          {"7000", "0.65137135223834`", "0.001792119983092151`", 
            "3.6717375376454906`"},
          {"8000", "0.65137135223834`", "0.001792119983092151`", 
            "3.6717375376454906`"},
          {"9000", "0.65137135223834`", "0.001792119983092151`", 
            "3.6717375376454906`"},
          {"10000", "0.65137135223834`", "0.001792119983092151`", 
            "3.6717375376454906`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nstart intake", 
          "Urine\n24 hours", "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
  CellLabel->"Out[24]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs1, 180, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Injection\>", 
      IntakeType \[Rule] \ "\<Continuous\>", \ 
      ShowReport \[Rule] \ "\<BioassayTable\>"]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nstart intake"\), \("Urine\n24 hours"\), \("Faecal\n\
24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "0.4178161248320853`", "1.0510363973131898`*^-7", 
            "0.5731209363837597`"},
          {"2", "0.5460488321799564`", "3.0484081123955835`*^-6", 
            "0.7136066436812707`"},
          {"3", "0.4190294298863402`", "0.0000153091697947363`", 
            "0.7791732859714813`"},
          {"4", "0.31138481893135883`", "0.000038813574435136545`", 
            "0.8059664076219502`"},
          {"5", "0.2308966345513772`", "0.00007043549903281953`", 
            "0.8065719232901711`"},
          {"6", "0.1712526590259238`", "0.00010578007360047907`", 
            "0.7893792443108285`"},
          {"7", "0.12708440177516933`", "0.00014113784541586673`", 
            "0.7604392309243526`"},
          {"8", "0.0943764462329193`", "0.00017394339701269954`", 
            "0.7241220857497654`"},
          {"9", "0.07015310566704303`", "0.00020266053871680875`", 
            "0.6835629057674886`"},
          {"10", "0.05221089452738892`", "0.0002265313883063314`", 
            "0.6409889628132013`"},
          {"20", "0.003290491885742486`", "0.0002470446473268424`", 
            "0.2856712593206444`"},
          {"30", "0.0005270502501897312`", "0.00013995645014970234`", 
            "0.11639242958662274`"},
          {"40", "0.00019044658606340303`", "0.00006532543053220903`", 
            "0.04658349519131743`"},
          {"50", "0.00007909439261329781`", "0.000028122145096740937`", 
            "0.01852459029268278`"},
          {"60", "0.00003251931033967925`", "0.000011639024787866775`", 
            "0.007342781154294736`"},
          {"70", "0.000013154500998754232`", "4.7180757176705414`*^-6", 
            "0.0029052594213583595`"},
          {"80", "5.266450397237166`*^-6", "1.8907800504696628`*^-6", 
            "0.0011482989278642235`"},
          {"90", "2.0957928950342698`*^-6", "7.528491618514804`*^-7", 
            "0.00045358738839894536`"},
          {"100", "8.311338028165567`*^-7", "2.9865210138324343`*^-7", 
            "0.00017910724402275615`"},
          {"180", "4.925335508757684`*^-10", "1.7705766291734331`*^-10", 
            "1.0551271941918479`*^-7"},
          {"200", "7.672467178523117`*^-11", "2.758135501899616`*^-11", 
            "1.6435423445642973`*^-8"},
          {"300", "7.03582934275552`*^-15", "2.529278813484757`*^-15", 
            "1.5071248911698649`*^-12"},
          {"400", "6.451821124841107`*^-19", "2.3193363328783454`*^-19", 
            "1.382025985657532`*^-16"},
          {"500", "5.91628761255349`*^-23", "2.1268197847736613`*^-23", 
            "1.2673108966000447`*^-20"},
          {"600", "5.4252060642240834`*^-27", "1.9502830743759708`*^-27", 
            "1.162117735267457`*^-24"},
          {"700", "4.974886747656755`*^-31", "1.7883997964439248`*^-31", 
            "1.065656133980965`*^-28"},
          {"800", "4.5619461902618715`*^-35", "1.6399536423622456`*^-35", 
            "9.772013294589978`*^-33"},
          {"900", "4.183281771011619`*^-39", "1.503829263716301`*^-39", 
            "8.96088717407508`*^-37"},
          {"1000", "3.836048413555845`*^-43", "1.3790038926612053`*^-43", 
            "8.217088590224982`*^-41"},
          {"2000", "1.612702297929653`*^-83", "5.797426051723714`*^-84", 
            "3.4545188721340407`*^-81"},
          {"3000", "6.803666531213586`*^-124", "2.4393096712317205`*^-124", 
            "1.452302784239992`*^-121"},
          {"4000", "8.465585081046682`*^-164", "1.5042015158029661`*^-164", 
            "6.105577810342711`*^-162"},
          {"5000", "1.3140749823527033`*^-201", "1.1322733464446837`*^-202", 
            "2.566825651144055`*^-202"},
          {
            "6000", \(-1.8746210173695387`*^-239\), \
\(-1.6028009698509556`*^-240\), "1.079110630972518`*^-242"},
          {
            "7000", \(-4.407212831701244`*^-277\), \(-3.79020303526307`*^-278\
\), "4.536653096633011`*^-283"},
          {"8000", 
            "4.45950677945045509972626418592346`15.954589770191005*^-314", 
            "3.8129611868907236912157649173323`15.954589770191005*^-315", 
            "1.907239232796668836199230914713689`15.954589770191*^-323"},
          {
            "9000", \(-2.44762994549373`1.9866321321741427*^-352\), \
\(-2.0943637677935`1.9866321321740947*^-353\), 
            "8.018160995864871691362898845344`15.954589770191014*^-364"},
          {"10000", "2.46288927692799`2.6180807201295657*^-389", 
            "2.10742072149509`2.61808072012953*^-390", 
            "3.37088838411404562011352830145`15.954589770191024*^-404"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nstart intake", 
          "Urine\n24 hours", "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
  CellLabel->"Out[25]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs2, 180, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Injection\>", 
      IntakeType \[Rule] \ "\<MultiInputs\>", \ 
      ShowReport \[Rule] \ "\<BioassayTable\>"]\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nlast intake"\), \("Urine\n24 hours"\), \("Faecal\n\
24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "4.137727093216034`", "0.00012412101721514214`", 
            "3.1451195145896746`"},
          {"2", "0.31626412094308365`", "0.0002134277746547855`", 
            "2.5676097625229066`"},
          {"3", "0.019603049361077575`", "0.0003434505384864355`", 
            "2.3345620337057267`"},
          {"4", "0.0028963267363966995`", "0.00047639665662053526`", 
            "2.1374301006272547`"},
          {"5", "0.002183156324766915`", "0.0005895155967093696`", 
            "1.9572593724210832`"},
          {"6", "0.0023119715164329987`", "0.0006766080855245779`", 
            "1.7918261785084133`"},
          {"7", "0.0024264751864792066`", "0.0007387637782103382`", 
            "1.6399466114475005`"},
          {"8", "0.0024895280566864224`", "0.0007793430151404029`", 
            "1.500568802265331`"},
          {"9", "0.002509104093264984`", "0.0008020396366597736`", 
            "1.3727165150541747`"},
          {"10", "0.0024941059564617227`", "0.0008102497677144343`", 
            "1.255482238754328`"},
          {"20", "0.00160158599397087`", "0.0005558431424361736`", 
            "0.5092721809988108`"},
          {"30", "0.0007743377950451191`", "0.0002737765477785892`", 
            "0.2041683884815531`"},
          {"40", "0.0003383868986956837`", "0.00012058822821159902`", 
            "0.08131075012775343`"},
          {"50", "0.00014110519442976944`", "0.00005048170623491117`", 
            "0.03225958836039911`"},
          {"60", "0.00005743090333677681`", "0.000020589450071906192`", 
            "0.012770793178230586`"},
          {"70", "0.000023067493449455814`", "8.279495698120417`*^-6", 
            "0.005049225987783382`"},
          {"80", "9.196533018142901`*^-6", "3.303039911288748`*^-6", 
            "0.0019948516486251603`"},
          {"90", "3.6509173118163744`*^-6", "1.3117650801948157`*^-6", 
            "0.0007877879006869206`"},
          {"100", "1.4458245273268754`*^-6", "5.195947136275897`*^-7", 
            "0.0003110275863477501`"},
          {"180", "8.551557834429245`*^-10", "3.07414870859638`*^-10", 
            "1.8319096310565848`*^-7"},
          {"200", "1.332100408407312`*^-10", "4.7887015217357046`*^-11", 
            "2.8535096583129272`*^-8"},
          {"300", "1.2215559406214085`*^-14", "4.391316812422206`*^-15", 
            "2.6166599651256985`*^-12"},
          {"400", "1.120160782256272`*^-18", "4.026815918646114`*^-19", 
            "2.3994640876888833`*^-16"},
          {"500", "1.0271818190022298`*^-22", "3.6925700004349895`*^-23", 
            "2.2002965326459974`*^-20"},
          {"600", "9.419205756156221`*^-27", "3.386068168232083`*^-27", 
            "2.0176608836041183`*^-24"},
          {"700", "8.637364431044452`*^-31", "3.105007525528231`*^-31", 
            "1.8501849095447606`*^-28"},
          {"800", "7.920419857689658`*^-35", "2.847276325988116`*^-35", 
            "1.6966102814028478`*^-32"},
          {"900", "7.262985280173692`*^-39", "2.6109381088077044`*^-39", 
            "1.555783117737213`*^-36"},
          {"1000", "6.6601210703421536`*^-43", "2.3942171491432666`*^-43", 
            "1.4266453150541575`*^-40"},
          {"2000", "0", "0", "0"},
          {"3000", "0", "0", "0"},
          {"4000", "0", "0", "0"},
          {"5000", "0", "0", "0"},
          {"6000", "0", "0", "0"},
          {"7000", "0", "0", "0"},
          {"8000", "0", "0", "0"},
          {"9000", "0", "0", "0"},
          {"10000", "0", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nlast intake", 
          "Urine\n24 hours", "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
  CellLabel->"Out[26]//TableForm="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Injection\",ShowReport\[Rule] \"GraphicReport\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, 180, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Injection\>", 
      IntakeType \[Rule] \ "\<Acute\>", \ 
      ShowReport \[Rule] \ "\<GraphicReport\>"]\)], "Input",
  CellLabel->"In[27]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.616435 0.0572248 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .10141 -46.5 -6.6875 ]
[-0.0125 .10141 0 6.6875 ]
[-0.0125 .21586 -46.5 -6.625 ]
[-0.0125 .21586 0 6.625 ]
[-0.0125 .33031 -46 -6.28125 ]
[-0.0125 .33031 0 6.28125 ]
[-0.0125 .44476 -34 -6.28125 ]
[-0.0125 .44476 0 6.28125 ]
[-0.0125 .55921 -22 -6.28125 ]
[-0.0125 .55921 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10141 m
.00625 .10141 L
s
gsave
-0.0125 .10141 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .21586 m
.00625 .21586 L
s
gsave
-0.0125 .21586 -107.5 -10.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.500 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.313 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
105.000 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .33031 m
.00625 .33031 L
s
gsave
-0.0125 .33031 -107 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00001) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .44476 m
.00625 .44476 L
s
gsave
-0.0125 .44476 -95 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .55921 m
.00625 .55921 L
s
gsave
-0.0125 .55921 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .04872 m
.00375 .04872 L
s
0 .06489 m
.00375 .06489 L
s
0 .0746 m
.00375 .0746 L
s
0 .08157 m
.00375 .08157 L
s
0 .087 m
.00375 .087 L
s
0 .09146 m
.00375 .09146 L
s
0 .09524 m
.00375 .09524 L
s
0 .09852 m
.00375 .09852 L
s
0 .16317 m
.00375 .16317 L
s
0 .17934 m
.00375 .17934 L
s
0 .18905 m
.00375 .18905 L
s
0 .19602 m
.00375 .19602 L
s
0 .20145 m
.00375 .20145 L
s
0 .20591 m
.00375 .20591 L
s
0 .20969 m
.00375 .20969 L
s
0 .21297 m
.00375 .21297 L
s
0 .27762 m
.00375 .27762 L
s
0 .29379 m
.00375 .29379 L
s
0 .3035 m
.00375 .3035 L
s
0 .31047 m
.00375 .31047 L
s
0 .3159 m
.00375 .3159 L
s
0 .32036 m
.00375 .32036 L
s
0 .32414 m
.00375 .32414 L
s
0 .32741 m
.00375 .32741 L
s
0 .39207 m
.00375 .39207 L
s
0 .40824 m
.00375 .40824 L
s
0 .41795 m
.00375 .41795 L
s
0 .42492 m
.00375 .42492 L
s
0 .43035 m
.00375 .43035 L
s
0 .43481 m
.00375 .43481 L
s
0 .43859 m
.00375 .43859 L
s
0 .44186 m
.00375 .44186 L
s
0 .50652 m
.00375 .50652 L
s
0 .52269 m
.00375 .52269 L
s
0 .5324 m
.00375 .5324 L
s
0 .53937 m
.00375 .53937 L
s
0 .5448 m
.00375 .5448 L
s
0 .54926 m
.00375 .54926 L
s
0 .55304 m
.00375 .55304 L
s
0 .55631 m
.00375 .55631 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Acute) show
99.000 12.813 moveto
(intake) show
141.000 12.813 moveto
(in) show
159.000 12.813 moveto
(t) show
171.000 12.813 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
183.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
189.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .60332 m
.06042 .59385 L
.08838 .58026 L
.13894 .54835 L
.20509 .49092 L
.23444 .45906 L
.26115 .42937 L
.2711 .41988 L
.28123 .41223 L
.29174 .40691 L
.30107 .40431 L
.31076 .40317 L
.31951 .40301 L
.32703 .40324 L
.3349 .40369 L
.3657 .40582 L
.37818 .40658 L
.39062 .40722 L
.40085 .40764 L
.41107 .40798 L
.41665 .40813 L
.42258 .40826 L
.42782 .40834 L
.43257 .4084 L
.43539 .40842 L
.43803 .40844 L
.44036 .40844 L
.44287 .40845 L
.44555 .40844 L
.44836 .40843 L
.45072 .40841 L
.4533 .40839 L
.45784 .40833 L
.46191 .40826 L
.47076 .40804 L
.47823 .4078 L
.48577 .40749 L
.49904 .40678 L
.51058 .40599 L
.53436 .40382 L
.55551 .40122 L
.57346 .39846 L
.60295 .39273 L
.65211 .37928 L
.69305 .3636 L
.72536 .34774 L
.75184 .33206 L
.77637 .31509 L
.79724 .29858 L
.8171 .28089 L
Mistroke
.83439 .26378 L
.84961 .24727 L
.86452 .22967 L
.87782 .2127 L
.89097 .19465 L
.90281 .17725 L
.91352 .1605 L
.92426 .14268 L
.93405 .12551 L
.94299 .109 L
.95205 .09143 L
.96037 .07451 L
.96882 .05653 L
.97619 .04014 L
Mfstroke
0 0 1 r
[ ] 0 setdash
.02381 .2549 m
.13894 .31374 L
.20509 .33966 L
.2577 .35528 L
.30107 .36503 L
.33772 .37126 L
.3667 .37499 L
.38932 .37721 L
.41107 .37879 L
.42166 .37936 L
.43106 .37976 L
.44084 .38007 L
.44612 .38019 L
.45081 .38027 L
.45313 .3803 L
.45556 .38033 L
.45783 .38034 L
.45987 .38035 L
.46224 .38036 L
.46477 .38036 L
.46713 .38035 L
.46927 .38033 L
.4731 .38029 L
.47524 .38027 L
.47721 .38023 L
.4811 .38015 L
.48524 .38005 L
.4924 .37982 L
.49894 .37955 L
.51059 .37892 L
.52332 .37803 L
.53436 .37706 L
.57035 .37259 L
.58806 .36959 L
.60327 .36654 L
.6526 .35328 L
.69364 .33766 L
.72602 .32179 L
.75256 .30607 L
.77713 .28904 L
.79803 .27244 L
.8179 .25468 L
.83521 .23748 L
.85045 .22088 L
.86538 .20318 L
.87869 .18612 L
.89064 .16969 L
.90256 .1522 L
.91334 .13535 L
.92415 .11744 L
Mistroke
.934 .10018 L
.94299 .08357 L
.9521 .0659 L
.96046 .04889 L
.96895 .03081 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[27]:=",
  ImageSize->{600, 294.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000>40001^A000`40O003h00OogooogooogooQgoo
003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mo
oomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogoo
ogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7
Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00
ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOooo
OoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomo
ohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool006aoo`L003ioo`H005Moo`@003aoo`L000=o
o`@003Moo`H000Aoo`@004moo`@000Eoo`@003=oo`L000=oo`@000Eoo`@002ioo`H000Aoo`@000Eo
o`@00?Qoo`00Kgoo00<007ooOol0?goo00<007ooOol00Woo00<007ooOol0E7oo00<007ooOol00Woo
00<007ooOol0?7oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0=7oo00<007ooOol00Woo
00D007ooOomoo`0000Aoo`03001oogoo04]oo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`0cOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0:goo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`3eOol006mo
o`03001oogoo041oo`03001oogoo05eoo`03001oogoo03aoo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo03Eoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo051oo`05001oogooOol0
0004Ool00`00Oomoo`0cOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<0
07ooOol0;7oo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo0?Eo
o`00Kgoo00<007ooOol0@Goo00<007ooOol0G7oo00<007ooOol0?7oo00<007ooOol00goo00<007oo
Ool00Woo00<007ooOol0=Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0D7oo00D007oo
Oomoo`0000Aoo`03001oogoo03=oo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0]Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool0mGoo001_Ool00`00Oomoo`12Ool00`00Oomoo`1KOol00`00Oomoo`0lOol00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`0gOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`1@Ool0
1@00Oomoogoo000017oo00<007ooOol0<goo00<007ooOol00goo00<007ooOol00Woo00D007ooOomo
o`0000Aoo`03001oogoo02ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool0
0`00Oomoo`3eOol006moo`03001oogoo04=oo`03001oogoo05Ioo`@003moo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo03Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo04aoo`@0
00Aoo`03001oogoo009oo`03001oogoo03=oo`03001oogoo00=oo`03001oogoo009oo`05001oogoo
Ool00004Ool00`00Oomoo`0_Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo
00<007ooOol0mGoo001_Ool00`00Oomoo`0oOol00`00Oomoo`02Ool00`00Oomoo`1EOol00`00Oomo
o`10Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0dOol00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00<007ooOol0C7oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0<goo00<0
07ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo02]oo`03001oogoo009o
o`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol0mGoo001]Ool30011Ool00`00
Oomoo`02Ool00`00Oomoo`1EOol00`00Oomoo`0nOol30005Ool00`00Oomoo`02Ool00`00Oomoo`0d
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0C7oo00<007ooOol01Goo00<007oo
Ool00Woo00<007ooOol0<Goo0`001Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo
02]oo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol0mGoo
001_Ool00`00Oomoo`10Ool4001HOol5000nOol00`00Oomoo`04Ool4000hOol40005Ool4001?Ool5
0004Ool4000fOol00`00Oomoo`04Ool40005Ool4000_Ool40005Ool40005Ool4003hOol00?mooomo
oomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooZgoo
0`00f7oo003oOoooOon]Ool00`00Oomoo`3FOol00?mooomoojeoo`03001oogoo0=Ioo`00ogooogoo
VGoo0`0000=oo`00000017oo1@001Goo0P001Goo1@00cGoo003oOoooOonHOol01000Oomoogoo0P00
17oo00D007ooOomoo`0000Ioo`8000Eoo`03001oogoo009oo`03001oogoo0<Yoo`00ogooogooV7oo
00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Eoo`04001oogoo0009Ool00`00Oomo
o`3:Ool0069oool00?l002D0015oo`03001oogoo009oo`03001oogoo00=oo`@000Eoo`04001oogoo
0005Ool4003=Ool0069oo`03001oogoo00Yoo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo
01Yoo`03001oogoo01=oo`03001oogoo011oo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo
00Uoo`03001oogoo00Qoo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo01Yoo`03001oogoo
01=oo`03001oogoo00moo`03001oogoo00eoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo
00Moo`03001oogoo04=oo`03001oogoo015oo`04001oogooOol20004Ool01@00Oomoogoo000017oo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo0<Yoo`00HWoo00<007ooOol02Woo00<0
07ooOol0@Woo00<007ooOol09Woo00<007ooOol06Woo00<007ooOol04goo00<007ooOol047oo00<0
07ooOol037oo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0@Woo00<0
07ooOol09Woo00<007ooOol06Woo00<007ooOol04goo00<007ooOol03goo00<007ooOol03Goo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol01goo00<007ooOol0@goo00<007ooOol04Woo0`00
00=oo`00Ool017oo0`0017oo0`000Woo0`000goo1@00c7oo001ROol00`00Oomoo`0:Ool00`00Oomo
o`12Ool00`00Oomoo`1IOol00`00Oomoo`13Ool00`00Oomoo`12Ool00`00Oomoo`1IOol00`00Oomo
o`12Ool00`00Oomoo`13Ool00`00Oomoo`0FOol00`00Oomoo`3VOol0069oo`03001oogoo00Yoo`03
001oogoo049oo`03001oogoo05Uoo`03001oogoo04=oo`03001oogoo049oo`03001oogoo05Uoo`03
001oogoo049oo`03001oogoo04=oo`03001oogoo01Ioo`03001oogoo0>Ioo`00HWoo00<007ooOol0
ogooogoo=goo0P00j7oo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mooomo
oomoob9oo`00HWoo00<007ooOol0ogooogoo57oo00<07gooOol0ogoo2goo001ROol00`00Oomoo`3o
OoooOolDOol00`0OOomoo`3oOol;Ool0069oo`03001oogoo0?mooomooa=oo`0301moogoo0?moo`ao
o`00HWoo00<007ooOol0ogooogoo4goo00<07gooOol0ogoo37oo001ROol00`00Oomoo`3oOoooOolB
Ool00`0OOomoo`3oOol=Ool0069oo`03001oogoo0?mooomooa9oo`0301moogoo0?moo`eoo`00HWoo
00<007ooOol0ogooogoo4Goo00<07gooOol0ogoo3Woo001ROol00`00Oomoo`3oOoooOolAOol00`0O
Oomoo`3oOol>Ool0069oo`03001oogoo0?mooomooa1oo`0301moogoo0?moo`moo`00HWoo00<007oo
Ool0ogooogoo47oo00<07gooOol0ogoo3goo001ROol00`00Oomoo`3oOoooOol@Ool00`0OOomoo`3o
Ool?Ool0069oo`03001oogoo0?mooomoo`moo`0301moogoo0?mooa1oo`00HWoo00<007ooOol0ogoo
ogoo3goo00<07gooOol0ogoo47oo001ROol00`00Oomoo`3oOoooOol>Ool00`0OOomoo`3oOolAOol0
069oo`03001oogoo0?mooomoo`ioo`0301moogoo0?mooa5oo`00HWoo00<007ooOol0ogooogoo3Woo
00<07gooOol0ogoo4Goo001ROol00`00Oomoo`3oOoooOol=Ool00`0OOomoo`3oOolBOol0069oo`03
001oogoo0?mooomoo`eoo`0301moogoo0?mooa9oo`00HWoo00<007ooOol0ogooogoo37oo00<07goo
Ool0ogoo4goo001ROol3003oOoooOol<Ool00`0OOomoo`03Ool00g`0Oomoo`3oOol=Ool0069oo`03
001oogoo0?mooomoo`]oo`0301moogoo00=oo`03O01oogoo0?moo`ioo`00HWoo00<007ooOol0ogoo
ogoo2goo00<07gooOol00goo00=l07ooOol0ogoo3Woo001ROol00`00Oomoo`3oOoooOol:Ool00`0O
Oomoo`03Ool00g`0Oomoo`3oOol?Ool0069oo`03001oogoo0?mooomoo`Yoo`0301moogoo00=oo`03
O01oogoo0?moo`moo`00HWoo00<007ooOol0ogooogoo2Goo00<07gooOol00goo00=l07ooOol0ogoo
47oo001ROol00`00Oomoo`3oOoooOol9Ool00`0OOomoo`03Ool00g`0Oomoo`3oOol@Ool0069oo`03
001oogoo0?mooomoo`Qoo`0301moogoo0?mooaMoo`00HWoo00<007ooOol0ogooogoo27oo00<07goo
Ool0ogoo5goo001ROol3003oOoooOol7Ool00`0OOomoo`3oOolHOol0069oo`03001oogoo0?mooomo
o`Ioo`0301moogoo0?mooaUoo`00HWoo00<007ooOol0ogooogoo1Woo00<07gooOol017oo00=l07oo
Ool0ogoo4Woo001ROol00`00Oomoo`3oOoooOol5Ool00`0OOomoo`05Ool00g`0Oomoo`3oOolBOol0
069oo`03001oogoo0?mooomoo`Eoo`0301moogoo00Aoo`03O01oogoo0?mooa=oo`00HWoo0`00ogoo
ogoo17oo00<07gooOol01Goo00=l07ooOol0ogoo4goo001ROol00`00Oomoo`3oOoooOol4Ool00`0O
Oomoo`04Ool00g`0Oomoo`3oOolDOol0069oo`03001oogoo0?mooomoo`=oo`0301moogoo00Eoo`03
O01oogoo0?mooaAoo`00HWoo00<007ooOol0ogooogoo0goo00<07gooOol017oo00=l07ooOol0ogoo
5Goo001ROol3003oOoooOol2Ool00`0OOomoo`3oOolMOol0069oo`03001oogoo0?mooomoo`9oo`03
01moogoo0?mooaeoo`00HWoo00<007ooOol0ogooogoo0Goo00<07gooOol0ogoo7Woo001ROol3003o
OoooOol1Ool00`0OOomoo`3oOolNOol0069oo`03001oogoo0?mooomoo`0301moogoo00Eoo`03O01o
ogoo0?mooaMoo`00HWoo0`00ogooogoo00<07gooOol017oo00=l07ooOol0ogoo67oo001ROol00`00
Oomoo`3oOoonOol00`0OOomoo`04Ool00g`0Oomoo`3oOolIOol001Yoo`L000Aoo`8000Moo`03001o
ogoo00=oo`03001oogoo00=oo`L000=oo`@001Yoo`<00?moooioo`0301moogoo00Aoo`03O01oogoo
0?mooaUoo`007Goo00<007ooOol01Goo0P0027oo00D007ooOomoo`0000Uoo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo01Moo`03001oogoo0?moooeoo`0301moogoo00Aoo`03O01oogoo0?mo
oaYoo`007Goo00<007ooOol047oo00<007oo00002Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol05goo0`00ogoooGoo00<07gooOol017oo00=l07ooOol0ogoo6Woo000MOol00`00Oomoo`0A
Ool00`00Oomoo`09Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0GOol4003oOookOol0
0`0OOomoo`3oOolROol001eoo`03001oogoo011oo`03001oo`0000Yoo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo01Moo`03001oogoo0?mooo]oo`0301moogoo0?moob=oo`007Goo00<007oo
Ool03goo00D007ooOomoo`0000Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo01Moo`03
001oogoo0?mooo]oo`0301moogoo0?moob=oo`007Goo00<007ooOol03Woo00<007ooOol00goo00<0
07ooOol01Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol01goo0`003Goo00<007ooOol0
ogoonWoo00<07gooOol0ogoo97oo000KOol3000MOol30005Ool00`00Oomoo`02Ool00`00Oomoo`0:
Ool00`00Oomoo`0:Ool00`00Oomoo`3oOoojOol00`0OOomoo`3oOolTOol001eoo`03001oogoo01eo
o`03001oogoo00Aoo`@000Aoo`D000Eoo`03001oogoo00Uoo`03001oogoo0?moooUoo`0301moogoo
00Eoo`03O01oogoo0?mooaeoo`00Dgoo10002goo00<007ooOol0ogoonGoo00<07gooOol017oo00=l
07ooOol0ogoo7Woo001BOol01@00Oomoogoo00002goo00<007ooOol0ogoon7oo00<07gooOol01Goo
00=l07ooOol0ogoo7Woo001BOol01@00Oomoogoo00002goo00<007ooOol0ogoon7oo00<07gooOol0
17oo00=l07ooOol0ogoo7goo001COol3000<Ool00`00Oomoo`3oOoogOol00`0OOomoo`05Ool00g`0
Oomoo`3oOolOOol0069oo`03001oogoo0?moooIoo`0301moogoo00Eoo`03O01oogoo05ioojX001Mo
o`00HWoo00<007ooOol0ogoomWoo00<07gooOol0IWooZP005goo001ROol00`00Oomoo`3oOooeOol0
0`0OOomoo`1WOonZ000GOol0069oo`03001oogoo0?moooEoo`0301moogoo06MoojX001Moo`00HWoo
00<007ooOol0ogoom7oo00<07gooOol0J7ooZP005goo001ROol00`00Oomoo`3oOoocOol00`0OOomo
o`05Ool00g`0Oomoo`1QOonZ000GOol0069oo`03001oogoo0?mooo=oo`0301moogoo00Aoo`03O01o
ogoo05]ook4001Moo`00HWoo00<007ooOol0ogoolWoo00<07gooOol01Goo00=l07ooOol0Fgoo00<0
07ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOoobOol00`0OOomoo`04Ool00g`0Oomoo`1LOol0
0`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?mooo5oo`0301moogoo00Eoo`03O01oogoo05ao
o`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogool7oo00<07gooOol01Goo00=l07ooOol0
GGoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOoo`Ool00`0OOomoo`1UOol00`00Oomo
o`2WOol7000GOol0069oo`03001oogoo0?moonmoo`0301moogoo06Ioo`03001oogoo0:Moo`L001Mo
o`00HWoo00<007ooOol0ogookWoo00<07gooOol0Igoo00<007ooOol0Ygoo1`005goo001ROol00`00
Oomoo`3oOoo^Ool00`0OOomoo`1WOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?mooneo
o`0301moogoo06Qoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogook7oo00<07gooOol0
1Woo00=l07ooOol0H7oo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOoo/Ool00`0OOomo
o`05Ool00g`0Oomoo`1QOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?moon]oo`0301mo
ogoo00Ioo`03O01oogoo065oo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoojWoo00<0
7gooOol01Woo00=l07ooOol0HWoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOooZOol0
0`0OOomoo`06Ool00g`0Oomoo`1ROol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?moonUo
o`0301moogoo00Ioo`03O01oogoo06=oo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoo
jGoo00<07gooOol0K7oo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOooXOol00`0OOomo
o`1]Ool00`00Oomoo`2WOol7000GOol0069oo`<00?moonMoo`0301moogoo06ioo`03001oogoo0:Mo
o`L001Moo`00HWoo00<007ooOol0ogooigoo00<07gooOol0KWoo00<007ooOol0Ygoo1`005goo001R
Ool00`00Oomoo`3oOooVOol00`0OOomoo`06Ool00g`0Oomoo`1VOol00`00Oomoo`2WOol7000GOol0
069oo`03001oogoo0?moonIoo`0301moogoo00Eoo`03O01oogoo06Moo`03001oogoo0:Moo`L001Mo
o`00HWoo00<007ooOol0ogooiGoo00<07gooOol01Woo00=l07ooOol0Igoo00<007ooOol0Ygoo1`00
5goo001ROol00`00Oomoo`3oOooTOol00`0OOomoo`06Ool00g`0Oomoo`1XOol00`00Oomoo`2WOol7
000GOol0069oo`03001oogoo0?moon=oo`0301moogoo00Moo`03O01oogoo06Qoo`03001oogoo0:Mo
o`L001Moo`00HWoo00<007ooOol0ogoohgoo00<07gooOol01Woo00=l07ooOol0JGoo00<007ooOol0
Ygoo1`005goo001ROol00`00Oomoo`3oOooROol00`0OOomoo`1cOol00`00Oomoo`2WOol7000GOol0
069oo`<00?moon5oo`0301moogoo07Aoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoo
h7oo00<07gooOol0MGoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOooPOol00`0OOomo
o`1eOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?moommoo`0301moogoo00Moo`03O01o
ogoo06aoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoogWoo00<07gooOol01goo00=l
07ooOol0KGoo00<007ooOol0Ygoo1`005goo001ROol3003oOooMOol00`0OOomoo`07Ool00g`0Oomo
o`1^Ool00`00Oomoo`1:Ool70002Ool30002Ool30003Ool40004Ool50005Ool40006Ool40002Ool7
0004Ool40003Ool30002Ool3000=Ool7000GOol0069oo`03001oogoo0?moomaoo`0301moogoo00Qo
o`03O01oogoo06ioo`03001oogoo04]oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo
000017oo00<007ooOol037oo1`005goo001ROol00`00Oomoo`3oOooLOol00`0OOomoo`07Ool00g`0
Oomoo`1_Ool00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`03Ool20004Ool00`00Oomoo`08
Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool01@00Oomoogoo000017oo00<007ooOol037oo1`005goo001ROol00`00Oomoo`3oOooKOol00`0O
Oomoo`07Ool00g`0Oomoo`1`Ool00`00Oomoo`1;Ool01000Oomoo`001goo0P0017oo00<007ooOol0
27oo00<007ooOol01Goo1P0017oo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00D0
07ooOomoo`0000Aoo`03001oogoo00aoo`L001Moo`00HWoo0`00ogoofWoo00<07gooOol0Ngoo00<0
07ooOol0Bgoo10001Woo00@007ooOol000Aoo`04001oogooOol20004Ool20006Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoogoo
0P000goo00<007ooOol037oo1`005goo001ROol00`00Oomoo`3oOooIOol00`0OOomoo`1lOol00`00
Oomoo`1;Ool01P00Oomoo`00Ool0009oo`<0009oo`<000=oo`<00003Ool007oo009oo`800004Ool0
00000004Ool40003Ool70003Ool30007Ool40003Ool2000017oo000000003goo1`005goo001ROol0
0`00Oomoo`3oOooIOol00`0OOomoo`1lOol00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`0V
Ool00`00Oomoo`0[Ool7000GOol0069oo`<00?moomQoo`0301moogoo07eoo`03001oogoo04Yoo`L0
02Qoo`03001oogoo02]oo`L001Moo`00HWoo00<007ooOol0ogooegoo00<07gooOol027oo00=l07oo
Ool0Lgoo00<007ooOol0Pgoo00<007ooOol08Goo1`005goo001ROol00`00Oomoo`3oOooFOol00`0O
Oomoo`08Ool00g`0Oomoo`1dOol00`00Oomoo`23Ool00`00Oomoo`0QOol7000GOol0069oo`<00?mo
omEoo`0301moogoo00Qoo`03O01oogoo07Eoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0
ogooeGoo00<07gooOol027oo00=l07ooOol0MGoo00<007ooOol0Ygoo1`005goo000JOol70004Ool2
0007Ool00`00Oomoo`03Ool00`00Oomoo`03Ool70003Ool4000JOol3003oOooDOol00`0OOomoo`08
Ool00g`0Oomoo`1fOol00`00Oomoo`2WOol7000GOol001eoo`03001oogoo00Eoo`8000Qoo`05001o
ogooOol00009Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0GOol3003oOooCOol00`0O
Oomoo`08Ool00g`0Oomoo`1gOol00`00Oomoo`0<Ool7O005Ool7O005Ool7O005Ool7O01`Ool7000G
Ool001eoo`03001oogoo011oo`03001oo`0000Yoo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo01Moo`03001oogoo0?moom9oo`0301moogoo08=oo`03001oogoo0:Moo`L001Moo`007Goo00<0
07ooOol04Goo00<007ooOol02Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol05goo1000
ogood7oo00<07gooOol0Q7oo00<007ooOol0Ygoo1`005goo000MOol00`00Oomoo`0@Ool00`00Ool0
000:Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0GOol00`00Oomoo`3oOooAOol00`0O
Oomoo`24Ool00`00Oomoo`2WOol7000GOol001eoo`03001oogoo00moo`05001oogooOol00009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0GOol00`00Oomoo`3oOoo@Ool00`0OOomoo`07
Ool00g`0Oomoo`1kOol00`00Oomoo`2WOol7000GOol001eoo`03001oogoo00ioo`03001oogoo00=o
o`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo00]o
o`03001oogoo0?moolmoo`0301moogoo00Moo`03O01oogoo07aoo`03001oogoo0:Moo`L001Moo`00
6goo0`007Goo0`001Goo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol02goo00<007ooOol0
ogoocWoo00<07gooOol027oo00=l07ooOol0O7oo00<007ooOol0Ygoo1`005goo000MOol00`00Oomo
o`0MOol00`00Oomoo`04Ool40004Ool50004Ool00`00Oomoo`0:Ool00`00Oomoo`3oOoo=Ool00`0O
Oomoo`08Ool00g`0Oomoo`1mOol00`00Oomoo`1<Ool40004Ool50003Ool70002Ool30002Ool30003
Ool4000cOol7000GOol005Eoo`03001oogoo00Yoo`03001oogoo0?moolaoo`0301moogoo00Uoo`03
O01oogoo07eoo`03001oogoo04]oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Moo`03
001oogoo00Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0`Ool7000GOol005Io
o`03001oogoo00Uoo`03001oogoo0?mool]oo`0301moogoo00Uoo`03O01oogoo07ioo`03001oogoo
04]oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo
009oo`05001oogooOol0000gOol7000GOol0059oo`05001oogooOol0000;Ool00`00Oomoo`3oOoo:
Ool00`0OOomoo`2;Ool00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`07
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoogoo1P00<Woo1`005goo001BOol5000;Ool0
0`00Oomoo`3oOoo9Ool00`0OOomoo`2<Ool00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool20008Ool00`00Oomoo`04Ool20003Ool01@00Oomoogoo000017oo00<007ooOol0<7oo1`005goo
001ROol00`00Oomoo`3oOoo8Ool00`0OOomoo`2=Ool00`00Oomoo`1;Ool00`00Oomoo`02Ool01000
Oomoogoo0P0000Aoo`00000000=oo`<000Eoo`800004Ool000000005Ool4000cOol7000GOol0069o
o`03001oogoo0?moolMoo`0301moogoo08ioo`03001oogoo04]oo`03001oogoo009oo`03001oogoo
05Aoo`L001Moo`00HWoo00<007ooOol0ogooaWoo00<07gooOol02Woo00=l07ooOol0PWoo00<007oo
Ool0BWoo0`000Woo0`00EGoo1`005goo001ROol00`00Oomoo`3oOoo5Ool00`0OOomoo`0:Ool00g`0
Oomoo`23Ool00`00Oomoo`1OOol00`00Oomoo`15Ool7000GOol0069oo`03001oogoo0?moolAoo`03
01moogoo00Yoo`03O01oogoo08Aoo`03001oogoo05moo`03001oogoo04Eoo`L001Moo`00HWoo00<0
07ooOol0ogoo`goo00<07gooOol02Woo00=l07ooOol0QGoo00<007ooOol0Ygoo1`005goo001ROol0
0`00Oomoo`3oOoo2Ool00`0OOomoo`0:Ool00g`0Oomoo`26Ool00`00Oomoo`2WOol7000GOol0069o
o`03001oogoo0?mool5oo`0301moogoo09Aoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0
ogoo`7oo00<07gooOol0UGoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOonoOol00`0O
Oomoo`2FOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?mookioo`0301moogoo09Moo`03
001oogoo0:Moo`L001Moo`00HWoo00<007ooOol02Woo00<07gooOol0ogoo/7oo00<07gooOol02goo
00=l07ooOol0RWoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`0;Ool201ooOon_Ool00`0O
Oomoo`0;Ool00g`0Oomoo`2;Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo00eoo`807omo
ojaoo`0301moogoo00]oo`03O01oogoo08aoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0
3goo0P0OogooZGoo00<07gooOol02goo00=l07ooOol0SGoo00<007ooOol0Ygoo1`005goo001ROol0
0`00Oomoo`0AOol201ooOonVOol00`0OOomoo`0;Ool00g`0Oomoo`2>Ool00`00Oomoo`2WOol7000G
Ool0069oo`03001oogoo01=oo`807omooj9oo`807imoo`03001oogoo0:Moo`L001Moo`00HWoo00<0
07ooOol05Goo0P0OogooWgoo00<07gooOol0Wgoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomo
o`0GOol201ooOonLOol00`0OOomoo`2POol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo01Uo
o`807omooiUoo`0301moogoo00aoo`03O01oogoo099oo`03001oogoo0:Moo`L001Moo`00HWoo00<0
07ooOol06goo0P0OogooUWoo00<07gooOol037oo00=l07ooOol0Tgoo00<007ooOol0Ygoo1`005goo
001ROol00`00Oomoo`0MOol201ooOonCOol00`0OOomoo`0<Ool00g`0Oomoo`2DOol00`00Oomoo`2W
Ool7000GOol0069oo`03001oogoo01moo`0301moogoo0?moohmoo`0301moogoo00aoo`03O01oogoo
09Eoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol087oo0P0OogooSGoo0P0O3Woo00=l07oo
Ool0UWoo00<007ooOol0Ygoo1`005goo001ROol3000ROol201ooOon:Ool00`0OOomoo`0=Ool00g`0
Oomoo`2GOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo02Aoo`807omoohMoo`0301moogoo
0:Qoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol09Woo0P0OogooQ7oo00<07gooOol03Goo
00=l07ooOol0VGoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`0XOol201ooOon1Ool00`0O
Oomoo`0=Ool00g`0Oomoo`2JOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo02Yoo`807omo
ogeoo`807`moo`03O01oogoo09]oo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0;7oo0P0O
ogooNWoo00<07gooOol03Woo00=l07ooOol0W7oo00<007ooOol0Ygoo1`005goo001ROol00`00Oomo
o`0^Ool201ooOomgOol00`0OOomoo`0>Ool00g`0Oomoo`2MOol00`00Oomoo`2WOol7000GOol0069o
o`03001oogoo031oo`807omoog=oo`807k5oo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0
<Woo0P0OogooL7oo00<07gooOol0/Goo00<007ooOol0Ygoo1`005goo001ROol3000dOol00`0OOomo
o`3oOom[Ool201ndOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo03Eoo`807omoofYoo`03
01moogoo00moo`03O01oogoo0:9oo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0=goo0P0O
ogooIWoo0P0O4Goo00=l07ooOol0Xgoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`0iOol2
01ooOomROol201lBOol00g`0Oomoo`2TOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo03]o
o`807omooemoo`0301moogoo015oo`03O01oogoo0:Eoo`03001oogoo0:Moo`L001Moo`00HWoo0`00
?Goo0P0OogooFgoo0P0O4goo00=l07ooOol0YWoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomo
o`0oOol201ooOomHOol00`0OOomoo`2lOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo045o
o`807omooeAoo`807kmoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0@goo0P0OogooDGoo
00<07gooOol04Goo00=l07ooOol0Zgoo00<007ooOol0Ygoo1`005goo001ROol30015Ool201ooOom=
Ool201lCOol00g`0Oomoo`2/Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo04Moo`807omo
odYoo`0301moogoo015oo`9l0:moo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0BGoo0P0O
ogooAWoo0P0O4goo00=l07ooOol0[goo00<007ooOol0Ygoo1`005goo001ROol3001;Ool201ooOom2
Ool201lDOol00g`0Oomoo`2`Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo04eoo`<07omo
ocioo`0301moogoo0<Moo`03001oogoo0:Moo`L001Moo`00HWoo0`00D7oo0P0Oogoo>Woo0P0ObWoo
00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`1BOol301ooOolfOol00`0OOomoo`0BOol00g`0
Oomoo`2eOol00`00Oomoo`2WOol7000GOol0069oo`<005Eoo`<07omooc5oo`807aAoo`03O01oogoo
0;Ioo`03001oogoo0:Moo`L001Moo`006goo10001Woo0P001Woo10001Goo10001Goo10001Goo1000
17oo1`002goo00<007ooOol0F7oo0P0Oogoo;Goo0P0O57oo0W`0^Goo00<007ooOol0Ygoo1`005goo
000JOol00`00Oomoo`02Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`02Ool01@00Oomoogoo0000
17oo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool3
001JOol301ooOolXOol201lEOol00g`0Oomoo`2iOol00`00Oomoo`2WOol7000GOol001Yoo`03001o
ogoo009oo`03001oogoo00Yoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo0000
17oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo05eoo`807omo
obAoo`807aIoo`03O01oogoo0;Yoo`03001oogoo0:Moo`L001Moo`006Woo00<007ooOol00Woo00<0
07ooOol02Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01@00Oomo
ogoo000017oo00<007ooOol017oo00<007ooOol037oo1000GWoo0`0Oogoo7goo0P0OeGoo00<007oo
Ool0Ygoo1`005goo000JOol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomo
o`0<Ool00`00Oomoo`1ROol201ooOolKOol201oGOol00`00Oomoo`1:Ool70002Ool30002Ool30003
Ool40004Ool50005Ool40006Ool40002Ool70004Ool40003Ool30002Ool3000=Ool7000GOol001Yo
o`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomo
ogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo06Ao
o`<07omooaIoo`807aMoo`03O01oogoo0;moo`03001oogoo04]oo`03001oogoo009oo`03001oogoo
009oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool01@00Oomoogoo000017oo00<007ooOol037oo1`005goo000JOol00`00Oomoo`02Ool00`00
Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`05001oogoo
Ool00004Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`1WOol301ooOolAOol201lGOol2
O032Ool00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`03Ool20004Ool00`00Oomoo`08Ool0
0`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00<007ooOol037oo1`005goo000JOol00`00Oomoo`02Ool00`00Oomoo`0:
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`05001oogooOol00004
Ool00`00Oomoo`02Ool3000>Ool00`00Oomoo`1ZOol201ooOol<Ool301lGOol2O034Ool00`00Oomo
o`1;Ool01000Oomoo`001goo0P0017oo00<007ooOol027oo00<007ooOol01Goo1P0017oo00<007oo
Ool01goo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00aoo`L0
01Moo`006goo10003Woo10001Goo10001Goo10001Goo10001goo00<007ooOol037oo00<007ooOol0
K7oo0`0Oogoo1Woo0`0O6Goo00=l07ooOol0a7oo00<007ooOol0Bgoo10001Woo00@007ooOol000Ao
o`04001oogooOol20004Ool20006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`07Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoogoo0P000goo00<007ooOol037oo1`005goo001R
Ool00`00Oomoo`1_Ool401ooOol201oSOol00`00Oomoo`1;Ool01P00Oomoo`00Ool0009oo`<0009o
o`<000=oo`<00003Ool007oo009oo`800004Ool000000004Ool40003Ool70003Ool30007Ool40003
Ool2000017oo000000003goo1`005goo001ROol00`00Oomoo`1cOol401ohOol301oUOol00`00Oomo
o`1;Ool00`00Oomoo`02Ool00`00Oomoo`0VOol00`00Oomoo`0[Ool7000GOol0069oo`03001oogoo
07Moo`<07o9oo`<07aaoo`03O01oogoo0<Uoo`03001oogoo04Yoo`L002Qoo`03001oogoo02]oo`L0
01Moo`00HWoo00<007ooOol0NWoo100Ojgoo0`0O7Goo0W`0c7oo00<007ooOol0Pgoo00<007ooOol0
8Goo1`005goo001ROol00`00Oomoo`1nOol301oVOol201lNOol2O03>Ool00`00Oomoo`23Ool00`00
Oomoo`0QOol7000GOol0069oo`03001oogoo085oo`@07mmoo`<07amoo`03O01oogoo0<ioo`03001o
ogoo0:Moo`L001Moo`00HWoo00<007ooOol0QGoo100Of7oo0`0Olgoo00<007ooOol0Ygoo1`005goo
001ROol00`00Oomoo`29Ool301oAOol401ofOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo
08aoo`@07lUoo`@07b9oo`9l0=Ioo`03001oogoo00aoobh07feoo`L001Moo`00HWoo00<007ooOol0
T7oo100O`Goo100O97oo0W`0f7oo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`2DOol401ni
Ool401lVOol2O03JOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo09Qoo`@07k5oo`@07omo
o`Moo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0W7oo100OZGoo100Oogoo2goo00<007oo
Ool0Ygoo1`005goo001ROol00`00Oomoo`2POol601nOOol401l[Ool2O03QOol00`00Oomoo`2WOol7
000GOol0069oo`03001oogoo0:Ioo`H07iEoo`@07beoo`9l0>=oo`03001oogoo0:Moo`L001Moo`00
HWoo00<007ooOol0[7oo1`0ORGoo1@0O;goo0W`0iGoo00<007ooOol0BWoo10001goo1@0017oo1000
1Goo10001Goo1@000Woo1`00:Goo1`005goo001ROol00`00Oomoo`2cOol701mnOol401ooOolLOol0
0`00Oomoo`1;Ool00`00Oomoo`06Ool01@00Oomoogoo000017oo00<007ooOol00Woo00D007ooOomo
o`0000Aoo`05001oogooOol00003Ool00`00Oomoo`04Ool00`00Oomoo`0ZOol7000GOol0069oo`03
001oogoo0;Yoo`P07fmoo`L07c5oo`9l0>aoo`03001oogoo04]oo`03001oogoo00Ioo`05001oogoo
Ool00004Ool00`00Oomoo`05Ool00`00Oomoo`07Ool01@00Oomoogoo00001Woo00<007ooOol0:Woo
1`005goo001ROol00`00Oomoo`32Ool:01mKOol:01lfOol2O03^Ool00`00Oomoo`1;Ool01000Oomo
o`001Woo100017oo1P000Woo00<007ooOol027oo10001Woo00<007ooOol0:Woo1`005goo001ROol0
0`00Oomoo`3<Ool<01m7Ool801lnOol2O03`Ool00`00Oomoo`1;Ool40005Ool01@00Oomoogoo0000
17oo00<007ooOol00Woo00D007ooOomoo`0000=oo`8000=oo`05001oogooOol00006Ool00`00Oomo
o`0ZOol7000GOol0069oo`03001oogoo0=Qoo`h07bMooa807omoocUoo`03001oogoo04]oo`06001o
ogoo001oo`0017oo0`001Woo10001Goo0`0000=oo`00Ool00goo0`001goo00<007ooOol0:Woo1`00
5goo001ROol00`00Oomoo`3VOolW01mAOol2O03gOol00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00
Oomoo`0WOol00`00Oomoo`0ZOol7000GOol0069oo`03001oogoo0?mooeaoo`=l0?Uoo`03001oogoo
04Yoo`L002Uoo`03001oogoo02Yoo`L001Moo`00HWoo00<007ooOol0ogooFWoo0W`0o7oo00<007oo
Ool0N7oo0`00;7oo1`005goo001ROol00`00Oomoo`3oOomCOol2O03oOol4Ool00`00Oomoo`2WOol7
000GOol0069oo`03001oogoo0?mooe5oo`9l0?moo`Ioo`03001oogoo0:Moo`L001Moo`00HWoo00<0
07ooOol0ogooCgoo0W`0ogoo27oo00<007ooOol0Ygoo1`005goo001ROol3003oOom9Ool00g`0Oomo
o`3oOol=Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?moodIoo`=l0?mooa1oo`03001o
ogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoo@goo0g`0ogoo4goo00<007ooOol0Ygoo1`005goo
001ROol00`00Oomoo`3oOolkOol3O03oOolKOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo
0?moocMoo`Al0?mooaioo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoo;Goo1G`0ogoo
9goo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`2VOol7O01fOol2O005Ool2O03oOol/Ool0
0`00Oomoo`2WOol7000GOol0069oo`03001oogoo09moo`=l011oo`Ml00Eoo`=l05eoo`El0?moocEo
o`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0W7oo0g`08Woo17`01Goo17`0?7oo0g`01Goo
1g`0ogoo?goo00<007ooOol0Ygoo1`005goo001ROol3002KOol00g`0Oomoo`0`Ool3O005Ool7O005
Ool7O005Ool7O005Ool7O005Ool4O03oOom>Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo
0?mooomooeUoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogooogooFGoo00<007ooOol0
Ygoo1`005goo001ROol00`00Oomoo`2FOol00g`0Oomoo`3oOonoOol00`00Oomoo`2WOol7000GOol0
069oo`03001oogoo09Eoo`03O01oogoo0?mool1oo`03001oogoo0:Moo`L001Moo`00HWoo0`00Tgoo
0W`0ogoo`goo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`2BOol00g`0Oomoo`3oOoo3Ool0
0`00Oomoo`2WOol7000GOol0069oo`03001oogoo095oo`03O01oogoo0?moolAoo`03001oogoo0:Mo
o`L001Moo`00HWoo00<007ooOol0ogooogooFGoo00<007ooOol0Ygoo1`005goo001ROol3003oOooo
OomIOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?mooomooeUoo`03001oogoo0:Moo`L0
01Moo`00HWoo00<007ooOol0SGoo00=l07ooOol0ogoob7oo00<007ooOol0Ygoo00<007ooOol06goo
001ROol3002<Ool00g`0Oomoo`3oOoo9Ool00`00Oomoo`2WOol00`00Oomoo`0KOol0069oo`03001o
ogoo08]oo`03O01oogoo0?moolYoo`03001oogoo0:Moo`03001oogoo01]oo`00HWoo00<007ooOol0
RGoo0W`0ogoocGoo00<007ooOol0Ygoo00<007ooOol06goo001ROol30028Ool00g`0Oomoo`3oOoo=
Ool00`00Oomoo`2WOol00`00Oomoo`0KOol0069oo`03001oogoo0?mooomooeUoo`03001oogoo0:Mo
o`03001oogoo01]oo`00;Goo10001Woo0P001Woo10001Goo100017oo1`002goo0`00ogooogooFGoo
Z`007Goo000/Ool00`00Oomoo`02Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00<007ooOol017oo00<007ooOol037oo00<007ooOol0ogooogooogoo8Woo000/Ool0
0`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0
17oo00<007ooOol037oo0`00ogooogooogoo8Woo000/Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool0
0`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol037oo1000Pgoo00=l
07ooOol0ogooogooVWoo000/Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01@00
Oomoogoo000017oo00<007ooOol017oo00<007ooOol037oo00<007ooOol0Pgoo00=l07ooOol0ogoo
ogooVgoo000/Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo0000
17oo00<007ooOol017oo00<007ooOol037oo00<007ooOol0PWoo00=l07ooOol0ogooogooW7oo000/
Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool017oo00<007ooOol037oo00<007ooOol0PGoo00=l07ooOol0ogooogooWGoo000/Ool00`00Oomo
o`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol00Woo0`00
3Woo00<007ooOol0P7oo00=l07ooOol0ogooogooWWoo000]Ool4000>Ool40005Ool40007Ool00`00
Oomoo`0<Ool00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mooomooomoob9oo`00HWoo
00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo
07aoo`03O01oogoo0?mooomooj9oo`00HWoo00<007ooOol0Ngoo00=l07ooOol0ogooogooXgoo001R
Ool00`00Oomoo`1jOol00g`0Oomoo`3oOoooOonTOol0069oo`03001oogoo07Uoo`03O01oogoo0?mo
oomoojEoo`00HWoo00<007ooOol0N7oo00=l07ooOol0ogooogooYWoo001ROol00`00Oomoo`3oOooo
OoooOolROol0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo
001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo07Aoo`03O01oogoo0?mooomoojYo
o`00HWoo00<007ooOol0Lgoo00=l07ooOol0ogooogooZgoo001ROol00`00Oomoo`1bOol00g`0Oomo
o`3oOoooOon/Ool0069oo`03001oogoo075oo`03O01oogoo0?mooomoojeoo`00HWoo00<007ooOol0
L7oo00=l07ooOol0ogooogoo[Woo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo
0?mooomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`1/Ool00g`0
Oomoo`3oOoooOonbOol0069oo`03001oogoo06]oo`03O01oogoo0?mooomook=oo`00HWoo00<007oo
Ool0JWoo00=l07ooOol0ogooogoo]7oo001ROol00`00Oomoo`1YOol00g`0Oomoo`3oOoooOoneOol0
069oo`03001oogoo06Qoo`03O01oogoo0?mooomookIoo`00HWoo00<007ooOol0ogooogooogoo8Woo
001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mooomooomoob9oo`00HWoo0`00
Hgoo00=l07ooOol0ogooogoo^goo001ROol00`00Oomoo`1ROol00g`0Oomoo`3oOoooOonlOol0069o
o`03001oogoo061oo`9l0?mooomookmoo`00HWoo00<007ooOol0Ggoo00=l07ooOol0ogooogoo_goo
001ROol00`00Oomoo`1NOol00g`0Oomoo`3oOoooOoo0Ool0069oo`03001oogoo0?mooomooomoob9o
o`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03
001oogoo05Yoo`03O01oogoo0?mooomoolAoo`00HWoo0`00FGoo00=l07ooOol0ogooogooaGoo001R
Ool00`00Oomoo`1GOol2O03oOoooOoo8Ool0069oo`03001oogoo05Ioo`03O01oogoo0?mooomoolQo
o`00HWoo00<007ooOol0EGoo00=l07ooOol0ogooogoobGoo001ROol00`00Oomoo`3oOoooOoooOolR
Ool0069oo`<00?mooomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomo
o`1AOol00g`0Oomoo`3oOoooOoo=Ool0069oo`03001oogoo051oo`03O01oogoo0?mooomoolioo`00
HWoo0`00CWoo0W`0ogooogoodGoo001ROol00`00Oomoo`1=Ool00g`0Oomoo`3oOoooOooAOol0069o
o`03001oogoo04aoo`03O01oogoo0?mooomoom9oo`00HWoo0`00ogooogooogoo8Woo001ROol00`00
Oomoo`3oOoooOoooOolROol0069oo`<00?mooomooomoob9oo`00HWoo00<007ooOol0B7oo00=l07oo
Ool0ogooogooeWoo001ROol30016Ool2O03oOoooOooIOol003moo`@000Ioo`8000Eoo`L000]oo`03
001oogoo04Aoo`9l0?mooomoom]oo`00?Woo00<007ooOol00Woo00<007ooOol00goo0P0027oo00<0
07ooOol037oo0`00@goo00=l07ooOol0ogooogoofgoo000nOol00`00Oomoo`02Ool00`00Oomoo`0=
Ool00`00Oomoo`0<Ool00`00Oomoo`3oOoooOoooOolROol003ioo`03001oogoo009oo`03001oogoo
00eoo`03001oogoo00aoo`@00?mooomooomoob5oo`00?Woo00<007ooOol00Woo00<007ooOol03Goo
00<007ooOol037oo00<007ooOol0?Woo00=l07ooOol0ogooogooh7oo000nOol00`00Oomoo`02Ool0
0`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0lOol2O03oOoooOooSOol003ioo`03001oogoo
009oo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo03Yoo`9l0?mooomoonEoo`00?Woo00<0
07ooOol00Woo00<007ooOol02goo0`003Woo00<007ooOol0>7oo0W`0ogooogooigoo000oOol4000@
Ool00`00Oomoo`0<Ool00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mooomooomoob9o
o`00HWoo00<007ooOol0<goo00=l07ooOol0ogooogoojgoo001ROol00`00Oomoo`0bOol00g`0Oomo
o`3oOoooOoo/Ool0069oo`03001oogoo031oo`9l0?mooomoonmoo`00HWoo00<007ooOol0;goo00=l
07ooOol0ogooogookgoo001ROol00`00Oomoo`0^Ool00g`0Oomoo`3oOoooOoo`Ool0069oo`03001o
ogoo0?mooomooomoob9oo`00HWoo00<007ooOol0:Goo00=l07ooOol0ogooogoomGoo001ROol00`00
Oomoo`0WOol2O03oOoooOoohOol0069oo`03001oogoo02Eoo`9l0?mooomoooYoo`00HWoo00<007oo
Ool097oo00=l07ooOol0ogooogoonWoo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001o
ogoo01ioo`03O01oogoo0?mooomooomoo`5oo`00HWoo00<007ooOol077oo0g`0ogooogooogoo0goo
001ROol00`00Oomoo`0HOol4O03oOoooOoooOol6Ool0069oo`03001oogoo0?mooomooomoob9oo`00
HWoo00<007ooOol04Goo0g`0ogooogooogoo3Woo001ROol00`00Oomoo`0=Ool4O03oOoooOoooOolA
Ool0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol0
0`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0
ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mooomooomo
ob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolROol00?mo
oomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogoo
ogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7
Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooaIoo`<000=oo`<0
00=oo`@000Eoo`<00003Ool0000000Aoo`@000Aoo`@000aoo`L0009oo`<0009oo`<000Aoo`@000Ao
o`D0009oo`80009oo`<000Aoo`@000aoo`L0009oo`<0009oo`<000eoo`@001ioo`@00?mookIoo`00
ogoo5goo00<007ooOol00goo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool20004Ool00`00
Oomoo`02Ool01000Oomoo`0017oo00<007ooOol037oo00<007ooOol017oo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol00Woo00@007ooOol000=oo`03001oogoo009oo`04001oogoo0005Ool0
0`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool0
0`00Oomoo`02Ool00`00Oomoo`09Ool6000;Ool00`00Oomoo`02Ool00`00Oomoo`3oOoncOol00?mo
oaQoo`D000=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Eoo`03
001oogoo015oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Eoo`05
001oogooOol00004Ool00`00Ool00006Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`02
Ool00`00Oomoo`0;Ool00`00Oomoo`0OOol00`00Oomoo`02Ool00`00Oomoo`3oOoncOol00?mooaQo
o`05001oogooOol00003Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`05Ool6000>Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`06Ool4
0004Ool30006Ool6000>Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomo
o`0OOol00`00Oomoo`02Ool00`00Oomoo`3oOoncOol006Moo`<00:ioo`03001oo`0000Eoo`04001o
ogooOol20003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
0`00Oomoo`0<Ool00`00Oomoo`04Ool20003Ool00`00Oomoo`02Ool00`00Oomoo`05Ool01@00Oomo
ogoo000017oo00@007ooOol000Eoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00Aoo`80
00=oo`03001oogoo00]oo`03001oogoo00ioo`H000]oo`03001oogoo009oo`03001oogoo0?mook=o
o`00J7oo00<007ooOol0[Goo00<007oo00001Woo0`0000Aoo`00Oomoo`8000=oo`80009oo`L000Ao
o`@000eoo`<000Eoo`800004Ool000000003Ool70004Ool30005Ool00`00Ool000020005Ool4000=
Ool30005Ool2000017oo0000000037oo1`007Goo00<007ooOol00Woo00<007ooOol0ogoo/goo001X
Ool00`00Oomoo`2^Ool00`00Oomoo`0GOol00`00Oomoo`0ZOol00`00Oomoo`0>Ool00`00Oomoo`0d
Ool00`00Oomoo`0OOol00`00Oomoo`02Ool00`00Oomoo`3oOoncOol005Yoo`H000Aoo`<00003Ool0
07oo0:ioo`8001Uoo`03001oogoo02Yoo`03001oogoo00ioo`03001oogoo03Aoo`03001oogoo01mo
o`03001oogoo009oo`03001oogoo0?mook=oo`00Fgoo00<007ooOol00Woo00@007ooOol000=oo`80
0>Ioo`03001oogoo01ioo`8001aoo`03001oogoo03Yoo`@00?mookIoo`00Fgoo00<007ooOol00Woo
00@007ooOol000Aoo`03001oogoo0>Aoo`03001oogoo03aoo`03001oogoo0?moooAoo`00Fgoo00<0
07ooOol00Woo00@007ooOol000Aoo`03001oogoo0?mooomooomooaaoo`00Fgoo1@000goo00@007oo
Oomoo`800?mooomooomooaioo`00Fgoo00<007ooOol00Woo00@007ooOomoo`<00003Ool000000?mo
oomooomooaeoo`00Fgoo00<007ooOol00Woo00<007ooOol0ogooogooogoo97oo001JOol6003oOooo
OoooOolWOol00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomo
ohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo
003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mo
oomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogoo
ogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7
Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00
ogooogooogooQgoo003oOoooOoooOon7Ool00001\
\>"],
  ImageRangeCache->{{{0, 899}, {440.375, 0}} -> {-1.06477, -0.648943, \
0.00442081, 0.00442081}, {{21.9375, 700.563}, {429.875, 10.4375}} -> \
{-0.483369, -12.3062, 0.00650107, 0.0479747}, {{700.563, 870.188}, {321.938, \
152.313}} -> {-14.9684, -2.19473, 0.0318352, 0.0265294}, {{714.688, 761.813}, \
{304.938, 248.375}} -> {-15.9492, -11.8048, 0.0334221, 0.108156}, {{714.688, \
761.813}, {225.813, 169.25}} -> {-15.9492, -17.51, 0.0334221, 0.108156}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, 180, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Injection\>", 
      IntakeType \[Rule] \ "\<Constant\>", \ 
      ShowReport \[Rule] \ "\<GraphicReport\>"]\)], "Input",
  CellLabel->"In[28]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.619313 0.0859132 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .01792 -46.5 -6.625 ]
[-0.0125 .01792 0 6.625 ]
[-0.0125 .18975 -46 -6.28125 ]
[-0.0125 .18975 0 6.28125 ]
[-0.0125 .36157 -34 -6.28125 ]
[-0.0125 .36157 0 6.28125 ]
[-0.0125 .5334 -22 -6.28125 ]
[-0.0125 .5334 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01792 m
.00625 .01792 L
s
gsave
-0.0125 .01792 -107.5 -10.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.500 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.313 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
105.000 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .18975 m
.00625 .18975 L
s
gsave
-0.0125 .18975 -107 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00001) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .36157 m
.00625 .36157 L
s
gsave
-0.0125 .36157 -95 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .5334 m
.00625 .5334 L
s
gsave
-0.0125 .5334 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .11064 m
.00375 .11064 L
s
0 .13491 m
.00375 .13491 L
s
0 .1495 m
.00375 .1495 L
s
0 .15995 m
.00375 .15995 L
s
0 .16811 m
.00375 .16811 L
s
0 .1748 m
.00375 .1748 L
s
0 .18048 m
.00375 .18048 L
s
0 .1854 m
.00375 .1854 L
s
0 .28246 m
.00375 .28246 L
s
0 .30674 m
.00375 .30674 L
s
0 .32132 m
.00375 .32132 L
s
0 .33178 m
.00375 .33178 L
s
0 .33994 m
.00375 .33994 L
s
0 .34663 m
.00375 .34663 L
s
0 .3523 m
.00375 .3523 L
s
0 .35723 m
.00375 .35723 L
s
0 .45429 m
.00375 .45429 L
s
0 .47856 m
.00375 .47856 L
s
0 .49315 m
.00375 .49315 L
s
0 .50361 m
.00375 .50361 L
s
0 .51177 m
.00375 .51177 L
s
0 .51846 m
.00375 .51846 L
s
0 .52413 m
.00375 .52413 L
s
0 .52905 m
.00375 .52905 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Constant) show
117.000 12.813 moveto
(intake) show
153.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .58397 m
.06042 .59354 L
.08838 .59794 L
.1161 .60048 L
.13894 .60167 L
.15779 .60227 L
.17363 .60257 L
.18958 .60277 L
.20509 .60288 L
.21944 .60294 L
.23372 .60297 L
.24625 .60299 L
.25701 .603 L
.26883 .60301 L
.2752 .60301 L
.28092 .60301 L
.30107 .60302 L
.33501 .60303 L
.36579 .60304 L
.41107 .60306 L
.45102 .60309 L
.48098 .60312 L
.53436 .60316 L
.6058 .60323 L
.65542 .60327 L
.69308 .60329 L
.70978 .6033 L
.72615 .60331 L
.7414 .60331 L
.75476 .60331 L
.76709 .60331 L
.7778 .60332 L
.78805 .60332 L
.79874 .60332 L
.80824 .60332 L
.81796 .60332 L
.82683 .60332 L
.83574 .60332 L
.84369 .60332 L
.8508 .60332 L
.8584 .60332 L
.86504 .60332 L
.87166 .60332 L
.87857 .60332 L
.88494 .60332 L
.89145 .60332 L
.8973 .60332 L
.90262 .60332 L
.90833 .60332 L
.9134 .60332 L
Mistroke
.91846 .60332 L
.92382 .60332 L
.92877 .60332 L
.93391 .60332 L
.93901 .60332 L
.94368 .60332 L
.94822 .60332 L
.9523 .60332 L
.95637 .60332 L
.96073 .60332 L
.96476 .60332 L
.96898 .60332 L
.97272 .60332 L
.97619 .60332 L
Mfstroke
0 0 1 r
[ ] 0 setdash
.02381 .01472 m
.20509 .18917 L
.30107 .25719 L
.41107 .3138 L
.48498 .3413 L
.53436 .35548 L
.60287 .36983 L
.63172 .37408 L
.65536 .37683 L
.67446 .3786 L
.69343 .37999 L
.71037 .38096 L
.72677 .38168 L
.74071 .38215 L
.75461 .38251 L
.76768 .38277 L
.77929 .38293 L
.79007 .38305 L
.79954 .38313 L
.80955 .38319 L
.81819 .38323 L
.82671 .38327 L
.8355 .38329 L
.84355 .3833 L
.85168 .38332 L
.85895 .38332 L
.86548 .38333 L
.87248 .38333 L
.87863 .38333 L
.88474 .38334 L
.89118 .38334 L
.8971 .38334 L
.90319 .38334 L
.90866 .38334 L
.91365 .38334 L
.91901 .38334 L
.92378 .38334 L
.92854 .38334 L
.93361 .38334 L
.93829 .38334 L
.94316 .38334 L
.94799 .38334 L
.95243 .38334 L
.95675 .38334 L
.96063 .38334 L
.9645 .38334 L
.96867 .38334 L
.97233 .38334 L
.97619 .38334 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[28]:=",
  ImageSize->{600, 294.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000>40001^A000`40O003h00OogooogooogooQgoo
003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mo
oomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogoo
ogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7
Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00
ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOooo
OoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomo
ohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool006aoo`L003ioo`H005Moo`@003aoo`L000=o
o`@003Moo`H000Aoo`@004moo`@000Eoo`@003=oo`L000=oo`@000Eoo`@002ioo`H000Aoo`@000Eo
o`@00?Qoo`00Kgoo00<007ooOol0?goo00<007ooOol00Woo00<007ooOol0E7oo00<007ooOol00Woo
00<007ooOol0?7oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0=7oo00<007ooOol00Woo
00D007ooOomoo`0000Aoo`03001oogoo04]oo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`0cOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0:goo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`3eOol006mo
o`03001oogoo041oo`03001oogoo05eoo`03001oogoo03aoo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo03Eoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo051oo`05001oogooOol0
0004Ool00`00Oomoo`0cOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<0
07ooOol0;7oo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo0?Eo
o`00Kgoo00<007ooOol0@Goo00<007ooOol0G7oo00<007ooOol0?7oo00<007ooOol00goo00<007oo
Ool00Woo00<007ooOol0=Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0D7oo00D007oo
Oomoo`0000Aoo`03001oogoo03=oo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0]Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool0mGoo001_Ool00`00Oomoo`12Ool00`00Oomoo`1KOol00`00Oomoo`0lOol00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`0gOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`1@Ool0
1@00Oomoogoo000017oo00<007ooOol0<goo00<007ooOol00goo00<007ooOol00Woo00D007ooOomo
o`0000Aoo`03001oogoo02ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool0
0`00Oomoo`3eOol006moo`03001oogoo04=oo`03001oogoo05Ioo`@003moo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo03Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo04aoo`@0
00Aoo`03001oogoo009oo`03001oogoo03=oo`03001oogoo00=oo`03001oogoo009oo`05001oogoo
Ool00004Ool00`00Oomoo`0_Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo
00<007ooOol0mGoo001_Ool00`00Oomoo`0oOol00`00Oomoo`02Ool00`00Oomoo`1EOol00`00Oomo
o`10Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0dOol00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00<007ooOol0C7oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0<goo00<0
07ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo02]oo`03001oogoo009o
o`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol0mGoo001]Ool30011Ool00`00
Oomoo`02Ool00`00Oomoo`1EOol00`00Oomoo`0nOol30005Ool00`00Oomoo`02Ool00`00Oomoo`0d
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0C7oo00<007ooOol01Goo00<007oo
Ool00Woo00<007ooOol0<Goo0`001Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo
02]oo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol0mGoo
001_Ool00`00Oomoo`10Ool4001HOol5000nOol00`00Oomoo`04Ool4000hOol40005Ool4001?Ool5
0004Ool4000fOol00`00Oomoo`04Ool40005Ool4000_Ool40005Ool40005Ool4003hOol00?mooomo
oomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooZgoo
0`00f7oo003oOoooOon]Ool00`00Oomoo`3FOol00?mooomoojeoo`03001oogoo0=Ioo`00ogooogoo
VGoo0`0000=oo`00000017oo1@001Goo0P001Goo1@00cGoo003oOoooOonHOol01000Oomoogoo0P00
17oo00D007ooOomoo`0000Ioo`8000Eoo`03001oogoo009oo`03001oogoo0<Yoo`00ogooogooV7oo
00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Eoo`04001oogoo0009Ool00`00Oomo
o`3:Ool0069oool00?l002D0015oo`03001oogoo009oo`03001oogoo00=oo`@000Eoo`04001oogoo
0005Ool4003=Ool0069oo`03001oogoo00Yoo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo
01Yoo`03001oogoo01=oo`03001oogoo011oo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo
00Uoo`03001oogoo00Qoo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo01Yoo`03001oogoo
01=oo`03001oogoo00moo`03001oogoo00eoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo
00Moo`03001oogoo04=oo`03001oogoo015oo`04001oogooOol20004Ool01@00Oomoogoo000017oo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo0<Yoo`00HWoo00<007ooOol02Woo00<0
07ooOol0@Woo00<007ooOol09Woo00<007ooOol06Woo00<007ooOol04goo00<007ooOol047oo00<0
07ooOol037oo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0@Woo00<0
07ooOol09Woo00<007ooOol06Woo00<007ooOol04goo00<007ooOol03goo00<007ooOol03Goo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol01goo00<007ooOol0@goo00<007ooOol04Woo0`00
00=oo`00Ool017oo0`0017oo0`000Woo0`000goo1@00c7oo001ROol00`00Oomoo`0:Ool00`00Oomo
o`12Ool00`00Oomoo`1IOol00`00Oomoo`13Ool00`00Oomoo`12Ool00`00Oomoo`1IOol00`00Oomo
o`12Ool00`00Oomoo`13Ool00`00Oomoo`0FOol00`00Oomoo`3VOol0069oo`03001oogoo00Yoo`03
001oogoo049oo`03001oogoo05Uoo`03001oogoo04=oo`03001oogoo049oo`03001oogoo05Uoo`03
001oogoo049oo`03001oogoo04=oo`03001oogoo01Ioo`03001oogoo0>Ioo`00HWoo00<007ooOol0
ogooogoo=goo0P00j7oo001ROol00`00Oomoo`3oOoooOoooOolROol001Yoo`L000Aoo`8000Moo`03
001oogoo00=oo`03001oogoo00=oo`L000=oo`@001Yoo`03001oogoo0?mooomooomoob9oo`007Goo
00<007ooOol01Goo0P0027oo00D007ooOomoo`0000Uoo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo01Moo`03001oogoo00Yoo`0301moogoo0?mooomooomooaEoo`007Goo00<007ooOol047oo
00<007oo00002Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol05goo00<007ooOol02goo
00<07gooOol0ogooogooogoo57oo000MOol00`00Oomoo`0AOol00`00Oomoo`09Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`0GOol4000;Ool00`0OOomoo`3oOoooOoooOolCOol001eoo`03
001oogoo011oo`03001oo`0000Yoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo01Moo`03
001oogoo00eoo`0301moogoo0?mooomooomooa9oo`007Goo00<007ooOol03goo00D007ooOomoo`00
00Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo01Moo`03001oogoo00ioo`0301moogoo
0?mooomooomooa5oo`007Goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol01Woo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol02goo00<007ooOol03goo00<07goo
Ool0ogooogooogoo47oo000KOol3000MOol30005Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00
Oomoo`0;Ool00`00Oomoo`0@Ool00`0OOomoo`3oOoooOoooOol?Ool001eoo`03001oogoo01eoo`03
001oogoo00Aoo`@000Aoo`D000Aoo`03001oogoo00Yoo`03001oogoo015oo`0301moogoo0?mooomo
oomoo`ioo`00EGoo00<007ooOol02Woo00<007ooOol04Woo00<07gooOol0ogooogooogoo3Goo001F
Ool00`00Oomoo`09Ool00`00Oomoo`0COol00`0OOomoo`3oOoooOoooOol<Ool0059oo`05001oogoo
Ool0000;Ool00`00Oomoo`0DOol00`0OOomoo`3oOoooOoooOol;Ool0059oo`D000]oo`03001oogoo
01Eoo`0301moogoo0?mooomooomoo`Yoo`00HWoo00<007ooOol05Woo0P0Oogooogooogoo2Woo001R
Ool00`00Oomoo`0HOol00`0OOomoo`3oOoooOoooOol7Ool0069oo`03001oogoo01Uoo`0301moogoo
0?mooomooomoo`Ioo`00HWoo00<007ooOol06Woo00<07gooOol0ogooogooogoo1Goo001ROol00`00
Oomoo`0KOol00`0OOomoo`3oOoooOoooOol4Ool0069oo`03001oogoo01aoo`0301moogoo0?mooomo
oomoo`=oo`00HWoo00<007ooOol07Goo00<07gooOol0ogooogooogoo0Woo001ROol00`00Oomoo`0N
Ool00`0OOomoo`3oOoooOoooOol1Ool0069oo`03001oogoo01moo`0301moogoo0?mooomooomoo`00
HWoo00<007ooOol087oo00<07gooOol0ogooogoooWoo001ROol00`00Oomoo`0QOol00`0OOomoo`3o
OoooOoomOol0069oo`03001oogoo029oo`0301moogoo0?mooomoooaoo`00HWoo00<007ooOol08goo
00<07gooOol0ogooogoongoo001ROol00`00Oomoo`0TOol00`0OOomoo`3oOoooOoojOol0069oo`03
001oogoo02Eoo`0301moogoo0?mooomoooUoo`00HWoo00<007ooOol09Woo00<07gooOol0ogooogoo
n7oo001ROol00`00Oomoo`0WOol00`0OOomoo`3oOoooOoogOol0069oo`03001oogoo02Qoo`0301mo
ogoo0?mooomoooIoo`00HWoo00<007ooOol0:Goo00<07gooOol0ogooogoomGoo001ROol00`00Oomo
o`0ZOol00`0OOomoo`3oOoooOoodOol0069oo`03001oogoo02]oo`0301moogoo0?mooomooo=oo`00
HWoo00<007ooOol0;7oo00<07gooOol0ogooogoolWoo001ROol00`00Oomoo`0]Ool00`0OOomoo`3o
OoooOooaOol0069oo`03001oogoo02ioo`0301moogoo0?mooomooo1oo`00HWoo00<007ooOol0;goo
0P0Oogooogool7oo001ROol00`00Oomoo`0aOol00`0OOomoo`3oOoooOoo]Ool0069oo`03001oogoo
039oo`0301moogoo0?mooomoonaoo`00HWoo00<007ooOol0<goo00<07gooOol0ogooogoojgoo001R
Ool00`00Oomoo`0dOol00`0OOomoo`3oOoooOooZOol0069oo`03001oogoo03Eoo`0301moogoo0?mo
oomoonUoo`00HWoo00<007ooOol0=Woo00<07gooOol0ogooogooj7oo001ROol00`00Oomoo`0gOol0
0`0OOomoo`3oOoooOooWOol0069oo`03001oogoo03Qoo`0301moogoo0?mooomoonIoo`00HWoo00<0
07ooOol0>Goo00<07gooOol0ogooogooiGoo001ROol00`00Oomoo`0jOol00`0OOomoo`3oOoooOooT
Ool0069oo`03001oogoo03]oo`0301moogoo0?mooomoon=oo`00HWoo00<007ooOol0?7oo00<07goo
Ool0ogooogoohWoo001ROol00`00Oomoo`0mOol00`0OOomoo`3oOoooOooQOol0069oo`03001oogoo
03ioo`0301moogoo0?mooomoon1oo`00HWoo00<007ooOol0?goo00<07gooOol0ogooogooggoo001R
Ool00`00Oomoo`10Ool00`0OOomoo`3oOoooOooNOol0069oo`<0045oo`0301moogoo0?mooomoomeo
o`00HWoo00<007ooOol0@Woo00<07gooOol0ogooogoog7oo001ROol00`00Oomoo`13Ool00`0OOomo
o`3oOoooOooKOol0069oo`03001oogoo04Aoo`0301moogoo0?mooomoomYoo`00HWoo00<007ooOol0
AGoo00<07gooOol0ogooogoo67ooZP005goo001ROol00`00Oomoo`16Ool00`0OOomoo`3oOoooOolG
OonZ000GOol0069oo`03001oogoo04Moo`807omooomooaMoojX001Moo`00HWoo00<007ooOol0BGoo
00<07gooOol0ogooogoo57ooZP005goo001ROol00`00Oomoo`1:Ool00`0OOomoo`3oOoooOolCOonZ
000GOol0069oo`03001oogoo04]oo`0301moogoo0?mooomooa9oojX001Moo`00HWoo00<007ooOol0
C7oo00<07gooOol0ogooogoo2Woo/@005goo001ROol00`00Oomoo`1=Ool00`0OOomoo`3oOoooOol9
Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo04ioo`0301moogoo0?mooomoo`Qoo`03001o
ogoo0:Moo`L001Moo`00HWoo0`00Cgoo00<07gooOol0ogooogoo1goo00<007ooOol0Ygoo1`005goo
001ROol00`00Oomoo`1@Ool00`0OOomoo`3oOoooOol6Ool00`00Oomoo`2WOol7000GOol0069oo`03
001oogoo055oo`0301moogoo0?mooomoo`Eoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0
DWoo00<07gooOol0ogooogoo17oo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`1COol00`0O
Oomoo`3oOoooOol3Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo05Aoo`0301moogoo0?mo
oomoo`9oo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0EGoo00<07gooOol0ogooogoo0Goo
00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`1FOol00`0OOomoo`3oOoooOol00`00Oomoo`2W
Ool7000GOol0069oo`<005Moo`0301moogoo0?moooioo`03001oogoo0:Moo`L001Moo`00HWoo00<0
07ooOol0F7oo00<07gooOol0ogoooGoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`1IOol0
0`0OOomoo`3oOoolOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo05Yoo`0301moogoo0?mo
oo]oo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0Fgoo00<07gooOol0ogoonWoo00<007oo
Ool0Ygoo1`005goo001ROol3001LOol00`0OOomoo`3oOooiOol00`00Oomoo`2WOol7000GOol0069o
o`03001oogoo05eoo`0301moogoo0?moooQoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0
GWoo00<07gooOol0ogoomgoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`1OOol00`0OOomo
o`3oOoofOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo061oo`807omoooIoo`03001oogoo
0:Moo`L001Moo`00HWoo0`00HWoo00<07gooOol0ogoolgoo00<007ooOol0Ygoo1`005goo001ROol0
0`00Oomoo`1SOol00`0OOomoo`3oOoobOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo06Ao
o`0301moogoo0?mooo5oo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0IGoo00<07gooOol0
ogool7oo00<007ooOol0Ygoo1`005goo001ROol3001VOol00`0OOomoo`3oOoo_Ool00`00Oomoo`2W
Ool7000GOol0069oo`03001oogoo06Moo`0301moogoo0?moonioo`03001oogoo0:Moo`L001Moo`00
HWoo00<007ooOol0J7oo00<07gooOol0ogookGoo00<007ooOol0Ygoo1`005goo001ROol3001YOol0
0`0OOomoo`3oOoo/Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo06Yoo`0301moogoo0?mo
on]oo`03001oogoo0:Moo`L001Moo`006goo10001Woo0P001Woo10001Goo10001Goo10001Goo1000
17oo1`002goo0`00Jgoo00<07gooOol0ogoojWoo00<007ooOol0Ygoo1`005goo000JOol00`00Oomo
o`02Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomo
o`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`1/Ool0
0`0OOomoo`3oOooYOol00`00Oomoo`2WOol7000GOol001Yoo`03001oogoo009oo`03001oogoo00Yo
o`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Ao
o`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo06eoo`0301moogoo0?moonQoo`03001oogoo
04Yoo`L0009oo`<0009oo`<000=oo`@000Aoo`D000Eoo`@000Ioo`@0009oo`L000Aoo`@000=oo`<0
009oo`<000eoo`L001Moo`006Woo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol00Woo00D0
07ooOomoo`0000Aoo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol017oo00<0
07ooOol037oo1000KGoo0P0Oogooj7oo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol00Woo
00@007ooOol000Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo009o
o`05001oogooOol00004Ool00`00Oomoo`0<Ool7000GOol001Yoo`03001oogoo009oo`03001oogoo
00Yoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00D007ooOomoo`00
00Aoo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo071oo`0301moogoo0?moonEoo`03001o
ogoo04]oo`03001oogoo009oo`03001oogoo00=oo`8000Aoo`03001oogoo00Qoo`03001oogoo00Eo
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`0<Ool7000GOol001Yoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo
009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo
00Aoo`03001oogoo00aoo`03001oogoo075oo`0301moogoo0?moonAoo`03001oogoo04]oo`04001o
ogoo0007Ool20004Ool00`00Oomoo`08Ool00`00Oomoo`05Ool60004Ool00`00Oomoo`07Ool00`00
Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol037oo1`005goo000JOol0
0`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomo
o`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`1bOol2
01ooOooTOol00`00Oomoo`1;Ool40006Ool01000Oomoo`0017oo00@007ooOomoo`8000Aoo`8000Io
o`03001oogoo009oo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009o
o`04001oogooOol20003Ool00`00Oomoo`0<Ool7000GOol001Yoo`03001oogoo009oo`03001oogoo
00Yoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00D007ooOomoo`00
00Aoo`03001oogoo009oo`<000ioo`03001oogoo07Aoo`0301moogoo0?moon5oo`03001oogoo04]o
o`06001oogoo001oo`000Woo0`000Woo0`000goo0`0000=oo`00Ool00Woo0P0000Aoo`00000000Ao
o`@000=oo`L000=oo`<000Moo`@000=oo`800004Ool00000000?Ool7000GOol001]oo`@000ioo`@0
00Eoo`@000Eoo`@000Eoo`@000Moo`03001oogoo00aoo`03001oogoo07Eoo`807omoon5oo`03001o
ogoo04]oo`03001oogoo009oo`03001oogoo02Ioo`03001oogoo02]oo`L001Moo`00HWoo00<007oo
Ool0Mgoo00<07gooOol0ogoogWoo00<007ooOol0BWoo1`00:7oo00<007ooOol0:goo1`005goo001R
Ool00`00Oomoo`1hOol00`0OOomoo`3oOooMOol00`00Oomoo`23Ool00`00Oomoo`0QOol7000GOol0
069oo`03001oogoo07Uoo`807omoomeoo`03001oogoo08=oo`03001oogoo025oo`L001Moo`00HWoo
00<007ooOol0Ngoo00<07gooOol0ogoofWoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`1l
Ool201ooOooJOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo07ioo`0301moogoo0?moomMo
o`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0Ogoo00<07gooOol0ogooeWoo00<007ooOol0
37oo1g`01Goo1g`01Goo1g`01Goo1g`0L7oo1`005goo001ROol00`00Oomoo`20Ool201ooOooFOol0
0`00Oomoo`2WOol7000GOol0069oo`03001oogoo089oo`0301moogoo0?moom=oo`03001oogoo0:Mo
o`L001Moo`00HWoo00<007ooOol0Pgoo0P0Oogoodgoo00<007ooOol0Ygoo1`005goo001ROol00`00
Oomoo`25Ool00`0OOomoo`3oOoo@Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo08Ioo`03
01moogoo0?moolmoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0Qgoo0P0Oogoocgoo00<0
07ooOol0Ygoo1`005goo001ROol00`00Oomoo`29Ool00`0OOomoo`3oOoo<Ool00`00Oomoo`1<Ool4
0004Ool50003Ool70002Ool30002Ool30003Ool4000cOol7000GOol0069oo`03001oogoo08Yoo`03
01moogoo0?mool]oo`03001oogoo04]oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Mo
o`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0`Ool7000GOol0
069oo`03001oogoo08]oo`807omool]oo`03001oogoo04]oo`03001oogoo009oo`03001oogoo009o
o`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol0000gOol7000GOol0
069oo`03001oogoo08eoo`0301moogoo0?moolQoo`03001oogoo04]oo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`04001oogooOol6000bOol7
000GOol0069oo`03001oogoo08ioo`807omoolQoo`03001oogoo04]oo`03001oogoo009oo`03001o
ogoo009oo`8000Qoo`03001oogoo00Aoo`8000=oo`05001oogooOol00004Ool00`00Oomoo`0`Ool7
000GOol0069oo`03001oogoo091oo`0301moogoo0?moolEoo`03001oogoo04]oo`03001oogoo009o
o`04001oogooOol2000017oo000000000goo0`001Goo0P0000Aoo`00000000Eoo`@003=oo`L001Mo
o`00HWoo00<007ooOol0TGoo00<07gooOol0ogooa7oo00<007ooOol0Bgoo00<007ooOol00Woo00<0
07ooOol0E7oo1`005goo001ROol00`00Oomoo`2BOol201ooOoo4Ool00`00Oomoo`1:Ool30002Ool3
001EOol7000GOol0069oo`03001oogoo09Aoo`0301moogoo0?mool5oo`03001oogoo05moo`03001o
ogoo04Eoo`L001Moo`00HWoo00<007ooOol0UGoo0P0Oogoo`Goo00<007ooOol0Ggoo00<007ooOol0
AGoo1`005goo001ROol00`00Oomoo`2GOol00`0OOomoo`3oOonnOol00`00Oomoo`2WOol7000GOol0
069oo`03001oogoo09Qoo`0301moogoo0?mookeoo`03001oogoo0:Moo`L001Moo`00HWoo00<007oo
Ool0VGoo0P0Oogoo_Goo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`2KOol00`0OOomoo`3o
OonjOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo09aoo`807omookYoo`03001oogoo0:Mo
o`L001Moo`00HWoo00<007ooOol0WWoo00<07gooOol0ogoo]goo00<007ooOol0Ygoo1`005goo001R
Ool00`00Oomoo`2OOol00`0OOomoo`3oOonfOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo
0:1oo`807omookIoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0XWoo00<07gooOol0ogoo
/goo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`2SOol201ooOoncOol00`00Oomoo`2WOol7
000GOol0069oo`03001oogoo0:Eoo`807omook5oo`03001oogoo0:Moo`L001Moo`00HWoo00<007oo
Ool0Ygoo0P0Oogoo[goo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`2YOol201ooOon]Ool0
0`00Oomoo`2WOol7000GOol0069oo`03001oogoo0:]oo`807omooj]oo`03001oogoo0:Moo`L001Mo
o`00HWoo00<007ooOol0[Goo0P0OogooZGoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`2_
Ool201ooOonWOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0;5oo`807omoojEoo`03001o
ogoo0:Moo`L001Moo`00HWoo00<007ooOol0/goo0P0OogooXgoo00<007ooOol0Ygoo1`005goo001R
Ool00`00Oomoo`2eOol201ooOonQOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0;Moo`80
7omooimoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0^Goo0P0OogooWGoo00<007ooOol0
Ygoo1`005goo001ROol3002kOol201ooOonKOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo
0;eoo`807omooiUoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0_goo00<07gooOol0ogoo
UWoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`30Ool201ooOonFOol00`00Oomoo`2WOol7
000GOol0069oo`03001oogoo0<9oo`807omooiAoo`03001oogoo0:Moo`L001Moo`00HWoo00<007oo
Ool0a7oo0P0OogooTWoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`36Ool201ooOon@Ool0
0`00Oomoo`2WOol7000GOol0069oo`03001oogoo0<Qoo`807omoohioo`03001oogoo0:Moo`L001Mo
o`00HWoo00<007ooOol0bWoo0P0OogooS7oo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3<
Ool201ooOon:Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0<ioo`807omoohQoo`03001o
ogoo0:Moo`L001Moo`00HWoo00<007ooOol0d7oo0P0OogooQWoo00<007ooOol0Ygoo1`005goo001R
Ool00`00Oomoo`3BOol201ooOon4Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0=Aoo`80
7omooh9oo`03001oogoo0:Moo`L001Moo`00HWoo0`00eWoo0P0OogooP7oo00<007ooOol0Ygoo1`00
5goo001ROol00`00Oomoo`3HOol201ooOomnOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo
0=Yoo`807omoogaoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0g7oo0P0OogooNWoo00<0
07ooOol0Ygoo1`005goo001ROol00`00Oomoo`3NOol201ooOomhOol00`00Oomoo`2WOol7000GOol0
069oo`03001oogoo0>1oo`807omoogIoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0hWoo
0`0OogooLgoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3UOol301ooOom`Ool00`00Oomo
o`2WOol7000GOol0069oo`<00>Qoo`807omoofioo`03001oogoo0:Moo`L001Moo`00HWoo00<007oo
Ool0jWoo0`0OogooJgoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3]Ool301ooOomXOol0
0`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?1oo`807omoofIoo`03001oogoo0:Moo`L001Mo
o`00HWoo00<007ooOol0lWoo0`0OogooHgoo00<007ooOol0Ygoo1`005goo001ROol3003eOol301oo
OomPOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?Qoo`807omooeioo`03001oogoo04Yo
o`L0009oo`<0009oo`<000=oo`@000Aoo`D000Eoo`@000Ioo`@0009oo`L000Aoo`@000=oo`<0009o
o`<000eoo`L001Moo`00HWoo00<007ooOol0nWoo0`0OogooFgoo00<007ooOol0Bgoo00<007ooOol0
0Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo
00Eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo
00Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0<Ool7000GOol0069oo`03001o
ogoo0?eoo`<07omooeQoo`03001oogoo04]oo`03001oogoo009oo`03001oogoo00=oo`8000Aoo`03
001oogoo00Qoo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Aoo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0<Ool7000GOol0069oo`03001oogoo0?mo
o`5oo`807omooeIoo`03001oogoo04]oo`04001oogoo0007Ool20004Ool00`00Oomoo`08Ool00`00
Oomoo`05Ool60004Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo
000017oo00<007ooOol037oo1`005goo001ROol3003oOol3Ool301ooOomCOol00`00Oomoo`1;Ool4
0006Ool01000Oomoo`0017oo00@007ooOomoo`8000Aoo`8000Ioo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`04001oogooOol20003Ool00`00
Oomoo`0<Ool7000GOol0069oo`03001oogoo0?moo`Ioo`<07omooe1oo`03001oogoo04]oo`06001o
ogoo001oo`000Woo0`000Woo0`000goo0`0000=oo`00Ool00Woo0P0000Aoo`00000000Aoo`@000=o
o`L000=oo`<000Moo`@000=oo`800004Ool00000000?Ool7000GOol0069oo`03001oogoo0?moo`Uo
o`@07omoodaoo`03001oogoo04]oo`03001oogoo009oo`03001oogoo02Ioo`03001oogoo02]oo`L0
01Moo`00HWoo0`00ogoo3Goo100OogooB7oo00<007ooOol0BWoo1`00:7oo00<007ooOol0:goo1`00
5goo001ROol00`00Oomoo`3oOolAOol401ooOom4Ool00`00Oomoo`23Ool00`00Oomoo`0QOol7000G
Ool0069oo`03001oogoo0?mooaEoo`@07omood1oo`03001oogoo08=oo`03001oogoo025oo`L001Mo
o`00HWoo00<007ooOol0ogoo6Goo100Oogoo?7oo00<007ooOol0Ygoo1`005goo001ROol3003oOolM
Ool401ooOolhOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?moob5oo`@07omoocAoo`03
001oogoo0:Moo`L001Moo`00;Goo10001Woo0P001Woo10001Goo100017oo1`002goo0`00ogoo9Goo
100Oogoo<7oo00<007ooOol037oo;P0OKGoo1`005goo000/Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool20005Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol037oo
00<007ooOol0ogoo:Goo1@0Oogoo:goo00<007ooOol0Ygoo1`005goo000/Ool00`00Oomoo`02Ool0
0`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol0
37oo00<007ooOol0ogoo;Woo1@0Oogoo9Woo00<007ooOol0Ygoo1`005goo000/Ool00`00Oomoo`02
Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo
Ool037oo1000ogoo<Woo100Oogoo8Woo00<007ooOol0Ygoo1`005goo000/Ool00`00Oomoo`02Ool0
0`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol0
37oo00<007ooOol0ogoo=goo1@0Oogoo7Goo00<007ooOol0Ygoo1`005goo000/Ool00`00Oomoo`02
Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo
Ool037oo00<007ooOol0ogoo?7oo1@0Oogoo67oo00<007ooOol0Ygoo1`005goo000/Ool00`00Oomo
o`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<0
07ooOol037oo00<007ooOol0ogoo@Goo100Oogoo57oo00<007ooOol0Ygoo1`005goo000/Ool00`00
Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol00Woo
0`003Woo00<007ooOol0ogooAGoo1P0Oogoo3Woo00<007ooOol0BWoo10001goo1@0017oo10001Goo
10001Goo1@000Woo1`00:Goo1`005goo000]Ool4000>Ool40005Ool40007Ool00`00Oomoo`0<Ool0
0`00Oomoo`3oOom;Ool801ooOol6Ool00`00Oomoo`1;Ool00`00Oomoo`06Ool01@00Oomoogoo0000
17oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool00`00Oomoo`04Ool0
0`00Oomoo`0ZOol7000GOol0069oo`03001oogoo0?mooe=oo`P07oeoo`03001oogoo04]oo`03001o
ogoo00Ioo`05001oogooOol00004Ool00`00Oomoo`05Ool00`00Oomoo`07Ool01@00Oomoogoo0000
1Woo00<007ooOol0:Woo1`005goo001ROol00`00Oomoo`3oOomKOol601ogOol00`00Oomoo`1;Ool0
1000Oomoo`001Woo100017oo1P000Woo00<007ooOol027oo10001Woo00<007ooOol0:Woo1`005goo
001ROol00`00Oomoo`3oOomQOol901o^Ool00`00Oomoo`1;Ool40005Ool01@00Oomoogoo000017oo
00<007ooOol00Woo00D007ooOomoo`0000=oo`8000=oo`05001oogooOol00006Ool00`00Oomoo`0Z
Ool7000GOol0069oo`03001oogoo0?moofYoo`X07nAoo`03001oogoo04]oo`06001oogoo001oo`00
17oo0`001Woo10001Goo0`0000=oo`00Ool00goo0`001goo00<007ooOol0:Woo1`005goo001ROol0
0`00Oomoo`3oOomdOolC01oAOol00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00
Oomoo`0ZOol7000GOol0069oo`03001oogoo0?moohMooch07i=oo`03001oogoo04Yoo`L002Uoo`03
001oogoo02Yoo`L001Moo`00HWoo00<007ooOol0ogooaGooC`0OA7oo00<007ooOol0N7oo0`00;7oo
1`005goo001ROol00`00Oomoo`3oOoooOomIOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo
0?mooomooeUoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogooogooFGoo00<007ooOol0
Ygoo1`005goo001ROol00`00Oomoo`3oOoooOomIOol00`00Oomoo`2WOol7000GOol0069oo`03001o
ogoo0?mooomooeUoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogooogooFGoo00<007oo
Ool0Ygoo1`005goo001ROol00`00Oomoo`3oOoooOomIOol00`00Oomoo`2WOol7000GOol0069oo`03
001oogoo0?mooomooeUoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogooogooFGoo00<0
07ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOoooOomIOol00`00Oomoo`2WOol7000GOol0069o
o`03001oogoo0?mooomooeUoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogooogooFGoo
00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOoooOomIOol00`00Oomoo`2WOol7000GOol0
069oo`03001oogoo0?mooomooeUoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogooogoo
FGoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOoooOomIOol00`00Oomoo`2WOol7000G
Ool0069oo`03001oogoo0?mooomooeUoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoo
ogooFGoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOoooOomIOol00`00Oomoo`2WOol7
000GOol0069oo`03001oogoo0?mooomooeUoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0
ogooogooFGoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOoooOomIOol00`00Oomoo`2W
Ool7000GOol0069oo`03001oogoo0?mooomooeUoo`03001oogoo0:Moo`L001Moo`00HWoo00<007oo
Ool0ogooogooFGoo00<007ooOol0Ygoo00<007ooOol06goo001ROol00`00Oomoo`3oOoooOomIOol0
0`00Oomoo`2WOol00`00Oomoo`0KOol0069oo`03001oogoo0?mooomooeUoo`03001oogoo0:Moo`03
001oogoo01]oo`00HWoo00<007ooOol0ogooogooFGoo00<007ooOol0Ygoo00<007ooOol06goo001R
Ool00`00Oomoo`3oOoooOomIOol00`00Oomoo`2WOol00`00Oomoo`0KOol0069oo`03001oogoo0?mo
oomooeUoo`03001oogoo0:Moo`03001oogoo01]oo`00HWoo00<007ooOol0ogooogooFGooZ`007Goo
001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<0
07ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mo
oomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolR
Ool0069oo`<00?mooomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomo
o`3oOoooOoooOolROol0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogooogoo
ogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mooomooomoob9oo`00
HWoo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001o
ogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`3oOooo
OoooOolROol0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo
001ROol3003oOoooOoooOolROol0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0
ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mooomooomo
ob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolROol0069o
o`03001oogoo0?mooomooomoob9oo`00HWoo0`00ogooogooogoo8Woo001ROol00`00Oomoo`3oOooo
OoooOolROol0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo
001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`<00?mooomooomoob9oo`00HWoo00<007ooOol0
ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mooomooomo
ob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol3003oOoooOoooOolROol0069oo`03001o
ogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol3003oOoooOoooOolR
Ool0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol3
003oOoooOoooOolROol0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogooogoo
ogoo8Woo000oOol40006Ool20005Ool7000;Ool3003oOoooOoooOolROol003ioo`03001oogoo009o
o`03001oogoo00=oo`8000Qoo`03001oogoo00aoo`03001oogoo0?mooomooomoob9oo`00?Woo00<0
07ooOol00Woo00<007ooOol03Goo00<007ooOol037oo00<007ooOol0ogooogooogoo8Woo000nOol0
0`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool4003oOoooOoooOolQOol003ioo`03001o
ogoo009oo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo0?mooomooomoob9oo`00?Woo00<0
07ooOol00Woo00<007ooOol03Goo00<007ooOol037oo00<007ooOol0ogooogooogoo8Woo000nOol0
0`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`3oOoooOoooOolROol003io
o`03001oogoo009oo`03001oogoo00]oo`<000ioo`03001oogoo0?mooomooomoob9oo`00?goo1000
47oo00<007ooOol037oo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolR
Ool0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol0
0`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0
ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mooomooomo
ob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolROol0069o
o`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomo
o`3oOoooOoooOolROol0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogooogoo
ogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mooomooomoob9oo`00
HWoo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001o
ogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`3oOooo
OoooOolROol0069oo`03001oogoo00moo`9l0?mooomooomooa5oo`00HWoo00<007ooOol04Goo0g`0
ogooogooogoo3Woo001ROol00`00Oomoo`0DOol2O03oOoooOoooOol<Ool0069oo`03001oogoo01Yo
o`9l0?mooomooomoo`Ioo`00HWoo00<007ooOol077oo0g`0ogooogooogoo0goo001ROol00`00Oomo
o`0OOol2O03oOoooOoooOol1Ool0069oo`03001oogoo02Ioo`=l0?mooomoooQoo`00HWoo00<007oo
Ool0:Goo17`01Goo0g`0ogooogook7oo001ROol00`00Oomoo`0eOol4O005Ool3O03oOoooOooPOol0
069oo`03001oogoo045oo`Al00Eoo`Ml00Eoo`Ml00Eoo`Ml0?mooomookQoo`00HWoo00<007ooOol0
KWoo1g`01Goo1g`01Goo1g`01Goo1g`01Goo1g`01Goo1g`01Goo1g`01Goo1g`01Goo1g`01Goo1g`0
1Goo1g`01Goo1g`01Goo1g`01Goo1g`01Goo1g`01Goo1g`01Goo1g`01Goo1g`01Goo1g`01Goo1g`0
1Goo1g`01Goo1g`01Goo1g`01Goo1g`01Goo1g`01Goo1g`01Goo1g`01Goo1g`01Goo1g`01Goo1g`0
1Goo1g`01Goo1g`01Goo0g`017oo1g`01Goo1g`01Goo1W`0ogoo3Goo001ROol00`00Oomoo`3oOooo
OoooOolROol0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo
001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<0
07ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mo
oomooomoob9oo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogoo
ogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7
Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00
ogoo=7oo10001Goo10000goo0`000Woo0`000Woo1@001Woo100017oo1@000Woo0`000Woo0`0017oo
10002goo1`000Woo0`000Woo0`0017oo100017oo1@000Woo0P000Woo0`0017oo1000ogood7oo003o
OolcOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`05001oogooOol0
0004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol02goo00<007ooOol017oo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000=oo`03001oogoo009oo`04001o
ogoo0005Ool00`00Oomoo`02Ool00`00Oomoo`3oOoo=Ool00?mooc9oo`03001oogoo00Moo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`05Ool0
1@00Oomoogoo000017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol047oo00<007ooOol0
17oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Goo00D007ooOomoo`0000Aoo`03001o
o`0000Ioo`03001oogoo0?moom9oo`00ogoo<Woo00<007ooOol01goo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`03001oogoo009oo`@000Eoo`03001oogoo00Ioo`@000Aoo`03001oogoo009oo`03
001oogoo009oo`03001oogoo011oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`03
001oogoo00Ioo`@000Aoo`<000Ioo`H00?moolmoo`00Igoo0`00agoo00<007ooOol01goo00<007oo
Ool00Woo00@007ooOomoo`8000=oo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`05
Ool01@00Oomoogoo000017oo0P000goo00<007ooOol00Woo00<007ooOol047oo00<007ooOol017oo
0P000goo00<007ooOol00Woo00<007ooOol01Goo00D007ooOomoo`0000Aoo`04001oogoo0005Ool0
0`00Oomoo`02Ool00`00Oomoo`3oOoo=Ool006Qoo`03001oogoo0<Ioo`03001oogoo00=oo`03001o
ogoo009oo`@000=oo`800004Ool000000005Ool50002Ool70004Ool30004Ool2000017oo00000000
0goo1`0037oo0`001Goo0P0000Aoo`00000000=oo`L000Aoo`<000Eoo`03001oo`00008000Eoo`@0
0?moom1oo`00J7oo00<007ooOol0agoo00@007ooOomoo`8001moo`03001oogoo01Qoo`03001oogoo
025oo`03001oogoo00ioo`03001oogoo0?moom]oo`00FWoo1P0017oo0`0000=oo`00Ool0bGoo0`00
00=oo`00Ool07Woo00<007ooOol067oo00<007ooOol08Goo00<007ooOol03Woo00<007ooOol0ogoo
fgoo001KOol00`00Oomoo`02Ool01000Oomoo`000goo0P00ogoo7Goo00<007ooOol07Woo0P00ogoo
gGoo001KOol00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol0ogoo6goo00<007ooOol0ogoo
oGoo001KOol00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol0ogooogooogoo77oo001KOol5
0003Ool01000Oomoogoo0P00ogooogooogoo7Woo001KOol00`00Oomoo`02Ool01000Oomoogoo0`00
00=oo`000000ogooogooogoo7Goo001KOol00`00Oomoo`02Ool00`00Oomoo`3oOoooOoooOolTOol0
05Yoo`H00?mooomooomoobMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMo
o`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003o
OoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomo
oomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogoo
Qgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool0
0?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogoo
ogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00\
\>"],
  ImageRangeCache->{{{0, 899}, {440.375, 0}} -> {-1.06477, -0.648943, \
0.00442081, 0.00442081}, {{21.9375, 700.563}, {429.875, 10.4375}} -> \
{-0.483369, -8.23038, 0.00650107, 0.0319548}, {{700.563, 870.188}, {321.938, \
152.313}} -> {-14.9684, -2.19473, 0.0318352, 0.0265294}, {{714.688, 761.813}, \
{304.938, 248.375}} -> {-15.9492, -11.8048, 0.0334221, 0.108156}, {{714.688, \
761.813}, {225.813, 169.25}} -> {-15.9492, -17.51, 0.0334221, 0.108156}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs1, 180, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Injection\>", 
      IntakeType \[Rule] \ "\<Continuous\>", \ 
      ShowReport \[Rule] \ "\<GraphicReport\>"]\)], "Input",
  CellLabel->"In[29]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.618313 0.0618955 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .12315 -46.5 -6.6875 ]
[-0.0125 .12315 0 6.6875 ]
[-0.0125 .24694 -46.5 -6.6875 ]
[-0.0125 .24694 0 6.6875 ]
[-0.0125 .37073 -40 -6.28125 ]
[-0.0125 .37073 0 6.28125 ]
[-0.0125 .49452 -28 -6.28125 ]
[-0.0125 .49452 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12315 m
.00625 .12315 L
s
gsave
-0.0125 .12315 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .24694 m
.00625 .24694 L
s
gsave
-0.0125 .24694 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .37073 m
.00625 .37073 L
s
gsave
-0.0125 .37073 -101 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0001) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .49452 m
.00625 .49452 L
s
gsave
-0.0125 .49452 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .06615 m
.00375 .06615 L
s
0 .08364 m
.00375 .08364 L
s
0 .09415 m
.00375 .09415 L
s
0 .10168 m
.00375 .10168 L
s
0 .10756 m
.00375 .10756 L
s
0 .11238 m
.00375 .11238 L
s
0 .11647 m
.00375 .11647 L
s
0 .12002 m
.00375 .12002 L
s
0 .18995 m
.00375 .18995 L
s
0 .20743 m
.00375 .20743 L
s
0 .21794 m
.00375 .21794 L
s
0 .22548 m
.00375 .22548 L
s
0 .23135 m
.00375 .23135 L
s
0 .23617 m
.00375 .23617 L
s
0 .24026 m
.00375 .24026 L
s
0 .24381 m
.00375 .24381 L
s
0 .31374 m
.00375 .31374 L
s
0 .33122 m
.00375 .33122 L
s
0 .34173 m
.00375 .34173 L
s
0 .34927 m
.00375 .34927 L
s
0 .35515 m
.00375 .35515 L
s
0 .35997 m
.00375 .35997 L
s
0 .36405 m
.00375 .36405 L
s
0 .3676 m
.00375 .3676 L
s
0 .43753 m
.00375 .43753 L
s
0 .45502 m
.00375 .45502 L
s
0 .46552 m
.00375 .46552 L
s
0 .47306 m
.00375 .47306 L
s
0 .47894 m
.00375 .47894 L
s
0 .48376 m
.00375 .48376 L
s
0 .48784 m
.00375 .48784 L
s
0 .49139 m
.00375 .49139 L
s
0 .56132 m
.00375 .56132 L
s
0 .57881 m
.00375 .57881 L
s
0 .58931 m
.00375 .58931 L
s
0 .59685 m
.00375 .59685 L
s
0 .60273 m
.00375 .60273 L
s
0 .60755 m
.00375 .60755 L
s
0 .61163 m
.00375 .61163 L
s
0 .61518 m
.00375 .61518 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Continuous) show
129.000 12.813 moveto
(intake) show
165.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .59485 m
.06042 .60086 L
.08838 .60295 L
.1161 .60332 L
.13894 .60267 L
.15779 .60162 L
.17363 .60043 L
.20509 .59736 L
.25791 .59029 L
.30107 .58265 L
.3616 .56841 L
.41107 .55277 L
.48481 .52047 L
.53436 .49134 L
.60255 .44381 L
.65487 .41142 L
.69419 .39124 L
.72541 .37419 L
.75367 .35613 L
.77729 .33848 L
.79945 .31947 L
.81854 .30098 L
.83519 .28309 L
.8514 .26398 L
.86575 .24552 L
.87857 .22775 L
.8913 .20881 L
.90277 .19056 L
.91423 .17115 L
.92462 .15245 L
.9341 .13446 L
.94367 .11531 L
.95243 .09687 L
.96048 .07914 L
.96868 .06025 L
.97619 .04222 L
s
0 0 1 r
[ ] 0 setdash
.02381 .18638 m
.13894 .26909 L
.20509 .30941 L
.30107 .35466 L
.36239 .37513 L
.41107 .38681 L
.43247 .39067 L
.45317 .39364 L
.47079 .39558 L
.47862 .39626 L
.48567 .39678 L
.49228 .39718 L
.49812 .39747 L
.5044 .3977 L
.50777 .3978 L
.51092 .39787 L
.51389 .39791 L
.51701 .39794 L
.51991 .39795 L
.5225 .39795 L
.52407 .39794 L
.5255 .39793 L
.52707 .39791 L
.5287 .39789 L
.53142 .39783 L
.53436 .39776 L
.53963 .39758 L
.5452 .39733 L
.5549 .39673 L
.56388 .396 L
.57182 .3952 L
.58864 .39302 L
.60496 .39026 L
.63121 .38439 L
.65285 .37812 L
.69164 .3633 L
.72549 .34614 L
.75308 .32883 L
.77619 .31174 L
.79796 .29326 L
.81673 .27528 L
.83477 .25604 L
.85062 .23741 L
.86467 .21945 L
.87853 .2003 L
.89095 .18184 L
.90215 .16407 L
.91337 .14515 L
.92355 .12693 L
.93379 .10755 L
Mistroke
.94314 .08888 L
.95171 .07092 L
.96041 .05181 L
.96841 .0334 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[29]:=",
  ImageSize->{600, 294.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000>40001^A000`40O003h00OogooogooogooQgoo
003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mo
oomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogoo
ogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7
Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00
ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOooo
OoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomo
ohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool006aoo`L003ioo`H005Moo`@003aoo`L000=o
o`@003Moo`H000Aoo`@004moo`@000Eoo`@003=oo`L000=oo`@000Eoo`@002ioo`H000Aoo`@000Eo
o`@00?Qoo`00Kgoo00<007ooOol0?goo00<007ooOol00Woo00<007ooOol0E7oo00<007ooOol00Woo
00<007ooOol0?7oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0=7oo00<007ooOol00Woo
00D007ooOomoo`0000Aoo`03001oogoo04]oo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`0cOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0:goo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`3eOol006mo
o`03001oogoo041oo`03001oogoo05eoo`03001oogoo03aoo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo03Eoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo051oo`05001oogooOol0
0004Ool00`00Oomoo`0cOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<0
07ooOol0;7oo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo0?Eo
o`00Kgoo00<007ooOol0@Goo00<007ooOol0G7oo00<007ooOol0?7oo00<007ooOol00goo00<007oo
Ool00Woo00<007ooOol0=Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0D7oo00D007oo
Oomoo`0000Aoo`03001oogoo03=oo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0]Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool0mGoo001_Ool00`00Oomoo`12Ool00`00Oomoo`1KOol00`00Oomoo`0lOol00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`0gOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`1@Ool0
1@00Oomoogoo000017oo00<007ooOol0<goo00<007ooOol00goo00<007ooOol00Woo00D007ooOomo
o`0000Aoo`03001oogoo02ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool0
0`00Oomoo`3eOol006moo`03001oogoo04=oo`03001oogoo05Ioo`@003moo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo03Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo04aoo`@0
00Aoo`03001oogoo009oo`03001oogoo03=oo`03001oogoo00=oo`03001oogoo009oo`05001oogoo
Ool00004Ool00`00Oomoo`0_Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo
00<007ooOol0mGoo001_Ool00`00Oomoo`0oOol00`00Oomoo`02Ool00`00Oomoo`1EOol00`00Oomo
o`10Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0dOol00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00<007ooOol0C7oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0<goo00<0
07ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo02]oo`03001oogoo009o
o`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol0mGoo001]Ool30011Ool00`00
Oomoo`02Ool00`00Oomoo`1EOol00`00Oomoo`0nOol30005Ool00`00Oomoo`02Ool00`00Oomoo`0d
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0C7oo00<007ooOol01Goo00<007oo
Ool00Woo00<007ooOol0<Goo0`001Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo
02]oo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol0mGoo
001_Ool00`00Oomoo`10Ool4001HOol5000nOol00`00Oomoo`04Ool4000hOol40005Ool4001?Ool5
0004Ool4000fOol00`00Oomoo`04Ool40005Ool4000_Ool40005Ool40005Ool4003hOol00?mooomo
oomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooZgoo
0`00f7oo003oOoooOon]Ool00`00Oomoo`3FOol00?mooomoojeoo`03001oogoo0=Ioo`00ogooogoo
VGoo0`0000=oo`00000017oo1@001Goo0P001Goo1@00cGoo003oOoooOonHOol01000Oomoogoo0P00
17oo00D007ooOomoo`0000Ioo`8000Eoo`03001oogoo009oo`03001oogoo0<Yoo`00ogooogooV7oo
00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Eoo`04001oogoo0009Ool00`00Oomo
o`3:Ool0069oool00?l002D0015oo`03001oogoo009oo`03001oogoo00=oo`@000Eoo`04001oogoo
0005Ool4003=Ool0069oo`03001oogoo00Yoo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo
01Yoo`03001oogoo01=oo`03001oogoo011oo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo
00Uoo`03001oogoo00Qoo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo01Yoo`03001oogoo
01=oo`03001oogoo00moo`03001oogoo00eoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo
00Moo`03001oogoo04=oo`03001oogoo015oo`04001oogooOol20004Ool01@00Oomoogoo000017oo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo0<Yoo`00HWoo00<007ooOol02Woo00<0
07ooOol0@Woo00<007ooOol09Woo00<007ooOol06Woo00<007ooOol04goo00<007ooOol047oo00<0
07ooOol037oo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0@Woo00<0
07ooOol09Woo00<007ooOol06Woo00<007ooOol04goo00<007ooOol03goo00<007ooOol03Goo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol01goo00<007ooOol0@goo00<007ooOol04Woo0`00
00=oo`00Ool017oo0`0017oo0`000Woo0`000goo1@00c7oo001ROol00`00Oomoo`0:Ool00`00Oomo
o`12Ool00`00Oomoo`1IOol00`00Oomoo`13Ool00`00Oomoo`12Ool00`00Oomoo`1IOol00`00Oomo
o`12Ool00`00Oomoo`13Ool00`00Oomoo`0FOol00`00Oomoo`3VOol0069oo`03001oogoo00Yoo`03
001oogoo049oo`03001oogoo05Uoo`03001oogoo04=oo`03001oogoo049oo`03001oogoo05Uoo`03
001oogoo049oo`03001oogoo04=oo`03001oogoo01Ioo`03001oogoo0>Ioo`00HWoo00<007ooOol0
ogooogoo=goo0P00j7oo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mooomo
oomoob9oo`00HWoo00<007ooOol0ogooogoo57oo00<07gooOol0ogoo2goo001ROol00`00Oomoo`3o
OoooOolDOol00`0OOomoo`3oOol;Ool0069oo`03001oogoo0?mooomooa=oo`0301moogoo0?moo`ao
o`00HWoo00<007ooOol0ogooogoo4goo00<07gooOol0ogoo37oo001ROol00`00Oomoo`3oOoooOolB
Ool00`0OOomoo`3oOol=Ool0069oo`03001oogoo0?mooomooa9oo`0301moogoo0?moo`eoo`00HWoo
00<007ooOol0ogooogoo4Woo00<07gooOol0ogoo3Goo001ROol00`00Oomoo`3oOoooOolAOol00`0O
Oomoo`3oOol>Ool0069oo`03001oogoo0?mooomooa5oo`0301moogoo0?moo`ioo`00HWoo00<007oo
Ool0ogooogoo47oo00<07gooOol0ogoo3goo001ROol00`00Oomoo`3oOoooOol@Ool00`0OOomoo`3o
Ool?Ool0069oo`03001oogoo0?mooomooa1oo`0301moogoo0?moo`moo`00HWoo00<007ooOol0ogoo
ogoo3goo00<07gooOol0ogoo47oo001ROol00`00Oomoo`3oOoooOol?Ool00`0OOomoo`3oOol@Ool0
069oo`03001oogoo0?mooomoo`ioo`0301moogoo0?mooa5oo`00HWoo00<007ooOol0ogooogoo3Woo
00<07gooOol0ogoo4Goo001ROol00`00Oomoo`3oOoooOol>Ool00`0OOomoo`3oOolAOol0069oo`03
001oogoo0?mooomoo`eoo`0301moogoo00=oo`03O01oogoo0?moo`aoo`00HWoo00<007ooOol0ogoo
ogoo3Goo00<07gooOol00goo00=l07ooOol0ogoo37oo001ROol00`00Oomoo`3oOoooOol<Ool00`0O
Oomoo`03Ool00g`0Oomoo`3oOol=Ool0069oo`03001oogoo0?mooomoo`aoo`0301moogoo00=oo`03
O01oogoo0?moo`eoo`00HWoo00<007ooOol0ogooogoo37oo00<07gooOol00goo00=l07ooOol0ogoo
3Goo001ROol00`00Oomoo`3oOoooOol;Ool00`0OOomoo`03Ool00g`0Oomoo`3oOol>Ool0069oo`03
001oogoo0?mooomoo`]oo`0301moogoo00=oo`03O01oogoo0?moo`ioo`00HWoo00<007ooOol0ogoo
ogoo2Woo00<07gooOol0ogoo5Goo001ROol00`00Oomoo`3oOoooOol:Ool00`0OOomoo`3oOolEOol0
069oo`03001oogoo0?mooomoo`Uoo`0301moogoo0?mooaIoo`00HWoo00<007ooOol0ogooogoo2Goo
00<07gooOol0ogoo5Woo001ROol3003oOoooOol8Ool00`0OOomoo`04Ool00g`0Oomoo`3oOol@Ool0
069oo`03001oogoo0?mooomoo`Qoo`0301moogoo00=oo`03O01oogoo0?mooa5oo`00HWoo00<007oo
Ool0ogooogoo1goo00<07gooOol017oo00=l07ooOol0ogoo4Goo001ROol00`00Oomoo`3oOoooOol7
Ool00`0OOomoo`03Ool00g`0Oomoo`3oOolBOol0069oo`03001oogoo0?mooomoo`Ioo`0301moogoo
00Aoo`03O01oogoo0?mooa9oo`00HWoo00<007ooOol0ogooogoo1Woo00<07gooOol00goo00=l07oo
Ool0ogoo4goo001ROol00`00Oomoo`3oOoooOol5Ool00`0OOomoo`04Ool00g`0Oomoo`3oOolCOol0
069oo`03001oogoo0?mooomoo`Eoo`0301moogoo0?mooaYoo`00HWoo00<007ooOol0ogooogoo17oo
00<07gooOol0ogoo6goo001ROol00`00Oomoo`3oOoooOol4Ool00`0OOomoo`3oOolKOol0069oo`<0
0?mooomoo`=oo`0301moogoo0?mooaaoo`00HWoo00<007ooOol0ogooogoo0goo00<07gooOol017oo
00=l07ooOol0ogoo5Goo001ROol00`00Oomoo`3oOoooOol2Ool00`0OOomoo`04Ool00g`0Oomoo`3o
OolFOol0069oo`03001oogoo0?mooomoo`9oo`0301moogoo00Aoo`03O01oogoo0?mooaIoo`00HWoo
00<007ooOol0ogooogoo0Goo00<07gooOol017oo00=l07ooOol0ogoo5goo001ROol00`00Oomoo`3o
OoooOol1Ool00`0OOomoo`04Ool00g`0Oomoo`3oOolGOol0069oo`<00?mooomoo`0301moogoo00Ao
o`03O01oogoo0?mooaQoo`00HWoo00<007ooOol0ogooogoo00<07gooOol017oo00=l07ooOol0ogoo
67oo001ROol00`00Oomoo`3oOoonOol00`0OOomoo`3oOolPOol0069oo`03001oogoo0?moooioo`03
01moogoo0?moob1oo`00HWoo0`00ogoooGoo00<07gooOol0ogoo8Goo001ROol00`00Oomoo`3oOoom
Ool00`0OOomoo`3oOolQOol0069oo`03001oogoo0?moooaoo`0301moogoo00Eoo`03O01oogoo0?mo
oaYoo`00HWoo0`00ogooo7oo00<07gooOol01Goo00=l07ooOol0ogoo6Woo001ROol00`00Oomoo`3o
OookOol00`0OOomoo`05Ool00g`0Oomoo`3oOolKOol0069oo`<00?mooo]oo`0301moogoo00Eoo`03
O01oogoo0?mooa]oo`00HWoo00<007ooOol0ogoonWoo00<07gooOol01Goo00=l07ooOol0ogoo77oo
001ROol00`00Oomoo`3oOoojOol00`0OOomoo`05Ool00g`0Oomoo`3oOolLOol001Yoo`L000Aoo`80
00Moo`03001oogoo00=oo`03001oogoo00=oo`L000=oo`@001Yoo`<00?moooUoo`0301moogoo00Eo
o`03O01oogoo0?mooaeoo`007Goo00<007ooOol01Goo0P0027oo00D007ooOomoo`0000Uoo`03001o
ogoo00=oo`03001oogoo009oo`03001oogoo01Moo`03001oogoo0?moooUoo`0301moogoo06=oojX0
01Moo`007Goo00<007ooOol047oo00<007oo00002Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol05goo0`00ogoon7oo00<07gooOol0I7ooZP005goo000MOol00`00Oomoo`0AOol00`00Oomo
o`09Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0GOol4003oOoogOol00`0OOomoo`1T
OonZ000GOol001eoo`03001oogoo011oo`03001oo`0000Yoo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo01Moo`03001oogoo0?moooMoo`0301moogoo06EoojX001Moo`007Goo00<007ooOol0
3goo00D007ooOomoo`0000Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo01Moo`03001o
ogoo0?moooMoo`0301moogoo00Eoo`03O01oogoo05eoojX001Moo`007Goo00<007ooOol03Woo00<0
07ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol027oo0`00
37oo00<007ooOol0ogoomWoo00<07gooOol01Goo00=l07ooOol0GWooZP005goo000KOol3000MOol3
0005Ool00`00Oomoo`02Ool00`00Oomoo`07Ool01@00Oomoogoo00002goo00<007ooOol0ogoomWoo
00<07gooOol01Goo00=l07ooOol0Egoo/@005goo000MOol00`00Oomoo`0MOol00`00Oomoo`04Ool4
0004Ool500000goo001oo`02Ool00`00Oomoo`09Ool00`00Oomoo`3oOooeOol00`0OOomoo`05Ool0
0g`0Oomoo`1HOol00`00Oomoo`2WOol7000GOol005=oo`<000aoo`03001oogoo0?moooEoo`0301mo
ogoo00Eoo`03O01oogoo05Qoo`03001oogoo0:Moo`L001Moo`00DWoo00D007ooOomoo`0000]oo`03
001oogoo0?moooAoo`0301moogoo00Eoo`03O01oogoo05Uoo`03001oogoo0:Moo`L001Moo`00DWoo
00D007ooOomoo`0000]oo`03001oogoo0?mooo=oo`0301moogoo069oo`03001oogoo0:Moo`L001Mo
o`00Dgoo0`0037oo00<007ooOol0ogoolgoo00<07gooOol0HWoo00<007ooOol0Ygoo1`005goo001R
Ool00`00Oomoo`3oOoobOol00`0OOomoo`1SOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo
0?mooo9oo`0301moogoo06=oo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoolGoo00<0
7gooOol0I7oo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOoo`Ool00`0OOomoo`06Ool0
0g`0Oomoo`1LOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?mooo1oo`0301moogoo00Eo
o`03O01oogoo05eoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogookgoo00<07gooOol0
1Woo00=l07ooOol0GGoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOoo_Ool00`0OOomo
o`05Ool00g`0Oomoo`1NOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?moonioo`0301mo
ogoo00Eoo`03O01oogoo05moo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogookWoo00<0
7gooOol01Goo00=l07ooOol0Ggoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOoo]Ool0
0`0OOomoo`1XOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?mooneoo`0301moogoo06Qo
o`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogook7oo00<07gooOol0JGoo00<007ooOol0
Ygoo1`005goo001ROol00`00Oomoo`3oOoo/Ool00`0OOomoo`1YOol00`00Oomoo`2WOol7000GOol0
069oo`03001oogoo0?moon]oo`0301moogoo00Eoo`03O01oogoo069oo`03001oogoo0:Moo`L001Mo
o`00HWoo00<007ooOol0ogoojWoo00<07gooOol01Woo00=l07ooOol0HWoo00<007ooOol0Ygoo1`00
5goo001ROol00`00Oomoo`3oOooZOol00`0OOomoo`05Ool00g`0Oomoo`1SOol00`00Oomoo`2WOol7
000GOol0069oo`03001oogoo0?moonUoo`0301moogoo00Ioo`03O01oogoo06=oo`03001oogoo0:Mo
o`L001Moo`00HWoo00<007ooOol0ogooj7oo00<07gooOol01goo00=l07ooOol0Hgoo00<007ooOol0
Ygoo1`005goo001ROol00`00Oomoo`3oOooXOol00`0OOomoo`05Ool2O01VOol00`00Oomoo`2WOol7
000GOol0069oo`03001oogoo0?moonMoo`0301moogoo06ioo`03001oogoo0:Moo`L001Moo`00HWoo
00<007ooOol0ogooiWoo00<07gooOol0Kgoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3o
OooVOol00`0OOomoo`1_Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?moonEoo`0301mo
ogoo071oo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogooi7oo00<07gooOol0LGoo00<0
07ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOooTOol00`0OOomoo`06Ool00g`0Oomoo`1XOol0
0`00Oomoo`2WOol7000GOol0069oo`03001oogoo00Yoo`0301moogoo0?moomIoo`0301moogoo00Io
o`03O01oogoo06Uoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol02goo0P0OogooeGoo00<0
7gooOol01goo00=l07ooOol0JGoo00<007ooOol0BWoo1`000Woo0`000Woo0`000goo100017oo1@00
1Goo10001Woo10000Woo1`0017oo10000goo0`000Woo0`003Goo1`005goo001ROol3000=Ool00`0O
Oomoo`3oOooBOol00`0OOomoo`06Ool00g`0Oomoo`1ZOol00`00Oomoo`1;Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Goo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00aoo`L001Moo`00HWoo00<007ooOol0
3Woo00<07gooOol0ogood7oo00<07gooOol01Woo00=l07ooOol0Jgoo00<007ooOol0Bgoo00<007oo
Ool00Woo00<007ooOol00goo0P0017oo00<007ooOol027oo00<007ooOol01Goo00<007ooOol01goo
00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo
00aoo`L001Moo`00HWoo00<007ooOol03goo0P0Oogood7oo00<07gooOol01Woo00=l07ooOol0Jgoo
00<007ooOol0Bgoo00@007ooOol000Moo`8000Aoo`03001oogoo00Qoo`03001oogoo00Eoo`H000Ao
o`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomo
o`0<Ool7000GOol0069oo`03001oogoo015oo`0301moogoo0?moolaoo`0301moogoo07Eoo`03001o
ogoo04]oo`@000Ioo`04001oogoo0004Ool01000Oomoogoo0P0017oo0P001Woo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00@007ooOomoo`80
00=oo`03001oogoo00aoo`L001Moo`00HWoo00<007ooOol04Woo0P0Oogoobgoo00<07gooOol0MWoo
00<007ooOol0Bgoo00H007ooOol007oo0002Ool30002Ool30003Ool300000goo001oo`02Ool20000
17oo0000000017oo10000goo1`000goo0`001goo10000goo0P0000Aoo`00000000moo`L001Moo`00
HWoo00<007ooOol057oo00<07gooOol0ogoob7oo00<07gooOol0MWoo00<007ooOol0Bgoo00<007oo
Ool00Woo00<007ooOol09Woo00<007ooOol0:goo1`005goo001ROol00`00Oomoo`0EOol00`0OOomo
o`3oOoo6Ool00`0OOomoo`1gOol00`00Oomoo`1:Ool7000XOol00`00Oomoo`0[Ool7000GOol0069o
o`03001oogoo01Ioo`807omoolEoo`0301moogoo00Moo`03O01oogoo06ioo`03001oogoo08=oo`03
001oogoo025oo`L001Moo`00HWoo00<007ooOol067oo00<07gooOol0ogoo`Goo00<07gooOol01goo
00=l07ooOol0Kgoo00<007ooOol0Pgoo00<007ooOol08Goo1`005goo001ROol3000IOol201ooOoo1
Ool00`0OOomoo`07Ool00g`0Oomoo`1_Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo01]o
o`0301moogoo0?mookeoo`0301moogoo00Moo`03O01oogoo071oo`03001oogoo0:Moo`L001Moo`00
HWoo00<007ooOol077oo00<07gooOol0ogoo^goo00<07gooOol01goo00=l07ooOol0LGoo00<007oo
Ool0Ygoo1`005goo001ROol00`00Oomoo`0MOol201ooOonjOol00`0OOomoo`08Ool00g`0Oomoo`1a
Ool00`00Oomoo`0<Ool7O005Ool7O005Ool7O005Ool7O01`Ool7000GOol0069oo`03001oogoo01mo
o`0301moogoo0?mookIoo`0301moogoo07eoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0
87oo0P0Oogoo]Woo00<07gooOol0OGoo00<007ooOol0Ygoo1`005goo001ROol3000ROol00`0OOomo
o`3oOonbOol00`0OOomoo`1nOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo02=oo`0301mo
ogoo0?mook1oo`0301moogoo07moo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol097oo0P0O
ogoo[goo00<07gooOol027oo00=l07ooOol0MGoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomo
o`0VOol00`0OOomoo`3oOon/Ool00`0OOomoo`07Ool00g`0Oomoo`1fOol00`00Oomoo`2WOol7000G
Ool0069oo`<002Moo`807omooj]oo`0301moogoo00Qoo`03O01oogoo07Ioo`03001oogoo04aoo`@0
00Aoo`D000=oo`L0009oo`<0009oo`<000=oo`@003=oo`L001Moo`00HWoo00<007ooOol0:Goo00<0
7gooOol0ogooYgoo00<07gooOol027oo00=l07ooOol0Mgoo00<007ooOol0Bgoo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`03001oogoo031oo`L001Moo`00HWoo00<007ooOol0:Woo00<07gooOol0ogooYGoo00<07goo
Ool02Goo00=l07ooOol0Mgoo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool01goo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0003Moo`L001Moo`00HWoo0`00
:goo0P0OogooYGoo00<07gooOol027oo00=l07ooOol0N7oo00<007ooOol0Bgoo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00@007ooOomoo`H0
039oo`L001Moo`00HWoo00<007ooOol0;Goo00<07gooOol0ogooXGoo00<07gooOol0Q7oo00<007oo
Ool0Bgoo00<007ooOol00Woo00<007ooOol00Woo0P0027oo00<007ooOol017oo0P000goo00D007oo
Oomoo`0000Aoo`03001oogoo031oo`L001Moo`00HWoo00<007ooOol0;Woo0P0OogooX7oo00<07goo
Ool0QGoo00<007ooOol0Bgoo00<007ooOol00Woo00@007ooOomoo`800004Ool000000003Ool30005
Ool2000017oo000000001Goo1000<goo1`005goo001ROol3000`Ool00`0OOomoo`3oOonMOol00`0O
Oomoo`25Ool00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`1DOol7000GOol0069oo`03001o
ogoo035oo`0301moogoo0?mooi]oo`0301moogoo08Ioo`03001oogoo04Yoo`<0009oo`<005Eoo`L0
01Moo`00HWoo0`00<Woo0P0OogooVWoo00<07gooOol02Goo00=l07ooOol0Ngoo00<007ooOol0Ggoo
00<007ooOol0AGoo1`005goo000JOol70004Ool20007Ool00`00Oomoo`03Ool00`00Oomoo`03Ool7
0003Ool4000JOol00`00Oomoo`0dOol00`0OOomoo`3oOonFOol00`0OOomoo`09Ool00g`0Oomoo`1l
Ool00`00Oomoo`1OOol00`00Oomoo`15Ool7000GOol001eoo`03001oogoo00Eoo`8000Qoo`05001o
ogooOol00009Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0GOol3000eOol201ooOonE
Ool00`0OOomoo`09Ool00g`0Oomoo`1mOol00`00Oomoo`2WOol7000GOol001eoo`03001oogoo011o
o`03001oo`0000Yoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo01Moo`03001oogoo03Mo
o`0301moogoo0?mooi5oo`0301moogoo00Uoo`03O01oogoo07ioo`03001oogoo0:Moo`L001Moo`00
7Goo00<007ooOol04Goo00<007ooOol02Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0
5goo1000=goo00<07gooOol0ogooSgoo00<07gooOol02Goo00=l07ooOol0Ogoo00<007ooOol0Ygoo
1`005goo000MOol00`00Oomoo`0@Ool00`00Ool0000:Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Oomoo`0GOol00`00Oomoo`0iOol201ooOon?Ool00`0OOomoo`09Ool00g`0Oomoo`1oOol00`00
Oomoo`2WOol7000GOol001eoo`03001oogoo00moo`05001oogooOol00009Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`0GOol00`00Oomoo`0kOol00`0OOomoo`3oOon;Ool00`0OOomoo`2<
Ool00`00Oomoo`2WOol7000GOol001eoo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00Io
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Qoo`<000aoo`03001oogoo03aoo`807omo
ohYoo`0301moogoo08eoo`03001oogoo0:Moo`L001Moo`006goo0`007Goo0`001Goo00<007ooOol0
0Woo00<007ooOol01goo00D007ooOomoo`0000]oo`03001oogoo03ioo`0301moogoo0?moohIoo`03
01moogoo08ioo`03001oogoo0:Moo`L001Moo`007Goo00<007ooOol07Goo00<007ooOol017oo1000
17oo1@0000=oo`00Ool00Woo00<007ooOol02Goo00<007ooOol0?goo00<07gooOol0ogooQ7oo00<0
7gooOol02Goo00=l07ooOol0Pgoo00<007ooOol0Ygoo1`005goo001BOol4000<Ool00`00Oomoo`10
Ool201ooOon3Ool00`0OOomoo`09Ool00g`0Oomoo`24Ool00`00Oomoo`2WOol7000GOol0059oo`03
001oogoo00eoo`03001oogoo049oo`0301moogoo0?moogmoo`0301moogoo00Uoo`03O01oogoo08Eo
o`03001oogoo0:Moo`L001Moo`00Dgoo00<007ooOol037oo00<007ooOol0@goo0P0OogooOWoo00<0
7gooOol02Woo00=l07ooOol0QGoo00<007ooOol0Ygoo1`005goo001DOol3000;Ool00`00Oomoo`15
Ool00`0OOomoo`3oOomjOol00`0OOomoo`0:Ool00g`0Oomoo`26Ool00`00Oomoo`2WOol7000GOol0
069oo`03001oogoo04Ioo`0301moogoo0?moogQoo`0301moogoo00]oo`03O01oogoo08Ioo`03001o
ogoo0:Moo`L001Moo`00HWoo00<007ooOol0Agoo0P0OogooMgoo00<07gooOol0UGoo00<007ooOol0
Ygoo1`005goo001ROol00`00Oomoo`19Ool00`0OOomoo`3oOomcOol00`0OOomoo`2FOol00`00Oomo
o`2WOol7000GOol0069oo`03001oogoo04Yoo`807omoog9oo`0301moogoo09Moo`03001oogoo0:Mo
o`L001Moo`00HWoo00<007ooOol0C7oo0P0OogooKgoo00<07gooOol0V7oo00<007ooOol0Ygoo1`00
5goo001ROol00`00Oomoo`1>Ool00`0OOomoo`3oOom[Ool00`0OOomoo`0<Ool00g`0Oomoo`2:Ool0
0`00Oomoo`2WOol7000GOol0069oo`03001oogoo04moo`807omoofYoo`0301moogoo00aoo`03O01o
ogoo08]oo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0DGoo00<07gooOol0ogooIWoo00<0
7gooOol037oo00=l07ooOol0S7oo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`1BOol201oo
OomUOol00`0OOomoo`0<Ool00g`0Oomoo`2=Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo
05Aoo`807omoof9oo`0301moogoo00aoo`03O01oogoo08ioo`03001oogoo0:Moo`L001Moo`00HWoo
00<007ooOol0EWoo00<07gooOol0ogooGWoo00<07gooOol0WWoo00<007ooOol0Ygoo1`005goo001R
Ool00`00Oomoo`1GOol201ooOomMOol00`0OOomoo`2OOol00`00Oomoo`2WOol7000GOol0069oo`03
001oogoo05Uoo`807omooeYoo`0301moogoo0:1oo`03001oogoo0:Moo`L001Moo`00HWoo00<007oo
Ool0Fgoo00<07gooOol0ogooEWoo00<07gooOol0XGoo00<007ooOol0Ygoo1`005goo001ROol00`00
Oomoo`1LOol201ooOomEOol00`0OOomoo`0=Ool00g`0Oomoo`2BOol00`00Oomoo`2WOol7000GOol0
069oo`03001oogoo05ioo`807omooe9oo`0301moogoo00eoo`03O01oogoo09=oo`03001oogoo0:Mo
o`L001Moo`00HWoo00<007ooOol0H7oo00<07gooOol0ogooCWoo00<07gooOol03Goo00=l07ooOol0
U7oo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`1QOol201ooOom=Ool00`0OOomoo`0=Ool0
0g`0Oomoo`2EOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo06=oo`0301moogoo0?moodQo
o`807`moo`03O01oogoo09Ioo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0I7oo0P0Oogoo
Agoo00<07gooOol0Z7oo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`1VOol201ooOom4Ool0
0`0OOomoo`2YOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo06Qoo`0301moogoo0?mood1o
o`0301moogoo0:Yoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0JGoo0P0Oogoo?goo00<0
7gooOol03Woo00=l07ooOol0VWoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`1[Ool201oo
OolkOol201l@Ool00g`0Oomoo`2KOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo06eoo`80
7omoocQoo`0301moogoo00ioo`9l09ioo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0Kgoo
0P0Oogoo=Goo00<07gooOol03Woo00=l07ooOol0WWoo00<007ooOol0Ygoo1`005goo001ROol00`00
Oomoo`1aOol201ooOolbOol00`0OOomoo`0>Ool00g`0Oomoo`2OOol00`00Oomoo`2WOol7000GOol0
069oo`<007=oo`807omoobioo`807k=oo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0MGoo
0P0Oogoo:goo00<07gooOol0/goo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`1gOol201oo
OolXOol00`0OOomoo`2dOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo07Uoo`807omoobAo
o`807kMoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0Ngoo0P0Oogoo8Goo00<07gooOol0
4Goo00=l07ooOol0Xgoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`1mOol301ooOolMOol0
0`0OOomoo`0@Ool2O02VOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo081oo`807omooaUo
o`807a5oo`9l0:Qoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0PWoo0P0Oogoo5Woo00<0
7gooOol047oo00=l07ooOol0Z7oo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`24Ool201oo
OolCOol00`0OOomoo`2lOol00`00Oomoo`2WOol7000GOol0069oo`<008Ioo`807omoo`moo`807kmo
o`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0R7oo0P0Oogoo2goo0P0O`Goo00<007ooOol0
BWoo1`000Woo0`000Woo0`000goo100017oo1@001Goo10001Woo10000Woo1`0017oo10000goo0`00
0Woo0`003Goo1`005goo001ROol00`00Oomoo`2:Ool201ooOol8Ool00`0OOomoo`0BOol00g`0Oomo
o`2/Ool00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03
001oogoo00aoo`L001Moo`00HWoo00<007ooOol0S7oo0P0Oogoo17oo0P0O57oo00=l07ooOol0[Goo
00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol00goo0P0017oo00<007ooOol027oo00<007oo
Ool01Goo00<007ooOol01goo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`03001oogoo00aoo`L001Moo`00HWoo00<007ooOol0SWoo0P0Oogoo0P0O5Goo00=l
07ooOol0[Woo00<007ooOol0Bgoo00@007ooOol000Moo`8000Aoo`03001oogoo00Qoo`03001oogoo
00Eoo`H000Aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0<Ool7000GOol0069oo`03001oogoo091oo`<07o]oo`0301moogoo01=oo`9l0;5o
o`03001oogoo04]oo`@000Ioo`04001oogoo0004Ool01000Oomoogoo0P0017oo0P001Woo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00@007oo
Oomoo`8000=oo`03001oogoo00aoo`L001Moo`00HWoo0`00Tgoo0P0Omgoo0P0O5Goo00=l07ooOol0
/Goo00<007ooOol0Bgoo00H007ooOol007oo0002Ool30002Ool30003Ool300000goo001oo`02Ool2
000017oo0000000017oo10000goo1`000goo0`001goo10000goo0P0000Aoo`00000000moo`L001Mo
o`00HWoo00<007ooOol0UGoo0P0Olgoo0P0Obgoo00<007ooOol0Bgoo00<007ooOol00Woo00<007oo
Ool09Woo00<007ooOol0:goo1`005goo001ROol00`00Oomoo`2GOol201o`Ool00`0OOomoo`3;Ool0
0`00Oomoo`1:Ool7000XOol00`00Oomoo`0[Ool7000GOol0069oo`03001oogoo09Uoo`807naoo`80
7lioo`03001oogoo08=oo`03001oogoo025oo`L001Moo`00HWoo0`00Vgoo0P0Oj7oo0P0O5goo00=l
07ooOol0]Woo00<007ooOol0Pgoo00<007ooOol08Goo1`005goo001ROol00`00Oomoo`2MOol201oT
Ool201lGOol2O02iOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo09moo`807n1oo`807aMo
o`9l0;]oo`03001oogoo0:Moo`L001Moo`00HWoo0`00XGoo0`0Og7oo00<07gooOol05Woo00=l07oo
Ool0^goo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`2TOol301oGOol201oGOol00`00Oomo
o`0<Ool^01m]Ool7000GOol0069oo`03001oogoo0:Moo`<07m9oo`807mUoo`03001oogoo0:Moo`L0
01Moo`00HWoo0`00ZWoo0`0OcGoo0P0O67oo00=l07ooOol0`7oo00<007ooOol0Ygoo1`005goo001R
Ool00`00Oomoo`2]Ool301o8Ool201lIOol00g`0Oomoo`31Ool00`00Oomoo`2WOol7000GOol0069o
o`<00;1oo`<07l=oo`807aUoo`9l0<Aoo`03001oogoo0:Moo`L001Moo`0097oo10001Woo0P001Woo
10001Goo10001Goo100017oo1`002goo00<007ooOol0/goo0`0O_Woo0P0O6Woo00=l07ooOol0a7oo
00<007ooOol0Ygoo1`005goo000SOol00`00Oomoo`02Ool00`00Oomoo`03Ool20005Ool00`00Oomo
o`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00ao
o`<00;Ioo`<07kQoo`<07a]oo`03O01oogoo0<Eoo`03001oogoo0:Moo`L001Moo`008goo00<007oo
Ool00Woo00<007ooOol02Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004
Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`2iOol301nbOol301oVOol00`00Oomoo`1:
Ool40007Ool50004Ool40005Ool40005Ool50002Ool7000YOol7000GOol002=oo`03001oogoo009o
o`03001oogoo00Yoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<0
07ooOol017oo00<007ooOol037oo1000^goo0`0O[Goo0P0OjGoo00<007ooOol0Bgoo00<007ooOol0
1Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo0000
0goo00<007ooOol017oo00<007ooOol0:Woo1`005goo000SOol00`00Oomoo`02Ool00`00Oomoo`0:
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03
001oogoo00aoo`03001oogoo0;moo`<07jMoo`<07aioo`03O01oogoo0<Yoo`03001oogoo04]oo`03
001oogoo00Ioo`05001oogooOol00004Ool00`00Oomoo`05Ool00`00Oomoo`07Ool01@00Oomoogoo
00001Woo00<007ooOol0:Woo1`005goo000SOol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomo
o`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00ao
o`03001oogoo0<9oo`@07j1oo`<07b1oo`03O01oogoo0<]oo`03001oogoo04]oo`04001oogoo0006
Ool40004Ool60002Ool00`00Oomoo`08Ool40006Ool00`00Oomoo`0ZOol7000GOol002=oo`03001o
ogoo009oo`03001oogoo00Yoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo0000
17oo00<007ooOol017oo00<007ooOol037oo00<007ooOol0aWoo100OVWoo0P0O8Goo0W`0cWoo00<0
07ooOol0Bgoo10001Goo00D007ooOomoo`0000Aoo`03001oogoo009oo`05001oogooOol00003Ool2
0003Ool01@00Oomoogoo00001Woo00<007ooOol0:Woo1`005goo000SOol00`00Oomoo`02Ool00`00
Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo
009oo`<000ioo`03001oogoo0<Yoo`D07i9oo`<07b5oo`9l0=1oo`03001oogoo04]oo`06001oogoo
001oo`0017oo0`001Woo10001Goo0`0000=oo`00Ool00goo0`001goo00<007ooOol0:Woo1`005goo
000TOol4000>Ool40005Ool40005Ool40007Ool00`00Oomoo`0<Ool00`00Oomoo`3?Ool401n:Ool4
01ofOol00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomoo`0ZOol7000GOol0
069oo`03001oogoo0==oo`D07h5oo`@07oYoo`03001oogoo04Yoo`L002Uoo`03001oogoo02Yoo`L0
01Moo`00HWoo00<007ooOol0f7oo100ON7oo1@0O9goo00=l07ooOol0e7oo00<007ooOol0N7oo0`00
;7oo1`005goo001ROol00`00Oomoo`3LOol401m`Ool401lZOol2O03GOol00`00Oomoo`2WOol7000G
Ool0069oo`03001oogoo0>1oo`@07fMoo`D07baoo`9l0=Uoo`03001oogoo0:Moo`L001Moo`00HWoo
00<007ooOol0i7oo100OGWoo1@0O<7oo00=l07ooOol0fGoo00<007ooOol0Ygoo1`005goo001ROol0
0`00Oomoo`3XOol701mCOol401ooOolBOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0>mo
o`/07d5oo`L07c=oo`03O01oogoo0=moo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0nWoo
1`0O;Woo300O>7oo0W`0hWoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOol2OolF01l6
OolB01m2Ool2O03TOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?mooaQoo`H07e=oo`03
O01oogoo0>Aoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogooogooFGoo00<007ooOol0
Ygoo1`005goo001ROol00`00Oomoo`3oOoooOomIOol00`00Oomoo`2WOol7000GOol0069oo`03001o
ogoo0?moofaoo`03O01oogoo0>Uoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogooJWoo
0W`0k7oo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOomXOol2O03^Ool00`00Oomoo`2W
Ool7000GOol0069oo`03001oogoo0?moofIoo`9l0?1oo`03001oogoo0:Moo`L001Moo`00HWoo00<0
07ooOol0ogooogooFGoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOoooOomIOol00`00
Oomoo`2WOol7000GOol0069oo`03001oogoo0?moof5oo`03O01oogoo0?Aoo`03001oogoo0:Moo`L0
01Moo`00HWoo00<007ooOol0ogooGgoo0W`0mgoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomo
o`3oOomMOol2O03iOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?mooeaoo`03O01oogoo
0?Uoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogooogooFGoo00<007ooOol0Ygoo1`00
5goo001ROol00`00Oomoo`3oOoooOomIOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?mo
oeMoo`03O01oogoo0?ioo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogooEGoo0W`0ogoo
0Woo00<007ooOol0Ygoo00<007ooOol06goo001ROol00`00Oomoo`3oOomCOol2O03oOol4Ool00`00
Oomoo`2WOol00`00Oomoo`0KOol0069oo`03001oogoo0?mooe9oo`03O01oogoo0?moo`Aoo`03001o
ogoo0:Moo`03001oogoo01]oo`00HWoo00<007ooOol0ogooogooFGoo00<007ooOol0Ygoo00<007oo
Ool06goo001ROol00`00Oomoo`3oOoooOomIOol00`00Oomoo`2WOol00`00Oomoo`0KOol0069oo`<0
0?moodeoo`03O01oogoo0?moo`Uoo`03001oogoo0:Moo`03001oogoo01]oo`00HWoo00<007ooOol0
ogooBgoo0W`0ogoo37ooZ`007Goo001ROol00`00Oomoo`3oOom9Ool2O03oOooFOol0069oo`03001o
ogoo0?moodMoo`9l0?moomQoo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`3o
OoooOoooOolROol0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogoo@goo00=l
07ooOol0ogoofgoo001ROol00`00Oomoo`3oOom1Ool2O03oOooNOol0069oo`03001oogoo0?moocmo
o`9l0?moon1oo`00HWoo0`00ogoo?Woo00=l07ooOol0ogooh7oo001ROol00`00Oomoo`3oOoooOooo
OolROol0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001R
Ool00`00Oomoo`3oOoliOol00g`0Oomoo`3oOooUOol0069oo`<00?moocMoo`9l0?moonQoo`00HWoo
00<007ooOol0ogoo=Goo0W`0ogoojWoo001ROol00`00Oomoo`3oOoldOol00g`0Oomoo`3oOooZOol0
069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol3003o
OoooOoooOolROol0069oo`03001oogoo0?moobmoo`03O01oogoo0?moonmoo`00HWoo00<007ooOol0
ogoo;Goo0W`0ogoolWoo001ROol3003oOol[Ool2O03oOoodOol0069oo`03001oogoo0?moobYoo`03
O01oogoo0?moooAoo`00HWoo0`00ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolROol0
069oo`03001oogoo0?moobEoo`03O01oogoo0?moooUoo`00=Woo10001Woo0P001Woo100017oo1`00
2goo0`00ogoo97oo00=l07ooOol0ogoonWoo000eOol00`00Oomoo`02Ool00`00Oomoo`03Ool20005
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`3oOolSOol00g`0Oomo
o`3oOookOol003Eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Ao
o`03001oogoo00aoo`<00?moob9oo`03O01oogoo0?moooaoo`00=Goo00<007ooOol00Woo00<007oo
Ool02Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol037oo1000ogoo7goo0W`0ogooogoo
000eOol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomo
o`0<Ool00`00Oomoo`3oOoooOoooOolROol003Eoo`03001oogoo009oo`03001oogoo00Yoo`03001o
ogoo009oo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo0?mooomooomoob9oo`00=Goo00<0
07ooOol00Woo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol037oo00<0
07ooOol0ogoo6goo00=l07ooOol0ogooogoo17oo000eOol00`00Oomoo`02Ool00`00Oomoo`0:Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool3000>Ool00`00Oomoo`3oOolIOol2O03oOoooOol7Ool003Io
o`@000ioo`@000Moo`03001oogoo00aoo`03001oogoo0?mooaMoo`9l0?mooomoo`Uoo`00HWoo00<0
07ooOol0ogoo5Woo00=l07ooOol0ogooogoo2Goo001ROol00`00Oomoo`3oOoooOoooOolROol0069o
o`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogoo47oo00=l07ooOol0ogooogoo3goo
001ROol00`00Oomoo`3oOol>Ool2O03oOoooOolBOol0069oo`03001oogoo0?moo`aoo`9l0?mooomo
oaAoo`00HWoo00<007ooOol0ogoo2goo00=l07ooOol0ogooogoo57oo001ROol00`00Oomoo`3oOooo
OoooOolROol0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogoo1Goo0W`0ogoo
ogoo6goo001ROol00`00Oomoo`3oOol3Ool2O03oOoooOolMOol0069oo`03001oogoo0?moo`5oo`9l
0?mooomooamoo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolR
Ool0069oo`03001oogoo0?Uoo`9l0?mooomoobIoo`00HWoo00<007ooOol0mgoo0W`0ogooogoo:7oo
001ROol00`00Oomoo`3eOol2O03oOoooOolZOol0069oo`03001oogoo0?mooomooomoob9oo`00HWoo
00<007ooOol0kgoo00=l07ooOol0ogooogoo;goo001ROol00`00Oomoo`3]Ool2O03oOoooOolbOol0
069oo`03001oogoo0>]oo`9l0?mooomoocAoo`00HWoo00<007ooOol0jWoo00=l07ooOol0ogooogoo
=7oo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0>Aoo`03O01oogoo0?mooomo
ocYoo`00HWoo00<007ooOol0hWoo0W`0ogooogoo?Goo001ROol00`00Oomoo`3POol2O03oOoooOolo
Ool0069oo`03001oogoo0=moo`03O01oogoo0?mooomoocmoo`00HWoo00<007ooOol0ogooogooogoo
8Woo001ROol00`00Oomoo`3GOol3O03oOoooOom7Ool0069oo`03001oogoo0==oo`Al0?mooomoodYo
o`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol3003<Ool2O03oOoooOomCOol0069oo`03001o
ogoo0<Yoo`9l0?mooomooeEoo`00HWoo00<007ooOol0b7oo0W`0ogooogooEgoo001ROol00`00Oomo
o`3oOoooOoooOolROol0069oo`03001oogoo0<1oo`=l0?mooomooeioo`00HWoo00<007ooOol0_7oo
17`0ogooogooHGoo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0;Aoo`=l0?mo
oomoofYoo`00HWoo00<007ooOol0/Goo0g`0ogooogooKGoo001ROol3002ZOol2O03oOoooOomeOol0
069oo`03001oogoo0:Moo`=l0?mooomoogMoo`00HWoo00<007ooOol0YGoo0W`0ogooogooNWoo001R
Ool00`00Oomoo`2MOol3O03oOoooOon1Ool0069oo`03001oogoo09Uoo`Al0?mooomoohAoo`00HWoo
00<007ooOol0TGoo0g`0ogooogooSGoo001ROol3002=Ool4O03oOoooOon@Ool0069oo`03001oogoo
08Eoo`=l0?mooomooiUoo`00HWoo00<007ooOol0PGoo17`0ogooogooW7oo001ROol00`00Oomoo`0:
Ool3O01XOol7O03oOoooOonUOol0069oo`<000eoo`Al05]oo`El0?mooomook1oo`00HWoo00<007oo
Ool05Woo0g`0BGoo0g`01Goo0W`0ogooogoo]Goo001ROol00`00Oomoo`0IOol4O00iOol3O005Ool4
O03oOoooOonoOol0069oo`<0029oo`Ml01eoo`Ml00Eoo`Al0?mooomool]oo`00HWoo00<007ooOol0
;Woo1g`01Goo1g`0ogooogooh7oo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`<00?mooomo
oomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol3003oOoooOoooOolROol0069oo`03
001oogoo0?mooomooomoob9oo`00HWoo0`00ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOooo
OolROol0069oo`03001oogoo0?mooomooomoob9oo`00ogooogooogooQgoo003oOoooOoooOon7Ool0
0?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogoo
ogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOooo
Oon7Ool00?mooomooomoohMoo`00ogoo:goo10001Goo10000goo0`000Woo0`0017oo10000Woo1`00
0Woo0`000Woo0`000goo0`0000=oo`0000000goo10001Goo0`0000=oo`0000000Woo1@0037oo1`00
0Woo0`000Woo0`0017oo100017oo1@000Woo0P000Woo0`0017oo1000ogooagoo003oOolZOol00`00
Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo
009oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol00003Ool20003
Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo0P000goo00<007ooOol00Woo00<007ooOol037oo
00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000=o
o`03001oogoo009oo`04001oogoo0005Ool00`00Oomoo`02Ool00`00Oomoo`3oOoo4Ool00?moobUo
o`03001oogoo00Moo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomo
o`07Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Ao
o`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool01@00Oomoogoo000017oo00<007oo00001Woo00<0
07ooOol0ogoobGoo003oOolYOol00`00Oomoo`07Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo
00<007ooOol00Woo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol00Woo10003goo00<007oo
Ool017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Woo100017oo0`001Woo1P00ogoo
aWoo001WOol3002nOol00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoogoo0P000goo00<007oo
Ool00Woo00<007ooOol01goo00<007ooOol017oo0P000goo00D007ooOomoo`0000Aoo`05001oogoo
Ool00004Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00aoo`03001oogoo
00Aoo`8000=oo`03001oogoo009oo`03001oogoo00Eoo`05001oogooOol00004Ool01000Oomoo`00
1Goo00<007ooOol00Woo00<007ooOol0ogooa7oo001XOol00`00Oomoo`2mOol00`00Oomoo`03Ool0
0`00Oomoo`02Ool40003Ool2000017oo000000000goo1`000goo0`001Goo0P0000Aoo`00000000=o
o`8000=oo`8000Aoo`@000=oo`8000=oo`8000Aoo`D000aoo`<000Eoo`800004Ool000000003Ool7
0004Ool30005Ool00`00Ool000020005Ool4003oOoo7Ool006Qoo`03001oogoo0;ioo`04001oogoo
Ool2000FOol00`00Oomoo`1GOol00`00Oomoo`0>Ool00`00Oomoo`3oOooBOol005Yoo`H000Aoo`<0
0003Ool007oo0<1oo`<00003Ool007oo01Eoo`03001oogoo05Moo`03001oogoo00ioo`03001oogoo
0?moom9oo`00Fgoo00<007ooOol00Woo00@007ooOol000=oo`800>Ioo`03001oogoo03aoo`03001o
ogoo01ioo`800?moomAoo`00Fgoo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo0>Aoo`03
001oogoo03aoo`03001oogoo0?moooAoo`00Fgoo00<007ooOol00Woo00@007ooOol000Aoo`03001o
ogoo0?mooomooomooaaoo`00Fgoo1@000goo00@007ooOomoo`800?mooomooomooaioo`00Fgoo00<0
07ooOol00Woo00@007ooOomoo`<00003Ool000000?mooomooomooaeoo`00Fgoo00<007ooOol00Woo
00<007ooOol0ogooogooogoo97oo001JOol6003oOoooOoooOolWOol00?mooomooomoohMoo`00ogoo
ogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOooo
Oon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMo
o`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003o
OoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomo
oomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogoo
Qgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool0
0001\
\>"],
  ImageRangeCache->{{{0, 899}, {440.375, 0}} -> {-1.06477, -0.648943, \
0.00442081, 0.00442081}, {{21.9375, 700.563}, {429.875, 10.4375}} -> \
{-0.483369, -11.4079, 0.00650107, 0.0443545}, {{700.563, 870.188}, {321.938, \
152.313}} -> {-14.9684, -2.19473, 0.0318352, 0.0265294}, {{714.688, 761.813}, \
{304.938, 248.375}} -> {-15.9492, -11.8048, 0.0334221, 0.108156}, {{714.688, \
761.813}, {225.813, 169.25}} -> {-15.9492, -17.51, 0.0334221, 0.108156}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[29]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs2, 180, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Injection\>", 
      IntakeType \[Rule] \ "\<MultiInputs\>", \ 
      ShowReport \[Rule] \ "\<GraphicReport\>"]\)], "Input",
  CellLabel->"In[30]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.567479 0.0581105 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .10259 -46.5 -6.6875 ]
[-0.0125 .10259 0 6.6875 ]
[-0.0125 .21882 -46.5 -6.6875 ]
[-0.0125 .21882 0 6.6875 ]
[-0.0125 .33504 -40 -6.28125 ]
[-0.0125 .33504 0 6.28125 ]
[-0.0125 .45126 -28 -6.28125 ]
[-0.0125 .45126 0 6.28125 ]
[-0.0125 .56748 -10 -6.28125 ]
[-0.0125 .56748 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10259 m
.00625 .10259 L
s
gsave
-0.0125 .10259 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .21882 m
.00625 .21882 L
s
gsave
-0.0125 .21882 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .33504 m
.00625 .33504 L
s
gsave
-0.0125 .33504 -101 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0001) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .45126 m
.00625 .45126 L
s
gsave
-0.0125 .45126 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .56748 m
.00625 .56748 L
s
gsave
-0.0125 .56748 -71 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .04908 m
.00375 .04908 L
s
0 .0655 m
.00375 .0655 L
s
0 .07537 m
.00375 .07537 L
s
0 .08244 m
.00375 .08244 L
s
0 .08796 m
.00375 .08796 L
s
0 .09249 m
.00375 .09249 L
s
0 .09632 m
.00375 .09632 L
s
0 .09965 m
.00375 .09965 L
s
0 .16531 m
.00375 .16531 L
s
0 .18172 m
.00375 .18172 L
s
0 .19159 m
.00375 .19159 L
s
0 .19866 m
.00375 .19866 L
s
0 .20418 m
.00375 .20418 L
s
0 .20871 m
.00375 .20871 L
s
0 .21254 m
.00375 .21254 L
s
0 .21587 m
.00375 .21587 L
s
0 .28153 m
.00375 .28153 L
s
0 .29795 m
.00375 .29795 L
s
0 .30781 m
.00375 .30781 L
s
0 .31488 m
.00375 .31488 L
s
0 .3204 m
.00375 .3204 L
s
0 .32493 m
.00375 .32493 L
s
0 .32877 m
.00375 .32877 L
s
0 .3321 m
.00375 .3321 L
s
0 .39775 m
.00375 .39775 L
s
0 .41417 m
.00375 .41417 L
s
0 .42403 m
.00375 .42403 L
s
0 .43111 m
.00375 .43111 L
s
0 .43662 m
.00375 .43662 L
s
0 .44115 m
.00375 .44115 L
s
0 .44499 m
.00375 .44499 L
s
0 .44832 m
.00375 .44832 L
s
0 .51397 m
.00375 .51397 L
s
0 .53039 m
.00375 .53039 L
s
0 .54025 m
.00375 .54025 L
s
0 .54733 m
.00375 .54733 L
s
0 .55285 m
.00375 .55285 L
s
0 .55737 m
.00375 .55737 L
s
0 .56121 m
.00375 .56121 L
s
0 .56454 m
.00375 .56454 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Multi) show
99.000 12.813 moveto
(Inputs) show
135.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .60332 m
.20509 .48957 L
.23623 .4564 L
.2498 .44218 L
.26149 .43129 L
.2715 .42377 L
.28154 .41836 L
.29109 .41516 L
.30107 .41345 L
.31022 .41288 L
.31516 .41282 L
.31957 .41286 L
.32783 .41311 L
.33536 .41344 L
.36608 .41494 L
.37752 .4154 L
.38897 .41578 L
.39525 .41595 L
.40077 .41608 L
.40617 .41618 L
.41107 .41626 L
.41625 .41631 L
.41893 .41633 L
.42177 .41635 L
.42469 .41636 L
.42742 .41636 L
.42984 .41636 L
.43243 .41635 L
.43704 .41632 L
.43933 .4163 L
.44182 .41627 L
.44613 .41621 L
.4501 .41614 L
.4594 .41591 L
.46754 .41564 L
.48465 .41486 L
.49747 .41407 L
.51055 .41306 L
.53436 .41067 L
.55504 .40796 L
.57199 .40525 L
.60516 .39852 L
.65547 .38404 L
.69357 .36893 L
.72693 .35212 L
.75417 .33551 L
.77703 .31929 L
.7986 .30184 L
.8172 .28494 L
.83511 .26689 L
Mistroke
.85084 .24945 L
.86481 .23265 L
.87858 .21475 L
.89093 .1975 L
.9032 .17916 L
.9143 .16148 L
.92438 .14446 L
.93452 .12636 L
.94378 .10893 L
.95227 .09217 L
.9609 .07432 L
.96883 .05714 L
.97619 .04053 L
Mfstroke
0 0 1 r
[ ] 0 setdash
.02381 .34049 m
.20509 .36283 L
.30107 .3776 L
.33536 .38162 L
.36608 .38445 L
.37932 .38541 L
.39101 .38614 L
.41107 .3871 L
.42093 .38743 L
.42637 .38757 L
.4312 .38767 L
.43616 .38775 L
.43884 .38778 L
.44135 .38781 L
.44572 .38784 L
.44815 .38784 L
.45038 .38784 L
.4546 .38783 L
.45849 .3878 L
.46191 .38776 L
.46554 .3877 L
.47345 .38753 L
.48043 .38731 L
.49442 .38671 L
.50863 .38585 L
.52239 .38476 L
.53436 .3836 L
.55537 .38105 L
.57328 .37832 L
.60275 .37258 L
.6518 .35907 L
.69268 .34326 L
.72495 .32725 L
.75139 .31141 L
.77591 .29425 L
.79676 .27755 L
.8166 .25966 L
.83388 .24235 L
.84908 .22565 L
.86399 .20783 L
.87729 .19066 L
.89043 .1724 L
.90226 .15479 L
.91297 .13784 L
.92371 .1198 L
.93349 .10243 L
.94242 .08573 L
.95148 .06794 L
.9598 .05082 L
.96824 .03262 L
Mistroke
.97603 .01509 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[30]:=",
  ImageSize->{600, 294.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000>40001^A000`40O003h00OogooogooogooQgoo
003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mo
oomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogoo
ogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7
Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00
ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOooo
OoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomo
ohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool006aoo`L003ioo`H005Moo`@003aoo`L000=o
o`@003Moo`H000Aoo`@004moo`@000Eoo`@003=oo`L000=oo`@000Eoo`@002ioo`H000Aoo`@000Eo
o`@00?Qoo`00Kgoo00<007ooOol0?goo00<007ooOol00Woo00<007ooOol0E7oo00<007ooOol00Woo
00<007ooOol0?7oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0=7oo00<007ooOol00Woo
00D007ooOomoo`0000Aoo`03001oogoo04]oo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`0cOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0:goo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`3eOol006mo
o`03001oogoo041oo`03001oogoo05eoo`03001oogoo03aoo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo03Eoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo051oo`05001oogooOol0
0004Ool00`00Oomoo`0cOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<0
07ooOol0;7oo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo0?Eo
o`00Kgoo00<007ooOol0@Goo00<007ooOol0G7oo00<007ooOol0?7oo00<007ooOol00goo00<007oo
Ool00Woo00<007ooOol0=Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0D7oo00D007oo
Oomoo`0000Aoo`03001oogoo03=oo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0]Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool0mGoo001_Ool00`00Oomoo`12Ool00`00Oomoo`1KOol00`00Oomoo`0lOol00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`0gOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`1@Ool0
1@00Oomoogoo000017oo00<007ooOol0<goo00<007ooOol00goo00<007ooOol00Woo00D007ooOomo
o`0000Aoo`03001oogoo02ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool0
0`00Oomoo`3eOol006moo`03001oogoo04=oo`03001oogoo05Ioo`@003moo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo03Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo04aoo`@0
00Aoo`03001oogoo009oo`03001oogoo03=oo`03001oogoo00=oo`03001oogoo009oo`05001oogoo
Ool00004Ool00`00Oomoo`0_Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo
00<007ooOol0mGoo001_Ool00`00Oomoo`0oOol00`00Oomoo`02Ool00`00Oomoo`1EOol00`00Oomo
o`10Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0dOol00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00<007ooOol0C7oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0<goo00<0
07ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo02]oo`03001oogoo009o
o`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol0mGoo001]Ool30011Ool00`00
Oomoo`02Ool00`00Oomoo`1EOol00`00Oomoo`0nOol30005Ool00`00Oomoo`02Ool00`00Oomoo`0d
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0C7oo00<007ooOol01Goo00<007oo
Ool00Woo00<007ooOol0<Goo0`001Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo
02]oo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol0mGoo
001_Ool00`00Oomoo`10Ool4001HOol5000nOol00`00Oomoo`04Ool4000hOol40005Ool4001?Ool5
0004Ool4000fOol00`00Oomoo`04Ool40005Ool4000_Ool40005Ool40005Ool4003hOol00?mooomo
oomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooZgoo
0`00f7oo003oOoooOon]Ool00`00Oomoo`3FOol00?mooomoojeoo`03001oogoo0=Ioo`00ogooogoo
VGoo0`0000=oo`00000017oo1@001Goo0P001Goo1@00cGoo003oOoooOonHOol01000Oomoogoo0P00
17oo00D007ooOomoo`0000Ioo`8000Eoo`03001oogoo009oo`03001oogoo0<Yoo`00ogooogooV7oo
00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Eoo`04001oogoo0009Ool00`00Oomo
o`3:Ool0069oool00?l002D0015oo`03001oogoo009oo`03001oogoo00=oo`@000Eoo`04001oogoo
0005Ool4003=Ool0069oo`03001oogoo00Yoo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo
01Yoo`03001oogoo01=oo`03001oogoo011oo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo
00Uoo`03001oogoo00Qoo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo01Yoo`03001oogoo
01=oo`03001oogoo00moo`03001oogoo00eoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo
00Moo`03001oogoo04=oo`03001oogoo015oo`04001oogooOol20004Ool01@00Oomoogoo000017oo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo0<Yoo`00HWoo00<007ooOol02Woo00<0
07ooOol0@Woo00<007ooOol09Woo00<007ooOol06Woo00<007ooOol04goo00<007ooOol047oo00<0
07ooOol037oo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0@Woo00<0
07ooOol09Woo00<007ooOol06Woo00<007ooOol04goo00<007ooOol03goo00<007ooOol03Goo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol01goo00<007ooOol0@goo00<007ooOol04Woo0`00
00=oo`00Ool017oo0`0017oo0`000Woo0`000goo1@00c7oo001ROol00`00Oomoo`0:Ool00`00Oomo
o`12Ool00`00Oomoo`1IOol00`00Oomoo`13Ool00`00Oomoo`12Ool00`00Oomoo`1IOol00`00Oomo
o`12Ool00`00Oomoo`13Ool00`00Oomoo`0FOol00`00Oomoo`3VOol0069oo`03001oogoo00Yoo`03
001oogoo049oo`03001oogoo05Uoo`03001oogoo04=oo`03001oogoo049oo`03001oogoo05Uoo`03
001oogoo049oo`03001oogoo04=oo`03001oogoo01Ioo`03001oogoo0>Ioo`00HWoo00<007ooOol0
ogooogoo=goo0P00j7oo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mooomo
oomoob9oo`00HWoo00<007ooOol0ogooogoo57oo00<07gooOol0ogoo2goo001ROol00`00Oomoo`3o
OoooOolDOol00`0OOomoo`3oOol;Ool0069oo`03001oogoo0?mooomooa=oo`0301moogoo0?moo`ao
o`00HWoo00<007ooOol0ogooogoo4goo00<07gooOol0ogoo37oo001ROol00`00Oomoo`3oOoooOolB
Ool00`0OOomoo`3oOol=Ool0069oo`03001oogoo0?mooomooa9oo`0301moogoo0?moo`eoo`00HWoo
00<007ooOol0ogooogoo4Woo00<07gooOol0ogoo3Goo001ROol00`00Oomoo`3oOoooOolAOol00`0O
Oomoo`3oOol>Ool0069oo`03001oogoo0?mooomooa5oo`0301moogoo0?moo`ioo`00HWoo00<007oo
Ool0ogooogoo47oo00<07gooOol0ogoo3goo001ROol00`00Oomoo`3oOoooOol@Ool00`0OOomoo`3o
Ool?Ool0069oo`03001oogoo0?mooomoo`moo`0301moogoo0?mooa1oo`00HWoo00<007ooOol0ogoo
ogoo3goo00<07gooOol0ogoo47oo001ROol00`00Oomoo`3oOoooOol>Ool00`0OOomoo`3oOolAOol0
069oo`03001oogoo0?mooomoo`ioo`0301moogoo0?mooa5oo`00HWoo00<007ooOol0ogooogoo3Goo
00<07gooOol0ogoo4Woo001ROol00`00Oomoo`3oOoooOol=Ool00`0OOomoo`3oOolBOol0069oo`03
001oogoo0?mooomoo`aoo`0301moogoo0?mooa=oo`00HWoo00<007ooOol0ogooogoo37oo00<07goo
Ool017oo00=l07ooOol0ogoo37oo001ROol3003oOoooOol;Ool00`0OOomoo`04Ool00g`0Oomoo`3o
Ool=Ool0069oo`03001oogoo0?mooomoo`]oo`0301moogoo00Aoo`03O01oogoo0?moo`eoo`00HWoo
00<007ooOol0ogooogoo2goo00<07gooOol00goo00=l07ooOol0ogoo3Woo001ROol00`00Oomoo`3o
OoooOol:Ool00`0OOomoo`04Ool00g`0Oomoo`3oOol>Ool0069oo`03001oogoo0?mooomoo`Yoo`03
01moogoo00=oo`03O01oogoo0?moo`moo`00HWoo00<007ooOol0ogooogoo2Goo00<07gooOol0ogoo
5Woo001ROol00`00Oomoo`3oOoooOol9Ool00`0OOomoo`3oOolFOol0069oo`03001oogoo0?mooomo
o`Qoo`0301moogoo0?mooaMoo`00HWoo00<007ooOol0ogooogoo27oo00<07gooOol0ogoo5goo001R
Ool3003oOoooOol7Ool00`0OOomoo`3oOolHOol0069oo`03001oogoo0?mooomoo`Moo`0301moogoo
00Aoo`03O01oogoo0?mooa5oo`00HWoo00<007ooOol0ogooogoo1Woo00<07gooOol017oo00=l07oo
Ool0ogoo4Woo001ROol00`00Oomoo`3oOoooOol6Ool00`0OOomoo`04Ool00g`0Oomoo`3oOolBOol0
069oo`03001oogoo0?mooomoo`Eoo`0301moogoo00Aoo`03O01oogoo0?mooa=oo`00HWoo0`00ogoo
ogoo1Goo00<07gooOol017oo00=l07ooOol0ogoo4goo001ROol00`00Oomoo`3oOoooOol4Ool00`0O
Oomoo`04Ool00g`0Oomoo`3oOolDOol0069oo`03001oogoo0?mooomoo`Aoo`0301moogoo0?mooa]o
o`00HWoo00<007ooOol0ogooogoo0goo00<07gooOol0ogoo77oo001ROol3003oOoooOol3Ool00`0O
Oomoo`3oOolLOol0069oo`03001oogoo0?mooomoo`9oo`0301moogoo0?mooaeoo`00HWoo00<007oo
Ool0ogooogoo0Woo00<07gooOol017oo00=l07ooOol0ogoo5Woo001ROol3003oOoooOol1Ool00`0O
Oomoo`04Ool00g`0Oomoo`3oOolGOol0069oo`03001oogoo0?mooomoo`5oo`0301moogoo00Aoo`03
O01oogoo0?mooaMoo`00HWoo00<007ooOol0ogooogoo00<07gooOol017oo00=l07ooOol0ogoo67oo
001ROol3003oOoooOol00`0OOomoo`04Ool00g`0Oomoo`3oOolHOol0069oo`03001oogoo0?moooio
o`0301moogoo00Aoo`03O01oogoo0?mooaUoo`006Woo1`0017oo0P001goo00<007ooOol00goo00<0
07ooOol00goo1`000goo10006Woo0`00ogoooWoo00<07gooOol017oo00=l07ooOol0ogoo6Goo000M
Ool00`00Oomoo`05Ool20008Ool01@00Oomoogoo00002Goo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol05goo00<007ooOol0ogoooGoo00<07gooOol0ogoo8Goo000MOol00`00Oomoo`0@Ool0
0`00Ool0000:Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0GOol3003oOoomOol00`0O
Oomoo`3oOolQOol001eoo`03001oogoo015oo`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo01Moo`@00?mooo]oo`0301moogoo0?moob9oo`007Goo00<007ooOol047oo00<0
07oo00002Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol05goo00<007ooOol0ogoongoo
00<07gooOol0ogoo8goo000MOol00`00Oomoo`0?Ool01@00Oomoogoo00002Goo00<007ooOol00goo
00<007ooOol00Woo00<007ooOol05goo00<007ooOol0ogoongoo00<07gooOol017oo00=l07ooOol0
ogoo77oo000MOol00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`08Ool3000<Ool00`00Oomoo`3oOoojOol00`0OOomoo`05Ool00g`0
Oomoo`3oOolLOol001]oo`<001eoo`<000Eoo`03001oogoo009oo`03001oogoo00Moo`05001oogoo
Ool0000;Ool00`00Oomoo`3oOoojOol00`0OOomoo`05Ool00g`0Oomoo`3oOolLOol001eoo`03001o
ogoo01eoo`03001oogoo00Aoo`@000Aoo`D00003Ool007oo009oo`03001oogoo00Uoo`03001oogoo
0?moooUoo`0301moogoo00Eoo`03O01oogoo0?mooaeoo`00Dgoo0`0037oo00<007ooOol0ogoonGoo
00<07gooOol01Goo00=l07ooOol0ogoo7Goo001BOol01@00Oomoogoo00002goo00<007ooOol0ogoo
n7oo00<07gooOol01Goo00=l07ooOol0ogoo7Woo001BOol01@00Oomoogoo00002goo00<007ooOol0
ogoon7oo00<07gooOol0ogoo9Woo001COol3000<Ool00`00Oomoo`3oOoogOol00`0OOomoo`1UOonZ
000GOol0069oo`03001oogoo0?moooMoo`0301moogoo06EoojX001Moo`00HWoo00<007ooOol0ogoo
mWoo00<07gooOol0IWooZP005goo001ROol00`00Oomoo`3oOoofOol00`0OOomoo`1VOonZ000GOol0
069oo`03001oogoo0?moooEoo`0301moogoo00Eoo`03O01oogoo05moojX001Moo`00HWoo00<007oo
Ool0ogoom7oo00<07gooOol01Goo00=l07ooOol0H7ooZP005goo001ROol00`00Oomoo`3oOoodOol0
0`0OOomoo`05Ool00g`0Oomoo`1IOona000GOol0069oo`03001oogoo0?mooo=oo`0301moogoo00Eo
o`03O01oogoo05Yoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoolWoo00<07gooOol0
1Woo00=l07ooOol0FWoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOoobOol00`0OOomo
o`05Ool00g`0Oomoo`1KOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?mooo5oo`0301mo
ogoo06Aoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogool7oo00<07gooOol0IGoo00<0
07ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOoo`Ool00`0OOomoo`1UOol00`00Oomoo`2WOol7
000GOol0069oo`03001oogoo0?moonmoo`0301moogoo06Ioo`03001oogoo0:Moo`L001Moo`00HWoo
00<007ooOol0ogookgoo00<07gooOol01Goo00=l07ooOol0GWoo00<007ooOol0Ygoo1`005goo001R
Ool00`00Oomoo`3oOoo^Ool00`0OOomoo`05Ool00g`0Oomoo`1OOol00`00Oomoo`2WOol7000GOol0
069oo`03001oogoo0?mooneoo`0301moogoo00Ioo`03O01oogoo05moo`03001oogoo0:Moo`L001Mo
o`00HWoo00<007ooOol0ogookGoo00<07gooOol01Goo00=l07ooOol0H7oo00<007ooOol0Ygoo1`00
5goo001ROol00`00Oomoo`3oOoo/Ool00`0OOomoo`06Ool00g`0Oomoo`1POol00`00Oomoo`2WOol7
000GOol0069oo`03001oogoo0?moonaoo`0301moogoo00Eoo`03O01oogoo065oo`03001oogoo0:Mo
o`L001Moo`00HWoo00<007ooOol0ogoojgoo00<07gooOol0JWoo00<007ooOol0Ygoo1`005goo001R
Ool00`00Oomoo`3oOooZOol00`0OOomoo`1[Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo
0?moonYoo`0301moogoo06]oo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoojGoo00<0
7gooOol0K7oo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOooXOol00`0OOomoo`1]Ool0
0`00Oomoo`2WOol7000GOol0069oo`<00?moonQoo`0301moogoo00Ioo`03O01oogoo06Aoo`03001o
ogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogooigoo00<07gooOol01Woo00=l07ooOol0IGoo00<0
07ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOooVOol00`0OOomoo`07Ool00g`0Oomoo`1UOol0
0`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?moonIoo`0301moogoo00Ioo`03O01oogoo06Io
o`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogooiGoo00<07gooOol01goo00=l07ooOol0
IWoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOooTOol00`0OOomoo`07Ool00g`0Oomo
o`1WOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?moon=oo`0301moogoo079oo`03001o
ogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoohgoo00<07gooOol0LWoo00<007ooOol0Ygoo1`00
5goo001ROol00`00Oomoo`3oOooROol00`0OOomoo`1cOol00`00Oomoo`2WOol7000GOol0069oo`<0
0?moon5oo`0301moogoo07Aoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogooh7oo00<0
7gooOol01goo00=l07ooOol0Jgoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOooOOol0
0`0OOomoo`07Ool00g`0Oomoo`1/Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?moommo
o`0301moogoo00Moo`03O01oogoo06aoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoo
gWoo00<07gooOol01goo00=l07ooOol0KGoo00<007ooOol0BWoo1`000Woo0`000Woo0`000goo1000
17oo1@001Goo10001Woo10000Woo1`0017oo10000goo0`000Woo0`003Goo1`005goo001ROol00`00
Oomoo`3oOooMOol00`0OOomoo`08Ool00g`0Oomoo`1]Ool00`00Oomoo`1;Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Goo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00aoo`L001Moo`00HWoo0`00ogoog7oo
00<07gooOol027oo00=l07ooOol0KWoo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol00goo
0P0017oo00<007ooOol027oo00<007ooOol01Goo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00aoo`L001Moo`00HWoo00<0
07ooOol0ogoog7oo00<07gooOol0NGoo00<007ooOol0Bgoo00@007ooOol000Moo`8000Aoo`03001o
ogoo00Qoo`03001oogoo00Eoo`H000Aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009o
o`05001oogooOol00004Ool00`00Oomoo`0<Ool7000GOol0069oo`03001oogoo0?moom]oo`0301mo
ogoo07Yoo`03001oogoo04]oo`@000Ioo`04001oogoo0004Ool01000Oomoogoo0P0017oo0P001Woo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo
00@007ooOomoo`8000=oo`03001oogoo00aoo`L001Moo`00HWoo00<007ooOol0ogoofWoo00<07goo
Ool0Ngoo00<007ooOol0Bgoo00H007ooOol007oo0002Ool30002Ool30003Ool300000goo001oo`02
Ool2000017oo0000000017oo10000goo1`000goo0`001goo10000goo0P0000Aoo`00000000moo`L0
01Moo`00HWoo0`00ogoofGoo00<07gooOol0O7oo00<007ooOol0Bgoo00<007ooOol00Woo00<007oo
Ool09Woo00<007ooOol0:goo1`005goo001ROol00`00Oomoo`3oOooIOol00`0OOomoo`08Ool00g`0
Oomoo`1aOol00`00Oomoo`1:Ool7000XOol00`00Oomoo`0[Ool7000GOol0069oo`03001oogoo0?mo
omQoo`0301moogoo00Qoo`03O01oogoo079oo`03001oogoo08=oo`03001oogoo025oo`L001Moo`00
HWoo0`00ogooegoo00<07gooOol027oo00=l07ooOol0Lgoo00<007ooOol0Pgoo00<007ooOol08Goo
1`005goo001ROol00`00Oomoo`3oOooGOol00`0OOomoo`07Ool00g`0Oomoo`1dOol00`00Oomoo`2W
Ool7000GOol0069oo`<00?moomIoo`0301moogoo00Moo`03O01oogoo07Eoo`03001oogoo0:Moo`L0
01Moo`00HWoo00<007ooOol0ogooeGoo00<07gooOol0P7oo00<007ooOol0Ygoo1`005goo000JOol7
0004Ool20007Ool00`00Oomoo`03Ool00`00Oomoo`03Ool70003Ool4000JOol3003oOooDOol00`0O
Oomoo`21Ool00`00Oomoo`0<Ool7O005Ool7O005Ool7O005Ool7O01`Ool7000GOol001eoo`03001o
ogoo00Eoo`8000Qoo`05001oogooOol00009Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`0GOol00`00Oomoo`3oOooCOol00`0OOomoo`22Ool00`00Oomoo`2WOol7000GOol001eoo`03001o
ogoo011oo`03001oo`0000Yoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo01Moo`<00?mo
om9oo`0301moogoo08=oo`03001oogoo0:Moo`L001Moo`007Goo00<007ooOol04Goo00<007ooOol0
2Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol05goo00<007ooOol0ogoodWoo00<07goo
Ool027oo00=l07ooOol0N7oo00<007ooOol0Ygoo1`005goo000MOol00`00Oomoo`0@Ool00`00Ool0
000:Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0GOol4003oOoo@Ool00`0OOomoo`08
Ool00g`0Oomoo`1iOol00`00Oomoo`2WOol7000GOol001eoo`03001oogoo00moo`05001oogooOol0
0009Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0GOol00`00Oomoo`3oOoo@Ool00`0O
Oomoo`08Ool00g`0Oomoo`1jOol00`00Oomoo`2WOol7000GOol001eoo`03001oogoo00ioo`03001o
ogoo00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo01Moo`03001o
ogoo0?moolmoo`0301moogoo00Uoo`03O01oogoo07Yoo`03001oogoo0:Moo`L001Moo`006goo0`00
7Goo0`001Goo00<007ooOol00Woo00<007ooOol027oo0`0037oo00<007ooOol0ogoocWoo00<07goo
Ool02Goo00=l07ooOol0Ngoo00<007ooOol0C7oo100017oo1@000goo1`000Woo0`000Woo0`000goo
1000<goo1`005goo000MOol00`00Oomoo`0MOol00`00Oomoo`04Ool4000:Ool01@00Oomoogoo0000
2goo00<007ooOol0ogoocGoo00<07gooOol02Goo00=l07ooOol0O7oo00<007ooOol0Bgoo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`03001oogoo031oo`L001Moo`00C7oo1@0000=oo`00Ool00Woo00<007ooOol02Goo
00<007ooOol0ogooc7oo00<07gooOol0RGoo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0003Moo`L001Mo
o`00DWoo100037oo00<007ooOol0ogooc7oo00<07gooOol0RGoo00<007ooOol0Bgoo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00@007ooOomo
o`H0039oo`L001Moo`00DWoo00<007ooOol03Goo00<007ooOol0ogoobgoo00<07gooOol0RWoo00<0
07ooOol0Bgoo00<007ooOol00Woo00<007ooOol00Woo0P0027oo00<007ooOol017oo0P000goo00D0
07ooOomoo`0000Aoo`03001oogoo031oo`L001Moo`00Dgoo00<007ooOol037oo00<007ooOol0ogoo
bWoo00<07gooOol0Rgoo00<007ooOol0Bgoo00<007ooOol00Woo00@007ooOomoo`800004Ool00000
0003Ool30005Ool2000017oo000000001Goo1000<goo1`005goo001DOol3000;Ool00`00Oomoo`3o
Ooo9Ool00`0OOomoo`09Ool00g`0Oomoo`20Ool00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomo
o`1DOol7000GOol0069oo`03001oogoo0?moolQoo`0301moogoo00Uoo`03O01oogoo085oo`03001o
ogoo04Yoo`<0009oo`<005Eoo`L001Moo`00HWoo00<007ooOol0ogoob7oo00<07gooOol027oo00=l
07ooOol0PWoo00<007ooOol0Ggoo00<007ooOol0AGoo1`005goo001ROol00`00Oomoo`3oOoo7Ool0
0`0OOomoo`08Ool00g`0Oomoo`23Ool00`00Oomoo`1OOol00`00Oomoo`15Ool7000GOol0069oo`03
001oogoo0?moolIoo`0301moogoo00Qoo`03O01oogoo08Aoo`03001oogoo0:Moo`L001Moo`00HWoo
00<007ooOol0ogooaGoo00<07gooOol0T7oo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3o
Ooo4Ool00`0OOomoo`2AOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?mool=oo`0301mo
ogoo099oo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoo`Woo00<07gooOol0Tgoo00<0
07ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOoo0Ool201l<Ool00g`0Oomoo`27Ool00`00Oomo
o`2WOol7000GOol0069oo`03001oogoo0?mookmoo`0301moogoo00]oo`03O01oogoo08Qoo`03001o
ogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoo_Woo00<07gooOol02Woo0W`0Rgoo00<007ooOol0
Ygoo1`005goo001ROol00`00Oomoo`3oOonmOol00`0OOomoo`0:Ool00g`0Oomoo`2;Ool00`00Oomo
o`2WOol7000GOol0069oo`03001oogoo0?mookaoo`0301moogoo00Yoo`03O01oogoo08aoo`03001o
ogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoo^goo00<07gooOol0VWoo00<007ooOol0Ygoo1`00
5goo001ROol00`00Oomoo`3oOonjOol00`0OOomoo`2KOol00`00Oomoo`2WOol7000GOol0069oo`03
001oogoo0?mookUoo`0301moogoo09aoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoo
^7oo00<07gooOol02goo00=l07ooOol0Sgoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3o
OonfOol201l=Ool00g`0Oomoo`2@Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?mookEo
o`0301moogoo00eoo`03O01oogoo091oo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoo
]7oo00<07gooOol0XGoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOoncOol00`0OOomo
o`2ROol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?mook9oo`0301moogoo0:=oo`03001o
ogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoo/Goo00<07gooOol037oo00=l07ooOol0UGoo00<0
07ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOon`Ool00`0OOomoo`0<Ool00g`0Oomoo`2FOol0
0`00Oomoo`2WOol7000GOol0069oo`<00?moojioo`807`ioo`03O01oogoo09Moo`03001oogoo0:Mo
o`L001Moo`00HWoo00<007ooOol0ogoo[Goo00<07gooOol03Woo00=l07ooOol0Ugoo00<007ooOol0
Ygoo1`005goo001ROol00`00Oomoo`3oOon/Ool00`0OOomoo`0=Ool2O02JOol00`00Oomoo`2WOol7
000GOol0069oo`03001oogoo0?mooj]oo`0301moogoo0:Yoo`03001oogoo0:Moo`L001Moo`00HWoo
00<007ooOol0ogooZWoo00<07gooOol0Zgoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3o
OonXOol201n^Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?moojMoo`0301moogoo00io
o`03O01oogoo09eoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogooYWoo00<07gooOol0
3Woo00=l07ooOol0WWoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOonTOol201l?Ool2
O02QOol00`00Oomoo`2WOol7000GOol0069oo`<00?mooj=oo`0301moogoo00ioo`03O01oogoo0:5o
o`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogooXGoo0P0O47oo00=l07ooOol0XWoo00<0
07ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOonPOol00`0OOomoo`2eOol00`00Oomoo`2WOol7
000GOol0069oo`03001oogoo0?mooimoo`0301moogoo0;Ioo`03001oogoo0:Moo`L001Moo`00HWoo
00<007ooOol0ogooWGoo0P0O^Goo00<007ooOol0Ygoo1`005goo001ROol3003oOonLOol00`0OOomo
o`0@Ool00g`0Oomoo`2VOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?mooiYoo`807a9o
o`03O01oogoo0:Moo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogooVGoo00<07gooOol0
47oo0W`0ZWoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOonGOol201lBOol00g`0Oomo
o`2ZOol00`00Oomoo`2WOol7000GOol0069oo`<00?mooiEoo`807a=oo`03O01oogoo0:]oo`03001o
ogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogooU7oo00<07gooOol0`Goo00<007ooOol0Ygoo1`00
5goo001ROol00`00Oomoo`3oOonBOol201o4Ool00`00Oomoo`2WOol7000GOol0069oo`<00?mooi1o
o`807lIoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogooSgoo00<07gooOol04goo00=l
07ooOol0/7oo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOon=Ool201lDOol2O02cOol0
0`00Oomoo`2WOol7000GOol0069oo`<00?mooh]oo`807aAoo`9l0;Eoo`03001oogoo0:Moo`L001Mo
o`00HWoo00<007ooOol0ogooRWoo00<07gooOol04goo00=l07ooOol0]Goo00<007ooOol0Ygoo1`00
5goo000TOol40006Ool20006Ool40005Ool40005Ool40004Ool7000;Ool3003oOon8Ool201o>Ool0
0`00Oomoo`2WOol7000GOol002=oo`03001oogoo009oo`03001oogoo00=oo`8000Eoo`03001oogoo
009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol037oo
00<007ooOol0ogooQWoo0P0Od7oo00<007ooOol0Ygoo1`005goo000SOol00`00Oomoo`02Ool00`00
Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo
00Aoo`03001oogoo00aoo`<00?moohAoo`807aEoo`03O01oogoo0;Yoo`03001oogoo04Yoo`L0009o
o`<0009oo`<000=oo`@000Aoo`D000Eoo`@000Ioo`@0009oo`L000Aoo`@000=oo`<0009oo`<000eo
o`L001Moo`008goo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool4003oOon1Ool201lFOol0
0g`0Oomoo`2kOol00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`03001oogoo00aoo`L001Moo`008goo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol0
0Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool0
0`00Oomoo`3oOon0Ool201lGOol00g`0Oomoo`2lOol00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool20004Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol037oo1`005goo
000SOol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D0
07ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo0?moogioo`807aMoo`9l
0;moo`03001oogoo04]oo`04001oogoo0007Ool20004Ool00`00Oomoo`08Ool00`00Oomoo`05Ool6
0004Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<0
07ooOol037oo1`005goo000SOol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01@00
Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo
00Yoo`D07omoofeoo`807aQoo`03O01oogoo0;moo`03001oogoo04]oo`@000Ioo`04001oogoo0004
Ool01000Oomoogoo0P0017oo0P001Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol017oo00<007ooOol00Woo00@007ooOomoo`8000=oo`03001oogoo00aoo`L001Moo`00
8goo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001o
ogooOol00004Ool00`00Oomoo`02Ool3000>Ool00`00Oomoo`0?Ool801ooOomSOol201oLOol00`00
Oomoo`1;Ool01P00Oomoo`00Ool0009oo`<0009oo`<000=oo`<00003Ool007oo009oo`800004Ool0
00000004Ool40003Ool70003Ool30007Ool40003Ool2000017oo000000003goo1`005goo000TOol4
000>Ool40005Ool40005Ool40007Ool00`00Oomoo`0<Ool00`00Oomoo`0GOol801ooOomHOol301oN
Ool00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`0VOol00`00Oomoo`0[Ool7000GOol0069o
o`03001oogoo01moo`P07omoodeoo`<07aYoo`03O01oogoo0<Aoo`03001oogoo04Yoo`L002Qoo`03
001oogoo02]oo`L001Moo`00HWoo00<007ooOol09goo2@0Oogoo@Woo0P0O6goo0W`0agoo00<007oo
Ool0Pgoo00<007ooOol08Goo1`005goo001ROol00`00Oomoo`0`Ool801ooOolgOol301lKOol2O039
Ool00`00Oomoo`23Ool00`00Oomoo`0QOol7000GOol0069oo`03001oogoo03Qoo`P07omoobaoo`<0
7aeoo`03O01oogoo0<Uoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0@7oo200Oogoo8Goo
0`0Ok7oo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`18Ool901ooOolFOol201o_Ool00`00
Oomoo`2WOol7000GOol0069oo`03001oogoo055oo`P07omoo`]oo`<07amoo`9l0=1oo`03001oogoo
00aoobh07feoo`L001Moo`00HWoo00<007ooOol0FGoo200Oogoo0`0O7goo0g`0dWoo00<007ooOol0
Ygoo1`005goo001ROol00`00Oomoo`1QOol801ocOol401lPOol2O03EOol00`00Oomoo`2WOol7000G
Ool0069oo`03001oogoo06Uoo`P07nQoo`<07o]oo`03001oogoo0:Moo`L001Moo`00HWoo00<007oo
Ool0LGoo1P0Oggoo0`0OoWoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`1gOol701oDOol4
01lUOol00g`0Oomoo`3IOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo07ioo`L07lYoo`<0
7bMoo`9l0=aoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0QGoo1P0O`Goo0`0O:Goo00=l
07ooOol0g7oo00<007ooOol0BWoo10001goo1@0017oo10001Goo10001Goo1@000Woo1`00:Goo1`00
5goo001ROol00`00Oomoo`2;Ool701nfOol401lZOol2O03OOol00`00Oomoo`1;Ool00`00Oomoo`06
Ool01@00Oomoogoo000017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00003
Ool00`00Oomoo`04Ool00`00Oomoo`0ZOol7000GOol0069oo`03001oogoo099oo`L07j]oo`@07omo
oa1oo`03001oogoo04]oo`03001oogoo00Ioo`05001oogooOol00004Ool00`00Oomoo`05Ool00`00
Oomoo`07Ool01@00Oomoogoo00001Woo00<007ooOol0:Woo1`005goo001ROol00`00Oomoo`2IOol6
01nPOol501l[Ool2O03VOol00`00Oomoo`1;Ool01000Oomoo`001Woo100017oo1P000Woo00<007oo
Ool027oo10001Woo00<007ooOol0:Woo1`005goo001ROol00`00Oomoo`2OOol601nDOol601l]Ool3
O03XOol00`00Oomoo`1;Ool40005Ool01@00Oomoogoo000017oo00<007ooOol00Woo00D007ooOomo
o`0000=oo`8000=oo`05001oogooOol00006Ool00`00Oomoo`0ZOol7000GOol0069oo`03001oogoo
0:Eoo`H07hMoo`L07c5oo`9l0>]oo`03001oogoo04]oo`06001oogoo001oo`0017oo0`001Woo1000
1Goo0`0000=oo`00Ool00goo0`001goo00<007ooOol0:Woo1`005goo001ROol00`00Oomoo`2[Ool6
01miOol801ooOolVOol00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomoo`0Z
Ool7000GOol0069oo`03001oogoo0;5oo``07fMoo`H07c]oo`03O01oogoo0>moo`03001oogoo04Yo
o`L002Uoo`03001oogoo02Yoo`L001Moo`00HWoo00<007ooOol0_Goo300OCWoo3@0O?Woo0g`0lWoo
00<007ooOol0N7oo0`00;7oo1`005goo001ROol00`00Oomoo`39Ool@01l_Ool?01m8Ool3O03eOol0
0`00Oomoo`2WOol7000GOol0069oo`03001oogoo0=Uoobl07omooe1oo`03001oogoo0:Moo`L001Mo
o`00HWoo00<007ooOol0ogooF7oo0g`0oGoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3o
OomEOol3O03oOol1Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?mooomooeUoo`03001o
ogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogooCWoo0W`0ogoo2Goo00<007ooOol0Ygoo1`005goo
001ROol3003oOom;Ool3O03oOol;Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?moodUo
o`9l0?moo`ioo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoo@Goo0g`0ogoo5Goo00<0
07ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOolmOol4O03oOolHOol00`00Oomoo`2WOol7000G
Ool0069oo`03001oogoo0?moocQoo`03O01oogoo0?mooaioo`03001oogoo0:Moo`L001Moo`00HWoo
00<007ooOol0ogoo<Woo1W`0ogoo8Goo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOolZ
Ool3O03oOol/Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?moobIoo`Al0?moobmoo`03
001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoo6Woo1g`0ogoo>7oo00<007ooOol0Ygoo1`00
5goo001ROol3002QOol7O005Ool7O005Ool3O01AOol7O03oOom4Ool00`00Oomoo`2WOol7000GOol0
069oo`03001oogoo09]oo`03O01oogoo01ioo`Al00Eoo`Ml00Eoo`Ml01eoo`Ml00Eoo`Ml0?mooe1o
o`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0VGoo0W`0@Woo1g`01Goo1g`0ogooJ7oo00<0
07ooOol0Ygoo1`005goo001ROol00`00Oomoo`2EOol4O03oOonoOol00`00Oomoo`2WOol7000GOol0
069oo`03001oogoo0?mooomooeUoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogooogoo
FGoo00<007ooOol0Ygoo1`005goo001ROol3002@Ool00g`0Oomoo`3oOoo5Ool00`00Oomoo`2WOol7
000GOol0069oo`03001oogoo08moo`03O01oogoo0?moolIoo`03001oogoo0:Moo`L001Moo`00HWoo
00<007ooOol0SWoo00=l07ooOol0ogooagoo00<007ooOol0Ygoo00<007ooOol06goo001ROol00`00
Oomoo`2=Ool00g`0Oomoo`3oOoo8Ool00`00Oomoo`2WOol00`00Oomoo`0KOol0069oo`<008aoo`03
O01oogoo0?moolUoo`03001oogoo0:Moo`03001oogoo01]oo`00HWoo00<007ooOol0ogooogooFGoo
00<007ooOol0Ygoo00<007ooOol06goo001ROol00`00Oomoo`3oOoooOomIOol00`00Oomoo`2WOol0
0`00Oomoo`0KOol0069oo`<00?mooomooeUoo`03001oogoo0:Moo`03001oogoo01]oo`00HWoo00<0
07ooOol0Qgoo00=l07ooOol0ogoocWooZ`007Goo001ROol30026Ool00g`0Oomoo`3oOoooOonHOol0
069oo`03001oogoo08Ioo`03O01oogoo0?mooomooiQoo`00HWoo0`00Q7oo0W`0ogooogooVgoo000f
Ool40006Ool20006Ool40004Ool7000;Ool00`00Oomoo`23Ool00g`0Oomoo`3oOoooOonKOol003Eo
o`03001oogoo009oo`03001oogoo00=oo`8000Eoo`03001oogoo009oo`03001oogoo00Aoo`03001o
ogoo00aoo`<00?mooomooomoob9oo`00=Goo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol0
0Woo00<007ooOol017oo00<007ooOol037oo00<007ooOol0ogooogooogoo8Woo000eOol00`00Oomo
o`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool4003oOooo
OoooOolQOol003Eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Ao
o`03001oogoo00aoo`03001oogoo0?mooomooomoob9oo`00=Goo00<007ooOol00Woo00<007ooOol0
2Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol037oo00<007ooOol0OWoo0W`0ogooogoo
XGoo000eOol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00
Oomoo`0<Ool00`00Oomoo`1mOol00g`0Oomoo`3oOoooOonQOol003Eoo`03001oogoo009oo`03001o
ogoo00Yoo`03001oogoo009oo`03001oogoo009oo`<000ioo`03001oogoo07aoo`03O01oogoo0?mo
oomooj9oo`00=Woo10003Woo10001goo00<007ooOol037oo00<007ooOol0O7oo00=l07ooOol0ogoo
ogooXWoo001ROol00`00Oomoo`1kOol00g`0Oomoo`3oOoooOonSOol0069oo`03001oogoo0?mooomo
oomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolROol0
069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0Mgoo00=l07ooOol0ogooogooYgoo
001ROol00`00Oomoo`1fOol00g`0Oomoo`3oOoooOonXOol0069oo`03001oogoo07Aoo`9l0?mooomo
oj]oo`00HWoo00<007ooOol0Lgoo00=l07ooOol0ogooogooZgoo001ROol00`00Oomoo`1bOol00g`0
Oomoo`3oOoooOon/Ool0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogooogoo
ogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo06ioo`03O01oogoo0?mo
oomook1oo`00HWoo00<007ooOol0KGoo00=l07ooOol0ogooogoo/Goo001ROol00`00Oomoo`1]Ool0
0g`0Oomoo`3oOoooOonaOol0069oo`03001oogoo06]oo`9l0?mooomookAoo`00HWoo00<007ooOol0
JWoo00=l07ooOol0ogooogoo]7oo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo
0?mooomooomoob9oo`00HWoo00<007ooOol0I7oo00=l07ooOol0ogooogoo^Woo001ROol00`00Oomo
o`1ROol2O03oOoooOonmOol0069oo`03001oogoo061oo`9l0?mooomookmoo`00HWoo00<007ooOol0
Ggoo00=l07ooOol0ogooogoo_goo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo
0?mooomooomoob9oo`00HWoo00<007ooOol0FWoo00=l07ooOol0ogooogooa7oo001ROol00`00Oomo
o`1IOol00g`0Oomoo`3oOoooOoo5Ool0069oo`<005Moo`9l0?mooomoolQoo`00HWoo00<007ooOol0
EWoo00=l07ooOol0ogooogoob7oo001ROol00`00Oomoo`1EOol00g`0Oomoo`3oOoooOoo9Ool0069o
o`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomo
o`1@Ool00g`0Oomoo`3oOoooOoo>Ool0069oo`03001oogoo04ioo`9l0?mooomoom5oo`00HWoo00<0
07ooOol0C7oo0W`0ogooogoodgoo001ROol00`00Oomoo`1;Ool00g`0Oomoo`3oOoooOooCOol0069o
o`<00?mooomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`16Ool0
0g`0Oomoo`3oOoooOooHOol0069oo`03001oogoo04Aoo`9l0?mooomoom]oo`00HWoo00<007ooOol0
@Woo0W`0ogooogoogGoo001ROol30011Ool00g`0Oomoo`3oOoooOooMOol0069oo`03001oogoo0?mo
oomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolR
Ool0069oo`<003aoo`03O01oogoo0?mooomoon9oo`00HWoo00<007ooOol0>Woo0W`0ogooogooiGoo
001ROol00`00Oomoo`0hOol2O03oOoooOooWOol0069oo`<003Moo`03O01oogoo0?mooomoonMoo`00
HWoo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`<0039o
o`03O01oogoo0?mooomoonaoo`00HWoo00<007ooOol0<7oo0W`0ogooogookgoo001@Ool7000;Ool3
000^Ool2O03oOoooOooaOol005=oo`03001oogoo00aoo`03001oogoo02eoo`03O01oogoo0?mooomo
oo5oo`00Dgoo00<007ooOol037oo0`00ogooogooogoo8Woo001COol00`00Oomoo`0<Ool4003oOooo
OoooOolQOol005=oo`03001oogoo00aoo`03001oogoo02Moo`03O01oogoo0?mooomoooMoo`00Dgoo
00<007ooOol037oo00<007ooOol09Goo0W`0ogooogoonWoo001COol00`00Oomoo`0<Ool00`00Oomo
o`0SOol2O03oOoooOoolOol0055oo`<000ioo`03001oogoo029oo`03O01oogoo0?mooomoooaoo`00
Dgoo00<007ooOol037oo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolR
Ool0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol07Goo00=l07ooOol0ogooogoo
ogoo0Woo001ROol00`00Oomoo`0KOol2O03oOoooOoooOol5Ool0069oo`03001oogoo01Uoo`9l0?mo
oomooomoo`Moo`00HWoo00<007ooOol067oo00=l07ooOol0ogooogooogoo1goo001ROol00`00Oomo
o`3oOoooOoooOolROol0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol04goo00=l
07ooOol0ogooogooogoo37oo001ROol00`00Oomoo`0AOol2O03oOoooOoooOol?Ool0069oo`03001o
ogoo00moo`9l0?mooomooomooa5oo`00HWoo00<007ooOol03Woo00=l07ooOol0ogooogooogoo4Goo
001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<0
07ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mo
oomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolR
Ool0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol0
0`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mooomooomoob9oo`00ogooogooogooQgoo
003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mo
oomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooQgoo
0`00ogooo7oo003oOon8Ool00`00Oomoo`3oOookOol00?moohQoo`03001oogoo0?mooo]oo`00ogoo
?Woo0`000goo0`000goo0`0000Aoo`00001oo`L000Eoo`@0009oo`L000]oo`L0009oo`<0009oo`<0
009oo`03001oo`00008000Eoo`<00003Ool0000000Aoo`@000=oo`D00?moomioo`00ogoo?goo00<0
07ooOol00goo00D007ooOomoo`0000=oo`8000Eoo`03001oogoo00Eoo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo00moo`03001oogoo00Aoo`03001oogoo009oo`04001oogooOol20003Ool0
1@00Oomoogoo00000goo0P0017oo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo0?moom]o
o`00ogoo?goo00@007ooOol0009oo`05001oogooOol00004Ool00`00Oomoo`03Ool00`00Oomoo`05
Ool00`00Oomoo`07Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo
000017oo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo0?moom]o
o`00ogoo?goo00L007oo001oo`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`05Ool00`00Oomoo`07Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo00Ioo`@00?moomioo`00
Igoo0`00e7oo00L007oo001oo`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`05Ool00`00Oomoo`07Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool20003Ool01000Oomoogoo0P00
0goo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009oo`03001o
ogoo0?moom]oo`00J7oo00<007ooOol0dgoo00L007oo001oo`00Ool00002Ool20003Ool20005Ool0
0`00Oomoo`03Ool70003Ool3000AOol00`00Oomoo`03Ool2000017oo000000000goo0P0000Aoo`00
000000=oo`8000=oo`80009oo`L000Aoo`D00?moomeoo`00J7oo00<007ooOol0dgoo0P000goo0P00
3Woo00<007ooOol01Goo00<007ooOol06Goo00<007ooOol087oo00<007ooOol0ogooj7oo001JOol6
0004Ool300000goo001oo`3COol30003Ool3000=Ool00`00Oomoo`05Ool00`00Oomoo`0FOol7000O
Ool00`00Oomoo`3oOooXOol005]oo`03001oogoo009oo`04001oogoo0003Ool2003XOol3000AOol0
0`00Oomoo`3oOoooOolNOol005]oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`3jOol0
0`00Oomoo`3oOoooOolNOol005]oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`3oOooo
OoooOolLOol005]oo`D000=oo`04001oogooOol2003oOoooOoooOolNOol005]oo`03001oogoo009o
o`04001oogooOol300000goo0000003oOoooOoooOolMOol005]oo`03001oogoo009oo`03001oogoo
0?mooomooomoobAoo`00FWoo1P00ogooogooogoo9goo003oOoooOoooOon7Ool00?mooomooomoohMo
o`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003o
OoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomo
oomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogoo
Qgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool0
0?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogoo
ogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo0000\
\>"],
  ImageRangeCache->{{{0, 899}, {440.375, 0}} -> {-1.06477, -0.648943, \
0.00442081, 0.00442081}, {{21.9375, 700.563}, {429.875, 10.4375}} -> \
{-0.483369, -11.2762, 0.00650107, 0.0472435}, {{700.563, 870.188}, {321.938, \
152.313}} -> {-14.9684, -2.19473, 0.0318352, 0.0265294}, {{714.688, 761.813}, \
{304.938, 248.375}} -> {-15.9492, -11.8048, 0.0334221, 0.108156}, {{714.688, \
761.813}, {225.813, 169.25}} -> {-15.9492, -17.51, 0.0334221, 0.108156}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[30]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Injection\",ShowReport\[Rule] \"CompartmentContent\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, t1, Log[2]/8.0, 
        IntakeWay \[Rule] \ "\<Injection\>", 
        IntakeType \[Rule] \ "\<Acute\>", 
        ShowReport \[Rule] \ "\<CompartmentContent\>"] // 
      TableForm\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(qB[t1] \[Rule] 
              1.000032423868219`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\
\ t1\) - 0.0008408891554192175`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\
\ t1\) + 0.0008084652872002794`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\
\ t1\)\)},
          {\(q\_2[
                t1] \[Rule] \(-0.30059375214527606`\)\ \
\[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) + 
                0.013560666527655115`\ \
\[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) + 
                0.2870330856176209`\ \
\[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\)\)},
          {\(q\_3[t1] \[Rule] 
              0.000960268779722304`\ \
\[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) - 
                0.04932247783689646`\ \
\[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) + 
                0.04836220905717415`\ \
\[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\)\)},
          {\(q\_4[
                t1] \[Rule] \(-0.2101841291828041`\)\ \
\[ExponentialE]\^\(\(-12.086643397569993`\)\ t1\) + 
                0.2101899867443482`\ \
\[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) - 
                0.000136628393537977`\ \
\[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) + 
                0.0001307708319938742`\ \
\[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\)\)},
          {\(qURI[t1] \[Rule] 
              0.2101841291828041`\ \
\[ExponentialE]\^\(\(-12.086643397569993`\)\ t1\) - 
                0.9105849231740755`\ \
\[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) + 
                0.027265619900402115`\ \
\[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) - 
                0.24804241375338593`\ \
\[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\) + 
                0.9211775878442552`\ \
\[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\)\)},
          {\(qULI[
                t1] \[Rule] \(-0.000011434651217512147`\)\ \
\[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) + 
                0.000027439995588919004`\ \
\[ExponentialE]\^\(\(-1.8866433975699932`\)\ t1\) - 
                0.00032742407622542434`\ \
\[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) + 
                0.00031141873185401743`\ \
\[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\)\)},
          {\(qLLI[t1] \[Rule] 
              0.000011628750326288566`\ \
\[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) - 
                0.00006173999007506776`\ \
\[ExponentialE]\^\(\(-1.8866433975699932`\)\ t1\) + 
                0.00011305901804593418`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) - 
                0.0006270704396056829`\ \
\[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) + 
                0.0005641226613085279`\ \
\[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\)\)},
          {\(qFEC[
                t1] \[Rule] \(-4.1981720468259125`*^-6\)\ \[ExponentialE]\^\(\
\(-2.8565990345907886`\)\ t1\) + 
                0.00003429999448614876`\ \
\[ExponentialE]\^\(\(-1.8866433975699932`\)\ t1\) - 
                0.00011305901804593418`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) + 
                0.010428203473627553`\ \
\[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) - 
                0.08916765843376664`\ \
\[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\) + 
                0.0788224121557457`\ \
\[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {qB[ t1] -> Plus[ 
          Times[ 1.000032423868219, 
            Power[ E, 
              Times[ -2.8565990345907886, t1]]], 
          Times[ -.00084088915541921747, 
            Power[ E, 
              Times[ -.14677556138819206, t1]]], 
          Times[ .00080846528720027937, 
            Power[ E, 
              Times[ -.09296993648799734, t1]]]], Subscript[ q, 2][ t1] -> 
        Plus[ 
          Times[ -.30059375214527606, 
            Power[ E, 
              Times[ -2.8565990345907886, t1]]], 
          Times[ .013560666527655115, 
            Power[ E, 
              Times[ -.14677556138819206, t1]]], 
          Times[ .28703308561762092, 
            Power[ E, 
              Times[ -.09296993648799734, t1]]]], Subscript[ q, 3][ t1] -> 
        Plus[ 
          Times[ .00096026877972230399, 
            Power[ E, 
              Times[ -2.8565990345907886, t1]]], 
          Times[ -.049322477836896458, 
            Power[ E, 
              Times[ -.14677556138819206, t1]]], 
          Times[ .048362209057174151, 
            Power[ E, 
              Times[ -.09296993648799734, t1]]]], Subscript[ q, 4][ t1] -> 
        Plus[ 
          Times[ -.2101841291828041, 
            Power[ E, 
              Times[ -12.086643397569993, t1]]], 
          Times[ .21018998674434819, 
            Power[ E, 
              Times[ -2.8565990345907886, t1]]], 
          Times[ -.00013662839353797699, 
            Power[ E, 
              Times[ -.14677556138819206, t1]]], 
          Times[ .00013077083199387421, 
            Power[ E, 
              Times[ -.09296993648799734, t1]]]], qURI[ t1] -> Plus[ 
          Times[ .2101841291828041, 
            Power[ E, 
              Times[ -12.086643397569993, t1]]], 
          Times[ -.91058492317407547, 
            Power[ E, 
              Times[ -2.8565990345907886, t1]]], 
          Times[ .027265619900402115, 
            Power[ E, 
              Times[ -.14677556138819206, t1]]], 
          Times[ -.24804241375338593, 
            Power[ E, 
              Times[ -.09296993648799734, t1]]], 
          Times[ .92117758784425519, 
            Power[ E, 
              Times[ -.086643397569993161, t1]]]], qULI[ t1] -> Plus[ 
          Times[ -.000011434651217512147, 
            Power[ E, 
              Times[ -2.8565990345907886, t1]]], 
          Times[ .000027439995588919004, 
            Power[ E, 
              Times[ -1.8866433975699932, t1]]], 
          Times[ -.00032742407622542434, 
            Power[ E, 
              Times[ -.14677556138819206, t1]]], 
          Times[ .00031141873185401743, 
            Power[ E, 
              Times[ -.09296993648799734, t1]]]], qLLI[ t1] -> Plus[ 
          Times[ .000011628750326288566, 
            Power[ E, 
              Times[ -2.8565990345907886, t1]]], 
          Times[ -.000061739990075067761, 
            Power[ E, 
              Times[ -1.8866433975699932, t1]]], 
          Times[ .00011305901804593418, 
            Power[ E, 
              Times[ -1.0866433975699932, t1]]], 
          Times[ -.00062707043960568288, 
            Power[ E, 
              Times[ -.14677556138819206, t1]]], 
          Times[ .00056412266130852792, 
            Power[ E, 
              Times[ -.09296993648799734, t1]]]], qFEC[ t1] -> Plus[ 
          Times[ -.41981720468259125*^-5, 
            Power[ E, 
              Times[ -2.8565990345907886, t1]]], 
          Times[ .000034299994486148757, 
            Power[ E, 
              Times[ -1.8866433975699932, t1]]], 
          Times[ -.00011305901804593418, 
            Power[ E, 
              Times[ -1.0866433975699932, t1]]], 
          Times[ .010428203473627553, 
            Power[ E, 
              Times[ -.14677556138819206, t1]]], 
          Times[ -.089167658433766644, 
            Power[ E, 
              Times[ -.09296993648799734, t1]]], 
          Times[ .078822412155745702, 
            Power[ E, 
              Times[ -.086643397569993161, t1]]]]}]]], "Output",
  CellLabel->"Out[31]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, t1, Log[2]\/8.0, 
      IntakeWay \[Rule] "\<Injection\>", IntakeType \[Rule] "\<Constant\>", 
      ShowReport \[Rule] "\<CompartmentContent\>"]\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \({qB[t1] \[Rule] \(\(0.3530448861723202`\)\(\[InvisibleSpace]\)\) - 
          0.3500779814593317`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ \
t1\) + 0.005729081513748965`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ \
t1\) - 0.008695986226737439`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ \
t1\), q\_2[t1] \[Rule] \(\(3.074537951915434`\)\(\[InvisibleSpace]\)\) + 
          0.1052278420966198`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ \
t1\) - 0.09239049334507302`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\
\) - 3.087375300666981`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\), 
      q\_3[t1] \[Rule] \(\(0.18448794653696848`\)\(\[InvisibleSpace]\)\) - 
          0.0003361580565190745`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\
\ t1\) + 0.33604012391714416`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ \
t1\) - 0.5201919123975935`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ \
t1\), q\_4[t1] \[Rule] \(\(0.05666644217467365`\)\(\[InvisibleSpace]\)\) + 
          0.017389784927803978`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t1\) - 0.07358050051797282`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ \
t1\) + 0.0009308660940946577`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ \
t1\) - 0.0014065926785994639`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ \
t1\), qURI[t1] \[Rule] \(\(7.848229930581397`\)\(\[InvisibleSpace]\)\) - 
          0.017389784927803978`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t1\) + 0.3187653962448804`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) \
- 0.18576403075911252`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) + 
          2.667985190948354`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ \
t1\) - 10.631826702087714`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ \
t1\), qULI[t1] \[Rule] \(\(0.001129432189064724`\)\(\[InvisibleSpace]\)\) + 
          4.0028898277458725`*^-6\ \
\[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) - 
          0.000014544346655155853`\ \[ExponentialE]\^\(\(-1.8866433975699932`\
\)\ t1\) + 
          0.0022307806090378565`\ \
\[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) - 
          0.0033496713412751703`\ \
\[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\), 
      qLLI[t1] \[Rule] \(\(0.0018708786570302179`\)\(\[InvisibleSpace]\)\) - 
          4.070837448824665`*^-6\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\
\ t1\) + 0.000032724779974100674`\ \
\[ExponentialE]\^\(\(-1.8866433975699932`\)\ t1\) - 
          0.00010404426907554259`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) + 
          0.004272308234932972`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\
\ t1\) - 0.006067796565412923`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ \
t1\), qFEC[t1] \[Rule] \(\(0.021592858884819988`\)\(\[InvisibleSpace]\)\) + 
          1.4696399445599148`*^-6\ \
\[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) - 
          0.000018180433318944818`\ \[ExponentialE]\^\(\(-1.8866433975699932`\
\)\ t1\) + 
          0.00010404426907554259`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) - 
          0.07104863626477323`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ \
t1\) + 0.9591020689282542`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ \
t1\) - 0.9097336250240021`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ \
t1\), qWB[t1] \[Rule] \(\(3.6717375376454906`\)\(\[InvisibleSpace]\)\) + 
          0.017389784927803978`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t1\) - 0.31876686588482495`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ \
t1\) + 0.000018180433318944818`\ \[ExponentialE]\^\(\(-1.8866433975699932`\)\ \
t1\) - 0.00010404426907554259`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ \
t1\) + 0.25681266702388567`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\
\) - 3.627087259876599`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ \
t1\)}\)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs1, t, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Injection\>", 
      IntakeType \[Rule] \ "\<Continuous\>", 
      ShowReport \[Rule] \ "\<CompartmentContent\>"]\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \({qB[
          t] \[Rule] \(-0.469388782677821`\)\ \
\[ExponentialE]\^\(\(-2.8565990345907886`\)\ t\) + 
          0.47128825656429735`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.006585548595544335`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\
\ t\) + 0.004686074709067989`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ \
t\), q\_2[t] \[Rule] 
        0.14109076069179818`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ \
t\) - 1.9110114268132006`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) + 
          0.10620237855407033`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ \
t\) + 1.6637182875673322`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ t\), 
      q\_3[t] \[Rule] \(-0.00045072477931652137`\)\ \
\[ExponentialE]\^\(\(-2.8565990345907886`\)\ t\) + 
          0.106407131977998`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.3862763273306888`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ \
t\) + 0.2803199201320073`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ t\), 
      q\_4[t] \[Rule] 
        0.02139887892691861`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t\) - 0.09865762314722522`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ t\) \
+ 0.07757078812813108`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.0010700256025146736`\ \
\[ExponentialE]\^\(\(-0.14677556138819206`\)\ t\) + 
          0.0007579816946902074`\ \
\[ExponentialE]\^\(\(-0.09296993648799734`\)\ t\), 
      qURI[t] \[Rule] \(-0.02139887892691861`\)\ \
\[ExponentialE]\^\(\(-12.086643397569993`\)\ t\) + 
          0.42740449050658`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ t\) \
- 4.36288095580705`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) + 
          0.21353476101403795`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ \
t\) - 1.437718230168087`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ t\) + 
          5.181058813381437`\ \[ExponentialE]\^\(\(-0.08664339756999317`\)\ t\
\), qULI[t] \[Rule] 
        5.367122992444869`*^-6\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ \
t\) - 0.00002075324219489604`\ \[ExponentialE]\^\(\(-1.8866433975699932`\)\ t\
\) + 0.0007745926880785834`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.0025642703933537563`\ \
\[ExponentialE]\^\(\(-0.14677556138819206`\)\ t\) + 
          0.001805063824477624`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\
\ t\), qLLI[
          t] \[Rule] \(-5.458227982856079`*^-6\)\ \
\[ExponentialE]\^\(\(-2.8565990345907886`\)\ t\) + 
          0.0000466947949385161`\ \[ExponentialE]\^\(\(-1.8866433975699932`\)\
\ t\) - 0.00017246801037702658`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ \
t\) + 0.0017724255270538817`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.00491099549356633`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ \
t\) + 0.003269801409933815`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ \
t\), qFEC[t] \[Rule] 
        1.970510974943496`*^-6\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ \
t\) - 0.000025941552743620058`\ \[ExponentialE]\^\(\(-1.8866433975699932`\)\ \
t\) + 0.00017246801037702658`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ t\
\) - 0.00830733854432908`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) + 
          0.08167002784755975`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ \
t\) - 0.5168388991694268`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ t\) \
+ 0.44332771289758777`\ \[ExponentialE]\^\(\(-0.08664339756999317`\)\ t\), 
      qWB[t] \[Rule] 
        0.02139887892691861`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t\) - 0.427406461017555`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ t\) + 
          0.000025941552743620058`\ \[ExponentialE]\^\(\(-1.8866433975699932`\
\)\ t\) - 
          0.00017246801037702658`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t\) - 
          1.2531982319276416`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.2952047888615976`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ \
t\) + 1.9545571293375088`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ t\)}\
\)], "Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs2, t, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Injection\>", 
      IntakeType \[Rule] \ "\<MultiInputs\>", 
      ShowReport \[Rule] \ "\<CompartmentContent\>"]\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \("Option not available for MultiInputs intake"\)], "Output",
  CellLabel->"Out[34]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Injection\",ShowReport\[Rule] \"Disintegrations\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, t1, Log[2]/8.0, 
        IntakeWay \[Rule] \ "\<Injection\>", 
        IntakeType \[Rule] \ "\<Acute\>", 
        ShowReport \[Rule] \ "\<Disintegrations\>"] // TableForm\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(qB[t1] \[Rule] \(\(30503.07816528847`\)\(\[InvisibleSpace]\)\) - 
                30246.737598086263`\ \
\[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) + 
                494.9926427879106`\ \
\[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) - 
                751.3332099901148`\ \
\[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\)\)},
          {\(q\_2[
                t1] \[Rule] \(\(265640.0790454935`\)\(\[InvisibleSpace]\)\) + 
                9091.68555714795`\ \
\[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) - 
                7982.538625014308`\ \
\[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) - 
                266749.22597762715`\ \
\[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\)\)},
          {\(q\_3[
                t1] \[Rule] \(\(15939.758580794074`\)\(\[InvisibleSpace]\)\) \
- 29.044056083248037`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) + 
                29033.86670644126`\ \
\[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) - 
                44944.581231152086`\ \
\[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\)\)},
          {\(q\_4[
                t1] \[Rule] \(\(4895.980603891803`\)\(\[InvisibleSpace]\)\) + 
                1502.4774177622637`\ \
\[ExponentialE]\^\(\(-12.086643397569993`\)\ t1\) - 
                6357.355244752852`\ \[ExponentialE]\^\(\(-2.8565990345907886`\
\)\ t1\) + 
                80.42683052977843`\ \
\[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) - 
                121.52960743099368`\ \
\[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\)\)},
          {\(qURI[
                t1] \[Rule] \(\(678087.0660022327`\)\(\[InvisibleSpace]\)\) - 
                1502.4774177622637`\ \
\[ExponentialE]\^\(\(-12.086643397569993`\)\ t1\) + 
                27541.330235557667`\ \
\[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) - 
                16050.012257587321`\ \
\[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) + 
                230513.9204979378`\ \
\[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\) - 
                918589.8270603786`\ \
\[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\)\)},
          {\(qULI[
                t1] \[Rule] \(\(97.58294113519213`\)\(\[InvisibleSpace]\)\) + 
                0.3458496811172434`\ \
\[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) - 
                1.2566315510054658`\ \
\[ExponentialE]\^\(\(-1.8866433975699932`\)\ t1\) + 
                192.73944462087078`\ \
\[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) - 
                289.4116038861747`\ \
\[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\)\)},
          {\(qLLI[
                t1] \[Rule] \(\(161.6439159674108`\)\(\[InvisibleSpace]\)\) - 
                0.35172035557845105`\ \
\[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) + 
                2.827420989762298`\ \[ExponentialE]\^\(\(-1.8866433975699932`\
\)\ t1\) - 
                8.98942484812688`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) + 
                369.1274314982088`\ \
\[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) - 
                524.2576232516766`\ \
\[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\)\)},
          {\(qFEC[
                t1] \[Rule] \(\(1865.6230076484353`\)\(\[InvisibleSpace]\)\) \
+ 0.12697689120997666`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) - 
                1.5707894387568322`\ \
\[ExponentialE]\^\(\(-1.8866433975699932`\)\ t1\) + 
                8.98942484812688`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) - 
                6138.6021732764075`\ \
\[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) + 
                82866.41875540117`\ \
\[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\) - 
                78600.98520207379`\ \
\[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\)\)},
          {\(qWB[
                t1] \[Rule] \(\(317238.12325257045`\)\(\[InvisibleSpace]\)\) \
+ 1502.4774177622637`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t1\) - 
                27541.457212448873`\ \
\[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) + 
                1.5707894387568322`\ \
\[ExponentialE]\^\(\(-1.8866433975699932`\)\ t1\) - 
                8.98942484812688`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) + 
                22188.614430863716`\ \
\[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) - 
                313380.33925333817`\ \
\[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {qB[ t1] -> Plus[ 30503.078165288469, 
          Times[ -30246.737598086263, 
            Power[ E, 
              Times[ -2.8565990345907886, t1]]], 
          Times[ 494.9926427879106, 
            Power[ E, 
              Times[ -.14677556138819206, t1]]], 
          Times[ -751.33320999011482, 
            Power[ E, 
              Times[ -.09296993648799734, t1]]]], Subscript[ q, 2][ t1] -> 
        Plus[ 265640.0790454935, 
          Times[ 9091.68555714795, 
            Power[ E, 
              Times[ -2.8565990345907886, t1]]], 
          Times[ -7982.5386250143083, 
            Power[ E, 
              Times[ -.14677556138819206, t1]]], 
          Times[ -266749.22597762715, 
            Power[ E, 
              Times[ -.09296993648799734, t1]]]], Subscript[ q, 3][ t1] -> 
        Plus[ 15939.758580794074, 
          Times[ -29.044056083248037, 
            Power[ E, 
              Times[ -2.8565990345907886, t1]]], 
          Times[ 29033.866706441258, 
            Power[ E, 
              Times[ -.14677556138819206, t1]]], 
          Times[ -44944.581231152086, 
            Power[ E, 
              Times[ -.09296993648799734, t1]]]], Subscript[ q, 4][ t1] -> 
        Plus[ 4895.9806038918032, 
          Times[ 1502.4774177622637, 
            Power[ E, 
              Times[ -12.086643397569993, t1]]], 
          Times[ -6357.3552447528518, 
            Power[ E, 
              Times[ -2.8565990345907886, t1]]], 
          Times[ 80.426830529778428, 
            Power[ E, 
              Times[ -.14677556138819206, t1]]], 
          Times[ -121.52960743099368, 
            Power[ E, 
              Times[ -.09296993648799734, t1]]]], qURI[ t1] -> Plus[ 
        678087.06600223272, 
          Times[ -1502.4774177622637, 
            Power[ E, 
              Times[ -12.086643397569993, t1]]], 
          Times[ 27541.330235557667, 
            Power[ E, 
              Times[ -2.8565990345907886, t1]]], 
          Times[ -16050.012257587321, 
            Power[ E, 
              Times[ -.14677556138819206, t1]]], 
          Times[ 230513.9204979378, 
            Power[ E, 
              Times[ -.09296993648799734, t1]]], 
          Times[ -918589.82706037862, 
            Power[ E, 
              Times[ -.086643397569993161, t1]]]], qULI[ t1] -> Plus[ 
        97.582941135192129, 
          Times[ .3458496811172434, 
            Power[ E, 
              Times[ -2.8565990345907886, t1]]], 
          Times[ -1.2566315510054658, 
            Power[ E, 
              Times[ -1.8866433975699932, t1]]], 
          Times[ 192.73944462087078, 
            Power[ E, 
              Times[ -.14677556138819206, t1]]], 
          Times[ -289.4116038861747, 
            Power[ E, 
              Times[ -.09296993648799734, t1]]]], qLLI[ t1] -> Plus[ 
        161.64391596741081, 
          Times[ -.35172035557845105, 
            Power[ E, 
              Times[ -2.8565990345907886, t1]]], 
          Times[ 2.8274209897622979, 
            Power[ E, 
              Times[ -1.8866433975699932, t1]]], 
          Times[ -8.9894248481268804, 
            Power[ E, 
              Times[ -1.0866433975699932, t1]]], 
          Times[ 369.12743149820881, 
            Power[ E, 
              Times[ -.14677556138819206, t1]]], 
          Times[ -524.25762325167659, 
            Power[ E, 
              Times[ -.09296993648799734, t1]]]], qFEC[ t1] -> Plus[ 
        1865.6230076484353, 
          Times[ .12697689120997666, 
            Power[ E, 
              Times[ -2.8565990345907886, t1]]], 
          Times[ -1.5707894387568322, 
            Power[ E, 
              Times[ -1.8866433975699932, t1]]], 
          Times[ 8.9894248481268804, 
            Power[ E, 
              Times[ -1.0866433975699932, t1]]], 
          Times[ -6138.6021732764075, 
            Power[ E, 
              Times[ -.14677556138819206, t1]]], 
          Times[ 82866.418755401173, 
            Power[ E, 
              Times[ -.09296993648799734, t1]]], 
          Times[ -78600.985202073789, 
            Power[ E, 
              Times[ -.086643397569993161, t1]]]], qWB[ t1] -> Plus[ 
        317238.12325257045, 
          Times[ 1502.4774177622637, 
            Power[ E, 
              Times[ -12.086643397569993, t1]]], 
          Times[ -27541.457212448873, 
            Power[ E, 
              Times[ -2.8565990345907886, t1]]], 
          Times[ 1.5707894387568322, 
            Power[ E, 
              Times[ -1.8866433975699932, t1]]], 
          Times[ -8.9894248481268804, 
            Power[ E, 
              Times[ -1.0866433975699932, t1]]], 
          Times[ 22188.614430863716, 
            Power[ E, 
              Times[ -.14677556138819206, t1]]], 
          Times[ -313380.33925333817, 
            Power[ E, 
              Times[ -.09296993648799734, t1]]]]}]]], "Output",
  CellLabel->"Out[35]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, t1, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Injection\>", 
      IntakeType \[Rule] \ "\<Constant\>", 
      ShowReport \[Rule] \ "\<Disintegrations\>"]\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \({qB[t1] \[Rule] \(-15297.391773850059`\) + 
          10588.373528040189`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ \
t1\) - 3372.4459174695567`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ \
t1\) + 8081.464163279426`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\) \
+ 30503.07816528847`\ t1, 
      q\_2[t1] \[Rule] \(-2.9204020788242994`*^6\) - 
          3182.695732602299`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\
\) + 54386.02005344805`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) + 
          2.8691987545034536`*^6\ \
\[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\) + 265640.0790454935`\ t1, 
      q\_3[t1] \[Rule] \(-285630.1957905155`\) + 
          10.167354862040915`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ \
t1\) - 197811.31430764878`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ \
t1\) + 483431.3427433023`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\) \
+ 15939.758580794074`\ t1, 
      q\_4[t1] \[Rule] \(-2860.4236517900213`\) - 
          124.30890598330512`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t1\) + 2225.4979322512972`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) \
- 547.957914581335`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) + 
          1307.192540103364`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ \
t1\) + 4895.980603891803`\ t1, 
      qURI[t1] \[Rule] \(-8.222347804957727`*^6\) + 
          124.30890598330512`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t1\) - 9641.300687305944`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) \
+ 109350.71278752082`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) - 
          2.4794458209369406`*^6\ \
\[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\) + 
          1.060195990488847`*^7\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\
\ t1\) + 678087.0660022327`\ t1, 
      qULI[t1] \[Rule] \(-1800.3464284191175`\) - 
          0.12107043268212363`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ \
t1\) + 0.6660673408785222`\ \[ExponentialE]\^\(\(-1.8866433975699932`\)\ t1\) \
- 1313.15760469901`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) + 
          3112.959036209931`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ \
t1\) + 97.58294113519213`\ t1, 
      qLLI[t1] \[Rule] \(-3130.988045139872`\) + 
          0.12312555991213357`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ \
t1\) - 1.4986515169766748`\ \[ExponentialE]\^\(\(-1.8866433975699932`\)\ t1\) \
+ 8.272653998753857`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) - 
          2514.910711340701`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ \
t1\) + 5639.001628438884`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\) \
+ 161.6439159674108`\ t1, 
      qFEC[t1] \[Rule] \(-57668.687896869495`\) - 
          0.04445037251374912`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ \
t1\) + 0.8325841760981527`\ \[ExponentialE]\^\(\(-1.8866433975699932`\)\ t1\) \
- 8.272653998753857`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) + 
          41823.053614770586`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ \
t1\) - 891324.8936778551`\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\ t1\) \
+ 907178.0124801492`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\) + 
          1865.6230076484353`\ t1, 
      qWB[t1] \[Rule] \(-3.229121424514014`*^6\) - 
          124.30890598330512`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t1\) + 9641.345137678458`\ \[ExponentialE]\^\(\(-2.8565990345907886`\)\ t1\) \
- 0.8325841760981527`\ \[ExponentialE]\^\(\(-1.8866433975699932`\)\ t1\) + 
          8.272653998753857`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\
\) - 151173.7664022913`\ \[ExponentialE]\^\(\(-0.14677556138819206`\)\ t1\) + 
          3.370770714614787`*^6\ \[ExponentialE]\^\(\(-0.09296993648799734`\)\
\ t1\) + 317238.12325257045`\ t1}\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs1, t, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Injection\>", 
      IntakeType \[Rule] \ "\<Continuous\>", 
      ShowReport \[Rule] \ \ "\<Disintegrations\>"]\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \("Option not available for continuous intake"\)], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs2, t, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Injection\>", 
      IntakeType \[Rule] \ "\<MultiInputs\>", 
      ShowReport \[Rule] \ "\<Disintegrations\>"]\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \("Option not available for MultiInputs intake"\)], "Output",
  CellLabel->"Out[38]="]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ingestion", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Ingestion\",ShowReport\[Rule] \"Automatic\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, 1, t1, Log[2]/8.0, 
        IntakeWay \[Rule] \ "\<Ingestion\>", 
        IntakeType \[Rule] \ "\<Acute\>"] // TableForm\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(qDailyUrine[t1] \[Rule] 
              2.4205791582603745`*^9\ \
\[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\) - 
                68416.52784120615`\ \[ExponentialE]\^\(\(-12.086643397569993`\
\)\ t1\) + 
                15.397569647497475`\ \
\[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) - 
                0.001694082921431736`\ \
\[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) + 
                0.0015746395133718338`\ \
\[ExponentialE]\^\(\(-0.09296993648799633`\)\ t1\) + 
                0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\)\)},
          {\(qDailyFaecal[
                t1] \[Rule] \(-0.6360417476322342`\)\ \
\[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\) + 
                0.00007098914646846348`\ \
\[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) - 
                0.00018724635695822618`\ \
\[ExponentialE]\^\(\(-1.8866433975699939`\)\ t1\) + 
                0.00020271365869748028`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) - 
                0.0006479310380772593`\ \
\[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) + 
                0.0005660601191546655`\ \
\[ExponentialE]\^\(\(-0.09296993648799633`\)\ t1\) + 
                0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\)\)},
          {\(qWholebody[t1] \[Rule] 
              0.09138011995454601`\ \[ExponentialE]\^\(\(-24.086643397569993`\
\)\ t1\) - 
                0.42036825836560815`\ \
\[ExponentialE]\^\(\(-12.086643397569993`\)\ t1\) + 
                1.0293967614319273`\ \
\[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) - 
                0.00003708107512016082`\ \
\[ExponentialE]\^\(\(-1.8866433975699939`\)\ t1\) + 
                0.00011797462752619218`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) - 
                0.03778850272554368`\ \
\[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) + 
                0.3372989861522724`\ \
\[ExponentialE]\^\(\(-0.09296993648799633`\)\ t1\) + 
                0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {qDailyUrine[ t1] -> Plus[ 
          Times[ 2420579158.2603745, 
            Power[ E, 
              Times[ -24.086643397569993, t1]]], 
          Times[ -68416.527841206145, 
            Power[ E, 
              Times[ -12.086643397569993, t1]]], 
          Times[ 15.397569647497475, 
            Power[ E, 
              Times[ -2.8565990345907895, t1]]], 
          Times[ -.001694082921431736, 
            Power[ E, 
              Times[ -.14677556138819248, t1]]], 
          Times[ .0015746395133718338, 
            Power[ E, 
              Times[ -.092969936487996327, t1]]], 
          Times[ 0.0, 
            Power[ E, 
              Times[ -.086643397569993161, t1]]]], qDailyFaecal[ t1] -> Plus[ 
        
          Times[ -.6360417476322342, 
            Power[ E, 
              Times[ -24.086643397569993, t1]]], 
          Times[ .000070989146468463478, 
            Power[ E, 
              Times[ -2.8565990345907895, t1]]], 
          Times[ -.00018724635695822618, 
            Power[ E, 
              Times[ -1.8866433975699939, t1]]], 
          Times[ .00020271365869748028, 
            Power[ E, 
              Times[ -1.0866433975699932, t1]]], 
          Times[ -.00064793103807725926, 
            Power[ E, 
              Times[ -.14677556138819248, t1]]], 
          Times[ .00056606011915466548, 
            Power[ E, 
              Times[ -.092969936487996327, t1]]], 
          Times[ 0.0, 
            Power[ E, 
              Times[ -.086643397569993161, t1]]]], qWholebody[ t1] -> Plus[ 
          Times[ .091380119954546007, 
            Power[ E, 
              Times[ -24.086643397569993, t1]]], 
          Times[ -.42036825836560815, 
            Power[ E, 
              Times[ -12.086643397569993, t1]]], 
          Times[ 1.0293967614319273, 
            Power[ E, 
              Times[ -2.8565990345907895, t1]]], 
          Times[ -.000037081075120160817, 
            Power[ E, 
              Times[ -1.8866433975699939, t1]]], 
          Times[ .00011797462752619218, 
            Power[ E, 
              Times[ -1.0866433975699932, t1]]], 
          Times[ -.037788502725543682, 
            Power[ E, 
              Times[ -.14677556138819248, t1]]], 
          Times[ .33729898615227238, 
            Power[ E, 
              Times[ -.092969936487996327, t1]]], 
          Times[ 0.0, 
            Power[ E, 
              Times[ -.086643397569993161, t1]]]]}]]], "Output",
  CellLabel->"Out[39]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, 1, t1, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Ingestion\>", 
      IntakeType \[Rule] \ "\<Constant\>"]\)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \({qDailyUrine[
          t1] \[Rule] \(\(0.6490282683097819`\)\(\[InvisibleSpace]\)\) - 
          1.0049466496043934`*^8\ \[ExponentialE]\^\(\(-24.086643397569993`\)\
\ t1\) + 5660.506857922294`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t1\) - 5.390175331240768`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) \
+ 0.011541995856866244`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) - 
          0.0169370828125186`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t1\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\), 
      qDailyFaecal[
          t1] \[Rule] \(\(0.0017856734490674792`\)\(\[InvisibleSpace]\)\) - 
          0.000024850931337877707`\ \[ExponentialE]\^\(\(-2.8565990345907895`\
\)\ t1\) + 
          0.000099248409741555`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ \
t1\) - 0.0001865503063385825`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ \
t1\) + 0.004414434064834605`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t1\) - 0.006088636182167706`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t1\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\), 
      qWholebody[
          t1] \[Rule] \(\(3.700046512603076`\)\(\[InvisibleSpace]\)\) - 
          0.0037938088112254354`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\
\ t1\) + 0.03477956985560795`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t1\) - 0.3603574561801913`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) \
+ 0.000019654522506967362`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ t1\) \
- 0.00010856793294839227`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) \
+ 0.25745772912154313`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) - 
          3.6280436331783688`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t1\)}\)], "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs1, 1, t, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Ingestion\>", 
      IntakeType \[Rule] \ "\<Continuous\>"]\)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    \({qDailyUrine[
          t] \[Rule] \(-1.221145388764347`*^8\)\ \
\[ExponentialE]\^\(\(-24.086643397569993`\)\ t\) + 
          6965.497354944461`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t\) - 7.227212138861818`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t\) + 
          1.046913369356873`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.01326746258061623`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t\) + 0.009127019448248452`\ \[ExponentialE]\^\(\(-0.09296993648799634`\)\ \
t\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999317`\)\ t\), 
      qDailyFaecal[
          t] \[Rule] \(-0.00003332042866698148`\)\ \
\[ExponentialE]\^\(\(-2.8565990345907895`\)\ t\) + 
          0.00014161696868622244`\ \
\[ExponentialE]\^\(\(-1.8866433975699939`\)\ t\) - 
          0.0003092333720570408`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\
\ t\) + 0.001993422207753722`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.005074368375808144`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\
\ t\) + 0.003281031418638336`\ \[ExponentialE]\^\(\(-0.09296993648799634`\)\ \
t\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999317`\)\ t\), 
      qWholebody[
          t] \[Rule] \(-0.004609988139674113`\)\ \
\[ExponentialE]\^\(\(-24.086643397569993`\)\ t\) + 
          0.042797757853837215`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t\) - 0.4831716264478803`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t\) + 
          0.000028044921884994644`\ \[ExponentialE]\^\(\(-1.8866433975699939`\
\)\ t\) - 
          0.00017996661952385379`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t\) - 
          1.2139904350360406`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.29594628429696224`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t\) + 1.955072497764359`\ \[ExponentialE]\^\(\(-0.09296993648799634`\)\ \
t\)}\)], "Output",
  CellLabel->"Out[41]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs2, 1, t, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Ingestion\>", 
      IntakeType \[Rule] \ "\<MultiInputs\>"]\)], "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    \({qDailyUrine[t] \[Rule] 
        1.6944054107822622`*^10\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ \
t\) - 478915.69489495875`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t\) + 
          107.93552081449482`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t\
\) - 0.01635017925295077`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ t\) \
+ 0.015846268898380284`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ t\) + 
          3.3306690738754696`*^-16\ \
\[ExponentialE]\^\(\(-0.08664339756999316`\)\ t\), 
      qDailyFaecal[
          t] \[Rule] \(-4.4522922334256405`\)\ \
\[ExponentialE]\^\(\(-24.086643397569993`\)\ t\) + 
          0.0004976272666183644`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\
\ t\) - 0.0013236335229016049`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ \
t\) + 0.001488502625298878`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ t\) \
- 0.006253406183423689`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ t\) + 
          0.005696504364714153`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\
\ t\) + 4.163336342344337`*^-17\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\
\ t\), qWholebody[t] \[Rule] 
        0.6396608396818221`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ t\) \
- 2.9425778085992906`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t\) + 
          7.215974865745617`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ \
t\) - 0.00026212394671703773`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ t\
\) + 0.0008662738560377878`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ t\) \
- 0.3647098884280646`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ t\) + 
          3.3943835324408993`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t\)}\)], "Output",
  CellLabel->"Out[42]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Ingestion\",ShowReport\[Rule] \"BioassayTable\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, 1, 180, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Ingestion\>", 
      IntakeType \[Rule] \ "\<Acute\>", \ 
      ShowReport \[Rule] \ "\<BioassayTable\>"]\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nstart intake"\), \("Urine\n24 hours"\), \("Faecal\n\
24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "0.5830947406215125`", "4.0665425751105033`*^-7", 
            "0.3339088959289011`"},
          {"2", "0.05088640384393987`", "5.910028230445536`*^-6", 
            "0.2553034937566397`"},
          {"3", "0.003022396810366228`", "0.00001827453862978707`", 
            "0.23107366467012122`"},
          {"4", "0.00031170596038730236`", "0.00003258202675706668`", 
            "0.2115511967934772`"},
          {"5", "0.0001856486952845348`", "0.00004545108847137243`", 
            "0.19376220302064978`"},
          {"6", "0.0001997483491753833`", "0.00005576576061903761`", 
            "0.1774252094803858`"},
          {"7", "0.00021506060333202422`", "0.0000634651271024054`", 
            "0.16242110872951512`"},
          {"8", "0.00022488380956026122`", "0.00006884302844904766`", 
            "0.1486470865687416`"},
          {"9", "0.0002299094423024729`", "0.00007227042017158806`", 
            "0.13600779953165673`"},
          {"10", "0.00023107863853136443`", "0.00007410154970599526`", 
            "0.12441452188966223`"},
          {"20", "0.00015531386615229997`", "0.00005376562010090875`", 
            "0.050533097332400446`"},
          {"30", "0.00007607254243566438`", "0.000026870546656842984`", 
            "0.02027357752683792`"},
          {"40", "0.000033428385162841134`", "0.000011907230851951073`", 
            "0.008077365230043527`"},
          {"50", "0.000013977835363717072`", "4.999529333477625`*^-6", 
            "0.0032054135667122074`"},
          {"60", "5.697464452945317`*^-6", "2.042325791055454`*^-6", 
            "0.0012691210308841238`"},
          {"70", "2.290295448654715`*^-6", "8.219845404747222`*^-7", 
            "0.0005018163329041771`"},
          {"80", "9.135173674606773`*^-7", "3.280866682781595`*^-7", 
            "0.0001982671924204927`"},
          {"90", "3.6275253744000983`*^-7", "1.3033294167003986`*^-7", 
            "0.00007829993006181581`"},
          {"100", "1.436782467900985`*^-7", "5.1633809423519815`*^-8", 
            "0.0000309141898540248`"},
          {"180", "8.499876311763976`*^-11", "3.055569461590563`*^-11", 
            "1.8208431516810994`*^-8"},
          {"200", "1.3240523485213099`*^-11", "4.7597696521807876`*^-12", 
            "2.836272303034129`*^-9"},
          {"300", "1.214176938214323`*^-15", "4.364790365458601`*^-16", 
            "2.6008536261374325`*^-13"},
          {"400", "1.113394278403402`*^-19", "4.002491316443937`*^-20", 
            "2.3849697550910107`*^-17"},
          {"500", "1.0209769689305713`*^-23", "3.670264462300816`*^-24", 
            "2.1870053023626013`*^-21"},
          {"600", "9.362307592212692`*^-28", "3.3656141016479506`*^-28", 
            "2.005472892104149`*^-25"},
          {"700", "8.585189100158375`*^-32", "3.086251249071218`*^-32", 
            "1.8390085824752292`*^-29"},
          {"800", "7.872575340932665`*^-36", "2.8300769145587433`*^-36", 
            "1.6863616455414617`*^-33"},
          {"900", "7.219112098290141`*^-40", "2.595166334802809`*^-40", 
            "1.54638517006031`*^-37"},
          {"1000", "6.619889582626779`*^-44", "2.379754511480946`*^-44", 
            "1.418027444175325`*^-41"},
          {"2000", "2.7830457787011646`*^-84", "1.0004646726550466`*^-84", 
            "5.961481993683298`*^-82"},
          {"3000", "1.1700059357516066`*^-124", "4.206018489951314`*^-125", 
            "2.506246808338542`*^-122"},
          {"4000", "4.917907999806934`*^-165", "1.767903134413355`*^-165", 
            "1.053642881243827`*^-162"},
          {"5000", "0.`", "0.`", "4.429584977433596`*^-203"},
          {"6000", "0.`", "0.`", "1.862227081071472`*^-243"},
          {"7000", "0.`", "0.`", "7.828926906568993`*^-284"},
          {"8000", "0.`", "0.`", 
            "3.29133311030651647622567350559625`15.954589770191005*^-324"},
          {"9000", "0.`", "0.`", 
            "1.383698401106444687009332944838`15.954589770191005*^-364"},
          {"10000", "0.`", "0.`", 
            "5.8171604060047371069774106394`15.954589770191005*^-405"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nstart intake", 
          "Urine\n24 hours", "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
  CellLabel->"Out[43]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, 1, 180, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Ingestion\>", 
      IntakeType \[Rule] \ "\<Constant\>", \ 
      ShowReport \[Rule] \ "\<BioassayTable\>"]\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\n start intake"\), \("Urine\n24 hours"\), \("Faecal\n\
24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "0.3622348033167331`", "7.454923499816735`*^-8", 
            "0.5956679643926783`"},
          {"2", "0.6257721573974775`", "2.5550266660788393`*^-6", 
            "0.8783580615909994`"},
          {"3", "0.6426217793636703`", "0.00001426852003298976`", 
            "1.1207246882362218`"},
          {"4", "0.6437090507843983`", "0.000039720048910894045`", 
            "1.3418631418581626`"},
          {"5", "0.6439251795725078`", "0.00007892723695074842`", 
            "1.5443926619613624`"},
          {"6", "0.6441166373741072`", "0.00012976000798675118`", 
            "1.7298707601916603`"},
          {"7", "0.644324483818131`", "0.00018958358692252393`", 
            "1.8996872561717968`"},
          {"8", "0.6445448968947782`", "0.00025591579812269283`", 
            "2.055122924300587`"},
          {"9", "0.6447726523475632`", "0.00032661973578469467`", 
            "2.197359601042458`"},
          {"10", "0.6450034319541853`", "0.00039992505343731943`", 
            "2.3274871237824772`"},
          {"20", "0.647002963387294`", "0.001071691546845304`", 
            "3.1485916484364096`"},
          {"30", "0.6481282762851297`", "0.001465385326401893`", 
            "3.4801571850620623`"},
          {"40", "0.648649870002715`", "0.0016503927453483131`", 
            "3.6127448544685294`"},
          {"50", "0.6488735795481855`", "0.0017302374511749263`", 
            "3.6654717267463477`"},
          {"60", "0.6489659851249501`", "0.0017633232674978058`", 
            "3.6863733238624046`"},
          {"70", "0.6490034029986163`", "0.0017767438831638935`", 
            "3.694643751298377`"},
          {"80", "0.6490183892456924`", "0.0017821241778681052`", 
            "3.697912733006959`"},
          {"90", "0.6490243542423855`", "0.0017842668845680885`", 
            "3.699204032562981`"},
          {"100", "0.6490267200619373`", "0.001785116988387507`", 
            "3.699713931545482`"},
          {"180", "0.6490282673954981`", "0.0017856731203968017`", 
            "3.700046316749677`"},
          {"200", "0.6490282681673643`", "0.0017856733978701585`", 
            "3.700046482095636`"},
          {"300", "0.6490282683097686`", "0.0017856734490627885`", 
            "3.7000465126002786`"},
          {"400", "0.6490282683097819`", "0.0017856734490674826`", 
            "3.7000465126030755`"},
          {"500", "0.6490282683097819`", "0.0017856734490674792`", 
            "3.700046512603076`"},
          {"600", "0.6490282683097819`", "0.0017856734490674792`", 
            "3.700046512603076`"},
          {"700", "0.6490282683097819`", "0.0017856734490674792`", 
            "3.700046512603076`"},
          {"800", "0.6490282683097819`", "0.0017856734490674792`", 
            "3.700046512603076`"},
          {"900", "0.6490282683097819`", "0.0017856734490674792`", 
            "3.700046512603076`"},
          {"1000", "0.6490282683097819`", "0.0017856734490674792`", 
            "3.700046512603076`"},
          {"2000", "0.6490282683097819`", "0.0017856734490674792`", 
            "3.700046512603076`"},
          {"3000", "0.6490282683097819`", "0.0017856734490674792`", 
            "3.700046512603076`"},
          {"4000", "0.6490282683097819`", "0.0017856734490674792`", 
            "3.700046512603076`"},
          {"5000", "0.6490282683097819`", "0.0017856734490674792`", 
            "3.700046512603076`"},
          {"6000", "0.6490282683097819`", "0.0017856734490674792`", 
            "3.700046512603076`"},
          {"7000", "0.6490282683097819`", "0.0017856734490674792`", 
            "3.700046512603076`"},
          {"8000", "0.6490282683097819`", "0.0017856734490674792`", 
            "3.700046512603076`"},
          {"9000", "0.6490282683097819`", "0.0017856734490674792`", 
            "3.700046512603076`"},
          {"10000", "0.6490282683097819`", "0.0017856734490674792`", 
            "3.700046512603076`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\n start intake", 
          "Urine\n24 hours", "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
  CellLabel->"Out[44]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs1, 1, \ 180, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Ingestion\>", 
      IntakeType \[Rule] \ "\<Continuous\>", \ 
      ShowReport \[Rule] \ "\<BioassayTable\>"]\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\n start intake"\), \("Urine\n24 hours"\), \("Faecal\n\
24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "0.3921475237728229`", "8.553039053860223`*^-8", 
            "0.5987895570153745`"},
          {"2", "0.5483795283633328`", "2.7775993221552118`*^-6", 
            "0.73481444720952`"},
          {"3", "0.4226354796291564`", "0.000014524564299576297`", 
            "0.7950156624171719`"},
          {"4", "0.31416209014019847`", "0.000037518002917851333`", 
            "0.8177179552393835`"},
          {"5", "0.23295831859003657`", "0.00006877433880867747`", 
            "0.815288117090899`"},
          {"6", "0.17277864934163012`", "0.00010391558041552873`", 
            "0.7958479034449777`"},
          {"7", "0.1282134481484516`", "0.0001392020758436276`", 
            "0.7652439069008055`"},
          {"8", "0.09521161986436222`", "0.00017203057305678181`", 
            "0.7276947322390002`"},
          {"9", "0.07077075216296547`", "0.00020083238923667698`", 
            "0.686223218696635`"},
          {"10", "0.05266754763806114`", "0.00022482497301776357`", 
            "0.6429735338300492`"},
          {"20", "0.0033121709230515828`", "0.0002465481444236424`", 
            "0.2858093466942553`"},
          {"30", "0.0005279399343462443`", "0.0001398562248570473`", 
            "0.11641987742981082`"},
          {"40", "0.0001904684039526483`", "0.00006531067161452448`", 
            "0.04659414953366874`"},
          {"50", "0.00007909867688496441`", "0.000028122170746875948`", 
            "0.018529055590590933`"},
          {"60", "0.000032523567023660244`", "0.00001164038991679833`", 
            "0.007344618482818204`"},
          {"70", "0.000013156949646099883`", "4.7189270843891475`*^-6", 
            "0.0029060025943000037`"},
          {"80", "5.267602771794923`*^-6", "1.89118811164124`*^-6", 
            "0.0011485964297901555`"},
          {"90", "2.0962909983751783`*^-6", "7.530268165646865`*^-7", 
            "0.00045370577207456557`"},
          {"100", "8.313403888446803`*^-7", "2.98726043146302`*^-7", 
            "0.00017915418992111188`"},
          {"180", "4.9266331988972`*^-10", "1.771043104345003`*^-10", 
            "1.0554053828785125`*^-7"},
          {"200", "7.674489687983605`*^-11", "2.7588625511594956`*^-11", 
            "1.6439756942411463`*^-8"},
          {"300", "7.037684514889161`*^-15", "2.5299457209631487`*^-15", 
            "1.5075222827199871`*^-12"},
          {"400", "6.45352231068018`*^-19", "2.319947884566354`*^-19", 
            "1.3823903917667554`*^-16"},
          {"500", "5.91784759144543`*^-23", "2.127380574608937`*^-23", 
            "1.2676450551746678`*^-20"},
          {"600", "5.426636557036287`*^-27", "1.9507973158398567`*^-27", 
            "1.1624241570043414`*^-24"},
          {"700", "4.976198502379728`*^-31", "1.7888713532886124`*^-31", 
            "1.065937121176755`*^-28"},
          {"800", "4.563149062831765`*^-35", "1.640386057626011`*^-35", 
            "9.774589933081841`*^-33"},
          {"900", "4.184384799112185`*^-39", "1.504225786343404`*^-39", 
            "8.963249938648422`*^-37"},
          {"1000", "3.837059885027484`*^-43", "1.3793675019019116`*^-43", 
            "8.219255233487888`*^-41"},
          {"2000", "1.6131275236056171`*^-83", "5.798954682065139`*^-84", 
            "3.455429743422253`*^-81"},
          {"3000", "6.805628539169866`*^-124", "2.4399516517762384`*^-124", 
            "1.4526857206088212`*^-121"},
          {"4000", "8.465585081046682`*^-164", "1.5042015158029661`*^-164", 
            "6.107187700395078`*^-162"},
          {"5000", "1.3140749823527033`*^-201", "1.1322733464446837`*^-202", 
            "2.5675024596665975`*^-202"},
          {
            "6000", \(-1.8746210173695387`*^-239\), \
\(-1.6028009698509556`*^-240\), "1.0793951657925272`*^-242"},
          {
            "7000", \(-4.407212831701244`*^-277\), \(-3.79020303526307`*^-278\
\), "4.537849300006139`*^-283"},
          {"8000", 
            "4.45950677945045509972626418592346`15.954589770191005*^-314", 
            "3.8129611868907236912157649173323`15.954589770191005*^-315", 
            "1.907742124678608585704096393561974`15.954589770191003*^-323"},
          {
            "9000", \(-2.44762994549373`1.9866321321741427*^-352\), \
\(-2.0943637677935`1.9866321321740947*^-353\), 
            "8.020275186899472972522320984589`15.954589770190998*^-364"},
          {"10000", "2.46288927692799`2.6180807201295657*^-389", 
            "2.10742072149509`2.61808072012953*^-390", 
            "3.37177720413545365565499492402`15.954589770190974*^-404"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\n start intake", 
          "Urine\n24 hours", "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
  CellLabel->"Out[45]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs2, 1, 180, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Ingestion\>", 
      IntakeType \[Rule] \ "\<MultiInputs\>", \ 
      ShowReport \[Rule] \ "\<BioassayTable\>"]\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nlast intake"\), \("Urine\n24 hours"\), \("Faecal\n\
24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "4.090945435385017`", "0.00012113532279430223`", 
            "3.1930043742421863`"},
          {"2", "0.35736482859830204`", "0.00020795930633330255`", 
            "2.570425133245651`"},
          {"3", "0.021943633200718994`", "0.00033654545599415536`", 
            "2.334810061284455`"},
          {"4", "0.0030122654087686262`", "0.0004694730188625653`", 
            "2.13754852788516`"},
          {"5", "0.0021739208018104654`", "0.0005832007245869789`", 
            "1.957383521090487`"},
          {"6", "0.0022978306091247986`", "0.0006710633583748705`", 
            "1.791959708974673`"},
          {"7", "0.002414017299140697`", "0.0007339697669160357`", 
            "1.6400863113235846`"},
          {"8", "0.0024788540568923875`", "0.0007752247396393883`", 
            "1.5007116998918304`"},
          {"9", "0.002499980805795614`", "0.0007985121725611088`", 
            "1.372860203507007`"},
          {"10", "0.0024863144013070933`", "0.0008072330475568122`", 
            "1.2556248099218494`"},
          {"20", "0.0016000612425312588`", "0.0005552450218939769`", 
            "0.5093630322594502`"},
          {"30", "0.0007740932864655765`", "0.00027367712964770474`", 
            "0.2042122142570181`"},
          {"40", "0.0003383727276606631`", "0.00012058047904415459`", 
            "0.08132988341054052`"},
          {"50", "0.00014111857375270997`", "0.0000504859041105147`", 
            "0.03226756293597354`"},
          {"60", "0.00005744055578815035`", "0.000020592779004620148`", 
            "0.012774038045308661`"},
          {"70", "0.000023072310498564985`", "8.281194868947899`*^-6", 
            "0.005050529120403783`"},
          {"80", "9.198666343132623`*^-6", "3.303799324005707`*^-6", 
            "0.001995371137831792`"},
          {"90", "3.6518127776879928`*^-6", "1.312085261956157`*^-6", 
            "0.0007879941221237499`"},
          {"100", "1.4461902719395247`*^-6", "5.197257959503902`*^-7", 
            "0.0003111092512585142`"},
          {"180", "8.553811437653134`*^-10", "3.0749588147281666`*^-10", 
            "1.832392632902785`*^-7"},
          {"200", "1.3324515849881575`*^-10", "4.789963933937276`*^-11", 
            "2.8542620437279675`*^-8"},
          {"300", "1.2218780344679541`*^-14", "4.392474693120898`*^-15", 
            "2.617349913652038`*^-12"},
          {"400", "1.1204561409796237`*^-18", "4.027877690516244`*^-19", 
            "2.4000967670897627`*^-16"},
          {"500", "1.0274526614713032`*^-22", "3.693543639918923`*^-23", 
            "2.200876696483542`*^-20"},
          {"600", "9.421689368012972`*^-27", "3.386960990755367`*^-27", 
            "2.0181928909332086`*^-24"},
          {"700", "8.639641890659993`*^-31", "3.1058262393039344`*^-31", 
            "1.8506727575971365`*^-28"},
          {"800", "7.92250827673401`*^-35", "2.848027082413997`*^-35", 
            "1.697057635619967`*^-32"},
          {"900", "7.264900349962437`*^-39", "2.611626548684653`*^-39", 
            "1.556193339310508`*^-36"},
          {"1000", "6.661877179733073`*^-43", "2.3948484450574407`*^-43", 
            "1.4270214861793329`*^-40"},
          {"2000", "0", "0", "0"},
          {"3000", "0", "0", "0"},
          {"4000", "0", "0", "0"},
          {"5000", "0", "0", "0"},
          {"6000", "0", "0", "0"},
          {"7000", "0", "0", "0"},
          {"8000", "0", "0", "0"},
          {"9000", "0", "0", "0"},
          {"10000", "0", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nlast intake", 
          "Urine\n24 hours", "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
  CellLabel->"Out[46]//TableForm="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Ingestion\",ShowReport\[Rule] \"GraphicReport\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, 1, 180, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Ingestion\>", 
      IntakeType \[Rule] \ "\<Acute\>", \ 
      ShowReport \[Rule] \ "\<GraphicReport\>"]\)], "Input",
  CellLabel->"In[47]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.616731 0.0572536 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .10145 -46.5 -6.6875 ]
[-0.0125 .10145 0 6.6875 ]
[-0.0125 .21596 -46.5 -6.625 ]
[-0.0125 .21596 0 6.625 ]
[-0.0125 .33046 -46 -6.28125 ]
[-0.0125 .33046 0 6.28125 ]
[-0.0125 .44497 -34 -6.28125 ]
[-0.0125 .44497 0 6.28125 ]
[-0.0125 .55948 -22 -6.28125 ]
[-0.0125 .55948 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10145 m
.00625 .10145 L
s
gsave
-0.0125 .10145 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .21596 m
.00625 .21596 L
s
gsave
-0.0125 .21596 -107.5 -10.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.500 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.313 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
105.000 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .33046 m
.00625 .33046 L
s
gsave
-0.0125 .33046 -107 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00001) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .44497 m
.00625 .44497 L
s
gsave
-0.0125 .44497 -95 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .55948 m
.00625 .55948 L
s
gsave
-0.0125 .55948 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .04873 m
.00375 .04873 L
s
0 .06491 m
.00375 .06491 L
s
0 .07462 m
.00375 .07462 L
s
0 .08159 m
.00375 .08159 L
s
0 .08703 m
.00375 .08703 L
s
0 .09149 m
.00375 .09149 L
s
0 .09527 m
.00375 .09527 L
s
0 .09855 m
.00375 .09855 L
s
0 .16324 m
.00375 .16324 L
s
0 .17941 m
.00375 .17941 L
s
0 .18913 m
.00375 .18913 L
s
0 .1961 m
.00375 .1961 L
s
0 .20154 m
.00375 .20154 L
s
0 .206 m
.00375 .206 L
s
0 .20978 m
.00375 .20978 L
s
0 .21306 m
.00375 .21306 L
s
0 .27774 m
.00375 .27774 L
s
0 .29392 m
.00375 .29392 L
s
0 .30364 m
.00375 .30364 L
s
0 .31061 m
.00375 .31061 L
s
0 .31605 m
.00375 .31605 L
s
0 .32051 m
.00375 .32051 L
s
0 .32429 m
.00375 .32429 L
s
0 .32757 m
.00375 .32757 L
s
0 .39225 m
.00375 .39225 L
s
0 .40843 m
.00375 .40843 L
s
0 .41815 m
.00375 .41815 L
s
0 .42512 m
.00375 .42512 L
s
0 .43055 m
.00375 .43055 L
s
0 .43501 m
.00375 .43501 L
s
0 .43879 m
.00375 .43879 L
s
0 .44207 m
.00375 .44207 L
s
0 .50676 m
.00375 .50676 L
s
0 .52293 m
.00375 .52293 L
s
0 .53265 m
.00375 .53265 L
s
0 .53962 m
.00375 .53962 L
s
0 .54506 m
.00375 .54506 L
s
0 .54952 m
.00375 .54952 L
s
0 .5533 m
.00375 .5533 L
s
0 .55658 m
.00375 .55658 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Acute) show
99.000 12.813 moveto
(intake) show
141.000 12.813 moveto
(in) show
159.000 12.813 moveto
(t) show
171.000 12.813 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
183.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
189.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .60332 m
.06042 .59656 L
.08838 .58349 L
.13894 .55166 L
.20509 .49415 L
.23444 .46212 L
.26115 .43181 L
.2711 .42187 L
.28123 .41366 L
.29174 .40778 L
.30107 .40479 L
.31076 .40339 L
.31951 .4031 L
.32703 .40328 L
.3349 .4037 L
.3657 .40584 L
.37818 .40662 L
.39062 .40727 L
.40085 .40771 L
.41107 .40806 L
.41665 .40821 L
.42258 .40834 L
.42782 .40843 L
.43257 .40849 L
.43539 .40852 L
.43803 .40853 L
.44036 .40854 L
.44287 .40855 L
.44555 .40854 L
.44836 .40853 L
.45072 .40852 L
.4533 .4085 L
.45784 .40844 L
.46191 .40837 L
.47076 .40816 L
.47823 .40792 L
.48577 .40762 L
.49904 .40691 L
.51058 .40613 L
.53436 .40397 L
.55551 .40137 L
.57346 .39862 L
.60295 .3929 L
.65211 .37945 L
.69305 .36376 L
.72536 .3479 L
.75184 .33222 L
.77637 .31524 L
.79724 .29872 L
.8171 .28103 L
Mistroke
.83439 .26391 L
.84961 .24739 L
.86452 .22978 L
.87782 .2128 L
.89097 .19474 L
.90281 .17733 L
.91352 .16057 L
.92426 .14274 L
.93405 .12557 L
.94299 .10905 L
.95205 .09147 L
.96037 .07454 L
.96882 .05655 L
.97619 .04015 L
Mfstroke
0 0 1 r
[ ] 0 setdash
.02381 .25084 m
.13894 .31199 L
.20509 .33875 L
.2577 .35481 L
.30107 .36478 L
.33772 .37114 L
.3667 .37494 L
.38932 .3772 L
.41107 .37882 L
.42166 .3794 L
.43106 .37982 L
.44084 .38014 L
.44612 .38026 L
.45081 .38035 L
.45313 .38038 L
.45556 .38041 L
.45783 .38043 L
.45987 .38044 L
.46224 .38045 L
.46477 .38045 L
.46713 .38044 L
.46927 .38043 L
.4731 .38039 L
.47524 .38036 L
.47721 .38033 L
.4811 .38026 L
.48524 .38015 L
.4924 .37993 L
.49894 .37966 L
.51059 .37904 L
.52332 .37815 L
.53436 .37719 L
.57035 .37274 L
.58806 .36973 L
.60327 .36669 L
.6526 .35344 L
.69364 .33781 L
.72602 .32194 L
.75256 .30621 L
.77713 .28917 L
.79803 .27257 L
.8179 .2548 L
.83521 .23759 L
.85045 .22098 L
.86538 .20327 L
.87869 .1862 L
.89064 .16977 L
.90256 .15227 L
.91334 .13541 L
.92415 .11749 L
Mistroke
.934 .10022 L
.94299 .08361 L
.9521 .06593 L
.96046 .04891 L
.96895 .03082 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[47]:=",
  ImageSize->{600, 294.25},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[47]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, 1, 180, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Ingestion\>", 
      IntakeType \[Rule] \ "\<Constant\>", \ 
      ShowReport \[Rule] \ "\<GraphicReport\>"]\)], "Input",
  CellLabel->"In[48]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.619242 0.0848156 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .02553 -46.5 -6.625 ]
[-0.0125 .02553 0 6.625 ]
[-0.0125 .19516 -46 -6.28125 ]
[-0.0125 .19516 0 6.28125 ]
[-0.0125 .36479 -34 -6.28125 ]
[-0.0125 .36479 0 6.28125 ]
[-0.0125 .53443 -22 -6.28125 ]
[-0.0125 .53443 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02553 m
.00625 .02553 L
s
gsave
-0.0125 .02553 -107.5 -10.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.500 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.313 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
105.000 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .19516 m
.00625 .19516 L
s
gsave
-0.0125 .19516 -107 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00001) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .36479 m
.00625 .36479 L
s
gsave
-0.0125 .36479 -95 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .53443 m
.00625 .53443 L
s
gsave
-0.0125 .53443 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .11706 m
.00375 .11706 L
s
0 .14103 m
.00375 .14103 L
s
0 .15543 m
.00375 .15543 L
s
0 .16575 m
.00375 .16575 L
s
0 .17381 m
.00375 .17381 L
s
0 .18041 m
.00375 .18041 L
s
0 .18601 m
.00375 .18601 L
s
0 .19087 m
.00375 .19087 L
s
0 .2867 m
.00375 .2867 L
s
0 .31066 m
.00375 .31066 L
s
0 .32506 m
.00375 .32506 L
s
0 .33538 m
.00375 .33538 L
s
0 .34344 m
.00375 .34344 L
s
0 .35004 m
.00375 .35004 L
s
0 .35564 m
.00375 .35564 L
s
0 .3605 m
.00375 .3605 L
s
0 .45633 m
.00375 .45633 L
s
0 .48029 m
.00375 .48029 L
s
0 .49469 m
.00375 .49469 L
s
0 .50501 m
.00375 .50501 L
s
0 .51307 m
.00375 .51307 L
s
0 .51967 m
.00375 .51967 L
s
0 .52527 m
.00375 .52527 L
s
0 .53013 m
.00375 .53013 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Constant) show
117.000 12.813 moveto
(intake) show
153.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .58184 m
.06042 .59228 L
.08838 .59729 L
.1161 .60016 L
.13894 .60152 L
.15779 .60218 L
.17363 .60253 L
.18958 .60274 L
.20509 .60287 L
.21944 .60293 L
.23372 .60297 L
.24625 .60299 L
.25701 .603 L
.26883 .60301 L
.2752 .60301 L
.28092 .60302 L
.30107 .60302 L
.33501 .60303 L
.36579 .60304 L
.41107 .60307 L
.45102 .60309 L
.48098 .60312 L
.53436 .60317 L
.6058 .60323 L
.65542 .60327 L
.69308 .60329 L
.70978 .6033 L
.72615 .60331 L
.7414 .60331 L
.75476 .60331 L
.76709 .60331 L
.7778 .60332 L
.78805 .60332 L
.79874 .60332 L
.80824 .60332 L
.81796 .60332 L
.82683 .60332 L
.83574 .60332 L
.84369 .60332 L
.8508 .60332 L
.8584 .60332 L
.86504 .60332 L
.87166 .60332 L
.87857 .60332 L
.88494 .60332 L
.89145 .60332 L
.8973 .60332 L
.90262 .60332 L
.90833 .60332 L
.9134 .60332 L
Mistroke
.91846 .60332 L
.92382 .60332 L
.92877 .60332 L
.93391 .60332 L
.93901 .60332 L
.94368 .60332 L
.94822 .60332 L
.9523 .60332 L
.95637 .60332 L
.96073 .60332 L
.96476 .60332 L
.96898 .60332 L
.97272 .60332 L
.97619 .60332 L
Mfstroke
0 0 1 r
[ ] 0 setdash
.02381 .01472 m
.20509 .19222 L
.30107 .2606 L
.41107 .31712 L
.48498 .34445 L
.53436 .35853 L
.60287 .37276 L
.63172 .37697 L
.65536 .3797 L
.67446 .38145 L
.69343 .38283 L
.71037 .38379 L
.72677 .38451 L
.74071 .38497 L
.75461 .38533 L
.76768 .38558 L
.77929 .38575 L
.79007 .38587 L
.79954 .38594 L
.80955 .38601 L
.81819 .38605 L
.82671 .38608 L
.8355 .3861 L
.84355 .38611 L
.85168 .38613 L
.85895 .38613 L
.86548 .38614 L
.87248 .38614 L
.87863 .38614 L
.88474 .38615 L
.89118 .38615 L
.8971 .38615 L
.90319 .38615 L
.90866 .38615 L
.91365 .38615 L
.91901 .38615 L
.92378 .38615 L
.92854 .38615 L
.93361 .38615 L
.93829 .38615 L
.94316 .38615 L
.94799 .38615 L
.95243 .38615 L
.95675 .38615 L
.96063 .38615 L
.9645 .38615 L
.96867 .38615 L
.97233 .38615 L
.97619 .38615 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[48]:=",
  ImageSize->{600, 294.25},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[48]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs1, 1, 180, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Ingestion\>", 
      IntakeType \[Rule] \ "\<Continuous\>", \ 
      ShowReport \[Rule] \ "\<GraphicReport\>"]\)], "Input",
  CellLabel->"In[49]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.618398 0.0619049 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .12316 -46.5 -6.6875 ]
[-0.0125 .12316 0 6.6875 ]
[-0.0125 .24697 -46.5 -6.6875 ]
[-0.0125 .24697 0 6.6875 ]
[-0.0125 .37078 -40 -6.28125 ]
[-0.0125 .37078 0 6.28125 ]
[-0.0125 .49459 -28 -6.28125 ]
[-0.0125 .49459 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12316 m
.00625 .12316 L
s
gsave
-0.0125 .12316 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .24697 m
.00625 .24697 L
s
gsave
-0.0125 .24697 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .37078 m
.00625 .37078 L
s
gsave
-0.0125 .37078 -101 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0001) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .49459 m
.00625 .49459 L
s
gsave
-0.0125 .49459 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .06616 m
.00375 .06616 L
s
0 .08365 m
.00375 .08365 L
s
0 .09415 m
.00375 .09415 L
s
0 .10169 m
.00375 .10169 L
s
0 .10757 m
.00375 .10757 L
s
0 .11239 m
.00375 .11239 L
s
0 .11648 m
.00375 .11648 L
s
0 .12003 m
.00375 .12003 L
s
0 .18996 m
.00375 .18996 L
s
0 .20746 m
.00375 .20746 L
s
0 .21796 m
.00375 .21796 L
s
0 .2255 m
.00375 .2255 L
s
0 .23138 m
.00375 .23138 L
s
0 .2362 m
.00375 .2362 L
s
0 .24029 m
.00375 .24029 L
s
0 .24384 m
.00375 .24384 L
s
0 .31377 m
.00375 .31377 L
s
0 .33127 m
.00375 .33127 L
s
0 .34177 m
.00375 .34177 L
s
0 .34931 m
.00375 .34931 L
s
0 .35519 m
.00375 .35519 L
s
0 .36001 m
.00375 .36001 L
s
0 .3641 m
.00375 .3641 L
s
0 .36765 m
.00375 .36765 L
s
0 .43758 m
.00375 .43758 L
s
0 .45508 m
.00375 .45508 L
s
0 .46558 m
.00375 .46558 L
s
0 .47312 m
.00375 .47312 L
s
0 .479 m
.00375 .479 L
s
0 .48382 m
.00375 .48382 L
s
0 .48791 m
.00375 .48791 L
s
0 .49145 m
.00375 .49145 L
s
0 .56139 m
.00375 .56139 L
s
0 .57889 m
.00375 .57889 L
s
0 .58939 m
.00375 .58939 L
s
0 .59693 m
.00375 .59693 L
s
0 .60281 m
.00375 .60281 L
s
0 .60763 m
.00375 .60763 L
s
0 .61172 m
.00375 .61172 L
s
0 .61526 m
.00375 .61526 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Continuous) show
129.000 12.813 moveto
(intake) show
165.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .59323 m
.06042 .60001 L
.08838 .60264 L
.1161 .60332 L
.13894 .60282 L
.15779 .60184 L
.17363 .60069 L
.20509 .59766 L
.25791 .59061 L
.30107 .58297 L
.3616 .56872 L
.41107 .55309 L
.48481 .52077 L
.53436 .49162 L
.60255 .444 L
.65487 .41151 L
.69419 .3913 L
.72541 .37424 L
.75367 .35618 L
.77729 .33852 L
.79945 .31951 L
.81854 .30102 L
.83519 .28313 L
.8514 .26401 L
.86575 .24556 L
.87857 .22778 L
.8913 .20884 L
.90277 .19059 L
.91423 .17118 L
.92462 .15247 L
.9341 .13447 L
.94367 .11532 L
.95243 .09688 L
.96048 .07915 L
.96868 .06026 L
.97619 .04222 L
s
0 0 1 r
[ ] 0 setdash
.02381 .18086 m
.13894 .2664 L
.20509 .30779 L
.30107 .35396 L
.36239 .37474 L
.41107 .38658 L
.43247 .39049 L
.45317 .3935 L
.47079 .39547 L
.47862 .39616 L
.48567 .39669 L
.49228 .3971 L
.49812 .3974 L
.5044 .39764 L
.50777 .39774 L
.51092 .39781 L
.51389 .39786 L
.51701 .39789 L
.51991 .39791 L
.5225 .39791 L
.52407 .3979 L
.5255 .39789 L
.52707 .39787 L
.5287 .39785 L
.53142 .3978 L
.53436 .39773 L
.53963 .39755 L
.5452 .39731 L
.5549 .39672 L
.56388 .39599 L
.57182 .39519 L
.58864 .39303 L
.60496 .39028 L
.63121 .38441 L
.65285 .37815 L
.69164 .36334 L
.72549 .34618 L
.75308 .32887 L
.77619 .31178 L
.79796 .2933 L
.81673 .27531 L
.83477 .25607 L
.85062 .23745 L
.86467 .21948 L
.87853 .20033 L
.89095 .18187 L
.90215 .1641 L
.91337 .14517 L
.92355 .12694 L
.93379 .10756 L
Mistroke
.94314 .08889 L
.95171 .07093 L
.96041 .05181 L
.96841 .03341 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[49]:=",
  ImageSize->{600, 294.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000>40001^A000`40O003h00OogooogooogooQgoo
003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mo
oomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogoo
ogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7
Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00
ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOooo
OoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomo
ohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool006aoo`L003ioo`H005Moo`@003aoo`L000=o
o`@003Moo`H000Aoo`@004moo`@000Eoo`@003=oo`L000=oo`@000Eoo`@002ioo`H000Aoo`@000Eo
o`@00?Qoo`00Kgoo00<007ooOol0?goo00<007ooOol00Woo00<007ooOol0E7oo00<007ooOol00Woo
00<007ooOol0?7oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0=7oo00<007ooOol00Woo
00D007ooOomoo`0000Aoo`03001oogoo04]oo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`0cOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0:goo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`3eOol006mo
o`03001oogoo041oo`03001oogoo05eoo`03001oogoo03aoo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo03Eoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo051oo`05001oogooOol0
0004Ool00`00Oomoo`0cOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<0
07ooOol0;7oo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo0?Eo
o`00Kgoo00<007ooOol0@Goo00<007ooOol0G7oo00<007ooOol0?7oo00<007ooOol00goo00<007oo
Ool00Woo00<007ooOol0=Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0D7oo00D007oo
Oomoo`0000Aoo`03001oogoo03=oo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0]Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool0mGoo001_Ool00`00Oomoo`12Ool00`00Oomoo`1KOol00`00Oomoo`0lOol00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`0gOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`1@Ool0
1@00Oomoogoo000017oo00<007ooOol0<goo00<007ooOol00goo00<007ooOol00Woo00D007ooOomo
o`0000Aoo`03001oogoo02ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool0
0`00Oomoo`3eOol006moo`03001oogoo04=oo`03001oogoo05Ioo`@003moo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo03Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo04aoo`@0
00Aoo`03001oogoo009oo`03001oogoo03=oo`03001oogoo00=oo`03001oogoo009oo`05001oogoo
Ool00004Ool00`00Oomoo`0_Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo
00<007ooOol0mGoo001_Ool00`00Oomoo`0oOol00`00Oomoo`02Ool00`00Oomoo`1EOol00`00Oomo
o`10Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0dOol00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00<007ooOol0C7oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0<goo00<0
07ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo02]oo`03001oogoo009o
o`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol0mGoo001]Ool30011Ool00`00
Oomoo`02Ool00`00Oomoo`1EOol00`00Oomoo`0nOol30005Ool00`00Oomoo`02Ool00`00Oomoo`0d
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0C7oo00<007ooOol01Goo00<007oo
Ool00Woo00<007ooOol0<Goo0`001Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo
02]oo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol0mGoo
001_Ool00`00Oomoo`10Ool4001HOol5000nOol00`00Oomoo`04Ool4000hOol40005Ool4001?Ool5
0004Ool4000fOol00`00Oomoo`04Ool40005Ool4000_Ool40005Ool40005Ool4003hOol00?mooomo
oomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooZgoo
0`00f7oo003oOoooOon]Ool00`00Oomoo`3FOol00?mooomoojeoo`03001oogoo0=Ioo`00ogooogoo
VGoo0`0000=oo`00000017oo1@001Goo0P001Goo1@00cGoo003oOoooOonHOol01000Oomoogoo0P00
17oo00D007ooOomoo`0000Ioo`8000Eoo`03001oogoo009oo`03001oogoo0<Yoo`00ogooogooV7oo
00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Eoo`04001oogoo0009Ool00`00Oomo
o`3:Ool0069oool00?l002D0015oo`03001oogoo009oo`03001oogoo00=oo`@000Eoo`04001oogoo
0005Ool4003=Ool0069oo`03001oogoo00Yoo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo
01Yoo`03001oogoo01=oo`03001oogoo011oo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo
00Uoo`03001oogoo00Qoo`03001oogoo049oo`03001oogoo02Ioo`03001oogoo01Yoo`03001oogoo
01=oo`03001oogoo00moo`03001oogoo00eoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo
00Moo`03001oogoo04=oo`03001oogoo015oo`04001oogooOol20004Ool01@00Oomoogoo000017oo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo0<Yoo`00HWoo00<007ooOol02Woo00<0
07ooOol0@Woo00<007ooOol09Woo00<007ooOol06Woo00<007ooOol04goo00<007ooOol047oo00<0
07ooOol037oo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0@Woo00<0
07ooOol09Woo00<007ooOol06Woo00<007ooOol04goo00<007ooOol03goo00<007ooOol03Goo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol01goo00<007ooOol0@goo00<007ooOol04Woo0`00
00=oo`00Ool017oo0`0017oo0`000Woo0`000goo1@00c7oo001ROol00`00Oomoo`0:Ool00`00Oomo
o`12Ool00`00Oomoo`1IOol00`00Oomoo`13Ool00`00Oomoo`12Ool00`00Oomoo`1IOol00`00Oomo
o`12Ool00`00Oomoo`13Ool00`00Oomoo`0FOol00`00Oomoo`3VOol0069oo`03001oogoo00Yoo`03
001oogoo049oo`03001oogoo05Uoo`03001oogoo04=oo`03001oogoo049oo`03001oogoo05Uoo`03
001oogoo049oo`03001oogoo04=oo`03001oogoo01Ioo`03001oogoo0>Ioo`00HWoo00<007ooOol0
ogooogoo=goo0P00j7oo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mooomo
oomoob9oo`00HWoo00<007ooOol0ogooogoo57oo00<07gooOol0ogoo2goo001ROol00`00Oomoo`3o
OoooOolDOol00`0OOomoo`3oOol;Ool0069oo`03001oogoo0?mooomooa=oo`0301moogoo0?moo`ao
o`00HWoo00<007ooOol0ogooogoo4goo00<07gooOol0ogoo37oo001ROol00`00Oomoo`3oOoooOolB
Ool00`0OOomoo`3oOol=Ool0069oo`03001oogoo0?mooomooa9oo`0301moogoo0?moo`eoo`00HWoo
00<007ooOol0ogooogoo4Woo00<07gooOol0ogoo3Goo001ROol00`00Oomoo`3oOoooOolAOol00`0O
Oomoo`3oOol>Ool0069oo`03001oogoo0?mooomooa5oo`0301moogoo0?moo`ioo`00HWoo00<007oo
Ool0ogooogoo47oo00<07gooOol0ogoo3goo001ROol00`00Oomoo`3oOoooOol@Ool00`0OOomoo`3o
Ool?Ool0069oo`03001oogoo0?mooomooa1oo`0301moogoo0?moo`moo`00HWoo00<007ooOol0ogoo
ogoo3goo00<07gooOol0ogoo47oo001ROol00`00Oomoo`3oOoooOol?Ool00`0OOomoo`3oOol@Ool0
069oo`03001oogoo0?mooomoo`ioo`0301moogoo0?mooa5oo`00HWoo00<007ooOol0ogooogoo3Woo
00<07gooOol0ogoo4Goo001ROol00`00Oomoo`3oOoooOol>Ool00`0OOomoo`3oOolAOol0069oo`03
001oogoo0?mooomoo`eoo`0301moogoo0?mooa9oo`00HWoo00<007ooOol0ogooogoo3Goo00<07goo
Ool00goo00=l07ooOol0ogoo37oo001ROol00`00Oomoo`3oOoooOol<Ool00`0OOomoo`04Ool00g`0
Oomoo`3oOol<Ool0069oo`03001oogoo0?mooomoo`aoo`0301moogoo00=oo`03O01oogoo0?moo`eo
o`00HWoo00<007ooOol0ogooogoo37oo00<07gooOol00goo00=l07ooOol0ogoo3Goo001ROol00`00
Oomoo`3oOoooOol;Ool00`0OOomoo`03Ool00g`0Oomoo`3oOol>Ool0069oo`03001oogoo0?mooomo
o`]oo`0301moogoo00=oo`03O01oogoo0?moo`ioo`00HWoo00<007ooOol0ogooogoo2Woo00<07goo
Ool0ogoo5Goo001ROol00`00Oomoo`3oOoooOol:Ool00`0OOomoo`3oOolEOol0069oo`03001oogoo
0?mooomoo`Uoo`0301moogoo0?mooaIoo`00HWoo00<007ooOol0ogooogoo2Goo00<07gooOol0ogoo
5Woo001ROol3003oOoooOol8Ool00`0OOomoo`3oOolGOol0069oo`03001oogoo0?mooomoo`Qoo`03
01moogoo00Aoo`03O01oogoo0?mooa1oo`00HWoo00<007ooOol0ogooogoo1goo00<07gooOol017oo
00=l07ooOol0ogoo4Goo001ROol00`00Oomoo`3oOoooOol7Ool00`0OOomoo`04Ool00g`0Oomoo`3o
OolAOol0069oo`03001oogoo0?mooomoo`Ioo`0301moogoo00Aoo`03O01oogoo0?mooa9oo`00HWoo
00<007ooOol0ogooogoo1Woo00<07gooOol017oo00=l07ooOol0ogoo4Woo001ROol00`00Oomoo`3o
OoooOol5Ool00`0OOomoo`04Ool00g`0Oomoo`3oOolCOol0069oo`03001oogoo0?mooomoo`Eoo`03
01moogoo0?mooaYoo`00HWoo00<007ooOol0ogooogoo17oo00<07gooOol0ogoo6goo001ROol00`00
Oomoo`3oOoooOol4Ool00`0OOomoo`3oOolKOol0069oo`<00?mooomoo`=oo`0301moogoo0?mooaao
o`00HWoo00<007ooOol0ogooogoo0goo00<07gooOol0ogoo77oo001ROol00`00Oomoo`3oOoooOol2
Ool00`0OOomoo`05Ool00g`0Oomoo`3oOolEOol0069oo`03001oogoo0?mooomoo`9oo`0301moogoo
00Aoo`03O01oogoo0?mooaIoo`00HWoo00<007ooOol0ogooogoo0Goo00<07gooOol01Goo00=l07oo
Ool0ogoo5Woo001ROol00`00Oomoo`3oOoooOol1Ool00`0OOomoo`04Ool00g`0Oomoo`3oOolGOol0
069oo`<00?mooomoo`0301moogoo00Eoo`03O01oogoo0?mooaMoo`00HWoo00<007ooOol0ogooogoo
00<07gooOol017oo00=l07ooOol0ogoo67oo001ROol00`00Oomoo`3oOoonOol00`0OOomoo`3oOolP
Ool0069oo`03001oogoo0?moooioo`0301moogoo0?moob1oo`00HWoo0`00ogoooGoo00<07gooOol0
ogoo8Goo001ROol00`00Oomoo`3oOoomOol00`0OOomoo`3oOolQOol0069oo`03001oogoo0?moooao
o`0301moogoo00Eoo`03O01oogoo0?mooaYoo`00HWoo0`00ogooo7oo00<07gooOol01Goo00=l07oo
Ool0ogoo6Woo001ROol00`00Oomoo`3oOookOol00`0OOomoo`05Ool00g`0Oomoo`3oOolKOol0069o
o`<00?mooo]oo`0301moogoo00Eoo`03O01oogoo0?mooa]oo`00HWoo00<007ooOol0ogoonWoo00<0
7gooOol01Goo00=l07ooOol0ogoo77oo001ROol00`00Oomoo`3oOoojOol00`0OOomoo`05Ool00g`0
Oomoo`3oOolLOol001Yoo`L000Aoo`8000Moo`03001oogoo00=oo`03001oogoo00=oo`L000=oo`@0
01Yoo`<00?moooUoo`0301moogoo00Eoo`03O01oogoo0?mooaeoo`007Goo00<007ooOol01Goo0P00
27oo00D007ooOomoo`0000Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo01Moo`03001o
ogoo0?moooUoo`0301moogoo06=oojX001Moo`007Goo00<007ooOol047oo00<007oo00002Woo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol05goo0`00ogoon7oo00<07gooOol0I7ooZP005goo
000MOol00`00Oomoo`0AOol00`00Oomoo`09Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`0GOol4003oOoogOol00`0OOomoo`1TOonZ000GOol001eoo`03001oogoo011oo`03001oo`0000Yo
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo01Moo`03001oogoo0?moooMoo`0301moogoo
06EoojX001Moo`007Goo00<007ooOol03goo00D007ooOomoo`0000Uoo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo01Moo`03001oogoo0?moooMoo`0301moogoo00Eoo`03O01oogoo05eoojX0
01Moo`007Goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol027oo0`0037oo00<007ooOol0ogoomWoo00<07gooOol01Goo00=l07oo
Ool0GWooZP005goo000KOol3000MOol30005Ool00`00Oomoo`02Ool00`00Oomoo`07Ool01@00Oomo
ogoo00002goo00<007ooOol0ogoomWoo00<07gooOol01Goo00=l07ooOol0Egoo/@005goo000MOol0
0`00Oomoo`0MOol00`00Oomoo`04Ool40004Ool500000goo001oo`02Ool00`00Oomoo`09Ool00`00
Oomoo`3oOooeOol00`0OOomoo`05Ool00g`0Oomoo`1HOol00`00Oomoo`2WOol7000GOol005=oo`<0
00aoo`03001oogoo0?moooEoo`0301moogoo00Eoo`03O01oogoo05Qoo`03001oogoo0:Moo`L001Mo
o`00DWoo00D007ooOomoo`0000]oo`03001oogoo0?moooAoo`0301moogoo00Eoo`03O01oogoo05Uo
o`03001oogoo0:Moo`L001Moo`00DWoo00D007ooOomoo`0000]oo`03001oogoo0?mooo=oo`0301mo
ogoo00Ioo`03O01oogoo05Uoo`03001oogoo0:Moo`L001Moo`00Dgoo0`0037oo00<007ooOol0ogoo
lgoo00<07gooOol0HWoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOoobOol00`0OOomo
o`1SOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?mooo9oo`0301moogoo06=oo`03001o
ogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoolGoo00<07gooOol0I7oo00<007ooOol0Ygoo1`00
5goo001ROol00`00Oomoo`3oOoo`Ool00`0OOomoo`06Ool00g`0Oomoo`1LOol00`00Oomoo`2WOol7
000GOol0069oo`03001oogoo0?mooo1oo`0301moogoo00Eoo`03O01oogoo05eoo`03001oogoo0:Mo
o`L001Moo`00HWoo00<007ooOol0ogookgoo00<07gooOol01Woo00=l07ooOol0GGoo00<007ooOol0
Ygoo1`005goo001ROol00`00Oomoo`3oOoo_Ool00`0OOomoo`05Ool00g`0Oomoo`1NOol00`00Oomo
o`2WOol7000GOol0069oo`03001oogoo0?moonioo`0301moogoo00Eoo`03O01oogoo05moo`03001o
ogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogookWoo00<07gooOol01Goo00=l07ooOol0Ggoo00<0
07ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOoo]Ool00`0OOomoo`1XOol00`00Oomoo`2WOol7
000GOol0069oo`03001oogoo0?mooneoo`0301moogoo06Qoo`03001oogoo0:Moo`L001Moo`00HWoo
00<007ooOol0ogook7oo00<07gooOol0JGoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3o
Ooo/Ool00`0OOomoo`1YOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?moon]oo`0301mo
ogoo00Eoo`03O01oogoo069oo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoojWoo00<0
7gooOol01Woo00=l07ooOol0HWoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOooZOol0
0`0OOomoo`05Ool00g`0Oomoo`1SOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?moonUo
o`0301moogoo00Ioo`03O01oogoo06=oo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoo
j7oo00<07gooOol01goo00=l07ooOol0Hgoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3o
OooXOol00`0OOomoo`06Ool00g`0Oomoo`1TOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo
0?moonMoo`0301moogoo00Ioo`03O01oogoo06Eoo`03001oogoo0:Moo`L001Moo`00HWoo00<007oo
Ool0ogooiWoo00<07gooOol0Kgoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOooVOol0
0`0OOomoo`1_Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo00Yoo`0301moogoo0?moomQo
o`0301moogoo071oo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol02goo0P0Oogooegoo00<0
7gooOol0LGoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`0=Ool00`0OOomoo`3oOooDOol0
0`0OOomoo`06Ool00g`0Oomoo`1XOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo00ioo`03
01moogoo0?moom9oo`0301moogoo00Ioo`03O01oogoo06Uoo`03001oogoo0:Moo`L001Moo`00HWoo
00<007ooOol03goo0P0OogoodGoo00<07gooOol01goo00=l07ooOol0JGoo00<007ooOol0BWoo1`00
0Woo0`000Woo0`000goo100017oo1@001Goo10001Woo10000Woo1`0017oo10000goo0`000Woo0`00
3Goo1`005goo001ROol3000AOol00`0OOomoo`3oOoo>Ool00`0OOomoo`06Ool00g`0Oomoo`1ZOol0
0`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo
00aoo`L001Moo`00HWoo00<007ooOol04Woo00<07gooOol0ogooc7oo00<07gooOol01Woo00=l07oo
Ool0Jgoo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol00goo0P0017oo00<007ooOol027oo
00<007ooOol01Goo00<007ooOol01goo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo
00D007ooOomoo`0000Aoo`03001oogoo00aoo`L001Moo`00HWoo00<007ooOol04goo0P0Oogooc7oo
00<07gooOol01Woo00=l07ooOol0Jgoo00<007ooOol0Bgoo00@007ooOol000Moo`8000Aoo`03001o
ogoo00Qoo`03001oogoo00Eoo`H000Aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009o
o`05001oogooOol00004Ool00`00Oomoo`0<Ool7000GOol0069oo`03001oogoo01Eoo`0301moogoo
0?moolQoo`0301moogoo07Eoo`03001oogoo04]oo`@000Ioo`04001oogoo0004Ool01000Oomoogoo
0P0017oo0P001Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol017oo
00<007ooOol00Woo00@007ooOomoo`8000=oo`03001oogoo00aoo`L001Moo`00HWoo00<007ooOol0
5Woo00<07gooOol0ogooaWoo00<07gooOol0MWoo00<007ooOol0Bgoo00H007ooOol007oo0002Ool3
0002Ool30003Ool300000goo001oo`02Ool2000017oo0000000017oo10000goo1`000goo0`001goo
10000goo0P0000Aoo`00000000moo`L001Moo`00HWoo00<007ooOol05goo0P0OogooaWoo00<07goo
Ool0MWoo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol09Woo00<007ooOol0:goo1`005goo
001ROol00`00Oomoo`0IOol00`0OOomoo`3oOoo2Ool00`0OOomoo`1gOol00`00Oomoo`1:Ool7000X
Ool00`00Oomoo`0[Ool7000GOol0069oo`03001oogoo01Yoo`0301moogoo0?mool1oo`0301moogoo
00Moo`03O01oogoo06ioo`03001oogoo08=oo`03001oogoo025oo`L001Moo`00HWoo00<007ooOol0
6goo0P0Oogoo_goo00<07gooOol01goo00=l07ooOol0Kgoo00<007ooOol0Pgoo00<007ooOol08Goo
1`005goo001ROol3000MOol00`0OOomoo`3oOonlOol00`0OOomoo`07Ool00g`0Oomoo`1_Ool00`00
Oomoo`2WOol7000GOol0069oo`03001oogoo01ioo`0301moogoo0?mookYoo`0301moogoo00Moo`03
O01oogoo071oo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol07goo0P0Oogoo^Goo00<07goo
Ool01goo00=l07ooOol0LGoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`0QOol00`0OOomo
o`3oOoneOol00`0OOomoo`08Ool00g`0Oomoo`1aOol00`00Oomoo`0<Ool7O005Ool7O005Ool7O005
Ool7O01`Ool7000GOol0069oo`03001oogoo029oo`0301moogoo0?mook=oo`0301moogoo07eoo`03
001oogoo0:Moo`L001Moo`00HWoo00<007ooOol08goo0P0Oogoo/goo00<07gooOol0OGoo00<007oo
Ool0Ygoo1`005goo001ROol3000UOol00`0OOomoo`3oOon_Ool00`0OOomoo`1nOol00`00Oomoo`2W
Ool7000GOol0069oo`03001oogoo02Ioo`0301moogoo0?moojeoo`0301moogoo07moo`03001oogoo
0:Moo`L001Moo`00HWoo00<007ooOol09goo0P0Oogoo[7oo00<07gooOol027oo00=l07ooOol0MGoo
00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`0YOol00`0OOomoo`3oOonYOol00`0OOomoo`07
Ool00g`0Oomoo`1fOol00`00Oomoo`2WOol7000GOol0069oo`<002Yoo`0301moogoo0?moojMoo`03
01moogoo00Qoo`03O01oogoo07Ioo`03001oogoo04aoo`@000Aoo`D000=oo`L0009oo`<0009oo`<0
00=oo`@003=oo`L001Moo`00HWoo00<007ooOol0:goo0P0OogooYWoo00<07gooOol027oo00=l07oo
Ool0Mgoo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01goo00<007oo
Ool017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo031oo`L001Moo`00HWoo00<0
07ooOol0;Goo00<07gooOol0ogooXWoo00<07gooOol02Goo00=l07ooOol0Mgoo00<007ooOol0Bgoo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo
00D007ooOomoo`0003Moo`L001Moo`00HWoo00<007ooOol0;Woo00<07gooOol0ogooXGoo00<07goo
Ool027oo00=l07ooOol0N7oo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool01goo00<007ooOol017oo00<007ooOol00Woo00@007ooOomoo`H0039oo`L001Moo`00HWoo0`00
;goo0P0OogooX7oo00<07gooOol0Q7oo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol00Woo
0P0027oo00<007ooOol017oo0P000goo00D007ooOomoo`0000Aoo`03001oogoo031oo`L001Moo`00
HWoo00<007ooOol0<Goo00<07gooOol0ogooW7oo00<07gooOol0QGoo00<007ooOol0Bgoo00<007oo
Ool00Woo00@007ooOomoo`800004Ool000000003Ool30005Ool2000017oo000000001Goo1000<goo
1`005goo001ROol3000bOol00`0OOomoo`3oOonKOol00`0OOomoo`25Ool00`00Oomoo`1;Ool00`00
Oomoo`02Ool00`00Oomoo`1DOol7000GOol0069oo`03001oogoo03=oo`807omooiYoo`0301moogoo
08Ioo`03001oogoo04Yoo`<0009oo`<005Eoo`L001Moo`00HWoo0`00=Goo00<07gooOol0ogooUWoo
00<07gooOol027oo00=l07ooOol0O7oo00<007ooOol0Ggoo00<007ooOol0AGoo1`005goo000JOol7
0004Ool20007Ool00`00Oomoo`03Ool00`00Oomoo`03Ool70003Ool4000JOol00`00Oomoo`0fOol0
0`0OOomoo`3oOonDOol00`0OOomoo`08Ool00g`0Oomoo`1mOol00`00Oomoo`1OOol00`00Oomoo`15
Ool7000GOol001eoo`03001oogoo00Eoo`8000Qoo`05001oogooOol00009Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`0GOol3000gOol201ooOonCOol00`0OOomoo`09Ool00g`0Oomoo`1m
Ool00`00Oomoo`2WOol7000GOol001eoo`03001oogoo011oo`03001oo`0000Yoo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo01Moo`03001oogoo03Uoo`0301moogoo0?moohmoo`0301moogoo
00Uoo`03O01oogoo07ioo`03001oogoo0:Moo`L001Moo`007Goo00<007ooOol04Goo00<007ooOol0
2Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol05goo1000>Goo00<07gooOol0ogooSGoo
00<07gooOol02Goo00=l07ooOol0Ogoo00<007ooOol0Ygoo1`005goo000MOol00`00Oomoo`0@Ool0
0`00Ool0000:Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0GOol00`00Oomoo`0kOol2
01ooOon=Ool00`0OOomoo`09Ool00g`0Oomoo`1oOol00`00Oomoo`2WOol7000GOol001eoo`03001o
ogoo00moo`05001oogooOol00009Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0GOol0
0`00Oomoo`0mOol00`0OOomoo`3oOon9Ool00`0OOomoo`2<Ool00`00Oomoo`2WOol7000GOol001eo
o`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo00Qoo`<000aoo`03001oogoo03ioo`0301moogoo0?moohMoo`0301moogoo08eoo`03
001oogoo0:Moo`L001Moo`006goo0`007Goo0`001Goo00<007ooOol00Woo00<007ooOol01goo00D0
07ooOomoo`0000]oo`03001oogoo03moo`807omoohIoo`0301moogoo08ioo`03001oogoo0:Moo`L0
01Moo`007Goo00<007ooOol07Goo00<007ooOol017oo100017oo1@0000=oo`00Ool00Woo00<007oo
Ool02Goo00<007ooOol0@Goo00<07gooOol0ogooPWoo00<07gooOol02Goo00=l07ooOol0Pgoo00<0
07ooOol0Ygoo1`005goo001BOol4000<Ool00`00Oomoo`12Ool00`0OOomoo`3oOon0Ool00`0OOomo
o`09Ool00g`0Oomoo`24Ool00`00Oomoo`2WOol7000GOol0059oo`03001oogoo00eoo`03001oogoo
04=oo`807omoogmoo`0301moogoo00Uoo`03O01oogoo08Eoo`03001oogoo0:Moo`L001Moo`00Dgoo
00<007ooOol037oo00<007ooOol0AGoo00<07gooOol0ogooNgoo00<07gooOol02Woo00=l07ooOol0
QGoo00<007ooOol0Ygoo1`005goo001DOol3000;Ool00`00Oomoo`16Ool00`0OOomoo`3oOomiOol0
0`0OOomoo`0:Ool00g`0Oomoo`26Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo04Moo`80
7omoogQoo`0301moogoo00]oo`03O01oogoo08Ioo`03001oogoo0:Moo`L001Moo`00HWoo00<007oo
Ool0BGoo00<07gooOol0ogooMGoo00<07gooOol0U7oo00<007ooOol0Ygoo1`005goo001ROol00`00
Oomoo`1:Ool201ooOomdOol00`0OOomoo`2EOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo
04aoo`807omoog5oo`0301moogoo09Ioo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0CWoo
00<07gooOol0ogooKGoo00<07gooOol0Ugoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`1?
Ool201ooOom/Ool00`0OOomoo`0;Ool00g`0Oomoo`2:Ool00`00Oomoo`2WOol7000GOol0069oo`03
001oogoo055oo`0301moogoo0?moofQoo`0301moogoo00]oo`03O01oogoo08]oo`03001oogoo0:Mo
o`L001Moo`00HWoo00<007ooOol0DWoo0P0OogooIgoo00<07gooOol02goo00=l07ooOol0S7oo00<0
07ooOol0Ygoo1`005goo001ROol00`00Oomoo`1DOol201ooOomTOol00`0OOomoo`0;Ool00g`0Oomo
o`2=Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo05Ioo`0301moogoo0?moof1oo`0301mo
ogoo00]oo`03O01oogoo08ioo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0Egoo0P0Oogoo
Ggoo00<07gooOol0WGoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`1IOol201ooOomKOol2
01nPOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo05]oo`0301moogoo0?mooeMoo`0301mo
ogoo0:1oo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0G7oo0P0OogooEWoo00<07gooOol0
XGoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`1NOol201ooOomCOol00`0OOomoo`0=Ool0
0g`0Oomoo`2BOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo061oo`0301moogoo0?moodmo
o`0301moogoo00eoo`03O01oogoo09=oo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0HGoo
0P0OogooCWoo00<07gooOol03Goo00=l07ooOol0U7oo00<007ooOol0Ygoo1`005goo001ROol00`00
Oomoo`1SOol00`0OOomoo`3oOom:Ool00`0OOomoo`0=Ool00g`0Oomoo`2EOol00`00Oomoo`2WOol7
000GOol0069oo`03001oogoo06Aoo`807omoodQoo`807`moo`03O01oogoo09Ioo`03001oogoo0:Mo
o`L001Moo`00HWoo00<007ooOol0IWoo0P0OogooAGoo00<07gooOol0Z7oo00<007ooOol0Ygoo1`00
5goo001ROol00`00Oomoo`1XOol00`0OOomoo`3oOom1Ool00`0OOomoo`2YOol00`00Oomoo`2WOol7
000GOol0069oo`03001oogoo06Uoo`807omood1oo`0301moogoo0:Yoo`03001oogoo0:Moo`L001Mo
o`00HWoo00<007ooOol0Jgoo0P0Oogoo?Goo00<07gooOol03Goo00=l07ooOol0Vgoo00<007ooOol0
Ygoo1`005goo001ROol00`00Oomoo`1]Ool201ooOoliOol201l?Ool00g`0Oomoo`2LOol00`00Oomo
o`2WOol7000GOol0069oo`03001oogoo06moo`807omoocIoo`0301moogoo00ioo`03O01oogoo09eo
o`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0LGoo0P0Oogoo<goo00<07gooOol03goo00=l
07ooOol0WGoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`1cOol201ooOol`Ool00`0OOomo
o`0?Ool00g`0Oomoo`2NOol00`00Oomoo`2WOol7000GOol0069oo`<007Eoo`807omoobaoo`807a5o
o`03O01oogoo09moo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0Mgoo0P0Oogoo:Goo00<0
7gooOol0/goo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`1iOol201ooOolVOol00`0OOomo
o`2dOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo07]oo`807omoob9oo`807kMoo`03001o
ogoo0:Moo`L001Moo`00HWoo00<007ooOol0OGoo0`0Oogoo7Woo00<07gooOol04Goo00=l07ooOol0
Xgoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`20Ool201ooOolKOol00`0OOomoo`0AOol0
0g`0Oomoo`2TOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo089oo`807omooaMoo`807a9o
o`9l0:Moo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0Q7oo0P0Oogoo57oo00<07gooOol0
4Goo00=l07ooOol0Ygoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`26Ool201ooOolAOol0
0`0OOomoo`0AOol00g`0Oomoo`2XOol00`00Oomoo`2WOol7000GOol0069oo`<008Qoo`807omoo`eo
o`807kmoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0RWoo0P0Oogoo2Goo0P0O`Goo00<0
07ooOol0BWoo1`000Woo0`000Woo0`000goo100017oo1@001Goo10001Woo10000Woo1`0017oo1000
0goo0`000Woo0`003Goo1`005goo001ROol00`00Oomoo`2<Ool201ooOol6Ool00`0OOomoo`0BOol0
0g`0Oomoo`2/Ool00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`03001oogoo00aoo`L001Moo`00HWoo00<007ooOol0SWoo0P0Oogoo0Woo0P0O57oo00=l07oo
Ool0[Goo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol00goo0P0017oo00<007ooOol027oo
00<007ooOol01Goo00<007ooOol01goo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo
00D007ooOomoo`0000Aoo`03001oogoo00aoo`L001Moo`00HWoo00<007ooOol0T7oo0`0Oo7oo0P0O
5Goo00=l07ooOol0[Woo00<007ooOol0Bgoo00@007ooOol000Moo`8000Aoo`03001oogoo00Qoo`03
001oogoo00Eoo`H000Aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`05001oogoo
Ool00004Ool00`00Oomoo`0<Ool7000GOol0069oo`03001oogoo09=oo`807oUoo`0301moogoo01=o
o`9l0;5oo`03001oogoo04]oo`@000Ioo`04001oogoo0004Ool01000Oomoogoo0P0017oo0P001Woo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo
00@007ooOomoo`8000=oo`03001oogoo00aoo`L001Moo`00HWoo0`00UGoo0P0OmGoo0P0O5Goo00=l
07ooOol0/Goo00<007ooOol0Bgoo00H007ooOol007oo0002Ool30002Ool30003Ool300000goo001o
o`02Ool2000017oo0000000017oo10000goo1`000goo0`001goo10000goo0P0000Aoo`00000000mo
o`L001Moo`00HWoo00<007ooOol0Ugoo0P0OlGoo0P0Obgoo00<007ooOol0Bgoo00<007ooOol00Woo
00<007ooOol09Woo00<007ooOol0:goo1`005goo001ROol00`00Oomoo`2IOol201o^Ool00`0OOomo
o`3;Ool00`00Oomoo`1:Ool7000XOol00`00Oomoo`0[Ool7000GOol0069oo`03001oogoo09]oo`80
7nYoo`807lioo`03001oogoo08=oo`03001oogoo025oo`L001Moo`00HWoo0`00WGoo0P0OiWoo0P0O
5goo00=l07ooOol0]Woo00<007ooOol0Pgoo00<007ooOol08Goo1`005goo001ROol00`00Oomoo`2O
Ool201oROol201lGOol2O02iOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0:5oo`<07meo
o`807aMoo`9l0;]oo`03001oogoo0:Moo`L001Moo`00HWoo0`00Y7oo0`0OfGoo00<07gooOol05Woo
00=l07ooOol0^goo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`2WOol201oEOol201oGOol0
0`00Oomoo`0<Ool^01m]Ool7000GOol0069oo`03001oogoo0:Uoo`<07m1oo`807mUoo`03001oogoo
0:Moo`L001Moo`00HWoo0`00[7oo0`0Obgoo0P0Ofgoo00<007ooOol0Ygoo1`005goo001ROol00`00
Oomoo`2_Ool301o6Ool201lJOol00g`0Oomoo`30Ool00`00Oomoo`2WOol7000GOol0069oo`<00;9o
o`807l9oo`807aYoo`9l0<=oo`03001oogoo0:Moo`L001Moo`0097oo10001Woo0P001Woo10001Goo
10001Goo100017oo1`002goo00<007ooOol0]7oo0`0O_Goo0P0O6Woo0W`0aGoo00<007ooOol0Ygoo
1`005goo000SOol00`00Oomoo`02Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00aoo`<00;Moo`<07kMo
o`<07a]oo`03O01oogoo0<Eoo`03001oogoo0:Moo`L001Moo`008goo00<007ooOol00Woo00<007oo
Ool02Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04
Ool00`00Oomoo`0<Ool00`00Oomoo`2jOol301naOol301oVOol00`00Oomoo`1:Ool40007Ool50004
Ool40005Ool40005Ool50002Ool7000YOol7000GOol002=oo`03001oogoo009oo`03001oogoo00Yo
o`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol017oo00<0
07ooOol037oo1000_7oo0P0O[Goo0P0OjGoo00<007ooOol0Bgoo00<007ooOol01Woo00D007ooOomo
o`0000Aoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00<007ooOol0
17oo00<007ooOol0:Woo1`005goo000SOol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02
Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00aoo`03
001oogoo0;moo`<07jMoo`<07aioo`03O01oogoo0<Yoo`03001oogoo04]oo`03001oogoo00Ioo`05
001oogooOol00004Ool00`00Oomoo`05Ool00`00Oomoo`07Ool01@00Oomoogoo00001Woo00<007oo
Ool0:Woo1`005goo000SOol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo0<9o
o`@07j1oo`<07b1oo`03O01oogoo0<]oo`03001oogoo04]oo`04001oogoo0006Ool40004Ool60002
Ool00`00Oomoo`08Ool40006Ool00`00Oomoo`0ZOol7000GOol002=oo`03001oogoo009oo`03001o
ogoo00Yoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol0
17oo00<007ooOol037oo00<007ooOol0aWoo100OVWoo0P0O8Goo0W`0cWoo00<007ooOol0Bgoo1000
1Goo00D007ooOomoo`0000Aoo`03001oogoo009oo`05001oogooOol00003Ool20003Ool01@00Oomo
ogoo00001Woo00<007ooOol0:Woo1`005goo000SOol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00
Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo009oo`<000ioo`03
001oogoo0<Yoo`D07i9oo`<07b5oo`9l0=1oo`03001oogoo04]oo`06001oogoo001oo`0017oo0`00
1Woo10001Goo0`0000=oo`00Ool00goo0`001goo00<007ooOol0:Woo1`005goo000TOol4000>Ool4
0005Ool40005Ool40007Ool00`00Oomoo`0<Ool00`00Oomoo`3?Ool401n:Ool401ofOol00`00Oomo
o`1;Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomoo`0ZOol7000GOol0069oo`03001oogoo
0==oo`D07h5oo`@07oYoo`03001oogoo04Yoo`L002Uoo`03001oogoo02Yoo`L001Moo`00HWoo00<0
07ooOol0f7oo100ON7oo1@0O9goo00=l07ooOol0e7oo00<007ooOol0N7oo0`00;7oo1`005goo001R
Ool00`00Oomoo`3LOol501m_Ool401lZOol2O03GOol00`00Oomoo`2WOol7000GOol0069oo`03001o
ogoo0>5oo`H07fAoo`D07baoo`9l0=Uoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0igoo
1@0OFWoo1@0O;goo0W`0fgoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3/Ool601m@Ool4
01ooOolBOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?9oo`P07d5oo`L07omooaIoo`03
001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0nWoo1`0O;Woo300O>Goo0W`0hGoo00<007ooOol0
Ygoo1`005goo001ROol00`00Oomoo`3oOol2Ool^01m3Ool2O03SOol00`00Oomoo`2WOol7000GOol0
069oo`03001oogoo0?moog5oo`9l0>Eoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoo
ogooFGoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOoooOomIOol00`00Oomoo`2WOol7
000GOol0069oo`03001oogoo0?moof]oo`03O01oogoo0>Yoo`03001oogoo0:Moo`L001Moo`00HWoo
00<007ooOol0ogooJGoo0W`0kGoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOomWOol2
O03_Ool00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?moofIoo`03O01oogoo0>moo`03001o
ogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogooogooFGoo00<007ooOol0Ygoo1`005goo001ROol0
0`00Oomoo`3oOoooOomIOol00`00Oomoo`2WOol7000GOol0069oo`03001oogoo0?moof5oo`03O01o
ogoo0?Aoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogooGgoo0W`0mgoo00<007ooOol0
Ygoo1`005goo001ROol00`00Oomoo`3oOomMOol2O03iOol00`00Oomoo`2WOol7000GOol0069oo`03
001oogoo0?mooeaoo`03O01oogoo0?Uoo`03001oogoo0:Moo`L001Moo`00HWoo00<007ooOol0ogoo
ogooFGoo00<007ooOol0Ygoo1`005goo001ROol00`00Oomoo`3oOoooOomIOol00`00Oomoo`2WOol7
000GOol0069oo`03001oogoo0?mooeMoo`03O01oogoo0?ioo`03001oogoo0:Moo`L001Moo`00HWoo
00<007ooOol0ogooEGoo0W`0ogoo0Woo00<007ooOol0Ygoo00<007ooOol06goo001ROol00`00Oomo
o`3oOomCOol2O03oOol4Ool00`00Oomoo`2WOol00`00Oomoo`0KOol0069oo`03001oogoo0?mooe9o
o`03O01oogoo0?moo`Aoo`03001oogoo0:Moo`03001oogoo01]oo`00HWoo00<007ooOol0ogooogoo
FGoo00<007ooOol0Ygoo00<007ooOol06goo001ROol00`00Oomoo`3oOoooOomIOol00`00Oomoo`2W
Ool00`00Oomoo`0KOol0069oo`<00?moodaoo`03O01oogoo0?moo`Yoo`03001oogoo0:Moo`03001o
ogoo01]oo`00HWoo00<007ooOol0ogooBgoo00=l07ooOol0ogoo2gooZ`007Goo001ROol00`00Oomo
o`3oOom9Ool2O03oOooFOol0069oo`03001oogoo0?moodQoo`03O01oogoo0?moomIoo`00HWoo00<0
07ooOol0ogooAgoo00=l07ooOol0ogooegoo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03
001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogoo@Woo00=l07ooOol0ogoog7oo001ROol0
0`00Oomoo`3oOom1Ool00g`0Oomoo`3oOooMOol0069oo`03001oogoo0?moocmoo`9l0?moon1oo`00
HWoo0`00ogoo?Woo00=l07ooOol0ogooh7oo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03
001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`3o
OoliOol00g`0Oomoo`3oOooUOol0069oo`<00?moocMoo`9l0?moonQoo`00HWoo00<007ooOol0ogoo
=Goo0W`0ogoojWoo001ROol00`00Oomoo`3oOoldOol00g`0Oomoo`3oOooZOol0069oo`03001oogoo
0?mooomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol3003oOoooOoooOolROol0
069oo`03001oogoo0?moobmoo`03O01oogoo0?moonmoo`00HWoo00<007ooOol0ogoo;Goo0W`0ogoo
lWoo001ROol3003oOol[Ool2O03oOoodOol0069oo`03001oogoo0?moobYoo`03O01oogoo0?moooAo
o`00HWoo0`00ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo
0?mooomooomoob9oo`00HWoo0`00ogoo9Goo00=l07ooOol0ogoonGoo000fOol40006Ool20006Ool4
0004Ool7000;Ool00`00Oomoo`3oOolSOol2O03oOoolOol003Eoo`03001oogoo009oo`03001oogoo
00=oo`8000Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00aoo`<00?moob9oo`03O01o
ogoo0?moooaoo`00=Goo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol0
17oo00<007ooOol037oo1000ogoo7goo0W`0ogooogoo000eOol00`00Oomoo`02Ool00`00Oomoo`0:
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`3oOoooOoooOolROol0
03Eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
00aoo`03001oogoo0?mooomooomoob9oo`00=Goo00<007ooOol00Woo00<007ooOol02Woo00<007oo
Ool00Woo00<007ooOol017oo00<007ooOol037oo00<007ooOol0ogoo6goo00=l07ooOol0ogooogoo
17oo000eOol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00
Oomoo`0<Ool00`00Oomoo`3oOolIOol2O03oOoooOol7Ool003Eoo`03001oogoo009oo`03001oogoo
00Yoo`03001oogoo009oo`03001oogoo009oo`<000ioo`03001oogoo0?mooaMoo`9l0?mooomoo`Uo
o`00=Woo10003Woo10001goo00<007ooOol037oo00<007ooOol0ogoo5Woo00=l07ooOol0ogooogoo
2Goo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mooomooomoob9oo`00HWoo
00<007ooOol0ogoo47oo00=l07ooOol0ogooogoo3goo001ROol00`00Oomoo`3oOol>Ool2O03oOooo
OolBOol0069oo`03001oogoo0?moo`aoo`9l0?mooomooaAoo`00HWoo00<007ooOol0ogoo2goo00=l
07ooOol0ogooogoo57oo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?mooomo
oomoob9oo`00HWoo00<007ooOol0ogoo1Goo0W`0ogooogoo6goo001ROol00`00Oomoo`3oOol3Ool2
O03oOoooOolMOol0069oo`03001oogoo0?moo`5oo`9l0?mooomooamoo`00HWoo00<007ooOol0ogoo
ogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0?Uoo`9l0?mooomo
obIoo`00HWoo00<007ooOol0mgoo0W`0ogooogoo:7oo001ROol00`00Oomoo`3eOol2O03oOoooOolZ
Ool0069oo`03001oogoo0?mooomooomoob9oo`00HWoo00<007ooOol0ogooogooogoo8Woo001ROol0
0`00Oomoo`3^Ool2O03oOoooOolaOol0069oo`03001oogoo0>aoo`9l0?mooomooc=oo`00HWoo00<0
07ooOol0jWoo0W`0ogooogoo=Goo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo
0>Aoo`03O01oogoo0?mooomoocYoo`00HWoo00<007ooOol0hWoo0W`0ogooogoo?Goo001ROol00`00
Oomoo`3POol2O03oOoooOoloOol0069oo`03001oogoo0=moo`03O01oogoo0?mooomoocmoo`00HWoo
00<007ooOol0ogooogooogoo8Woo001ROol00`00Oomoo`3HOol2O03oOoooOom7Ool0069oo`03001o
ogoo0=Eoo`=l0?mooomoodUoo`00HWoo00<007ooOol0dgoo0W`0ogooogooC7oo001ROol3003<Ool2
O03oOoooOomCOol0069oo`03001oogoo0<Yoo`9l0?mooomooeEoo`00HWoo00<007ooOol0b7oo0W`0
ogooogooEgoo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001oogoo0<1oo`=l0?mooomo
oeioo`00HWoo00<007ooOol0_7oo17`0ogooogooHGoo001ROol00`00Oomoo`3oOoooOoooOolROol0
069oo`03001oogoo0;Aoo`=l0?mooomoofYoo`00HWoo00<007ooOol0/7oo17`0ogooogooKGoo001R
Ool3002ZOol2O03oOoooOomeOol0069oo`03001oogoo0:Moo`=l0?mooomoogMoo`00HWoo00<007oo
Ool0YGoo0W`0ogooogooNWoo001ROol00`00Oomoo`2MOol3O03oOoooOon1Ool0069oo`03001oogoo
09Uoo`Al0?mooomoohAoo`00HWoo00<007ooOol0TGoo0g`0ogooogooSGoo001ROol3002=Ool4O03o
OoooOon@Ool0069oo`03001oogoo08Eoo`=l0?mooomooiUoo`00HWoo00<007ooOol02Woo0g`0M7oo
17`0ogooogooW7oo001ROol00`00Oomoo`0=Ool4O01XOol3O03oOoooOonUOol0069oo`<001Ioo`9l
05Moo`03O01oogoo00=oo`Al0?mooomoojQoo`00HWoo00<007ooOol067oo0g`0CWoo1W`0ogooogoo
/Woo001ROol00`00Oomoo`0KOol2O005Ool3O00iOol7O03oOoooOonlOol0069oo`<002Eoo`Al00Eo
o`=l01Moo`El00Eoo`Ml0?mooomoolQoo`00HWoo00<007ooOol0<Goo17`01Goo1g`01Goo0W`0ogoo
ogoofGoo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`<00?mooomooomoob9oo`00HWoo00<0
07ooOol0ogooogooogoo8Woo001ROol3003oOoooOoooOolROol0069oo`03001oogoo0?mooomooomo
ob9oo`00HWoo0`00ogooogooogoo8Woo001ROol00`00Oomoo`3oOoooOoooOolROol0069oo`03001o
ogoo0?mooomooomoob9oo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00
ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOooo
OoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomo
ohMoo`00ogoo:goo10001Goo10000goo0`000Woo0`0017oo10000Woo1`000Woo0`000Woo0`000goo
0`0000=oo`0000000goo10001Goo0`0000=oo`0000000Woo1@0037oo1`000Woo0`000Woo0`0017oo
100017oo1@000Woo0P000Woo0`0017oo1000ogooagoo003oOolZOol00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo009o
o`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol00003Ool20003Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000goo0P000goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol017oo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000=oo`03001oogoo009oo`04
001oogoo0005Ool00`00Oomoo`02Ool00`00Oomoo`3oOoo4Ool00?moobUoo`03001oogoo00Moo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`04
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`05001oogooOol00004
Ool00`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`05Ool01@00Oomoogoo000017oo00<007oo00001Woo00<007ooOol0ogoobGoo003o
OolYOol00`00Oomoo`07Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol00Woo00<0
07ooOol01goo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol0
0004Ool01@00Oomoogoo000017oo00<007ooOol00Woo10003goo00<007ooOol017oo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol01Woo100017oo0`001Woo1P00ogooaWoo001WOol3002nOol0
0`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoogoo0P000goo00<007ooOol00Woo00<007ooOol0
1goo00<007ooOol017oo0P000goo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01@00Oomo
ogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00aoo`03001oogoo00Aoo`8000=oo`03001o
ogoo009oo`03001oogoo00Eoo`05001oogooOol00004Ool01000Oomoo`001Goo00<007ooOol00Woo
00<007ooOol0ogooa7oo001XOol00`00Oomoo`2mOol00`00Oomoo`03Ool00`00Oomoo`02Ool40003
Ool2000017oo000000000goo1`000goo0`001Goo0P0000Aoo`00000000=oo`8000=oo`8000Aoo`@0
00=oo`8000=oo`8000Aoo`D000aoo`<000Eoo`800004Ool000000003Ool70004Ool30005Ool00`00
Ool000020005Ool4003oOoo7Ool006Qoo`03001oogoo0;ioo`04001oogooOol2000FOol00`00Oomo
o`1GOol00`00Oomoo`0>Ool00`00Oomoo`3oOooBOol005Yoo`H000Aoo`<00003Ool007oo0<1oo`<0
0003Ool007oo01Eoo`03001oogoo05Moo`03001oogoo00ioo`03001oogoo0?moom9oo`00Fgoo00<0
07ooOol00Woo00@007ooOol000=oo`800>Ioo`03001oogoo03aoo`03001oogoo01ioo`800?moomAo
o`00Fgoo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo0>Aoo`03001oogoo03aoo`03001o
ogoo0?moooAoo`00Fgoo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo0?mooomooomooaao
o`00Fgoo1@000goo00@007ooOomoo`800?mooomooomooaioo`00Fgoo00<007ooOol00Woo00@007oo
Oomoo`<00003Ool000000?mooomooomooaeoo`00Fgoo00<007ooOol00Woo00<007ooOol0ogooogoo
ogoo97oo001JOol6003oOoooOoooOolWOol00?mooomooomoohMoo`00ogooogooogooQgoo003oOooo
OoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomo
ohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo
003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mo
oomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogoo
ogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7
Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00001\
\>"],
  ImageRangeCache->{{{0, 899}, {440.375, 0}} -> {-1.06477, -0.648943, \
0.00442081, 0.00442081}, {{21.9375, 700.563}, {429.875, 10.4375}} -> \
{-0.483369, -11.4076, 0.00650107, 0.0443477}, {{700.563, 870.188}, {321.938, \
152.313}} -> {-14.9684, -2.19473, 0.0318352, 0.0265294}, {{714.688, 761.813}, \
{304.938, 248.375}} -> {-15.9492, -11.8048, 0.0334221, 0.108156}, {{714.688, \
761.813}, {225.813, 169.25}} -> {-15.9492, -17.51, 0.0334221, 0.108156}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[49]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs2, 1, 180, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Ingestion\>", 
      IntakeType \[Rule] \ "\<MultiInputs\>", \ 
      ShowReport \[Rule] \ "\<GraphicReport\>"]\)], "Input",
  CellLabel->"In[50]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.567748 0.0581395 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .10263 -46.5 -6.6875 ]
[-0.0125 .10263 0 6.6875 ]
[-0.0125 .21891 -46.5 -6.6875 ]
[-0.0125 .21891 0 6.6875 ]
[-0.0125 .33519 -40 -6.28125 ]
[-0.0125 .33519 0 6.28125 ]
[-0.0125 .45147 -28 -6.28125 ]
[-0.0125 .45147 0 6.28125 ]
[-0.0125 .56775 -10 -6.28125 ]
[-0.0125 .56775 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10263 m
.00625 .10263 L
s
gsave
-0.0125 .10263 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .21891 m
.00625 .21891 L
s
gsave
-0.0125 .21891 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .33519 m
.00625 .33519 L
s
gsave
-0.0125 .33519 -101 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0001) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .45147 m
.00625 .45147 L
s
gsave
-0.0125 .45147 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .56775 m
.00625 .56775 L
s
gsave
-0.0125 .56775 -71 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .0491 m
.00375 .0491 L
s
0 .06552 m
.00375 .06552 L
s
0 .07539 m
.00375 .07539 L
s
0 .08247 m
.00375 .08247 L
s
0 .08799 m
.00375 .08799 L
s
0 .09252 m
.00375 .09252 L
s
0 .09636 m
.00375 .09636 L
s
0 .09969 m
.00375 .09969 L
s
0 .16537 m
.00375 .16537 L
s
0 .1818 m
.00375 .1818 L
s
0 .19167 m
.00375 .19167 L
s
0 .19875 m
.00375 .19875 L
s
0 .20427 m
.00375 .20427 L
s
0 .2088 m
.00375 .2088 L
s
0 .21264 m
.00375 .21264 L
s
0 .21597 m
.00375 .21597 L
s
0 .28165 m
.00375 .28165 L
s
0 .29808 m
.00375 .29808 L
s
0 .30795 m
.00375 .30795 L
s
0 .31503 m
.00375 .31503 L
s
0 .32055 m
.00375 .32055 L
s
0 .32508 m
.00375 .32508 L
s
0 .32892 m
.00375 .32892 L
s
0 .33225 m
.00375 .33225 L
s
0 .39793 m
.00375 .39793 L
s
0 .41436 m
.00375 .41436 L
s
0 .42423 m
.00375 .42423 L
s
0 .43131 m
.00375 .43131 L
s
0 .43683 m
.00375 .43683 L
s
0 .44136 m
.00375 .44136 L
s
0 .4452 m
.00375 .4452 L
s
0 .44853 m
.00375 .44853 L
s
0 .51421 m
.00375 .51421 L
s
0 .53064 m
.00375 .53064 L
s
0 .54051 m
.00375 .54051 L
s
0 .54759 m
.00375 .54759 L
s
0 .55311 m
.00375 .55311 L
s
0 .55764 m
.00375 .55764 L
s
0 .56147 m
.00375 .56147 L
s
0 .56481 m
.00375 .56481 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Multi) show
99.000 12.813 moveto
(Inputs) show
135.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .60332 m
.20509 .4928 L
.23623 .45929 L
.2498 .44471 L
.26149 .43333 L
.2713 .42544 L
.28154 .41937 L
.29128 .41572 L
.30107 .41377 L
.31022 .41304 L
.31516 .41293 L
.31957 .41294 L
.32783 .41316 L
.33536 .41348 L
.36608 .41499 L
.37752 .41546 L
.38897 .41586 L
.39525 .41603 L
.40077 .41616 L
.40617 .41627 L
.41107 .41635 L
.41625 .41641 L
.41893 .41643 L
.42177 .41645 L
.42469 .41646 L
.42742 .41647 L
.42984 .41646 L
.43243 .41646 L
.43704 .41643 L
.43933 .41641 L
.44182 .41639 L
.44613 .41633 L
.4501 .41626 L
.4594 .41603 L
.46754 .41577 L
.48465 .415 L
.49747 .41421 L
.51055 .41321 L
.53436 .41083 L
.55504 .40812 L
.57199 .40541 L
.60516 .39868 L
.65547 .38421 L
.69357 .36909 L
.72693 .35228 L
.75417 .33567 L
.77703 .31944 L
.7986 .30198 L
.8172 .28507 L
.83511 .26701 L
Mistroke
.85084 .24957 L
.86481 .23276 L
.87858 .21485 L
.89093 .19759 L
.9032 .17924 L
.9143 .16155 L
.92438 .14453 L
.93452 .12642 L
.94378 .10898 L
.95227 .09221 L
.9609 .07435 L
.96883 .05716 L
.97619 .04055 L
Mfstroke
0 0 1 r
[ ] 0 setdash
.02381 .34003 m
.20509 .36243 L
.30107 .37746 L
.33536 .38156 L
.36608 .38444 L
.37932 .38543 L
.39101 .38617 L
.41107 .38715 L
.42093 .38749 L
.42637 .38764 L
.4312 .38774 L
.43616 .38783 L
.43884 .38786 L
.44135 .38789 L
.44572 .38792 L
.44815 .38793 L
.45038 .38793 L
.4546 .38792 L
.45849 .38789 L
.46191 .38785 L
.46554 .3878 L
.46943 .38773 L
.47345 .38763 L
.48043 .38742 L
.48775 .38714 L
.49527 .38678 L
.50812 .38601 L
.52231 .3849 L
.53436 .38374 L
.57108 .37883 L
.58898 .37561 L
.60412 .37243 L
.65389 .35853 L
.69164 .34388 L
.72478 .32749 L
.75186 .31125 L
.77685 .29368 L
.79807 .27656 L
.8164 .25998 L
.83408 .24224 L
.84963 .22512 L
.86483 .20689 L
.87837 .1893 L
.89051 .17235 L
.90261 .15432 L
.91355 .13695 L
.92348 .12024 L
.9335 .10245 L
.94265 .08533 L
.9519 .06712 L
Mistroke
.9604 .04958 L
.96821 .03271 L
.97618 .01475 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[50]:=",
  ImageSize->{600, 294.25},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[50]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Ingestion\",ShowReport\[Rule] \"CompartmentContent\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, 1, t1, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Ingestion\>", IntakeType \[Rule] \ "\<Acute\>", 
      ShowReport \[Rule] \ "\<CompartmentContent\>"]\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \({qST[t1] \[Rule] \[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\), 
      qSI[t1] \[Rule] 0, 
      qB[t1] \[Rule] \(-1.1304757110749415`\)\ \
\[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\) + 
          1.1305100339163512`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ \
t1\) - 0.0008430013009328277`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t1\) + 0.0008086784595230427`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t1\), q\_2[t1] \[Rule] 
        0.03910973751024155`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\
\) - 0.33981323487325266`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) \
+ 0.013594728211984571`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) + 
          0.2871087691510265`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t1\), q\_3[
          t1] \[Rule] \(-0.000014153225097714162`\)\ \
\[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\) + 
          0.0010855582927336474`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\
\ t1\) - 0.04944636604452997`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t1\) + 0.04837496097689403`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ t1\
\), q\_4[t1] \[Rule] 
        0.18276023995711543`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\
\) - 0.42036825836560815`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t1\) \
+ 0.23761418467221967`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) - 
          0.00013697157675848022`\ \[ExponentialE]\^\(\(-0.14677556138819248`\
\)\ t1\) + 
          0.0001308053130315232`\ \
\[ExponentialE]\^\(\(-0.09296993648799633`\)\ t1\), 
      qURI[t1] \[Rule] \(-0.09138011997855733`\)\ \
\[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\) + 
          0.42036825836560815`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t1\) - 1.0293920155101854`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) \
+ 0.027334105688781352`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) - 
          0.2481078164099017`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t1\) + 0.9211775878442552`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ \
t1\), qULI[t1] \[Rule] 
        7.363502246805157`*^-9\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ \
t1\) - 0.0000129265688063678`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ \
t1\) + 0.000029664860096128653`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ \
t1\) - 0.0003282465000718857`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t1\) + 0.00031150084527987803`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t1\), qLLI[
          t1] \[Rule] \(-5.762740889949519`*^-10\)\ \
\[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\) + 
          0.000013145992681842941`\ \[ExponentialE]\^\(\(-2.8565990345907895`\
\)\ t1\) - 
          0.00006674593521628947`\ \
\[ExponentialE]\^\(\(-1.8866433975699939`\)\ t1\) + 
          0.00011797462752619218`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) - 
          0.0006286455152350866`\ \
\[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) + 
          0.0005642714065174299`\ \
\[ExponentialE]\^\(\(-0.09296993648799633`\)\ t1\), 
      qFEC[t1] \[Rule] 
        2.401143173180742`*^-11\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ \
t1\) - 4.745921741902702`*^-6\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ \
t1\) + 0.00003708107512016082`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ \
t1\) - 0.00011797462752619218`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ \
t1\) + 0.010454397036762347`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t1\) - 0.08919116974237154`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ t1\
\) + 0.0788224121557457`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\)}\
\)], "Output",
  CellLabel->"Out[51]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, 1, \ t1, Log[2]/8.0, 
      IntakeWay \[Rule] "\<Ingestion\>", IntakeType \[Rule] \ "\<Constant\>", 
      ShowReport \[Rule] \ "\<CompartmentContent\>"]\)], "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    \({qST[t1] \[Rule] \(\(0.04151678519477255`\)\(\[InvisibleSpace]\)\) - 
          0.04151678519477255`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ \
t1\), qSI[t1] \[Rule] 0, 
      qB[t1] \[Rule] \(\(0.35177492887989953`\)\(\[InvisibleSpace]\)\) + 
          0.04693371726460611`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ \
t1\) - 0.3957538388226396`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) \
+ 0.005743471821601521`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) - 
          0.008698279143467566`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\
\ t1\), q\_2[t1] \[Rule] \(\(3.0634783613484102`\)\(\[InvisibleSpace]\)\) - 
          0.0016237105712366372`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\
\ t1\) + 0.11895727428260902`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ \
t1\) - 0.09262255980087304`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\
\) - 3.0881893652589096`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ t1\), 
      q\_3[t1] \[Rule] \(\(0.1838243147376067`\)\(\[InvisibleSpace]\)\) + 
          5.875964061950627`*^-7\ \[ExponentialE]\^\(\(-24.086643397569993`\)\
\ t1\) - 0.00038001773423169787`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\
\ t1\) + 0.33688418955355964`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t1\) - 0.5203290741533408`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t1\), q\_4[t1] \[Rule] \(\(0.05646260418043024`\)\(\[InvisibleSpace]\)\) - 
          0.007587617624444649`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ \
t1\) + 0.03477956985560795`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t1\) - 0.08318079709295223`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ \
t1\) + 0.0009332042436970645`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t1\) - 0.0014069635623383688`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t1\), qURI[t1] \[Rule] \(\(7.819998628491152`\)\(\[InvisibleSpace]\)\) + 
          0.0037938088122223086`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\
\ t1\) - 0.03477956985560795`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t1\) + 0.36035579479135643`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ \
t1\) - 0.18623063288096048`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\
\) + 2.6686886727295525`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ t1\) \
- 10.631826702087714`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\), 
      qULI[t1] \[Rule] \(\(0.0011253694460511285`\)\(\[InvisibleSpace]\)\) - 
          3.0570894106183475`*^-10\ \[ExponentialE]\^\(\(-24.086643397569993`\
\)\ t1\) + 
          4.52516039172419`*^-6\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ \
t1\) - 0.00001572361800557389`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ \
t1\) + 0.0022363838841245394`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t1\) - 0.003350554566852877`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t1\), qLLI[t1] \[Rule] \(\(0.0018641488159058736`\)\(\[InvisibleSpace]\)\) - 
          4.601973368560672`*^-6\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\
\ t1\) + 0.00003537814051254125`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\
\ t1\) - 0.00010856793294839227`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\
\ t1\) + 0.004283039419433341`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t1\) - 0.006069396493459851`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t1\), qFEC[t1] \[Rule] \(\(0.021515186016482946`\)\(\[InvisibleSpace]\)\) + 
          1.6613888349166091`*^-6\ \
\[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) - 
          0.000019654522506967362`\ \[ExponentialE]\^\(\(-1.8866433975699939`\
\)\ t1\) + 
          0.00010856793294839227`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) - 
          0.07122709624058275`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t1\) + 0.9593549604488255`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t1\) - 0.9097336250240021`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ \
t1\), qWB[t1] \[Rule] \(\(3.700046512603076`\)\(\[InvisibleSpace]\)\) - 
          
          0.0037938088112254354`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\
\ t1\) + 0.03477956985560795`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t1\) - 0.3603574561801913`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) \
+ 0.000019654522506967362`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ t1\) \
- 0.00010856793294839227`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) \
+ 0.25745772912154313`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) - 
          3.6280436331783688`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t1\)}\)], "Output",
  CellLabel->"Out[52]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs1, 1, \ t, Log[2]/8.0, 
      IntakeWay \[Rule] "\<Ingestion\>", 
      IntakeType \[Rule] \ "\<Continuous\>", 
      ShowReport \[Rule] \ "\<CompartmentContent\>"]\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    \({qST[
          t] \[Rule] \(-0.05044847984405358`\)\ \
\[ExponentialE]\^\(\(-24.086643397569993`\)\ t\) + 
          0.05044847984405358`\ \[ExponentialE]\^\(\(-0.3`\)\ t\), 
      qSI[t] \[Rule] 0, 
      qB[t] \[Rule] 
        0.057030781124356326`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ t\
\) - 0.5306315234984672`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t\) + 
          0.475515522240462`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.006602090177548471`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\
\ t\) + 0.004687310311197322`\ \[ExponentialE]\^\(\(-0.09296993648799634`\)\ \
t\), q\_2[
          t] \[Rule] \(-0.001973026804491647`\)\ \
\[ExponentialE]\^\(\(-24.086643397569993`\)\ t\) + 
          0.15949934906909324`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ \
t\) - 1.928152428946829`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) + 
          0.1064691377053239`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t\) + 1.6641569689769036`\ \[ExponentialE]\^\(\(-0.09296993648799634`\)\ t\), 
      q\_3[t] \[Rule] 
        7.140086910703862`*^-7\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ \
t\) - 0.000509532364541819`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t\) \
+ 0.10736156105711403`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.3872465762707878`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t\) + 0.2803938335695245`\ \[ExponentialE]\^\(\(-0.09296993648799634`\)\ t\), 
      q\_4[t] \[Rule] \(-0.009219976281770934`\)\ \
\[ExponentialE]\^\(\(-24.086643397569993`\)\ t\) + 
          0.042797757853837215`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t\) - 0.11152981666219816`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t\) \
+ 0.07826656682738739`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.0010727132929923503`\ \
\[ExponentialE]\^\(\(-0.14677556138819248`\)\ t\) + 
          0.0007581815557368406`\ \
\[ExponentialE]\^\(\(-0.09296993648799634`\)\ t\), 
      qURI[t] \[Rule] 
        0.004609988140885447`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ t\
\) - 0.042797757853837215`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t\) \
+ 0.48316939883767906`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t\) - 
          4.402014239220751`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) + 
          0.21407111766053472`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t\) - 1.4380973209459484`\ \[ExponentialE]\^\(\(-0.09296993648799634`\)\ t\) \
+ 5.181058813381437`\ \[ExponentialE]\^\(\(-0.08664339756999317`\)\ t\), 
      qULI[t] \[Rule] \(-3.7147749467959325`*^-10\)\ \
\[ExponentialE]\^\(\(-24.086643397569993`\)\ t\) + 
          6.067389667979045`*^-6\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\
\ t\) - 0.000022435937507995716`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\
\ t\) + 0.0007815404722376891`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.0025707113281334556`\ \
\[ExponentialE]\^\(\(-0.14677556138819248`\)\ t\) + 
          0.0018055397752132776`\ \
\[ExponentialE]\^\(\(-0.09296993648799634`\)\ t\), 
      qLLI[t] \[Rule] \(-6.1703814343873105`*^-6\)\ \
\[ExponentialE]\^\(\(-2.8565990345907895`\)\ t\) + 
          0.00005048085939299036`\ \
\[ExponentialE]\^\(\(-1.8866433975699939`\)\ t\) - 
          0.00017996661952385379`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t\) + 
          0.0017883234695333042`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.0049233309328239995`\ \
\[ExponentialE]\^\(\(-0.14677556138819248`\)\ t\) + 
          0.0032706635757837944`\ \
\[ExponentialE]\^\(\(-0.09296993648799634`\)\ t\), 
      qFEC[t] \[Rule] 
        2.2276102013762996`*^-6\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ \
t\) - 0.000028044921884994644`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ \
t\) + 0.00017996661952385379`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ t\
\) - 0.00838185202344044`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) + 
          0.08187516663642765`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t\) - 0.5169751768184153`\ \[ExponentialE]\^\(\(-0.09296993648799634`\)\ t\) \
+ 0.44332771289758777`\ \[ExponentialE]\^\(\(-0.08664339756999317`\)\ t\), 
      qWB[t] \[Rule] \(-0.004609988139674113`\)\ \
\[ExponentialE]\^\(\(-24.086643397569993`\)\ t\) + 
          
          0.042797757853837215`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t\) - 0.4831716264478803`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t\) + 
          0.000028044921884994644`\ \[ExponentialE]\^\(\(-1.8866433975699939`\
\)\ t\) - 
          0.00017996661952385379`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t\) - 
          1.2139904350360406`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.29594628429696224`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t\) + 1.955072497764359`\ \[ExponentialE]\^\(\(-0.09296993648799634`\)\ \
t\)}\)], "Output",
  CellLabel->"Out[53]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs2, 1, \ t, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Ingestion\>", 
      IntakeType \[Rule] \ "\<MultiInputs\>", 
      ShowReport \[Rule] \ "\<CompartmentContent\>"]\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \("Option not available for MultiInputs intake"\)], "Output",
  CellLabel->"Out[54]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Ingestion\",ShowReport\[Rule] \"Disintegrations\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, 1, t1, Log[2]/8.0, 
        IntakeWay \[Rule] \ "\<Ingestion\>", 
        IntakeType \[Rule] \ "\<Acute\>", 
        ShowReport \[Rule] \ "\<Disintegrations\>"] // TableForm\)], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(qST[
                t1] \[Rule] \(\(3587.0502408283487`\)\(\[InvisibleSpace]\)\) \
- 3587.0502408283487`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\)\)},
          {\(qSI[t1] \[Rule] 0\)},
          {\(qB[t1] \[Rule] \(\(30393.35385522332`\)\(\[InvisibleSpace]\)\) + 
                4055.0731716619675`\ \
\[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\) - 
                34193.13167427606`\ \[ExponentialE]\^\(\(-2.8565990345907895`\
\)\ t1\) + 
                496.2359653863714`\ \
\[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) - 
                751.5313179955978`\ \
\[ExponentialE]\^\(\(-0.09296993648799633`\)\ t1\)\)},
          {\(q\_2[
                t1] \[Rule] \(\(264684.53042050265`\)\(\[InvisibleSpace]\)\) \
- 140.28859335484546`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\) + 
                10277.90849801742`\ \[ExponentialE]\^\(\(-2.8565990345907895`\
\)\ t1\) - 
                8002.58916679543`\ \[ExponentialE]\^\(\(-0.14677556138819248`\
\)\ t1\) - 
                266819.5611583698`\ \
\[ExponentialE]\^\(\(-0.09296993648799633`\)\ t1\)\)},
          {\(q\_3[
                t1] \[Rule] \(\(15882.420793329213`\)\(\[InvisibleSpace]\)\) \
+ 0.05076832949525341`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\) - 
                32.8335322376187`\ \
\[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) + 
                29106.79397742756`\ \
\[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) - 
                44956.43200684865`\ \
\[ExponentialE]\^\(\(-0.09296993648799633`\)\ t1\)\)},
          {\(q\_4[
                t1] \[Rule] \(\(4878.36900118917`\)\(\[InvisibleSpace]\)\) - 
                655.5701627520177`\ \[ExponentialE]\^\(\(-24.086643397569993`\
\)\ t1\) + 
                3004.954835524527`\ \[ExponentialE]\^\(\(-12.086643397569993`\
\)\ t1\) - 
                7186.8208688310715`\ \
\[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) + 
                80.62884665542637`\ \
\[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) - 
                121.56165178603506`\ \
\[ExponentialE]\^\(\(-0.09296993648799633`\)\ t1\)\)},
          {\(qURI[
                t1] \[Rule] \(\(675647.8815016355`\)\(\[InvisibleSpace]\)\) + 
                
                327.78508137600744`\ \
\[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\) - 
                3004.954835524527`\ \[ExponentialE]\^\(\(-12.086643397569993`\
\)\ t1\) + 
                31134.7406699732`\ \
\[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) - 
                16090.326680914986`\ \
\[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) + 
                230574.70132383335`\ \
\[ExponentialE]\^\(\(-0.09296993648799633`\)\ t1\) - 
                918589.8270603786`\ \
\[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\)\)},
          {\(qULI[
                t1] \[Rule] \(\(97.23192013881743`\)\(\[InvisibleSpace]\)\) - 
                0.000026413252507742525`\ \
\[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\) + 
                0.3909738578449701`\ \
\[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) - 
                1.358520595681584`\ \[ExponentialE]\^\(\(-1.8866433975699939`\
\)\ t1\) + 
                193.22356758836023`\ \
\[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) - 
                289.48791457608854`\ \
\[ExponentialE]\^\(\(-0.09296993648799633`\)\ t1\)\)},
          {\(qLLI[
                t1] \[Rule] \(\(161.06245769426744`\)\(\[InvisibleSpace]\)\) \
+ 2.0671241097124794`*^-6\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\) \
- 0.39761049904364215`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) + 
                3.056671340283564`\ \[ExponentialE]\^\(\(-1.8866433975699939`\
\)\ t1\) - 
                9.38026940674109`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) + 
                370.0546058390407`\ \
\[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) - 
                524.395857034931`\ \[ExponentialE]\^\(\(-0.09296993648799633`\
\)\ t1\)\)},
          {\(qFEC[
                t1] \[Rule] \(\(1858.9120719102648`\)\(\[InvisibleSpace]\)\) \
- 8.613021197621326`*^-8\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\) + 
                0.14354399533679504`\ \
\[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) - 
                1.6981507446019801`\ \
\[ExponentialE]\^\(\(-1.8866433975699939`\)\ t1\) + 
                9.38026940674109`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) - 
                6154.0211151863505`\ \
\[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) + 
                
                82888.26858277853`\ \
\[ExponentialE]\^\(\(-0.09296993648799633`\)\ t1\) - 
                78600.98520207379`\ \
\[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\)\)},
          {\(qWB[
                t1] \[Rule] \(\(319684.01868890575`\)\(\[InvisibleSpace]\)\) \
- 327.78508128987727`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\) + 
                3004.954835524527`\ \[ExponentialE]\^\(\(-12.086643397569993`\
\)\ t1\) - 
                31134.884213968537`\ \
\[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) + 
                1.6981507446019801`\ \
\[ExponentialE]\^\(\(-1.8866433975699939`\)\ t1\) - 
                9.38026940674109`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) + 
                22244.347796101323`\ \
\[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) - 
                313462.9699066111`\ \
\[ExponentialE]\^\(\(-0.09296993648799633`\)\ t1\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {qST[ t1] -> Plus[ 3587.0502408283487, 
          Times[ -3587.0502408283487, 
            Power[ E, 
              Times[ -24.086643397569993, t1]]]], qSI[ t1] -> 0, qB[ t1] -> 
        Plus[ 30393.353855223319, 
          Times[ 4055.0731716619675, 
            Power[ E, 
              Times[ -24.086643397569993, t1]]], 
          Times[ -34193.131674276061, 
            Power[ E, 
              Times[ -2.8565990345907895, t1]]], 
          Times[ 496.23596538637139, 
            Power[ E, 
              Times[ -.14677556138819248, t1]]], 
          Times[ -751.53131799559776, 
            Power[ E, 
              Times[ -.092969936487996327, t1]]]], Subscript[ q, 2][ t1] -> 
        Plus[ 264684.53042050265, 
          Times[ -140.28859335484546, 
            Power[ E, 
              Times[ -24.086643397569993, t1]]], 
          Times[ 10277.908498017419, 
            Power[ E, 
              Times[ -2.8565990345907895, t1]]], 
          Times[ -8002.5891667954302, 
            Power[ E, 
              Times[ -.14677556138819248, t1]]], 
          Times[ -266819.56115836982, 
            Power[ E, 
              Times[ -.092969936487996327, t1]]]], Subscript[ q, 3][ t1] -> 
        Plus[ 15882.420793329213, 
          Times[ .050768329495253409, 
            Power[ E, 
              Times[ -24.086643397569993, t1]]], 
          Times[ -32.833532237618698, 
            Power[ E, 
              Times[ -2.8565990345907895, t1]]], 
          Times[ 29106.793977427558, 
            Power[ E, 
              Times[ -.14677556138819248, t1]]], 
          Times[ -44956.432006848649, 
            Power[ E, 
              Times[ -.092969936487996327, t1]]]], Subscript[ q, 4][ t1] -> 
        Plus[ 4878.3690011891704, 
          Times[ -655.57016275201772, 
            Power[ E, 
              Times[ -24.086643397569993, t1]]], 
          Times[ 3004.954835524527, 
            Power[ E, 
              Times[ -12.086643397569993, t1]]], 
          Times[ -7186.8208688310715, 
            Power[ E, 
              Times[ -2.8565990345907895, t1]]], 
          Times[ 80.628846655426372, 
            Power[ E, 
              Times[ -.14677556138819248, t1]]], 
          Times[ -121.56165178603506, 
            Power[ E, 
              Times[ -.092969936487996327, t1]]]], qURI[ t1] -> Plus[ 
        675647.88150163554, 
          Times[ 327.78508137600744, 
            Power[ E, 
              Times[ -24.086643397569993, t1]]], 
          Times[ -3004.954835524527, 
            Power[ E, 
              Times[ -12.086643397569993, t1]]], 
          Times[ 31134.740669973198, 
            Power[ E, 
              Times[ -2.8565990345907895, t1]]], 
          Times[ -16090.326680914986, 
            Power[ E, 
              Times[ -.14677556138819248, t1]]], 
          Times[ 230574.70132383335, 
            Power[ E, 
              Times[ -.092969936487996327, t1]]], 
          Times[ -918589.82706037862, 
            Power[ E, 
              Times[ -.086643397569993161, t1]]]], qULI[ t1] -> Plus[ 
        97.231920138817429, 
          Times[ -.000026413252507742525, 
            Power[ E, 
              Times[ -24.086643397569993, t1]]], 
          Times[ .39097385784497007, 
            Power[ E, 
              Times[ -2.8565990345907895, t1]]], 
          Times[ -1.358520595681584, 
            Power[ E, 
              Times[ -1.8866433975699939, t1]]], 
          Times[ 193.22356758836023, 
            Power[ E, 
              Times[ -.14677556138819248, t1]]], 
          Times[ -289.48791457608854, 
            Power[ E, 
              Times[ -.092969936487996327, t1]]]], qLLI[ t1] -> Plus[ 
        161.06245769426744, 
          Times[ .20671241097124794*^-5, 
            Power[ E, 
              Times[ -24.086643397569993, t1]]], 
          Times[ -.39761049904364215, 
            Power[ E, 
              Times[ -2.8565990345907895, t1]]], 
          Times[ 3.0566713402835641, 
            Power[ E, 
              Times[ -1.8866433975699939, t1]]], 
          Times[ -9.3802694067410908, 
            Power[ E, 
              Times[ -1.0866433975699932, t1]]], 
          Times[ 370.05460583904068, 
            Power[ E, 
              Times[ -.14677556138819248, t1]]], 
          Times[ -524.39585703493105, 
            Power[ E, 
              Times[ -.092969936487996327, t1]]]], qFEC[ t1] -> Plus[ 
        1858.9120719102648, 
          Times[ -.86130211976213256*^-7, 
            Power[ E, 
              Times[ -24.086643397569993, t1]]], 
          Times[ .14354399533679504, 
            Power[ E, 
              Times[ -2.8565990345907895, t1]]], 
          Times[ -1.6981507446019801, 
            Power[ E, 
              Times[ -1.8866433975699939, t1]]], 
          Times[ 9.3802694067410908, 
            Power[ E, 
              Times[ -1.0866433975699932, t1]]], 
          Times[ -6154.0211151863505, 
            Power[ E, 
              Times[ -.14677556138819248, t1]]], 
          Times[ 82888.268582778532, 
            Power[ E, 
              Times[ -.092969936487996327, t1]]], 
          Times[ -78600.985202073789, 
            Power[ E, 
              Times[ -.086643397569993161, t1]]]], qWB[ t1] -> Plus[ 
        319684.01868890575, 
          Times[ -327.78508128987727, 
            Power[ E, 
              Times[ -24.086643397569993, t1]]], 
          Times[ 3004.954835524527, 
            Power[ E, 
              Times[ -12.086643397569993, t1]]], 
          Times[ -31134.884213968537, 
            Power[ E, 
              Times[ -2.8565990345907895, t1]]], 
          Times[ 1.6981507446019801, 
            Power[ E, 
              Times[ -1.8866433975699939, t1]]], 
          Times[ -9.3802694067410908, 
            Power[ E, 
              Times[ -1.0866433975699932, t1]]], 
          Times[ 22244.347796101323, 
            Power[ E, 
              Times[ -.14677556138819248, t1]]], 
          Times[ -313462.96990661108, 
            Power[ E, 
              Times[ -.092969936487996327, t1]]]]}]]], "Output",
  CellLabel->"Out[55]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, 1, t1, Log[2]/8.0, 
      IntakeWay \[Rule] "\<Ingestion\>", IntakeType \[Rule] \ "\<Constant\>", 
      ShowReport \[Rule] \ "\<Disintegrations\>"]\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \({qST[t1] \[Rule] \(-148.9227943313277`\) + 
          148.9227943313277`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\
\) + 3587.0502408283487`\ t1, qSI[t1] \[Rule] 0, 
      qB[t1] \[Rule] \(-16504.199022921333`\) - 
          168.35360181697496`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ \
t1\) + 11969.87440667334`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) \
- 3380.916827658556`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) + 
          8083.595045723524`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t1\) + 30393.35385522332`\ t1, 
      q\_2[t1] \[Rule] \(-2.9208857897278857`*^6\) + 
          5.824331395589915`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\
\) - 3597.9528010621693`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) + 
          54522.62686722183`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t1\) + 2.8699552913303305`*^6\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t1\) + 264684.53042050265`\ t1, 
      q\_3[t1] \[Rule] \(-285262.1266630771`\) - 
          0.0021077378303518716`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\
\ t1\) + 11.493924012447946`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\
\) - 198308.17679821927`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) \
+ 483558.8116450217`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ t1\) + 
          15882.420793329213`\ t1, 
      q\_4[t1] \[Rule] \(-3052.668461541155`\) + 
          27.217165627077602`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ \
t1\) - 248.6178119666102`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t1\) \
+ 2515.866168757069`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) - 
          549.3342753578638`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t1\) + 1307.5372144814826`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t1\) + 4878.36900118917`\ t1, 
      qURI[t1] \[Rule] \(-8.220821470726903`*^6\) - 
          13.608582813538742`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ \
t1\) + 248.6178119666102`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t1\) \
- 10899.233771684474`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) + 
          109625.37992519911`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t1\) - 2.4800995895442357`*^6\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t1\) + 1.060195990488847`*^7\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ \
t1\) + 675647.8815016355`\ t1, 
      qULI[t1] \[Rule] \(-1797.907059419012`\) + 
          1.0965933306592338`*^-6\ \
\[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\) - 
          0.13686690120336664`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ \
t1\) + 0.720072800949753`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ t1\) \
- 1316.4559941782263`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) + 
          3113.779846600899`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t1\) + 97.23192013881743`\ t1, 
      qLLI[t1] \[Rule] \(-3126.4121902785228`\) - 
          8.582034763386846`*^-8\ \[ExponentialE]\^\(\(-24.086643397569993`\)\
\ t1\) + 0.1391901678285767`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\
\) - 1.6201638021369444`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ t1\) + 
          8.632334607395327`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\
\) - 2521.2276644632893`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) \
+ 5640.488493854545`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ t1\) + 
          161.06245769426744`\ t1, 
      qFEC[t1] \[Rule] \(-57538.420722254785`\) + 
          3.575849509396672`*^-9\ \[ExponentialE]\^\(\(-24.086643397569993`\)\
\ t1\) - 0.05024996283993979`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ \
t1\) + 0.9000910011871913`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ t1\) \
- 8.632334607395327`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) + 
          41928.104767456316`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t1\) - 891559.9140317852`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ t1\) \
+ 907178.0124801492`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\) + 
          1858.9120719102648`\ t1, 
      qWB[t1] \[Rule] \(-3.2307780259194532`*^6\) + 
          
          13.608582809962895`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ \
t1\) - 248.6178119666102`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t1\) \
+ 10899.284021647314`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) - 
          0.9000910011871913`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ \
t1\) + 8.632334607395327`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) \
- 151553.48469265533`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) + 
          3.3716595035760123`*^6\ \
\[ExponentialE]\^\(\(-0.09296993648799633`\)\ t1\) + 
          319684.01868890575`\ t1}\)], "Output",
  CellLabel->"Out[56]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs1, 1, \ t, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Ingestion\>", 
      IntakeType \[Rule] \ "\<Continuous\>", 
      ShowReport \[Rule] \ \ "\<Disintegrations\>"]\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \("Option not available for continuous intake"\)], "Output",
  CellLabel->"Out[57]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs2, 1, t, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Ingestion\>", 
      IntakeType \[Rule] \ "\<MultiInputs\>", 
      ShowReport \[Rule] \ "\<Disintegrations\>"]\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \("Option not available for MultiInputs intake"\)], "Output",
  CellLabel->"Out[58]="]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inhalation", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Inhalation\",ShowReport\[Rule] \"Automatic\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, AMADAdultW[5], \ F, \ 1, t1, 
      Log[2]/8.0, IntakeWay \[Rule] \ "\<Inhalation\>", 
      IntakeType \[Rule] \ "\<Acute\>"]\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \({qLungs[t1] \[Rule] 
        0.01006337724365423`\ \[ExponentialE]\^\(\(-110.08664339756999`\)\ t1\
\) + 0.00798948637352798`\ \[ExponentialE]\^\(\(-102.08664339756999`\)\ t1\) \
+ 0.010318191574724172`\ \[ExponentialE]\^\(\(-100.11664339756999`\)\ t1\) + 
          0.01615017914617113`\ \[ExponentialE]\^\(\(-100.10664339756998`\)\ \
t1\) + 0.`\ \[ExponentialE]\^\(\(-100.09664339756999`\)\ t1\) + 
          0.03193255793813499`\ \[ExponentialE]\^\(\(-100.08764339756999`\)\ \
t1\) + 0.00443273582045417`\ \[ExponentialE]\^\(\(-100.08676339757`\)\ t1\) + 
          0.0010879819033333337`\ \[ExponentialE]\^\(\(-100.08664339756999`\)\
\ t1\), qDailyUrine[t1] \[Rule] 
        7.785583963640016`*^82\ \[ExponentialE]\^\(\(-200.08664339757`\)\ \
t1\) + 1.2961342546388468`*^43\ \[ExponentialE]\^\(\(-110.08664339756999`\)\ \
t1\) + 4.112883456707889`*^39\ \[ExponentialE]\^\(\(-102.08664339756999`\)\ \
t1\) + 7.770653256668326`*^38\ \[ExponentialE]\^\(\(-100.11664339756999`\)\ \
t1\) + 1.2044700911844392`*^39\ \[ExponentialE]\^\(\(-100.10664339756998`\)\ \
t1\) + 2.3377896866745392`*^39\ \[ExponentialE]\^\(\(-100.08764339756999`\)\ \
t1\) + 3.2424320237277655`*^38\ \[ExponentialE]\^\(\(-100.08676339757`\)\ \
t1\) + 9.416130638902479`*^37\ \[ExponentialE]\^\(\(-100.08664339756999`\)\ \
t1\) + 5.502475894263499`*^8\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\
\) - 24977.524454636114`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t1\) + 
          1.1474873099236649`\ \[ExponentialE]\^\(\(-2.856599034590793`\)\ t1\
\) + 3.500185297657762`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) + 
          2.370235074702033`\ \[ExponentialE]\^\(\(-2.856599034590779`\)\ \
t1\) - 0.000385100004114753`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t1\) - 0.00042863452496805926`\ \[ExponentialE]\^\(\(-0.14677556138818892`\)\ \
t1\) + 0.0002701612430197689`\ \[ExponentialE]\^\(\(-0.09296993648801054`\)\ \
t1\) + 0.0004869541171210884`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t1\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\), 
      qDailyFaecal[
          t1] \[Rule] \(-5.76613051288575`*^70\)\ \
\[ExponentialE]\^\(\(-200.08664339757`\)\ t1\) - 
          5.726221416172984`*^31\ \[ExponentialE]\^\(\(-110.08664339756999`\)\
\ t1\) - 2.2611882829956096`*^28\ \[ExponentialE]\^\(\(-102.08664339756999`\)\
\ t1\) - 4.519847666015237`*^27\ \[ExponentialE]\^\(\(-100.11664339756999`\)\ \
t1\) - 6.993292132949468`*^27\ \[ExponentialE]\^\(\(-100.10664339756998`\)\ \
t1\) - 1.3606652695361516`*^28\ \[ExponentialE]\^\(\(-100.08764339756999`\)\ \
t1\) - 1.887340900491311`*^27\ \[ExponentialE]\^\(\(-100.08676339757`\)\ t1\) \
- 5.475546318642533`*^26\ \[ExponentialE]\^\(\(-100.08664339756999`\)\ t1\) - 
          0.14458536318684456`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ \
t1\) + 5.290389754990557`*^-6\ \[ExponentialE]\^\(\(-2.856599034590793`\)\ t1\
\) + 0.000016137297797680258`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ \
t1\) + 0.000010927761246402881`\ \[ExponentialE]\^\(\(-2.856599034590779`\)\ \
t1\) - 0.000029993290591164584`\ \[ExponentialE]\^\(\(-1.8866433975700045`\)\ \
t1\) - 0.00004256496061842337`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ \
t1\) - 0.000014449641529201313`\ \[ExponentialE]\^\(\(-1.8866433975699903`\)\ \
t1\) + 0.0000956644392041158`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ \
t1\) - 0.0001472880945041057`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t1\) - 0.00016393861788276077`\ \[ExponentialE]\^\(\(-0.14677556138818892`\)\ \
t1\) + 0.00009711905748336844`\ \[ExponentialE]\^\(\(-0.09296993648801054`\)\ \
t1\) + 0.00017505295861029724`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t1\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\), 
      qWholebody[t1] \[Rule] 
        0.0001077444260589866`\ \[ExponentialE]\^\(\(-200.08664339757`\)\ \
t1\) + 0.000021890565410158033`\ \[ExponentialE]\^\(\(-110.08664339756999`\)\ \
t1\) + 0.00002070662170450266`\ \[ExponentialE]\^\(\(-102.08664339756999`\)\ \
t1\) + 0.000028053077108649432`\ \[ExponentialE]\^\(\(-100.11664339756999`\)\ \
t1\) + 0.00004391996044533428`\ \[ExponentialE]\^\(\(-100.10664339756998`\)\ \
t1\) + 2.710505431213761`*^-20\ \[ExponentialE]\^\(\(-100.09664339756999`\)\ \
t1\) + 0.00008688062842016064`\ \[ExponentialE]\^\(\(-100.08764339756999`\)\ \
t1\) + 0.000012060646110905598`\ \[ExponentialE]\^\(\(-100.08676339757`\)\ t1\
\) + 3.502872137665534`*^-6\ \[ExponentialE]\^\(\(-100.08664339756999`\)\ \
t1\) + 0.020772586822823024`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\
\) - 0.1534681572506803`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t1\) + 
          0.07671468599667161`\ \[ExponentialE]\^\(\(-2.856599034590793`\)\ \
t1\) + 0.23400312466884313`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ \
t1\) + 0.15846087178616627`\ \[ExponentialE]\^\(\(-2.856599034590779`\)\ t1\) \
- 5.939680106886648`*^-6\ \[ExponentialE]\^\(\(-1.8866433975700045`\)\ t1\) - 
          8.429293513734781`*^-6\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\
\ t1\) - 2.861514913869582`*^-6\ \[ExponentialE]\^\(\(-1.8866433975699903`\)\ \
t1\) + 0.3387552744752925`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) \
- 0.00859010640565248`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) - 
          0.009561194856583246`\ \[ExponentialE]\^\(\(-0.14677556138818892`\)\
\ t1\) + 0.05787046025084984`\ \[ExponentialE]\^\(\(-0.09296993648801054`\)\ \
t1\) + 0.10430903620340772`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ t1\
\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\)}\)], "Output",
  CellLabel->"Out[59]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, AMADAdultW[5], \ F, 1, t1, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Inhalation\>", 
      IntakeType \[Rule] \ "\<Constant\>"]\)], "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    \({qLungs[
          t1] \[Rule] \(\(0.0008082717969697772`\)\(\[InvisibleSpace]\)\) - 
          0.00009141324445065574`\ \
\[ExponentialE]\^\(\(-110.08664339756999`\)\ t1\) - 
          0.00007826181866332336`\ \
\[ExponentialE]\^\(\(-102.08664339756999`\)\ t1\) - 
          0.00010306170107751148`\ \
\[ExponentialE]\^\(\(-100.11664339756999`\)\ t1\) - 
          0.00016132974394148116`\ \
\[ExponentialE]\^\(\(-100.10664339756998`\)\ t1\) - 
          0.0003190459566651189`\ \[ExponentialE]\^\(\(-100.08764339756999`\)\
\ t1\) - 0.000044288931622718376`\ \[ExponentialE]\^\(\(-100.08676339757`\)\ \
t1\) - 0.000010870400548968245`\ \[ExponentialE]\^\(\(-100.08664339756999`\)\ \
t1\), qDailyUrine[
          t1] \[Rule] \(\(0.31260123468227263`\)\(\[InvisibleSpace]\)\) - 
          3.891106288474285`*^80\ \[ExponentialE]\^\(\(-200.08664339757`\)\ \
t1\) - 1.177376486953047`*^41\ \[ExponentialE]\^\(\(-110.08664339756999`\)\ \
t1\) - 4.0288164247799743`*^37\ \[ExponentialE]\^\(\(-102.08664339756999`\)\ \
t1\) - 7.761599862882418`*^36\ \[ExponentialE]\^\(\(-100.11664339756999`\)\ \
t1\) - 1.2031869717186708`*^37\ \[ExponentialE]\^\(\(-100.10664339756998`\)\ \
t1\) - 2.3357425625342296`*^37\ \[ExponentialE]\^\(\(-100.08764339756999`\)\ \
t1\) - 3.239621218290356`*^36\ \[ExponentialE]\^\(\(-100.08676339757`\)\ t1\) \
- 9.407979246040965`*^35\ \[ExponentialE]\^\(\(-100.08664339756999`\)\ t1\) - 
          2.284451097415517`*^7\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ \
t1\) + 2066.5393718538785`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t1\) \
- 0.40169701663714313`\ \[ExponentialE]\^\(\(-2.856599034590793`\)\ t1\) - 
          1.2252980748343514`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ \
t1\) - 0.8297402071486663`\ \[ExponentialE]\^\(\(-2.856599034590779`\)\ t1\) \
+ 0.00262373381830399`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ t1\) + 
          0.0029203398775250883`\ \
\[ExponentialE]\^\(\(-0.14677556138818892`\)\ t1\) - 
          0.0029058989736386875`\ \
\[ExponentialE]\^\(\(-0.09296993648801054`\)\ t1\) - 
          0.005237758952152838`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\
\ t1\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\), 
      qDailyFaecal[
          t1] \[Rule] \(\(0.000860060727996579`\)\(\[InvisibleSpace]\)\) - 
          1.8519889179156021`*^-6\ \[ExponentialE]\^\(\(-2.856599034590793`\)\
\ t1\) - 5.64912947259045`*^-6\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ \
t1\) - 3.825444563299843`*^-6\ \[ExponentialE]\^\(\(-2.856599034590779`\)\ t1\
\) + 0.000015897699920290143`\ \[ExponentialE]\^\(\(-1.8866433975700045`\)\ \
t1\) + 0.000022561211447402962`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ \
t1\) + 7.658915059312508`*^-6\ \[ExponentialE]\^\(\(-1.8866433975699903`\)\ \
t1\) - 0.00008803664515704549`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ \
t1\) + 0.0010034919513239524`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t1\) + 0.0011169340204339531`\ \[ExponentialE]\^\(\(-0.14677556138818892`\)\ \
t1\) - 0.0010446286310617225`\ \[ExponentialE]\^\(\(-0.09296993648801054`\)\ \
t1\) - 0.0018828985500371487`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t1\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\), 
      qWholebody[
          t1] \[Rule] \(\(5.861735589759598`\)\(\[InvisibleSpace]\)\) + 
          9.032488298976737`*^-15\ \[ExponentialE]\^\(\(-200.08664339757`\)\ \
t1\) - 5.475237982183884`*^-11\ \[ExponentialE]\^\(\(-110.08664339756999`\)\ \
t1\) - 5.531551018828681`*^-11\ \[ExponentialE]\^\(\(-102.08664339756999`\)\ \
t1\) - 7.621553820729484`*^-11\ \[ExponentialE]\^\(\(-100.11664339756999`\)\ \
t1\) + 1.3781863020603802`*^-14\ \[ExponentialE]\^\(\(-100.10664339756998`\)\ \
t1\) - 4.235164736271502`*^-22\ \[ExponentialE]\^\(\(-100.09664339756999`\)\ \
t1\) + 2.7272238287134876`*^-14\ \[ExponentialE]\^\(\(-100.08764339756999`\)\ \
t1\) - 4.955830311284635`*^-11\ \[ExponentialE]\^\(\(-100.08676339757`\)\ \
t1\) - 9.519184997409036`*^-12\ \[ExponentialE]\^\(\(-100.08664339756999`\)\ \
t1\) + 6.428190271745571`*^-11\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ \
t1\) + 0.`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t1\) + 
          6.938893903907228`*^-18\ \[ExponentialE]\^\(\(-2.856599034590793`\)\
\ t1\) + 1.3877787807814457`*^-17\ \
\[ExponentialE]\^\(\(-2.8565990345907895`\)\ t1\) + 
          2.0816681711721685`*^-17\ \
\[ExponentialE]\^\(\(-2.856599034590779`\)\ t1\) + 
          8.470329472543003`*^-22\ \
\[ExponentialE]\^\(\(-1.8866433975700045`\)\ t1\) + 
          0.`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ t1\) + 
          4.235164736271502`*^-22\ \
\[ExponentialE]\^\(\(-1.8866433975699903`\)\ t1\) - 
          0.31169342284452944`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ \
t1\) - 4.163336342344337`*^-17\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t1\) - 5.551115123125783`*^-17\ \[ExponentialE]\^\(\(-0.14677556138818892`\)\ \
t1\) + 1.5543122344752192`*^-15\ \[ExponentialE]\^\(\(-0.09296993648801054`\)\
\ t1\) + 2.7755575615628914`*^-15\ \[ExponentialE]\^\(\(-0.09296993648799633`\
\)\ t1\) - 
          5.5500421669352855`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ \
t1\)}\)], "Output",
  CellLabel->"Out[60]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs1, AMADAdultW[5], \ F, 1, t, 
      Log[2]/8.0, IntakeWay \[Rule] \ "\<Inhalation\>", 
      IntakeType \[Rule] \ "\<Continuous\>"]\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \("Option not available for inhalation"\)], "Output",
  CellLabel->"Out[61]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs2, AMADAdultW[5], \ F, 1, t, 
      Log[2]/8.0, IntakeWay \[Rule] \ "\<Inhalation\>", 
      IntakeType \[Rule] \ "\<MultiInputs\>"]\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \({qLungs[t] \[Rule] 
        0.07044364070557961`\ \[ExponentialE]\^\(\(-110.08664339756999`\)\ \
t\) + 0.05592640461469586`\ \[ExponentialE]\^\(\(-102.08664339756999`\)\ t\) \
+ 0.0722273410230692`\ \[ExponentialE]\^\(\(-100.11664339756999`\)\ t\) + 
          0.11305125402319792`\ \[ExponentialE]\^\(\(-100.10664339756998`\)\ \
t\) + 0.`\ \[ExponentialE]\^\(\(-100.09664339756999`\)\ t\) + 
          0.2235279055669449`\ \[ExponentialE]\^\(\(-100.08764339756999`\)\ t\
\) + 0.03102915074317919`\ \[ExponentialE]\^\(\(-100.08676339757`\)\ t\) + 
          0.007615873323333336`\ \[ExponentialE]\^\(\(-100.08664339756999`\)\ \
t\), qDailyUrine[t] \[Rule] 
        5.449908774548012`*^83\ \[ExponentialE]\^\(\(-200.08664339757`\)\ t\) \
+ 9.072939782471927`*^43\ \[ExponentialE]\^\(\(-110.08664339756999`\)\ t\) + 
          2.8790184196955225`*^40\ \
\[ExponentialE]\^\(\(-102.08664339756999`\)\ t\) + 
          5.439457279667828`*^39\ \[ExponentialE]\^\(\(-100.11664339756999`\)\
\ t\) + 8.431290638291074`*^39\ \[ExponentialE]\^\(\(-100.10664339756998`\)\ \
t\) + 1.6364527806721775`*^40\ \[ExponentialE]\^\(\(-100.08764339756999`\)\ t\
\) + 2.269702416609436`*^39\ \[ExponentialE]\^\(\(-100.08676339757`\)\ t\) + 
          6.591291447231735`*^38\ \[ExponentialE]\^\(\(-100.08664339756999`\)\
\ t\) + 3.8517331259844494`*^9\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ \
t\) - 174842.67118483153`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t\) + 
          8.04377854817914`\ \[ExponentialE]\^\(\(-2.856599034590793`\)\ t\) \
+ 24.53597104601051`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t\) + 
          16.615125834636302`\ \[ExponentialE]\^\(\(-2.856599034590779`\)\ \
t\) - 0.003716733117329887`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t\) - 0.004136899810847659`\ \[ExponentialE]\^\(\(-0.14677556138818892`\)\ \
t\) + 0.00271874779367429`\ \[ExponentialE]\^\(\(-0.09296993648801054`\)\ t\) \
+ 0.004900426932987874`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ t\) + 
          0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t\), 
      qDailyFaecal[
          t] \[Rule] \(-4.036291359020025`*^71\)\ \
\[ExponentialE]\^\(\(-200.08664339757`\)\ t\) - 
          4.008354991321089`*^32\ \[ExponentialE]\^\(\(-110.08664339756999`\)\
\ t\) - 1.5828317980969268`*^29\ \[ExponentialE]\^\(\(-102.08664339756999`\)\ \
t\) - 3.163893366210666`*^28\ \[ExponentialE]\^\(\(-100.11664339756999`\)\ \
t\) - 4.895304493064628`*^28\ \[ExponentialE]\^\(\(-100.10664339756998`\)\ \
t\) - 9.524656886753061`*^28\ \[ExponentialE]\^\(\(-100.08764339756999`\)\ \
t\) - 1.3211386303439178`*^28\ \[ExponentialE]\^\(\(-100.08676339757`\)\ t\) \
- 3.832882423049773`*^27\ \[ExponentialE]\^\(\(-100.08664339756999`\)\ t\) - 
          1.012097542307912`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ \
t\) + 0.00003708513658903177`\ \[ExponentialE]\^\(\(-2.856599034590793`\)\ \
t\) + 0.00011312094585097769`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t\
\) + 0.000076602582645804`\ \[ExponentialE]\^\(\(-2.856599034590779`\)\ t\) - 
          0.00021202081329385565`\ \
\[ExponentialE]\^\(\(-1.8866433975700045`\)\ t\) - 
          0.0003008892118958612`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\
\ t\) - 0.00010214366908205854`\ \[ExponentialE]\^\(\(-1.8866433975699903`\)\ \
t\) + 0.0007024527593159229`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ \
t\) - 0.0014215282596275922`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ t\
\) - 0.0015822282102925724`\ \[ExponentialE]\^\(\(-0.14677556138818892`\)\ \
t\) + 0.0009773504900453594`\ \[ExponentialE]\^\(\(-0.09296993648801054`\)\ t\
\) + 0.0017616325705277927`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t\), 
      qWholebody[t] \[Rule] 
        0.0007542109824125176`\ \[ExponentialE]\^\(\(-200.08664339757`\)\ t\) \
+ 0.00015323395787110623`\ \[ExponentialE]\^\(\(-110.08664339756999`\)\ t\) + 
          0.0001449463519315186`\ \[ExponentialE]\^\(\(-102.08664339756999`\)\
\ t\) + 0.00019637153976054603`\ \[ExponentialE]\^\(\(-100.11664339756999`\)\ \
t\) + 0.00030743972311733994`\ \[ExponentialE]\^\(\(-100.10664339756998`\)\ t\
\) + 7.215636508434153`*^-16\ \[ExponentialE]\^\(\(-100.09664339756999`\)\ \
t\) + 0.0006081643989477789`\ \[ExponentialE]\^\(\(-100.08764339756999`\)\ \
t\) + 0.00008442452327628129`\ \[ExponentialE]\^\(\(-100.08676339757`\)\ t\) \
+ 0.000024520104456326065`\ \[ExponentialE]\^\(\(-100.08664339756999`\)\ t\) \
+ 0.14540810775976118`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ t\) - 
          1.0742771007693777`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t\
\) + 0.5377627623536647`\ \[ExponentialE]\^\(\(-2.856599034590793`\)\ t\) + 
          1.6403399829696983`\ \[ExponentialE]\^\(\(-2.8565990345907895`\)\ t\
\) + 1.1107958669138767`\ \[ExponentialE]\^\(\(-2.856599034590779`\)\ t\) - 
          0.000041987250553242646`\ \[ExponentialE]\^\(\(-1.8866433975700045`\
\)\ t\) - 
          0.0000595861818109794`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\
\ t\) - 0.00002022788121386881`\ \[ExponentialE]\^\(\(-1.8866433975699903`\)\ \
t\) + 2.487440257505364`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ t\) - 
          0.08290608314239963`\ \[ExponentialE]\^\(\(-0.14677556138819248`\)\ \
t\) - 0.09227839310569826`\ \[ExponentialE]\^\(\(-0.14677556138818892`\)\ t\) \
+ 0.5823751192705285`\ \[ExponentialE]\^\(\(-0.09296993648801054`\)\ t\) + 
          1.0497063119359258`\ \[ExponentialE]\^\(\(-0.09296993648799633`\)\ \
t\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t\)}\)], "Output",
  CellLabel->"Out[62]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Inhalation\",ShowReport\[Rule] \"BioassayTable\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, AMADAdultW[5], \ F, \ 1, 180, 
      Log[2]/8.0, IntakeWay \[Rule] \ "\<Inhalation\>", 
      IntakeType \[Rule] \ "\<Acute\>", \ 
      ShowReport \[Rule] \ "\<BioassayTable\>"]\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nintake"\), \("Lung\nretention"\), \("Urine\n24 \
hours"\), \("Faecal\n24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "2.1950568164839258`*^-45", "0.28187961572268394`", 
            "2.111073758178995`*^-7", "0.2733433150482452`"},
          {"2", "0", "0.02319492833159299`", "2.931340021286037`*^-6", 
            "0.16122786625174743`"},
          {"3", "0", "0.0013805921674297852`", "8.927467730166087`*^-6", 
            "0.1241141935595887`"},
          {"4", "0", "0.0001461212959575002`", "0.00001581677035708527`", 
            "0.10611397310050664`"},
          {"5", "0", "0.00008941122019196147`", "0.000021995043801446728`", 
            "0.09465284898329085`"},
          {"6", "0", "0.0000963650976340271`", "0.000026939207920687246`", 
            "0.08581597320429805`"},
          {"7", "0", "0.0001036946779850256`", "0.0000306253739235899`", 
            "0.078269909040545`"},
          {"8", "0", "0.00010837896037238504`", "0.00003319659324468177`", 
            "0.07153463099827706`"},
          {"9", "0", "0.00011076118557602921`", "0.00003483165211910578`", 
            "0.0654190223899547`"},
          {"10", "0", "0.0001112937984669058`", "0.00003570085419080528`", 
            "0.05983140433536818`"},
          {"20", "0", "0.00007472082398304044`", "0.00002586796926458298`", 
            "0.024298194913154283`"},
          {"30", "0", "0.00003658699337713083`", "0.000012923645915305757`", 
            "0.009748126843679558`"},
          {"40", "0", "0.000016075264616598542`", "5.7260886191863765`*^-6", 
            "0.0038837953715240466`"},
          {"50", "0", "6.721325131376009`*^-6", "2.404066438073704`*^-6", 
            "0.0015412329912264263`"},
          {"60", "0", "2.7395661964017293`*^-6", "9.820339141577362`*^-7", 
            "0.0006102192191070504`"},
          {"70", "0", "1.1012437700623134`*^-6", "3.9523584882275964`*^-7", 
            "0.00024128305804627036`"},
          {"80", "0", "4.3924224252809337`*^-7", "1.5775251408833358`*^-7", 
            "0.00009533062148988153`"},
          {"90", "0", "1.7441951447928616`*^-7", "6.266702107513292`*^-8", 
            "0.00003764806577721411`"},
          {"100", "0", "6.908346081168418`*^-8", "2.482660713511378`*^-8", 
            "0.000014864113228033761`"},
          {"180", "0", "4.086895628713474`*^-11", "1.4691735586494916`*^-11", 
            "8.754945601241615`*^-9"},
          {"200", "0", "6.36628501296248`*^-12", "2.2885840034738046`*^-12", 
            "1.3637313893194229`*^-9"},
          {"300", "0", "5.837983882275271`*^-16", "2.0986707127459962`*^-16", 
            "1.2505377980938612`*^-13"},
          {"400", "0", "5.353402495700069`*^-20", "1.9244707304579792`*^-20", 
            "1.1467369005488578`*^-17"},
          {"500", "0", "4.9090432379025336`*^-24", "1.764730007460474`*^-24", 
            "1.051551985747554`*^-21"},
          {"600", "0", "4.501568025080489`*^-28", "1.6182485648431864`*^-28", 
            "9.642678962761351`*^-26"},
          {"700", "0", "4.127915298802901`*^-32", "1.4839258167163294`*^-32", 
            "8.842288240534123`*^-30"},
          {"800", "0", "3.7852776231378465`*^-36", "1.360752530461736`*^-36", 
            "8.108333963064758`*^-34"},
          {"900", "0", "3.4710805932362697`*^-40", "1.2478032448002246`*^-40",
             "7.435301572188802`*^-38"},
          {"1000", "0", "3.182963492764194`*^-44", "1.1442293164091295`*^-44",
             "6.818134245730716`*^-42"},
          {"2000", "0", "0", "0", "0"},
          {"3000", "0", "0", "0", "0"},
          {"4000", "0", "0", "0", "0"},
          {"5000", "0", "0", "0", "0"},
          {"6000", "0", "0", "0", "0"},
          {"7000", "0", "0", "0", "0"},
          {"8000", "0", "0", "0", "0"},
          {"9000", "0", "0", "0", "0"},
          {"10000", "0", "0", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nintake", 
          "Lung\nretention", "Urine\n24 hours", "Faecal\n24 hours", 
          "Wholebody"}}]]]], "Output",
  CellLabel->"Out[63]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, AMADAdultW[5], \ F, 1, 180, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Inhalation\>", 
      IntakeType \[Rule] \ "\<Constant\>", \ 
      ShowReport \[Rule] \ "\<BioassayTable\>"]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nintake"\), \("Thoracic\nLung"\), \("Urine\n24 \
hours"\), \("Faecal\n24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "0.0008082717969697772`", "0.17964444903582147`", 
            "3.9423203141819795`*^-8", "0.6671756618778399`"},
          {"2", "0.0008082717969697772`", "0.30186077838250475`", 
            "1.2825998621362198`*^-6", "1.1592533946491699`"},
          {"3", "0.0008082717969697772`", "0.3095429275950003`", 
            "7.033978615472757`*^-6", "1.5701017876228365`"},
          {"4", "0.0008082717969697772`", "0.31004205628164727`", 
            "0.000019419756852689145`", "1.9332263610760814`"},
          {"5", "0.0008082717969697772`", "0.31014500747223794`", 
            "0.00003841821224183329`", "2.2616166895244527`"},
          {"6", "0.0008082717969697772`", "0.31023734643767287`", 
            "0.0000629933929293142`", "2.5612013759166112`"},
          {"7", "0.0008082717969697772`", "0.31033759102953806`", 
            "0.00009187569615611508`", "2.835398663725158`"},
          {"8", "0.0008082717969697772`", "0.3104438395009508`", 
            "0.00012387219622719237`", "3.0866622255445937`"},
          {"9", "0.0008082717969697772`", "0.3105535816949516`", 
            "0.00015795695938274372`", "3.317012399491683`"},
          {"10", "0.0008082717969697772`", "0.3106647461314953`", 
            "0.00019328045763570455`", "3.5282243587146653`"},
          {"20", "0.0008082717969697772`", "0.31162713762007366`", 
            "0.0005166529454436828`", "4.880617476618223`"},
          {"30", "0.0008082717969697772`", "0.3121684344738198`", 
            "0.0007060344908059561`", "5.449226237666811`"},
          {"40", "0.0008082717969697772`", "0.31241927829437843`", 
            "0.0007950093391034521`", "5.68829677204287`"},
          {"50", "0.0008082717969697772`", "0.312526853915601`", 
            "0.0008334047164527108`", "5.788813549717679`"},
          {"60", "0.0008082717969697772`", "0.3125712869646664`", 
            "0.0008493140369637553`", "5.831075648727479`"},
          {"70", "0.0008082717969697772`", "0.3125892787969704`", 
            "0.000855767157094102`", "5.848844672506698`"},
          {"80", "0.0008082717969697772`", "0.3125964846043492`", 
            "0.0008583541569399215`", "5.856315626705951`"},
          {"90", "0.0008082717969697772`", "0.3125993527172426`", 
            "0.0008593844222900219`", "5.859456776008288`"},
          {"100", "0.0008082717969697772`", "0.3126004902541739`", 
            "0.000859793170672819`", "5.860777466602344`"},
          {"180", "0.0008082717969697772`", "0.31260123424266917`", 
            "0.0008600605699657215`", "5.861734654092452`"},
          {"200", "0.0008082717969697772`", "0.31260123461379496`", 
            "0.0008600607033799734`", "5.8617354243554525`"},
          {"300", "0.0008082717969697772`", "0.3126012346822664`", 
            "0.0008600607279943204`", "5.861735589731044`"},
          {"400", "0.0008082717969697772`", "0.31260123468227263`", 
            "0.0008600607279965807`", "5.861735589759593`"},
          {"500", "0.0008082717969697772`", "0.31260123468227263`", 
            "0.000860060727996579`", "5.861735589759598`"},
          {"600", "0.0008082717969697772`", "0.31260123468227263`", 
            "0.000860060727996579`", "5.861735589759598`"},
          {"700", "0.0008082717969697772`", "0.31260123468227263`", 
            "0.000860060727996579`", "5.861735589759598`"},
          {"800", "0.0008082717969697772`", "0.31260123468227263`", 
            "0.000860060727996579`", "5.861735589759598`"},
          {"900", "0.0008082717969697772`", "0.31260123468227263`", 
            "0.000860060727996579`", "5.861735589759598`"},
          {"1000", "0.0008082717969697772`", "0.31260123468227263`", 
            "0.000860060727996579`", "5.861735589759598`"},
          {"2000", "0.0008082717969697772`", "0.31260123468227263`", 
            "0.000860060727996579`", "5.861735589759598`"},
          {"3000", "0.0008082717969697772`", "0.31260123468227263`", 
            "0.000860060727996579`", "5.861735589759598`"},
          {"4000", "0.0008082717969697772`", "0.31260123468227263`", 
            "0.000860060727996579`", "5.861735589759598`"},
          {"5000", "0.0008082717969697772`", "0.31260123468227263`", 
            "0.000860060727996579`", "5.861735589759598`"},
          {"6000", "0.0008082717969697772`", "0.31260123468227263`", 
            "0.000860060727996579`", "5.861735589759598`"},
          {"7000", "0.0008082717969697772`", "0.31260123468227263`", 
            "0.000860060727996579`", "5.861735589759598`"},
          {"8000", "0.0008082717969697772`", "0.31260123468227263`", 
            "0.000860060727996579`", "5.861735589759598`"},
          {"9000", "0.0008082717969697772`", "0.31260123468227263`", 
            "0.000860060727996579`", "5.861735589759598`"},
          {"10000", "0.0008082717969697772`", "0.31260123468227263`", 
            "0.000860060727996579`", "5.861735589759598`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nintake", 
          "Thoracic\nLung", "Urine\n24 hours", "Faecal\n24 hours", 
          "Wholebody"}}]]]], "Output",
  CellLabel->"Out[64]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs1, AMADAdultW[5], \ F, 1, \ 180, 
      Log[2]/8.0, IntakeWay \[Rule] \ "\<Inhalation\>", 
      IntakeType \[Rule] \ "\<Continuous\>", \ 
      ShowReport \[Rule] \ "\<BioassayTable\>"]\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \("Option not available for inhalation"\)], "Output",
  CellLabel->"Out[65]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs2, AMADAdultW[5], \ F, 1, 180, 
      Log[2]/8.0, IntakeWay \[Rule] \ "\<Inhalation\>", 
      IntakeType \[Rule] \ "\<MultiInputs\>", \ 
      ShowReport \[Rule] \ "\<BioassayTable\>"]\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nlast intake"\), "\<\"Lung\"\>", \("Urine\n24 hours"\
\), \("Faecal\n24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "1.536539771538759`*^-44", "1.9774027812390629`", 
            "0.000058885528744821204`", "2.3640156950570277`"},
          {"2", "0", "0.1629112411693956`", "0.00010116628446496957`", 
            "1.5184716140620291`"},
          {"3", "0", "0.010043140018160306`", "0.00016330905763460384`", 
            "1.2181769242569482`"},
          {"4", "0", "0.001423238163071188`", "0.00022723587045245285`", 
            "1.0600771356518088`"},
          {"5", "0", "0.001047326663589477`", "0.000281795153411415`", 
            "0.9520952442748574`"},
          {"6", "0", "0.0011079875822749023`", "0.0003238817383165195`", 
            "0.8653448314938231`"},
          {"7", "0", "0.0011635008431930974`", "0.0003539715209390032`", 
            "0.7898824613609228`"},
          {"8", "0", "0.0011942981710764903`", "0.00037366564848514695`", 
            "0.7220406603953462`"},
          {"9", "0", "0.0012041261977474634`", "0.0003847377698147995`", 
            "0.6602835352411309`"},
          {"10", "0", "0.0011972698609678547`", "0.00038882230417977516`", 
            "0.6038150068898926`"},
          {"20", "0", "0.0007697544486108974`", "0.00026713097235800246`", 
            "0.24492030108129437`"},
          {"30", "0", "0.0003722939834687759`", "0.00013162560125739726`", 
            "0.09819108997416645`"},
          {"40", "0", "0.0001627178544736161`", "0.0000579857369315799`", 
            "0.03910538196960539`"},
          {"50", "0", "0.00006785746971819614`", "0.00002427648866572823`", 
            "0.015514945529962836`"},
          {"60", "0", "0.000027619638219477614`", "9.901831768481731`*^-6", 
            "0.006142016330488527`"},
          {"70", "0", "0.000011093857393506436`", "3.98185269425472`*^-6", 
            "0.002428392424729072`"},
          {"80", "0", "4.42294860713357`*^-6", "1.5885507120680371`*^-6", 
            "0.0009594121779451085`"},
          {"90", "0", "1.7558724522647268`*^-6", "6.308799823579256`*^-7", 
            "0.00037888224736879893`"},
          {"100", "0", "6.953579321951383`*^-7", "2.4989489435075427`*^-7", 
            "0.0001495870686378259`"},
          {"180", "0", "4.1128286101697356`*^-10", "1.4784963091820744`*^-10",
             "8.810477608578058`*^-8"},
          {"200", "0", "6.406670066775953`*^-11", "2.3031019622024502`*^-11", 
            "1.3723811842161949`*^-8"},
          {"300", "0", "5.875012155796842`*^-15", "2.1119818417490385`*^-15", 
            "1.2584695136108164`*^-12"},
          {"400", "0", "5.387357217283081`*^-19", "1.9366769615246545`*^-19", 
            "1.1540102434568625`*^-16"},
          {"500", "0", "4.940179547186894`*^-23", "1.7759230600898348`*^-23", 
            "1.058221604708786`*^-20"},
          {"600", "0", "4.530119864511323`*^-27", "1.628512537958052`*^-27", 
            "9.703839034083256`*^-25"},
          {"700", "0", "4.154097192374867`*^-31", "1.49333782858052`*^-31", 
            "8.898371719153392`*^-29"},
          {"800", "0", "3.809286288180335`*^-35", "1.3693832981266062`*^-35", 
            "8.159762231640117`*^-33"},
          {"900", "0", "3.493096418628395`*^-39", "1.2557176154645426`*^-39", 
            "7.482461036504796`*^-37"},
          {"1000", "0", "3.203151894278649`*^-43", "1.1514867546180422`*^-43",
             "6.861379237953477`*^-41"},
          {"2000", "0", "0", "0", "0"},
          {"3000", "0", "0", "0", "0"},
          {"4000", "0", "0", "0", "0"},
          {"5000", "0", "0", "0", "0"},
          {"6000", "0", "0", "0", "0"},
          {"7000", "0", "0", "0", "0"},
          {"8000", "0", "0", "0", "0"},
          {"9000", "0", "0", "0", "0"},
          {"10000", "0", "0", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nlast intake", 
          "Lung", "Urine\n24 hours", "Faecal\n24 hours", 
          "Wholebody"}}]]]], "Output",
  CellLabel->"Out[66]//TableForm="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Inhalation\",ShowReport\[Rule] \"GraphicReport\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, AMADAdultW[5], \ F, 1, 5, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Inhalation\>", 
      IntakeType \[Rule] \ "\<Acute\>", \ 
      ShowReport \[Rule] \ "\<GraphicReport\>"]\)], "Input",
  CellLabel->"In[67]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 1.36255 0.603319 0.0026932 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.26374 -0.0125 -11 -12.5625 ]
[.26374 -0.0125 11 0 ]
[.43398 -0.0125 -5 -12.5625 ]
[.43398 -0.0125 5 0 ]
[.67391 -0.0125 -5 -12.5625 ]
[.67391 -0.0125 5 0 ]
[.97619 -0.0125 -5 -12.5625 ]
[.97619 -0.0125 5 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 4e-005 -54.875 -6.6875 ]
[-0.0125 4e-005 0 6.6875 ]
[-0.0125 .10508 -54.875 -6.6875 ]
[-0.0125 .10508 0 6.6875 ]
[-0.0125 .21011 -54.875 -6.6875 ]
[-0.0125 .21011 0 6.6875 ]
[-0.0125 .31515 -54.875 -6.6875 ]
[-0.0125 .31515 0 6.6875 ]
[-0.0125 .42018 -50.6875 -6.6875 ]
[-0.0125 .42018 0 6.6875 ]
[-0.0125 .52522 -50.6875 -6.6875 ]
[-0.0125 .52522 0 6.6875 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12.5625 ]
[ 0 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.26374 0 m
.26374 .00625 L
s
gsave
.26374 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.43398 0 m
.43398 .00625 L
s
gsave
.43398 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.67391 0 m
.67391 .00625 L
s
gsave
.67391 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.08021 0 m
.08021 .00375 L
s
.1317 0 m
.1317 .00375 L
s
.17906 0 m
.17906 .00375 L
s
.22292 0 m
.22292 .00375 L
s
.30193 0 m
.30193 .00375 L
s
.33781 0 m
.33781 .00375 L
s
.37163 0 m
.37163 .00375 L
s
.40363 0 m
.40363 .00375 L
s
.84415 0 m
.84415 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 4e-005 m
.00625 4e-005 L
s
gsave
-0.0125 4e-005 -115.875 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(224) show
113.375 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10508 m
.00625 .10508 L
s
gsave
-0.0125 .10508 -115.875 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(185) show
113.375 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .21011 m
.00625 .21011 L
s
gsave
-0.0125 .21011 -115.875 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(146) show
113.375 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .31515 m
.00625 .31515 L
s
gsave
-0.0125 .31515 -115.875 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(107) show
113.375 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .42018 m
.00625 .42018 L
s
gsave
-0.0125 .42018 -111.688 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(68) show
109.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .52522 m
.00625 .52522 L
s
gsave
-0.0125 .52522 -111.688 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(29) show
109.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Acute) show
99.000 12.813 moveto
(intake) show
141.000 12.813 moveto
(in) show
159.000 12.813 moveto
(t) show
171.000 12.813 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
183.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
189.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .48304 m
.11279 .46404 L
.19666 .44332 L
.26588 .42386 L
.32559 .40514 L
.38316 .38522 L
.43374 .36605 L
.48314 .34566 L
.52713 .32603 L
.56657 .30714 L
.60582 .28704 L
.64131 .26769 L
.67354 .24909 L
.70603 .22928 L
.7357 .21021 L
.76569 .18994 L
.79321 .17042 L
.81852 .15164 L
.84432 .13165 L
.86814 .11241 L
.89245 .09196 L
.91496 .07226 L
.93584 .05331 L
.95726 .03314 L
.97619 .01472 L
s
0 1 0 r
1.5 Mabswid
[ ] 0 setdash
.02381 .60184 m
.02672 .60184 L
.02936 .60184 L
.0324 .60184 L
.03525 .60184 L
.03787 .60184 L
.04029 .60184 L
.04292 .60183 L
.04571 .60183 L
.05147 .60183 L
.05681 .60182 L
.0688 .60179 L
.08018 .60176 L
.0904 .60172 L
.11279 .60162 L
.19666 .60111 L
.26611 .60056 L
.326 .60003 L
.38371 .59946 L
.43441 .59891 L
.48392 .59833 L
.528 .59777 L
.56752 .59723 L
.60684 .59666 L
.64239 .59612 L
.67467 .5956 L
.70721 .59507 L
.73692 .59457 L
.76695 .59408 L
.7945 .59364 L
.81985 .59328 L
.84568 .59297 L
.86953 .59275 L
.89158 .5926 L
.90258 .59255 L
.9142 .5925 L
.92516 .59247 L
.93066 .59246 L
.93648 .59244 L
.94196 .59244 L
.94689 .59243 L
.95153 .59242 L
.9564 .59242 L
.95879 .59242 L
.9614 .59242 L
.9638 .59242 L
.96598 .59242 L
.96721 .59242 L
.96854 .59242 L
.96995 .59242 L
Mistroke
.97064 .59242 L
.97128 .59242 L
.97192 .59242 L
.97252 .59242 L
.97315 .59242 L
.9735 .59242 L
.97383 .59242 L
.97438 .59242 L
.97498 .59242 L
.97561 .59242 L
.97619 .59242 L
Mfstroke
0 0 1 r
2 Mabswid
[ 1 8 ] 0 Mabsdash
.02381 .58534 m
.11279 .58607 L
.19666 .58673 L
.26588 .58726 L
.32559 .58769 L
.38316 .58809 L
.43374 .58842 L
.48314 .58872 L
.52713 .58897 L
.56657 .58919 L
.60582 .58939 L
.64131 .58957 L
.67354 .58972 L
.70603 .58986 L
.7357 .58999 L
.76569 .59011 L
.79321 .59021 L
.81852 .5903 L
.84432 .59039 L
.86814 .59047 L
.89245 .59054 L
.91496 .59061 L
.93584 .59067 L
.95726 .59073 L
.97619 .59077 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0227273 0.227273 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.0681818 0.361111 0.295455 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .18182 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Lungs) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.386364 0.361111 0.613636 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
1.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .5 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.704545 0.361111 0.931818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
2 Mabswid
[ 1 8 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .81818 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[67]:=",
  ImageSize->{600, 294.25},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[67]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, AMADAdultW[5], \ F, 1, 180, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Inhalation\>", 
      IntakeType \[Rule] \ "\<Constant\>", \ 
      ShowReport \[Rule] \ "\<GraphicReport\>"]\)], "Input",
  CellLabel->"In[68]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.422291 0.603319 0.0794956 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .12635 -46.5 -6.6875 ]
[-0.0125 .12635 0 6.6875 ]
[-0.0125 .28534 -40 -6.28125 ]
[-0.0125 .28534 0 6.28125 ]
[-0.0125 .44433 -28 -6.28125 ]
[-0.0125 .44433 0 6.28125 ]
[-0.0125 .60332 -10 -6.28125 ]
[-0.0125 .60332 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35242 0 m
.35242 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12635 m
.00625 .12635 L
s
gsave
-0.0125 .12635 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .28534 m
.00625 .28534 L
s
gsave
-0.0125 .28534 -101 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0001) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .44433 m
.00625 .44433 L
s
gsave
-0.0125 .44433 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -71 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .05314 m
.00375 .05314 L
s
0 .07561 m
.00375 .07561 L
s
0 .0891 m
.00375 .0891 L
s
0 .09878 m
.00375 .09878 L
s
0 .10633 m
.00375 .10633 L
s
0 .11252 m
.00375 .11252 L
s
0 .11777 m
.00375 .11777 L
s
0 .12232 m
.00375 .12232 L
s
0 .21214 m
.00375 .21214 L
s
0 .2346 m
.00375 .2346 L
s
0 .24809 m
.00375 .24809 L
s
0 .25777 m
.00375 .25777 L
s
0 .26532 m
.00375 .26532 L
s
0 .27151 m
.00375 .27151 L
s
0 .27676 m
.00375 .27676 L
s
0 .28131 m
.00375 .28131 L
s
0 .37113 m
.00375 .37113 L
s
0 .39359 m
.00375 .39359 L
s
0 .40708 m
.00375 .40708 L
s
0 .41676 m
.00375 .41676 L
s
0 .42431 m
.00375 .42431 L
s
0 .4305 m
.00375 .4305 L
s
0 .43575 m
.00375 .43575 L
s
0 .4403 m
.00375 .4403 L
s
0 .53012 m
.00375 .53012 L
s
0 .55258 m
.00375 .55258 L
s
0 .56607 m
.00375 .56607 L
s
0 .57575 m
.00375 .57575 L
s
0 .5833 m
.00375 .5833 L
s
0 .58949 m
.00375 .58949 L
s
0 .59474 m
.00375 .59474 L
s
0 .5993 m
.00375 .5993 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Constant) show
117.000 12.813 moveto
(intake) show
153.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .35748 m
.41107 .35748 L
.53436 .35748 L
.60372 .35748 L
.65224 .35748 L
.69278 .35748 L
.72483 .35748 L
.75369 .35748 L
.77776 .35748 L
.79827 .35748 L
.81784 .35748 L
.83489 .35748 L
.84991 .35748 L
.86466 .35748 L
.87782 .35748 L
.89084 .35748 L
.90257 .35748 L
.91318 .35748 L
.92384 .35748 L
.93355 .35748 L
.94333 .35748 L
.95229 .35748 L
.96051 .35748 L
.96887 .35748 L
.97619 .35748 L
s
0 1 0 r
1.5 Mabswid
[ ] 0 setdash
.02381 .54405 m
.06042 .55342 L
.08838 .55783 L
.1161 .56036 L
.13894 .56156 L
.1578 .56215 L
.17363 .56245 L
.18958 .56265 L
.20509 .56276 L
.21944 .56282 L
.23372 .56285 L
.24625 .56287 L
.25701 .56288 L
.26883 .56289 L
.2752 .56289 L
.28092 .56289 L
.30107 .5629 L
.33501 .56291 L
.36579 .56292 L
.41107 .56294 L
.45102 .56296 L
.48098 .56298 L
.53436 .56303 L
.6058 .56309 L
.65542 .56313 L
.69308 .56315 L
.70978 .56316 L
.72615 .56316 L
.7414 .56316 L
.75476 .56317 L
.76709 .56317 L
.7778 .56317 L
.78805 .56317 L
.79874 .56317 L
.80824 .56317 L
.81796 .56317 L
.82683 .56317 L
.83574 .56317 L
.84369 .56317 L
.8508 .56317 L
.8584 .56317 L
.86504 .56317 L
.87166 .56317 L
.87857 .56317 L
.88494 .56317 L
.89145 .56317 L
.8973 .56317 L
.90262 .56317 L
.90833 .56317 L
.9134 .56317 L
Mistroke
.91846 .56317 L
.92382 .56317 L
.92877 .56317 L
.93391 .56317 L
.93901 .56317 L
.94368 .56317 L
.94822 .56317 L
.9523 .56317 L
.95637 .56317 L
.96073 .56317 L
.96476 .56317 L
.96898 .56317 L
.97272 .56317 L
.97619 .56317 L
Mfstroke
0 0 1 r
2 Mabswid
[ 1 8 ] 0 Mabsdash
.02381 .01472 m
.20509 .1788 L
.30107 .24238 L
.41107 .29508 L
.48498 .32062 L
.53436 .33379 L
.60287 .3471 L
.63172 .35104 L
.65536 .35359 L
.67446 .35523 L
.69343 .35652 L
.71037 .35742 L
.72677 .35809 L
.74071 .35853 L
.75461 .35886 L
.76768 .35909 L
.7793 .35925 L
.79007 .35936 L
.79954 .35943 L
.80955 .35949 L
.81819 .35953 L
.82671 .35956 L
.8355 .35958 L
.84355 .35959 L
.85168 .3596 L
.85895 .35961 L
.86548 .35962 L
.87248 .35962 L
.87863 .35962 L
.88474 .35962 L
.89118 .35962 L
.8971 .35963 L
.90319 .35963 L
.90866 .35963 L
.91365 .35963 L
.91901 .35963 L
.92378 .35963 L
.92854 .35963 L
.93361 .35963 L
.93829 .35963 L
.94316 .35963 L
.94799 .35963 L
.95243 .35963 L
.95675 .35963 L
.96063 .35963 L
.9645 .35963 L
.96867 .35963 L
.97233 .35963 L
.97619 .35963 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0227273 0.227273 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.0681818 0.361111 0.295455 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .18182 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Lungs) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.386364 0.361111 0.613636 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
1.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .5 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.704545 0.361111 0.931818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
2 Mabswid
[ 1 8 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .81818 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{600, 294.25},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[68]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs1, AMADAdultW[5], \ F, 1, 180, 
      Log[2]/8.0, IntakeWay \[Rule] \ "\<Inhalation\>", 
      IntakeType \[Rule] \ "\<Continuous\>", \ 
      ShowReport \[Rule] \ "\<GraphicReport\>"]\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \("Option not available for inhalation"\)], "Output",
  CellLabel->"Out[69]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs2, AMADAdultW[5], \ F, 1, 5, 
      Log[2]/8.0, IntakeWay \[Rule] \ "\<Inhalation\>", 
      IntakeType \[Rule] \ "\<MultiInputs\>", \ 
      ShowReport \[Rule] \ "\<GraphicReport\>"]\)], "Input",
  CellLabel->"In[70]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 1.36255 0.602518 0.00269998 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.26374 -0.0125 -11 -12.5625 ]
[.26374 -0.0125 11 0 ]
[.43398 -0.0125 -5 -12.5625 ]
[.43398 -0.0125 5 0 ]
[.67391 -0.0125 -5 -12.5625 ]
[.67391 -0.0125 5 0 ]
[.97619 -0.0125 -5 -12.5625 ]
[.97619 -0.0125 5 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .00042 -54.875 -6.6875 ]
[-0.0125 .00042 0 6.6875 ]
[-0.0125 .10572 -54.875 -6.6875 ]
[-0.0125 .10572 0 6.6875 ]
[-0.0125 .21102 -54.875 -6.6875 ]
[-0.0125 .21102 0 6.6875 ]
[-0.0125 .31632 -54.875 -6.6875 ]
[-0.0125 .31632 0 6.6875 ]
[-0.0125 .42162 -50.6875 -6.6875 ]
[-0.0125 .42162 0 6.6875 ]
[-0.0125 .52692 -50.6875 -6.6875 ]
[-0.0125 .52692 0 6.6875 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12.5625 ]
[ 0 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.26374 0 m
.26374 .00625 L
s
gsave
.26374 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.43398 0 m
.43398 .00625 L
s
gsave
.43398 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.67391 0 m
.67391 .00625 L
s
gsave
.67391 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.08021 0 m
.08021 .00375 L
s
.1317 0 m
.1317 .00375 L
s
.17906 0 m
.17906 .00375 L
s
.22292 0 m
.22292 .00375 L
s
.30193 0 m
.30193 .00375 L
s
.33781 0 m
.33781 .00375 L
s
.37163 0 m
.37163 .00375 L
s
.40363 0 m
.40363 .00375 L
s
.84415 0 m
.84415 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .00042 m
.00625 .00042 L
s
gsave
-0.0125 .00042 -115.875 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(223) show
113.375 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10572 m
.00625 .10572 L
s
gsave
-0.0125 .10572 -115.875 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(184) show
113.375 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .21102 m
.00625 .21102 L
s
gsave
-0.0125 .21102 -115.875 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(145) show
113.375 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .31632 m
.00625 .31632 L
s
gsave
-0.0125 .31632 -115.875 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(106) show
113.375 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .42162 m
.00625 .42162 L
s
gsave
-0.0125 .42162 -111.688 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(67) show
109.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .52692 m
.00625 .52692 L
s
gsave
-0.0125 .52692 -111.688 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(28) show
109.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Multiple) show
117.000 12.813 moveto
(intake) show
153.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .48422 m
.11279 .46517 L
.19666 .4444 L
.26588 .42489 L
.32559 .40612 L
.38316 .38615 L
.43374 .36693 L
.48314 .3465 L
.52713 .32681 L
.56657 .30788 L
.60582 .28773 L
.64131 .26833 L
.67354 .24968 L
.70603 .22982 L
.7357 .21071 L
.76569 .19038 L
.79321 .17081 L
.81852 .15198 L
.84432 .13195 L
.86814 .11266 L
.89245 .09216 L
.91496 .07241 L
.93584 .0534 L
.95726 .03319 L
.97619 .01472 L
s
0 1 0 r
1.5 Mabswid
[ ] 0 setdash
.02381 .60332 m
.02672 .60332 L
.02936 .60332 L
.0324 .60332 L
.03525 .60332 L
.03787 .60332 L
.04029 .60332 L
.04292 .60331 L
.04571 .60331 L
.05147 .6033 L
.05681 .6033 L
.0688 .60327 L
.08018 .60323 L
.0904 .6032 L
.11279 .6031 L
.19666 .60258 L
.26611 .60204 L
.326 .6015 L
.38371 .60093 L
.43441 .60039 L
.48392 .5998 L
.528 .59924 L
.56752 .59871 L
.60684 .59815 L
.64239 .59761 L
.67467 .59711 L
.70721 .5966 L
.73692 .59614 L
.76695 .5957 L
.7945 .59533 L
.81985 .59505 L
.84568 .59482 L
.8581 .59473 L
.86953 .59467 L
.88037 .59462 L
.89158 .59457 L
.90305 .59454 L
.91336 .59452 L
.92418 .5945 L
.93406 .59449 L
.93965 .59448 L
.94488 .59448 L
.94954 .59447 L
.95213 .59447 L
.95454 .59447 L
.95689 .59447 L
.9594 .59447 L
.96083 .59447 L
.96218 .59447 L
.96339 .59447 L
Mistroke
.96407 .59447 L
.9647 .59447 L
.96505 .59447 L
.96537 .59447 L
.96573 .59447 L
.9661 .59447 L
.96672 .59447 L
.96708 .59447 L
.96741 .59447 L
.96803 .59447 L
.96859 .59447 L
.96923 .59447 L
.96985 .59447 L
.9712 .59447 L
.97245 .59447 L
.97527 .59447 L
.97619 .59447 L
Mfstroke
0 0 1 r
2 Mabswid
[ 1 8 ] 0 Mabsdash
.02381 .5911 m
.11279 .59119 L
.19666 .5913 L
.26588 .59141 L
.32559 .59151 L
.38316 .59163 L
.43374 .59173 L
.48314 .59184 L
.52713 .59194 L
.56657 .59203 L
.60582 .59213 L
.64131 .59221 L
.67354 .59229 L
.70603 .59237 L
.7357 .59244 L
.76569 .59251 L
.79321 .59257 L
.81852 .59263 L
.84432 .59268 L
.86814 .59273 L
.89245 .59278 L
.91496 .59282 L
.93584 .59286 L
.95726 .5929 L
.97619 .59293 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0227273 0.227273 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.0681818 0.361111 0.295455 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .18182 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Lungs) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.386364 0.361111 0.613636 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
1.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .5 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.704545 0.361111 0.931818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
2 Mabswid
[ 1 8 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .81818 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{600, 294.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000>40001^A000`40O003h00OogooogooogooQgoo
003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mo
oomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogoo
ogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7
Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00
ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOooo
OoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomo
ohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo
003oOoooOoooOon7Ool00?mooomooomoohMoo`00N7oo1`00L7oo1`0017oo0P001Woo1000CGoo1P00
Ngoo1000WGoo1000ogoo37oo001kOol00`00Oomoo`1dOol00`00Oomoo`05Ool20005Ool00`00Oomo
o`02Ool00`00Oomoo`1:Ool00`00Oomoo`02Ool00`00Oomoo`1hOol00`00Oomoo`02Ool00`00Oomo
o`2IOol00`00Oomoo`02Ool00`00Oomoo`3oOol9Ool007]oo`03001oogoo07Aoo`03001oogoo015o
o`03001oogoo04]oo`03001oogoo085oo`03001oogoo09ioo`03001oogoo0?moo`Uoo`00Ngoo00<0
07ooOol0M7oo00<007ooOol04Goo00<007ooOol0C7oo00<007ooOol0P7oo00<007ooOol0WWoo00<0
07ooOol0ogoo2Goo001kOol00`00Oomoo`1dOol00`00Oomoo`0AOol00`00Oomoo`1=Ool00`00Oomo
o`1mOol2002QOol00`00Oomoo`3oOol9Ool007]oo`03001oogoo07Aoo`03001oogoo00eoo`@0055o
o`03001oogoo07ioo`03001oogoo09Yoo`@00?moo`aoo`00Ngoo00<007ooOol0M7oo00<007ooOol0
3Goo00<007ooOol0CWoo00<007ooOol00Woo00<007ooOol0OGoo00<007ooOol0VWoo00<007ooOol0
ogoo3Goo001iOol3001dOol3000?Ool00`00Oomoo`1>Ool00`00Oomoo`02Ool00`00Oomoo`1hOol0
0`00Oomoo`02Ool00`00Oomoo`2JOol00`00Oomoo`3oOol=Ool007]oo`03001oogoo07Aoo`03001o
ogoo00eoo`D004eoo`@007aoo`@009eoo`D00?moo`]oo`00ogooogooogooQgoo003oOoooOoooOon7
Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOon[Ool3003HOol00?mooomoojeoo`03
001oogoo0=Ioo`00ogooogoo[Goo00<007ooOol0eWoo000JOol70004Ool20007Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool70003Ool4003oOoooOomAOol300000goo00000004Ool50005Ool20005Ool5
003=Ool001eoo`03001oogoo00Eoo`8000Qoo`05001oogooOol00009Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`3oOoooOom=Ool01000Oomoogoo0P0017oo00D007ooOomoo`0000Ioo`80
00Eoo`03001oogoo009oo`03001oogoo0<Yoo`007Goo00<007ooOol047oo00<007oo00002Woo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol0ogooogooCGoo00<007ooOol00Woo00<007ooOol0
0Woo00D007ooOomoo`0000Eoo`04001oogoo0009Ool00`00Oomoo`3:Ool001eoo`03001oogoo015o
o`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo02=oool00?l001X0011o
o`03001oogoo009oo`03001oogoo00=oo`@000Eoo`04001oogoo0005Ool4003=Ool001eoo`03001o
ogoo011oo`03001oo`0000Yoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo02=oo`03001o
ogoo00Yoo`03001oogoo01]oo`03001oogoo01Uoo`03001oogoo01Ioo`03001oogoo01Eoo`03001o
ogoo019oo`03001oogoo019oo`03001oogoo011oo`03001oogoo00moo`03001oogoo00ioo`03001o
ogoo00eoo`03001oogoo07eoo`03001oogoo05Qoo`03001oogoo04Aoo`03001oogoo01]oo`04001o
ogooOol20004Ool01@00Oomoogoo000017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001o
ogoo0<Yoo`007Goo00<007ooOol03goo00D007ooOomoo`0000Uoo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo02=oo`03001oogoo00Yoo`03001oogoo01]oo`03001oogoo01Uoo`03001oogoo
01Ioo`03001oogoo01Eoo`03001oogoo019oo`03001oogoo019oo`03001oogoo011oo`03001oogoo
00moo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo07eoo`03001oogoo05Qoo`03001oogoo
04Aoo`03001oogoo01aoo`<00003Ool007oo00Aoo`<000Aoo`<0009oo`<000=oo`D00<aoo`007Goo
00<007ooOol03Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol01goo1@000Woo1@000goo0`002Woo00<007ooOol02Woo00<007ooOol0OGoo00<007oo
Ool0F7oo00<007ooOol0OGoo00<007ooOol0Wgoo00<007ooOol087oo00<007ooOol0iWoo000KOol3
000MOol30005Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
1@00Oomoogoo00002Goo00<007ooOol0ogooogoo;7oo00<007ooOol0iWoo000MOol00`00Oomoo`0M
Ool00`00Oomoo`04Ool40004Ool50002Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`3oOoooOol[Ool2003XOol005Aoo`03001oogoo00Aoo`03001oogoo00Aoo`8000Yo
o`03001oogoo0?mooomooomooaIoo`00EGoo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1goo00<007ooOol0ogooogooogoo5Woo001BOol01@00Oomoogoo00000Woo00D007ooOomoo`00009o
o`05001oogooOol00009Ool00`00Oomoo`3oOoooOol9Ool00g`0Oomoo`3oOol:Ool005=oo`<000Ao
o`<000Aoo`<000Yoo`03001oogoo0?mooomooomooaIoo`00KWoo00<007ooOol0ogooogooogoo5Woo
001^Ool00`00Oomoo`3oOoooOoooOolFOol006ioo`03001oogoo0?mooomoo`Eoo`03O01oogoo0?mo
o`ioo`00KWoo00<007ooOol0ogooogoo17oo00=l07ooOol0ogoo3goo001^Ool00`00Oomoo`3oOooo
Ool2Ool2O03oOolBOol006ioo`03001oogoo0?mooomoo`5oo`03O01oogoo0?mooa9oo`00KWoo00<0
07ooOol0ogooogoo00=l07ooOol0ogoo4goo001^Ool00`00Oomoo`3oOoooOoooOolFOol006ioo`03
001oogoo0?mooomooomooaIoo`00KWoo00<007ooOol0ogooogooogoo5Woo001^Ool00`00Oomoo`3o
OookOol00g`0Oomoo`3oOolGOol006ioo`03001oogoo0?moooYoo`03O01oogoo0?mooaQoo`00KWoo
00<007ooOol0ogoonGoo00=l07ooOol0ogoo6Goo001^Ool00`00Oomoo`3oOoohOol00g`0Oomoo`3o
OolJOol006ioo`03001oogoo0?moooMoo`03O01oogoo0?mooa]oo`00KWoo00<007ooOol0ogooogoo
ogoo5Woo001^Ool00`00Oomoo`3oOoooOoooOolFOol006ioo`03001oogoo0?mooomooomooaIoo`00
KWoo00<007ooOol0ogooogooogoo5Woo001^Ool00`00Oomoo`3oOoobOol00g`0Oomoo`3oOolPOol0
06ioo`03001oogoo0?mooo5oo`03O01oogoo0?moob5oo`00KWoo00<007ooOol0ogool7oo00=l07oo
Ool0ogoo8Woo001^Ool00`00Oomoo`3oOoo_Ool00g`0Oomoo`3oOolSOol006ioo`03001oogoo0?mo
onioo`03O01oogoo0?moobAoo`00KWoo00<007ooOol0ogooogooogoo5Woo001^Ool00`00Oomoo`3o
OoooOoooOolFOol006ioo`03001oogoo0?mooomooomooaIoo`00KWoo00<007ooOol0ogoojGoo00=l
07ooOol0ogoo:Goo001^Ool00`00Oomoo`3oOooXOol00g`0Oomoo`3oOolZOol006ioo`03001oogoo
0?moonMoo`03O01oogoo0?moob]oo`00KWoo00<007ooOol0ogooiWoo00=l07ooOol0ogoo;7oo001^
Ool00`00Oomoo`3oOooUOol00g`0Oomoo`3oOol]Ool006ioo`03001oogoo0?mooomooomooaIoo`00
KWoo00<007ooOol0ogooogooogoo5Woo001^Ool00`00Oomoo`3oOoooOoooOolFOol006ioo`03001o
ogoo0?moon1oo`03O01oogoo0?mooc9oo`00KWoo00<007ooOol0ogooggoo00=l07ooOol0ogoo<goo
001^Ool00`00Oomoo`3oOooNOol00g`0Oomoo`3oOoldOol006ioo`03001oogoo0?moomeoo`03O01o
ogoo0?moocEoo`00KWoo00<007ooOol0ogoog7oo00=l07ooOol0ogoo=Woo001^Ool00`00Oomoo`3o
OoooOoooOolFOol006ioo`03001oogoo0?mooomooomooaIoo`00KWoo00<007ooOol0ogooegoo00=l
07ooOol0ogoo>goo000JOol70004Ool20007Ool00`00Oomoo`03Ool00`00Oomoo`03Ool70003Ool4
000VOol00`00Oomoo`3oOooFOol00g`0Oomoo`3oOollOol001eoo`03001oogoo00Eoo`8000Qoo`05
001oogooOol00009Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0SOol00`00Oomoo`3o
OooEOol00g`0Oomoo`3oOolmOol001eoo`03001oogoo011oo`03001oo`0000Yoo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo02=oo`03001oogoo0?moomAoo`03O01oogoo0?moocioo`007Goo
00<007ooOol04Goo00<007ooOol02Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol08goo
1@00ogoodGoo00=l07ooOol0ogoo?goo000MOol00`00Oomoo`0@Ool00`00Ool0000:Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`0SOol00`00Oomoo`3oOoooOoooOolFOol001eoo`03001o
ogoo00moo`05001oogooOol00009Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0SOol0
0`00Oomoo`3oOoooOoooOolFOol001eoo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00Io
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Moo`D000=oo`<000Eoo`<000Uoo`03001o
ogoo0?mooomooomooaIoo`006goo0`007Goo0`001Goo00<007ooOol00Woo00<007ooOol02Goo00<0
07ooOol00Woo00D007ooOomoo`0000Eoo`03001oogoo00Qoo`03001oogoo0?moolioo`03O01oogoo
0?moodAoo`007Goo00<007ooOol07Goo00<007ooOol017oo100017oo1@000goo00<007ooOol00Woo
00D007ooOomoo`00009oo`D000Uoo`03001oogoo0?mooleoo`03O01oogoo08=oojX001Moo`00E7oo
00<007ooOol00goo0`000goo00@007ooOol000Yoo`03001oogoo0?mool]oo`9l08IoojX001Moo`00
E7oo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oo`0000Yoo`03001oogoo0?moolYoo`03
O01oogoo08IoojX001Moo`00E7oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`8000Yoo`03001o
ogoo0?moolUoo`03O01oogoo08MoojX001Moo`00Dgoo0P001Goo0`001Woo00<007ooOol027oo00<0
07ooOol0ogooogooE7ooZP005goo001^Ool00`00Oomoo`3oOoooOomDOonZ000GOol006ioo`03001o
ogoo0?mooomoodeook4001Moo`00KWoo00<007ooOol0ogooaGoo00=l07ooOol0Q7oo00<007ooOol0
Ygoo1`005goo001^Ool00`00Oomoo`3oOoo3Ool2O027Ool00`00Oomoo`2WOol7000GOol006ioo`03
001oogoo0?mool9oo`03O01oogoo08Moo`03001oogoo0:Moo`L001Moo`00KWoo00<007ooOol0ogoo
`Goo00=l07ooOol0R7oo00<007ooOol0Ygoo1`005goo001^Ool00`00Oomoo`3oOoo0Ool00g`0Oomo
o`29Ool00`00Oomoo`2WOol7000GOol006ioo`03001oogoo0?mooomoodeoo`03001oogoo0:Moo`L0
01Moo`00KWoo00<007ooOol0ogooogooCGoo00<007ooOol0Ygoo1`005goo001^Ool00`00Oomoo`3o
OonkOol00g`0Oomoo`2>Ool00`00Oomoo`2WOol7000GOol006ioo`03001oogoo0?mookYoo`03O01o
ogoo08moo`03001oogoo0:Moo`L001Moo`00KWoo00<007ooOol0ogoo^Goo00=l07ooOol0T7oo00<0
07ooOol0Ygoo1`005goo001^Ool00`00Oomoo`3oOonhOol00g`0Oomoo`2AOol00`00Oomoo`2WOol7
000GOol006ioo`03001oogoo0?mookMoo`03O01oogoo099oo`03001oogoo0:Moo`L001Moo`00KWoo
00<007ooOol0ogooogooCGoo00<007ooOol0Ygoo1`005goo001^Ool00`00Oomoo`3oOoooOom=Ool0
0`00Oomoo`2WOol7000GOol006ioo`03001oogoo0?mook9oo`03O01oogoo09Moo`03001oogoo0:Mo
o`L001Moo`00KWoo00<007ooOol0ogoo/Goo00=l07ooOol0V7oo00<007ooOol0Ygoo1`005goo001^
Ool00`00Oomoo`3oOon_Ool2O02KOol00`00Oomoo`2WOol7000GOol006ioo`03001oogoo0?moojio
o`03O01oogoo09]oo`03001oogoo0:Moo`L001Moo`00KWoo00<007ooOol0ogoo[Goo00=l07ooOol0
W7oo00<007ooOol0Ygoo1`005goo001^Ool00`00Oomoo`3oOoooOom=Ool00`00Oomoo`2WOol7000G
Ool006ioo`03001oogoo0?mooomoodeoo`03001oogoo0:Moo`L001Moo`00KWoo00<007ooOol0ogoo
ogooCGoo00<007ooOol0Ygoo1`005goo001^Ool00`00Oomoo`3oOonXOol00g`0Oomoo`2QOol00`00
Oomoo`2WOol7000GOol006ioo`03001oogoo0?moojIoo`9l0:Aoo`03001oogoo0:Moo`L001Moo`00
KWoo00<007ooOol0ogooY7oo0W`0YWoo00<007ooOol0IWoo1000?Goo1`005goo001^Ool00`00Oomo
o`3oOonSOol00g`0Oomoo`2VOol00`00Oomoo`1ZOol00`00Oomoo`0jOol7000GOol006ioo`03001o
ogoo0?mooomoodeoo`03001oogoo06Yoo`03001oogoo03Yoo`L001Moo`00KWoo00<007ooOol0ogoo
ogooCGoo00<007ooOol0BWoo1`0017oo0`0000Aoo`00001oo`<0009oo`<0009oo`<00003Ool007oo
00=oo`D003=oo`L001Moo`00KWoo00<007ooOol0ogooogooCGoo00<007ooOol0C7oo00D007ooOomo
o`0000=oo`04001oogooOol20003Ool00`00Oomoo`02Ool01000Oomoo`000goo0P0017oo00<007oo
Ool00Woo00<007ooOol0<7oo1`005goo001^Ool00`00Oomoo`3oOonNOol00g`0Oomoo`2[Ool00`00
Oomoo`0<Ool7O005Ool7O005Ool7O005Ool7O00EOol01@00Oomoogoo00000goo00<007ooOol00Woo
00D007ooOomoo`0000Aoo`04001oogoo0004Ool00`00Oomoo`07Ool00`00Oomoo`0`Ool7000GOol0
06ioo`03001oogoo0?mooieoo`03O01oogoo0:aoo`03001oogoo04aoo`05001oogooOol00003Ool0
0`00Oomoo`02Ool01@00Oomoogoo000017oo00@007ooOol000Aoo`03001oogoo00=oo`@003=oo`L0
01Moo`00KWoo00<007ooOol0ogooVgoo0W`0[goo00<007ooOol0C7oo00<007ooOol01Goo00<007oo
Ool00Woo00@007ooOomoo`8000=oo`04001oogoo0003Ool20004Ool00`00Oomoo`02Ool00`00Oomo
o`0`Ool7000GOol006ioo`03001oogoo0?mooiYoo`03O01oogoo0:moo`03001oogoo04aoo`03001o
ogoo00Aoo`8000=oo`80009oo`800004Ool000000004Ool300000goo00000004Ool5000bOol7000G
Ool006ioo`03001oogoo0?mooomoodeoo`03001oogoo04aoo`03001oogoo05Qoo`L001Moo`00KWoo
00<007ooOol0ogooogooCGoo00<007ooOol0BWoo1@00F7oo1`005goo001^Ool00`00Oomoo`3oOooo
Oom=Ool00`00Oomoo`2WOol7000GOol006ioo`03001oogoo0?mooiEoo`03O01oogoo0;Aoo`03001o
ogoo0:Moo`L001Moo`00KWoo00<007ooOol0ogooTgoo0W`0]goo00<007ooOol0Ygoo1`005goo001^
Ool00`00Oomoo`3oOonAOol2O02iOol00`00Oomoo`2WOol7000GOol006ioo`03001oogoo0?mooi1o
o`03O01oogoo0;Uoo`03001oogoo0:Moo`L001Moo`00KWoo00<007ooOol0ogooogooCGoo00<007oo
Ool0Ygoo1`005goo000JOol70004Ool20007Ool00`00Oomoo`03Ool00`00Oomoo`03Ool70003Ool4
000VOol00`00Oomoo`3oOoooOom=Ool00`00Oomoo`2WOol7000GOol001eoo`03001oogoo00Eoo`80
00Qoo`05001oogooOol00009Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0SOol00`00
Oomoo`3oOon;Ool00g`0Oomoo`2nOol00`00Oomoo`2WOol7000GOol001eoo`03001oogoo011oo`03
001oo`0000Yoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo02=oo`03001oogoo0?moohUo
o`9l0<5oo`03001oogoo0:Moo`L001Moo`007Goo00<007ooOol04Goo00<007ooOol02Goo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol08goo00<007ooOol0ogooQgoo0W`0`goo00<007ooOol0
Ygoo1`005goo000MOol00`00Oomoo`0@Ool00`00Ool0000:Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`0SOol5003oOon4Ool00g`0Oomoo`33Ool00`00Oomoo`2WOol7000GOol001eoo`03
001oogoo00moo`05001oogooOol00009Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0S
Ool00`00Oomoo`3oOon6Ool00g`0Oomoo`33Ool00`00Oomoo`2WOol7000GOol001eoo`03001oogoo
00ioo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
02=oo`03001oogoo0?mooomoodeoo`03001oogoo0:Moo`L001Moo`006goo0`007Goo0`001Goo00<0
07ooOol00Woo00<007ooOol01goo1@0017oo0`000goo0`002Woo00<007ooOol0ogooogooCGoo00<0
07ooOol0Ygoo1`005goo000MOol00`00Oomoo`0MOol00`00Oomoo`04Ool4000<Ool00`00Oomoo`05
Ool01@00Oomoogoo00000goo00<007ooOol01goo00<007ooOol0ogooPGoo00=l07ooOol0b7oo00<0
07ooOol0Ygoo1`005goo001<Ool50003Ool00`00Oomoo`02Ool50006Ool00`00Oomoo`07Ool00`00
Oomoo`3oOomoOol2O03;Ool00`00Oomoo`2WOol7000GOol005Aoo`03001oogoo009oo`04001oogoo
0004Ool3000:Ool00`00Oomoo`3oOommOol2O03=Ool00`00Oomoo`2WOol7000GOol005Aoo`03001o
ogoo00=oo`03001oo`0000Aoo`03001oogoo00Yoo`03001oogoo0?moogaoo`03O01oogoo0<eoo`03
001oogoo0:Moo`L001Moo`00E7oo00<007ooOol017oo0P0017oo00<007ooOol02Woo00<007ooOol0
ogooogooCGoo00<007ooOol0Ygoo1`005goo001COol20007Ool00`00Oomoo`02Ool40009Ool00`00
Oomoo`3oOoooOom=Ool00`00Oomoo`2WOol7000GOol006ioo`03001oogoo0?moogMoo`03O01oogoo
0=9oo`03001oogoo0:Moo`L001Moo`00KWoo00<007ooOol0ogooMGoo0W`0eGoo00<007ooOol0Ygoo
1`005goo001^Ool00`00Oomoo`3oOomcOol2O03GOol00`00Oomoo`2WOol7000GOol006ioo`03001o
ogoo0?moog5oo`9l0=Uoo`03001oogoo0:Moo`L001Moo`00KWoo00<007ooOol0ogooogooCGoo00<0
07ooOol0Ygoo1`005goo001^Ool00`00Oomoo`3oOoooOom=Ool00`00Oomoo`2WOol7000GOol006io
o`03001oogoo0?mooomoodeoo`03001oogoo0:Moo`L001Moo`00KWoo00<007ooOol0ogooK7oo00=l
07ooOol0gGoo00<007ooOol0Ygoo1`005goo001^Ool00`00Oomoo`3oOomZOol2O03POol00`00Oomo
o`2WOol7000GOol006ioo`03001oogoo0?moofQoo`9l0>9oo`03001oogoo0:Moo`L001Moo`00KWoo
00<007ooOol0ogooIgoo00=l07ooOol0hWoo00<007ooOol0Ygoo1`005goo001^Ool00`00Oomoo`3o
OoooOom=Ool00`00Oomoo`2WOol7000GOol006ioo`03001oogoo0?mooomoodeoo`03001oogoo0:Mo
o`L001Moo`00KWoo00<007ooOol0ogooHWoo00=l07ooOol0igoo00<007ooOol0Ygoo1`005goo001^
Ool00`00Oomoo`3oOomPOol2O03ZOol00`00Oomoo`2WOol7000GOol006ioo`03001oogoo0?mooeio
o`9l0>aoo`03001oogoo0:Moo`L001Moo`00KWoo00<007ooOol0ogooGGoo00=l07ooOol0k7oo00<0
07ooOol0BWoo1`000Woo0`000Woo0`000goo100017oo1@001Goo10001Woo10000Woo1`0017oo1000
0goo0`000Woo0`003Goo1`005goo001^Ool00`00Oomoo`3oOoooOom=Ool00`00Oomoo`1;Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol01Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00aoo`L001Moo`00KWoo
00<007ooOol0ogooogooCGoo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol00goo0P0017oo
00<007ooOol027oo00<007ooOol01Goo00<007ooOol01goo00<007ooOol01goo00<007ooOol017oo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00aoo`L001Moo`00KWoo00<007ooOol0
ogooEgoo0W`0lgoo00<007ooOol0Bgoo00@007ooOol000Moo`8000Aoo`03001oogoo00Qoo`03001o
ogoo00Eoo`H000Aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`0<Ool7000GOol006ioo`03001oogoo0?mooeEoo`9l0?Eoo`03001oogoo04]o
o`@000Ioo`04001oogoo0004Ool01000Oomoogoo0P0017oo0P001Woo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00@007ooOomoo`8000=oo`03
001oogoo00aoo`L001Moo`00KWoo00<007ooOol0ogooDgoo0W`0mgoo00<007ooOol0Bgoo00H007oo
Ool007oo0002Ool30002Ool30003Ool300000goo001oo`02Ool2000017oo0000000017oo10000goo
1`000goo0`001goo10000goo0P0000Aoo`00000000moo`L001Moo`00KWoo00<007ooOol0ogooDWoo
00=l07ooOol0mgoo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol09Woo00<007ooOol0:goo
1`005goo001^Ool00`00Oomoo`3oOoooOom=Ool00`00Oomoo`1:Ool7000XOol00`00Oomoo`0[Ool7
000GOol006ioo`03001oogoo0?mooomoodeoo`03001oogoo08=oo`03001oogoo025oo`L001Moo`00
KWoo00<007ooOol0ogooC7oo0W`0oWoo00<007ooOol0Pgoo00<007ooOol08Goo1`005goo001^Ool0
0`00Oomoo`3oOom:Ool2O03oOol1Ool00`00Oomoo`2WOol7000GOol006ioo`03001oogoo0?moodQo
o`9l0?moo`=oo`03001oogoo0:Moo`L001Moo`00KWoo00<007ooOol0ogooogooCGoo00<007ooOol0
2goo;`?PKGoo1`005goo001^Ool00`00Oomoo`3oOoooOom=Ool00`00Oomoo`0;Ool_0n1]Ool7000G
Ool006ioo`03001oogoo0?mood=oo`03O01oogoo0?moo`Moo`03001oogoo0:Moo`L001Moo`00KWoo
00<007ooOol0ogoo@Goo0W`0ogoo2Woo00<007ooOol0Ygoo1`005goo001^Ool00`00Oomoo`3oOolo
Ool2O03oOol<Ool00`00Oomoo`2WOol7000GOol006ioo`03001oogoo0?mooceoo`9l0?moo`ioo`03
001oogoo0:Moo`L001Moo`00KWoo00<007ooOol0ogooogooCGoo00<007ooOol0Ygoo1`005goo001^
Ool00`00Oomoo`3oOoooOom=Ool00`00Oomoo`1<Ool40004Ool50003Ool70002Ool30002Ool30003
Ool4000cOol7000GOol006ioo`03001oogoo0?moocQoo`03O01oogoo0?mooa9oo`03001oogoo04]o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009o
o`05001oogooOol00004Ool00`00Oomoo`0`Ool7000GOol006ioo`03001oogoo0?moocIoo`9l0?mo
oaEoo`03001oogoo04]oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Moo`03001oogoo
00Aoo`03001oogoo009oo`05001oogooOol0000gOol7000GOol006ioo`03001oogoo0?moocAoo`9l
0?mooaMoo`03001oogoo04]oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Moo`03001o
ogoo00Aoo`03001oogoo009oo`04001oogooOol6000bOol7000GOol006ioo`03001oogoo0?mooc=o
o`03O01oogoo0?mooaMoo`03001oogoo04]oo`03001oogoo009oo`03001oogoo009oo`8000Qoo`03
001oogoo00Aoo`8000=oo`05001oogooOol00004Ool00`00Oomoo`0`Ool7000GOol006ioo`03001o
ogoo0?mooomoodeoo`03001oogoo04]oo`03001oogoo009oo`04001oogooOol2000017oo00000000
0goo0`001Goo0P0000Aoo`00000000Eoo`@003=oo`L001Moo`00KWoo00<007ooOol0ogoo;Goo00=l
07ooOol0ogoo7Goo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol0E7oo1`005goo000JOol7
0004Ool20007Ool00`00Oomoo`03Ool00`00Oomoo`03Ool70003Ool4000VOol00`00Oomoo`3oOol[
Ool2O03oOolPOol00`00Oomoo`1:Ool30002Ool3001EOol7000GOol001eoo`03001oogoo00Eoo`80
00Qoo`05001oogooOol00009Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0SOol00`00
Oomoo`3oOolYOol2O03oOolROol00`00Oomoo`1OOol00`00Oomoo`15Ool7000GOol001eoo`03001o
ogoo011oo`03001oo`0000Yoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo02=oo`03001o
ogoo0?moobQoo`03O01oogoo0?moob9oo`03001oogoo05moo`03001oogoo04Eoo`L001Moo`007Goo
00<007ooOol04Goo00<007ooOol02Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol08goo
00<007ooOol0ogooogooCGoo00<007ooOol0Ygoo1`005goo000MOol00`00Oomoo`0@Ool00`00Ool0
000:Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0SOol5003oOoooOom;Ool00`00Oomo
o`2WOol7000GOol001eoo`03001oogoo00moo`05001oogooOol00009Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`0SOol00`00Oomoo`3oOolQOol2O03oOolZOol00`00Oomoo`2WOol7000G
Ool001eoo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo02=oo`03001oogoo0?mooamoo`9l0?moobaoo`03001oogoo0:Moo`L001Mo
o`006goo0`007Goo0`001Goo00<007ooOol00Woo00<007ooOol01goo1@000goo0`0017oo0`002Woo
00<007ooOol0ogoo7Goo0W`0ogoo;Woo00<007ooOol0Ygoo1`005goo000MOol00`00Oomoo`0MOol0
0`00Oomoo`04Ool4000<Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000Uo
o`03001oogoo0?mooomoodeoo`03001oogoo0:Moo`L001Moo`00C7oo1@000goo00<007ooOol00Woo
00D007ooOomoo`00009oo`05001oogooOol00009Ool00`00Oomoo`3oOoooOom=Ool00`00Oomoo`2W
Ool7000GOol005Aoo`03001oogoo009oo`05001oogooOol00002Ool4000:Ool00`00Oomoo`3oOolG
Ool2O03oOoldOol00`00Oomoo`2WOol7000GOol005Aoo`03001oogoo009oo`05001oogooOol00002
Ool00`00Oomoo`0;Ool00`00Oomoo`3oOolDOol3O03oOolfOol00`00Oomoo`2WOol7000GOol005Ao
o`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0:Ool00`00Oomoo`3oOolBOol2O03o
OoliOol00`00Oomoo`2WOol7000GOol005=oo`8000Eoo`<000Eoo`<000Uoo`03001oogoo0?mooomo
odeoo`03001oogoo0:Moo`L001Moo`00KWoo00<007ooOol0ogooogooCGoo00<007ooOol0Ygoo1`00
5goo001^Ool00`00Oomoo`3oOol<Ool2O03oOoloOol00`00Oomoo`2WOol7000GOol006ioo`03001o
ogoo0?moo`Uoo`=l0?mood5oo`03001oogoo0:Moo`L001Moo`00KWoo00<007ooOol0ogoo1goo0W`0
ogooA7oo00<007ooOol0Ygoo1`005goo001^Ool00`00Oomoo`3oOoooOom=Ool00`00Oomoo`2WOol7
000GOol006ioo`03001oogoo0?mooomoodeoo`03001oogoo0:Moo`L001Moo`00KWoo00<007ooOol0
ogoo0g`0ogooBWoo00<007ooOol0Ygoo1`005goo001^Ool00`00Oomoo`3mOol2O03oOom=Ool00`00
Oomoo`2WOol7000GOol006ioo`03001oogoo0?]oo`9l0?moodmoo`03001oogoo0:Moo`L001Moo`00
KWoo00<007ooOol0ogooogooCGoo00<007ooOol0Ygoo1`005goo001^Ool00`00Oomoo`3eOol2O03o
OomEOol00`00Oomoo`2WOol7000GOol006ioo`03001oogoo0?9oo`=l0?mooeMoo`03001oogoo0:Mo
o`L001Moo`00KWoo00<007ooOol0l7oo0W`0ogooFWoo00<007ooOol0Ygoo1`005goo001^Ool00`00
Oomoo`3oOoooOom=Ool00`00Oomoo`2WOol7000GOol006ioo`03001oogoo0?mooomoodeoo`03001o
ogoo04Yoo`L0009oo`<0009oo`<000=oo`@000Aoo`D000Eoo`@000Ioo`@0009oo`L000Aoo`@000=o
o`<0009oo`<000eoo`L001Moo`00KWoo00<007ooOol0jWoo0W`0ogooH7oo00<007ooOol0Bgoo00<0
07ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo009oo`03
001oogoo00Eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03
001oogoo00Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0<Ool7000GOol006io
o`03001oogoo0>Moo`=l0?moof9oo`03001oogoo04]oo`03001oogoo009oo`03001oogoo00=oo`80
00Aoo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0<Ool7000GOol006ioo`03001o
ogoo0>Eoo`9l0?moofEoo`03001oogoo04]oo`04001oogoo0007Ool20004Ool00`00Oomoo`08Ool0
0`00Oomoo`05Ool60004Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00<007ooOol037oo1`005goo001^Ool00`00Oomoo`3oOoooOom=Ool00`00Oomoo`1;
Ool40006Ool01000Oomoo`0017oo00@007ooOomoo`8000Aoo`8000Ioo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`04001oogooOol20003Ool0
0`00Oomoo`0<Ool7000GOol006ioo`03001oogoo0=ioo`9l0?moofaoo`03001oogoo04]oo`06001o
ogoo001oo`000Woo0`000Woo0`000goo0`0000=oo`00Ool00Woo0P0000Aoo`00000000Aoo`@000=o
o`L000=oo`<000Moo`@000=oo`800004Ool00000000?Ool7000GOol006ioo`03001oogoo0=aoo`9l
0?moofioo`03001oogoo04]oo`03001oogoo009oo`03001oogoo02Ioo`03001oogoo02]oo`L001Mo
o`00KWoo00<007ooOol0fWoo0W`0ogooL7oo00<007ooOol0BWoo1`00:7oo00<007ooOol0:goo1`00
5goo001^Ool00`00Oomoo`3oOoooOom=Ool00`00Oomoo`23Ool00`00Oomoo`0QOol7000GOol006io
o`03001oogoo0=Aoo`03O01oogoo0?moogEoo`03001oogoo08=oo`03001oogoo025oo`L001Moo`00
KWoo00<007ooOol0dWoo0W`0ogooN7oo00<007ooOol0Ygoo1`005goo001^Ool00`00Oomoo`3@Ool2
O03oOomjOol00`00Oomoo`0;Ool501l9Ool401l9Ool501l9Ool401m_Ool7000GOol006ioo`03001o
ogoo0<moo`03O01oogoo0?moogYoo`03001oogoo00]oo`D07`Uoo`@07`Uoo`D07`Uoo`@07fmoo`L0
01Moo`00KWoo00<007ooOol0ogooogooCGoo00<007ooOol02goo1@0O2Goo100O2Goo1@0O2Goo100O
Kgoo1`005goo001^Ool00`00Oomoo`38Ool2O03oOon2Ool00`00Oomoo`2WOol7000GOol006ioo`03
001oogoo0<Eoo`=l0?moohAoo`03001oogoo0:Moo`L001Moo`00KWoo00<007ooOol0`goo0W`0ogoo
Qgoo00<007ooOol0Ygoo1`005goo001^Ool00`00Oomoo`3oOoooOom=Ool00`00Oomoo`2WOol7000G
Ool006ioo`03001oogoo0;eoo`9l0?mooheoo`03001oogoo0:Moo`L001Moo`00KWoo00<007ooOol0
^Woo0g`0ogooSgoo00<007ooOol0BWoo10001goo1@0017oo10001Goo10001Goo1@000Woo1`00:Goo
1`005goo001^Ool00`00Oomoo`2hOol2O03oOonBOol00`00Oomoo`1;Ool00`00Oomoo`06Ool01@00
Oomoogoo000017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool00`00
Oomoo`04Ool00`00Oomoo`0ZOol7000GOol006ioo`03001oogoo0?mooomoodeoo`03001oogoo04]o
o`03001oogoo00Ioo`05001oogooOol00004Ool00`00Oomoo`05Ool00`00Oomoo`07Ool01@00Oomo
ogoo00001Woo00<007ooOol0:Woo1`005goo001^Ool00`00Oomoo`2`Ool3O03oOonIOol00`00Oomo
o`1;Ool01000Oomoo`001Woo100017oo1P000Woo00<007ooOol027oo10001Woo00<007ooOol0:Woo
1`005goo001^Ool00`00Oomoo`2]Ool3O03oOonLOol00`00Oomoo`1;Ool40005Ool01@00Oomoogoo
000017oo00<007ooOol00Woo00D007ooOomoo`0000=oo`8000=oo`05001oogooOol00006Ool00`00
Oomoo`0ZOol7000GOol006ioo`03001oogoo0?mooomoodeoo`03001oogoo04]oo`06001oogoo001o
o`0017oo0`001Woo10001Goo0`0000=oo`00Ool00goo0`001goo00<007ooOol0:Woo1`005goo001^
Ool00`00Oomoo`2VOol2O03oOonTOol00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`0WOol0
0`00Oomoo`0ZOol7000GOol006ioo`03001oogoo0:=oo`=l0?moojIoo`03001oogoo04Yoo`L002Uo
o`03001oogoo02Yoo`L001Moo`00KWoo00<007ooOol0XGoo0W`0ogooZGoo00<007ooOol0N7oo0`00
;7oo1`005goo001^Ool00`00Oomoo`3oOoooOom=Ool00`00Oomoo`2WOol7000GOol0021oo`L000Ao
o`8000Moo`03001oogoo00=oo`03001oogoo00=oo`L000=oo`@0021oo`03001oogoo09Yoo`9l0?mo
ok1oo`03001oogoo0:Moo`L001Moo`008goo00<007ooOol01Goo0P0027oo00D007ooOomoo`0000Uo
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo01eoo`03001oogoo09Qoo`9l0?mook9oo`03
001oogoo0:Moo`L001Moo`008goo00<007ooOol047oo00<007oo00002Woo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol07Goo00<007ooOol0UWoo0W`0ogoo]7oo00<007ooOol0Ygoo1`005goo
000SOol00`00Oomoo`0AOol00`00Oomoo`09Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`0MOol5002=Ool2O03oOonkOol00`00Oomoo`2WOol7000GOol002=oo`03001oogoo011oo`03001o
o`0000Yoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo01eoo`03001oogoo08eoo`9l0?mo
okeoo`03001oogoo0:Moo`L001Moo`008goo00<007ooOol03goo00D007ooOomoo`0000Uoo`03001o
ogoo00=oo`03001oogoo009oo`03001oogoo01eoo`03001oogoo08Yoo`=l0?mookmoo`03001oogoo
0:Moo`L001Moo`008goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol0
0goo00<007ooOol00Woo00<007ooOol027oo0`001Goo00<007ooOol02Woo00<007ooOol0ogooogoo
CGoo00<007ooOol0Ygoo1`005goo000QOol3000MOol30005Ool00`00Oomoo`02Ool00`00Oomoo`07
Ool01@00Oomoogoo000017oo00<007ooOol02Woo00<007ooOol0Q7oo0W`0ogooaWoo00<007ooOol0
Ygoo1`005goo000SOol00`00Oomoo`0MOol00`00Oomoo`04Ool40004Ool500000goo001oo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`21Ool3O03oOoo8Ool00`00Oomoo`2WOol00`00
Oomoo`0KOol005Qoo`@000Ioo`03001oogoo00Uoo`03001oogoo07moo`9l0?mool]oo`03001oogoo
0:Moo`03001oogoo01]oo`00F7oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0N7oo0W`0
ogoodWoo00<007ooOol0Ygoo00<007ooOol06goo001IOol00`00Oomoo`03Ool01@00Oomoogoo0000
2Woo00<007ooOol0MGoo0g`0ogooe7oo00<007ooOol0Ygoo00<007ooOol06goo001JOol30002Ool5
000:Ool00`00Oomoo`1cOol2O03oOooGOol00`00Oomoo`2WOol00`00Oomoo`0KOol006ioo`03001o
ogoo06aoo`9l0?moomioo`03001oogoo0:Moo`03001oogoo01]oo`00KWoo00<007ooOol0JWoo0W`0
ogooh7ooZ`007Goo001^Ool00`00Oomoo`1XOol2O03oOoooOon[Ool006ioo`03001oogoo0?mooomo
oomooaIoo`00KWoo00<007ooOol0H7oo0g`0ogooogoo/Woo001^Ool00`00Oomoo`1LOol4O03oOooo
OoneOol006ioo`03001oogoo05Eoo`9l0?mooomookioo`00KWoo00<007ooOol0DWoo0g`0ogooogoo
`7oo001^Ool00`00Oomoo`1@Ool2O03oOoooOoo3Ool006ioo`03001oogoo04Yoo`9l0?mooomoolUo
o`00KWoo00<007ooOol0Agoo0g`0ogooogoobgoo001^Ool00`00Oomoo`15Ool2O03oOoooOoo>Ool0
06ioo`03001oogoo03eoo`=l0?mooomoomEoo`00KWoo00<007ooOol0>Woo0g`0ogooogoof7oo001^
Ool00`00Oomoo`0iOol00g`0Oomoo`3oOoooOooIOol006ioo`03001oogoo035oo`=l0?mooomoon5o
o`00KWoo00<007ooOol0;Goo17`0ogooogooi7oo001^Ool00`00Oomoo`0VOol2O03oOoooOoo]Ool0
06ioo`03001oogoo02Aoo`9l0?mooomoonmoo`00KWoo00<007ooOol08Woo0W`0ogooogoolGoo001^
Ool00`00Oomoo`0JOol3O03oOoooOoohOol006ioo`03001oogoo01Ioo`Al0?mooomooo]oo`00KWoo
00<007ooOol03goo0W`0ogooogooogoo1Goo001^Ool00`00Oomoo`0<Ool3O03oOoooOoooOol7Ool0
06ioo`03001oogoo00Yoo`9l0?mooomooomoo`Yoo`00KWoo00<007ooOol0ogooogooogoo5Woo001^
Ool00`00Oomoo`3oOoooOoooOolFOol006ioo`03001oogoo0?mooomooomooaIoo`00KWoo00<007oo
Ool0ogooogooogoo5Woo001^Ool00`00Oomoo`3oOoooOoooOolFOol006ioo`03001oogoo0?mooomo
oomooaIoo`00KWoo00<007ooOol0ogooogooogoo5Woo001^Ool00`00Oomoo`3oOoooOoooOolFOol0
06ioo`03001oogoo0?mooomooomooaIoo`00KWoo00<007ooOol0ogooogooogoo5Woo001^Ool00`00
Oomoo`3oOoooOoooOolFOol006ioo`03001oogoo0?mooomooomooaIoo`00KWoo00<007ooOol0ogoo
ogooogoo5Woo001^Ool00`00Oomoo`3oOoooOoooOolFOol006ioo`03001oogoo0?mooomooomooaIo
o`00KWoo00<007ooOol0ogooogooogoo5Woo001^Ool00`00Oomoo`3oOoooOoooOolFOol006ioo`03
001oogoo0?mooomooomooaIoo`0087oo1`0017oo0P001goo00<007ooOol00goo00<007ooOol00goo
1`000goo100087oo00<007ooOol0ogooogooogoo5Woo000SOol00`00Oomoo`05Ool20008Ool01@00
Oomoogoo00002Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol07Goo00<007ooOol0ogoo
ogooogoo5Woo000SOol00`00Oomoo`0@Ool00`00Ool0000:Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`0MOol00`00Oomoo`3oOoooOoooOolFOol002=oo`03001oogoo015oo`03001oogoo
00Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo01eoo`D00?mooomooomooaAoo`008goo
00<007ooOol047oo00<007oo00002Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol07Goo
00<007ooOol0ogooogooogoo5Woo000SOol00`00Oomoo`0?Ool01@00Oomoogoo00002Goo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol07Goo00<007ooOol0ogooogooogoo5Woo000SOol00`00
Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`07Ool50003Ool3000;Ool00`00Oomoo`3oOoooOoooOolFOol0025oo`<001eoo`<000Eoo`03
001oogoo009oo`03001oogoo00Moo`03001oogoo00Aoo`05001oogooOol0000:Ool00`00Oomoo`3o
OoooOoooOolFOol002=oo`03001oogoo01eoo`03001oogoo00Aoo`@000Aoo`D0009oo`03001oogoo
00=oo`05001oogooOol0000:Ool00`00Oomoo`3oOoooOoooOolFOol005Yoo`03001oogoo00=oo`<0
00]oo`03001oogoo0?mooomooomooaIoo`00Fgoo00D007ooOomoo`0000=oo`03001oogoo00Qoo`03
001oogoo0?mooomooomooaIoo`00F7oo00D007ooOomoo`00009oo`05001oogooOol0000:Ool00`00
Oomoo`3oOoooOoooOolFOol005Uoo`<000Aoo`<000]oo`03001oogoo0?mooomooomooaIoo`00KWoo
00<007ooOol0ogooogooogoo5Woo001^Ool00`00Oomoo`3oOoooOoooOolFOol006ioo`03001oogoo
0?mooomooomooaIoo`00KWoo00<007ooOol0ogooogooogoo5Woo001^Ool00`00Oomoo`3oOoooOooo
OolFOol006ioo`03001oogoo0?mooomooomooaIoo`00KWoo00<007ooOol0ogooogooogoo5Woo001^
Ool00`00Oomoo`3oOoooOoooOolFOol006ioo`03001oogoo0?mooomooomooaIoo`00KWoo00<007oo
Ool0ogooogooogoo5Woo001^Ool00`00Oomoo`3oOoooOoooOolFOol006ioo`03001oogoo0?mooomo
oomooaIoo`00KWoo00<007ooOol0ogooogooogoo5Woo001^Ool00`00Oomoo`3oOoooOoooOolFOol0
06ioo`03001oogoo0?mooomooomooaIoo`00KWoo00<007ooOol0ogooogooogoo5Woo001^Ool00`00
Oomoo`3oOoooOoooOolFOol006ioo`03001oogoo0?mooomooomooaIoo`00KWoo00<007ooOol0ogoo
ogooogoo5Woo001^Ool00`00Oomoo`3oOoooOoooOolFOol006ioo`03001oogoo0?mooomooomooaIo
o`00KWoo00<007ooOol0ogooogooogoo5Woo001^Ool00`00Oomoo`3oOoooOoooOolFOol006ioo`03
001oogoo0?mooomooomooaIoo`00KWoo00<007ooOol02Goo1@0O2Goo100O2Goo1@0O2Goo100O2Goo
1@0O2Goo100O2Goo1@0O2Goo100O2Goo1@0O2Goo100O2Goo1@0O2Goo100O2Goo1@0O2Goo100O2Goo
1@0O2Goo100O2Goo1@0O2Goo100O2Goo1@0O2Goo100O2Goo1@0O2Goo100O2Goo1@0O27oo1@0O2Goo
1@0O2Goo100O2Goo1@0O2Goo100O2Goo1@0O2Goo100O2Goo1@0OogooLGoo001^Ool00`00Oomoo`09
Ool501l9Ool401l9Ool501l9Ool401l9Ool501l9Ool401l9Ool501l9Ool401l9Ool501l9Ool401l9
Ool501l9Ool401l9Ool501l9Ool401l9Ool501l9Ool401l9Ool501l9Ool401l9Ool501l9Ool401l9
Ool501l9Ool401l9Ool501l8Ool501l9Ool501l9Ool401l9Ool501l9Ool401l9Ool501l9Ool401l9
Ool501l9Ool401l9Ool501l9Ool401l9Ool501l9Ool401l9Ool501l9Ool401ooOolCOol006ioo`03
001oogoo00Uoo`D07`Uoo`@07`Uoo`D07`Uoo`@07`Uoo`D07`Uoo`@07`Uoo`D07`Uoo`@07`Uoo`D0
7`Uoo`@07`Uoo`D07`Uoo`@07`Uoo`D07`Uoo`@07`Uoo`D07`Uoo`@07`Uoo`D07`Uoo`@07`Uoo`D0
7`Uoo`@07`Uoo`D07`Uoo`@07`Uoo`D07`Qoo`D07`Uoo`D07`Uoo`@07`Uoo`D07`Uoo`@07`Uoo`D0
7`Uoo`@07`Uoo`D07`Uoo`@07`Uoo`D07`Uoo`@07`Uoo`D07`Uoo`@07`Uoo`D07`Uoo`@07omooa=o
o`00KWoo00<007ooOol0ogooN7oo=@?P100O2@?P1@0O2@?P100O2@?P1@0O2@?P100O2@?P1@0O2@?P
100O1`?Pogoo37oo001^Ool00`00Oomoo`3oOol^OooK0n3oOol<Ool006ioo`03001oogoo0>Iooi43
h?mooieoo`00KWoo00<007ooOol0S7ooX@?Pogooigoo001^Ool00`00Oomoo`09OooM0n3oOoooOol_
Ool006ioo`03001oogoo00Uooh<3h?mooomoohUoo`00KWoo00<007ooOol0ogooogooogoo5Woo001^
Ool00`00Oomoo`3oOoooOoooOolFOol006ioo`03001oogoo0?mooomooomooaIoo`00KWoo00<007oo
Ool0ogooogooogoo5Woo001^Ool00`00Oomoo`3oOoooOoooOolFOol006ioo`03001oogoo0?mooomo
oomooaIoo`00KWoo00<007ooOol0ogooogooogoo5Woo003oOoooOoooOon7Ool00?mooomooomoohMo
o`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003o
OoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOomUOol3003oOoooOolOOol0
0?moofIoo`03001oogoo0?mooomooaioo`00ogooIWoo00<007ooOol0ogooogoo7Woo003oOolgOol3
0003Ool30003Ool3000017oo000007oo1`001Goo10000Woo1`000goo00<007oo00000P000goo1`00
17oo100037oo1`000Woo0`000Woo0`0017oo100017oo1@000Woo0P000Woo0`0017oo1000ogoobWoo
003oOolhOol00`00Oomoo`03Ool01@00Oomoogoo00000goo0P001Goo00<007ooOol01Goo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol017oo0P000goo00<007ooOol00goo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol037oo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol00Woo00@007ooOol000=oo`03001oogoo009oo`04001oogoo0005Ool00`00Oomoo`02
Ool00`00Oomoo`3oOoo7Ool00?moocQoo`04001oogoo0002Ool01@00Oomoogoo000017oo00<007oo
Ool00goo00<007ooOol01Goo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol017oo00<007ooOol04Goo00<007ooOol017oo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol01Goo00D007ooOomoo`0000Aoo`03001oo`0000Ioo`03001oogoo0?moolao
o`00ogoo>7oo00L007oo001oo`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`05Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`04Ool6000>Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`06Ool4
0004Ool30006Ool6003oOoo9Ool007=oo`<00<5oo`07001oo`00Ool007oo00000goo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01goo00<007ooOol017oo0P000goo00<0
07ooOol00goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol037oo00<007ooOol017oo0P00
0goo00<007ooOol00Woo00<007ooOol01Goo00D007ooOomoo`0000Aoo`04001oogoo0005Ool00`00
Oomoo`02Ool00`00Oomoo`3oOoo7Ool007Aoo`03001oogoo0<1oo`07001oo`00Ool007oo00000Woo
0P000goo0P001Goo00<007ooOol00goo1`000goo0`001Goo0P0000Aoo`00000000Ioo`03001oogoo
00Eoo`@000eoo`<000Eoo`800004Ool000000003Ool70004Ool30005Ool00`00Ool000020005Ool4
003oOoo:Ool007Aoo`03001oogoo0<1oo`8000=oo`8000ioo`03001oogoo00Eoo`03001oogoo01Uo
o`03001oogoo02Uoo`03001oogoo00ioo`03001oogoo0?moomEoo`00IWoo1P0017oo0`0000=oo`00
Ool0`7oo0`000goo0`003Goo00<007ooOol01Goo00<007ooOol06Goo00<007ooOol0:Goo00<007oo
Ool03Woo00<007ooOol0ogooeGoo001WOol00`00Oomoo`02Ool01000Oomoo`000goo0P00eGoo0`00
4Goo00<007ooOol03Goo0`006Woo00<007ooOol07Woo0P00ogooegoo001WOol00`00Oomoo`02Ool0
1000Oomoo`0017oo00<007ooOol0igoo00<007ooOol0:Woo00<007ooOol0ogoomgoo001WOol00`00
Oomoo`02Ool01000Oomoo`0017oo00<007ooOol0ogooogooogoo47oo001WOol50003Ool01000Oomo
ogoo0P00ogooogooogoo4Woo001WOol00`00Oomoo`02Ool01000Oomoogoo0`0000=oo`000000ogoo
ogooogoo4Goo001WOol00`00Oomoo`02Ool00`00Oomoo`3oOoooOoooOolHOol006Ioo`H00?mooomo
oomooa]oo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogoo
Qgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool0
0?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogoo
ogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOooo
Oon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMo
o`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003o
OoooOoooOon7Ool00?mooomooomoohMoo`00ogooogooogooQgoo003oOoooOoooOon7Ool00?mooomo
oomoohMoo`00ogooogooogooQgoo0000\
\>"],
  ImageRangeCache->{{{0, 899}, {440.375, 0}} -> {-1.06477, -0.648943, \
0.00442081, 0.00442081}, {{21.9375, 700.563}, {429.875, 10.4375}} -> \
{-0.169858, -259.053, 0.00206052, 1.03984}, {{700.563, 870.188}, {321.938, \
152.313}} -> {-14.9684, -3.17227, 0.0318352, 0.0389097}, {{714.688, 761.813}, \
{310.313, 271.813}} -> {-15.9492, -10.766, 0.0334221, 0.108156}, {{714.688, \
761.813}, {256.375, 217.813}} -> {-15.9492, -14.6574, 0.0334221, 0.108156}, \
{{714.688, 761.813}, {202.375, 163.875}} -> {-15.9492, -18.5488, 0.0334221, \
0.108156}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[70]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Inhalation\",ShowReport\[Rule] \"CompartmentContent\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, AMADAdultW[5], \ F, \ 1, 5, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Inhalation\>", IntakeType \[Rule] \ "\<Acute\>", 
      ShowReport \[Rule] \ "\<CompartmentContent\>"]\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \({q\_ET1[5] \[Rule] 0.0014797846804166885`, 
      q\_AI[5] \[Rule] 2.3795308407285945`*^-219, 
      q\_bb1[5] \[Rule] 7.496951083598179`*^-222, 
      q\_bb2[5] \[Rule] 1.7431777514283452`*^-220, 
      q\_bbseq[5] \[Rule] 3.392988579811896`*^-222, 
      q\_BB1[5] \[Rule] 2.0273024694702056`*^-222, 
      q\_BB2[5] \[Rule] 2.35432378335019`*^-220, 
      q\_BBseq[5] \[Rule] 5.4616847848893334`*^-222, 
      q\_LNth[5] \[Rule] 4.785532501394152`*^-223, 
      q\_ET2[5] \[Rule] 2.7343089190848`*^-223, 
      q\_ETseq[5] \[Rule] 9.16806891834134`*^-222, 
      q\_LNet[5] \[Rule] 4.595513669357081`*^-224, 
      qLungs[5] \[Rule] 2.808138474374357`*^-219, 
      qST[5] \[Rule] 1.1302051537631537`*^-53, qSI[5] \[Rule] 0, 
      qB[5] \[Rule] 0.000050213130228152225`, 
      q\_2[5] \[Rule] 0.08985990984110798`, 
      q\_3[5] \[Rule] 0.003210807903967718`, 
      q\_4[5] \[Rule] 7.99601896976969`*^-6, 
      qURI[5] \[Rule] 0.21858906258344224`, 
      qULI[5] \[Rule] 0.000018405992356105896`, 
      qLLI[5] \[Rule] 0.000025731416244447142`, 
      qFEC[5] \[Rule] 0.00004641580939480916`}\)], "Output",
  CellLabel->"Out[71]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, AMADAdultW[5], \ F, 1, \ 5, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Inhalation\>", 
      IntakeType \[Rule] \ "\<Constant\>", 
      ShowReport \[Rule] \ "\<CompartmentContent\>"]\)], "Input",
  CellLabel->"In[72]:="],

Cell[BoxData[
    \({q\_ET1[5] \[Rule] 0.3103316286407218`, 
      q\_AI[5] \[Rule] 0.0005313944500743153`, 
      q\_bb1[5] \[Rule] 0.00006438169010523872`, 
      q\_bb2[5] \[Rule] 0.00004378892311232248`, 
      q\_bbseq[5] \[Rule] 7.713692225754938`*^-7, 
      q\_BB1[5] \[Rule] 0.00010755246578955283`, 
      q\_BB2[5] \[Rule] 0.00005914101590968554`, 
      q\_BBseq[5] \[Rule] 1.24167100695224`*^-6, 
      q\_LNth[5] \[Rule] 2.1174913459582982`*^-10, 
      q\_ET2[5] \[Rule] 0.0019980236666473465`, 
      q\_ETseq[5] \[Rule] 1.9927534831419603`*^-6, 
      q\_LNet[5] \[Rule] \(-4.600687518127181`*^-226\), 
      qLungs[5] \[Rule] 0.0008082717969697772`, 
      qST[5] \[Rule] 0.00829515193822697`, qSI[5] \[Rule] 0, 
      qB[5] \[Rule] 0.1681274438386309`, q\_2[5] \[Rule] 0.5213204083786547`, 
      q\_3[5] \[Rule] 0.00904535289329253`, 
      q\_4[5] \[Rule] 0.026985097044688856`, 
      qURI[5] \[Rule] 1.2145426530373076`, 
      qULI[5] \[Rule] 0.000045619555622885156`, 
      qLLI[5] \[Rule] 0.000051888028899815634`, 
      qFEC[5] \[Rule] 0.00006315795130679147`}\)], "Output",
  CellLabel->"Out[72]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs1, AMADAdultW[5], \ F, 1, \ t, 
      Log[2]/8.0, IntakeWay \[Rule] \ "\<Inhalation\>", 
      IntakeType \[Rule] \ "\<Continuous\>", 
      ShowReport \[Rule] \ "\<CompartmentContent\>"]\)], "Input",
  CellLabel->"In[73]:="],

Cell[BoxData[
    \("Option not available for inhalation"\)], "Output",
  CellLabel->"Out[73]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs2, AMADAdultW[5], \ F, 1, \ t, 
      Log[2]/8.0, IntakeWay \[Rule] \ \ "\<Inhalation\>", 
      IntakeType \[Rule] \ "\<MultiInputs\>", 
      ShowReport \[Rule] \ "\<CompartmentContent\>"]\)], "Input",
  CellLabel->"In[74]:="],

Cell[BoxData[
    \("Option not available for MultiInputs intake"\)], "Output",
  CellLabel->"Out[74]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Inhalation\",ShowReport\[Rule] \"Disintegrations\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, AMADAdultW[5], \ F, \ 1, 5, Log[2]/8.0, 
      IntakeWay \[Rule] \ "\<Inhalation\>", IntakeType \[Rule] \ "\<Acute\>", 
      ShowReport \[Rule] \ "\<Disintegrations\>"]\)], "Input",
  CellLabel->"In[75]:="],

Cell[BoxData[
    \({q\_ET1[5] \[Rule] 26812.65271455836`, 
      q\_AI[5] \[Rule] 45.91248048642084`, 
      q\_bb1[5] \[Rule] 5.562578025092626`, 
      q\_bb2[5] \[Rule] 3.783362956904662`, 
      q\_bbseq[5] \[Rule] 0.06664630083052266`, 
      q\_BB1[5] \[Rule] 9.292533044217365`, 
      q\_BB2[5] \[Rule] 5.10978377459683`, 
      q\_BBseq[5] \[Rule] 0.10728037500067353`, 
      q\_LNth[5] \[Rule] 0.000018295125228995346`, 
      q\_ET2[5] \[Rule] 172.62924479833075`, 
      q\_ETseq[5] \[Rule] 0.17217390094346538`, 
      q\_LNet[5] \[Rule] 1.7202485276812673`*^-6, 
      qLungs[5] \[Rule] 69.83468325818875`, 
      qST[5] \[Rule] 716.7011274628103`, qSI[5] \[Rule] 0, 
      qB[5] \[Rule] 14526.211147657705`, q\_2[5] \[Rule] 45042.08328391573`, 
      q\_3[5] \[Rule] 781.5184899804699`, 
      q\_4[5] \[Rule] 2331.5123846611173`, 
      qURI[5] \[Rule] 104936.48522242345`, 
      qULI[5] \[Rule] 3.9415296124771473`, 
      qLLI[5] \[Rule] 4.4831256968313085`, 
      qFEC[5] \[Rule] 5.456847012501385`}\)], "Output",
  CellLabel->"Out[75]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, 1, AMADAdultW[5], \ F, 1, 5, Log[2]/8.0, 
      IntakeWay \[Rule] "\<Inhalation\>", 
      IntakeType \[Rule] \ "\<Constant\>", 
      ShowReport \[Rule] \ "\<Disintegrations\>"]\)], "Input",
  CellLabel->"In[76]:="],

Cell[BoxData[
    \({q\_ET1[5] \[Rule] 109976.81001208496`, 
      q\_AI[5] \[Rule] 229.1037053799538`, 
      q\_bb1[5] \[Rule] 27.75837163878675`, 
      q\_bb2[5] \[Rule] 18.879025233969955`, 
      q\_bbseq[5] \[Rule] 0.33256568461493097`, 
      q\_BB1[5] \[Rule] 46.37725337262007`, 
      q\_BB2[5] \[Rule] 25.49788056805112`, 
      q\_BBseq[5] \[Rule] 0.5353301070463287`, 
      q\_LNth[5] \[Rule] 0.00009111005775310627`, 
      q\_ET2[5] \[Rule] 862.2791751397849`, 
      q\_ETseq[5] \[Rule] 0.8591492733770849`, 
      q\_LNet[5] \[Rule] 8.566867623407796`*^-6, 
      qLungs[5] \[Rule] 348.48422309510073`, 
      qST[5] \[Rule] 3550.1508024626855`, qSI[5] \[Rule] 0, 
      qB[5] \[Rule] 67177.19081461412`, q\_2[5] \[Rule] 112425.13349625818`, 
      q\_3[5] \[Rule] 1333.6556040496653`, 
      q\_4[5] \[Rule] 10589.560193479607`, 
      qURI[5] \[Rule] 255509.79901784402`, qULI[5] \[Rule] 6.07544204117238`, 
      qLLI[5] \[Rule] 5.938167012015583`, 
      qFEC[5] \[Rule] 5.555183813041367`}\)], "Output",
  CellLabel->"Out[76]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs1, AMADAdultW[5], \ F, 1, \ t, 
      Log[2]/8.0, IntakeWay \[Rule] \ "\<Inhalation\>", 
      IntakeType \[Rule] \ "\<Continuous\>", 
      ShowReport \[Rule] \ \ "\<Disintegrations\>"]\)], "Input",
  CellLabel->"In[77]:="],

Cell[BoxData[
    \("Option not available for inhalation"\)], "Output",
  CellLabel->"Out[77]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BioassayReport[iodineMatrix, inputs2, AMADAdultW[5], \ F, 1, t, 
      Log[2]/8.0, IntakeWay \[Rule] \ "\<Inhalation\>", 
      IntakeType \[Rule] \ "\<MultiInputs\>", 
      ShowReport \[Rule] \ "\<Disintegrations\>"]\)], "Input",
  CellLabel->"In[78]:="],

Cell[BoxData[
    \("Option not available for MultiInputs intake"\)], "Output",
  CellLabel->"Out[78]="]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{1013, 643},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageFooters->{{Inherited, Cell[ 
        TextData[ {
          "\[Copyright]2003 Guillermo Sanchez & ENUSA. All rights \
reserved."}], "PageFooter"], Inherited}, {Inherited, Cell[ 
        TextData[ {
          "\[Copyright]2003 Guillermo Sanchez & ENUSA . All rights \
reserved."}], "PageFooter"], Inherited}},
ShowSelection->True,
Magnification->1.5,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Introduction"->{
    Cell[1947, 60, 780, 21, 67, "Text",
      CellTags->"Introduction"],
    Cell[4854, 147, 1401, 24, 262, "Text",
      CellTags->"Introduction"],
    Cell[334150, 4280, 299, 12, 58, "MathCaption",
      CellTags->"Introduction"],
    Cell[334474, 4296, 115, 3, 40, "Input",
      CellTags->"Introduction"],
    Cell[334592, 4301, 119, 3, 70, "Print",
      CellTags->"Introduction"],
    Cell[334714, 4306, 146, 3, 70, "Print",
      CellTags->"Introduction"],
    Cell[334863, 4311, 117, 3, 70, "Print",
      CellTags->"Introduction"],
    Cell[343821, 4544, 211, 6, 85, "MathCaption",
      CellTags->"Introduction"],
    Cell[344057, 4554, 101, 3, 40, "Input",
      CellTags->"Introduction"],
    Cell[344161, 4559, 405, 6, 70, "Print",
      CellTags->{"Info3345388266-5846447", "Introduction"}],
    Cell[344581, 4568, 130, 3, 58, "MathCaption",
      CellTags->"Introduction"],
    Cell[344736, 4575, 129, 4, 40, "Input",
      CellTags->"Introduction"],
    Cell[344868, 4581, 160, 4, 70, "Output",
      CellTags->"Introduction"],
    Cell[345065, 4590, 122, 4, 40, "Input",
      CellTags->"Introduction"],
    Cell[345190, 4596, 614, 11, 70, "Output",
      CellTags->"Introduction"],
    Cell[346041, 4621, 84, 1, 58, "MathCaption",
      CellTags->"Introduction"],
    Cell[346128, 4624, 559, 20, 108, "DefinitionBox3Col",
      CellTags->"Introduction"]},
  "ICRP 78"->{
    Cell[289595, 3710, 488, 8, 100, "Text",
      CellTags->"ICRP 78"]},
  "Info3345388266-5846447"->{
    Cell[344161, 4559, 405, 6, 70, "Print",
      CellTags->{"Info3345388266-5846447", "Introduction"}]},
  "Info3345388266-7899843"->{
    Cell[345910, 4616, 116, 2, 70, "Print",
      CellTags->"Info3345388266-7899843"]},
  "Info3345388266-2320785"->{
    Cell[347448, 4675, 658, 10, 208, "Print",
      CellTags->"Info3345388266-2320785"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Introduction", 1211395, 30043},
  {"ICRP 78", 1212784, 30078},
  {"Info3345388266-5846447", 1212887, 30081},
  {"Info3345388266-7899843", 1213023, 30084},
  {"Info3345388266-2320785", 1213141, 30087}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 168, 5, 186, "Chapter"],
Cell[1947, 60, 780, 21, 67, "Text",
  CellTags->"Introduction"],
Cell[2730, 83, 58, 0, 47, "Commentary"],

Cell[CellGroupData[{
Cell[2813, 87, 65, 2, 40, "Input"],
Cell[2881, 91, 101, 2, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3019, 98, 41, 0, 58, "SubsectionIcon"],
Cell[3063, 100, 1017, 19, 303, "Text"],
Cell[4083, 121, 692, 19, 127, "Commentary"]
}, Closed]],

Cell[CellGroupData[{
Cell[4812, 145, 39, 0, 39, "SubsectionIcon"],
Cell[4854, 147, 1401, 24, 262, "Text",
  CellTags->"Introduction"],

Cell[CellGroupData[{
Cell[6280, 175, 62, 0, 35, "SubsubsectionIcon"],
Cell[6345, 177, 795, 19, 122, "Text"],
Cell[7143, 198, 281170, 3474, 622, 281074, 3471, "GraphicsData", "Metafile", \
"Text"],
Cell[288316, 3674, 116, 4, 34, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[288469, 3683, 67, 0, 35, "SubsubsectionIcon"],
Cell[288539, 3685, 810, 15, 144, "Text"],
Cell[289352, 3702, 240, 6, 90, "NumberedEquation"],
Cell[289595, 3710, 488, 8, 100, "Text",
  CellTags->"ICRP 78"],
Cell[290086, 3720, 43706, 542, 498, 43614, 539, "GraphicsData", "Metafile", \
"Text"],
Cell[333795, 4264, 139, 4, 34, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[333983, 4274, 62, 0, 39, "SubsectionIcon"],
Cell[334048, 4276, 99, 2, 40, "Input"],
Cell[334150, 4280, 299, 12, 58, "MathCaption",
  CellTags->"Introduction"],

Cell[CellGroupData[{
Cell[334474, 4296, 115, 3, 40, "Input",
  CellTags->"Introduction"],
Cell[334592, 4301, 119, 3, 70, "Print",
  CellTags->"Introduction"],
Cell[334714, 4306, 146, 3, 70, "Print",
  CellTags->"Introduction"],
Cell[334863, 4311, 117, 3, 70, "Print",
  CellTags->"Introduction"]
}, Open  ]],
Cell[334995, 4317, 120, 3, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[335140, 4324, 86, 2, 40, "Input"],
Cell[335229, 4328, 8577, 213, 70, "Print"]
}, Open  ]],
Cell[343821, 4544, 211, 6, 85, "MathCaption",
  CellTags->"Introduction"],

Cell[CellGroupData[{
Cell[344057, 4554, 101, 3, 40, "Input",
  CellTags->"Introduction"],
Cell[344161, 4559, 405, 6, 70, "Print",
  CellTags->{"Info3345388266-5846447", "Introduction"}]
}, Open  ]],
Cell[344581, 4568, 130, 3, 58, "MathCaption",
  CellTags->"Introduction"],

Cell[CellGroupData[{
Cell[344736, 4575, 129, 4, 40, "Input",
  CellTags->"Introduction"],
Cell[344868, 4581, 160, 4, 70, "Output",
  CellTags->"Introduction"]
}, Open  ]],

Cell[CellGroupData[{
Cell[345065, 4590, 122, 4, 40, "Input",
  CellTags->"Introduction"],
Cell[345190, 4596, 614, 11, 70, "Output",
  CellTags->"Introduction"]
}, Open  ]],

Cell[CellGroupData[{
Cell[345841, 4612, 66, 2, 40, "Input"],
Cell[345910, 4616, 116, 2, 70, "Print",
  CellTags->"Info3345388266-7899843"]
}, Open  ]],
Cell[346041, 4621, 84, 1, 58, "MathCaption",
  CellTags->"Introduction"],
Cell[346128, 4624, 559, 20, 108, "DefinitionBox3Col",
  CellTags->"Introduction"]
}, Closed]],

Cell[CellGroupData[{
Cell[346724, 4649, 43, 0, 39, "SubsectionIcon"],
Cell[346770, 4651, 312, 6, 83, "Text"],
Cell[347085, 4659, 260, 8, 66, "Text"],

Cell[CellGroupData[{
Cell[347370, 4671, 75, 2, 40, "Input"],
Cell[347448, 4675, 658, 10, 208, "Print",
  CellTags->"Info3345388266-2320785"]
}, Open  ]],
Cell[348121, 4688, 359, 6, 78, "Text"],
Cell[348483, 4696, 357, 10, 56, "Text"],
Cell[348843, 4708, 570, 13, 115, "Text"],
Cell[349416, 4723, 17697, 221, 293, 17605, 218, "GraphicsData", "Metafile", \
"Graphics"],
Cell[367116, 4946, 520, 17, 83, "Text"],
Cell[367639, 4965, 988, 30, 103, "DefinitionBox"],
Cell[368630, 4997, 1004, 30, 125, "DefinitionBox"],
Cell[369637, 5029, 1058, 31, 125, "DefinitionBox"],
Cell[370698, 5062, 10931, 320, 678, "Commentary"],

Cell[CellGroupData[{
Cell[381654, 5386, 77, 2, 40, "Input"],
Cell[381734, 5390, 133, 3, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[381904, 5398, 77, 2, 40, "Input"],
Cell[381984, 5402, 204, 4, 54, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[382225, 5411, 78, 2, 40, "Input"],
Cell[382306, 5415, 732, 12, 160, "Output"]
}, Open  ]],
Cell[383053, 5430, 2310, 61, 279, "DefinitionBox"],
Cell[385366, 5493, 1761, 34, 572, "Commentary"],

Cell[CellGroupData[{
Cell[387152, 5531, 81, 2, 40, "Input"],
Cell[387236, 5535, 803, 13, 160, "Output"]
}, Open  ]],
Cell[388054, 5551, 933, 25, 122, "Text"],
Cell[388990, 5578, 92, 2, 34, "Text"],
Cell[389085, 5582, 492, 13, 74, "Text"],
Cell[389580, 5597, 1004, 33, 169, "DefinitionBox3Col"]
}, Closed]],

Cell[CellGroupData[{
Cell[390621, 5635, 36, 0, 39, "SubsectionIcon"],
Cell[390660, 5637, 1305, 20, 428, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[392002, 5662, 30, 0, 49, "Subsection"],
Cell[392035, 5664, 274, 7, 74, "Commentary"]
}, Open  ]],

Cell[CellGroupData[{
Cell[392346, 5676, 35, 0, 58, "SubsectionIcon"],
Cell[392384, 5678, 448, 10, 78, "Text"],
Cell[392835, 5690, 51075, 1120, 402, 15699, 678, "GraphicsData", \
"PostScript", "Graphics"],
Cell[443913, 6812, 92, 2, 34, "Text"],
Cell[444008, 6816, 88, 2, 34, "Text"],

Cell[CellGroupData[{
Cell[444121, 6822, 210, 5, 66, "Input"],
Cell[444334, 6829, 519, 13, 70, "Output"]
}, Open  ]],
Cell[444868, 6845, 750, 15, 122, "Text"],
Cell[445621, 6862, 750, 20, 227, "Output"],
Cell[446374, 6884, 147, 3, 58, "MathCaption"],
Cell[446524, 6889, 273, 6, 94, "Input"],
Cell[446800, 6897, 56, 0, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[446881, 6901, 86, 2, 40, "Input"],
Cell[446970, 6905, 867, 18, 70, "Output"]
}, Open  ]],
Cell[447852, 6926, 178, 3, 80, "MathCaption"],
Cell[448033, 6931, 102, 3, 34, "Text"],
Cell[448138, 6936, 297, 9, 56, "Text"],
Cell[448438, 6947, 101, 2, 40, "Input"],
Cell[448542, 6951, 818, 24, 58, "Text"],
Cell[449363, 6977, 101, 2, 40, "Input"],
Cell[449467, 6981, 171, 4, 39, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[449675, 6990, 35, 0, 39, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[449735, 6994, 99, 2, 35, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[449859, 7000, 207, 4, 66, "Input"],
Cell[450069, 7006, 4093, 99, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[454199, 7110, 193, 4, 66, "Input"],
Cell[454395, 7116, 1669, 27, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[456101, 7148, 200, 4, 66, "Input"],
Cell[456304, 7154, 1696, 29, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[458037, 7188, 201, 4, 66, "Input"],
Cell[458241, 7194, 1560, 25, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[459850, 7225, 103, 2, 27, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[459978, 7231, 242, 5, 66, "Input"],
Cell[460223, 7238, 4029, 80, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[464289, 7323, 245, 5, 66, "Input"],
Cell[464537, 7330, 4389, 89, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[468963, 7424, 253, 5, 92, "Input"],
Cell[469219, 7431, 5042, 96, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[474298, 7532, 254, 5, 92, "Input"],
Cell[474555, 7539, 3995, 80, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[478599, 7625, 103, 2, 27, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[478727, 7631, 242, 5, 66, "Input"],
Cell[478972, 7638, 71524, 2015, 70, 35038, 1561, "GraphicsData", \
"PostScript", "Graphics"],
Cell[550499, 9655, 155, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[550691, 9664, 245, 5, 66, "Input"],
Cell[550939, 9671, 63401, 1775, 70, 30872, 1370, "GraphicsData", \
"PostScript", "Graphics"],
Cell[614343, 11448, 155, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[614535, 11457, 253, 5, 92, "Input"],
Cell[614791, 11464, 69101, 1913, 70, 32732, 1460, "GraphicsData", \
"PostScript", "Graphics"],
Cell[683895, 13379, 155, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[684087, 13388, 254, 5, 92, "Input"],
Cell[684344, 13395, 69405, 1972, 70, 34507, 1538, "GraphicsData", \
"PostScript", "Graphics"],
Cell[753752, 15369, 155, 4, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[753956, 15379, 108, 2, 27, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[754089, 15385, 270, 6, 66, "Input"],
Cell[754362, 15393, 7563, 182, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[761962, 15580, 235, 4, 94, "Input"],
Cell[762200, 15586, 3895, 59, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[766132, 15650, 254, 5, 66, "Input"],
Cell[766389, 15657, 3993, 66, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[770419, 15728, 255, 5, 66, "Input"],
Cell[770677, 15735, 104, 2, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[770830, 15743, 105, 2, 27, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[770960, 15749, 260, 5, 66, "Input"],
Cell[771223, 15756, 9466, 225, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[780726, 15986, 244, 5, 66, "Input"],
Cell[780973, 15993, 3861, 59, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[784871, 16057, 253, 5, 66, "Input"],
Cell[785127, 16064, 103, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[785267, 16071, 252, 5, 66, "Input"],
Cell[785522, 16078, 104, 2, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[785687, 16087, 35, 0, 39, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[785747, 16091, 99, 2, 35, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[785871, 16097, 210, 4, 70, "Input"],
Cell[786084, 16103, 4702, 114, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[790823, 16222, 196, 4, 70, "Input"],
Cell[791022, 16228, 1820, 28, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[792879, 16261, 203, 4, 70, "Input"],
Cell[793085, 16267, 1885, 33, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[795007, 16305, 204, 4, 70, "Input"],
Cell[795214, 16311, 1801, 27, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[797064, 16344, 103, 2, 27, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[797192, 16350, 245, 5, 70, "Input"],
Cell[797440, 16357, 4572, 86, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[802049, 16448, 248, 5, 70, "Input"],
Cell[802300, 16455, 4435, 89, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[806772, 16549, 258, 5, 70, "Input"],
Cell[807033, 16556, 5042, 96, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[812112, 16657, 257, 5, 70, "Input"],
Cell[812372, 16664, 3987, 80, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[816408, 16750, 103, 2, 27, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[816536, 16756, 245, 5, 70, "Input"],
Cell[816784, 16763, 35129, 1564, 70, 35045, 1561, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[851916, 18329, 155, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[852108, 18338, 248, 5, 70, "Input"],
Cell[852359, 18345, 30966, 1373, 70, 30882, 1370, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[883328, 19720, 155, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[883520, 19729, 256, 5, 70, "Input"],
Cell[883779, 19736, 69150, 1913, 70, 32721, 1460, "GraphicsData", \
"PostScript", "Graphics"],
Cell[952932, 21651, 155, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[953124, 21660, 257, 5, 70, "Input"],
Cell[953384, 21667, 34625, 1543, 70, 34541, 1540, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[988012, 23212, 155, 4, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[988216, 23222, 108, 2, 27, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[988349, 23228, 240, 4, 70, "Input"],
Cell[988592, 23234, 3689, 62, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[992318, 23301, 243, 4, 70, "Input"],
Cell[992564, 23307, 4592, 65, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[997193, 23377, 257, 5, 70, "Input"],
Cell[997453, 23384, 4817, 83, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1002307, 23472, 260, 5, 70, "Input"],
Cell[1002570, 23479, 104, 2, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1002723, 23487, 105, 2, 27, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[1002853, 23493, 263, 5, 66, "Input"],
Cell[1003119, 23500, 11693, 277, 322, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1014849, 23782, 238, 4, 70, "Input"],
Cell[1015090, 23788, 4778, 73, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1019905, 23866, 258, 5, 70, "Input"],
Cell[1020166, 23873, 103, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1020306, 23880, 255, 5, 70, "Input"],
Cell[1020564, 23887, 104, 2, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1020729, 23896, 36, 0, 39, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[1020790, 23900, 100, 2, 35, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[1020915, 23906, 216, 4, 70, "Input"],
Cell[1021134, 23912, 5640, 76, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1026811, 23993, 217, 4, 70, "Input"],
Cell[1027031, 23999, 5238, 81, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1032306, 24085, 224, 4, 70, "Input"],
Cell[1032533, 24091, 96, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1032666, 24098, 225, 4, 70, "Input"],
Cell[1032894, 24104, 5633, 79, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1038576, 24189, 104, 2, 27, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[1038705, 24195, 268, 5, 70, "Input"],
Cell[1038976, 24202, 4290, 81, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1043303, 24288, 269, 5, 70, "Input"],
Cell[1043575, 24295, 5466, 90, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1049078, 24390, 279, 5, 70, "Input"],
Cell[1049360, 24397, 96, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1049493, 24404, 278, 5, 70, "Input"],
Cell[1049774, 24411, 4248, 81, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1054071, 24498, 104, 2, 27, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[1054200, 24504, 264, 5, 66, "Input"],
Cell[1054467, 24511, 39782, 1659, 70, 39698, 1656, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1094252, 26172, 155, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1094444, 26181, 269, 5, 70, "Input"],
Cell[1094716, 26188, 33462, 1508, 70, 33378, 1505, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1128181, 27698, 155, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1128373, 27707, 277, 5, 92, "Input"],
Cell[1128653, 27714, 96, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1128786, 27721, 276, 5, 92, "Input"],
Cell[1129065, 27728, 73388, 2069, 70, 39330, 1644, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1202456, 29799, 155, 4, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1202660, 29809, 109, 2, 27, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[1202794, 29815, 262, 4, 92, "Input"],
Cell[1203059, 29821, 1161, 23, 227, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1204257, 29849, 272, 5, 70, "Input"],
Cell[1204532, 29856, 1128, 22, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1205697, 29883, 280, 5, 70, "Input"],
Cell[1205980, 29890, 96, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1206113, 29897, 283, 5, 70, "Input"],
Cell[1206399, 29904, 104, 2, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1206552, 29912, 106, 2, 27, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[1206683, 29918, 259, 4, 92, "Input"],
Cell[1206945, 29924, 1061, 22, 166, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1208043, 29951, 265, 5, 92, "Input"],
Cell[1208311, 29958, 1052, 21, 166, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1209400, 29984, 279, 5, 92, "Input"],
Cell[1209682, 29991, 96, 2, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1209815, 29998, 276, 5, 92, "Input"],
Cell[1210094, 30005, 104, 2, 38, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

