(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    490675,      11481]*)
(*NotebookOutlinePosition[    494462,      11585]*)
(*  CellTagsIndexPosition[    494215,      11575]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Solving the ICRP 66 compartmental models ", "Chapter"],

Cell["Last update of this help. 2005-08-22 ", "Commentary"],

Cell[CellGroupData[{

Cell[BoxData[
    \($Version\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("5.1 for Microsoft Windows (January 28, 2005)"\)], "Output",
  CellLabel->"Out[1]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Initialization", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Needs["\<Biokmod`Resptract`\>"]\)], "Input",
  CellLabel->"In[2]:=",
  CellTags->"Introduction"],

Cell[BoxData[
    \("Resptract 1.2 b1 2005-05-16"\)], "Print",
  CellLabel->"From In[2]:=",
  CellTags->"Introduction"]
}, Open  ]],

Cell[BoxData[
    \(Needs["\<Graphics`Graphics`\>"]\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \(Needs["\<Graphics`Legend`\>"]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(styles = {{AbsoluteThickness[0.5], \ AbsoluteDashing[{4, 4}], 
          RGBColor[1, 0, 0]}, {AbsoluteThickness[1.5], 
          RGBColor[0, 1, 0]}, \ {AbsoluteThickness[2], \ 
          AbsoluteDashing[{1, 8}], RGBColor[0, 0, 1]}, \ 
        AbsoluteThickness[2.5]}; \)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(styles1 = {{AbsoluteThickness[1], \ AbsoluteDashing[{4, 4}], 
          RGBColor[1, 0, 1]}, {AbsoluteThickness[1], 
          RGBColor[0, 1, 0]}}; \)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(Off[General::spell1]; Off[General::spell]; \)], "Input",
  CellLabel->"In[7]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["The respiratory tract model (ICRP 66)", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["RT model description", "SubsubsectionIcon"],

Cell[TextData[{
  "ICRP 66 describes the compartmental model of the human respiratory tract \
(RT) applied to the intake of radioactive aerosols by inhalation (Fig.1). The \
respiratory tract is represented by five regions (fig. 1). The extrathoracic \
(ET) airways are divided into ",
  Cell[BoxData[
      \(TraditionalForm\`ET\_1\)]],
  "(nasal passage) and ",
  Cell[BoxData[
      \(TraditionalForm\`ET\_2\)]],
  " (posterior nasal and oral passages, the pharynx and the larynx) and the \
thoracic region is divided into BB (Bronchial), bronchiolar (bb), and \
alveolar-interstitial (AI: AI1, AI2, and AI3). ",
  Cell[BoxData[
      \(TraditionalForm\`LN\_ET\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`LN\_TH\)]],
  " represent extrathoracic and thoracic airways. "
}], "Text"],

Cell[TextData[{
  "In this model the material is deposited in the respiratory tract: in \
compartments labeled \[OpenCurlyDoubleQuote]Particles in Initial State\
\[CloseCurlyDoubleQuote] (PIS) and in ET1. From each PIS compartment the \
material is transferred into the body fluids,at a absorption rate sp.It is \
also simultaneously transferred from PIS (at a rate spt) to a corresponding \
compartment labeled \[OpenCurlyDoubleQuote]Particles in Transformed State\
\[CloseCurlyDoubleQuote] (PTS). The flow goes from 1, in PIS, to 1, in PTS, \
from 2, in PIS,to 2, in PTS,and so on. We can consider that each compartment \
1-13 in PIS has a mirror compartment 1-13 in PTS. In each compartment in PTS \
the isotope is dissolved at a constant rate ",
  Cell[BoxData[
      \(TraditionalForm\`s\_p\)]],
  " into the body fluids (usually the blood). For instance: the total \
transfer rate for AI2 in PIS will be ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(K\_AI2\),
            "TraditionalForm"], "=", 
          RowBox[{
            FormBox[\(k\_\(2, 4\)\),
              "TraditionalForm"], "+", 
            FormBox[\(s\_pt\),
              "TraditionalForm"], "+", 
            FormBox[\(s\_p\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  ", and for AI2, in PTS, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(K\_AI2\),
            "TraditionalForm"], "=", 
          RowBox[{
            FormBox[\(k\_\(2, 4\)\),
              "TraditionalForm"], "+", 
            FormBox[\(s\_t\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  ".This general model of RT is common to any element.\nThe initial \
deposition factor of inhaled aerosols are functions of AMAD (Activity Median \
Diameter) and AMTD  (Activity Median Thermodynamic Diameter).  Reference \
values for regional deposition are given in ICRP 66.  The transfer \
compartment  represents the body fluid (usually the blood). "
}], "Text"],

Cell[TextData[{
  "The values of ",
  Cell[BoxData[
      \(TraditionalForm\`s\_p\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`s\_pt\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`s\_t\)]],
  " depend on absorption, they ",
  "are related with the chemical form of the element",
  ". ICRP 66 consider tree type of compounds: Type F (fast absorption), type \
M (moderate absorption) and type S (Slow absorption). Default absorption \
rates, taken from Tabla 30 of ICRP 66, are given in table 1 "
}], "Text"],

Cell[TextData[{
  StyleBox["Table1",
    FontWeight->"Bold"],
  ".- Absorption parameters values for metabolism F, M and S (ICRP 66) "
}], "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          StyleBox[
            RowBox[{
              StyleBox["Default",
                FontWeight->"Bold"], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              StyleBox["absorption",
                FontWeight->"Bold"], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              StyleBox["parameters",
                FontWeight->"Bold"], " "}],
            FontSlant->"Plain",
            FontVariations->{"CompatibilityType"->0}], "s", 
          StyleBox["F",
            FontWeight->"Bold"], 
          StyleBox["M",
            FontWeight->"Bold"], 
          StyleBox["S",
            FontWeight->"Bold"]},
        {
          StyleBox[
            RowBox[{"Initial", " ", "disolution", " ", "rate", " ", 
              RowBox[{"(", 
                FormBox[\(d\^\(-1\)\),
                  "TraditionalForm"], ")"}]}],
            FontFamily->"Times New Roman"], \(s\_p\), "100", "10", "0.1"},
        {
          StyleBox[
            RowBox[{"Transformation", " ", "rate", " ", 
              RowBox[{"(", 
                FormBox[\(d\^\(-1\)\),
                  "TraditionalForm"], ")"}]}],
            FontFamily->"Times New Roman"], 
          FormBox[\(s\_pt\),
            "TraditionalForm"], "0", "90", "100"},
        {
          StyleBox[
            RowBox[{"Transformation", " ", "rate", " ", 
              RowBox[{"(", 
                FormBox[\(d\^\(-1\)\),
                  "TraditionalForm"], ")"}]}],
            FontFamily->"Times New Roman"], 
          FormBox[\(s\_t\),
            "TraditionalForm"], "0", "0.005", "0.0001"}
        },
      RowLines->True,
      ColumnLines->True]]]], "Commentary"],

Cell[TextData[{
  StyleBox["Table 2",
    FontWeight->"Bold"],
  ".- Respiratory Tract model: Compartments numbering and rate transfer \
coefficients values (ICRP 66) "
}], "Text"],

Cell["\<\
k[i,j]-> K value means transfer coeffs. from compartment i to compartment j.
k[i,0]-> K value means transfer coeffs. from compartment i to out the system \
or Environment(0).
This notation has little differences with ICRP 66. Compartment 14 here \
represents the transfer compartment or Blood (in place of  ET1). 
Lungs include the compartments 1 to 10\
\>", "Commentary"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"AI1\"\>", "1", "\<\"bb1\"\>", "4", "\<\"k[1,4]->\"\>", 
            "0.02`"},
          {"\<\"AI2\"\>", "2", "\<\"bb1\"\>", "4", "\<\"k[2,4]->\"\>", 
            "0.001`"},
          {"\<\"AI3\"\>", "3", "\<\"bb1\"\>", "4", "\<\"k[3,4]->\"\>", 
            "0.0001`"},
          {"\<\"AI3\"\>", "3", "\<\"\\!\\(LN\\_TH\\)\"\>", 
            "10", "\<\"k[3,10]->\"\>", "0.00002`"},
          {"\<\"bb1\"\>", "4", "\<\"BB1\"\>", "7", "\<\"k[4,7]->\"\>", "2"},
          {"\<\"bb2\"\>", "5", "\<\"BB1\"\>", "7", "\<\"k[5,9]->\"\>", 
            "0.03`"},
          {"\<\"bbseq\"\>", "6", "\<\"\\!\\(LN\\_TH\\)\"\>", 
            "10", "\<\"k[6,10]->\"\>", "0.01`"},
          {"\<\"BB1\"\>", "7", "\<\"ET2\"\>", "11", "\<\"k[7,11]->\"\>", 
            "10"},
          {"\<\"BB2\"\>", "8", "\<\"ET2\"\>", "11", "\<\"k[8,11]->\"\>", 
            "0.03`"},
          {"\<\"BBseq\"\>", "9", "\<\"LN-TH\"\>", "10", "\<\"k[9,10]->\"\>", 
            "0.01`"},
          {"\<\"LN-TH\"\>", "10", "\<\"Blood\"\>", 
            "14", "\<\"k[10,14]->\"\>", "\<\"\\!\\(s\\_p\\)\"\>"},
          {"\<\"ET2\"\>", "11", "\<\"Gitract\"\>", "15", "\<\"k[11,15]->\"\>",
             "100"},
          {"\<\"ETseq\"\>", "12", "\<\"\\!\\(LN\\_ET\\)\"\>", 
            "13", "\<\"k[12,13]->\"\>", "0.001`"},
          {"\<\"\\!\\(LN\\_ET\\)\"\>", "13", "\<\"Blood\"\>", 
            "14", "\<\"k[13,14]->\"\>", "\<\"\\!\\(s\\_p\\)\"\>"},
          {"\<\"Blood\"\>", "14", "\<\"Env\"\>", "0", "\<\"k[14,0]->\"\>", 
            "0"},
          {"\<\"GItract(ST)\"\>", "15", "\<\"Env\"\>", 
            "0", "\<\"k[15,0]->\"\>", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@000Bc80@0006`0000;0000000000T200020`00
^0400000002@D@00N7P00215CDH00040b2`108l9000<0000000000000000000080<005P200100@00
l0000000000000000000003R1020Z@<0AP0002`0000P0000ADe6:`500@0L00004000004@`=/10000
H000060000160000G00005000015CDH[8T0400`0000000007T0100`000000000940100`000000000
8D0700`000000000<4020100000400000020?`A0000<0000000001P0000<0000000001T0000<0000
oooo01@0000<00003@000180000<00000P00024000080000500000`0000=0000<00000`0000?0020
AP0002P0000L0000AdA9@`80000:0000ooooo`/200040`00000004H0000`K@0096d004E=AR/Z@000
900001P00000080o000000000000080o00000000000Q@0D030000000000U@000400000@000000000
;40002@0000H0000iM02?`0008000020@F15?ooo;d40002024001Fa/001PK0000A30f`8000020000
>6`00=O=aYX00:L02@2V0_d2H0000000Q5L000402@000a`f000=02d0000000D000090P0000050000
0@;oool01@0000@13@0000D000020@800005000030;d0_l10`0001h01@0000/22@2W00D0000<0_@2
o`450000104=0000;@000?L000<D0000002000000800082000000800P0200020P030`<00`=c00:K:
l03ono00X:2T0820P03o00000?l00?oo00000?l0o`3o003oo`3oool0100003@2000@00009PH?01H0
ooooo`00Y`0000T0002V0P00o@8000L0003l0P00oooo0000100002d10@080000nP80004000000002
100002d10P0700006`A80?d19P360@L0003l0P00oooo0000100002d10`040000l04100P0003j0P00
0000000000040000;@4100@0003`0@801`000?`2003oool000040000;@4200P0003j0P000@000?oo
o`840000;@4400L0000K14<0mP4/0=T1100002d10`040000l04200@0000]0@4010000?0110030000
7P0700005PA20?<1;@3L0A`0003k0_?o00000000T04000000000045bJF5/0000kP8:hjF7kGN^Qneg
d6O_Mnh22^<000X0100002d10P0L0000n`;go`0000000901000000000211LVUQK0000?X32SBUQneg
[XO]Mm1WkgOj0`Xd000:00@0000]0@@0100002d10P040000;@4400@0000]0@801@0000810@0000X0
000b2Rl0g0420000AE@900L0100002d110090000<PXe0>`10@00035D1@0400009`7oo`<0000N00D0
00010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0
100002d10`070000o0800?ooo`0000@0000]0@D020000?X20001000000000P@0000]0@H01`0001/4
A`2F0RL0@P840000;@4300@0003`0@D0100002d10@040000l04600<0000N00L0000F14H0T`8X04D2
100002d10P040000;@4200D000040@d0000500000P4100006000038:;P180P/00015KWIYLVm^KFE^
M00900L01@0300@01`0700/01`0700@0100002L1ool300007P0500000@;oool01@0000T2000000L0
000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<01`000?`20030`<00
00040000;@4500P0003j0P000@00000000840000;@4600L0000K1;`1I`:K0A<2100002d10`040000
l04500@0000]0@4010000?011P0300007P0700005PBk0F@2W04F0Q`0003k0_?o00000000_0800000
0000845bJF5/0000?0@:6ZF7kGN^Qnegd6O_Mc`42QX000X0100002d11@040000;@4500D000040@d0
000500000P4100004`00038:X`4T0PP00017BB1DLV5SM0X0100400P01@0800L0100400009`7oo`<0
000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P0000050000
0@;oool0100002d10`070000o0800?ooo`0000@0000]0@H020000?X200010000oooo0P@0000]0@L0
1`0001/4/P7B0I/1/0440000;@4300@0003`0@H0100002d10@040000l04700<0000N00L0000F1;41
c`6L0K<1100002d10P040000;@4400@0000]0@80100002d110040000;@4200D000040@d000050000
0P4100002@00038:WP6c0@40001cE0L0100002d1100:0000<PZT0KX10P00071d1@0300@0000W0Ooo
0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D0
00010_ooo`040000;@4300L0003l0P00oooo0000100002d11P080000nP800040003oool2100002d1
1`0700006`BC0C`1O04J0@@0000]0@<010000?011P040000;@4100@0003`0@L00`0001h01`0001H4
TP4i0Gd17@440000;@4200@0000]0@@0100002d10P040000;@4400@0000]0@801@0000@13@0000D0
00020@4000090000<PYo0Ad10@0007=d1`040000;@4400T0000b2XD190410000L7@500@0000W0Ooo
0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D0
00010_ooo`040000;@430100000V1Pl05P3ooooo000;0@00L04001T1002K0@0020000?X200010000
000000@0000]0@H01`000?`2003oool000040000;@470180000T0`L0306?0@l1S`4?0G41505a0A@1
S`4G0Hl14@6I0@@0000]0@4010000?011P040000;@4300@0003`0@L0200002H63`060?ooool10100
000V1Pl05P3ooooo002T0000E@000942001f0@0020000?X200010000000000@0000]0@H01`000?`2
003oool000040000;@4700L0000K17<1SP9I0:P0100002d10@040000l04600@0000]0@<010000?01
1`0800009PH?00H0ooooo`400`0001h01`0001H4LP6:0UX0[00L0000n`;]o`000000090100000000
0211LVUQK0000:`32RJUQneg[XO]Mm1WkgN/0`XV000:00@0000]0@H01@0000@13@0000D000020@40
00090000<P[307L20@0005003@090000<P[K07/20@0004T01P090000<P[c07L20@0005<03@040000
9`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00
000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@L020000?X20001000000000P@0
000]0@P01`0001/4J05X0TH1_`440000;@4300@0003`0@L0100002d10@040000l04800L0003l0P00
oooo0000100002d11`080000nP80004000000002100002d1200700006`AX0Nh0_`3100@0000]0@<0
10000?011`040000;@4100@0003`0@P0400002H63`0F0?ooool00>`0001A0@00_P4005h100080000
nP80004000000000100002d11`070000o0810000000000@0000]0@P0200002D30P2l0EL1m@1G0@P0
003j0PD00@00000000040000;@4900@0003`0@L01`000?`20000000000040000;@4700X0000T0`<0
n01B0Nh0F07h05d1100002d10@040000;@4300@0003`0@L0200002H63`060?ooool100L0003l0P00
oooo0000100002d11`080000nP80004000000002100002d12P0700006`@V0FP2106n0@@0000]0@<0
10000?011`040000;@4100@0003`0@X01`000?`2003oool000040000;@4700P0003j0P000@000000
00840000;@4:00L0000K1>00I`:n0<01100002d10`040000l04700@0000]0@4010000?012P0@0000
9PH?01H0ooooo`00m04004D1003g0@00JP4000P0003j0P000@00000000040000;@4700@0000]0@P0
200002D30P3e0DH1m@5X0@@0000]0@4010000?011`040000;@4300P0000V1Pl01P3ooooo0@0@0000
9PH?01H0ooooo`00;08004H1000_0P00JP4000P0003j0P000@00000000040000;@4700@0000]0@P0
200002D30P0]0TL1;@9X0@@0000]0@4010000?011`040000;@4300P0000V1Pl01P3ooooo0@070000
o0800?ooo`0000@0000]0@L020000?X20001000000000P@0000]0@X01`0001/4SP1X0V`0_P440000
;@4300@0003`0@L0100002d10@040000l04:00L0003l0P00oooo0000100002d11`080000nP800040
003oool2100002d12P0700006`AQ0N`1C@7@0@@0000]0@<010000?011`040000;@4100@0003`0@X0
0`0001h01`0001H4H07Y0Dh1d`440000;@4200@0000]0@@0100002d10P040000;@4400@0000]0@80
1@0000@13@0000D000020@40000:0000<PY@0M<10P0004592@0300@0000]0@@02@00038:EP7O0@40
000cB@D0100002L1ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1
ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool000040000;@4700P0003j0P00
0@000?ooo`840000;@4:00L0000K16418@9=0@H2100002d10`040000l04700@0000]0@4010000?01
2P0300007P0700005PAP0Ah2CP490P@0000]0@80100002d110040000;@4200@0000]0@@0100002d1
0P050000104=00001@0000810@0000X0000b2U012@820000@DT900<0100002d110090000<PYF0AD2
0@0003991@0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P040000
9`7oo`D000090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@L020000?X2
00010000oooo0P@0000]0@X01`0001/4H`5G0Tl1?P840000;@4300@0003`0@L0100002d10@040000
l04:00<0000N00L0000F1681E09@0D42100002d10P040000;@4400@0000]0@80100002d110040000
;@4200D000040@d0000500000P4100002P00038:DP510P800011B@T00`040000;@4400T0000b2UP1
C@810000<DT500@0000W0Ooo0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0
000W0Ooo1@0000T2000000D000010_ooo`040000;@4300L0003l0P00oooo0000100002d11`080000
nP800040003oool2100002d12P0700006`@N0B<22P470P@0000]0@<010000?011`040000;@4100@0
003`0@X00`0001h01`0001H47@4P0P/12P840000;@4200@0000]0@@0100002d10P040000;@4400@0
000]0@801@0000@13@0000D000020@40000:0000<PX=0@X20P00069R1`0700@0000]0@@02@00038:
4`4H0P40000aHPD0100002L1ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0
100002L1ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool000040000;@4700P0
003j0P000@000?ooo`840000;@4:00L0000K1=T08@;500@2100002d10`040000l04700@0000]0@40
10000?012P0300007P0700005PCH01h2aP070P@0000]0@80100002d110040000;@4200@0000]0@@0
100002d10P050000104=00001@0000810@0000X0000b2/P01`820000@T8900T0100002d110090000
<P[>01T20@0003521@0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a40
6P0400009`7oo`D000090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@L0
20000?X200010000oooo0P@0000]0@X01`0001/4Q`0S0W001P840000;@4300@0003`0@L0100002d1
0@040000l04:00<0000N00L0000F18H0809a00T2100002d10P040000;@4400@0000]0@80100002d1
10040000;@4200D000040@d0000500000P4100002P00038:L`090P800015E0T01`040000;@4400T0
000b2WT06@810000<U@500@0000W0Ooo0`0001h01@000042oooo00D000090P00000700005PB<0@d3
4@0J00@0000W0Ooo1@0000T2000000D000010_ooo`040000;@4300L0003l0P00oooo0000100002d1
1`080000nP80004000000002100002d12P0700006`CQ09l1_`1a0@@0000]0@<010000?011`040000
;@4100@0003`0@X01`000?`2003oool000040000;@4700P0003j0P000@00000000840000;@4:00L0
000K12D1W`430G41100002d10`040000l04700@0000]0@4010000?012P070000o0800?ooo`0000@0
000]0@L020000?X20001000000000P@0000]0@X01`0001/4h@1;0Kl040440000;@4300@0003`0@L0
100002d10@040000l04:00L0003l0P00oooo0000100002d11`080000nP80004000000002100002d1
2P0700006`@U0D/10`4@0@@0000]0@<010000?011`040000;@4100@0003`0@X0400002H63`0F0?oo
ool008P1003M0000``4000@100080000nP80004000000000100002d11`040000;@4800P0000U0`80
R@420K/1h@040000;@4900@0003`0@L01`000?`20000000000040000;@4700X0000T0`<0^`7Y0<81
gP2f0N00100002d10@040000;@4300@0003`0@L0200002H63`060?ooool10100000V1Pl05P3ooooo
00270@00RP000<81002o000020000?X200010000000000@0000]0@L0100002d1200800009@<208P1
_@2k0I00100002d12@040000l04700L0003l0P0000000000100002d11`0:000090<30;d1U`300H`0
]@6?00@0000]0@40100002d10`040000l04700P0000V1Pl01P3ooooo0@0@00009PH?01H0ooooo`00
kP000</0000?0@00f00000P0003j0P000@00000000040000;@4700@0000]0@P0200002D30P0=0M40
m`3A00@0000]0@T010000?011`070000o0800000000000@0000]0@L02P0002@30`3j0<`0l03B0?X0
e`040000;@4100@0000]0@<010000?011`0800009PH?00H0ooooo`40400002H63`0F0?ooool00>d0
000>0@003P4001/100080000nP80004000000000100002d11`040000;@4800P0000U0`80304D0OH0
50440000;@4900@0003`0@L01`000?`20000000000040000;@4700X0000T0`<0n@0?0Nh0507i01X1
100002d10@040000;@4300@0003`0@L0200002H63`060?ooool100L0003l0P00oooo0000100002d1
1`080000nP80004000000002100002d12P0700006`B<0?00JP3200@0000]0@<010000?011`040000
;@4100@0003`0@X01`000?`2003oool000040000;@4700P0003j0P000@00000000840000;@4:00L0
000K18`0B@5Z0101100002d10`040000l04700@0000]0@4010000?012P070000o0800?ooo`0000@0
000]0@L020000?X200010000oooo0P@0000]0@X01`0001/4Q@130Fh06P440000;@4300@0003`0@L0
100002d10@040000l04:00<0000N00L0000F18@0@05_01d1100002d10P040000;@4400@0000]0@80
100002d110040000;@4200D000040@d0000500000P4100002P00038:L@0M0@800015E0T01`040000
;@4400`0000b2WL0;@430000LfEaN0D01@0500@0000W0Ooo0`0001h01@000042oooo00D000090P00
000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D000010_ooo`040000;@4300L0003l0P00
oooo0000100002d11`080000nP800040003oool2100002d12P0700006`CK0401a00G0@@0000]0@<0
10000?011`040000;@4100@0003`0@X00`0001h01`0001H4fP0m0LD06P440000;@4200@0000]0@@0
100002d10P040000;@4400@0000]0@801@0000@13@0000D000020@40000:0000<P[701X10P000492
2@0900@0000]0@@03000038:c@0/0@<0001cIG5i1@0500D0100002L1ool300007P0500000@;oool0
1@0000T2000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<0
1`000?`2003oool000040000;@4700P0003j0P000@000?ooo`840000;@4:00L0000K11l1?P480AD1
100002d10`040000l04700@0000]0@4010000?012P0300007P0700005P@N0C/12@4H0@@0000]0@80
100002d110040000;@4200@0000]0@@0100002d10P050000104=00001@0000810@0000X0000b2P/1
60420000HV8700L0100002d1100<0000<PXA0BH10`0007=ULGX500D01@0400009`7oo`<0000N00D0
00010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0
100002d10`070000o0800?ooo`0000@0000]0@L020000?X200010000oooo0P@0000]0@X01`0001/4
7@7/00H1``040000;@4300@0003`0@L0100002d10@040000l04:00<0000N00L0000F11`1j@070LH0
100002d10P040000;@4400@0000]0@80100002d110040000;@4200D000040@d0000500000P410000
2P00038:2@760080001<CPL02@040000;@4400X0000b2Pl1eP020000E4P500L0100002L1ool30000
7P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042
oooo00@0000]0@<01`000?`2003oool000040000;@4700P0003j0P000@000?ooo`840000;@4:00L0
000K18H0k@1_0<@0100002d10`040000l04700@0000]0@4010000?012P0300007P0700005PB50>X0
L03700@0000]0@80100002d110040000;@4200@0000]0@@0100002d10P050000104=00001@000081
0@0000X0000b2W80a`020000C4h700T0100002d1100:0000<PYh0=L00P0004ED1P0500@0000W0Ooo
0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D0
00010_ooo`040000;@430100000V1Pl05P3ooooo003^0000M@0000l10022000020000?X200010000
000000@0000]0@L0100002d1200800009@<200d1N`3g07/0100002d12@040000l04700L0003l0P00
00000000100002d11`0:000090<30?X0MP3`07`0nP2100@0000]0@40100002d10`040000l04700P0
000V1Pl01P3ooooo0@070000o0800?ooo`0000@0000]0@L020000?X200010000oooo0P@0000]0@X0
1`0001/4f@2C0LD0MP440000;@4300@0003`0@L0100002d10@040000l04:00<0000N00L0000F1=P0
T07607T1100002d10P040000;@4400@0000]0@80100002d110040000;@4200D000040@d000050000
0P4100002P00038:b01i0@800012@PT02@040000;@4400T0000b2/h0R`410000<T8500@0000W0Ooo
0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D0
00010_ooo`040000;@4300L0003l0P00oooo0000100002d11`080000nP800040003oool2100002d1
2P0700006`@L0ID1205i0@@0000]0@<010000?011`040000;@4100@0003`0@X00`0001h01`0001H4
6`6B0@T1O0440000;@4200@0000]0@@0100002d10P040000;@4400@0000]0@801@0000@13@0000D0
00020@40000:0000<PX;0G`10P00069R1`0700@0000]0@@02@00038:4@6:0@40000bHPD0100002L1
ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@800000
1@000042oooo00@0000]0@<01`000?`2003oool000040000;@4700P0003j0P000@00000000840000
;@4:00L0000K16L1kP1I0ML0100002d10`040000l04700@0000]0@4010000?012P0300007P070000
5PAV0N/0FP7J01`0003k0_Go00000000T04000000000845bJF5/0000B`@:7ZF7kGN^Qnegd6O_Md/4
2Qh000X0100002d11`040000;@4700D000040@d0000500000P4100002P00038:FP7J0080000a<0H0
1P0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D0
00090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X020000?X200010000
00000P@0000]0@/01`0001/4I`5X0UX1G@840000;@4300@0003`0@X0100002d10@040000l04;00<0
000N00L0000F16H1I@9K0F02100002d11`040000;@4700@0000]0@L01@0000@13@0000D000020@40
00090000<PYK0F020@00034`1P0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4
S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0
000]0@X020000?X20001000000000P@0000]0@/01`0001/4I`4^0UX18`840000;@4300@0003`0@X0
100002d10@040000l04;00<0000N00L0000F16H1:`9K0BH2100002d11`040000;@4700@0000]0@L0
1@0000@13@0000D000020@4000090000<PYK0BH20@00038`1P0400009`7oo`<0000N00D000010_oo
o`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d1
0`070000o0800?ooo`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4I`7e0EX1
jP440000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F16H1lP5K0Nd1100002d1
1`040000;@4700@0000]0@L01@0000@13@0000D000020@4000090000<PYK0Nd10@0003<`1P040000
9`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00
000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X020000?X20001000000000P@0
000]0@/01`0001/49@5W0QP1G0840000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0
000F12@1I08I0El2100002d11`040000;@4700@0000]0@L01@0000@13@0000D000020@4000090000
<PXI0El20@0003@`1P0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a40
6P0400009`7oo`D000090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X0
20000?X20001000000000P@0000]0@/01`0001/4g`1V0]80F`840000;@4300@0003`0@X0100002d1
0@040000l04;00<0000N00L0000F1=h0H`;C05h2100002d11`040000;@4700@0000]0@L01@0000@1
3@0000D000020@4000090000<P[C05h20@0003L`1P0400009`7oo`<0000N00D000010_ooo`050000
2@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d10`070000
o0800?ooo`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4h@2O0M40T@440000
;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F1>00W07B09@1100002d11`040000
;@4700D000040@d0000500000P4100002@00038:dP2D0@40000h<0H0100002L1ool300007P050000
0@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0
000]0@<01`000?`2003oool000040000;@4:00P0003j0P000@00000000840000;@4;00L0000K12D1
W`4G0I<1100002d10`040000l04:00@0000]0@4010000?012`0300007P0700005P@T0I`1606F0@@0
000]0@L0100002d11`050000104=00001@0000810@0000T0000b2QP1UP410000=C0600@0000W0Ooo
0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D0
00010_ooo`040000;@4300L0003l0P00oooo0000100002d12P080000nP80004000000002100002d1
2`0700006`CP04X1d00n0@@0000]0@<010000?012P040000;@4100@0003`0@/00`0001h01`0001H4
g`170M40@@440000;@4700@0000]0@L01@0000@13@0000D000020@4000090000<P[A04410@0003T`
1P0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D0
00090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X020000?X200010000
00000P@0000]0@/01`0001/49@5;0A@1?`440000;@4300@0003`0@X0100002d10@040000l04;00<0
000N00L0000F12@1B04E0D81100002d11`040000;@4700D000040@d0000500000P4100002@00038:
5@520@40000f<0H0100002L1ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0
100002L1ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool000040000;@4:00P0
003j0P000@00000000840000;@4;00L0000K1900D`6203`1100002d10`040000l04:00@0000]0@40
10000?012`0300007P0700005PB?0501P`0o0@@0000]0@L0100002d11`050000104=00001@000081
0@0000X0000b2X<0?`420000<C8600H0100002L1ool300007P0500000@;oool01@0000T2000000L0
000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool0
00040000;@4:00P0003j0P000@00000000840000;@4;00L0000K1900m`230>40100002d10`040000
l04:00@0000]0@4010000?012`0300007P0700005PB?0?@0Q03T00@0000]0@L0100002d11`050000
104=00001@0000810@0000X0000b2X@0i0020000<C<600H0100002L1ool300007P0500000@;oool0
1@0000T2000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<0
1`000?`2003oool000040000;@4:00P0003j0P000@00000000840000;@4;00L0000K18d0I`9o0502
100002d10`040000l04:00@0000]0@4010000?012`0300007P0700005PB<06@2P01C0P@0000]0@L0
100002d11`050000104=00001@0000810@0000X0000b2X00D`820000<C4600H0100002L1ool30000
7P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042
oooo00@0000]0@<0400002H63`0F0?ooool00:h0001J0000L`8005h000080000nP80004000000000
100002d12P040000;@4800P0000U0`80[`1L0742F`040000;@4100@0003`0@X0100002d10`080000
9PH?00H0ooooo`40400002H63`0F0?ooool000d2002<00006P800<0000080000nP80004000000000
100002d12P040000;@4800P0000U0`804`:n01<2U@040000;@4900@0003`0@X01`000?`200000000
00040000;@4:00X0000T0`<06@:H01@2SP0>0YP0100002d10@040000;@4300@0003`0@X0200002H6
3`060?ooool10100000V1Pl05P3ooooo000;0P00gP0001P200070@0020000?X200010000000000@0
000]0@X0100002d1200800009@<201421@4A0^L0100002d12@040000l04:00L0003l0P0000000000
100002d12P0:000090<301L2jP0B0^0030;Z00@0000]0@40100002d10`040000l04:00P0000V1Pl0
1P3ooooo0@0@00009PH?01H0ooooo`00e@400281003R0@00B@4000P0003j0P000@00000000040000
;@4:00@0000]0@P0200002D30P3K0DL1f`4[0@@0000]0@T010000?012P070000o0800000000000@0
000]0@X02P0002@30`3Q0Bh1g04T0MH1;P440000;@4100@0000]0@<010000?012P0800009PH?00H0
ooooo`40400002H63`0F0?ooool000X2000R0@005`8004T100080000nP80004000000000100002d1
2P040000;@4800P0000U0`8040970A02:`440000;@4900@0003`0@X01`000?`20000000000040000
;@4:00X0000T0`<05P8^0A02904;0Rh1100002d10@040000;@4300@0003`0@X0200002H63`060?oo
ool10100000V1Pl05P3ooooo00130P008P40050200190@0020000?X200010000000000@0000]0@X0
100002d1200800009@<204T2A`590R/1100002d12@040000l04:00L0003l0P0000000000100002d1
2P0:000090<304l2;P5:0R@1A08^0@@0000]0@40100002d10`040000l04:00P0000V1Pl01P3ooooo
0@0@00009PH?01H0ooooo`00X`000=l1002@0P0000<000P0003j0P000@00000000040000;@4:00L0
003l0P00oooo0000100002d12`0700006`Cm0Xd2h`6W00@0000]0@4010000?012P040000;@4300@0
003`0@/0200002H63`060?ooool100<0000N00L0000F1?`2R@;T0J/0100002d11P050000104=0000
1@0000810@0000T0000b2Td2MP810000D00=00T0000b2VD2M`810000E00<00T0000b2Wd2MP810000
D`0=00@0000W0Ooo0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo
1@0000T2000000D000010_ooo`040000;@4300L0003l0P00oooo0000100002d12P080000nP800040
00000002100002d12`0700006`Cb0VL2d0:n0@@0000]0@<010000?012P040000;@4100@0003`0@/0
1`000?`2003oool000040000;@4:00P0003j0P000@00000000840000;@4;00L0000K1?82k@190/00
100002d10`040000l04:00@0000]0@4010000?012`0@00009PH?01H0ooooo`00j`000=/2002m0@00
j08000P0003j0P000@00000000040000;@4:00@0000]0@P0200002D30P2k0N42m03Q0P@0000]0@T0
10000?012P070000o0800000000000@0000]0@X02P0002@30`3g0=`2k03R0_L0i`840000;@4100@0
000]0@<010000?012P0800009PH?00H0ooooo`401`000?`2003oool000040000;@4:00P0003j0P00
0@00000000840000;@4;00L0000K1;02I`:>0[d1100002d10`040000l04:00@0000]0@4010000?01
2`070000o0800?ooo`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4JP9V0TP2
_`440000;@4300@0003`0@X0100002d10@040000l04;0100000V1Pl05P3ooooo003c0@00c`800?H1
003d0P0020000?X200010000000000@0000]0@X0100002d1200800009@<20?@1d0;d0O82100002d1
0@040000l04:00@0000]0@<0200002H63`060?ooool10100000V1Pl05P3ooooo000[0P00d08002h2
003d0P0020000?X200010000000000@0000]0@X0100002d1200800009@<202`2d@8/0_82100002d1
0@040000l04:00@0000]0@<0200002H63`060?ooool100L0003l0P00oooo0000100002d12P080000
nP80004000000002100002d12`0700006`@H0VL2mP6m0@@0000]0@<010000?012P040000;@4100@0
003`0@/01`000?`2003oool000040000;@4:00P0003j0P000@000?ooo`840000;@4;00L0000K1>/2
j`7G0/l1100002d10`040000l04:00@0000]0@4010000?012`0300007P0700005PCZ0^P1f0;B0@@0
000]0@80100002d110040000;@4200@0000]0@@0100002d10P050000104=00001@0000810@0000X0
000b2]X2dP420000@DT900<0100002d110090000<P[P0]h10@0003=91@0400009`7oo`<0000N00D0
00010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0
100002d10`070000o0800?ooo`0000@0000]0@X020000?X200010000oooo0P@0000]0@/01`0001/4
j`8P0]L21@840000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F1>X27@;H0PP2
100002d10P040000;@4400@0000]0@80100002d110040000;@4200D000040@d0000500000P410000
2P00038:fP880P800011B@T00`040000;@4400T0000b2^0250810000<TT500@0000W0Ooo0`0001h0
1@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D000010_oo
o`040000;@4300L0003l0P00oooo0000100002d12P080000nP800040003oool2100002d12`070000
6`C]0UH2f@8m0P@0000]0@<010000?012P040000;@4100@0003`0@/00`0001h01`0001H4k09C0]X2
@0840000;@4200@0000]0@@0100002d10P040000;@4400@0000]0@801@0000@13@0000D000020@40
000:0000<P[L0T020P0004592@0300@0000]0@@02@00038:hP9<0P40000aB@D0100002L1ool30000
7P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042
oooo00@0000]0@<01`000?`2003oool000040000;@4:00P0003j0P000@000?ooo`840000;@4;00L0
000K1:P28P:D0PH2100002d10`040000l04:00@0000]0@4010000?012`0300007P0700005PBW0Ql2
U@890P@0000]0@80100002d110040000;@4200@0000]0@@0100002d10P050000104=00001@000081
0@0000X0000b2YL22@820000HV8700L0100002d110090000<PZM0QL20@00035R1@0400009`7oo`<0
000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P0000050000
0@;oool0100002d10`070000o0800?ooo`0000@0000]0@X020000?X200010000oooo0P@0000]0@/0
1`0001/4H`8P0Tl20`840000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F1682
7@9@0PH2100002d10P040000;@4400@0000]0@80100002d110040000;@4200D000040@d000050000
0P4100002P00038:DP860P800012@PT02@040000;@4400T0000b2UP260810000<D8500@0000W0Ooo
0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D0
00010_ooo`040000;@4300L0003l0P00oooo0000100002d12P080000nP800040003oool2100002d1
2`0700006`@A0R82nP450P@0000]0@<010000?012P040000;@4100@0003`0@/00`0001h01`0001H4
408O0_/120840000;@4200@0000]0@@0100002d10P040000;@4400@0000]0@801@0000@13@0000D0
00020@40000:0000<P[m0@P20P0004ED2@0700@0000]0@@02@00038:0`8H0P40000bE0D0100002L1
ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@800000
1@000042oooo00@0000]0@<01`000?`2003oool000040000;@4:00P0003j0P000@00000000840000
;@4;00L0000K16/2WP590W01100002d10`040000l04:00@0000]0@4010000?012`070000o0800?oo
o`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4[`:N0Hd2L0440000;@4300@0
003`0@X0100002d10@040000l04;00L0003l0P00oooo0000100002d12P080000nP80004000000002
100002d12`0700006`A[0TX1B@8?0@@0000]0@<010000?012P040000;@4100@0003`0@/01`000?`2
003oool000040000;@4:00P0003j0P000@00000000840000;@4;00L0000K1:l2BP6=0Pl1100002d1
0`040000l04:00@0000]0@4010000?012`0@00009PH?01H0ooooo`00Q`4006L200320@00SP8000P0
003j0P000@00000000040000;@4:00@0000]0@P0200002D30P280H`2^P5[0P@0000]0@T010000?01
2P070000o0800000000000@0000]0@X02P0002@30`2j0G<2`05X0[D1JP840000;@4100@0000]0@<0
10000?012P0800009PH?00H0ooooo`40400002H63`0F0?ooool008H1000D0P00`@4004T200080000
nP80004000000000100002d12P040000;@4800P0000U0`80Q`570[X16P840000;@4900@0003`0@X0
1`000?`20000000000040000;@4:00X0000T0`<0_04Q0/015P:d0AT2100002d10@040000;@4300@0
003`0@X0200002H63`060?ooool10100000V1Pl05P3ooooo003]0000E@8000h1001R0P0020000?X2
00010000000000@0000]0@X0100002d1200800009@<200`1F`;f05/2100002d12@040000l04:00L0
003l0P0000000000100002d12P0:000090<30?T0EP;^05`2n@1Q0P@0000]0@40100002d10`040000
l04:00P0000V1Pl01P3ooooo0@0@00009PH?01H0ooooo`00k00009P2000=0@00Y@8000P0003j0P00
0@00000000040000;@4:00@0000]0@P0200002D30P0;0Ih2m@2N0P@0000]0@T010000?012P070000
o0800000000000@0000]0@X02P0002@30`3h09T2kP2N0_P0Y0840000;@4100@0000]0@<010000?01
2P0800009PH?00H0ooooo`401`000?`2003oool000040000;@4:00P0003j0P000@00000000840000
;@4;00L0000K11H2k`3d0L40100002d10`040000l04:00@0000]0@4010000?012`070000o0800?oo
o`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/45P980O@13`440000;@4300@0
003`0@X0100002d10@040000l04;00L0003l0P00oooo0000100002d12P080000nP800040003oool2
100002d12`0700006`@?0T81n04I0@@0000]0@<010000?012P040000;@4100@0003`0@/00`0001h0
1`0001H43P8o0OT170440000;@4200@0000]0@@0100002d10P040000;@4400@0000]0@801@0000@1
3@0000D000020@40000:0000<P[k0A`10P0004ED2@0700@0000]0@@03000038:0@8/0@<0001cIG6/
1@0500D0100002L1ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1
ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool000040000;@4:00P0003j0P00
0@000?ooo`840000;@4;00L0000K16D2?`5>0QH1100002d10`040000l04:00@0000]0@4010000?01
2`0300007P0700005PAT0S`1C`8I0@@0000]0@80100002d110040000;@4200@0000]0@@0100002d1
0P050000104=00001@0000810@0000X0000b2U426@420000@T8900T0100002d1100<0000<PYG0R/1
0`0007=ULJd500D01@0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a40
6P0400009`7oo`D000090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X0
20000?X200010000oooo0P@0000]0@/01`0001/4Z@8m0I8250440000;@4300@0003`0@X0100002d1
0@040000l04;00<0000N00L0000F1:P2>P6C0QL1100002d10P040000;@4400@0000]0@80100002d1
10040000;@4200D000040@d0000500000P4100002P00038:U@8G0@80001RHPL01`040000;@4400`0
000b2Y/29@430000LfEa[PD01@0500@0000W0Ooo0`0001h01@000042oooo00D000090P0000070000
5PB<0@d34@0J00@0000W0Ooo1@0000T2000000D000010_ooo`040000;@4300L0003l0P00oooo0000
100002d12P080000nP800040003oool2100002d12`0700006`BW0^/0T0;200@0000]0@<010000?01
2P040000;@4100@0003`0@/00`0001h01`0001H4YP;X0942a@040000;@4200@0000]0@@0100002d1
0P040000;@4400@0000]0@801@0000@13@0000D000020@40000:0000<PZC0/D00P0004a>1`0900@0
000]0@@02P00038:V@;E0080001DB0D01`0400009`7oo`<0000N00D000010_ooo`0500002@800000
1`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d10`070000o0800?oo
o`0000@0000]0@X020000?X200010000oooo0P@0000]0@/01`0001/440;/0?T1``040000;@4300@0
003`0@X0100002d10@040000l04;00<0000N00L0000F10l2j@3j0LH0100002d10P040000;@4400@0
000]0@80100002d110040000;@4200D000040@d0000500000P4100002P00038:o0760080001<CPL0
2@040000;@4400X0000b2P82eP020000AE@600D0100002L1ool300007P0500000@;oool01@0000T2
000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<0400002H6
3`0F0?ooool00>d0003o0@003P4000`200080000nP80004000000000100002d12P040000;@4800P0
000U0`8030450_H01@840000;@4900@0003`0@X01`000?`20000000000040000;@4:00X0000T0`<0
n@000^h01P;i00/2100002d10@040000;@4300@0003`0@X0200002H63`060?ooool100L0003l0P00
oooo0000100002d12P080000nP800040003oool2100002d12`0700006`AT0Y81D09e0@@0000]0@<0
10000?012P040000;@4100@0003`0@/00`0001h01`0001H4H`:?0E42N0440000;@4200@0000]0@@0
100002d10P040000;@4400@0000]0@801@0000@13@0000D000020@40000:0000<PYC0WP10P000492
2@0900@0000]0@@02@00038:F@::0@40000b@PD0100002L1ool300007P0500000@;oool01@0000T2
000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<01`000?`2
003oool000040000;@4:00P0003j0P000@000?ooo`840000;@4;00L0000K1:H2U06B0WP1100002d1
0`040000l04:00@0000]0@4010000?012`0300007P0700005PBU0Y41T`9k0@@0000]0@80100002d1
10040000;@4200@0000]0@@0100002d10P050000104=00001@0000810@0000X0000b2YD2N`420000
HV8700L0100002d110090000<PZK0XT10@00039R1@0400009`7oo`<0000N00D000010_ooo`050000
2@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d10`070000
o0800?ooo`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4l@;]0><2eP040000
;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F1?02jP3T0]T0100002d11`040000
;@4700D000040@d0000500000P4100002P00038:i0;I0080000a<0H01P0400009`7oo`<0000N00D0
00010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0
100002d10`070000o0800?ooo`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4
l@9W0^@2G0840000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F1?02I0;U0Ul2
100002d11`040000;@4700@0000]0@L01@0000@13@0000D000020@4000090000<P[U0Ul20@00034`
1P0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D0
00090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X020000?X200010000
00000P@0000]0@/01`0001/4l@8]0^@28P840000;@4300@0003`0@X0100002d10@040000l04;00<0
000N00L0000F1?02:P;U0RD2100002d11`040000;@4700@0000]0@L01@0000@13@0000D000020@40
00090000<P[U0RD20@00038`1P0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4
S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0
000]0@X020000?X20001000000000P@0000]0@/01`0001/4l@;d0N@2j@440000;@4300@0003`0@X0
100002d10@040000l04;00<0000N00L0000F1?02l@7U0^`1100002d11`040000;@4700@0000]0@L0
1@0000@13@0000D000020@4000090000<P[U0^`10@0003<`1P0400009`7oo`<0000N00D000010_oo
o`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d1
0`070000o0800?ooo`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4[`9V0Z82
F`840000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F1:h2H`:S0Uh2100002d1
1`040000;@4700@0000]0@L01@0000@13@0000D000020@4000090000<PZS0Uh20@0003@`1P040000
9`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00
000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X020000?X20001000000000P@0
000]0@/01`0001/4JP9V0Ud2F`840000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0
000F16T2H`9N0Uh2100002d11`040000;@4700@0000]0@L01@0000@13@0000D000020@4000090000
<PYN0Uh20@0003L`1P0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a40
6P0400009`7oo`D000090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X0
20000?X20001000000000P@0000]0@/01`0001/4J`:N0E`2TP440000;@4300@0003`0@X0100002d1
0@040000l04;00<0000N00L0000F16X2V`5M0YD1100002d11`040000;@4700D000040@d000050000
0P4100002@00038:G@:E0@40000h<0H0100002L1ool300007P0500000@;oool01@0000T2000000L0
000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool0
00040000;@4:00P0003j0P000@00000000840000;@4;00L0000K1:l2WP6P0Y41100002d10`040000
l04:00@0000]0@4010000?012`0300007P0700005PB^0Y/1X@:D0@@0000]0@L0100002d11`050000
104=00001@0000810@0000T0000b2Z42U0410000=C0600@0000W0Ooo0`0001h01@000042oooo00D0
00090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D000010_ooo`040000;@4300L0
003l0P00oooo0000100002d12P080000nP80004000000002100002d12`0700006`A[0TT1G@8l0@@0
000]0@<010000?012P040000;@4100@0003`0@/00`0001h01`0001H4JP960Eh2?`440000;@4700@0
000]0@L01@0000@13@0000D000020@4000090000<PYN0Sl10@0003T`1P0400009`7oo`<0000N00D0
00010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0
100002d10`070000o0800?ooo`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4
[`9:0J02?@440000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F1:h2A`6Q0T01
100002d11`040000;@4700D000040@d0000500000P4100002@00038:X@900@40000f<0H0100002L1
ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@800000
1@000042oooo00@0000]0@<01`000?`2003oool000040000;@4:00P0003j0P000@00000000840000
;@4;00L0000K11X2DP4<0S/1100002d10`040000l04:00@0000]0@4010000?012`0300007P070000
5P@I0Tl13@8n0@@0000]0@L0100002d11`050000104=00001@0000810@0000X0000b2Pd2?P420000
<C8600H0100002L1ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1
ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool000040000;@4:00P0003j0P00
0@00000000840000;@4;00L0000K11X2mP0=0^00100002d10`040000l04:00@0000]0@4010000?01
2`0300007P0700005P@I0_<03P;S00@0000]0@L0100002d11`050000104=00001@0000810@0000X0
000b2Ph2h`020000<C<600H0100002L1ool300007P0500000@;oool01@0000T2000000L0000F18`1
3@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool000040000
;@4:00P0003j0P000@00000000840000;@4;00L0000K11L2IP890Tl2100002d10`040000l04:00@0
000]0@4010000?012`0300007P0700005P@F0V<22P9B0P@0000]0@L0100002d11`050000104=0000
1@0000810@0000X0000b2PX2DP820000<C4600H0100002L1ool300007P0500000@;oool01@0000T2
000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<0400002H6
3`0F0?ooool00:d0003T0@00LP800>P100080000nP80004000000000100002d12P040000;@4800P0
000U0`80[P3V0G02i@440000;@4100@0003`0@X0100002d10`0800009PH?00H0ooooo`40400002H6
3`0F0?ooool000`2000F0P006@8004X200080000nP80004000000000100002d12P040000;@4800P0
000U0`804P980Q827`840000;@4900@0003`0@X01`000?`20000000000040000;@4:00X0000T0`<0
608R0Q82608=0R82100002d10@040000;@4300@0003`0@X0200002H63`060?ooool10100000V1Pl0
5P3ooooo000:0P00J08001L2002A0P0020000?X200010000000000@0000]0@X0100002d120080000
9@<20102S`8@0W42100002d12@040000l04:00L0003l0P0000000000100002d12P0:000090<301H2
M08@0VX22`9d0P@0000]0@40100002d10`040000l04:00P0000V1Pl01P3ooooo0@0@00009PH?01H0
ooooo`00e0400:`2003Q0@00d`8000P0003j0P000@00000000040000;@4:00@0000]0@P0200002D3
0P3J0M42fP6e0P@0000]0@T010000?012P070000o0800000000000@0000]0@X02P0002@30`3P0KP2
fP6^0]D1^0840000;@4100@0000]0@<010000?012P0800009PH?00H0ooooo`40400002H63`0F0?oo
ool000T2002/0P005P800=<200080000nP80004000000000100002d12P040000;@4800P0000U0`80
3`;A0Pl2]@840000;@4900@0003`0@X01`000?`20000000000040000;@4:00X0000T0`<05@:h0Q02
[P8:0[P2100002d10@040000;@4300@0003`0@X0200002H63`060?ooool10100000V1Pl05P3ooooo
00120P00[08004l2003C0P0020000?X200010000000000@0000]0@X0100002d1200800009@<204P2
d@980[D2100002d12@040000l04:00L0003l0P0000000000100002d12P0:000090<304h2^0980Zh2
@`:h0P@0000]0@40100002d10`040000l04:00P0000V1Pl01P3ooooo0@070000o0800?ooo`0000@0
000]0@X020000?X200010000oooo0P@0000]0@/01`0001/4f`4k0L@16@440000;@4300@0003`0@X0
100002d10@040000l04;00<0000N00L0000F1=X1>0750A`1100002d10P040000;@4400@0000]0@80
100002d110040000;@4200D000040@d0000500000P4100002@00038:a`4L0@40001c00L0100002d1
10090000<P[=0B<10@0007@00`0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4
S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d10`0@00009PH?01H0ooooo`00
2@400;X1000G0@00iP4000P0003j0P000@00000000040000;@4:00L0003l0P00oooo0000100002d1
2`0B000090<700X1a@4=0LD13@7T0A81i04B0LD15@750@l1^`440000;@4100@0003`0@X0100002d1
0`040000l04;00P0000V1Pl01P3ooooo0@0@00009PH?01H0ooooo`00V`400701002]0@00i`4000@0
000]0@T01`000?`2003oool000040000;@4:0180000T0`L0W0780J01b06P0G41Y`5a0JL1b06[0LP1
X`7U0@@0000]0@40100002d10`040000l04:00@0000]0@T01`000?`20000000000040000;@4:00D0
00060@80000L000090<<09`1b06L0LP1W0780I`1c06M0L`1W@7<0Id1b06L0LP1W0790J01b@6P0LP1
X0780A00000T0`H0X0750J01a@6Q0LD1X@710J01`@6P0L41400002@31P2P0Kh1X06n0J41_P6Q0KX1
X06j0J01^P4@000090<60:01]`6P0KL1X@6g0J41/`6P0K<1X06c0A00000T0`H0X06`0J01/06Q0K01
X@6/0J01[06P0J`1400002@31P2P0JT1X06Y0J41Z@6Q0JD1X06U0J01Y@4@000090<60:01XP6P0J81
X@6R0J41WP6P0Ih1X06N0A00000T0`H0X06K0J01V`6Q0I/1X@6G0J01U`6P0IL1400002@31P2P0I@1
X06D0J41U06Q0I01X06@0J01T04@000090<60:01S@6P0Hd1X@6=0J41R@6P0HT1X0690A00000T0`H0
X0660J01QP6Q0HH1X@620J01PP6P0H81400002@31P2P0Gl1X05o0J41O`6Q0G/1X05k0J01N`4@0000
90<60:01N06P0GP1X@5h0J41M06P0G@1X05d0A00000T0`H0X05a0J01L@6P0G81Y05b0J@1L@6T0G41
400002@31P2X0G41Y`5a0JL1L@6W0GD1Y`5e0JP1M@4@000090<60:P1N06W0GL1Y`5h0JL1O06W0G`1
Z05l0A00000T0`H0Z05o0JL1OP6W0Gl1Y`630JL1P`6X0H<1400002@31P2X0HH1Y`650JL1QP6W0HX1
Y`6:0JP1RP4@000090<60:P1S@6W0H`1Y`6=0JL1T@6W0I41Z06A0A00000T0`H0Z06D0JL1T`6W0I@1
Y`6H0JL1V06X0IP1400002@31P2X0I/1Y`6J0JL1V`6W0Il1Y`6O0JP1W`4@000090<60:P1XP6W0J41
Y`6R0JL1YP6W0JH1Z06V0A00000T0`H0Z06Y0JL1Z06W0JT1Y`6]0JL1[@6X0Jd1400002@31P2X0K01
Y`6_0JL1/06W0K@1Y`6d0JP1]04@000090<60:P1]`6W0KH1Y`6g0JL1^`6W0K/1Z06k0A00000T0`H0
Z06n0JL1_@6W0Kh1Y`720JL1`P6X0L816P0002@32`2X0LD1Y`740JL1a@6W0LP1Y`790JP1b@6X0LP1
Z0780JL1b06W0LP1Z0780A00000T0`H0[0780J/1b06[0LP1Z@7<0JX1c06Z0L`1400002@31P2Z0Ll1
Z@7>0JT1c`6X0M<1Z07C0JT1d`4@000090<60:P1e@6W0MD1Y`7E0JH1f@6V0MX1Y`7I0A00000T0`H0
YP7L0JD1g06U0M`1Y07P0J@1h@6U0N017P0002@33@2T0N<1Y07R0J<1h`6S0ND1X`7U0J@1i@6S0N<1
X`7S0J81h`6S0ND1X`7U0J<1i@6T0ND1400002@31P2Q0N01XP7Q0J81h06Q0M`1X@7L0J01g04@0000
90<60:01f@6P0MX1X@7I0J01eP6O0MD1W`7F0A00000T0`H0WP7C0Il1d`6O0M<1WP7?0Ih1cP6M0Ll1
1@0000H10@0000@0000]0@40100002d10`040000l04:00P0000V1Pl01P3ooooo0@0@00009PH?01H0
ooooo`00n`40034000140P00?P0000P0003j0P000@00000000040000;@4:00@0000]0@P0200002D3
0P3l0CL0>P8g00@0000]0@T010000?012P070000o0800000000000@0000]0@X02P0002@30`0h0Sd0
@P8h03P2<P040000;@4100@0000]0@<010000?012P0800009PH?00H0ooooo`40400002H63`0F0?oo
ool003L2002j0@00P08000T200080000nP80004000000000100002d12P040000;@4800h0000U0`D0
IP870Wh21`9n0]P1?@;H0Cd2``440000;@4900@0003`0@X01`000?`20000000000040000;@4:00X0
000T0`<0@`;60Ch2_04h0/H1100002d10@040000;@4300@0003`0@X0200002H63`060?ooool10100
000V1Pl05P3ooooo002U0@008P000<L10012000020000?X200010000000000@0000]0@X01`000?`2
003oool000040000;@4;01H0000T0`T0a@4h0;/1;`2k0C@0/04d0;018`2V0B<0YP4l0;/1?02k0D00
100002d10@040000l04:00@0000]0@<010000?012`0800009PH?00H0ooooo`40400002H63`0F0?oo
ool009@1000R0000[P4005`000080000nP80004000000000100002d12P070000o0800?ooo`0000@0
000]0@/04P0002@31`2E0D`0V`5<09/18`2V0B<0YP5<0:`1C02P0EX0100002d10@040000l04:00@0
000]0@<010000?012`0800009PH?00H0ooooo`40400002H63`0F0?ooool006D2001l0000X`800;81
00080000nP80004000000000100002d12P040000;@4800`0000U0`@0I`9m0:42O@2Q0Z/1KP:[0@@0
000]0@T010000?012P070000o0800000000000@0000]0@X02P0002@30`1a0ZH1IP:/0G42/@440000
;@4100@0000]0@<010000?012P0800009PH?00H0ooooo`401`000?`20030`<0000040000;@4:00P0
003j0P000@00000000840000;@4;00L0000K1;`1>`6K0NL0100002d10`040000l04:00@0000]0@40
10000?012`0300007P0700005PBk0CP1W07Z00@0000]0@D0100002d11@050000104=00001@000081
0@0001T0000b2Z<1kP0<0000@VmTNB1VK7EYI7<P2@0800P01`0400@0100800@0200600@0100002L1
ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@800000
1@000042oooo00@0000]0@<01`000?`2003oool000040000;@4:00P0003j0P000@000?ooo`840000
;@4;00L0000K12<0_0490981100002d10`040000l04:00@0000]0@4010000?012`0300007P070000
5P@R0;P12P2F0A`0003k0_3o00000000_08000000000845bJF5/0000>@<::ZF7kGN^Qnegd6O_McT3
2RX000X0100002d12P0L0000n`;`o`0000000901000000000211LVUQK0000:d32TbUQneg[XO]Mm1W
kgN]0`Y<000:00@0000]0@/070000?/2l?l00000002@0@400000000P@G9YHF`0002J0`ZPYHO]Mjj7
kGO@InmgVP<:X0002P040000;@4<00@0000]0@/0100002d12P040000;@4;00@0000]0@X01@0000@1
3@0000D000020@4000090000<PX;09H10@0006802P040000;@4;00T0000b2P/0X0410000:00500@0
000]0@`02@00038:2P2U0@40001d00@0100002d12`090000<PX;0:`10@0002T01@0400009`7oo`<0
000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P0000050000
0@;oool0100002d10`0800009PH?00H0ooooo`401@0000T2000000D000010_ooo`040000;@4300@0
000W0Ooo0`000000240122@0000H00000A30f`400003000000000000000000006T00@2`0000P0000
0@000080000002M3000@@@20od<003e400000>P3j0<Q000020000680000<00000@00024000080000
HP0000`0000100004@0000`0000800002P000100002W00002@0000T0000@0000o`400?@2000<0000
400000/0000000002`000100003o0@000`<00240000800009@0000`0000700209@0000`000000020
5P0000`000000000600000`0000000006@0000`0003oool0500000`0000=0000DP00070100010000
400000L00000000000000;`2000000001`828U<0N@1c07@0I@1]0000000000000000000000000000
000000000000000000000000000000000000000000000780K`1c06l0IP1d0200C`1V06H0J@1S06D0
801H0000000hKLEg00000=l>8@lI0;01000@0640K00P06<0K`1^0200AP1b06l0KP1d0500H@1W06D0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000I7H02000000U0000
30000040000H000030000000000I000030000?ooo`0D0000300000d0000B000030000080000:0000
40000000000000002@000100003o0@00m0800240000800002P000100002W00002@0000T0000@0000
o`400?@2000D0000300000d0000W00006000008000000000oooo0000000U000030000080000V0000
700000<0000000000@000000000000009@0000`000030000:`0001P000360@009P000?`100170000
9`0001P00004000000000?ooo`0000009@0000`000040000:00000`0000200009P0001`000020000
0000000000000000000002D0000<00000P0002P0000<00000`0002L0000H00000`000000003oool0
000002D0000<00000`0002H0000L00001@0000000001000000000?ooo`0U0000300000D0000[0000
60000=T1000/0000m@400480000U0000300000@0000X0000300000<0000U000030000080000X0000
300000D0000Q0000200001h0000H0000g04002d0003c0@00@P000580001`0@001@000??oool00000
00000000002@0@00000000L000110780J@1Q06`00000000000000000000000000000000000000000
00000000000000000000000000000000000C0:A:bc3O3R4?23dm0Q/4001XcQ<00000090Fm7N8aC`2
CQKdMdP75@1Z5_Agi`h`0I35?0:@aC`2K`1c06l0IP1d0200C`1V06H0J@1S06D0801H0000000hKLEg
00000=l>8@lI0;01000@0640K00P06<0K`1^0200AP0001<00000090Fm7OhT_T6CQKdMoP85@1Z5_Ag
G9?i1/80_`L0ToT60000000000000000000000@0000P00000000000000000000000100005@2/cA<0
00000:3>4`05T?Igb=GeMooooomZ5_Agbf3UM`005@000000gV3UMfAf00P000009@0000`000050000
DP00070100030000moooo`000000000000000901000000001`008440LP1Y0640K000000000000000
000000000000000000000000000000000000000000000000000000000000024?6@2`0@00401Q06`0
801S06l0KP0P04H0000C0000002@5_Agn9;i1ThFm7Oh21D0JQKdMebCn@K20;l709?i1P0000000000
00000000000400008000000000000000000000000@0001D0[<dC0000002PcQ<01I3fM`00mGOooooo
JQKdMl]PiGL001D000000=iPiGMTMP080000002Cn@H0000000000000000000001000020000000000
0000000000000040000E0:c=4`000000X<hC00F@mWO8eOEgooooofXFm7O;H>Eg000E0000003NH>Eg
I7H02000000U0000300000<0000U0000300000D0000U0000300000<0000U0000300000D0000B0000
30000040001D0000F0000401000W0000C`4003H000010000000P@[</8d;L0@00;`000080001<0000
0000000000000000oooooooooom@0000A@1D00T0000700009@0000`000030000E00005@0001@0@00
;@0005@1000h00000@00000084:c;2=2k04003D000010000C00000000000000000000?oooooooooo
D0000340000500008P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
600001X0000A00003@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000
300000@0000W0000600000H000000000oooo0000000U0000300000H0000V0000700000L000000000
0@000000000000009@0000`000070000:`0001P000120P009`0009D2001600009@0000`000040000
:00000`0000600009@0000`000020000:00000`0000700008@0000P0000N0000600004D2000X0000
T`8004H0000U0000300000D0000U0000300000D0000D0000300000d0000B000030000040001D0000
T0000:`1000V0000lP4003D000010000000P@[</8d980P00;P0000/0001<00000000000000000000
oooooooooomT0000A@1^07H0J@1b06l0KP1]06D0KP1d00002@0000L0000500000`0000@000070000
1`0000/0000700001`0000@0000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000
000001h0000H00006P000140000=0`00S0400280000<0000oooooaP0000<0000000001T0000<0000
oooo02D0000<0000100002L0000H00001`0000000030`<00000002D0000<00001`0002H0000L0000
1P0000000001000000000000000U0000300000H0000[0000600001<2002K0@00IP800;/1000U0000
300000@0000X0000300000L0000U000030000080000X0000300000H0000Q0000200001h0000H0000
5P8009`1001T0P00^`400580001`0@001P000??oool0000000000000002l0P00000000L002110780
J@1Q06`0000000000000000000000000000000000000000000000000000000000000000000000000
000C0:A:bc3O3R4?23dm0Q/4001XcQ<00000090Fm7L0DCD2CQKdMdP75@1Z5_Agi`h`1`QA=@88DCD2
0000002Cn@H00000000004D0KP1f06T0LP1_06h0K@1U06h0M000000000000040000E0:c=4`000000
X<hC00F@mWL001<00000090Fm7L`YC`2CQKdMmP75@1Z5_AgYP>o1cRU?08hYC`20000000000000000
000000@0000P00000000000000000000YAl100005@2/cA<0YAo4MjDOa7O4l?eo0>3mO`0000000000
000000000032?LAg0P0006Af00P000009@0000`0000600009@0000`000060000500000`0000=0000
4P0000`000010000E00007`000280@00XP400;T1002a0@000@00000084:c;2=290800:<100080000
C00000000000000000000?ooooooooooG00004L0B@0P05@0LP1Q06<0M00:0000100000@000080000
1@0000P00007000010000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000400009`0001P00007000000000?ooo`0000009@0000`0000700009P0001`000080000
0000004000000000oooo02D0000<0000200002/0000H0000/04009/1003A0@00/@4002D0000<0000
100002P0000<00001`0002D0000<00000P0002P0000<000020000240000800007P0001P0002c0@00
W0400<l1002a0@009@0000`0000500009@0000`0000300009@0000`0000500009@0000`000030000
9@0000`000050000500000`0000=00004P0000`000010000E00005@0000G0@00W@4001d1002/0@00
0@00000084:c;2=2/`4009h100010000C00000000000000000000?ooooooooooD00007<000070000
9@0000`000030000E00005P0000N0@00X`4002D1002^0@000@00000084:c;2=2^P400:@100020000
C00000000000000000000?ooooooooooD0000700M00500000`000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009`0001P00008000000000?ooo`000000
9@0000`0000800009P0001`0000700000000004000000000oooo02D0000<00001`0002/0000H0000
6P4007`1000k0@00TP4002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<0000
1`000240000800007P0001P0000M0@00O@4003T1002B0@009@0000`0000500009@0000`000030000
9@0000`0000500009@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000
E00005@000210000O@4008L0002<0@000@00000084:c;2=27@4007l100010000C000000000000000
00000?ooooooooooD00007<0000700009@0000`000030000E00005@000280000Q04008`0002?0@00
0@00000084:c;2=2904008D100010000C00000000000000000000?ooooooooooD000070000050000
8P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A0000
3@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000300000@0000V0000
700000L0000000000@000000000000009@0000`0000700009`0001P00008000000000?ooo`000000
9@0000`000080000EP0003P0001`0000K`4007/0002H0@001`0000`1S`4?0Hl13`5a0A@1L@4D0Hl1
5`6?0A41V@4U000030000080000X0000300000L0000U0000300000@0000X0000300000P0000V0000
700000P0000000000@000000000000009@0000`0000800009`0001P00007000000000?ooo`000000
9@0000`000070000:`0001P0002X0000F@0008d2001b0@009@0000`000020000:00000`000080000
9@0000`000040000:00000`0000700008@0000P0000N000060000:`0001J0000RP800781001B0000
L04000L0003]oooo0000000000000000T04000000007000P@@1b06T0H@1/00000000000000000000
000000000000000000000000000000000000000000000000000000004`2TB//`g`hQ3`Pm?@8K1000
J<hC0000002@5_AgF;dl0ThFm7M81aD0JQKdMd0=40IP_C`2H;dl0SRU?08hYC`200000000001`07@0
801D0780H@1S07@00000000000000000YAl100005@2/cA<0YAo4MjDOa7O4l?eo000C0000002@5_Ag
h=_i1ThFm7L821D0JQKdM`L000000000j=_i1P000000000000000000000400008000000000000000
YAo4MjDO0@0001D0[<dC0000002PcQ<01I3fMlSEmGOoooooJQKdMl]PiGL001D000000=iPiGMTMP08
000002D0000<00001`0001@0000<00003@000180000<00000@0005@0001D0000f`400;h0003W0@00
d`00004000000212/b`S@WL2003300000@0004`00000000000000000003ooooooooooe00001@0000
3@0005@0001D0000g`400=H0003T0@00j`00004000000212/b`S@W/2003K00000@0004`000000000
00000000003ooooooooooe00001900001P0005@0001D0000f`400>l0003W0@001040004000000212
/b`S@WL2003c00000@0004`00000000000000000003ooooooooooe00001C00003@000280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000400009`0001P000080000
00000?ooo`0000009@0000`0000800009P0001`0000900000000004000000000000002D0000<0000
2@0002/0000H0000_`4004H1001W0P00I`4002D0000<0000100002P0000<0000200002D0000<0000
0P0002P0000<00002@0002L0000H00002@000000003oool0000002D0000<00002@0002H0000L0000
200000000001000000000000000U0000300000P0000[000060000<40002o0000k@0006L1000U0000
300000@0000X0000300000T0000U000030000080000X0000300000P0000V0000700000P000000000
0@000000000000009@0000`0000800009@0000`000050020E`0002@0001I0000E@400201001E0@00
0P000;`1E`7e05L19@0000`000080020:00000`0000800009`0001P0000800000000000000000000
9@0000`000080000EP0002P0001B0000D04005`0001K0@000`000?P0DP7^05P1n01M0BD0000<0000
0P0002D0000<0000100002P0000<0000200002L0000H000020000000003oool0000002D0000<0000
200002H0000L00002@0000000001000000000000000U0000300000T0000[000060000;h100040@00
I`8002D1000U0000300000@0000X0000300000P0000U000030000080000X0000300000T0000W0000
600000T000000000oooo0000000U0000300000T0000V0000700000P0000000000@00000000000000
9@0000`000080000:`0001P000300@00_P0006H2003O00009@0000`000040000:00000`000090000
9@0000`000020000:00000`0000800009P0001`0000800000000004000000000000002D0000<0000
200002D0000<00001@00P5L0000T0000F@4004<1001I0@00IP400080003e0DH1m@5X0BD0000<0000
0P0002P0000<0000200002D0000<0000100002H0000L0000200000000001000000000000000U0000
300000P0000U0000300000D0081G00009000094100140@00T@4006H100020000;@970Bd2J04U0000
30000080000X0000300000P0000U0000300000@0000W0000600000P000000000oooo0000000U0000
300000P0000V0000700000T0000000000@000000000000009@0000`000090000:`0001P0002n0@00
K00006L2002=00009@0000`000040000:00000`0000800009@0000`000020000:00000`000090000
9`0001P00009000000000?ooo`0000009@0000`0000900009P0001`0000800000000004000000000
oooo02D0000<0000200002/0000H0000d04004d1003[0@00H04002D0000<0000100002P0000<0000
2@0002D0000<00000P0002P0000<000020000240000800007P0001P0003C0@00CP400>T1001P0@00
9@0000`0000500009@0000`0000300009@0000`0000500009@0000`0000300009@0000`000050000
500000`0000=00004P0000`000010000E00005P0000g0@00CP400481001M0@000@00000084:c;2=2
d`40050100020000C00000000000000000000?ooooooooooD0000440B@0900000`0002D0000<0000
0`0005@0001D0000@`4005@100170@00G@40004000000212/b`S@]l1001F0@000@0004`000000000
00000000003ooooooooooe00000c00001@000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P00008000000000?ooo`0000009@0000`000080000
9P0001`0000900000000004000000000oooo02D0000<00002@0002/0000H00001P8004d1000P0P00
H04002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<00002@00024000080000
7P0001P000090P00CP4001h2001P0@009@0000`0000500009@0000`0000300009@0000`000050000
9@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000E00005P0001]0@00
CP4007P1001M0@000@00000084:c;2=22@80050100020000C00000000000000000000?oooooooooo
D0000440B@0900000`0002D0000<00000`0005@0001D0000N@4005@1001m0@00G@40004000000212
/b`S@QD2001F0@000@0004`00000000000000000003ooooooooooe00000b00001@000280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000400009`0001P000090000
00000?ooo`0000009@0000`0000900009P0001`0000800000000004000000000oooo02D0000<0000
200002/0000H0000?P8004l1001F0P00HP4002D0000<0000100002P0000<00002@0002D0000<0000
0P0002P0000<000020000240000800007P0001P000110P00D04005@2001R0@009@0000`000050000
9@0000`0000300009@0000`0000500009@0000`0000300009@0000`000050000500000`0000=0000
4P0000`000010000E00005P0002U0@00D0400;01001O0@000@00000084:c;2=2@@80058100020000
C00000000000000000000?ooooooooooD0000440B@0900000`0002D0000<00000`0005@0001D0000
/@4005H1002e0@00G`40004000000212/b`S@Td2001H0@000@0004`00000000000000000003ooooo
oooooe00000a00001@000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000400009`0001P00008000000000?ooo`0000009@0000`0000800009P0001`000090000
0000004000000000oooo02D0000<00002@0002/0000H00001`8000X1000R0P007@4002D0000<0000
100002P0000<0000200002D0000<00000P0002P0000<00002@000240000800007P0001P0000:0P00
2`400202000M0@009@0000`0000500009@0000`0000300009@0000`0000500009@0000`000030000
9@0000`000050000500000`0000=00004P0000`000010000E00005P0001^0@002@4007/1000H0@00
0@00000084:c;2=22P8000d100020000C00000000000000000000?ooooooooooD0000680HP070000
1`0002D0000<00000`0005@0001D0000O04000l100200@006040004000000212/b`S@QP2000C0@00
0@0004`00000000000000000003ooooooooooe00000a00001@000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009`0001P00009000000000?ooo`000000
9@0000`0000900009P0001`0000800000000004000000000oooo02D0000<0000200002/0000H0000
10800<D0000P0P00f00002D0000<0000100002P0000<00002@0002D0000<00000P0002P0000<0000
20000240000800007P0001P000070P00aP0001h2003H00009@0000`0000500009@0000`000030000
9@0000`0000500009@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000
E00005P0001[0@00``0007`1003B00000@00000084:c;2=21`800<P000020000C000000000000000
00000?ooooooooooD0000480@P0900002@0002D0000<00000`0005@0001D0000O@400<T000210@00
dP00004000000212/b`S@QT2003>00000@0004`00000000000000000003ooooooooooe00000a0000
1@000280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J0000
4@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000040000
9`0001P00008000000000?ooo`0000009@0000`0000800009P0001`0000900000000004000000000
oooo02D0000<00002@0002/0000H00001P800700000R0P00QP0002D0000<0000100002P0000<0000
200002D0000<00000P0002P0000<00002@000240000800007P0001P000090P00L@00020200260000
9@0000`0000500009@0000`0000300009@0000`0000500009@0000`0000300009@0000`000050000
500000`0000=00004P0000`000010000E00005P0001]0@00K00007`1001k00000@00000084:c;2=2
2@8007<000020000C00000000000000000000?ooooooooooD00004D0E00900001`0002D0000<0000
0`0005@0001D0000O@40078000210@00O@00004000000212/b`S@QT2001i00000@0004`000000000
00000000003ooooooooooe00000b00001@000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P00009000000000?ooo`0000009@0000`000090000
9P0001`0000800000000004000000000000002D0000<0000200002/0000H0000L@400;l0002N0@00
h00002D0000<0000100002P0000<00002@0002D0000<00000P0002P0000<0000200002L0000H0000
20000000003oool0000002D0000<0000200002H0000L00002@0000000001000000000000000U0000
300000T0000[00006000074100030@00WP4002@1000U0000300000@0000X0000300000P0000U0000
30000080000X0000300000T0000W0000600000T000000000oooo0000000U0000300000T0000V0000
700000P0000000000@000000000000009@0000`000080000:`0001P0000@0@00_`0004X1003P0000
9@0000`000040000:00000`0000900009@0000`000020000:00000`0000800009`0001P000080000
00000?ooo`0000009@0000`0000800009P0001`0000900000000004000000000000002D0000<0000
2@0002/0000H0000404000<1001:0@00904002D0000<0000100002P0000<0000200002D0000<0000
0P0002P0000<00002@0002H0000L00002@0000000001000000000000000U0000300000T0000U0000
300000D0081G000090000>d0003L00007`400?h000020000R@420K/1h@0U0000300000P0080X0000
300000T0000W0000600000T00000000000000000000U0000300000T0001F0000:00001X1003I0000
9P400>@000030000^`7Y0<81gP2f0N009@0000`0000200009@0000`000040000:00000`000090000
9P0001`0000900000000004000000000000002D0000<00002@0002D0000<00001@00P5L0000T0000
k00008X0000O0@00^000008000280Kd0^`6@02D0000<00002000P2P0000<00002@0002L0000H0000
2@00000000000000000002D0000<00002@0005H0000X00006@4008H0000T0@00T@0000<0002m0IL0
`06<0;D1S`0U000030000080000U0000300000@0000X0000300000T0000V0000700000T000000000
0@000000000000009@0000`0000900009@0000`000050020E`0002@0001K0000c0000740003<0000
0P0000d1d@3g0=409@0000`000080020:00000`0000900009`0001P0000900000000000000000000
9@0000`000090000EP0002P0001D0000a`0005h0003B00000`000?X0c03`0=80nP3G02D0000<0000
0P0002D0000<0000100002P0000<00002@0002H0000L00002@0000000001000000000000000U0000
300000T0000U0000300000D0081G0000900005X0000@0@00L000010100020000304D0OH0504U0000
300000P0080X0000300000T0000W0000600000T00000000000000000000U0000300000T0001F0000
:0000580000;0@00G@0001H100030000n@0?0Nh0507i01X19@0000`0000200009@0000`000040000
:00000`0000900009`0001P00009000000000?ooo`0000009@0000`0000900009P0001`000080000
0000004000000000000002D0000<0000200002/0000H0000`P0006X0003_0000R`0002D0000<0000
100002P0000<00002@0002D0000<00000P0002P0000<0000200002L0000H000020000000003oool0
000002D0000<0000200002H0000L00002@0000000001000000000000000U0000300000T0000[0000
60000101001Z0000B04008/0000U0000300000@0000X0000300000P0000U000030000080000X0000
300000T0000W0000600000T000000000oooo0000000U0000300000T0000V0000700000P000000000
0@000000003oool09@0000`000080000:`0001P0000J0@00KP000481002400009@0000`000040000
:00000`0000900009@0000`000020000:00000`0000800008@0000P0000N0000600001d1001_0000
@04008@0000U0000300000D0000U0000300000<0000U0000300000D0000U0000300000<0000U0000
300000D0000D0000300000d0000B000030000040001D0000F0000840001Z0000T00007T000010000
000P@[</8d8M0@00L@000080001<00000000000000000000oooooooooom@0000A@1D00T000070000
9@0000`000030000E0000600002A0000L00009l0001k00000@00000084:c;2=2;@4007L000030000
C00000000000000000000?ooooooooooE00007<0I@1a00001@0000D0000500008P0000`0003ooooo
8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R0000
30000?oooolH000030000000000I000030000?ooo`0U0000300000@0000W0000600000P000000000
oooo0000000U0000300000P0000V0000700000T0000000000@000000003oool09@0000`000090000
:`0001P0000G0@00a00003l1003J00009@0000`000040000:00000`0000800009@0000`000020000
:00000`0000900008@0000P0000N0000600001X100350000?@400=X0000U0000300000D0000U0000
300000<0000U0000300000D0000U0000300000<0000U0000300000D0000D0000300000d0000B0000
30000040001D0000F00007h000320000S`000=4000010000000P@[</8d8J0@00a`000080001<0000
0000000000000000oooooooooom@0000@P1200T0000900009@0000`000030000E0000600002@0000
b00009h0003C00000@00000084:c;2=2;0400<d000030000C00000000000000000000?oooooooooo
E00007<0I@1a00001@0000D0000500008P0000`0003ooooo8@0000P0000I000030000?ooo`0H0000
30000000000N0000600001X0000A00003@<008`1000R000030000?oooolH000030000000000I0000
30000?ooo`0U0000300000@0000W0000600000T000000000oooo0000000U0000300000T0000V0000
700000P0000000000@000000003oool09@0000`000080000:`0001P0000E0@00204003d1000N0@00
9@0000`000040000:00000`0000900009@0000`000020000:00000`0000800008@0000P0000N0000
600001P100090@00>`4001h1000U0000300000D0000U0000300000<0000U0000300000D0000U0000
300000<0000U0000300000D0000D0000300000d0000B000030000040001D0000F00007`000070@00
R@0001H100010000000P@[</8d8H0@002`400080001<00000000000000000000oooooooooom@0000
HP1R00L0000700009@0000`000030000E0000600002:00003@4009P0000H0@000@00000084:c;2=2
9P40014100030000C00000000000000000000?ooooooooooE00007<0I@1a00001@0000D000050000
8P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A0000
3@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000300000@0000W0000
600000P000000000oooo0000000U0000300000P0000V0000700000T0000000000@000000003oool0
9@0000`000090000:`0001P0003300001P400>/0000L0@009@0000`000040000:00000`000080000
9@0000`000020000:00000`0000900008@0000P0000N000060000<H000070@00j@0001`1000U0000
300000D0000U0000300000<0000U0000300000D0000U0000300000<0000U0000300000D0000D0000
300000d0000B000030000040001D0000F00002X000050@00>@0001@100010000000P@[</8d;60000
2@400080001<00000000000000000000oooooooooom@0000C01>00L0000900009@0000`000030000
E00005P0000j00002`4004D0000F0@000@00000084:c;2=2eP0000l100020000C000000000000000
00000?ooooooooooD00005@0B00500001`000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P00009000000000?ooo`0000009@0000`000090000
9P0001`0000800000000004000000000oooo02D0000<0000200002/0000H0000a00006l0003/0000
Q@0002D0000<0000100002P0000<00002@0002D0000<00000P0002P0000<00002000024000080000
7P0001P000370000L0000>X0002500009@0000`0000500009@0000`0000300009@0000`000050000
9@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000E00005P0000[0000
J`0003X0001j00000@00000084:c;2=2a`00078000020000C00000000000000000000?oooooooooo
D00004`0CP0700002@0002D0000<00000`0005@0001H0000>`00074000150000O000004000000212
/b`S@]L0001h00000P0004`00000000000000000003ooooooooooe00001505@01P0000D0000R0000
30000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H00006P000140000=0`00
S0400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000100002H0000L0000
200000000001000000000000000U0000300000P0000U0000300000D0081G0000900005/0001d0000
L@0007@0000200003@5k0?L0N`0U0000300000P0080X0000300000P0000W0000600000P000000000
00000000000U0000300000P0001F0000:00005@0001_0000GP0007X000030000nP1f0?00O03j0840
9@0000`0000200009@0000`000040000:00000`0000800009`0001P00008000000000?ooo`000000
9@0000`0000800009P0001`0000900000000004000000000oooo02D0000<00002@0002/0000H0000
MP400<D0002B0@00f00002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<0000
2@000240000800007P0001P0001i0@00aP000901003H00009@0000`0000500009@0000`000030000
9@0000`0000500009@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000
E00005P0003M0000``000>h0003B00000@00000084:c;2=2N@400<P000020000C000000000000000
00000?ooooooooooD0000480@P0900002@0002D0000<00000`0005@0001D0000k`000<T0003c0000
dP00004000000212/b`S@X/1003>00000@0004`00000000000000000003ooooooooooe00000b0000
1@000280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J0000
4@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000040000
9`0001P00009000000000?ooo`0000009@0000`0000900009P0001`0000800000000004000000000
oooo02D0000<0000200002/0000H0000N@4000P1002D0@006`4002D0000<0000100002P0000<0000
2@0002D0000<00000P0002P0000<000020000240000800007P0001P0001l0@002@400981000K0@00
9@0000`0000500009@0000`0000300009@0000`0000500009@0000`0000300009@0000`000050000
500000`0000=00004P0000`000010000E00005P0003P00001`400>d0000F0@000@00000084:c;2=2
O04000/100020000C00000000000000000000?ooooooooooD0000680HP0700001`0002D0000<0000
0`0005@0001D0000kP0000d1003b00005P40004000000212/b`S@XX1000A0@000@0004`000000000
00000000003ooooooooooe00000b00001@000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P00008000000000?ooo`0000009@0000`000080000
9P0001`0000900000000004000000000000002D0000<00002@0002/0000H0000e`0005T1003]0000
IP4002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<00002@00024000080000
7P0001P0003J0000FP400>/0001V0@00DP00070100090000mOooo`00000000000000090100000000
1`008440LP1Y0640K000000000000000000000000000000000000000000000000000000000000000
00000000000001<0Y4[;<=l>8@l8?Cd26`@006S>4`000000T1KdMmQCn@I>5_AgB0LE06XFm7O[3S0c
h5?i1^1Cn@H00000j=_i1P0000000000<P1R0740000400008000000000000000YAo4MjDO0@0001D0
[<dC0000002PcQ<01I3fM`004`000000T1KdMf0Y>`9>5_Agj0HE06XFm7LD8[l7J2Tk0VPY>`800000
00000000000000001000020000000000YAo4MjDOa7NU7`40000E0:c=4`2U7lAgYAo4MlC`oGl0h?eo
000000000000000000000<8ma7L20000I7H02000000U0000300000T0000U0000300000T0000D0000
300000d0000B000030000040001D0000F00003h0001H0@00B@0006<100010000000P@[</8d;J0000
FP400080001<00000000000000000000oooooooooom@0000<@0`00H0000600008P0000`0003ooooo
8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R0000
30000?oooolH000030000000000I000030000?ooo`0U0000300000@0000W0000600000P000000000
oooo0000000U0000300000P0000V0000700000X0000000000@000000000000009@0000`0000:0000
:`0001P0001M0P00FP4006L2001V0@009@0000`000040000:00000`0000800009@0000`000020000
:00000`0000:00008@0000P0000N000060000602001K0@00I@8006H1000U0000300000T0000U0000
300000T0000U0000300000T0000D0000300000d0000B000030000040001D0000E0000<@1001I0@00
b04006<100010000000P@[</8d9P0P00F`400040001<00000000000000000000oooooooooom@0000
<@0000H0000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H0000
6P000140000=0`00S0400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000
100002L0000H00002P000000003oool0000002D0000<00002P0002H0000L00002000000000010000
00000000000U0000300000P0000[0000600002<2001J0@00;@8006H1000U0000300000@0000X0000
300000X0000U000030000080000X0000300000P0000Q0000200001h0000H00009P8005/1000[0P00
IP4002D0000<00002@0002D0000<00002@0002D0000<00002@0001@0000<00003@000180000<0000
0@0005@0001D0000RP4005T1002>0@00H`40004000000212/b`S@RH2001K0@000@0004`000000000
00000000003ooooooooooe00000b00001P000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P00008000000000?ooo`0000009@0000`000080000
9P0001`0000:00000000004000000000000002D0000<00002P0002/0000H0000jP4005X1003d0@00
IP4002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<00002P00024000080000
7P0001P0003]0@00F`400?81001V0@009@0000`0000900009@0000`0000900009@0000`000090000
500000`0000=00004P0000`000010000E00005@0001A0@00F@4005D1001S0@000@00000084:c;2=2
k@4005/100010000C00000000000000000000?ooooooooooD00003<0000600008P0000`0003ooooo
8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R0000
30000?oooolH000030000000000I000030000?ooo`0U0000300000@0000W0000600000X000000000
oooo0000000U0000300000X0000V0000700000P0000000000@000000000000009@0000`000080000
:`0001P0001L0P00604006H2000T0@009@0000`000040000:00000`0000:00009@0000`000020000
:00000`0000800008@0000P0000N0000600005l2000I0@00I08002@1000U0000300000T0000U0000
300000T0000U0000300000T0000D0000300000d0000B000030000040001D0000E0000<<1000E0@00
a`40020100010000000P@[</8d9O0P006@400040001<00000000000000000000oooooooooom@0000
=00000H0000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H0000
6P000140000=0`00S0400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000
100002L0000H000020000000003oool0000002D0000<0000200002H0000L00002P00000000010000
00000000000U0000300000X0000[0000600005/2003B0000I@800=h0000U0000300000@0000X0000
300000P0000U000030000080000X0000300000X0000Q0000200001h0000H0000GP800=<0001S0P00
gP0002D0000<00002@0002D0000<00002@0002D0000<00002@0001@0000<00003@000180000<0000
0@0005@0001D0000`P400<h000360@00f000004000000212/b`S@Uh2003C00000@0004`000000000
00000000003ooooooooooe00000g00001P000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P0000:000000000?ooo`0000009@0000`0000:0000
9P0001`0000800000000004000000000000002D0000<0000200002/0000H0000T@400=40002N0@00
h00002D0000<0000100002P0000<00002P0002D0000<00000P0002P0000<00002000024000080000
7P0001P0002D0@00dP0009`1003P00009@0000`0000900009@0000`000090000500000`0000=0000
4P0000`000010000E00005@0003h0000c@000?d0003J00000@00000084:c;2=2U0400=8000010000
C00000000000000000000?ooooooooooD00003P0000600008P0000`0003ooooo8@0000P0000I0000
30000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R000030000?oooolH0000
30000000000I000030000?ooo`0U0000300000@0000W0000600000P000000000oooo0000000U0000
300000P0000V0000700000X0000000000@000000000000009@0000`0000:0000:`0001P0002C0@00
5`4009h1000T0@009@0000`000040000:00000`0000800009@0000`000020000:00000`0000:0000
8@0000P0000N0000600009H1000H0@00W04002@1000U0000300000T0000U0000300000T0000D0000
300000d0000B000030000040001D0000E0000?X0000D0@00o`00020100010000000P@[</8d:F0@00
60400040001<00000000000000000000oooooooooom@0000=@0000H0000R000030000?oooolQ0000
200001T0000<0000oooo01P0000<0000000001h0000H00006P000140000=0`00S0400280000<0000
oooooaP0000<0000000001T0000<0000oooo02D0000<0000100002L0000H00002P000000003oool0
000002D0000<00002P0002H0000L0000200000000001000000000000000U0000300000P0000[0000
600003h1003@0000B@400=l0000U0000300000@0000X0000300000X0000U000030000080000X0000
300000P0000Q0000200001h0000H0000@@400=4000170@00g`0002D0000<00002@0002D0000<0000
2@0001@0000<00003@000180000<00000@0005@0001D0000Y@000<`0002Z0000f@00004000000212
/b`S@T41003A00000@0004`00000000000000000003ooooooooooe00000i00001P000280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000400009`0001P000080000
00000?ooo`0000009@0000`0000800009P0001`0000:00000000004000000000000002D0000<0000
2P0002/0000H0000?`4001@1001:0@00904002D0000<0000100002P0000<0000200002D0000<0000
0P0002P0000<00002P000240000800007P0001P000120@005@4004P1000T0@009@0000`000090000
9@0000`000090000500000`0000=00004P0000`000010000E00005@0002V00004@400:/0000N0@00
0@00000084:c;2=2@P4001D100010000C00000000000000000000?ooooooooooD00003H000060000
8P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A0000
3@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000300000@0000W0000
600000X000000000oooo0000000U0000300000X0000V0000700000P0000000000@00000000000000
9@0000`000080000:`0001P0000l0@00PP000581002?00009@0000`000040000:00000`0000:0000
9@0000`000020000:00000`0000800008@0000P0000N0000600003l100230000D04008l0000U0000
300000T0000U0000300000T0000D0000300000d0000B000030000040001D0000F0000:<0001l0000
[P0008P000010000000P@[</8d8o0@00P`000080001<00000000000000000000oooooooooom@0000
<@0b00H0000600008P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
600001X0000A00003@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000
300000@0000W0000600000P000000000oooo0000000U0000300000P0000V0000700000X000000000
0@000000000000009@0000`0000:0000:`0001P0003Q0000P`000?H0002?00009@0000`000040000
:00000`0000800009@0000`000020000:00000`0000:00008@0000P0000N000060000>@000240000
m00008l0000U0000300000T0000U0000300000T0000D0000300000d0000B000030000040001D0000
F00004P0001m0000D`0008P000010000000P@[</8d;T0000Q0000080001<00000000000000000000
oooooooooom@0000<@0c00H0000600008P0000`0003ooooo8@0000P0000I000030000?ooo`0H0000
30000000000N0000600001X0000A00003@<008`1000R000030000?oooolH000030000000000I0000
30000?ooo`0U0000300000@0000W0000600000X000000000oooo0000000U0000300000X0000V0000
700000P0000000000@000000000000009@0000`000080000:`0001P0001@0P00O`0006H2002<0000
9@0000`000040000:00000`0000:00009@0000`000020000:00000`0000800008@0000P0000N0000
600005<200200000I08008`0000U0000300000T0000U0000300000T0000D0000300000d0000B0000
30000040001D0000F0000;L1001i0000`P4008D000010000000P@[</8d9C0P00P0000080001<0000
0000000000000000oooooooooom@0000<@0a00H0000600008P0000`0003ooooo8@0000P0000I0000
30000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R000030000?oooolH0000
30000000000I000030000?ooo`0U0000300000@0000V0000700000P0000000000@00000000000000
9@0000`0000800009@0000`000050020E`0002@0000C0000E0000=D1001E00000P000:l0G01a0U/0
9@0000`000020000:00000`0000800009@0000`0000400009P0001`0000800000000004000000000
000002D0000<0000200002D0000<00001@00P5L0000T0000M`4008l0001g0@00^@000080000C0[h0
4`:E02D0000<00002000P2P0000<0000200002L0000H00002000000000000000000002D0000<0000
200005H0000X0000LP4008P0001m0@00TP0000<0000I0YP050:>00h2V00U000030000080000U0000
300000@0000X0000300000P0000V0000700000P0000000000@000000000000009@0000`000080000
9@0000`000050020E`0002@0001e0@00hP0007D100010@000P0001421@4A0^L09@0000`000080020
:00000`0000800009`0001P00008000000000000000000009@0000`000080000EP0002P0001`0@00
f`0007/1003U00000`0001L2jP0B0^0030;Z02D0000<00000P0002D0000<0000100002P0000<0000
200002H0000L0000200000000001000000000000000U0000300000P0000U0000300000D0081G0000
900003l1000X0@00?`4004@100020000f`570M/1:`4U0000300000P0080X0000300000P0000W0000
600000P00000000000000000000U0000300000P0001F0000:00003X1000Q0@00A@4002/100030000
h@4^0M`1907F0Bh19@0000`0000200009@0000`000040000:00000`0000800009P0001`000080000
0000004000000000000002D0000<0000200002D0000<00001@00P5L0000T0000M04002P1001d0@00
A0400080000@0TL1408[0BD0000<00002000P2P0000<0000200002L0000H00002000000000000000
000002D0000<0000200005H0000X0000K`400241001j0@00:`4000<0000F0Rh1408T0@/2;P4U0000
30000080000U0000300000@0000X0000300000P0000V0000700000P0000000000@00000000000000
9@0000`0000800009@0000`000050020E`0002@0002]0@00:0400:d100140@000P0004T2A`590R/1
9@0000`000080020:00000`0000800009`0001P00008000000000000000000009@0000`000080000
EP0002P0002X0@008@400;<1000[0@000`0004l2;P5:0R@1A08^0BD0000<00000P0002D0000<0000
100002P0000<0000200002H0000L0000200000000001000000000000000U0000300000P0000W0000
600000X000000000oooo0000000U0000300000X0000[000060000:L0003S0@00S0800?`2000U0000
30000080000X0000300000P0000U0000300000@0000X0000300000X0000Q0000200001h0000H0000
Z`000>@100290P00o08002D0000<00001`0001@0000<00003@000180000<00000@0005@0001D0000
fP400502003V0@00I@80004000000212/b`S@WH2001=0P000@0004`00000000000000000003ooooo
oooooe00001@00003@0005@0001D0000f`4006P2003V0@00O@80004000000212/b`S@WL2001U0P00
0@0004`00000000000000000003ooooooooooe00001D0000300005@0001D0000fP400802003V0@00
U@80004000000212/b`S@WH2001m0P000@0004`00000000000000000003ooooooooooe00001C0000
3@000280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J0000
4@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000040000
9`0001P0000:000000000?ooo`0000009@0000`0000:00009P0001`0000800000000004000000000
000002D0000<0000200002/0000H0000_P400=02001V0P00l@8002D0000<0000100002P0000<0000
2P0002D0000<00000P0002P0000<0000200002L0000H000020000000003oool0000002D0000<0000
200002H0000L00002P0000000001000000000000000U0000300000X0000[000060000<0000190P00
k0000?42000U0000300000@0000X0000300000P0000U000030000080000X0000300000X0000V0000
700000X0000000000@000000000000009@0000`0000:00009@0000`000050020E`0002@0001H0000
iP8001l1003V0P000P000;/1h@;d0>429@0000`000080020:00000`0000:00009`0001P0000:0000
00000000000000009@0000`0000:0000EP0002P0001@0000h@8005/0003]0P000`000?L0g0;/0>82
m`3W0RD0000<00000P0002D0000<0000100002P0000<00002P0002L0000H00002P000000003oool0
000002D0000<00002P0002H0000L0000200000000001000000000000000U0000300000P0000[0000
60000;d1002>0P00IP800:l2000U0000300000@0000X0000300000X0000U000030000080000X0000
300000P0000W0000600000P000000000oooo0000000U0000300000P0000V0000700000X000000000
0@000000000000009@0000`0000:0000:`0001P0002o0@00B08006D2001Y0P009@0000`000040000
:00000`0000800009@0000`000020000:00000`0000:00009P0001`0000:00000000004000000000
000002D0000<00002P0002D0000<00001@00P5L0000T0000F0400=D2001H0@00n0800080003d0M02
m07b0RD0000<00000P0002P0000<00002P0002D0000<0000100002H0000L00002P00000000010000
00000000000U0000300000X0000U0000300000D0081G000090000901003F0P00T0400?P200020000
;0;A0R`2lP8U000030000080000X0000300000X0000U0000300000@0000W0000600000X000000000
oooo0000000U0000300000X0000V0000700000P0000000000@000000000000009@0000`000080000
:`0001P0002m0@00mP4006H2000G0P009@0000`000040000:00000`0000:00009@0000`000020000
:00000`0000800009`0001P00008000000000?ooo`0000009@0000`0000800009P0001`0000:0000
0000004000000000oooo02D0000<00002P0002/0000H0000c`400=L2003Z0@00jP8002D0000<0000
100002P0000<0000200002D0000<00000P0002P0000<00002P000240000800007P0001P0003B0@00
f0800>P1003Z0P009@0000`0000500009@0000`0000300009@0000`0000500009@0000`000030000
9@0000`000050000500000`0000=00004P0000`000010000E00005P0000f0@00g`800441003^0P00
0@00000084:c;2=2dP400=X200020000C00000000000000000000?ooooooooooD0000440B@090000
0`0002D0000<00000`0005@0001D0000@P400>D200160@00k`80004000000212/b`S@]h1003P0P00
0@0004`00000000000000000003ooooooooooe00000c00001@000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009`0001P0000:000000000?ooo`000000
9@0000`0000:00009P0001`0000800000000004000000000oooo02D0000<0000200002/0000H0000
1@800=L2000O0P00jP8002D0000<0000100002P0000<00002P0002D0000<00000P0002P0000<0000
20000240000800007P0001P000080P00f08001d2003Z0P009@0000`0000500009@0000`000030000
9@0000`0000500009@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000
E00005P0001/0@00g`8007L1003^0P000@00000084:c;2=220800=X200020000C000000000000000
00000?ooooooooooD0000440B@0900000`0002D0000<00000`0005@0001D0000N0400>D2001l0@00
k`80004000000212/b`S@Q@2003P0P000@0004`00000000000000000003ooooooooooe00000b0000
1@000280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J0000
4@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000040000
9`0001P00008000000000?ooo`0000009@0000`0000800009P0001`0000:00000000004000000000
oooo02D0000<00002P0002/0000H0000?@800=T2001E0P00k08002D0000<0000100002P0000<0000
200002D0000<00000P0002P0000<00002P000240000800007P0001P000100P00fP8005<2003/0P00
9@0000`0000500009@0000`0000300009@0000`0000500009@0000`0000300009@0000`000050000
500000`0000=00004P0000`000010000E00005P0002T0@00h@800:l1003`0P000@00000084:c;2=2
@0800=`200020000C00000000000000000000?ooooooooooD0000440B@0900000`0002D0000<0000
0`0005@0001D0000/0400>L2002d0@00l@80004000000212/b`S@T`2003R0P000@0004`000000000
00000000003ooooooooooe00000a00001@000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P0000:000000000?ooo`0000009@0000`0000:0000
9P0001`0000800000000004000000000oooo02D0000<0000200002/0000H00001P8009@2000Q0P00
Y`8002D0000<0000100002P0000<00002P0002D0000<00000P0002P0000<00002000024000080000
7P0001P000090P00U@8001l2002W0P009@0000`0000500009@0000`0000300009@0000`000050000
9@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000E00005P0001]0@00
V`8007X1002Z0P000@00000084:c;2=22@8009L200020000C00000000000000000000?oooooooooo
D0000680HP0700001`0002D0000<00000`0005@0001D0000N`400:42001o0@00ZP80004000000212
/b`S@QL2002M0P000@0004`00000000000000000003ooooooooooe00000a00001@000280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000400009`0001P000080000
00000?ooo`0000009@0000`0000800009P0001`0000:00000000004000000000oooo02D0000<0000
2P0002/0000H00000`8004l2000O0P00HP8002D0000<0000100002P0000<0000200002D0000<0000
0P0002P0000<00002P000240000800007P0001P000060P00D08001d2001R0P009@0000`000050000
9@0000`0000300009@0000`0000500009@0000`0000300009@0000`000050000500000`0000=0000
4P0000`000010000E00005P0001Z0@00E@8007/1001T0P000@00000084:c;2=21P80058200020000
C00000000000000000000?ooooooooooD0000480@P0900002@0002D0000<00000`0005@0001D0000
O04005/200200@00I080004000000212/b`S@QP2001H0P000@0004`00000000000000000003ooooo
oooooe00000a00001@000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000400009`0001P0000:000000000?ooo`0000009@0000`0000:00009P0001`000080000
0000004000000000oooo02D0000<0000200002/0000H00001@800?X1000Q0P00408002D0000<0000
100002P0000<00002P0002D0000<00000P0002P0000<000020000240000800007P0001P000080P00
n`4001l2000@0P009@0000`0000500009@0000`0000300009@0000`0000500009@0000`000030000
9@0000`000050000500000`0000=00004P0000`000010000E00005P0001/0@00oP4007/1000=0P00
0@00000084:c;2=220800?d100020000C00000000000000000000?ooooooooooD00004D0E0090000
1`0002D0000<00000`0005@0001D0000O04000@200200@003`80004000000212/b`S@QP200030P00
0@0004`00000000000000000003ooooooooooe00000b00001@000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009`0001P00008000000000?ooo`000000
9@0000`0000800009P0001`0000:00000000004000000000000002D0000<00002P0002/0000H0000
L04004T2002M0@00JP8002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<0000
2P0002L0000H00002P000000003oool0000002D0000<00002P0002H0000L00002000000000010000
00000000000U0000300000P0000[000060000701002=0P00W@400:h2000U0000300000@0000X0000
300000X0000U000030000080000X0000300000P0000W0000600000P000000000oooo0000000U0000
300000P0000V0000700000X0000000000@000000000000009@0000`0000:0000:`0001P0000?0@00
B@8004T1001Z0P009@0000`000040000:00000`0000800009@0000`000020000:00000`0000:0000
9`0001P0000:000000000?ooo`0000009@0000`0000:00009P0001`0000800000000004000000000
000002D0000<0000200002/0000H00003`4008d200190@00[P8002D0000<0000100002P0000<0000
2P0002D0000<00000P0002P0000<0000200002H0000L0000200000000001000000000000000U0000
300000P0000U0000300000D0081G000090000>`0001^0P007P40090200020000R06<0[X1J`8U0000
300000P0080X0000300000P0000W0000600000P00000000000000000000U0000300000P0001F0000
:00001T1001[0P00904007H200030000^P5c0/01J0:e0FX29@0000`0000200009@0000`000040000
:00000`0000800009P0001`0000800000000004000000000000002D0000<0000200002D0000<0000
1@00P5L0000T0000j`0001/2000N0@00B@80008000270DL2^P4J0RD0000<00002000P2P0000<0000
200002L0000H00002000000000000000000002D0000<0000200005H0000X0000604001L2000T0@00
8`8000<0002l0B42`04F0[@16@8U000030000080000U0000300000@0000X0000300000P0000V0000
700000P0000000000@000000000000009@0000`0000800009@0000`000050020E`0002@0001J0000
GP800700001N0P000P0000`1F`;f05/29@0000`000080020:00000`0000800009`0001P000080000
00000000000000009@0000`000080000EP0002P0001B0000F@8005d0001T0P000`000?T0EP;^05`2
n@1Q0RD0000<00000P0002D0000<0000100002P0000<0000200002H0000L00002000000000010000
00000000000U0000300000P0000U0000300000D0081G0000900005T0002R0P00K`000:8200020000
2`6N0_D0WP8U0000300000P0080X0000300000P0000W0000600000P00000000000000000000U0000
300000P0001F0000:0000580002M0P00G0000:P200030000n02I0^h0WP;h0:@29@0000`000020000
9@0000`000040000:00000`0000800009`0001P00008000000000?ooo`0000009@0000`000080000
9P0001`0000:00000000004000000000000002D0000<00002P0002/0000H0000`@000?@1003^0000
5@8002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<00002P0002L0000H0000
2P000000003oool0000002D0000<00002P0002H0000L0000200000000001000000000000000U0000
300000P0000[0000600000l1003d0@00A`4001D2000U0000300000@0000X0000300000X0000U0000
30000080000X0000300000P0000W0000600000P000000000oooo0000000U0000300000P0000V0000
700000X0000000000@000000003oool09@0000`0000:0000:`0001P0000I0@00n0400441000>0P00
9@0000`000040000:00000`0000800009@0000`000020000:00000`0000:00008@0000P0000N0000
600001`1003i0@00?`4000h2000U0000300000D0000U0000300000<0000U0000300000D0000U0000
300000<0000U0000300000D0000D0000300000d0000B000030000040001D0000F0000800003l0@00
S`0000/200010000000P@[</8d8L0@00n`400080001<00000000000000000000oooooooooom@0000
A@1D00T0000700009@0000`000030000E0000600002@00000P8009h0000=0P000@00000084:c;2=2
;040004200030000C00000000000000000000?ooooooooooE00007<0I@1a00001@0000D000050000
8P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A0000
3@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000300000@0000W0000
600000X000000000oooo0000000U0000300000X0000V0000700000P0000000000@000000003oool0
9@0000`000080000:`0001P0000F0@00CP8003h1001T0P009@0000`000040000:00000`0000:0000
9@0000`000020000:00000`0000800008@0000P0000N0000600001T1001?0P00?04006@2000U0000
300000D0000U0000300000<0000U0000300000D0000U0000300000<0000U0000300000D0000D0000
300000d0000B000030000040001D0000F00007d0001D0P00SP0006<200010000000P@[</8d8I0@00
D@800080001<00000000000000000000oooooooooom@0000@P1200T0000900009@0000`000030000
E0000600002?0000FP8009d0001U0P000@00000084:c;2=2:`4005L200030000C000000000000000
00000?ooooooooooE00007<0I@1a00001@0000D0000500008P0000`0003ooooo8@0000P0000I0000
30000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R000030000?oooolH0000
30000000000I000030000?ooo`0U0000300000@0000W0000600000P000000000oooo0000000U0000
300000P0000V0000700000X0000000000@000000003oool09@0000`0000:0000:`0001P0000D0@00
TP8003`1002X0P009@0000`000040000:00000`0000800009@0000`000020000:00000`0000:0000
8@0000P0000N0000600001L1002C0P00>P400:P2000U0000300000D0000U0000300000<0000U0000
300000D0000U0000300000<0000U0000300000D0000D0000300000d0000B000030000040001D0000
F00007/0002I0P00R0000:P200010000000P@[</8d8G0@00U@800080001<00000000000000000000
oooooooooom@0000HP1R00L0000700009@0000`000030000E000060000290000W`8009L0002Z0P00
0@00000084:c;2=29@4009/200030000C00000000000000000000?ooooooooooE00007<0I@1a0000
1@0000D0000500008P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
600001X0000A00003@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000
300000@0000W0000600000X000000000oooo0000000U0000300000X0000V0000700000P000000000
0@000000003oool09@0000`000080000:`0001P000320000T0800>X0002V0P009@0000`000040000
:00000`0000:00009@0000`000020000:00000`0000800008@0000P0000N000060000<D0002A0P00
j0000:H2000U0000300000D0000U0000300000<0000U0000300000D0000U0000300000<0000U0000
300000D0000D0000300000d0000B000030000040001D0000F00002T0002G0P00>0000:H200010000
000P@[</8d;50000T`800080001<00000000000000000000oooooooooom@0000C01>00L000090000
9@0000`000030000E00005P0000i0000W@8004@0002X0P000@00000084:c;2=2e@0009T200020000
C00000000000000000000?ooooooooooD00005@0B00500001`000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009`0001P00008000000000?ooo`000000
9@0000`0000800009P0001`0000:00000000004000000000oooo02D0000<00002P0002/0000H0000
``000?T1003[00003`8002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<0000
2P000240000800007P0001P000360000nP400>T0000?0P009@0000`0000500009@0000`000030000
9@0000`0000500009@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000
E00005P0000Z0000o@4003T0000<0P000@00000084:c;2=2aP000?`100020000C000000000000000
00000?ooooooooooD00004`0CP0700002@0002D0000<00000`0005@0001H0000>P0000<200140000
3P80004000000212/b`S@]H000020P000P0004`00000000000000000003ooooooooooe00001505@0
1P0000D0000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H0000
6P000140000=0`00S0400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000
100002H0000L00002P0000000001000000000000000U0000300000X0000U0000300000D0081G0000
900005X000060P00L00000H20002000030450_H01@8U0000300000P0080X0000300000X0000W0000
600000X00000000000000000000U0000300000X0001F0000:000058000010P00G@0000`200030000
n@000^h01P;i00/29@0000`0000200009@0000`000040000:00000`0000:00009`0001P0000:0000
00000?ooo`0000009@0000`0000:00009P0001`0000800000000004000000000oooo02D0000<0000
200002/0000H0000M@400502002A0@00H`8002D0000<0000100002P0000<00002P0002D0000<0000
0P0002P0000<000020000240000800007P0001P0001h0@00D@8008l1001S0P009@0000`000050000
9@0000`0000300009@0000`0000500009@0000`0000300009@0000`000050000500000`0000=0000
4P0000`000010000E00005P0003L0000EP800>d0001U0P000@00000084:c;2=2N04005<200020000
C00000000000000000000?ooooooooooD0000480@P0900002@0002D0000<00000`0005@0001D0000
kP0005`2003b0000I@80004000000212/b`S@XX1001I0P000@0004`00000000000000000003ooooo
oooooe00000b00001@000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000400009`0001P00008000000000?ooo`0000009@0000`0000800009P0001`0000:0000
0000004000000000oooo02D0000<00002P0002/0000H0000N0400982002C0@00Y@8002D0000<0000
100002P0000<0000200002D0000<00000P0002P0000<00002P000240000800007P0001P0001k0@00
T`800941002U0P009@0000`0000500009@0000`0000300009@0000`0000500009@0000`000030000
9@0000`000050000500000`0000=00004P0000`000010000E00005P0003O0000V@800>`0002X0P00
0@00000084:c;2=2N`4009D200020000C00000000000000000000?ooooooooooD0000680HP070000
1`0002D0000<00000`0005@0001D0000k@0009l2003a0000Z080004000000212/b`S@XT1002K0P00
0@0004`00000000000000000003ooooooooooe00000b00001@000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009`0001P0000:000000000?ooo`000000
9@0000`0000:00009P0001`0000800000000004000000000000002D0000<0000200002/0000H0000
eP000><2003/0000l08002D0000<0000100002P0000<00002P0002D0000<00000P0002P0000<0000
20000240000800007P0001P0003I0000i0800>X0003`0P009@0000`0000900009@0000`000090000
500000`0000=00004P0000`000010000E00005P0000m0000jP8004P0003e0P000@00000084:c;2=2
f@000>@200020000C00000000000000000000?ooooooooooD0000340<00600001P000280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000400009`0001P000080000
00000?ooo`0000009@0000`0000800009P0001`0000:00000000004000000000000002D0000<0000
2P0002/0000H0000G0800>@2001V0P00l08002D0000<0000100002P0000<0000200002D0000<0000
0P0002P0000<00002P000240000800007P0001P0001O0P00i@8006@2003`0P009@0000`000090000
9@0000`0000900009@0000`000090000500000`0000=00004P0000`000010000E00005@000330@00
j`800<L1003e0P000@00000084:c;2=2G`800>D200010000C00000000000000000000?oooooooooo
D0000340000600008P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
600001X0000A00003@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000
300000@0000W0000600000X000000000oooo0000000U0000300000X0000V0000700000P000000000
0@000000000000009@0000`000080000:`0001P0000R0P00i08002`2003`0P009@0000`000040000
:00000`0000:00009@0000`000020000:00000`0000800008@0000P0000N0000600002D2003U0P00
:P800?02000U0000300000T0000U0000300000T0000U0000300000T0000D0000300000d0000B0000
30000040001D0000E00008T1003[0P00S@400?D200010000000P@[</8d8U0P00i@800040001<0000
0000000000000000oooooooooom@0000<P0000H0000R000030000?oooolQ0000200001T0000<0000
oooo01P0000<0000000001h0000H00006P000140000=0`00S0400280000<0000oooooaP0000<0000
000001T0000<0000oooo02D0000<0000100002L0000H000020000000003oool0000002D0000<0000
200002H0000L00002P0000000001000000000000000U0000300000X0000[000060000>T1003T0P00
l`400?02000U0000300000@0000X0000300000P0000U000030000080000X0000300000X0000Q0000
200001h0000H0000k0400>D2003a0@00l08002D0000<00002@0002D0000<00002@0002D0000<0000
2@0001@0000<00003@000180000<00000@0005@0001D0000D0400>/2001D0@00m@80004000000212
/b`S@^`1003U0P000@0004`00000000000000000003ooooooooooe00000c00001P000280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000400009`0001P0000:0000
00000?ooo`0000009@0000`0000:00009P0001`0000800000000004000000000000002D0000<0000
200002/0000H0000F`800:82001U0P00[P8002D0000<0000100002P0000<00002P0002D0000<0000
0P0002P0000<000020000240000800007P0001P0001N0P00X`8006<2002^0P009@0000`000090000
9@0000`0000900009@0000`000090000500000`0000=00004P0000`000010000E00005@000320@00
Y`800<H1002a0P000@00000084:c;2=2GP800:<200010000C00000000000000000000?oooooooooo
D00003@0000600008P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
600001X0000A00003@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000
300000@0000W0000600000P000000000oooo0000000U0000300000P0000V0000700000X000000000
0@000000000000009@0000`0000:0000:`0001P0001K0P00G@8006D2001Y0P009@0000`000040000
:00000`0000800009@0000`000020000:00000`0000:00008@0000P0000N0000600005h2001N0P00
H`8006T2000U0000300000T0000U0000300000T0000U0000300000T0000D0000300000d0000B0000
30000040001D0000E0000<81001Q0P00aP4006/200010000000P@[</8d9N0P00GP800040001<0000
0000000000000000oooooooooom@0000=`0000H0000R000030000?oooolQ0000200001T0000<0000
oooo01P0000<0000000001h0000H00006P000140000=0`00S0400280000<0000oooooaP0000<0000
000001T0000<0000oooo02D0000<0000100002L0000H00002P000000003oool0000002D0000<0000
2P0002H0000L0000200000000001000000000000000U0000300000P0000[000060000981001L0P00
W@4006X2000U0000300000@0000X0000300000X0000U000030000080000X0000300000P0000Q0000
200001h0000H0000U@4005d2002K0@00JP8002D0000<00002@0002D0000<00002@0001@0000<0000
3@000180000<00000@0005@0001D0000n@000602003n0000K080004000000212/b`S@YD1001M0P00
0@0004`00000000000000000003ooooooooooe00000h00001P000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009`0001P00008000000000?ooo`000000
9@0000`0000800009P0001`0000:00000000004000000000000002D0000<00002P0002/0000H0000
T@400:02002M0@00[P8002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<0000
2P000240000800007P0001P0002D0@00X@8009/1002^0P009@0000`0000900009@0000`000090000
500000`0000=00004P0000`000010000E00005@0003h0000Y@800?d0002a0P000@00000084:c;2=2
U0400:4200010000C00000000000000000000?ooooooooooD00003D0000600008P0000`0003ooooo
8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R0000
30000?oooolH000030000000000I000030000?ooo`0U0000300000@0000W0000600000X000000000
oooo0000000U0000300000X0000V0000700000P0000000000@000000000000009@0000`000080000
:`0001P0000l0@00G@8004P1001Z0P009@0000`000040000:00000`0000:00009@0000`000020000
:00000`0000800008@0000P0000N0000600003l1001N0P00AP4006X2000U0000300000T0000U0000
300000T0000D0000300000d0000B000030000040001D0000E0000:<0001Q0P00Z00006`200010000
000P@[</8d8o0@00GP800040001<00000000000000000000oooooooooom@0000>@0000H0000R0000
30000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H00006P000140000=0`00
S0400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000100002L0000H0000
20000000003oool0000002D0000<0000200002H0000L00002P0000000001000000000000000U0000
300000X0000[0000600003d1002P0P00B@400:h2000U0000300000@0000X0000300000P0000U0000
30000080000X0000300000X0000Q0000200001h0000H0000@0400:4200170@00[P8002D0000<0000
2@0002D0000<00002@0001@0000<00003@000180000<00000@0005@0001D0000Y0000:D2002Y0000
/@80004000000212/b`S@T01002Q0P000@0004`00000000000000000003ooooooooooe00000f0000
1P000280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J0000
4@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000040000
9`0001P0000:000000000?ooo`0000009@0000`0000:00009P0001`0000800000000004000000000
000002D0000<0000200002/0000H0000>`4000`2001A0@006@8002D0000<0000100002P0000<0000
2P0002D0000<00000P0002P0000<000020000240000800007P0001P0000n0@003@8004l1000I0P00
9@0000`0000900009@0000`000090000500000`0000=00004P0000`000010000E00005P0002R0000
3P800:d0000I0P000@00000084:c;2=2?P4000d200020000C00000000000000000000?oooooooooo
D0000340<P0600001P000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000400009`0001P00008000000000?ooo`0000009@0000`0000800009P0001`0000:0000
0000004000000000000002D0000<00002P0002/0000H0000h00000d2003e00006@8002D0000<0000
100002P0000<0000200002D0000<00000P0002P0000<00002P000240000800007P0001P0003S0000
3P800?<0000I0P009@0000`0000900009@0000`000090000500000`0000=00004P0000`000010000
E00005P0001700003`800580000I0P000@00000084:c;2=2h`0000h200020000C000000000000000
00000?ooooooooooD0000340<`0600001P000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P0000:000000000?ooo`0000009@0000`0000:0000
9P0001`0000800000000004000000000000002D0000<0000200002/0000H0000C`8000T2001U0P00
5P8002D0000<0000100002P0000<00002P0002D0000<00000P0002P0000<00002000024000080000
7P0001P0001B0P002P8006<2000F0P009@0000`0000900009@0000`000090000500000`0000=0000
4P0000`000010000E00005P0002f0@002`800<41000F0P000@00000084:c;2=2DP8000X200020000
C00000000000000000000?ooooooooooD0000340<@0600001P000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009P0001`0000800000000004000000000
000002D0000<0000200002D0000<00001@00P5L0000T00004P000>D1003D0@00iP400080002^0>H1
L0;U0BD0000<00000P0002P0000<0000200002D0000<0000100002H0000L00002000000000010000
00000000000U0000300000P0000U0000300000D0081G0000900007H1000Q0P00MP4004X200020000
4P980Q827`8U0000300000P0080X0000300000P0000W0000600000P00000000000000000000U0000
300000P0001F0000:0000741000I0P00O04002@200030000608R0Q82608=0R829@0000`000020000
9@0000`000040000:00000`0000800009P0001`0000800000000004000000000000002D0000<0000
200002D0000<00001@00P5L0000T0000M04007@2001d0@00T`800080000@0Xl2409a0RD0000<0000
2000P2P0000<0000200002L0000H00002000000000000000000002D0000<0000200005H0000X0000
K`4006d2001j0@00M`8000<0000F0W@2409Z0P/2M08U000030000080000U0000300000@0000X0000
300000P0000V0000700000P0000000000@000000000000009@0000`0000800009@0000`000050020
E`0002@0000n0@00^P8003h1003F0P000P000=X1d@;J0KD29@0000`000080020:00000`000080000
9`0001P00008000000000000000000009@0000`000080000EP0002P0000i0@00/P8004@1002m0P00
0`000>01^0;J0Jh2e@6h0RD0000<00000P0002D0000<0000100002P0000<0000200002H0000L0000
200000000001000000000000000U0000300000P0000U0000300000D0081G0000900007<1002j0P00
L`400=H2000200003`;A0Pl2]@8U0000300000P0080X0000300000P0000W0000600000P000000000
00000000000U0000300000P0001F0000:00006h1002b0P00N@400;d2000300005@:h0Q02[P8:0[P2
9@0000`0000200009@0000`000040000:00000`0000800009P0001`0000800000000004000000000
000002D0000<0000200002D0000<00001@00P5L0000T0000[0400;X2002/0@00eP80008000180]42
B0:e0RD0000<00002000P2P0000<0000200002L0000H00002000000000000000000002D0000<0000
200005H0000X0000Y`400;82002b0@00_@8000<0001>0[P2B0:^0T<2^08U000030000080000U0000
300000@0000X0000300000P0000W0000600000P000000000oooo0000000U0000300000P0000V0000
700000X0000000000@000000003oool09@0000`0000:0000:`0001P0000I0@00a04003X1003J0@00
9@0000`000040000:00000`0000800009@0000`000020000:00000`0000:00008@0000P0000N0000
600001`100350@00>0400=X1000U0000300000D0000U0000300000<0000U0000300000D0000U0000
300000<0000U0000300000D0000D0000300000d0000B000030000040001D0000E000080000370@00
QP000=H100010000000P@[</8d8L0@00a`400040001<00000000000000000000oooooooooom@0000
L`0000L0000U0000300000<0001D0000E00008H0003=0@00R@000=P100010000000P@[</8d8S0@00
c@400040001<00000000000000000000oooooooooom@0000M00000<0000R000030000?oooolQ0000
200001T0000<0000oooo01P0000<0000000001h0000H00006P000140000=0`00S0400280000<0000
oooooaP0000<0000000001T0000<0000oooo02D0000<0000100002H0000L00002P00000000010000
00000000000U0000300000X0000W0000600000P000000000oooo0000000U0000300000P0001F0000
>00006h0002k0@00N@000>@1000700002P750@d1a@4=0N@14P7T0A81a@4E0LD13`6k0BD0000<0000
0P0002P0000<00002P0002D0000<0000100002P0000<0000200002D0000<00002000P2L0000H0000
20000000003oool0000002D0000<0000200005H0000h0000004006l1000?0@00i@4000L0002L0LP1
X0780J01L@6W0G41Y`780J/1b06S0ND19@0000`0000200009@0000`000040000:00000`000080000
9@0000`0000800209`0001P00008000000000000000000009@0000`0000800004`0000`000020000
EP0004`000000@00b04000@1003<0@00300009`1b06L0LP1W0780I`1c06M0L`1W@7<0Id1b06L0LP1
W0790J01b@6P0LP1X0780EH0000d000010400<4100050@00a@4000H0002P0LD1X0750J41a@6Q0L41
X0710J01`@5F0000=00000@1002j0@001@400;h100060000X06n0J01_P6Q0Kh1X@6j0J01^P6P0KX1
EP0003@000040@00/P4000D1002g0@001P000:01]`6P0KL1X@6g0J41/`6P0K<1X06c0EH0000d0000
10400:/100050@00[`4000H0002P0K01X06`0J41/06Q0J`1X06/0J01[05F0000=00000@1002T0@00
1@400:P100060000X06Y0J01Z@6Q0JT1X@6U0J01Y@6P0JD1EP0003@000040@00W@4000D1002Q0@00
1P000:01XP6P0J81X@6R0J41WP6P0Ih1X06N0EH0000d0000104009H100050@00VP4000H0002P0I/1
X06K0J41V`6Q0IL1X06G0J01U`5F0000=00000@1002?0@001@4009<100060000X06D0J01U06Q0I@1
X@6@0J01T06P0I01EP0003@000040@00R04000D1002<0@001P000:01S@6P0Hd1X@6=0J41R@6P0HT1
X0690EH0000d00001040084100050@00Q@4000H0002P0HH1X0660J41QP6Q0H81X0620J01PP5F0000
=00000@1001i0@001@4007d100060000X05o0J01O`6Q0Gl1X@5k0J01N`6P0G/1EP0003@000040@00
LP4000D1001f0@001P000:01N06P0GP1X@5h0J41M06P0G@1X05d0EH0000d0000104006l100080@00
L04000H0002P0G41X05a0J01LP6T0G81Y05a0J@1L@5F0000=00000/1001_0@00304007<100060000
Z05a0JL1L@6W0G41Y`5e0JL1M@6X0GD1EP0003@0000;0@00M@4000`1001j0@001P000:P1N06W0GL1
Y`5h0JL1O06W0G`1Z05l0EH0000d00002`4007`1000<0@00PP4000H0002X0Gl1Y`5n0JL1O`6W0H<1
Y`630JP1P`5F0000=00000/100240@00304008T100060000Z0660JL1Q@6W0HH1Y`6:0JL1RP6X0HX1
EP0003@0000;0@00R`4000`1002@0@001P000:P1S@6W0H`1Y`6=0JL1T@6W0I41Z06A0EH0000d0000
2`400981000<0@00U`4000H0002X0I@1Y`6C0JL1U06W0IP1Y`6H0JP1V05F0000=00000/1002I0@00
304009h100060000Z06K0JL1VP6W0I/1Y`6O0JL1W`6X0Il1EP0003@0000;0@00X04000`1002U0@00
1P000:P1XP6W0J41Y`6R0JL1YP6W0JH1Z06V0EH0000d00002`400:L1000<0@00[04000H0002X0JT1
Y`6X0JL1Z@6W0Jd1Y`6]0JP1[@5F0000=00000/1002^0@0030400;<100060000Z06`0JL1[`6W0K01
Y`6d0JL1]06X0K@1EP0003@0000;0@00]P4000`1002k0@001P000:P1]`6W0KH1Y`6g0JL1^`6W0K/1
Z06k0EH0000d00002`400;d1000<0@00`P4000H0002X0Kh1Y`6m0JL1_P6W0L81Y`720JP1`P5F0000
B00000/100340@0030400<T1000;0000Z0750JL1a06W0LD1Y`780JL1b@6X0LT1Z0780JP1b06W0LP1
Y`780JP1b05F0000=00000d100380@0040400<`100060000[0780J/1b06[0LP1Z@7<0JX1c06Z0L`1
EP0003@0000<0@00cP4000h1003C0@001P000:X1c`6Y0Lh1Z@7?0JP1d`6X0M<1Z@7C0EH0000d0000
2P400=D1000<0@00fP4000H0002X0MD1Y`7E0JL1e@6V0MT1YP7J0JL1f@5F0000=00000P1003L0@00
2P400>4100060000YP7L0JD1g06U0M`1Y07P0J@1h@6U0N01EP00050000060@00hP4000P1003U0@00
3@000:@1h`6T0N81X`7S0J<1i@6S0ND1Y07U0J<1h`6S0N<1XP7S0J<1i@6S0ND1X`7U0J@1i@5F0000
=00000@1003L0@001P400>4100060000X@7P0J81h@6R0N01X@7L0J41g06P0M`1EP0003@000030@00
e@4000D1003J0@001P000:01f@6P0MX1X@7I0J01eP6O0MD1W`7F0EH0000d00000@400<h100030@00
d`4000H0002N0M<1W`7C0Il1d`6N0Ll1WP7>0Id1c`4C000030000040000U000030000080000U0000
300000@0000X0000300000P0000V0000700000P0000000000@000000000000009@0000`000080000
9@0000`000050020E`0002@0001P0@00;`0009h1000_00000P000?`1=`0j0SL09@0000`000080020
:00000`0000800009`0001P00008000000000000000000009@0000`000080000EP0002P0002L0@00
:P000:H1000e00000`0003P2?@120SP0>08b02D0000<00000P0002D0000<0000100002P0000<0000
200002H0000L0000200000000001000000000000000U0000300000P0000U0000300000D0081G0000
<0000:4100330@00hP4000P200050000IP870Wh21`9n0]P1?@;H0Cd2``4U0000300000P0080X0000
300000P0000W0000600000P00000000000000000000U0000300000P0001F0000:00009`1002l0@00
Y`400<H100030000@`;60Ch2_04h0/H19@0000`0000200009@0000`000040000:00000`000080000
9P0001`0000800000000004000000000000002D0000<0000200002L0000H00002P000000003oool0
000002D0000<00002P0005H0001000002P4001/0000Y0@00>00000T000350CP0^`4_0;/1=02`0C@0
/04S0:H18`2V0C`0^`4l0;/1@00U000030000080000X0000300000P0000U0000300000@0000X0000
300000X0000V0000700000X0000000000@000000000000009@0000`0000:00009`0001P000080000
00000?ooo`0000009@0000`000080000EP0003P0003i00006`000101001C00001`0009D1C02K0D`0
V`4S0:H18`2V0D`0[05<0:01FP0U000030000080000X0000300000X0000U0000300000@0000X0000
300000P0000V0000700000P0000000000@000000000000009@0000`0000800009@0000`000050020
E`0002`0003;0@00MP0000D2002Z0@00100006L2O@2Q0Wd0X@:[0Fh2Z`4U0000300000P0080X0000
300000P0000W0000600000P00000000000000000000U0000300000P0001F0000:0000<X1002U0@00
e@400;0100030000L@:V0FH2[05a0[419@0000`0000200009@0000`000040000:00000`000080000
9`0001P00008000000000<30`00000009@0000`0000800009P0001`0000:00000000004000000000
000002D0000<00002P0002/0000H0000i`0009/1000j0@00^`4002D0000<0000100002P0000<0000
200002D0000<00000P0002P0000<00002P000240000800007P0001P0003Z0000W04003P1002k0@00
9@0000`0000600009@0000`000060000500000`0000=00004P0000`000010000E00009@0001B0000
XP4009/0002a0@000@00000084:c;2=2kP000:<1000<0000C00000000000000000000?oooooooooo
I0000480K`1T07T0801V06`0M@1Y06@0L`0P00T000080000200000L000040000100000@000080000
100000P00006000010000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000400009`0001P0000:000000000?ooo`0000009@0000`0000:00009P0001`000080000
0000004000000000oooo02D0000<0000200002/0000H0000TP4000T0002k0@008P0002D0000<0000
100002P0000<00002P0002D0000<00000P0002P0000<000020000240000800007P0001P0002F0@00
2P000;P1000R0000DP00070100080000l?ooo`000000000000000;`2000000001`008440LP1Y0640
K00000000000000000000000000000000000000000000000000000000000000000000000000001<0
Y4[;<=l>8@l8?Cd26`@006S>4`000000T1KdMaS?>`9>5_AgB0LE06XFm7O/3S0Q8<lk0R3?>`9X:C/2
J2Tk0P0000000000@P1_06@0N@0P06H0K01e06T0I01c0200YAo4MjDO0@0001D0[<dC0:DOa7NU7lAg
a?3mO`004`000000T1KdMc2U?09>5_Agf0LE06XFm7MjJKl7>:Dl0SRU?081800000000000002h??X6
1000020000000000YAo4MjDOa7NU7`40000E0:c=4`2U7lAgYAo4MlC`oGl0h?eo0000000000000000
00000<8ma7L20000I7H02000000U0000300000P0001B0000L04000X0003`oooo0000000000000000
T04000000007000P@@1b06T0H@1/0000000000000000000000000000000000000000000000000000
000000000000000000000000a7NU7`40000E0:c=4`2U7lAgYAo4MlC`oGl001<00000090Fm7L`YC`2
CQKdMmP75@1Z5_AgNVVo1cRU?08hYC`20B00000000000000^3cj1P@0000P000000000:DOa7NU7lAg
YAl100005@2/cA<0YAo4MjDOa7O4l?eo003mO`0000000000000000000032?LAg0P0006Af00P00000
>:Dl0P4P0000000000000;PlnPH4000080000000002U7lAgYAo4MjDO0@0001D0[<dC0:DOa7NU7lAg
a?3mO`3PoGl000000000000000000000`Sg4M`80001TMP08000002D0000<00002P000580001`0@00
2`000?3oool0000000000000002@0@000@0000L002110780J@1Q06`0000000000000000000000000
0000000000000000000000000000000000000000000000000034MjDO0@0001D0[<dC0:DOa7NU7lAg
a?3mO`00oGl000000000000000000000`Sg4M`80001TMP08000003RU?081800000000000002h??X6
1000020000000000YAo4MjDOa7NU7`40000E0:c=4`2U7lAgYAo4MlC`oGl00?eo0000000000000000
00000<8ma7L20000I7H02000000hYC`20B00000000000000^3cj1P@0000P000000000:DOa7NU7lAg
YAl100005@2/cA<0YAo4MjDOa7O4l?eo0>3mO`0000000000000000000032?LAg0P0006Af00P00000
9@0000`0000;00009@0000`0000:00009@0000`0000800009@0000`0000:00009@0000`000080000
500000`0000=00004P0000`000010000E00005@0003j00000P0000<1000D00000@00000084:c;2=2
UP4000/000010000C00000000000000000000?ooooooooooD0000680000:00009@0000`0000:0000
E00005@000040@000P0000P1000C00000@00000084:c;2=2X04000/000010000C000000000000000
00000?ooooooooooD00002P0000500009@0000`0000;0000E00005@000090@000@0000`1000C0000
0@00000084:c;2=2Y@4000X000010000C00000000000000000000?ooooooooooD00007@000040000
9@0000`0000:0000E00005@0000@0@000P0001@1000C00000@00000084:c;2=2[04000/000010000
C00000000000000000000?ooooooooooD00002T0000500008P0000`0003ooooo8@0000P0000I0000
30000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R000030000?oooolH0000
30000000000I000030000?ooo`0U0000300000@0000H000030000000000I000030000?ooo`0U0000
300000@0000R000030000?oooolU0000300000L0080U000030000000080`0000300000l0080U0000
300000d0081;00004000000000050000:00000`000020000:00000`000050000:00000`000040000
:00000`000030000:00000`000060000:00000`000070000:00000`000090000:00000`000080000
:00000`0000:0000:00000`0000;00009@0000`0000000209@0000`0000700208P0000`0003ooooo
9@0000`0000=0020:00000`0000100008P0000`0003ooooo8P0000`0003oooooAP0003P0000/0000
ADe6:bI0000@000010000000000Q@0L0300000000004@0003000000000160000500000P00017A4U3
0`0001P0000<0000000001T0000<0000oooo02D0000<00000000P2D0000<00003@00P280000<0000
ooooodH0000d0000:00004E=AR/Z@000900001P00000080o0000P0000800080o0000P000080Q0000
20000680000<00000@0004`0001T00002`00000000090P000P<000/000000000o`4000<3000Y0:X0
000000000000080o000000000000080o0000000000000000000000000000000000000000000R0000
30000?oooom60000700001000015CDH[0T0000`0000000003P0001@000000000400001@0
\>"], "Text",
  ImageSize->{384.875, 581.188},
  ImageMargins->{{0, 0}, {0, 63}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Figure 1:",
    FontWeight->"Bold"],
  " Respiratory tract model (ICRP66). "
}], "Text"],

Cell[TextData[{
  "The retention in each compartment as function of time is obtained with \
functions ",
  StyleBox["RespiratoryTract",
    FontWeight->"Bold"],
  ". These functions compute the retention  in  Respiratory Tract \
compartments, Lungs and ST (Stomach)  an  B (transferred to blood directly \
from Respiratory Tract) after a single intake. ST and B are considered as \
trap compartments\n"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Function for solving the ICRP 66 model ", "SubsubsectionIcon"],

Cell[TextData[{
  "Here are included the specific functions used for evaluated the \
respiratory tract contents ",
  StyleBox["for persons exposed to inhalation ",
    CharacterEncoding->"WindowsANSI"],
  "of aerosols as function ",
  StyleBox["of the activity median aerodynamic diameter (AMAD).",
    CharacterEncoding->"WindowsANSI"]
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      RowBox[{
        StyleBox["RespiratoryTract",
          "Input"], 
        StyleBox["[",
          "Input"], 
        StyleBox[\(Intake, \ IFD\ , \ FRA, \ t, \ \[Lambda], \ options\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["]",
          "Input"]}]]],
  " for one specific nuclide, gives the retention in compartments  of the \
respiratory tract (see fig.1) for  an intake",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(I\)\)\)]],
  " by inhalation. By default an acute intake is assumed. Other type of \
intake can be chosen with Options. For each type of intake mush be used a \
format for intake data input."
}], "DefinitionBox",
  CellTags->"Introduction"],

Cell[TextData[{
  Cell[BoxData[
      RowBox[{
        StyleBox["LungsRetention",
          "Input"], 
        StyleBox["[",
          "Input"], 
        StyleBox[\(Intake, \ IFD\ , \ FRA, \ t, \ \[Lambda], \ options\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["]",
          "Input"]}]]],
  " for one specific nuclide, gives the retention in Lungs for  an intake",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(I\)\)\)]],
  " by inhalation. By default an acute intake is assumed. Other type of \
intake can be chosen with Options. For each type of intake mush be used a \
format for intake data input."
}], "DefinitionBox",
  CellTags->"Introduction"],

Cell[TextData[{
  Cell[BoxData[
      RowBox[{
        StyleBox["qBfromRT",
          "Input"], 
        StyleBox["[",
          "Input"], 
        StyleBox[\(I\_0, \ IFD\ , \ FRA, \ t, \ \[Lambda], \ options\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["]",
          "Input"]}]]],
  " for one specific nuclide, gives the retention in compartments B (blood)   \
from the flow of the respiratory tract as function of time ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(t\)\)\)]],
  ", in days,  after an acute intake ",
  Cell[BoxData[
      \(\(\(I\_0\)\(\ \)\)\)]],
  "in ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  "=0, B -blood-  is assumed as the final -trap- compartments of the system, \
see fig.1)"
}], "DefinitionBox",
  CellTags->"Introduction"],

Cell[TextData[{
  Cell[BoxData[
      RowBox[{
        StyleBox["qSTfromRT",
          "Input"], 
        StyleBox["[",
          "Input"], 
        StyleBox[\(I\_0, \ IFD\ , \ FRA, \ t, \ \[Lambda], \ options\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["]",
          "Input"]}]]],
  "for one specific nuclide, gives the retention in compartments ST (stomach) \
 from the flow of the respiratory tract as function of time ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(t\)\)\)]],
  ", in days,  after an acute intake ",
  Cell[BoxData[
      \(\(\(I\_0\)\(\ \)\)\)]],
  "in ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  "=0,  ST-stomach- is assumed as the final -trap- compartments of the \
system, see fig.1)  "
}], "DefinitionBox",
  CellTags->"Introduction"],

Cell[TextData[{
  StyleBox["Intake",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  ": \n",
  Cell[BoxData[
      \(TraditionalForm\`I\_0\)]],
  " for an Acute input (Bq);",
  StyleBox[" ",
    FontSlant->"Italic"],
  "The intake type can be chosen with Options: ",
  StyleBox["IntakeType",
    FontFamily->"Courier New"],
  "\[Rule] \"Acute\", it is assumed by default. ",
  StyleBox["\n",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`I\_d\)]],
  " for a Constant input (Bq/day); chosing",
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox["IntakeType",
    FontFamily->"Courier New"],
  "\[Rule]\"Constant\" with options. \"Constant\" means a daily chronic \
intake ",
  Cell[BoxData[
      \(I\_d\)]],
  " ;  ",
  StyleBox["\n",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`{I(t), \ t}\)]],
  " for a continuous input; chosing",
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox["IntakeType ",
    FontFamily->"Courier New"],
  "\[Rule] \"Continuous\" with options. \"Continuous\" mean a daily \
continuous intake  ",
  Cell[BoxData[
      \(TraditionalForm\`I(t)\)]],
  ";  \n",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox["{",
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False,
              "StrikeThrough"->False,
              "Masked"->False,
              "CompatibilityType"->0,
              "RotationAngle"->0}], 
            RowBox[{
              StyleBox[\(I\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], ",", " ", "0"}], "}"}], ",", " ", 
          RowBox[{"{", 
            StyleBox[\(I\_1, \[Tau]\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False,
              "StrikeThrough"->False,
              "Masked"->False,
              "CompatibilityType"->0,
              "RotationAngle"->0}], 
            StyleBox["}",
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False,
              "StrikeThrough"->False,
              "Masked"->False,
              "CompatibilityType"->0,
              "RotationAngle"->0}]}], 
          StyleBox[",",
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False,
            "StrikeThrough"->False,
            "Masked"->False,
            "CompatibilityType"->0,
            "RotationAngle"->0}], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False,
            "StrikeThrough"->False,
            "Masked"->False,
            "CompatibilityType"->0,
            "RotationAngle"->0}], 
          StyleBox["...",
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False,
            "StrikeThrough"->False,
            "Masked"->False,
            "CompatibilityType"->0,
            "RotationAngle"->0}], 
          StyleBox[",",
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False,
            "StrikeThrough"->False,
            "Masked"->False,
            "CompatibilityType"->0,
            "RotationAngle"->0}], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False,
            "StrikeThrough"->False,
            "Masked"->False,
            "CompatibilityType"->0,
            "RotationAngle"->0}], 
          RowBox[{
            StyleBox["{",
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False,
              "StrikeThrough"->False,
              "Masked"->False,
              "CompatibilityType"->0,
              "RotationAngle"->0}], 
            RowBox[{
              StyleBox[\(I\_n\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], ",", " ", 
              StyleBox[\(\[Tau]\_n\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}]}], 
            StyleBox["}",
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False,
              "StrikeThrough"->False,
              "Masked"->False,
              "CompatibilityType"->0,
              "RotationAngle"->0}]}]}], 
        StyleBox["}",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}]}]]],
  "for multi acute inputs (This option only works with LungsRetention chosing \
",
  StyleBox["IntakeType",
    FontFamily->"Courier New"],
  "\[Rule]\"MultiInputs\") ; \"MultiInputs\" means multiple single intakes \
{",
  Cell[BoxData[
      \(I\_0\)]],
  ", ..., ",
  Cell[BoxData[
      \(I\_n\)]],
  "} at time 0<",
  Cell[BoxData[
      \(\[Tau]\_1\)]],
  "< ...<",
  Cell[BoxData[
      \(\[Tau]\_n\)]],
  ", in this case  the function give he retention in Lungs  after the last \
intake ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{
          StyleBox[\(I\_n\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False,
            "StrikeThrough"->False,
            "Masked"->False,
            "CompatibilityType"->0,
            "RotationAngle"->0}], ",", " ", 
          StyleBox[\(\[Tau]\_n\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False,
            "StrikeThrough"->False,
            "Masked"->False,
            "CompatibilityType"->0,
            "RotationAngle"->0}]}], 
        StyleBox["}",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}]}]]],
  ". "
}], "Text",
  CellDingbat->None],

Cell[TextData[{
  StyleBox["IFD: Initial fractional  deposition values ",
    FontSlant->"Italic"],
  StyleBox["as function of AMAD",
    FontVariations->{"CompatibilityType"->0}],
  ". It can be directly written the values with this pattern ",
  Cell[BoxData[
      \({AI\)]],
  ", ",
  Cell[BoxData[
      \(bb\_\(fast + seq\)\)]],
  ", ",
  Cell[BoxData[
      \(\(\(bb\_slow\)\(,\)\)\)]],
  " ",
  Cell[BoxData[
      \(BB\_\(fast + seq\)\)]],
  " ",
  Cell[BoxData[
      \(\(\(,\)\(\ \)\(BB\_slow\)\(,\)\(\ \)\)\)]],
  " ",
  Cell[BoxData[
      \(\(\(ET\_2, \ ET\_1\)\(}\)\)\)]],
  " (i.e: {0.12, 0.011, 0.011, 0.0039, 0.004, 0.11, 0.089} or writing ",
  StyleBox["AMADAdultW[x]", "Input",
    FontWeight->"Bold"],
  " where X means AMAD size in \[Mu]m (i.e:  ",
  StyleBox["AMADAdultW[5])", "Input",
    FontWeight->"Bold"],
  " "
}], "Text",
  CellDingbat->None],

Cell[TextData[{
  StyleBox["IFD",
    FontSlant->"Italic"],
  " for normal adult (female and male), Child (10 y old) or Infant (1 y old) \
can be obtained applied  ",
  StyleBox["AMADAdultP[x], ", "Input",
    FontWeight->"Bold"],
  "  ",
  StyleBox["AMADyr10[x], AMADyr1[x].", "Input",
    FontWeight->"Bold"],
  "  "
}], "Commentary"],

Cell[TextData[{
  StyleBox["FRA: Fractional rate of absorption",
    FontSlant->"Italic"],
  " {",
  Cell[BoxData[
      StyleBox[\(s\_p, s\_pt, s\_t\),
        "Input"]]],
  "} of material into the blood, they can be written directly (i.e.: {10, 90, \
0.005}) or writing ",
  StyleBox[" F ",
    FontWeight->"Bold"],
  StyleBox["or",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" M ",
    FontWeight->"Bold"],
  StyleBox["or",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" S, ",
    FontWeight->"Bold"],
  StyleBox["in these case are applied default values. ",
    FontVariations->{"CompatibilityType"->0}],
  "The default",
  Cell[BoxData[
      RowBox[{" ", 
        StyleBox[\(s\_p, s\_pt, s\_t\),
          "Input"]}]]],
  "  values  are (ICRP 66): type F:{100, 0, 0};  type M: {10, 90, 0.005};  \
type S: {0.1, 100, 0.0001}; "
}], "Text",
  CellDingbat->None],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " always in days. "
}], "Text",
  CellDingbat->None],

Cell[TextData[{
  "\[Lambda]: Radioactive Decay constant in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(day\)\(\ \)\)\^\(-1\)\)]]
}], "Text",
  CellDingbat->None],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      RowBox[{
        StyleBox["qLungs",
          "Input"], 
        StyleBox["[",
          "Input"], 
        StyleBox[\(I\_0, \ IFD\ , \ FRA, \ t, \ \[Lambda], \ options\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["]",
          "Input"]}]]],
  " is equivalent to ",
  Cell[BoxData[
      RowBox[{
        StyleBox["LungsRetention",
          "Input"], 
        StyleBox["[",
          "Input"], 
        StyleBox[\(I\_0, \ IFD\ , \ FRA, \ t, \ \[Lambda], \ options\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["]",
          "Input"]}]]],
  ". It will be an obsolete function in futures version of this package. "
}], "Commentary"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?"\<Biokmod`Resptract`*\>"\)\)], "Input",
  CellLabel->"In[8]:=",
  CellTags->"Introduction"],

Cell[BoxData[GridBox[{
        {
          StyleBox["Biokmod`Resptract`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["AMADAdultP",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717806-3426306", 
                    "Biokmod`Resptract`AMADAdultP"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Resptract`"], 
                ButtonBox[
                  StyleBox["AMADfit",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717806-3426306", 
                    "Biokmod`Resptract`AMADfit"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Resptract`"], 
                ButtonBox[
                  StyleBox["AMADyr10",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717806-3426306", 
                    "Biokmod`Resptract`AMADyr10"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Resptract`"], 
                ButtonBox[
                  StyleBox["qLungs",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717806-3426306", 
                    "Biokmod`Resptract`qLungs"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Resptract`"], 
                ButtonBox[
                  StyleBox["qRT2",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717806-3426306", 
                    "Biokmod`Resptract`qRT2"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Resptract`"]},
              {
                ButtonBox[
                  StyleBox["AMADAdultW",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717806-3426306", 
                    "Biokmod`Resptract`AMADAdultW"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Resptract`"], 
                ButtonBox[
                  StyleBox["AMADyr1",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717806-3426306", 
                    "Biokmod`Resptract`AMADyr1"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Resptract`"], 
                ButtonBox[
                  StyleBox["LungsRetention",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717806-3426306", 
                    "Biokmod`Resptract`LungsRetention"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Resptract`"], 
                ButtonBox[
                  StyleBox["qRespTract",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717806-3426306", 
                    "Biokmod`Resptract`qRespTract"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Resptract`"], 
                ButtonBox[
                  StyleBox["RespiratoryTract",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717806-3426306", 
                    "Biokmod`Resptract`RespiratoryTract"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Resptract`"]}
              },
            RowMinHeight->{1, 1.05}]}
        },
      RowSpacings->{2, 3},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->RGBColor[0.964706, 0.929412, 0.839216],
  ButtonBoxOptions->{Active->True},
  GridBoxOptions->{ColumnAlignments->{Left}},
  CellTags->"Introduction"]
}, Open  ]],

Cell["For fitting purposed sometime is useful applied AMADfit[x]", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?AMADfit\)\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \("AMADfit[x] gives an ajusted function of the fractional  deposition \
values for AMAD x , where x can be a parameter. This function  is applicable \
when 0.5<=x<=20. It has been obtained fitting the values given  in  Annex F \
-workers- of ICRP 66."\)], "Print",
  CellTags->"Info3333717806-1192881"]
}, Open  ]],

Cell["\<\
To check what are the fractional deposition values for AMAD 0.5 write  \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AMADAdultW[0.5]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \({0.12`, 0.011`, 0.011`, 0.004`, 0.0039`, 0.11`, 0.089`}\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell["To check what are the FRA applied write S, M or F", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(S\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \({0.1`, 100, 0.0001`}\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell[TextData[{
  "Partition of deposit in each region between compartments and rate \
transfers (in ",
  Cell[BoxData[
      \(TraditionalForm\`days\^\(-1\)\)]],
  ") applied by default are obtained from Table 29 ICRP 66. It can changes \
with Options. "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", 
      StyleBox["LungsRetention",
        "Input"], "]"}]], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \({IntakeType \[Rule] "Acute", fAI1 \[Rule] 0.3`, fAI2 \[Rule] 0.6`, 
      fAI3 \[Rule] 0.1`, fbs \[Rule] 0.007`, fBs \[Rule] 0.007`, 
      k\_"AI1,bb1" \[Rule] 0.02`, k\_"AI2,bb1" \[Rule] 0.001`, 
      k\_"AI3,bb1" \[Rule] 0.0001`, k\_"AI3,TH" \[Rule] 0.00002`, 
      k\_"bb1,BB1" \[Rule] 2, k\_"bb2,BB1" \[Rule] 0.03`, 
      k\_"bbseq,TH" \[Rule] 0.01`, k\_"BB1,ET2" \[Rule] 10, 
      k\_"BB2,ET2" \[Rule] 0.03`, k\_"BBseq,TH" \[Rule] 0.01`, 
      k\_"ETseq,ET" \[Rule] 0.001`}\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell["\<\
To obtain information about options white the name of the option\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?\ fAI1\)\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \("Fraction of deposition factor fAI1 = AI1/AI"\)], "Print",
  CellTags->"Info3333717806-3361058"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?k\)\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \("Represent the rate transfer coefficient"\)], "Print",
  CellTags->"Info3333717806-8086490"]
}, Open  ]],

Cell[TextData[{
  "Transfer coefficients can be modifies with options (note: ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(k\_"\<A,B\>"\),
          "Input"], " "}]]],
  "must be write using \")"
}], "Text"],

Cell[TextData[{
  "Recommended fractional  deposition values (",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  ") for other reference subjects and AMADs can be obtained from Annex F of \
ICRP 66.   Annex F gives ",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  " for AI",
  Cell[BoxData[
      \(TraditionalForm\`\(\(,\)\(\ \)\(bb\_\((fast + 
              seq)\)\)\(,\)\(\ \)\(bb\)\(,\)\(\ \)\(BB\_\((fast + 
              seq)\)\)\(,\)\(\ \ \)\(BB\)\)\)]],
  " and we need ",
  Cell[BoxData[
      \({AI\)]],
  ", ",
  Cell[BoxData[
      \(bb\_\(fast + seq\)\)]],
  ", ",
  Cell[BoxData[
      \(\(\(bb\_slow\)\(,\)\)\)]],
  " ",
  Cell[BoxData[
      \(BB\_\(fast + seq\)\)]],
  " ",
  Cell[BoxData[
      \(\(\(,\)\(\ \)\(BB\_slow\)\(,\)\(\ \)\)\)]],
  " ",
  Cell[BoxData[
      \(\(\(ET\_2, \ ET\_1\)\(}\)\)\)]],
  "\nIt can be done using these relationship:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`F\_bb1\)]],
  " = (1-",
  Cell[BoxData[
      \(TraditionalForm\`f\_bs\)]],
  ")*",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(bb1(fast) + bbseq\)\)]],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`f\_bs\)]],
  Cell[BoxData[
      \(TraditionalForm\`F\_\(bb2(slow)\)\)]],
  "; ",
  Cell[BoxData[
      \(TraditionalForm\`F\_bb2\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(bb2(slow)\)\)]],
  "; ",
  Cell[BoxData[
      \(TraditionalForm\`F\_bbseq\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`f\_bs\)]],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(bb1(fast) + bbseq\)\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(bb2(slow)\)\)]],
  ")\n",
  Cell[BoxData[
      \(TraditionalForm\`F\_BB1\)]],
  " = (1-",
  Cell[BoxData[
      \(TraditionalForm\`f\_Bs\)]],
  ")*",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(BB1(fast) + BBseq\)\)]],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`f\_Bs\)]],
  Cell[BoxData[
      \(TraditionalForm\`F\_\(BB2(slow)\)\)]],
  "; ",
  Cell[BoxData[
      \(TraditionalForm\`F\_BB2\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(BB2(slow)\)\)]],
  "; ",
  Cell[BoxData[
      \(TraditionalForm\`F\_BBseq\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`f\_Bs\)]],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(BB1(fast) + bbseq\)\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(BB2(slow)\)\)]],
  ")"
}], "Commentary"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f\_bs\)]],
  "bs and ",
  Cell[BoxData[
      \(TraditionalForm\`f\_Bs\)]],
  " default values can be modified with options  "
}], "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples ", "SubsectionIcon",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell["Example 1", "SubsubsectionIcon",
  CellTags->"Examples"],

Cell["\<\
Here is evaluated the retention in the Respiratory tract compartments \
supposing  a single intake 1 Bq   of aerosols type S and AMAD = 5 \[Mu]m  in \
t = 0 with lambda \[Rule] 0 \
\>", "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(RTAMAD5S[t_]\), "=", 
      RowBox[{
        StyleBox["RespiratoryTract",
          "Input"], "[", \(1, AMADAdultW[5], S, \ t, 0\), "]"}]}]], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \({q\_ET1[t] \[Rule] 0.3386996`\ \[ExponentialE]\^\(-t\), 
      q\_AI[t] \[Rule] 
        0.00001592483439044265`\ \[ExponentialE]\^\(\(-100.11999999999999`\)\ \
t\) + 0.0000318496687808853`\ \[ExponentialE]\^\(\(-100.101`\)\ t\) + 
          5.308278130147261`*^-6\ \[ExponentialE]\^\(\(-100.10012`\)\ t\) + 
          0.015940775165609558`\ \[ExponentialE]\^\(\(-0.0201`\)\ t\) + 
          0.031881550331219116`\ \[ExponentialE]\^\(\(-0.0011`\)\ t\) + 
          0.005313591721869853`\ \[ExponentialE]\^\(\(-0.00022`\)\ t\), 
      q\_bb1[t] \[Rule] 
        6.378825063484139`*^-6\ \[ExponentialE]\^\(\(-102.1`\)\ t\) + 
          1.608569130347507`*^-7\ \[ExponentialE]\^\(\(-100.11999999999999`\)\
\ t\) + 1.5932800790831997`*^-8\ \[ExponentialE]\^\(\(-100.101`\)\ t\) + 
          2.6542983229730416`*^-10\ \[ExponentialE]\^\(\(-100.10012`\)\ t\) + 
          0.006385210273758899`\ \[ExponentialE]\^\(\(-2.0001`\)\ t\) + 
          0.00016101793096575314`\ \[ExponentialE]\^\(\(-0.0201`\)\ t\) + 
          0.00001594874954037975`\ \[ExponentialE]\^\(\(-0.0011`\)\ t\) + 
          2.6569552782516216`*^-7\ \[ExponentialE]\^\(\(-0.00022`\)\ t\), 
      q\_bb2[t] \[Rule] 
        4.375245130114162`*^-6\ \[ExponentialE]\^\(\(-100.13`\)\ t\) + 
          0.004379624754869886`\ \[ExponentialE]\^\(\(-0.0301`\)\ t\), 
      q\_bbseq[t] \[Rule] 
        7.70572783089738`*^-8\ \[ExponentialE]\^\(\(-100.11`\)\ t\) + 
          0.00007713441272169102`\ \[ExponentialE]\^\(\(-0.0101`\)\ t\), 
      q\_BB1[t] \[Rule] 
        0.000010043280629059431`\ \[ExponentialE]\^\(\(-110.1`\)\ t\) + 
          1.5947062658710348`*^-6\ \[ExponentialE]\^\(\(-102.1`\)\ t\) + 
          1.316523108359444`*^-8\ \[ExponentialE]\^\(\(-100.13`\)\ t\) + 
          3.223585431558597`*^-8\ \[ExponentialE]\^\(\(-100.11999999999999`\)\
\ t\) + 3.186878846052369`*^-9\ \[ExponentialE]\^\(\(-100.101`\)\ t\) + 
          5.308660349870766`*^-11\ \[ExponentialE]\^\(\(-100.10012`\)\ t\) + 
          0.010053333963025171`\ \[ExponentialE]\^\(\(-10.0001`\)\ t\) + 
          0.0015963025684397247`\ \[ExponentialE]\^\(\(-2.0001`\)\ t\) + 
          0.000013178409493088923`\ \[ExponentialE]\^\(\(-0.0301`\)\ t\) + 
          0.000032268122438026674`\ \[ExponentialE]\^\(\(-0.0201`\)\ t\) + 
          3.1900689149674457`*^-6\ \[ExponentialE]\^\(\(-0.0011`\)\ t\) + 
          5.313974324195133`*^-8\ \[ExponentialE]\^\(\(-0.00022`\)\ t\), 
      q\_BB2[t] \[Rule] 
        5.90917573344181`*^-6\ \[ExponentialE]\^\(\(-100.13`\)\ t\) + 
          0.005915090824266558`\ \[ExponentialE]\^\(\(-0.0301`\)\ t\), 
      q\_BBseq[t] \[Rule] 
        1.240388980408222`*^-7\ \[ExponentialE]\^\(\(-100.11`\)\ t\) + 
          0.00012416306110195918`\ \[ExponentialE]\^\(\(-0.0101`\)\ t\), 
      q\_LNth[t] \[Rule] \(-2.0109617634983664`*^-7\)\ \
\[ExponentialE]\^\(\(-100.11`\)\ t\) - 
          8.847130216915354`*^-7\ \[ExponentialE]\^\(\(-100.10012`\)\ t\) + 
          1.0858091980412094`*^-6\ \[ExponentialE]\^\(\(-100.1`\)\ t\) - 
          0.00020129747382365018`\ \[ExponentialE]\^\(\(-0.0101`\)\ t\) - 
          0.0008855986203116422`\ \[ExponentialE]\^\(\(-0.00022`\)\ t\) + 
          0.0010868960941352924`\ \[ExponentialE]\^\(\(-0.0001`\)\ t\), 
      q\_ET2[t] \[Rule] 
        0.0003966190593791552`\ \[ExponentialE]\^\(\(-200.1`\)\ t\) + 
          1.115920069896456`*^-6\ \[ExponentialE]\^\(\(-110.1`\)\ t\) + 
          1.62725129168248`*^-7\ \[ExponentialE]\^\(\(-102.1`\)\ t\) + 
          3.090202889150656`*^-9\ \[ExponentialE]\^\(\(-100.13`\)\ t\) + 
          3.2242302777305`*^-9\ \[ExponentialE]\^\(\(-100.11999999999999`\)\ \
t\) + 3.1869107152511164`*^-10\ \[ExponentialE]\^\(\(-100.101`\)\ t\) + 
          5.308666721005103`*^-12\ \[ExponentialE]\^\(\(-100.10012`\)\ t\) + 
          0.39701607545481515`\ \[ExponentialE]\^\(\(-100.0001`\)\ t\) + 
          0.0011170371070027966`\ \[ExponentialE]\^\(\(-10.0001`\)\ t\) + 
          0.00016288801718772702`\ \[ExponentialE]\^\(\(-2.0001`\)\ t\) + 
          3.093296185444493`*^-6\ \[ExponentialE]\^\(\(-0.0301`\)\ t\) + 
          3.2274577353497375`*^-6\ \[ExponentialE]\^\(\(-0.0201`\)\ t\) + 
          3.190100815975606`*^-7\ \[ExponentialE]\^\(\(-0.0011`\)\ t\) + 
          5.313980700971974`*^-9\ \[ExponentialE]\^\(\(-0.00022`\)\ t\), 
      q\_ETseq[t] \[Rule] 
        1.9905169735425876`*^-7\ \[ExponentialE]\^\(\(-100.101`\)\ t\) + 
          0.00019925094830262376`\ \[ExponentialE]\^\(\(-0.0011`\)\ t\), 
      q\_LNet[t] \[Rule] \(-1.9905169735434007`*^-7\)\ \
\[ExponentialE]\^\(\(-100.101`\)\ t\) + 
          1.9905169735428586`*^-7\ \[ExponentialE]\^\(\(-100.1`\)\ t\) - 
          0.00019925094830262376`\ \[ExponentialE]\^\(\(-0.0011`\)\ t\) + 
          0.0001992509483026237`\ \[ExponentialE]\^\(\(-0.0001`\)\ t\)}\)], \
"Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell["\<\
The default initial deposition values (IFD) applied for AMAD = 5 \[Mu]m and \
the FRA (fractional rate absorption) for S can be obtained as follow\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AMADAdultW[5]\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \({0.053189`, 0.00664621`, 0.004384`, 0.0118343`, 0.005921`, 0.3989`, 
      0.3386996`}\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(S\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \({0.1`, 100, 0.0001`}\)], "Output",
  CellLabel->"Out[17]="]
}, Open  ]],

Cell["\<\
Now it is evaluated the retention in AI,  bb, and BB showing the solution for \
different days\
\>", "MathCaption"],

Cell[BoxData[
    \({qAI[t_], qbb[t_], \ 
        qBB[t_]} = {q\_AI[t], q\_bb1[t] + \ q\_bb2[t] + q\_bbseq[t], 
          q\_BB1[t] + q\_BB2[t] + q\_BBseq[t]} /. RTAMAD5S[t]; \)], "Input",
  CellLabel->"In[18]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[Table[{t, \ qAI[t], \ qbb[t], \ qBB[t]}, \ {t, 0, 100, 10}], 
      TableHeadings \[Rule] {None, {"\<Days after\nintake\>", "\<AI\>", "\<bb\
\>", "\<BB\>"}}]\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nintake"\), "\<\"AI\"\>", "\<\"bb\"\>", \
"\<\"BB\"\>"},
          {"0", "0.05318900000000001`", "0.011030209999999999`", 
            "0.0177553`"},
          {"10", "0.04987284790449266`", "0.003458725244576257`", 
            "0.004529216078344519`"},
          {"20", "0.047142150225485985`", "0.0025853969235850208`", 
            "0.00337321595406321`"},
          {"30", "0.04484754355666152`", "0.0019360588747911567`", 
            "0.0025155365802198276`"},
          {"40", "0.04291027162394983`", "0.0014529368168218523`", 
            "0.0018788756867220233`"},
          {"50", "0.041265911615949925`", "0.0010932012774089348`", 
            "0.0014059948763755106`"},
          {"60", "0.03986176431588312`", "0.0008250953374473403`", 
            "0.001054508400533378`"},
          {"70", "0.03865471945722764`", "0.0006250667247958805`", 
            "0.0007930258885427081`"},
          {"80", "0.03760950977071896`", "0.0004756435778731963`", 
            "0.0005982971951995639`"},
          {"90", "0.036697282946859075`", "0.00036386089644944774`", 
            "0.00045309896777544277`"},
          {"100", "0.035894433625481975`", "0.0002800948010769305`", 
            "0.0003446702051134617`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nintake", "AI", "bb",
           "BB"}}]]]], "Output",
  CellLabel->"Out[19]//TableForm="]
}, Open  ]],

Cell["\<\
In this example is evaluated the Lung retention where some by default \
parameters are modified (Some parameters instead of values are applied). \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", 
      StyleBox["LungsRetention",
        "Input"], 
      StyleBox["]",
        "Input"]}]], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({IntakeType \[Rule] "Acute", fAI1 \[Rule] 0.3`, fAI2 \[Rule] 0.6`, 
      fAI3 \[Rule] 0.1`, fbs \[Rule] 0.007`, fBs \[Rule] 0.007`, 
      k\_"AI1,bb1" \[Rule] 0.02`, k\_"AI2,bb1" \[Rule] 0.001`, 
      k\_"AI3,bb1" \[Rule] 0.0001`, k\_"AI3,TH" \[Rule] 0.00002`, 
      k\_"bb1,BB1" \[Rule] 2, k\_"bb2,BB1" \[Rule] 0.03`, 
      k\_"bbseq,TH" \[Rule] 0.01`, k\_"BB1,ET2" \[Rule] 10, 
      k\_"BB2,ET2" \[Rule] 0.03`, k\_"BBseq,TH" \[Rule] 0.01`, 
      k\_"ETseq,ET" \[Rule] 0.001`}\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{\(qLungsExample[t_]\), "=", 
        RowBox[{
          RowBox[{
            StyleBox["LungsRetention",
              "Input"], 
            StyleBox["[",
              "Input"], \(A, {AI, 0.006, 0.004, 0.01, 0.005, 0.3, \ 0.5}, 
            S, \ t, Log[2]/7.3, \ fAI1 \[Rule] 0.15, \ fAI2 \[Rule] 0.7, 
            fAI3 \[Rule] 0.15\ , \ k\_"\<bb2,BB1\>" \[Rule] 0.05\), "]"}], "//",
           "Expand"}]}]}]], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \(8.375639833795023`*^-6\ A\ \[ExponentialE]\^\(\(-110.19495166856986`\)\ \
t\) + 9.284127978248958`*^-8\ A\ AI\ \
\[ExponentialE]\^\(\(-110.19495166856986`\)\ t\) + 
      7.3976972004945185`*^-6\ A\ \[ExponentialE]\^\(\(-102.19495166856986`\)\
\ t\) - 2.3363587596855057`*^-6\ A\ AI\ \
\[ExponentialE]\^\(\(-102.19495166856986`\)\ t\) + 
      4.012072341740523`*^-6\ A\ \[ExponentialE]\^\(\(-100.24495166856985`\)\ \
t\) + 4.990014975039293`*^-6\ A\ \[ExponentialE]\^\(\(-100.22495166856986`\)\ \
t\) + 0.0001515156062136258`\ A\ AI\ \
\[ExponentialE]\^\(\(-100.21495166856985`\)\ t\) + 
      0.`\ A\ \[ExponentialE]\^\(\(-100.20495166856986`\)\ t\) + 
      0.00069902147443901`\ A\ AI\ \
\[ExponentialE]\^\(\(-100.19595166856986`\)\ t\) + 
      0.00012475935695985263`\ A\ AI\ \
\[ExponentialE]\^\(\(-100.19507166856987`\)\ t\) + 
      1.7465052412634925`*^-7\ A\ \[ExponentialE]\^\(\(-100.19495166856986`\)\
\ t\) + 0.0000249500748751956`\ A\ AI\ \
\[ExponentialE]\^\(\(-100.19495166856986`\)\ t\) + 
      0.008384023857653642`\ A\ \[ExponentialE]\^\(\(-10.095051668569855`\)\ \
t\) + 0.00009293421399649143`\ A\ AI\ \
\[ExponentialE]\^\(\(-10.095051668569855`\)\ t\) + 
      0.0074051023027995036`\ A\ \[ExponentialE]\^\(\(-2.0950516685698557`\)\ \
t\) - 0.002338697457143175`\ A\ AI\ \[ExponentialE]\^\(\(-2.0950516685698557`\
\)\ t\) + 
      0.004016088430170823`\ A\ \[ExponentialE]\^\(\(-0.14505166856985552`\)\ \
t\) + 0.004995009985024961`\ A\ \[ExponentialE]\^\(\(-0.1250516685698555`\)\ \
t\) + 0.15166727348712458`\ A\ AI\ \[ExponentialE]\^\(\(-0.11505166856985552`\
\)\ t\) + 0.`\ A\ \[ExponentialE]\^\(\(-0.10505166856985551`\)\ t\) + 
      0.6997211956348156`\ A\ AI\ \
\[ExponentialE]\^\(\(-0.09605166856985552`\)\ t\) + 
      0.12488424120107385`\ A\ AI\ \[ExponentialE]\^\(\(-0.09517166856985551`\
\)\ t\) + 
      0.00017482534947587362`\ A\ \
\[ExponentialE]\^\(\(-0.09505166856985552`\)\ t\) + 
      0.024975049925124802`\ A\ AI\ \
\[ExponentialE]\^\(\(-0.09505166856985552`\)\ t\)\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell[TextData[{
  "You realize that the default parameters  given by ",
  StyleBox["Options[",
    FontWeight->"Bold"],
  "LungsRetention",
  StyleBox["]",
    FontWeight->"Bold"],
  " can be changed. The double subscript (e.i.:\"bb2, BB1\") of transfer \
coeffs. should be written with quotation marks. "
}], "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[{t, \ qLungsExample[t]}, \ {t, \ 0, \ 100, 10}] // 
      TableForm\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"0", \(0.025`\ A + 1.`\ A\ AI\)},
          {"10", \(0.0024395007008250844`\ A + 0.3736474082679879`\ A\ AI\)},
          {
            "20", \(0.0006564631704440644`\ A + 
              0.14001469430763053`\ A\ AI\)},
          {
            "30", \(0.00017914103550955372`\ A + 
              0.05265432681781928`\ A\ AI\)},
          {
            "40", \(0.00004962335336912687`\ A + 
              0.019862060844575733`\ A\ AI\)},
          {
            "50", \(0.000013971156324003039`\ A + 
              0.0075118941571334485`\ A\ AI\)},
          {
            "60", \(4.004212103700719`*^-6\ A + 
              0.00284733312546126`\ A\ AI\)},
          {
            "70", \(1.170435870582635`*^-6\ A + 
              0.001081289248437165`\ A\ AI\)},
          {
            "80", \(3.496283434757837`*^-7\ A + 
              0.00041127466513392715`\ A\ AI\)},
          {
            "90", \(1.0694466121828233`*^-7\ A + 
              0.00015663857359856943`\ A\ AI\)},
          {
            "100", \(3.355236303917017`*^-8\ A + 
              0.00005972399100667384`\ A\ AI\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[22]//TableForm="]
}, Open  ]],

Cell[BoxData[
    \(Clear[RTAMAD5S, qLungsExample, qAI, qbb, qBB]\)], "Input",
  CellLabel->"In[23]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2", "SubsubsectionIcon",
  CellTags->"Examples"],

Cell["\<\
Here is shown the thoracic lung retention fraction  for a single intake 1 Bq  \
of aerosols class F, M and S and AMAD = 5 \[Mu]m  in t = 0. (The radioactive \
decay constant is taken \"0\") \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\({qLungs5F[t1_], \ qLungs5M[t1_], \ qLungs5S[t1_]}\), "=", 
      RowBox[{"Map", "[", 
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["LungsRetention",
                "Input"], "[", \(1, AMADAdultW[5], #, \ t1, 0\), "]"}], "&"}],
           ",", \({F, \ M, \ S}\)}], "]"}]}]], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \({0.01006337724365423`\ \[ExponentialE]\^\(\(-110\)\ t1\) + 
        0.00798948637352798`\ \[ExponentialE]\^\(\(-102\)\ t1\) + 
        0.010318191574724172`\ \[ExponentialE]\^\(\(-100.03`\)\ t1\) + 
        0.01615017914617113`\ \[ExponentialE]\^\(\(-100.02`\)\ t1\) + 
        0.`\ \[ExponentialE]\^\(\(-100.01`\)\ t1\) + 
        0.03193255793813499`\ \[ExponentialE]\^\(\(-100.001`\)\ t1\) + 
        0.00443273582045417`\ \[ExponentialE]\^\(\(-100.00012000000001`\)\ t1\
\) + 0.0010879819033333337`\ \[ExponentialE]\^\(\(-100\)\ t1\), 
      0.001005884849745729`\ \[ExponentialE]\^\(\(-110\)\ t1\) + 
        0.0007985890924887447`\ \[ExponentialE]\^\(\(-102\)\ t1\) + 
        0.0010313548156344627`\ \[ExponentialE]\^\(\(-100.03`\)\ t1\) + 
        0.001614291120215815`\ \[ExponentialE]\^\(\(-100.02`\)\ t1\) - 
        5.421010862427522`*^-20\ \[ExponentialE]\^\(\(-100.01`\)\ t1\) + 
        0.003191818756854436`\ \[ExponentialE]\^\(\(-100.001`\)\ t1\) + 
        0.00044307409895934236`\ \[ExponentialE]\^\(\(-100.00012000000001`\)\ \
t1\) + 0.00010874922869960168`\ \[ExponentialE]\^\(\(-100\)\ t1\) + 
        0.009057492393908503`\ \[ExponentialE]\^\(\(-10.005`\)\ t1\) + 
        0.0071908972810392335`\ \[ExponentialE]\^\(\(-2.005`\)\ t1\) + 
        0.00928683675908971`\ \[ExponentialE]\^\(\(-0.034999999999999996`\)\ \
t1\) + 0.014535888025955315`\ \[ExponentialE]\^\(\(-0.025`\)\ t1\) + 
        0.`\ \[ExponentialE]\^\(\(-0.015`\)\ t1\) + 
        0.02874073918128055`\ \[ExponentialE]\^\(\(-0.006`\)\ t1\) + 
        0.003989661721494828`\ \[ExponentialE]\^\(\(-0.00512`\)\ t1\) + 
        0.0009792326746337317`\ \[ExponentialE]\^\(\(-0.005`\)\ t1\), 
      0.000010043280629059431`\ \[ExponentialE]\^\(\(-110.1`\)\ t1\) + 
        7.97353132935344`*^-6\ \[ExponentialE]\^\(\(-102.1`\)\ t1\) + 
        0.000010297586094639224`\ \[ExponentialE]\^\(\(-100.13`\)\ t1\) + 
        0.000016117927157791034`\ \[ExponentialE]\^\(\(-100.11999999999999`\)\
\ t1\) - 8.131516293641283`*^-20\ \[ExponentialE]\^\(\(-100.11`\)\ t1\) + 
        0.000031868788460523434`\ \[ExponentialE]\^\(\(-100.101`\)\ t1\) + 
        4.423883624891933`*^-6\ \[ExponentialE]\^\(\(-100.10012`\)\ t1\) + 
        1.0858091980412094`*^-6\ \[ExponentialE]\^\(\(-100.1`\)\ t1\) + 
        0.010053333963025171`\ \[ExponentialE]\^\(\(-10.0001`\)\ t1\) + 
        0.007981512842198623`\ \[ExponentialE]\^\(\(-2.0001`\)\ t1\) + 
        0.010307893988629533`\ \[ExponentialE]\^\(\(-0.0301`\)\ t1\) + 
        0.016134061219013337`\ \[ExponentialE]\^\(\(-0.0201`\)\ t1\) + 
        2.710505431213761`*^-20\ \[ExponentialE]\^\(\(-0.0101`\)\ t1\) + 
        0.03190068914967446`\ \[ExponentialE]\^\(\(-0.0011`\)\ t1\) + 
        0.004428311936829278`\ \[ExponentialE]\^\(\(-0.00022`\)\ t1\) + 
        0.0010868960941352924`\ \[ExponentialE]\^\(\(-0.0001`\)\ t1\)}\)], \
"Output",
  CellLabel->"Out[24]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Chop[
      TableForm[\(({#1, qLungs5F[#1], \ qLungs5M[#1]\ \ , qLungs5S[#1]} &)\) /@ 
          Join[Range[0.25, \ 0.75, \ 0.25], Range[10], Range[20, 100, 10], \ 
            Range[200, 1000, 100], \ \ Range[2000, 10000, 1000]], 
        TableHeadings \[Rule] {None, {"\<Days after\nintake\>", "\<Class \
F\>", "\<Class M\>", "\<Class S\>"}}], \ 10\^\(-45\)]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nintake"\), "\<\"Class F\"\>", "\<\"Class M\"\>", \
"\<\"Class S\"\>"},
          {"0.25`", "9.64209468129449`*^-13", "0.062410088142724994`", 
            "0.06935678259355907`"},
          {"0.5`", "1.2845103203910416`*^-23", "0.05979160089348118`", 
            "0.06652828601822008`"},
          {"0.75`", "1.7468879998135926`*^-34", "0.05847723433699765`", 
            "0.06514558502332594`"},
          {"1", "2.3937264320153046`*^-45", "0.057625599694425524`", 
            "0.06427552500237536`"},
          {"2", "0", "0.05593276558815258`", "0.06269378801433073`"},
          {"3", "0", "0.05498583800741929`", "0.061935137890495325`"},
          {"4", "0", "0.05415636789713769`", "0.06130047409779483`"},
          {"5", "0", "0.05335929481514609`", "0.060694931817597914`"},
          {"6", "0", "0.052582691012688434`", "0.06010535929127244`"},
          {"7", "0", "0.05182449123151805`", "0.059529670629585585`"},
          {"8", "0", "0.05108397226897482`", "0.058967285487397984`"},
          {"9", "0", "0.05036060517506575`", "0.058417835123414426`"},
          {"10", "0", "0.049653900264422415`", "0.057880987087771014`"},
          {"20", "0", "0.04340630532925459`", "0.05313929788613847`"},
          {"30", "0", "0.03838679246652552`", "0.04935432825601152`"},
          {"40", "0", "0.034298371519371526`", "0.04631240670334732`"},
          {"50", "0", "0.03092126690692689`", "0.0438491883809243`"},
          {"60", "0", "0.028092204712756582`", "0.041837963228833416`"},
          {"70", "0", "0.025689367601014104`", "0.04018079749916242`"},
          {"80", "0", "0.02362144232042384`", "0.03880180963056221`"},
          {"90", "0", "0.021819627998477756`", "0.037642056328222546`"},
          {"100", "0", "0.020231790716410864`", "0.03665563536597257`"},
          {"200", "0", "0.010556103115000716`", "0.031218666464948697`"},
          {"300", "0", "0.005836340033898102`", "0.028174460369493545`"},
          {"400", "0", "0.0032551303788948944`", "0.025650019783283295`"},
          {"500", "0", "0.001819771626553487`", "0.023406716857724684`"},
          {"600", "0", "0.0010188962233987154`", "0.02139231874660401`"},
          {"700", "0", "0.0005713252284099429`", "0.019580131605462667`"},
          {"800", "0", "0.00032084869129634513`", "0.0179488559839372`"},
          {"900", "0", "0.0001804720465158918`", "0.016479754588993967`"},
          {"1000", "0", "0.00010168149765891541`", "0.01515608482609662`"},
          {"2000", "0", "3.635284885516419`*^-7", "0.007276566540623154`"},
          {"3000", "0", "1.5887472477352625`*^-9", "0.0042705698227413135`"},
          {"4000", "0", "8.191795546467708`*^-12", "0.0029570119626817575`"},
          {"5000", "0", "4.669764224003561`*^-14", "0.002263663623664677`"},
          {"6000", "0", "2.8002225290149845`*^-16", 
            "0.0018228563480254336`"},
          {"7000", "0", "1.7199222254277957`*^-18", 
            "0.0015035285167753596`"},
          {"8000", "0", "1.0690929143315241`*^-20", 
            "0.0012550507091918426`"},
          {"9000", "0", "6.691568944533769`*^-23", "0.0010549132337941709`"},
          {"10000", "0", "4.208918921515846`*^-25", "0.0008910504723014032`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nintake", "Class F", 
          "Class M", "Class S"}}]]]], "Output",
  CellLabel->"Out[25]//TableForm="]
}, Open  ]],

Cell["\<\
This solution is the same that the obtained by Potter (in Table A1, Health \
Phys 83 (5):594-789; 2002)\
\>", "Text"],

Cell["\<\
Here is evaluated the lung retention for AMAD 1, 3, 5, and 10 \[Mu]m (Type S) \
for an acute input = \"1\"\
\>", "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{\({qLungs1S[t1_], qLungs3S[t1_], qLungs5S[t1_], 
          qLungs10S[t1_]}\), "=", " ", 
        RowBox[{"Map", "[", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["LungsRetention",
                  "Input"], "[", \(1, AMADAdultW[#], S, t1, 0\), "]"}], "&"}],
             ",", " ", \({1, \ 3, \ 5, \ 10}\)}], "]"}]}], ";"}]], "Input",
  CellLabel->"In[26]:="],

Cell["\<\
 We can eliminate the negligible terms for Lungs (AMAD 5, and S)\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(qLungs5SShort[t_] = Drop[qLungs5S[t] // Chop, \ 7]\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(0.010053333963025171`\ \[ExponentialE]\^\(\(-10.0001`\)\ t\) + 
      0.007981512842198623`\ \[ExponentialE]\^\(\(-2.0001`\)\ t\) + 
      0.010307893988629533`\ \[ExponentialE]\^\(\(-0.0301`\)\ t\) + 
      0.016134061219013337`\ \[ExponentialE]\^\(\(-0.0201`\)\ t\) + 
      0.03190068914967446`\ \[ExponentialE]\^\(\(-0.0011`\)\ t\) + 
      0.004428311936829278`\ \[ExponentialE]\^\(\(-0.00022`\)\ t\) + 
      0.0010868960941352924`\ \[ExponentialE]\^\(\(-0.0001`\)\ t\)\)], \
"Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell["\<\
Here is shown the thoracic lung retention fraction  for AMAD 5,  Class F, M \
and S\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{qLungs1S[t], qLungs3S[t], qLungs5S[t], qLungs10S[t]}, \ {t, \ 
        0, \ 1000}, PlotStyle \[Rule] styles, \ 
      AxesLabel \[Rule] {"\<days\>", \ "\<r\>"}, \[IndentingNewLine]PlotLabel \
\[Rule] "\<Acute intake lung retention fraction,\n class S, for different \
AMADs\>", \ PlotLegend \[Rule] {"\<1\>", "\<3\>", "\<5\>", \ "\<10\>"}, \ 
      LegendPosition \[Rule] \ {0.5, \ \(-0.1\)}, \ 
      LegendSize \[Rule] \ {0.3, \ 0.5}]\)], "Input",
  CellLabel->"In[28]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000952381 0.0147151 4.34245 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -12 -9 ]
[.97619 .00222 12 0 ]
[1.025 .01472 0 -6.25 ]
[1.025 .01472 28 6.25 ]
[.01131 .10156 -24 -4.5 ]
[.01131 .10156 0 4.5 ]
[.01131 .18841 -24 -4.5 ]
[.01131 .18841 0 4.5 ]
[.01131 .27526 -24 -4.5 ]
[.01131 .27526 0 4.5 ]
[.01131 .36211 -24 -4.5 ]
[.01131 .36211 0 4.5 ]
[.01131 .44896 -18 -4.5 ]
[.01131 .44896 0 4.5 ]
[.01131 .53581 -24 -4.5 ]
[.01131 .53581 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12.5 ]
[.5 .63053 -113.094 0 ]
[.5 .63053 113.094 25.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(200)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(400)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(600)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(800)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1000)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10156 m
.03006 .10156 L
s
[(0.02)] .01131 .10156 1 0 Mshowa
.02381 .18841 m
.03006 .18841 L
s
[(0.04)] .01131 .18841 1 0 Mshowa
.02381 .27526 m
.03006 .27526 L
s
[(0.06)] .01131 .27526 1 0 Mshowa
.02381 .36211 m
.03006 .36211 L
s
[(0.08)] .01131 .36211 1 0 Mshowa
.02381 .44896 m
.03006 .44896 L
s
[(0.1)] .01131 .44896 1 0 Mshowa
.02381 .53581 m
.03006 .53581 L
s
[(0.12)] .01131 .53581 1 0 Mshowa
.125 Mabswid
.02381 .03643 m
.02756 .03643 L
s
.02381 .05814 m
.02756 .05814 L
s
.02381 .07985 m
.02756 .07985 L
s
.02381 .12328 m
.02756 .12328 L
s
.02381 .14499 m
.02756 .14499 L
s
.02381 .1667 m
.02756 .1667 L
s
.02381 .21013 m
.02756 .21013 L
s
.02381 .23184 m
.02756 .23184 L
s
.02381 .25355 m
.02756 .25355 L
s
.02381 .29697 m
.02756 .29697 L
s
.02381 .31869 m
.02756 .31869 L
s
.02381 .3404 m
.02756 .3404 L
s
.02381 .38382 m
.02756 .38382 L
s
.02381 .40554 m
.02756 .40554 L
s
.02381 .42725 m
.02756 .42725 L
s
.02381 .47067 m
.02756 .47067 L
s
.02381 .49238 m
.02756 .49238 L
s
.02381 .5141 m
.02756 .5141 L
s
.02381 .55752 m
.02756 .55752 L
s
.02381 .57923 m
.02756 .57923 L
s
.02381 .60095 m
.02756 .60095 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -174.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Acute) show
99.188 12.750 moveto
(intake) show
141.188 12.750 moveto
(lung) show
171.188 12.750 moveto
(retention) show
231.188 12.750 moveto
(fraction) show
279.188 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
69.000 25.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(class) show
105.000 25.875 moveto
(S) show
111.000 25.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
123.000 25.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(for) show
147.000 25.875 moveto
(different) show
207.188 25.875 moveto
(AMADs) show
237.188 25.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .60332 m
.02499 .53805 L
.02605 .52943 L
.02729 .52306 L
.02846 .51751 L
.03279 .49829 L
.04262 .46115 L
.06244 .40696 L
.07295 .38626 L
.08265 .37065 L
.10458 .34421 L
.12331 .32817 L
.14393 .31483 L
.18422 .29611 L
.22299 .28272 L
.26421 .27077 L
.30392 .26046 L
.34212 .25122 L
.38276 .24194 L
.42189 .23344 L
.46347 .22483 L
.50354 .21691 L
.54209 .20962 L
.58309 .2022 L
.62258 .19537 L
.66055 .18908 L
.70098 .18267 L
.73989 .17676 L
.78125 .17075 L
.82109 .16522 L
.85942 .16011 L
.9002 .15492 L
.93947 .15013 L
.97619 .14583 L
s
0 1 0 r
1.5 Mabswid
[ ] 0 setdash
.02381 .48994 m
.02499 .40763 L
.02605 .40031 L
.02729 .39514 L
.02846 .39068 L
.03279 .37525 L
.04262 .34562 L
.06244 .30289 L
.07295 .28677 L
.08265 .2747 L
.09397 .26325 L
.10458 .2545 L
.12331 .24243 L
.14393 .23249 L
.1827 .21915 L
.22393 .20876 L
.26364 .20042 L
.30183 .19322 L
.34247 .18609 L
.3816 .17962 L
.42319 .17309 L
.46325 .16709 L
.5018 .16157 L
.54281 .15595 L
.58229 .15079 L
.62027 .14602 L
.66069 .14117 L
.6996 .1367 L
.74096 .13216 L
.7808 .12797 L
.81913 .12411 L
.85992 .12018 L
.89918 .11655 L
.93693 .11321 L
.97619 .10988 L
s
0 0 1 r
2 Mabswid
[ 1 8 ] 0 Mabsdash
.02381 .37066 m
.02499 .29141 L
.02605 .28565 L
.02729 .28184 L
.02846 .27859 L
.03279 .26739 L
.04262 .24593 L
.06244 .21516 L
.07295 .20361 L
.08265 .19501 L
.09397 .18687 L
.10458 .18068 L
.12331 .17218 L
.14393 .16522 L
.1827 .15594 L
.22393 .14874 L
.26364 .14299 L
.30183 .13802 L
.34247 .1331 L
.3816 .12864 L
.42319 .12413 L
.46325 .11999 L
.5018 .11618 L
.54281 .11231 L
.58229 .10875 L
.62027 .10546 L
.66069 .10211 L
.6996 .09903 L
.74096 .09589 L
.7808 .093 L
.81913 .09034 L
.85992 .08763 L
.89918 .08513 L
.93693 .08283 L
.97619 .08053 L
s
0 g
2.5 Mabswid
[ ] 0 setdash
.02381 .19967 m
.02499 .14127 L
.02605 .13812 L
.02729 .13628 L
.02846 .13474 L
.03279 .12945 L
.04262 .11935 L
.05224 .11153 L
.06244 .10495 L
.07295 .09958 L
.08265 .0956 L
.09321 .09207 L
.10458 .08901 L
.12411 .08498 L
.14241 .08217 L
.18364 .07771 L
.22335 .07462 L
.26154 .07214 L
.30219 .06977 L
.34132 .06767 L
.3829 .06555 L
.42296 .06362 L
.46152 .06184 L
.50252 .06004 L
.54201 .05838 L
.57998 .05685 L
.6204 .05529 L
.65931 .05385 L
.70067 .05239 L
.74052 .05105 L
.77885 .04981 L
.81963 .04854 L
.8589 .04738 L
.89665 .04631 L
.93685 .04521 L
.97554 .0442 L
.97619 .04419 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.7619 .23759 m
.7619 .47568 L
.90476 .47568 L
.90476 .23759 L
F
1 g
.7381 .2614 m
.7381 .49949 L
.88095 .49949 L
.88095 .2614 L
F
0 g
.001 w
[ ] 0 setdash
.7381 .2614 m
.88095 .2614 L
.88095 .49949 L
.7381 .49949 L
.7381 .2614 L
s
% Start of sub-graphic
p
0.738095 0.261398 0.880952 0.499493 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0344353 0.344353 [
[ 0 0 0 0 ]
[ 1 1.66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.66667 L
0 1.66667 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0619835 0.35119 0.406336 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
2.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .23416 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.461433 0.35119 0.805785 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
2 Mabswid
[ 1 8 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .63361 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.860882 0.35119 1.20523 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
1.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 1.03306 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 1.26033 0.35119 1.60468 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 1.43251 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[28]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00IP3oool6000000@0oooo100000050?ooo`@00000:03oool4000000@0
oooo100000050?ooo`@00000:03oool4000000@0oooo100000050?ooo`@000009`3oool4000000D0
oooo100000050?ooo`@000008P3oool7000000<0oooo100000050?ooo`@000001@3oool4000003X0
oooo001V0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool0=`3oool006L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool0=`3oool006P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0S0?ooo`H0
00000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`0T0?ooo`8000000`3oool010000000oooo0?ooo`0000040?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo03L0oooo001Y0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0903oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`0000000P0000030?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02@0oooo100000040?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0=`3o
ool006X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`0T0?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool0=`3oool006H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`000000103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`0g0?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`0P0?ooo`<000001@3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0=`3oool006L0oooo100000050?ooo`@000001@3oool4000002T0oooo0P00
00050?ooo`@000001@3oool4000002X0oooo0`0000030?ooo`@000001@3oool4000002L0oooo1000
00050?ooo`@000001@3oool4000002D0oooo00<000000?ooo`3oool0103oool4000000D0oooo1000
00050?ooo`@00000>P3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0ooooSP3oool300000200
oooo000f0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`0N0?ooo`00=P3o
ool00`000000oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool07P3oool003H0oooo00<00000
0?ooo`3oool0o`3ooom30?ooo`<0000000<0oooo000000000000103oool5000000D0oooo0P000005
0?ooo`D000005@3oool003H0oooo00<000000?ooo`3oool0o`3ooom20?ooo`040000003oool0oooo
0?ooo`800000103oool01@000000oooo0?ooo`3oool0000000H0oooo0P0000050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool04P3oool003H0oooo00<000000?ooo`3oool0o`3ooom2
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0B0?ooo`00;P3o
oooo0000048000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo1000
00050?ooo`040000003oool0oooo000000D0oooo1000000E0?ooo`00=P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool010000000oooo0?oo
o`3oool2000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0180oooo000f0?ooo`03
0000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0A0?ooo`<0
000000<0oooo0000003oool0103oool3000000@0oooo0`0000020?ooo`<000000`3oool5000001@0
oooo000f0?ooo`030000003oool0oooo0?l0ooooA`3oool00`000000oooo0?ooo`0^0?ooo`00=P3o
ool00`000000oooo0?ooo`3o0?ooodL0oooo00<000000?ooo`3oool0;P3oool003H0oooo00<00000
0?ooo`3oool0o`3ooom60?ooo`800000<03oool003H0oooo0P00003o0?ooogT0oooo000f0?ooo`03
0000003oool0oooo0?l0ooooN03oool003H0oooo00<000000?ooo`3oool0o`3ooolL0?oooaD00000
A`3oool003H0oooo00<000000?ooo`3oool0m@3ooolk000004L0oooo000f0?ooo`030000003oool0
oooo0=`0ooooE00000170?ooo`00=P3oool00`000000oooo0?ooo`2f0?ooofD00000G03oool003H0
oooo00<000000?ooo`3oool0W@3ooomH00000880oooo000f0?ooo`800000T@3ooom<000009/0oooo
000f0?ooo`030000003oool0oooo07H0oooo@00000310?ooo`00=P3oool00`000000oooo0?ooo`1L
0?oood400000fP3oool003H0oooo00<000000?ooo`3oool0D03ooom000000>L0oooo000f0?ooo`03
0000003oool0oooo04<0oooo<`00003o0?ooo`80oooo000f0?ooo`030000003oool0oooo03L0oooo
9@00003o0?oooa`0oooo000f0?ooo`030000003oool0oooo02X0oooo9P00003o0?ooobP0oooo000f
0?ooo`8000008@3ooolS00000=/0oooo1@000?l90?ooo`@0003oA`3oool003H0oooo00<000000?oo
o`3oool06P3ooolM00000=X0oooo10000?l90?ooo`D0003o2@3oool40000odL0oooo000f0?ooo`03
0000003oool0oooo01D0oooo5@00003I0?ooo`D0003o2@3oool40000o`T0oooo1@000?l90?ooo`@0
003oA`3oool003H0oooo00<000000?ooo`3oool04@3oool?00000=H0oooo10000?l90?ooo`D0003o
2@3oool40000of80oooo000@0?ooo`@000001P3oool2000000H0oooo100000040?ooo`H000001P3o
ool00`000000oooo0?ooo`0>0?ooo``00000cP3oool50000o`T0oooo10000?l90?ooo`D0003oK`3o
ool000l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00d0oooo200000360?ooo`@0003o2@3oool50000o`T0oooo1000
0?mm0?ooo`003`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02P3oool700000;`0oooo1@000?l90?ooo`@0003o2@3oool50000ohX0oooo000?0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool3000000P0oooo1`00002a0?oo
o`@0003o2@3oool50000o`T0oooo10000?nH0?ooo`003`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool7000009T0oooo00<0003o0?ooo`3o
ool0203oool50000o`T0oooo10000?l90?ooo`D0003oY@3oool000l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo1@00002K0?ooo`<0003o
2@3oool50000o`T0oooo10000?nc0?ooo`003`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`@00000W03oool40000o`T0oooo
1@000?mZ0?ooo`h00?l0B03oool000l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool4000008l0oooo1@000?l80?ooo`@0003o
K@3ooolJ003o04P0oooo000@0?ooo`@000003P3oool4000000D0oooo100000070?ooo`030000003o
ool0oooo0080oooo1@0000230?ooo`D0003o203oool50000o`T0oooo0P000?mQ0?oooaT00?l0EP3o
ool003H0oooo00@000000?ooo`3oool0oooo1@00001g0?ooo`@0003o2@3oool50000o`P0oooo1@00
0?mV0?oooa<00?l0HP3oool003H0oooo0P0000000`3oool0000000000003000007P0oooo10000?l9
0?ooo`D0003oK03oool=003o06l0oooo000f0?ooo`030000003oool0000000<00000K03oool50000
o`T0oooo10000?m^0?oooa<00?l0M@3oool003H0oooo1@00001P0?ooo`@0003o2@3oool50000ofh0
oooo6@00o`1l0?ooo`00=P3oool400000640oooo10000?l90?ooo`D0003oJ03ooolC003o08P0oooo
000e0?ooo`@00000E03oool50000o`T0oooo10000?m_0?ooo`d00?l0U@3oool003D0oooo0`00001E
0?ooo`D0003oL03ooolC003o09/0oooo000e0?ooo`<00000B03oool40000o`T0oooo1@000?mZ0?oo
oa800?l0XP3oool003D0oooo0`0000180?ooo`@0003oL@3oool=003o06<0oooo0`3o00180?ooo`00
=@3oool3000003/0oooo10000?l90?ooo`@0003oI@3ooolC003o06D0oooo103o001;0?ooo`00=@3o
ool3000003/0oooo10000?m/0?oooa800?l0I03oool30?l005@0oooo000e0?ooo`<00000;@3oool5
0000o`T0oooo10000?mU0?ooo`d00?l0H`3oool40?l000D0oooo103o001G0?ooo`00=@3oool30000
02d0oooo1@000?m/0?ooo`d00?l0IP3oool30?l006@0oooo000e0?ooo`<00000;@3oool50000ofD0
oooo3@00o`1T0?ooo`@0o`00K03oool003D0oooo0`00000R0?ooo`<0003oI@3ooolD003o0640oooo
00<0o`000?ooo`3oool00`3oool30?l00700oooo000e0?ooo`<00000803oool50000oel0oooo4`00
o`1R0?ooo`H0o`00N@3oool003D0oooo0`00000P0?ooo`D0003oF@3oool<003o06H0oooo1@3o0023
0?ooo`00=@3oool300000200oooo0`000?mD0?ooo`d00?l0JP3oool20?l008P0oooo000e0?ooo`<0
00005P3oool00`000?l0oooo0?ooo`1G0?ooo`h00?l0I@3oool60?l008l0oooo000@0?ooo`@00000
1P3oool2000000H0oooo100000060?ooo`@000001@3oool3000001D0oooo0`000?mB0?ooo`d00?l0
J`3oool00`3o0000oooo0?ooo`2C0?ooo`003`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`<00000503oool40000od`0oooo3000o`1V0?ooo`L0o`00V`3o
ool000l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`<000004`3oool4
0000odT0oooo2P00o`1T0?ooo`<0o`00Y`3oool000l0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo1P000005
0?ooo`@000004`3oool20000odH0oooo2000o`1V0?ooo`@0o`00ZP3oool000l0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000060?ooo`<00000E`3oool9003o0680oooo0`3o002c
0?ooo`003`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000H0oooo0`00001A
0?ooo`/00?l0HP3oool40?l00;H0oooo000?0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`0000001P3oool3000004X0oooo3@00o`1O0?ooo`<0o`00_`3oool000l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo000000060?ooo`<00000AP3oool;003o0640oooo103o00320?ooo`00
403oool4000000h0oooo100000070?ooo`8000001P3oool3000000`0oooo00<0003o0?ooo`3oool0
<`3oool8003o0600oooo0`3o003;0?ooo`00=P3oool00`000000oooo0?ooo`0:0?ooo`<0003o<03o
ool8003o0640oooo0`3o003>0?ooo`00=P3oool2000000X0oooo10000?l/0?ooo`P00?l0o`3ooolg
0?ooo`00=P3oool00`000000oooo0?ooo`080?ooo`@0003o:@3oool8003o0640oooo0`3o003F0?oo
o`00=P3oool00`000000oooo0?ooo`090?ooo`80003o9@3oool9003o0640oooo103o003I0?ooo`00
=P3oool00`000000oooo0?ooo`0]0?ooo`P00?l0G@3oool30?l00>80oooo000f0?ooo`030000003o
ool0oooo02X0oooo1P00o`1N0?ooo`@0o`00i@3oool003H0oooo00<000000?ooo`3oool09`3oool6
003o05T0oooo0`3o003^0?ooo`00=P3oool00`000000oooo0?ooo`0S0?ooo`L00?l0F03oool40?l0
0?40oooo000f0?ooo`8000008P3oool6003o0?l0ooooD@3oool003H0oooo00<000000?ooo`3oool0
7`3oool5003o05H0oooo0`3o003j0?ooo`00=P3oool00`000000oooo0?ooo`0M0?ooo`D00?l0E03o
ool40?l00?d0oooo000f0?ooo`030000003oool0oooo0080oooo0`000?lF0?ooo`D00?l0CP3oool4
0?l00?l0oooo1P3oool003H0oooo00@000000?ooo`3oool0oooo10000?lE0?ooo`@00?l0C@3oool3
0?l00?l0oooo2P3oool003H0oooo00@000000?ooo`3oool0oooo10000?lC0?ooo`@00?l0o`3ooomL
0?ooo`00=P3oool010000000oooo0?ooo`3oool40000oa80oooo1000o`170?ooo`@0o`00o`3ooolB
0?ooo`00=P3oool2000001L0oooo0`00o`160?ooo`<0o`00o`3ooolF0?ooo`00=P3oool00`000000
oooo0?ooo`0D0?ooo`@00?l0o`3ooomP0?ooo`00=P3oool00`000000oooo0?ooo`0C0?ooo`@00?l0
?P3oool50?l00?l0oooo7P3oool00100oooo100000060?ooo`8000001P3oool4000000H0oooo1000
00060?ooo`030000003oool0oooo0180oooo0`00o`0n0?ooo`80o`00^P3ooolm000002/0oooo000?
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`<00?l0n`3ooolm000002/0oooo000?0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0100oooo0`00o`0j0?ooo`80o`00`03ooolm000002/0oooo000?0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo0P0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool03`3oool3003o03H0oooo1@3o00320?ooocd00000:`3oool000l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo00000002000000H0oooo00<000000000o`0000003`3oool2003o0?h0oooo
?@00000[0?ooo`003`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo0`00
0?l>0?ooo`800?l0<03oool30?l00<`0oooo?@00000[0?ooo`003`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00H0oooo10000?l=0?ooo`800?l0;@3oool40?l00<l0oooo?@00000[
0?ooo`003`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo10000?l=0?oo
o`800?l0o`3oool20?ooocd00000:`3oool00100oooo1000000>0?ooo`@00000203oool3000000@0
oooo0`000?l=0?ooo`03003o003oool0oooo02L0oooo0P3o003G0?ooocd00000:`3oool003D0oooo
0`000?l<0?ooo`800?l09P3oool30?l00<h0ooooB000000[0?ooo`00=P3oool00`000000oooo0?oo
o`0:0?ooo`800?l09@3oool20?l00=40oooo00<000000?ooo`3oool0>`3oool:000002/0oooo000f
0?ooo`8000002`3oool00`00o`00oooo0?ooo`3g0?ooo`030000003oool0oooo03/0oooo2P00000[
0?ooo`00=P3oool00`000000oooo0?ooo`090?ooo`800?l0n@3oool00`000000oooo0?ooo`0k0?oo
o`X00000:`3oool003H0oooo00<000000?ooo`3oool02@3oool00`00o`00oooo0?ooo`0N0?ooo`80
o`00f03oool00`000000oooo0?ooo`0k0?ooo`X00000:`3oool003H0oooo00<000000?ooo`3oool0
203oool2003o01h0oooo0P3o003J0?ooo`030000003oool0oooo03/0oooo2P00000[0?ooo`00=P3o
ool00`000000oooo0?ooo`080?ooo`03003o003oool0oooo01/0oooo0P3o003L0?ooo`030000003o
ool0oooo03/0oooo2P00000[0?ooo`00=P3oool00`000000oooo0?ooo`070?ooo`800?l0n`3oool0
0`000000oooo0?ooo`0k0?ooo`X00000:`3oool003H0oooo00<000000?ooo`3oool01`3oool00`00
o`00oooo0?ooo`3j0?ooo`030000003oool0oooo03/0oooo2P00000[0?ooo`00=P3oool2000000L0
oooo0P00o`0I0?ooo`030?l0003oool0oooo0>00oooo00<000000?ooo`3oool0>`3oool:000002/0
oooo000e0?ooo`<0003o1`3oool00`00o`00oooo0?ooo`0G0?ooo`030?l0003oool0oooo0>40oooo
00<000000?ooo`3oool0>`3oool:000002/0oooo000e0?ooo`<0003o1`3oool00`00o`00oooo0?oo
o`0E0?ooo`80o`00i03oool00`000000oooo0?ooo`0k0?ooo`X00000:`3oool003D0oooo0`000?l6
0?ooo`800?l05P3oool00`3o0000oooo0?ooo`3T0?ooo`030000003oool0oooo01T0oooo1`000003
0?ooo`@00000503oool:000002/0oooo000e0?ooo`<0003o1P3oool00`00o`00oooo0?ooo`0D0?oo
o`030?l0003oool0oooo0>D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool:000002/0oooo000f0?ooo`03
0000003oool0oooo00@0oooo0P00o`3n0?ooo`040000003oool0oooo0?oooa<00000203oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool:0000
02/0oooo000f0?ooo`030000003oool0oooo00@0oooo00<00?l00?ooo`3oool0o@3oool010000000
oooo0?ooo`3ooolC000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0140oooo2P00000[0?ooo`00=P3oool2000000@0oooo0P00o`0B0?ooo`03
0?l0003oool0oooo0>X0oooo00@000000?ooo`3oool0oooo4`0000080?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`X00000:`3oool003H0
oooo00<000000?ooo`3oool00`3oool00`00o`00oooo0?ooo`0A0?ooo`030?l0003oool0oooo0>X0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool04@3oool:000002/0oooo000f0?ooo`030000003oool0oooo0080oooo
0P00o`0B0?ooo`030?l0003oool0oooo0>/0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool:000002/0oooo
000@0?ooo`@000001P3oool2000000H0oooo100000050?ooo`@000001`3oool00`000000oooo0?oo
o`020?ooo`800?l04@3oool00`3o0000oooo0?ooo`3/0?ooo`030000003oool0oooo01X0oooo0`00
00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool:000002/0oooo000?
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103o
ool010000000oooo0?ooo`3oool3003o0100oooo00<0o`000?ooo`3oool0k@3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo00@0oooo1000000D0?ooo`X00000:`3oool000l0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0
oooo0P00o`0@0?ooo`030?l0003oool0oooo0>h0oooo00<000000?ooo`3oool0>`3oool:000002/0
oooo000?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`04
0000003oool0oooo0?ooo`800?l0o`3oool20?ooo`030000003oool0oooo03/0oooo2P00000[0?oo
o`003`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`@000001P3oool30000o`040000003oool00?l0003o
0?l0oooo0P3oool00`000000oooo0?ooo`0k0?ooo`X00000:`3oool000l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo00<0oooo0`000?l0103oool00?l0003o0000o`3o
0?ooo`80oooo00<000000?ooo`3oool0>`3oool:000002/0oooo000?0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`<0003o00<0oooo003o0000o`003P3oool0
0`3o0000oooo0?ooo`3a0?ooo`030000003oool0oooo03/0oooo2P00000[0?ooo`003`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool30000o`030?ooo`00o`00
0?l000d0oooo00<0o`000?ooo`3oool0lP3oool00`000000oooo0?ooo`0k0?ooo`X00000:`3oool0
0100oooo1000000>0?ooo`@000001@3oool4000000H0oooo0`000?l3003o00`0oooo00<0o`000?oo
o`3oool0l`3oool00`000000oooo0?ooo`0k0?ooo`X00000:`3oool003H0oooo00@000000?ooo`00
o`000?l03@3oool00`3o0000oooo0?ooo`3c0?ooo`030000003oool0oooo03/0oooo2P00000[0?oo
o`00=P3oool0100000000?l0003o0000o`0<0?ooo`030?l0003oool0oooo0?@0oooo00<000000?oo
o`3oool0>`3oool:000002/0oooo000f0?ooo`0300000000o`000?l000d0oooo00<0o`000?ooo`3o
ool0m03oool00`000000oooo0?ooo`0k0?ooo`X00000:`3oool003H0oooo00<00000003o0000o`00
303oool00`3o0000oooo0?ooo`3e0?ooo`030000003oool0oooo03/0oooo2P00000[0?ooo`00=P3o
ool3003o0?l0oooo1@3oool00`000000oooo0?ooo`0k0?ooo`X00000:`3oool003H0oooo0P00o`3o
0?ooo`H0oooo00<000000?ooo`3oool0>`3oool:000002/0oooo000f0?ooo`800?l0o`3oool60?oo
o`030000003oool0oooo03/0oooo2P00000[0?ooo`00=P3oool00`00o`00oooo0?ooo`3o0?ooo`D0
oooo00<000000?ooo`3oool0>`3oool:000002/0oooo000e0?ooo`800?l0303oool00`3o0000oooo
0?ooo`3g0?ooo`030000003oool0oooo01X0oooo1000000M0?ooo`X00000:`3oool003D0oooo0P00
o`000`000000oooo0?ooo`080?ooo`030?l0003oool0oooo0?P0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo2P00000[0?ooo`00=@3oool2
003o00/0oooo00<0o`000?ooo`3oool0n03oool010000000oooo0?ooo`3oool40000o`T0oooo1000
0?l<0?ooo`030000003oool0oooo01X0oooo2P00000[0?ooo`00=@3oool2003o00X0oooo00<0o`00
0?ooo`3oool0n@3oool010000000oooo0?ooo`3oool40000o`T0oooo10000?l<0?ooo`030000003o
ool0oooo01X0oooo2P00000[0?ooo`00=@3oool2003o00X0oooo00<0o`000?ooo`3oool0n@3oool0
10000000oooo0?ooo`3oool40000o`T0oooo10000?l<0?ooo`030000003oool0oooo01X0oooo2P00
000[0?ooo`00=@3oool2003o00T0oooo00<0o`000?ooo`3oool0nP3oool00`000000oooo0?ooo`0J
0?ooo`@000007@3oool:000002/0oooo000e0?ooo`800?l02@3oool00`3o0000oooo0?ooo`3j0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool07P3oool:000002/0oooo000e0?ooo`80
0?l0o`3oool70?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool07P3oool:000002/0
oooo000e0?ooo`800?l000<000000?ooo`3oool0o`3oool40?ooo`030000003oool0oooo01X0oooo
1@00000L0?ooo`X00000:`3oool003D0oooo0P00o`3o0?ooo`L0oooo00<000000?ooo`3oool0>`3o
ool:000002/0oooo000e0?ooo`800?l0o`3oool70?ooo`030000003oool0oooo03/0oooo2P00000[
0?ooo`006@3oool4000000H0oooo0P0000050?ooo`L00000103oool2003o00L0oooo00<0o`000?oo
o`3oool0o03oool00`000000oooo0?ooo`0k0?ooo`X00000:`3oool001P0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`800000203oool00`000000oooo0?ooo`050?ooo`80
0?l01`3oool00`3o0000oooo0?ooo`3l0?ooo`030000003oool0oooo03/0oooo2P00000[0?ooo`00
603oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1@3oool2003o00H0oooo00<0o`000?ooo`3oool0o@3oool00`000000oooo0?ooo`0k0?ooo`X00000
:`3oool001P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00D0oooo0P00o`060?ooo`030?l0003oool0oooo0?d0oooo00<000000?ooo`3oool0>`3o
ool:000002/0oooo000H0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`050?ooo`800?l00P0000040?ooo`030?l0003oool0oooo0?d0oooo00<00000
0?ooo`3oool0>`3oool:000002/0oooo000H0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`050?ooo`800?l01@3oool00`3o0000oooo0?ooo`3n0?oo
o`030000003oool0oooo03/0oooo2P00000[0?ooo`00603oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool2003o00D0oooo00<0o`000?ooo`3o
ool0oP3oool00`000000oooo0?ooo`0k0?ooo`X00000:`3oool001P0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`<000001`3oool2003o0?l0oooo1`3oool00`000000oooo
0?ooo`0k0?ooo`X00000:`3oool001T0oooo1000000@0?ooo`030000003oool0oooo00D0oooo0P00
o`3o0?ooo`L0oooo00<000000?ooo`3oool0>`3oool:000002/0oooo000e0?ooo`800?l0o`3oool7
0?ooo`030000003oool0oooo03/0oooo2P00000[0?ooo`00=@3oool2003o0?l0oooo1`3oool00`00
0000oooo0?ooo`0k0?ooo`X00000:`3oool003D0oooo0P00o`000`000000oooo0?ooo`3o0?ooo`@0
oooo00<000000?ooo`3oool0>`3oool:000002/0oooo000e0?ooo`800?l0103oool00`3o0000oooo
0?ooo`3o0?ooo`030000003oool0oooo03/0oooo2P00000[0?ooo`00=@3oool2003o00@0oooo00<0
o`000?ooo`3oool0o`3oool00`000000oooo0?ooo`0k0?ooo`X00000:`3oool003D0oooo0P00o`03
0?ooo`030?l0003oool0oooo0?l0oooo0@3oool00`000000oooo0?ooo`0J0?ooo`@000007@3oool:
000002/0oooo000e0?ooo`800?l00`3oool00`3o0000oooo0?ooo`3o0?ooo`40oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo2P00000[0?oo
o`00=@3oool2003o0080oooo00<0o`000?ooo`3oool0o`3oool20?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool06P3oool:000002/0oooo000e0?ooo`800?l000<000000?ooo`3o0000
o`3oool40?ooo`040000003oool0oooo0?oooa<00?l02P3oool00`000000oooo0?ooo`0J0?ooo`X0
0000:`3oool003D0oooo0P00o`3o0?ooo`L0oooo00@000000?ooo`3oool0oooo4`00o`080?ooo`80
00007@3oool:000002/0oooo000f0?ooo`030000003oool0oooo0?l0oooo1@3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo01X0oooo2P00000[0?ooo`00=P3oool00`000000oooo0?oo
o`3o0?ooo`D0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0J0?ooo`X00000:`3o
ool003H0oooo00<000000?ooo`3oool0o`3oool50?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`X00000:`3oool003H0oooo00<000000?oo
o`3oool0o`3oool50?ooo`030000003oool0oooo01X0oooo1000000M0?ooo`X00000:`3oool003H0
oooo00<000000?ooo`3o0000o`3oool50?ooo`030000003oool0oooo03/0oooo2P00000[0?ooo`00
=P3oool2000000030?l0003oool0oooo0?l0oooo0`3oool00`000000oooo0?ooo`0k0?ooo`X00000
:`3oool003H0oooo00<000000?l0003oool0o`3oool50?ooo`030000003oool0oooo03/0oooo2P00
000[0?ooo`00=P3oool00`000000o`000?ooo`3o0?ooo`D0oooo00<000000?ooo`3oool0>`3oool:
000002/0oooo000f0?ooo`030000003o0000oooo0?l0oooo1@3oool00`000000oooo0?ooo`0k0?oo
o`X00000:`3oool00100oooo100000060?ooo`8000001@3oool700000080oooo1P0000060?ooo`03
0?l0003oool0oooo0?l0oooo1@3oool00`000000oooo0?ooo`0k0?ooo`X00000:`3oool000l0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`800000203oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`3o0000oooo
0?ooo`3o0?ooo`D0oooo00<000000?ooo`3oool0>`3oool:000002/0oooo000?0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0o`3oool50?ooo`030000003oool0oooo03/0oooo2P00
000[0?ooo`003`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`<00000o`3oool50?ooo`030000003oool0
oooo03/0oooo2P00000[0?ooo`003`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0?l0oooo1@3oool00`000000oooo0?ooo`0k0?ooo`X00000:`3oool000l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`3o0?ooo`D0oooo00<000000?ooo`3oool0>`3oool:000002/0
oooo000?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`3o0?ooo`D0oooo00<000000?ooo`3oool0>`3oool:000002/0oooo000?0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02`3oool3000000D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo0?l0oooo1@3oool00`000000oooo0?oo
o`0k0?ooo`X00000:`3oool00100oooo1000000@0?ooo`030000003oool0oooo00@0oooo10000007
0?ooo`030?l0003oool0oooo0?l0oooo1@3oool00`000000oooo0?ooo`0k0?ooo`X00000:`3oool0
03H0oooo00<0o`000?ooo`3oool0o`3oool50?ooo`030000003oool0oooo03/0oooo2P00000[0?oo
o`00=P3oool00`3o000000000?ooo`3o0?ooo`D0oooo00<000000?ooo`3oool06@3oool7000001/0
oooo2P00000[0?ooo`00=P3oool00`3o0000oooo0?ooo`3o0?ooo`D0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0L0?ooo`X00000:`3oool003H0oooo00<0o`000?ooo`3oool0o`3o
ool50?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool:000002/0oooo000f
0?ooo`030?l0003oool0oooo0?l0oooo1@3oool010000000oooo0?ooo`3oool70?l000D0oooo1`3o
00080?ooo`030000003oool0oooo01`0oooo2P00000[0?ooo`00=P3oool00`000000oooo0?ooo`3o
0?ooo`D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`X00000:`3oool0
03H0oooo00<000000?ooo`3oool0o`3oool50?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0703oool:000002/0oooo000f0?ooo`030000003oool0oooo0?l0oooo1@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo2P00000[0?ooo`00=P3oool200000?l0oooo
1P3oool00`000000oooo0?ooo`0J0?ooo`<000007P3oool:000002/0oooo000f0?ooo`030000003o
ool0oooo0?l0oooo1@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0<P3oool003H0oooo00<0o`000?ooo`3oool0o`3oool50?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0<P3oool003H0oooo00<0o`000?ooo`3oool0o`3oool50?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0<P3oool003H0oooo00<0o`000?ooo`3o
ool0o`3oool50?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0<P3oool003H0oooo
00<0o`000?ooo`3oool0o`3oool50?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
<P3oool003H0oooo00<0o`000?ooo`3oool0o`3oool50?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0<P3oool003H0oooo00<0o`000000003oool0o`3oool50?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0<P3oool003H0oooo00<0o`000?ooo`3oool0o`3oool50?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0<P3oool003H0oooo00<000000?ooo`3o
ool0o`3oool50?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0<P3oool003H0oooo
00<000000?ooo`3oool0o`3oool50?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
<P3oool003H0oooo00<000000?ooo`3oool0o`3oool50?ooocl00000=03oool003H0oooo00<00000
0?ooo`3oool0o`3ooomh0?ooo`00=P3oool00`000000oooo0?ooo`3o0?ooogP0oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo001b0?ooo`030000003oool0oooo0?l0oooo?03oool00780oooo0P00003o
0?ooocd0oooo000d0?ooo`@000000`3oool7000000@0oooo1@0000030?ooo`D00000103oool50000
00d0oooo00<000000?ooo`0000000P0000050?ooo`030000003oool0oooo00l0oooo1@0000040?oo
o`@00000103oool5000000d0oooo0`0000000`3oool00000000000020?ooo`L00000103oool50000
00@0oooo1@0000040?ooo`@00000103oool5000000D0oooo100000030?ooo`<000000P3oool30000
00@0oooo1000000:0?ooo`<000000`3oool6000000<0oooo1P0000030?ooo`<0000000<0oooo0000
000000000`0000050?ooo`D00000Q@3oool003<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00X0oooo0P0000030?ooo`030000003oool0oooo0080oooo0P00000A0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00d0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00001@3oool010000000oooo0?ooo`0000050?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0PP3oool0
0380oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`0000002@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`D000000`3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo0?ooo`D00000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0PP3oool00380oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`050?ooo`@000001@3oool4000000D0oooo1000000B0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00@0oooo1P0000040?ooo`030000003oool0oooo00D0oooo1P0000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`@00000Q@3oool003<0oooo1P0000050?ooo`030000003oool0oooo00@0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo00/0oooo1000000H0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`8000003P3oool010000000oooo0?oo
o`3oool2000000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000
1P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`000000103oool01`000000
oooo0000003oool000000?ooo`000000103oool00`000000oooo000000050?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0880oooo000d
0?ooo`<0000000<0oooo0000003oool0103oool00`000000oooo0?ooo`050?ooo`<000001P3oool5
000000@0oooo1@00000<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04`3oool6
000000@0oooo100000040?ooo`80000000@0oooo0000000000000000303oool3000000030?ooo`00
0000oooo00<0oooo0`0000060?ooo`H000000`3oool6000000@0oooo100000040?ooo`80000000@0
oooo0000000000000000103oool4000000<0oooo0P000000103oool000000000000000030?ooo`L0
00003@3oool00`000000oooo000000040?ooo`070000003oool000000?ooo`000000oooo00000004
0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`D00000Q03oool003@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0X0?oo
o`040000003oool0oooo0?ooo`8000005`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool00`3oool2000000<0oooo0P0000050?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`3oool0oooo0000002>0?ooo`00=03oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo02T0oooo0`0000000`3oool000000?ooo`0F0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool03`3oool2000000@0oooo0`0000030?ooo`<000000`3oool2
000000D0oooo1@00002?0?ooo`00=03oool2000000H0oooo0`0000180?ooo`<000008@3oool20000
00H0oooo00<000000?ooo`3oool01`3oool3000000H0oooo0`00003W0?ooo`00<`3oool200000004
0?ooo`0000000000000007X0oooo00<000000?ooo`3oool0nP3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00;X0oooo1000003b0?ooo`00_P3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0
oooo03l0oooo002n0?ooo`030000003oool0oooo0:d0oooo0P0000100?ooo`00:03oool3000000<0
oooo0`0000030?ooo`@000001@3oool3000000030?ooo`000000000000@0oooo100000040?ooo`@0
0000303oool700000080oooo0`0000020?ooo`<00000103oool4000000@0oooo1@0000020?ooo`80
00000P3oool3000000@0oooo1000000<0?ooo`L00000103oool3000000040?ooo`00000000000?oo
o`<000000P3oool300000080oooo0`0000000`3oool000000?ooo`0<0?ooo`D000001@3oool40000
00H0oooo100000040?ooo`@000000`3oool300000080oooo0`0000040?ooo`@000000P3oool70000
00@0oooo100000030?ooo`<000000P3oool3000000`0oooo1@0000030?ooo`D000001@3oool50000
00@0oooo100000060?ooo`@000000P3oool7000000@0oooo100000030?ooo`<000000P3oool30000
00<0oooo00<000000?ooo`3oool0?P3oool002T0oooo00<000000?ooo`3oool00`3oool01@000000
oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`8000000`3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo0P00000>0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo0080oooo0P00000o0?ooo`00:P3oool5000000<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo04<0oooo000Z0?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`H000003P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`@00000103oool3000000H0oooo1P00000>0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo
1P0000040?ooo`030000003oool0oooo00D0oooo1P0000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo100000030?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
04<0oooo000[0?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool0oooo0P0000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?oo
o`8000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00D000000?oo
o`3oool0oooo000000040?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`3oool2000000<0oooo00@000000?ooo`3oool000000`3oool2000000h0
oooo0P0000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool01@3oool2000000H0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`040000003oool0oooo0?ooo`800000103oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000000<0
oooo00<000000?ooo`3oool0@`3oool002/0oooo00<000000?ooo`0000001P3oool3000000040?oo
o`000000oooo0?ooo`8000000`3oool200000080oooo1`0000040?ooo`@000003@3oool3000000D0
oooo0P000000103oool000000000000000030?ooo`L00000103oool3000000D0oooo00<000000?oo
o`0000000P0000050?ooo`@000003`3oool00`000000oooo0?ooo`030?ooo`8000000`3oool20000
0080oooo0P000000103oool000000000000000040?ooo`<0000000<0oooo000000000000303oool2
000000040?ooo`0000000000000000@0oooo100000030?ooo`L00000103oool4000000<0oooo0P00
0000103oool000000000000000030?ooo`L000000`3oool3000000L0oooo100000030?ooo`800000
00@0oooo00000000000000003@3oool6000000<0oooo0P000000103oool000000000000000040?oo
o`<000001P3oool3000000040?ooo`000000oooo0?ooo`L000000`3oool3000000L0oooo10000003
0?ooo`80000000@0oooo0000000000000000AP3oool002`0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0680oooo000[0?ooo`8000006@3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo0680oooo001R0?ooo`030000003oool0oooo01h0
oooo0P00000J0?ooo`<00000HP3oool00`000000oooo0?ooo`0R0?ooo`<00000:@3oool00`000000
oooo0?ooo`1H0?ooo`00HP3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool0F03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-1.05197, -0.648943, \
0.0073223, 0.0073223}, {{10.625, 420.313}, {259.5, 6.3125}} -> {-177.446, \
-0.0171676, 4.91726, 0.00107845}, {{317.875, 379.375}, {153.375, 50.9375}} -> \
{-17.4787, -5.41552, 0.0820022, 0.0708733}, {{321.188, 339.438}, {149.563, \
128.375}} -> {-18.5045, -23.6282, 0.0863022, 0.27928}, {{321.188, 339.438}, \
{125, 103.813}} -> {-18.5045, -28.2014, 0.0863022, 0.27928}, {{321.188, \
339.438}, {100.438, 79.25}} -> {-18.5045, -32.7747, 0.0863022, 0.27928}, \
{{321.188, 339.438}, {75.875, 54.6875}} -> {-18.5045, -37.3479, 0.0863022, \
0.27928}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[28]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 3", "SubsubsectionIcon",
  CellTags->"Examples"],

Cell[TextData[{
  "Not only single intakes  can be calculated. For instance, if we to \
estimate the retention of the lungs   for an daily constant intake (AMAD 5 \
\[Mu]m and S, and \[Lambda]=0) with ",
  Cell[BoxData[
      \(TraditionalForm\`I\_c\)]],
  "= 0.3 Bq/day, the first step is to evaluate the retention for an acute \
unit intake  ",
  Cell[BoxData[
      \(TraditionalForm\`I\_0\)]],
  "= 1 in ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  "=0. Now it can be calculated for a constant intake  ",
  Cell[BoxData[
      \(TraditionalForm\`I\_c\)]],
  "= 0.3 Bq/day."
}], "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
    \(inputconst[t_] = 
      LungsRetention[0.3, AMADAdultW[5], S, t, \ 0, 
        IntakeType \[Rule] "\<Constant\>"]\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(\(\(18.344525793741155`\)\(\[InvisibleSpace]\)\) - 
      2.73658872726415`*^-8\ \[ExponentialE]\^\(\(-110.1`\)\ t\) - 
      2.3428593524055162`*^-8\ \[ExponentialE]\^\(\(-102.1`\)\ t\) - 
      3.085264983912681`*^-8\ \[ExponentialE]\^\(\(-100.13`\)\ t\) - 
      4.8295826481595195`*^-8\ \[ExponentialE]\^\(\(-100.11999999999999`\)\ t\
\) - 9.550990038218429`*^-8\ \[ExponentialE]\^\(\(-100.101`\)\ t\) - 
      1.3258376588035858`*^-8\ \[ExponentialE]\^\(\(-100.10012`\)\ t\) - 
      3.254173420702925`*^-9\ \[ExponentialE]\^\(\(-100.1`\)\ t\) - 
      0.0003015970029207259`\ \[ExponentialE]\^\(\(-10.0001`\)\ t\) - 
      0.0011971670679763945`\ \[ExponentialE]\^\(\(-2.0001`\)\ t\) - 
      0.10273648493650696`\ \[ExponentialE]\^\(\(-0.0301`\)\ t\) - 
      0.2408068838658707`\ \[ExponentialE]\^\(\(-0.0201`\)\ t\) - 
      8.700187949911216`\ \[ExponentialE]\^\(\(-0.0011`\)\ t\) - 
      6.038607186585378`\ \[ExponentialE]\^\(\(-0.00022`\)\ t\) - 
      3.260688282405877`\ \[ExponentialE]\^\(\(-0.0001`\)\ t\)\)], "Output",
  CellLabel->"Out[29]="]
}, Open  ]],

Cell[TextData[{
  "We can supposed other kinds of intakes: continuous ",
  Cell[BoxData[
      \(TraditionalForm\`I(t)\)]],
  " or multiple single intakes "
}], "Text"],

Cell[TextData[{
  " Here it assumed a periodic (",
  Cell[BoxData[
      \(TraditionalForm\`I(t)\ \  = \ 0.3 + 0.3\ Cos[t]\)]],
  ") intake. "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(inputcos[t_] = 
      LungsRetention[{0.3 + 0.3\ Cos[t], t}, AMADAdultW[5], S, t, \ 0, 
        IntakeType \[Rule] "\<Continuous\>"]\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(\(\(18.344525793741155`\)\(\[InvisibleSpace]\)\) - 
      5.4729517194404586`*^-8\ \[ExponentialE]\^\(\(-110.1`\)\ t\) - 
      4.68549397893911`*^-8\ \[ExponentialE]\^\(\(-102.1`\)\ t\) - 
      6.170222272624019`*^-8\ \[ExponentialE]\^\(\(-100.13`\)\ t\) - 
      9.65868354313092`*^-8\ \[ExponentialE]\^\(\(-100.11999999999999`\)\ t\) \
- 1.9101026998929587`*^-7\ \[ExponentialE]\^\(\(-100.101`\)\ t\) - 
      2.651543012132943`*^-8\ \[ExponentialE]\^\(\(-100.10012`\)\ t\) - 
      6.50802210633217`*^-9\ \[ExponentialE]\^\(\(-100.1`\)\ t\) - 
      0.0006002079560316375`\ \[ExponentialE]\^\(\(-10.0001`\)\ t\) - 
      0.002154919875977137`\ \[ExponentialE]\^\(\(-2.0001`\)\ t\) - 
      0.10282948096389351`\ \[ExponentialE]\^\(\(-0.0301`\)\ t\) - 
      0.24090413296541266`\ \[ExponentialE]\^\(\(-0.0201`\)\ t\) - 
      8.700198477125898`\ \[ExponentialE]\^\(\(-0.0011`\)\ t\) - 
      6.038607478853952`\ \[ExponentialE]\^\(\(-0.00022`\)\ t\) - 
      3.2606883150127595`\ \[ExponentialE]\^\(\(-0.0001`\)\ t\) + 
      0.0014577029200076464`\ Cos[t] + 
      0.019661305794627937`\ Sin[t]\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell["Here are compared both kind of intakes", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{inputconst[t], inputcos[t]}, \ {t, 0.1, 100}, 
      PlotStyle \[Rule] styles1]\)], "Input",
  CellLabel->"In[31]:=",
  CellTags->"Examples"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0147151 0.4272 [
[.21429 .00222 -6 -9 ]
[.21429 .00222 6 0 ]
[.40476 .00222 -6 -9 ]
[.40476 .00222 6 0 ]
[.59524 .00222 -6 -9 ]
[.59524 .00222 6 0 ]
[.78571 .00222 -6 -9 ]
[.78571 .00222 6 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .10016 -18 -4.5 ]
[.01131 .10016 0 4.5 ]
[.01131 .1856 -18 -4.5 ]
[.01131 .1856 0 4.5 ]
[.01131 .27103 -18 -4.5 ]
[.01131 .27103 0 4.5 ]
[.01131 .35647 -18 -4.5 ]
[.01131 .35647 0 4.5 ]
[.01131 .44191 -6 -4.5 ]
[.01131 .44191 0 4.5 ]
[.01131 .52735 -18 -4.5 ]
[.01131 .52735 0 4.5 ]
[.01131 .61279 -18 -4.5 ]
[.01131 .61279 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(20)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(40)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(60)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(80)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(100)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10016 m
.03006 .10016 L
s
[(0.2)] .01131 .10016 1 0 Mshowa
.02381 .1856 m
.03006 .1856 L
s
[(0.4)] .01131 .1856 1 0 Mshowa
.02381 .27103 m
.03006 .27103 L
s
[(0.6)] .01131 .27103 1 0 Mshowa
.02381 .35647 m
.03006 .35647 L
s
[(0.8)] .01131 .35647 1 0 Mshowa
.02381 .44191 m
.03006 .44191 L
s
[(1)] .01131 .44191 1 0 Mshowa
.02381 .52735 m
.03006 .52735 L
s
[(1.2)] .01131 .52735 1 0 Mshowa
.02381 .61279 m
.03006 .61279 L
s
[(1.4)] .01131 .61279 1 0 Mshowa
.125 Mabswid
.02381 .03608 m
.02756 .03608 L
s
.02381 .05744 m
.02756 .05744 L
s
.02381 .0788 m
.02756 .0788 L
s
.02381 .12152 m
.02756 .12152 L
s
.02381 .14288 m
.02756 .14288 L
s
.02381 .16424 m
.02756 .16424 L
s
.02381 .20696 m
.02756 .20696 L
s
.02381 .22831 m
.02756 .22831 L
s
.02381 .24967 m
.02756 .24967 L
s
.02381 .29239 m
.02756 .29239 L
s
.02381 .31375 m
.02756 .31375 L
s
.02381 .33511 m
.02756 .33511 L
s
.02381 .37783 m
.02756 .37783 L
s
.02381 .39919 m
.02756 .39919 L
s
.02381 .42055 m
.02756 .42055 L
s
.02381 .46327 m
.02756 .46327 L
s
.02381 .48463 m
.02756 .48463 L
s
.02381 .50599 m
.02756 .50599 L
s
.02381 .54871 m
.02756 .54871 L
s
.02381 .57007 m
.02756 .57007 L
s
.02381 .59143 m
.02756 .59143 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 1 r
1 Mabswid
[ 4 4 ] 0 Mabsdash
.02476 .01571 m
.06336 .04862 L
.10545 .08256 L
.14498 .11317 L
.183 .14157 L
.22347 .17079 L
.26242 .198 L
.30383 .22604 L
.34372 .25227 L
.38209 .27684 L
.42292 .30232 L
.46223 .32627 L
.50003 .3488 L
.54028 .3723 L
.57901 .39448 L
.62019 .41762 L
.65986 .43952 L
.69802 .46025 L
.73862 .48197 L
.77771 .50258 L
.81925 .52417 L
.85928 .54471 L
.89779 .56423 L
.93875 .58476 L
.97619 .60332 L
s
0 1 0 r
[ ] 0 setdash
.02476 .0167 m
.0294 .02495 L
.03373 .0312 L
.03617 .03401 L
.03847 .03615 L
.03975 .03711 L
.04113 .03798 L
.04238 .03862 L
.04355 .0391 L
.0447 .03947 L
.04593 .03976 L
.04663 .03987 L
.0473 .03996 L
.04855 .04006 L
.04986 .04009 L
.05108 .04007 L
.05179 .04004 L
.05242 .04001 L
.05385 .03994 L
.05507 .03989 L
.0562 .03987 L
.05744 .03989 L
.05875 .03997 L
.05988 .04012 L
.06094 .04033 L
.06211 .04065 L
.06336 .0411 L
.06472 .04173 L
.06617 .04259 L
.06877 .0446 L
.07157 .04745 L
.07467 .05137 L
.08538 .06861 L
.09036 .0764 L
.09298 .0799 L
.09573 .08298 L
.09815 .08512 L
.09943 .08604 L
.1008 .08684 L
.10206 .08744 L
.10321 .08786 L
.10436 .08819 L
.10545 .0884 L
.1066 .08854 L
.10784 .08861 L
.10901 .08861 L
.11008 .08856 L
.11132 .08846 L
.11269 .08833 L
.11396 .08821 L
Mistroke
.11516 .0881 L
.11581 .08806 L
.11652 .08802 L
.11775 .088 L
.11844 .08802 L
.11918 .08807 L
.1205 .08823 L
.12172 .08848 L
.12286 .08881 L
.12411 .08929 L
.12544 .08996 L
.12782 .09153 L
.1304 .09383 L
.13509 .09947 L
.14388 .11323 L
.14841 .1204 L
.15329 .12692 L
.15609 .1298 L
.15865 .13182 L
.1611 .13317 L
.16233 .13365 L
.16367 .13404 L
.16435 .13418 L
.16509 .13429 L
.16579 .13437 L
.16643 .13441 L
.16765 .13442 L
.16894 .13436 L
.16961 .13431 L
.17032 .13423 L
.17162 .13407 L
.17303 .13387 L
.17456 .13366 L
.17524 .13358 L
.17597 .1335 L
.17727 .13341 L
.1785 .13339 L
.17919 .13341 L
.17985 .13345 L
.18106 .13361 L
.18217 .13384 L
.18339 .13421 L
.18467 .13473 L
.18724 .13621 L
.18966 .13815 L
.19419 .14317 L
.20437 .1586 L
.20864 .16512 L
.21317 .17092 L
.21553 .1733 L
Mistroke
.21813 .17534 L
.21927 .17604 L
.2205 .17665 L
.22165 .17711 L
.22271 .17742 L
.224 .17769 L
.22521 .17783 L
.2263 .17787 L
.22748 .17784 L
.22876 .17774 L
.22941 .17766 L
.23012 .17756 L
.23256 .17715 L
.23484 .17675 L
.23612 .17658 L
.23728 .17646 L
.23837 .17641 L
.23955 .17642 L
.24066 .17651 L
.24169 .17667 L
.24288 .17695 L
.24416 .17738 L
.24536 .17792 L
.24647 .17853 L
.24903 .18038 L
.25174 .18296 L
.25683 .1894 L
.2624 .19788 L
.26769 .20595 L
.27267 .21237 L
.27485 .21458 L
.27715 .21645 L
.27836 .21723 L
.27968 .21793 L
.28088 .21843 L
.28201 .21879 L
.2833 .21907 L
.28403 .21917 L
.28471 .21923 L
.28596 .21926 L
.28665 .21924 L
.28728 .21919 L
.28848 .21906 L
.28977 .21885 L
.2921 .21839 L
.29485 .21783 L
.29623 .2176 L
.29702 .2175 L
.29775 .21743 L
.29906 .21738 L
Mistroke
.30026 .21742 L
.30092 .21748 L
.30164 .21758 L
.30294 .21787 L
.30416 .21826 L
.30528 .21874 L
.30781 .22023 L
.31014 .22214 L
.31236 .22439 L
.32275 .23892 L
.32761 .24617 L
.33279 .25262 L
.33577 .25538 L
.33847 .25718 L
.33978 .2578 L
.34047 .25807 L
.34119 .2583 L
.34183 .25848 L
.34253 .25862 L
.34375 .25879 L
.34505 .25885 L
.34626 .25881 L
.34689 .25876 L
.34758 .25868 L
.34898 .25845 L
.35137 .25793 L
.35394 .25732 L
.35516 .25706 L
.35644 .25684 L
.35754 .25669 L
.35873 .2566 L
.35986 .25659 L
.36107 .25667 L
.3622 .25684 L
.36323 .25709 L
.36454 .25754 L
.36592 .25817 L
.36839 .25974 L
.37105 .26205 L
.37398 .26529 L
.38412 .27982 L
.38933 .28713 L
.39189 .29017 L
.39427 .29252 L
.39642 .29422 L
.39871 .29555 L
.40001 .2961 L
.40124 .29647 L
.40235 .2967 L
.40354 .29684 L
Mistroke
.40485 .29687 L
.40607 .2968 L
.40677 .29672 L
.4074 .29663 L
.40883 .29637 L
.41151 .29572 L
.41442 .29497 L
.41571 .29468 L
.41642 .29455 L
.41709 .29444 L
.41826 .29431 L
.41955 .29425 L
.42077 .29429 L
.42189 .29442 L
.42312 .29468 L
.42441 .2951 L
.42565 .29563 L
.42699 .29637 L
.42942 .29813 L
.43397 .30279 L
.44416 .31721 L
.44881 .32365 L
.45135 .32667 L
.45372 .32904 L
.45591 .3308 L
.45791 .33201 L
.45905 .33254 L
.46014 .33293 L
.46128 .33323 L
.46252 .33343 L
.46373 .33351 L
.46484 .3335 L
.46607 .33339 L
.46735 .33319 L
.46847 .33296 L
.46952 .33271 L
.47189 .33205 L
.47446 .33135 L
.47573 .33105 L
.47689 .33082 L
.47755 .33072 L
.47824 .33064 L
.47893 .33059 L
.4797 .33056 L
.48101 .33061 L
.48224 .33078 L
.48354 .33108 L
.48427 .33132 L
.48495 .33159 L
.48752 .33297 L
Mistroke
.48986 .33475 L
.49235 .33717 L
.50322 .35188 L
.50822 .35884 L
.51095 .36209 L
.5135 .36462 L
.51626 .36672 L
.51772 .36755 L
.51847 .3679 L
.51929 .36821 L
.52003 .36845 L
.52072 .36863 L
.52138 .36876 L
.52207 .36886 L
.52328 .36895 L
.52397 .36895 L
.52461 .36892 L
.52579 .3688 L
.52708 .36859 L
.52842 .36828 L
.52968 .36795 L
.53431 .36658 L
.53568 .36624 L
.53696 .36597 L
.53812 .3658 L
.53937 .36571 L
.54002 .3657 L
.54073 .36572 L
.54148 .36579 L
.54218 .36589 L
.54343 .36617 L
.54413 .36639 L
.54477 .36662 L
.54606 .36721 L
.54728 .36791 L
.54955 .36957 L
.55199 .37187 L
.55463 .37488 L
.56378 .38764 L
.56903 .39467 L
.5719 .39782 L
.57458 .40017 L
.57686 .40166 L
.57814 .40228 L
.57931 .40272 L
.58059 .40305 L
.58131 .40318 L
.58197 .40326 L
.5832 .40332 L
.5845 .40327 L
Mistroke
.5857 .40312 L
.58701 .40288 L
.5894 .40225 L
.59389 .40085 L
.59519 .40049 L
.59642 .4002 L
.5971 .40006 L
.59784 .39995 L
.59913 .39982 L
.60036 .3998 L
.60166 .3999 L
.60277 .40009 L
.60399 .40042 L
.60522 .40089 L
.60638 .40146 L
.60855 .40287 L
.61089 .40485 L
.61344 .40753 L
.62227 .41943 L
.62678 .42569 L
.63165 .43133 L
.63443 .43373 L
.63565 .43457 L
.63699 .43533 L
.63825 .43589 L
.63943 .43628 L
.64067 .43657 L
.64137 .43667 L
.642 .43672 L
.64331 .43674 L
.64397 .43671 L
.6447 .43664 L
.64598 .43643 L
.64718 .43617 L
.65279 .43442 L
.65531 .43366 L
.65655 .43337 L
.65771 .43316 L
.65902 .43301 L
.65972 .43298 L
.66046 .43298 L
.66114 .43302 L
.66179 .43309 L
.66299 .43332 L
.66415 .43365 L
.6654 .43415 L
.66764 .4354 L
.67032 .4375 L
.67275 .43993 L
.68306 .45366 L
Mistroke
.68761 .45975 L
.69 .46255 L
.69255 .46505 L
.69477 .46679 L
.69594 .46753 L
.69721 .46818 L
.69837 .46864 L
.69944 .46896 L
.70045 .46918 L
.70152 .46931 L
.70276 .46934 L
.70346 .46931 L
.7041 .46926 L
.70528 .46909 L
.70653 .46883 L
.70869 .46822 L
.71107 .46742 L
.71361 .46655 L
.71501 .46613 L
.71634 .46579 L
.71757 .46555 L
.71827 .46545 L
.71892 .46539 L
.72006 .46534 L
.72127 .4654 L
.72251 .46558 L
.72366 .46586 L
.72491 .46631 L
.72623 .46694 L
.72846 .46836 L
.7309 .47042 L
.73542 .47546 L
.73962 .48111 L
.74465 .48815 L
.7473 .49159 L
.75011 .49482 L
.75256 .49716 L
.75386 .4982 L
.75526 .49914 L
.75654 .49985 L
.75771 .50036 L
.75889 .50075 L
.76002 .501 L
.76118 .50115 L
.76224 .50119 L
.76346 .50114 L
.76462 .50099 L
.76568 .50079 L
.76667 .50055 L
.76889 .49987 L
Mistroke
.77149 .49896 L
.77395 .49811 L
.77617 .49748 L
.77742 .49722 L
.77857 .49706 L
.77965 .49699 L
.78085 .49701 L
.78209 .49715 L
.78326 .4974 L
.78453 .49781 L
.78569 .49831 L
.7883 .4999 L
.79041 .50163 L
.79272 .50395 L
.79737 .50967 L
.80294 .51739 L
.80819 .52419 L
.81048 .52668 L
.8129 .52886 L
.81417 .5298 L
.81556 .53067 L
.81674 .53126 L
.81802 .53175 L
.81932 .53211 L
.82056 .5323 L
.82177 .53237 L
.82289 .53234 L
.82358 .53227 L
.82423 .53219 L
.82543 .53195 L
.82673 .53162 L
.82813 .53119 L
.83265 .52956 L
.83504 .52878 L
.83636 .52843 L
.8376 .52819 L
.83829 .52809 L
.83904 .52802 L
.84035 .52799 L
.84099 .52802 L
.84168 .52809 L
.84291 .52832 L
.84357 .5285 L
.84428 .52873 L
.84557 .52928 L
.84711 .53012 L
.84851 .53109 L
.85339 .53575 L
.85853 .54227 L
.86809 .55498 L
Mistroke
.87084 .55788 L
.87344 .56006 L
.87577 .5615 L
.87708 .5621 L
.87829 .5625 L
.87935 .56275 L
.88049 .56291 L
.88156 .56296 L
.88254 .56293 L
.88369 .56281 L
.88494 .56258 L
.88612 .56229 L
.88721 .56196 L
.89213 .56018 L
.89429 .55942 L
.89551 .55906 L
.89665 .55878 L
.89774 .55858 L
.8989 .55844 L
.90014 .5584 L
.90127 .55846 L
.90249 .55865 L
.90319 .55882 L
.90383 .55901 L
.905 .55945 L
.90625 .56007 L
.90846 .56151 L
.91054 .56326 L
.91527 .56846 L
.92031 .57519 L
.92582 .5826 L
.92833 .5856 L
.93101 .58833 L
.93355 .59037 L
.93584 .59172 L
.93711 .59225 L
.9378 .59248 L
.93845 .59266 L
.93959 .59288 L
.94085 .593 L
.94155 .593 L
.94221 .59298 L
.94346 .59285 L
.94416 .59273 L
.9448 .59259 L
.94626 .59221 L
.95093 .59053 L
.95341 .58961 L
.95471 .58918 L
.95608 .58879 L
Mistroke
.95723 .58854 L
.95849 .58836 L
.95964 .58829 L
.96071 .58831 L
.96181 .58843 L
.96281 .58863 L
.96396 .58897 L
.96505 .5894 L
.96744 .59072 L
.96963 .59239 L
.97459 .59759 L
.97619 .59959 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[31]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00I@3oool6000000@0oooo100000110?ooo`@00000103oool400000440oooo100000040?oo
o`@00000?`3oool4000000D0oooo1000000j0?ooo`L000000`3oool4000000D0oooo100000060?oo
o`00I@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0m0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`00IP3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?@3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool006L0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03`0oooo1P0000030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0?@3oool2000000<0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`030?ooo`00J03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0?@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo00000002000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0l0?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`00J@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?@3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool00`3oool006D0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0?P3oool00`000000oooo000000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool00`3oool006D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool0?P3oool00`000000oooo000000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0h0?ooo`<000001@3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`00
IP3oool4000000D0oooo100000120?ooo`8000001@3oool4000004<0oooo0`0000030?ooo`@00000
?`3oool4000000D0oooo1000000m0?ooo`030000003oool0oooo00@0oooo100000050?ooo`@00000
1P3oool00?l0oooo/@3oool00?l0oooo/@3oool00240oooo00<000000?ooo`3oool0o`3ooon=0?oo
o`008@3oool00`000000oooo0?ooo`3o0?ooohd0oooo000Q0?ooo`030000003oool0oooo0?l0oooo
S@3oool00240oooo00<000000?ooo`3oool0o`3ooon=0?ooo`008@3oool00`000000oooo0?ooo`3o
0?ooohd0oooo000Q0?ooo`030000003oool0oooo0?l0ooooS@3oool001L0ooooo`00002D000000H0
oooo000Q0?ooo`03003o003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0=0?ooo`008@3oool00`0000000?l00?l0o`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool03@3oool00240oooo00<00000003o003oool00P3o0?m70?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool03@3oool00240oooo00<000000?ooo`00o`000P3oool00`3o
0?l0oooo0?ooo`3o0?ooohP0oooo000Q0?ooo`040000003oool0oooo003o0?l0ooooS03oool00240
oooo00@000000?ooo`3oool00?l0o`3ooon<0?ooo`008@3oool01@000000oooo0?ooo`3oool00?l0
0?l0ooooR`3oool00240oooo00<000000?ooo`3oool00P3oool01@00o`00oooo0?ooo`3oool0o`3o
0?l0ooooQP3oool00240oooo0P0000040?ooo`05003o003oool0oooo0?ooo`3o0?l0o`3ooon50?oo
o`008@3oool00`000000oooo0?ooo`040?ooo`T00?l0o`3ooon00?ooo`008@3oool00`000000oooo
0?ooo`0:0?ooo`030?l0o`3oool00?l000800?l0o`3ooomn0?ooo`008@3oool00`000000oooo0?oo
o`0;0?ooo`050?l0o`3oool0oooo0?ooo`00o`00o`3ooomm0?ooo`008@3oool00`000000oooo0?oo
o`0@0?ooo`03003o003oool0oooo0?l0ooooNP3oool00240oooo00<000000?ooo`3oool0403oool0
0`00o`00oooo0?ooo`3o0?ooogX0oooo000Q0?ooo`030000003oool0oooo0140oooo00<00?l00?oo
o`3oool0o`3ooomi0?ooo`008@3oool00`000000oooo0?ooo`0?0?ooo`040?l0o`3oool0oooo003o
0?l0ooooNP3oool00240oooo0P00000A0?ooo`030?l0o`3oool00?l00?l0ooooNP3oool00240oooo
00<000000?ooo`3oool04@3oool20?l0o`03003o003oool0oooo0?l0ooooM`3oool00240oooo00<0
00000?ooo`3oool04`3oool00`00o`00oooo0?ooo`3o0?ooogL0oooo000Q0?ooo`030000003oool0
oooo01@0oooo00<00?l00?ooo`3oool0o`3ooomf0?ooo`008@3oool00`000000oooo0?ooo`0D0?oo
o`03003o003oool0oooo0?l0ooooMP3oool00240oooo00<000000?ooo`3oool05@3oool00`00o`00
oooo0?ooo`3o0?ooogD0oooo000Q0?ooo`030000003oool0oooo01H0oooo00<00?l00?ooo`3oool0
o`3ooomd0?ooo`008@3oool00`000000oooo0?ooo`0F0?ooo`04003o003oool0oooo0?l0ool0oooo
L`3oool00240oooo00<000000?ooo`3oool05`3oool01000o`00oooo0?ooo`3o0?oo0?ooog80oooo
000Q0?ooo`8000006@3oool2003o00030?ooo`3o0?l0o`3o0?l0ooooL03oool00240oooo00<00000
0?ooo`3oool06@3oool01@00o`00oooo0?ooo`3oool0o`3o0?l0ooooK`3oool00240oooo00<00000
0?ooo`3oool06P3oool2003o0?l0ooooL@3oool00240oooo00<000000?ooo`3oool06`3oool2003o
0?l0ooooL03oool00240oooo00<000000?ooo`3oool07@3oool:003o0?l0ooooIP3oool000<0oooo
100000060?ooo`8000001@3oool6000000L0oooo00<000000?ooo`3oool08P3oool00`3o0?l0oooo
0?ooo`020?ooo`03003o003oool0oooo0?l0ooooH`3oool00080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool08`3oool00`3o0?l0oooo0?ooo`020?ooo`03003o003o
ool0oooo0?l0ooooHP3oool00080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0903oool20?l0o`80oooo00<00?l0
0?ooo`3oool0o`3ooomR0?ooo`000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0V0?ooo`040?l0o`3oool0oooo
003o0?l0ooooH`3oool00080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00L0oooo0`00000W0?ooo`040?l0o`3oool0oooo003o0?l0ooooHP3oool0
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0:P3oool00`00o`00oooo0?ooo`3o0?ooof00oooo00020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0:`3oool00`00o`00oooo0?ooo`3o0?oooel0
oooo00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;03oool00`00o`00oooo
0?ooo`3o0?oooeh0oooo00030?ooo`@000003P3oool4000000P0oooo00<000000?ooo`3oool0;03o
ool00`00o`00oooo0?ooo`3o0?oooeh0oooo000Q0?ooo`030000003oool0oooo02d0oooo00<00?l0
0?ooo`3oool0o`3ooomM0?ooo`008@3oool00`000000oooo0?ooo`0^0?ooo`03003o003o0?l0oooo
0?l0ooooG03oool00240oooo00<000000?ooo`3oool0;P3oool00`00o`00oooo0?l0o`3o0?oooe`0
oooo000Q0?ooo`800000<03oool00`00o`00oooo0?ooo`3o0?oooe/0oooo000Q0?ooo`030000003o
ool0oooo0300oooo00<00?l00?ooo`3oool0o`3ooomJ0?ooo`008@3oool00`000000oooo0?ooo`0a
0?ooo`03003o003oool0oooo0?l0ooooF@3oool00240oooo00<000000?ooo`3oool0<P3oool01000
o`00oooo0?ooo`3o0?oo0?oooeL0oooo000Q0?ooo`030000003oool0oooo03<0oooo00<00?l00?oo
o`3oool00P3o0?oo0?oooeD0oooo000Q0?ooo`030000003oool0oooo03@0oooo2P00o`3o0?ooodl0
oooo000Q0?ooo`030000003oool0oooo03X0oooo00D0o`3o0?ooo`3oool0oooo003o003o0?ooodh0
oooo000Q0?ooo`030000003oool0oooo03l0oooo00<00?l00?ooo`3oool0o`3ooom;0?ooo`008@3o
ool00`000000oooo0?ooo`100?ooo`03003o003oool0oooo0?l0ooooBP3oool00240oooo0P000012
0?ooo`03003o003oool0oooo0?l0ooooB@3oool00240oooo00<000000?ooo`3oool0?`3oool0103o
0?l0oooo0?ooo`00o`3o0?ooodX0oooo000Q0?ooo`030000003oool0oooo0400oooo0P3o0?l00`00
o`00oooo0?ooo`3o0?ooodP0oooo000Q0?ooo`030000003oool0oooo0480oooo00<0o`3o003o003o
ool0o`3ooom80?ooo`008@3oool00`000000oooo0?ooo`140?ooo`03003o003oool0oooo0?l0oooo
AP3oool00240oooo00<000000?ooo`3oool0A03oool00`00o`00oooo0?ooo`3o0?ooodH0oooo000Q
0?ooo`030000003oool0oooo04D0oooo00<00?l00?ooo`3oool0o`3ooom50?ooo`008@3oool00`00
0000oooo0?ooo`160?ooo`03003o003oool0oooo0?l0ooooA03oool00240oooo0P0000170?ooo`04
003o003oool0oooo0?l0ool0oooo@`3oool00240oooo00<000000?ooo`3oool0A`3oool01000o`00
oooo0?ooo`3o0?oo0?oood80oooo000Q0?ooo`030000003oool0oooo04P0oooo00<00?l00?ooo`3o
ool00P3o0?oo0?oood00oooo000Q0?ooo`030000003oool0oooo04T0oooo00D00?l00?ooo`3oool0
oooo0?l0o`3o0?ooocl0oooo000Q0?ooo`030000003oool0oooo04X0oooo00<00?l00?ooo`3oool0
o`3ooom00?ooo`000`3oool4000000H0oooo0P0000070?ooo`@000001`3oool00`000000oooo0?oo
o`1;0?ooo`800?l0103oool5003o0?l0oooo=`3oool00080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`8000002@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo04d0oooo1000o`040?ooo`800?l0o`3ooolf0?ooo`000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1B0?oo
o`030?l0o`3oool0oooo0080oooo00<00?l00?ooo`3oool0o`3ooolc0?ooo`000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo1P0000070?ooo`030000003oool0oooo05<0
oooo0P3o0?l30?ooo`03003o003oool0oooo0?l0oooo<P3oool00080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000P0oooo0`00001E0?ooo`80
o`3o0P3oool00`00o`00oooo0?ooo`3o0?oooc40oooo00020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo05L0
oooo00@0o`3o0?ooo`3oool00?l0o`3ooolb0?ooo`000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`1K0?ooo`03
003o003oool0oooo0?l0oooo;`3oool00080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool0F`3oool00`00o`00oooo
0?ooo`3o0?ooobl0oooo00030?ooo`@00000403oool2000000P0oooo00<000000?ooo`3oool0G03o
ool00`00o`00oooo0?ooo`3o0?ooobh0oooo000Q0?ooo`030000003oool0oooo05`0oooo00<0o`3o
003o003oool0o`3oool^0?ooo`008@3oool00`000000oooo0?ooo`1N0?ooo`03003o003oool0oooo
0?l0oooo;03oool00240oooo00<000000?ooo`3oool0GP3oool00`00o`00o`3o0?l0o`3o0?ooob`0
oooo000Q0?ooo`800000H03oool00`00o`00oooo0?l0o`3o0?ooob/0oooo000Q0?ooo`030000003o
ool0oooo0600oooo00<00?l00?ooo`3oool0o`3ooolZ0?ooo`008@3oool00`000000oooo0?ooo`1P
0?ooo`03003o003oool0oooo0?l0oooo:P3oool00240oooo00<000000?ooo`3oool0H@3oool00`00
o`00oooo0?ooo`020?ooo`030?l0o`3oool0oooo0?l0oooo903oool00240oooo00<000000?ooo`3o
ool0HP3oool2003o00<0oooo00<0o`3o0?ooo`3oool0o`3ooolS0?ooo`008@3oool00`000000oooo
0?ooo`1S0?ooo``00?l0o`3ooolN0?ooo`008@3oool00`000000oooo0?ooo`1Z0?ooo`030?l0o`3o
ool0oooo0080oooo00<00?l00?ooo`3oool0o`3ooolK0?ooo`008@3oool00`000000oooo0?ooo`1[
0?ooo`030?l0o`3oool0oooo0080oooo0P00o`3o0?oooa/0oooo000Q0?ooo`030000003oool0oooo
0780oooo00<00?l00?ooo`3oool0o`3ooolH0?ooo`008@3oool2000007<0oooo00<00?l00?ooo`3o
ool0o`3ooolH0?ooo`008@3oool00`000000oooo0?ooo`1`0?ooo`040?l0o`3oool0oooo003o0?l0
oooo6@3oool00240oooo00<000000?ooo`3oool0L@3oool20?l0o`030?ooo`00o`00oooo0?l0oooo
5`3oool00240oooo00<000000?ooo`3oool0L`3oool00`3o0?l00?l00?ooo`3o0?oooaL0oooo000Q
0?ooo`030000003oool0oooo07D0oooo00<00?l00?ooo`3oool0o`3ooolE0?ooo`008@3oool00`00
0000oooo0?ooo`1f0?ooo`03003o003oool0oooo0?l0oooo503oool00240oooo00<000000?ooo`3o
ool0MP3oool00`00o`00oooo0?ooo`3o0?oooa@0oooo000Q0?ooo`030000003oool0oooo07L0oooo
00<00?l00?ooo`3oool0o`3ooolC0?ooo`008@3oool00`000000oooo0?ooo`1h0?ooo`03003o003o
ool0o`3o0?l0oooo4P3oool00240oooo0P00001i0?ooo`03003o003oool0oooo0080o`3oo`3oool@
0?ooo`008@3oool00`000000oooo0?ooo`1i0?ooo`05003o003oool0oooo0?ooo`3o0?l0o`3oool?
0?ooo`008@3oool00`000000oooo0?ooo`1j0?ooo`04003o003oool0oooo0?ooo`80o`3o0`3oool2
003o0?l0oooo203oool00240oooo00<000000?ooo`3oool0N`3oool9003o00030?ooo`00o`000?l0
0?l0oooo1P3oool00240oooo00<000000?ooo`3oool0Q`3oool00`00o`00oooo0?ooo`3o0?ooo`<0
oooo00030?ooo`@000001P3oool2000000L0oooo100000070?ooo`030000003oool0oooo08@0oooo
00D0o`3o0?ooo`3oool0oooo003o003o0?ooo`@0oooo00020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool2000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo08D0oooo0P3o0?l20?ooo`800?l0o`3oool20?ooo`000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08L0oooo0P3o0?l20?ooo`03003o003o
ool0oooo0?h0oooo00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool2
000000<0oooo00<000000?ooo`3oool0103oool3000008T0oooo00<0o`3o0?ooo`00o`00o`3oool1
0?ooo`000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`0000000P0000070?ooo`030000003oool0oooo08`0oooo00<00?l00?ooo`3oool0o@3oool00080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0S@3oool00`00o`00oooo0?ooo`3l0?ooo`000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`2=0?ooo`03003o003oool0oooo0?`0oooo00020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08h0oooo00<0
0?l00?ooo`3oool0n`3oool000<0oooo1000000A0?ooo`<000001P3oool00`000000oooo0?ooo`2?
0?ooo`03003o003o0?l0oooo0?X0oooo000Q0?ooo`030000003oool0oooo08l0oooo00@00?l00?oo
o`3o0?l0o`3on@3oool00240oooo00<000000?ooo`3oool0T03oool01000o`00oooo0?ooo`3o0?oh
0?ooo`008@3oool00`000000oooo0?ooo`2A0?ooo`03003o003oool0oooo0?P0oooo000Q0?ooo`80
0000T`3oool00`00o`00oooo0?ooo`3g0?ooo`008@3oool00`000000oooo0?ooo`2C0?ooo`<00?l0
0P3oool8003o0>`0oooo000Q0?ooo`030000003oool0oooo09D0oooo0`00o`020?ooo`030?l0o`3o
ool0oooo00<0oooo00<00?l00?ooo`3oool0j@3oool00240oooo00<000000?ooo`3oool0V`3oool2
0?l0o`@0oooo00<00?l00?ooo`3oool0j03oool00240oooo00<000000?ooo`3oool0W@3oool20?l0
o`<0oooo00<00?l00?ooo`3oool0i`3oool00240oooo00<000000?ooo`3oool0X`3oool00`00o`00
oooo0?ooo`3V0?ooo`008@3oool00`000000oooo0?ooo`2S0?ooo`03003o003oool0oooo0>H0oooo
000Q0?ooo`030000003oool0oooo0:<0oooo00<0o`3o003o003oool0iP3oool00240oooo0P00002U
0?ooo`030?l0o`00o`00oooo0>D0oooo000Q0?ooo`030000003oool0oooo0:D0oooo00<00?l00?l0
o`3o0?l0i03oool00240oooo00<000000?ooo`3oool0YP3oool00`00o`00oooo0?l0o`3S0?ooo`00
8@3oool00`000000oooo0?ooo`2W0?ooo`03003o003oool0oooo0>80oooo000Q0?ooo`030000003o
ool0oooo0:P0oooo00<00?l00?ooo`3oool0h@3oool00240oooo00<000000?ooo`3oool0Z03oool0
0`00o`00oooo0?ooo`020?ooo`030?l0o`3oool0oooo0=`0oooo000Q0?ooo`030000003oool0oooo
0:T0oooo00<00?l00?ooo`3oool00P3oool00`3o0?l0oooo0?ooo`3K0?ooo`008@3oool00`000000
oooo0?ooo`2Z0?ooo`800?l00`3oool20?l0o`80oooo1000o`3E0?ooo`008@3oool00`000000oooo
0?ooo`2[0?ooo`P00?l00`3oool2003o0=@0oooo000Q0?ooo`800000/`3oool00`3o0?l0oooo0?oo
o`030?ooo`03003o003oool0oooo0=40oooo000Q0?ooo`030000003oool0oooo0;T0oooo00<00?l0
0?ooo`3oool0d03oool00240oooo00<000000?ooo`3oool0^P3oool00`00o`00oooo0?ooo`3?0?oo
o`008@3oool00`000000oooo0?ooo`2g0?ooo`050?l0o`3oool0oooo0?ooo`00o`00d03oool00240
oooo00<000000?ooo`3oool0^03oool20?l0o`030?ooo`00o`00oooo0<l0oooo00030?ooo`@00000
1P3oool2000000H0oooo100000080?ooo`030000003oool0oooo0;X0oooo0P3o0?l00`00o`00oooo
0?ooo`3=0?ooo`000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P00
00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`2l0?ooo`030?l0o`00o`00oooo0<d0oooo00020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0_P3oool00`00o`00oooo0?ooo`3;0?ooo`000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0;l0oooo00<00?l00?ooo`3oool0bP3oool00080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0;0?ooo`@00000203oool300000;l0oooo00@00?l00?ooo`3o
ool0o`3ob@3oool00080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`300?ooo`03
003o003oool0oooo0080o`3oa`3oool00080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`310?ooo`04003o003oool0oooo0?ooo`80o`3oa@3oool00080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`320?ooo`03003o003oool0oooo0080oooo00@0o`3o0?ooo`3oool0
oooo0`00o`2n0?ooo`000`3oool4000000h0oooo100000080?ooo`030000003oool0oooo0<<0oooo
0P00o`030?ooo`@00?l00P3oool2003o0;`0oooo000Q0?ooo`030000003oool0oooo0<D0oooo0`00
o`080?ooo`03003o003oool0oooo0;T0oooo000Q0?ooo`030000003oool0oooo0<`0oooo00<0o`3o
0?ooo`3oool00P3oool00`00o`00oooo0?ooo`2h0?ooo`008@3oool00`000000oooo0?ooo`3=0?oo
o`80o`3o0`3oool00`00o`00oooo0?ooo`2g0?ooo`008@3oool200000=00oooo0P3o0?l20?ooo`03
003o003oool0oooo0;H0oooo000Q0?ooo`030000003oool0oooo0=40oooo00@0o`3o0?ooo`3oool0
0?l0]`3oool00240oooo00<000000?ooo`3oool0e03oool00`00o`00oooo0?ooo`2e0?ooo`008@3o
ool00`000000oooo0?ooo`3E0?ooo`03003o003oool0oooo0;@0oooo000Q0?ooo`030000003oool0
oooo0=H0oooo00<00?l00?ooo`3oool0/`3oool00240oooo00<000000?ooo`3oool0e`3oool00`00
o`00o`3o0?ooo`2b0?ooo`008@3oool00`000000oooo0?ooo`3G0?ooo`04003o003oool0o`3o0?l0
ok40oooo000Q0?ooo`030000003oool0oooo0=P0oooo00<00?l00?ooo`3oool00P3o0?n_0?ooo`00
8@3oool00`000000oooo0?ooo`3I0?ooo`03003o003oool0oooo0;00oooo000Q0?ooo`800000f`3o
ool00`00o`00oooo0?ooo`050?ooo`D00?l0Y@3oool00240oooo00<000000?ooo`3oool0f`3oool7
003o00D0oooo0P00o`2S0?ooo`008@3oool00`000000oooo0?ooo`3R0?ooo`80o`3o1@3oool00`00
o`00oooo0?ooo`2P0?ooo`008@3oool00`000000oooo0?ooo`3T0?ooo`80o`3o103oool00`00o`00
oooo0?ooo`2O0?ooo`008@3oool00`000000oooo0?ooo`3V0?ooo`030?l0o`3oool0oooo0080oooo
00<00?l00?ooo`3oool0WP3oool00240oooo00<000000?ooo`3oool0j`3oool00`00o`00oooo0?oo
o`2N0?ooo`008@3oool00`000000oooo0?ooo`3/0?ooo`03003o003oool0oooo09d0oooo000Q0?oo
o`030000003oool0oooo0>/0oooo00<0o`3o003o003o0?l0WP3oool00240oooo0P00003^0?ooo`03
003o003o0?l0o`3o09`0oooo000Q0?ooo`030000003oool0oooo0>h0oooo00@00?l00?ooo`3o0?l0
o`3oVP3oool00240oooo00<000000?ooo`3oool0k`3oool00`00o`00oooo0?ooo`2J0?ooo`008@3o
ool00`000000oooo0?ooo`3`0?ooo`03003o003oool0oooo09T0oooo000Q0?ooo`030000003oool0
oooo0?00oooo00<00?l00?ooo`3oool00`3oool00`3o0?l0oooo0?ooo`2C0?ooo`008@3oool00`00
0000oooo0?ooo`3a0?ooo`03003o003oool0oooo00<0oooo0P3o0?l30?ooo`800?l0SP3oool001@0
oooo1`0000060?ooo`030000003oool0oooo0?80oooo0P00o`050?ooo`<00?l00P3oool3003o08/0
oooo000G0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0m03oool5003o0080oooo
00<0o`3o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`280?ooo`005`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0?l0oooo0`3oool00`00o`00oooo0?ooo`270?ooo`005`3oool0
0`000000oooo0?ooo`070?ooo`<00000o`3oool40?ooo`03003o003oool0oooo08H0oooo000G0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3oool10?ooo`040?l0o`3oool0oooo
003o08P0oooo000G0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3oool20?oo
o`80o`3o00<0oooo003o003oool0QP3oool001L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`3o0?ooo`@0oooo0P3o0?l00`00o`00oooo0?ooo`240?ooo`005@3oool3000000T0oooo
00<000000?ooo`3oool0o`3oool60?ooo`03003o003o0?l0oooo08@0oooo000G0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0o`3oool70?ooo`03003o003oool0oooo08<0oooo000Q
0?ooo`030000003oool0oooo0?l0oooo203oool00`00o`00oooo0?ooo`220?ooo`008@3oool00`00
0000oooo0?ooo`3o0?ooo`T0oooo00<00?l00?ooo`3oool00P3o0?mo0?ooo`008@3oool00`000000
oooo0?ooo`3o0?ooo`X0oooo00D00?l00?ooo`3oool0oooo0?l0o`1n0?ooo`008@3oool200000?l0
oooo303oool01000o`00oooo0?ooo`3oool20?l0o`@0oooo0P00o`1f0?ooo`008@3oool00`000000
oooo0?ooo`3o0?ooo``0oooo00<00?l00?ooo`3oool00P3oool00`3o0?l00?l0003o0002003o0003
0?ooo`00o`000?l007@0oooo000Q0?ooo`030000003oool0oooo0?l0oooo3@3oool5003o00L0oooo
0P00o`1b0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooaH0oooo00<0o`3o0?ooo`3oool00P3o
ool00`00o`00oooo0?ooo`1_0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooaL0oooo0P3o0?l2
0?ooo`03003o003oool0oooo06l0oooo000Q0?ooo`030000003oool0oooo0?l0oooo6@3oool20?l0
o`030?ooo`00o`00oooo06l0oooo000Q0?ooo`030000003oool0oooo0?l0oooo6`3oool20?l0o`03
003o003oool0oooo06d0oooo000Q0?ooo`030000003oool0oooo0?l0oooo7P3oool00`00o`00oooo
0?ooo`1/0?ooo`008@3oool200000?l0oooo803oool00`00o`00oooo0?ooo`1[0?ooo`008@3oool0
0`000000oooo0?ooo`3o0?oooal0oooo00<00?l00?ooo`3o0?l0J`3oool00240oooo00<000000?oo
o`3oool0o`3ooolP0?ooo`04003o003oool0o`3o0?l0ofT0oooo000Q0?ooo`030000003oool0oooo
0?l0oooo8@3oool00`00o`00oooo0?ooo`020?l0ofL0oooo000Q0?ooo`030000003oool0oooo0?l0
oooo8P3oool01@00o`00oooo0?ooo`3oool0o`3o06H0oooo000Q0?ooo`030000003oool0oooo0?l0
oooo8`3oool00`00o`00oooo0?ooo`060?ooo`D00?l0G03oool00240oooo00<000000?ooo`3oool0
o`3ooolS0?ooo`800?l0103oool3003o00@0oooo0P00o`1K0?ooo`008@3oool00`000000oooo0?oo
o`3o0?ooobD0oooo1@00o`020?ooo`80o`3o103oool00`00o`00oooo0?ooo`1H0?ooo`008@3oool0
0`000000oooo0?ooo`3o0?ooobh0oooo00<0o`3o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`1G
0?ooo`008@3oool200000?l0oooo<03oool20?l0o`<0oooo00<00?l00?ooo`3oool0EP3oool00240
oooo00<000000?ooo`3oool0o`3ooola0?ooo`050?l0o`3oool0oooo0?ooo`00o`00E`3oool00240
oooo00<000000?ooo`3oool0o`3ooolf0?ooo`03003o003oool0oooo05@0oooo000Q0?ooo`030000
003oool0oooo0?l0oooo=P3oool00`00o`00oooo0?ooo`1D0?ooo`008@3oool00`000000oooo0?oo
o`3o0?ooocL0oooo00<00?l00?l0o`3oool0D`3oool00080oooo1`0000040?ooo`8000001@3oool6
000000L0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`03003o003o0?l0o`3o0580oooo00050?oo
o`030000003oool0oooo00D0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`3o0?ooocP0oooo00<00?l00?ooo`3oool00P3o0?m@0?oo
o`001@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0o`3oooli0?ooo`03003o003oool0oooo0540oooo00050?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0203oool300000?l0oooo>P3oool00`00o`00oooo0?ooo`1@0?ooo`001@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3o
oolk0?ooo`800?l0103oool00`3o0?l0oooo003o0006003o04<0oooo00050?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?oooc`0oooo1`00o`00
0`3o0?l0oooo0?ooo`030?ooo`03003o003oool0oooo0440oooo00050?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0?l0ooooA03oool20?l0o`@0oooo00<00?l00?ooo`3oool0@03oool000<0oooo0`00000>0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooodH0
oooo00<0o`3o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`0o0?ooo`001@3oool00`000000oooo
0?ooo`0=0?ooo`@00000203oool00`000000oooo0?ooo`3o0?oood`0oooo00<00?l00?ooo`3oool0
?P3oool00240oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030?l0o`00o`00oooo03h0oooo000Q
0?ooo`030000003oool0oooo0?l0ooooC@3oool00`3o0?l00?l00?ooo`0m0?ooo`008@3oool00`00
0000oooo0?ooo`3o0?ooodl0oooo00<00?l00?l0o`3oool0>`3oool00240oooo0P00003o0?oooe00
oooo00<00?l00?ooo`3o0?l0>`3oool00240oooo00<000000?ooo`3oool0o`3ooom@0?ooo`03003o
003oool0oooo03X0oooo000Q0?ooo`030000003oool0oooo0?l0ooooD@3oool00`00o`00oooo0?oo
o`0i0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooe40oooo00<00?l00?ooo`3oool00P3oool2
0?l0ocD0oooo000Q0?ooo`030000003oool0oooo0?l0ooooDP3oool00`00o`00oooo0?ooo`030?oo
o`<0o`3o00<0oooo003o0000o`000`00o`0/0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooe<0
oooo0`00o`030?ooo`<00?l000<0o`3o0?ooo`3oool00P3oool2003o02X0oooo000Q0?ooo`030000
003oool0oooo0?l0ooooE@3oool4003o00T0oooo00<00?l00?ooo`3oool0:03oool00240oooo00<0
00000?ooo`3oool0o`3ooomS0?ooo`03003o003oool0oooo02L0oooo000Q0?ooo`030000003oool0
oooo0?l0ooooH@3oool0103o0?l0oooo0?ooo`00o`0X0?ooo`008@3oool200000?l0ooooH`3oool2
0?l0o`030?ooo`00o`00oooo02H0oooo000Q0?ooo`030000003oool0oooo0?l0ooooI03oool00`3o
0?l00?l00?ooo`0V0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooofH0oooo00<00?l00?ooo`3o
ool0903oool00240oooo00<000000?ooo`3oool0o`3ooomW0?ooo`03003o003oool0oooo02<0oooo
000Q0?ooo`030000003oool0oooo0?l0ooooJ03oool01@00o`00oooo0?ooo`3oool0o`3o0200oooo
000Q0?ooo`030000003oool0oooo0?l0ooooJ@3oool01000o`00oooo0?ooo`3oool20?l0oah0oooo
000Q0?ooo`030000003oool0oooo0?l0ooooJP3oool00`00o`00oooo0?ooo`020?ooo`80o`3o703o
ool00240oooo00<000000?ooo`3oool0o`3ooom[0?ooo`03003o003oool0oooo00<0oooo00<0o`3o
0?ooo`3oool01@00o`0D0?ooo`008@3oool200000?l0ooooK@3oool2003o00<0oooo0`00o`050?oo
o`03003o003oool0oooo0140oooo000Q0?ooo`030000003oool0oooo0?l0ooooK@3oool4003o00T0
oooo00<00?l00?ooo`3oool0403oool00240oooo00<000000?ooo`3oool0o`3ooomf0?ooo`80o`3o
0`3oool00`00o`00oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooogP0oooo0`3o
0?l00`3oool00?l0003o000?0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooog/0oooo0P3o0?l@
0?ooo`000P3oool7000000@0oooo0P0000070?ooo`@000001`3oool00`000000oooo0?ooo`3o0?oo
ohd0oooo00050?ooo`030000003oool0oooo00D0oooo0P0000090?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0o`3ooon=0?ooo`001@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooon=0?ooo`001@3oool00`000000oooo0?oo
o`0<0?ooo`H000001`3oool00`000000oooo0?ooo`3o0?ooohd0oooo00050?ooo`030000003oool0
oooo00d0oooo00@000000?ooo`3oool00000203oool300000?l0ooooS@3oool000D0oooo00<00000
0?ooo`3oool03@3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0?l0ooooS@3o
ool000D0oooo00<000000?ooo`3oool03P3oool00`000000oooo000000080?ooo`030000003oool0
oooo0?l0ooooS@3oool000<0oooo0`00000@0?ooo`030000003oool000000?l0ooooV03oool000D0
oooo00<000000?ooo`3oool03`3oool200000?l0ooooV03oool00?l0oooo/@3oool00?l0oooo/@3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-8.66564, -0.10781, \
0.391514, 0.00872825}},
  CellTags->"Examples"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[31]=",
  CellTags->"Examples"]
}, Open  ]],

Cell["\<\
 Here are assume multiples intake: 3 Bq the at the beginning, that is \[Tau] \
= 0, follow 5 Bq the third day {\[Tau] = 3}, 6  Bq at \[Tau] =5. Then the \
lung retention starting when ceased the intake will be:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(inputmultiple[t1_] = 
      LungsRetention[{{3, \ 0}, \ {5, \ 3}, \ {6, \ 5}}, AMADAdultW[5], S, \ 
        t1, \ 0, \ IntakeType \[Rule] "\<MultiInputs\>"]\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \(0.00006025968377435659`\ \[ExponentialE]\^\(\(-110.1`\)\ t1\) + 
      0.000047841187976120636`\ \[ExponentialE]\^\(\(-102.1`\)\ t1\) + 
      0.00006178551656783535`\ \[ExponentialE]\^\(\(-100.13`\)\ t1\) + 
      0.0000967075629467462`\ \[ExponentialE]\^\(\(-100.11999999999999`\)\ t1\
\) - 4.87890977618477`*^-19\ \[ExponentialE]\^\(\(-100.11`\)\ t1\) + 
      0.0001912127307631406`\ \[ExponentialE]\^\(\(-100.101`\)\ t1\) + 
      0.0000265433017493516`\ \[ExponentialE]\^\(\(-100.10012`\)\ t1\) + 
      6.514855188247256`*^-6\ \[ExponentialE]\^\(\(-100.1`\)\ t1\) + 
      0.06032000388173764`\ \[ExponentialE]\^\(\(-10.0001`\)\ t1\) + 
      0.048620949953282915`\ \[ExponentialE]\^\(\(-2.0001`\)\ t1\) + 
      0.13697865709077264`\ \[ExponentialE]\^\(\(-0.0301`\)\ t1\) + 
      0.2180702598855114`\ \[ExponentialE]\^\(\(-0.0201`\)\ t1\) + 
      3.727561621969548`*^-19\ \[ExponentialE]\^\(\(-0.0101`\)\ t1\) + 
      0.44573420970293176`\ \[ExponentialE]\^\(\(-0.0011`\)\ t1\) + 
      0.061972021577385926`\ \[ExponentialE]\^\(\(-0.00022`\)\ t1\) + 
      0.015213828593859231`\ \[ExponentialE]\^\(\(-0.0001`\)\ t1\)\)], \
"Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[inputmultiple[t], \ {t, 0.1, \ 100}]\)], "Input",
  CellLabel->"In[33]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 -0.687809 1.37491 [
[.21429 -0.01285 -6 -9 ]
[.21429 -0.01285 6 0 ]
[.40476 -0.01285 -6 -9 ]
[.40476 -0.01285 6 0 ]
[.59524 -0.01285 -6 -9 ]
[.59524 -0.01285 6 0 ]
[.78571 -0.01285 -6 -9 ]
[.78571 -0.01285 6 0 ]
[.97619 -0.01285 -9 -9 ]
[.97619 -0.01285 9 0 ]
[.01131 .13714 -18 -4.5 ]
[.01131 .13714 0 4.5 ]
[.01131 .27463 -18 -4.5 ]
[.01131 .27463 0 4.5 ]
[.01131 .41212 -18 -4.5 ]
[.01131 .41212 0 4.5 ]
[.01131 .54961 -18 -4.5 ]
[.01131 .54961 0 4.5 ]
[ 0 -0.00035 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 -0.00035 m
.21429 .0059 L
s
[(20)] .21429 -0.01285 0 1 Mshowa
.40476 -0.00035 m
.40476 .0059 L
s
[(40)] .40476 -0.01285 0 1 Mshowa
.59524 -0.00035 m
.59524 .0059 L
s
[(60)] .59524 -0.01285 0 1 Mshowa
.78571 -0.00035 m
.78571 .0059 L
s
[(80)] .78571 -0.01285 0 1 Mshowa
.97619 -0.00035 m
.97619 .0059 L
s
[(100)] .97619 -0.01285 0 1 Mshowa
.125 Mabswid
.07143 -0.00035 m
.07143 .0034 L
s
.11905 -0.00035 m
.11905 .0034 L
s
.16667 -0.00035 m
.16667 .0034 L
s
.2619 -0.00035 m
.2619 .0034 L
s
.30952 -0.00035 m
.30952 .0034 L
s
.35714 -0.00035 m
.35714 .0034 L
s
.45238 -0.00035 m
.45238 .0034 L
s
.5 -0.00035 m
.5 .0034 L
s
.54762 -0.00035 m
.54762 .0034 L
s
.64286 -0.00035 m
.64286 .0034 L
s
.69048 -0.00035 m
.69048 .0034 L
s
.7381 -0.00035 m
.7381 .0034 L
s
.83333 -0.00035 m
.83333 .0034 L
s
.88095 -0.00035 m
.88095 .0034 L
s
.92857 -0.00035 m
.92857 .0034 L
s
.25 Mabswid
0 -0.00035 m
1 -0.00035 L
s
.02381 .13714 m
.03006 .13714 L
s
[(0.6)] .01131 .13714 1 0 Mshowa
.02381 .27463 m
.03006 .27463 L
s
[(0.7)] .01131 .27463 1 0 Mshowa
.02381 .41212 m
.03006 .41212 L
s
[(0.8)] .01131 .41212 1 0 Mshowa
.02381 .54961 m
.03006 .54961 L
s
[(0.9)] .01131 .54961 1 0 Mshowa
.125 Mabswid
.02381 .02714 m
.02756 .02714 L
s
.02381 .05464 m
.02756 .05464 L
s
.02381 .08214 m
.02756 .08214 L
s
.02381 .10964 m
.02756 .10964 L
s
.02381 .16463 m
.02756 .16463 L
s
.02381 .19213 m
.02756 .19213 L
s
.02381 .21963 m
.02756 .21963 L
s
.02381 .24713 m
.02756 .24713 L
s
.02381 .30212 m
.02756 .30212 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35712 m
.02756 .35712 L
s
.02381 .38462 m
.02756 .38462 L
s
.02381 .43962 m
.02756 .43962 L
s
.02381 .46711 m
.02756 .46711 L
s
.02381 .49461 m
.02756 .49461 L
s
.02381 .52211 m
.02756 .52211 L
s
.02381 .57711 m
.02756 .57711 L
s
.02381 .6046 m
.02756 .6046 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02476 .60332 m
.02594 .56821 L
.027 .55224 L
.02824 .54075 L
.0294 .53297 L
.03148 .52282 L
.03373 .5149 L
.03621 .50838 L
.03884 .50298 L
.04355 .49531 L
.06336 .47032 L
.10545 .4231 L
.14325 .38464 L
.1835 .34735 L
.22223 .31468 L
.26341 .28305 L
.30308 .25531 L
.34124 .2309 L
.38184 .20713 L
.42093 .18618 L
.46247 .1658 L
.5025 .14781 L
.54101 .13188 L
.58197 .11627 L
.62142 .10241 L
.65935 .09008 L
.69974 .07791 L
.73861 .06704 L
.77993 .05632 L
.81973 .04672 L
.85802 .03809 L
.89877 .02952 L
.93799 .02179 L
.97571 .0148 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[33]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00IP3oool6000000@0oooo100000100?ooo`@00000103oool400000400oooo100000040?oo
o`@00000@03oool4000000D0oooo1000000i0?ooo`L000000`3oool4000000D0oooo100000070?oo
o`00IP3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`00I`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool006P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03/0oooo1P0000030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0?03oool2000000<0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`040?ooo`00J@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0?03oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0?03oool00`000000oooo00000002000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0m0?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo03T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`00JP3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?03oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool0103oool006H0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo000000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool0103oool006H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo000000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0g0?ooo`<000001@3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`00
I`3oool4000000D0oooo100000110?ooo`8000001@3oool400000480oooo0`0000030?ooo`@00000
@03oool4000000D0oooo1000000l0?ooo`030000003oool0oooo00@0oooo100000050?ooo`@00000
1`3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool001P0ooooo`00002B000000L0
oooo000R0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0>0?ooo`008P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool03P3oool00280oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo00h0oooo000R0?ooo`030000003oool0oooo0?l0ooooS03oool00280
oooo00<000000?ooo`3oool0o`3ooon<0?ooo`008P3oool00`000000oooo0?ooo`3o0?ooogT0oooo
0`00000@0?ooo`008P3oool00`000000oooo0?ooo`3o0?ooog@0oooo1@00000C0?ooo`008P3oool0
0`000000oooo0?ooo`3o0?ooofh0oooo1P00000H0?ooo`008P3oool00`000000oooo0?ooo`3o0?oo
ofT0oooo1@00000N0?ooo`008P3oool00`000000oooo0?ooo`3o0?ooof@0oooo1@00000S0?ooo`00
8P3oool200000?l0ooooH03oool5000002P0oooo000R0?ooo`030000003oool0oooo0?l0ooooFP3o
ool5000002d0oooo000R0?ooo`030000003oool0oooo0?l0ooooEP3oool400000380oooo000R0?oo
o`030000003oool0oooo0?l0ooooDP3oool4000003H0oooo000R0?ooo`030000003oool0oooo0?l0
ooooCP3oool4000003X0oooo000R0?ooo`030000003oool0oooo0?l0ooooB@3oool5000003h0oooo
000R0?ooo`030000003oool0oooo0?l0ooooA03oool5000004<0oooo000R0?ooo`030000003oool0
oooo0?l0oooo?`3oool5000004P0oooo000R0?ooo`030000003oool0oooo0?l0oooo>`3oool40000
04d0oooo000R0?ooo`030000003oool0oooo0?l0oooo=`3oool400000540oooo000R0?ooo`030000
003oool0oooo0?l0oooo<`3oool4000005D0oooo000R0?ooo`800000o`3oool`0?ooo`@00000F@3o
ool00280oooo00<000000?ooo`3oool0o`3oool[0?ooo`@00000G@3oool00280oooo00<000000?oo
o`3oool0o`3ooolW0?ooo`@00000H@3oool00280oooo00<000000?ooo`3oool0o`3ooolS0?ooo`@0
0000I@3oool00280oooo00<000000?ooo`3oool0o`3ooolO0?ooo`@00000J@3oool00280oooo00<0
00000?ooo`3oool0o`3ooolK0?ooo`@00000K@3oool00280oooo00<000000?ooo`3oool0o`3ooolG
0?ooo`@00000L@3oool00280oooo00<000000?ooo`3oool0o`3ooolC0?ooo`@00000M@3oool00280
oooo00<000000?ooo`3oool0o`3oool?0?ooo`@00000N@3oool00280oooo00<000000?ooo`3oool0
o`3oool;0?ooo`@00000O@3oool00280oooo00<000000?ooo`3oool0o`3oool80?ooo`<00000P@3o
ool00280oooo0P00003o0?ooo`H0oooo0`0000240?ooo`008P3oool00`000000oooo0?ooo`3o0?oo
o`40oooo100000270?ooo`008P3oool00`000000oooo0?ooo`3m0?ooo`<00000R`3oool00280oooo
00<000000?ooo`3oool0nP3oool3000008h0oooo000R0?ooo`030000003oool0oooo0?L0oooo0`00
002A0?ooo`008P3oool00`000000oooo0?ooo`3d0?ooo`<00000U03oool00280oooo00<000000?oo
o`3oool0l@3oool3000009L0oooo000R0?ooo`030000003oool0oooo0>h0oooo0`00002J0?ooo`00
8P3oool00`000000oooo0?ooo`3[0?ooo`<00000W@3oool00280oooo00<000000?ooo`3oool0j@3o
ool200000:00oooo000R0?ooo`030000003oool0oooo0>H0oooo0`00002R0?ooo`008P3oool20000
0>@0oooo0`00002U0?ooo`008P3oool00`000000oooo0?ooo`3Q0?ooo`800000Z03oool00280oooo
00<000000?ooo`3oool0gP3oool300000:X0oooo000R0?ooo`030000003oool0oooo0=/0oooo0`00
002]0?ooo`008P3oool00`000000oooo0?ooo`3I0?ooo`800000/03oool00280oooo00<000000?oo
o`3oool0eP3oool300000;80oooo000R0?ooo`030000003oool0oooo0=<0oooo0`00002e0?ooo`00
8P3oool00`000000oooo0?ooo`3A0?ooo`800000^03oool000@0oooo100000060?ooo`8000001`3o
ool4000000L0oooo00<000000?ooo`3oool0cP3oool300000;X0oooo00030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool2000000H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0</0oooo0`00002m0?ooo`000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0<T0oooo0P0000300?ooo`000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo0P0000030?ooo`030000003oool0oooo00@0
oooo0`0000360?ooo`<00000`P3oool000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool00000008000001`3oool00`000000oooo0?ooo`330?ooo`<00000
a@3oool000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0`@3oool200000<P0oooo00030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0;h0oooo0`00003:0?ooo`000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2l0?ooo`800000c@3oool000@0
oooo1000000A0?ooo`<000001P3oool00`000000oooo0?ooo`2j0?ooo`800000c`3oool00280oooo
00<000000?ooo`3oool0^03oool200000=40oooo000R0?ooo`030000003oool0oooo0;H0oooo0P00
003C0?ooo`008P3oool00`000000oooo0?ooo`2d0?ooo`800000e@3oool00280oooo00<000000?oo
o`3oool0/P3oool200000=L0oooo000R0?ooo`030000003oool0oooo0;00oooo0P00003I0?ooo`00
8P3oool200000:l0oooo0P00003K0?ooo`008P3oool00`000000oooo0?ooo`2/0?ooo`800000g@3o
ool00280oooo00<000000?ooo`3oool0ZP3oool200000=l0oooo000R0?ooo`030000003oool0oooo
0:P0oooo0P00003Q0?ooo`008P3oool00`000000oooo0?ooo`2V0?ooo`800000h`3oool00280oooo
00<000000?ooo`3oool0Y03oool200000>D0oooo000R0?ooo`030000003oool0oooo0:80oooo0P00
003W0?ooo`008P3oool00`000000oooo0?ooo`2P0?ooo`800000j@3oool00280oooo00<000000?oo
o`3oool0WP3oool200000>/0oooo000R0?ooo`030000003oool0oooo09`0oooo0P00003]0?ooo`00
8P3oool00`000000oooo0?ooo`2J0?ooo`800000k`3oool00280oooo0P00002I0?ooo`800000l@3o
ool00280oooo00<000000?ooo`3oool0UP3oool200000?<0oooo000R0?ooo`030000003oool0oooo
09@0oooo0P00003e0?ooo`008P3oool00`000000oooo0?ooo`2B0?ooo`800000m`3oool00280oooo
00<000000?ooo`3oool0T03oool200000?T0oooo000R0?ooo`030000003oool0oooo08h0oooo0P00
003k0?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`800000o@3oool00280oooo00<000000?oo
o`3oool0RP3oool200000?l0oooo000R0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3o
ool0o`3oool00280oooo00<000000?ooo`3oool0Q`3oool200000?l0oooo0`3oool00280oooo00<0
00000?ooo`3oool0Q@3oool200000?l0oooo1@3oool00280oooo0P0000250?ooo`030000003oool0
oooo0?l0oooo1@3oool00280oooo00<000000?ooo`3oool0PP3oool200000?l0oooo203oool00280
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`3o0?ooo`P0oooo000R0?ooo`030000
003oool0oooo07l0oooo0P00003o0?ooo`/0oooo000R0?ooo`030000003oool0oooo07d0oooo0P00
003o0?ooo`d0oooo000R0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0o`3oool=
0?ooo`008P3oool00`000000oooo0?ooo`1j0?ooo`800000o`3oool@0?ooo`008P3oool00`000000
oooo0?ooo`1h0?ooo`800000o`3ooolB0?ooo`008P3oool00`000000oooo0?ooo`1f0?ooo`800000
o`3ooolD0?ooo`008P3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0?l0oooo503o
ool00280oooo00<000000?ooo`3oool0L`3oool200000?l0oooo5`3oool00280oooo0P00001b0?oo
o`800000o`3ooolI0?ooo`008P3oool00`000000oooo0?ooo`1_0?ooo`800000o`3ooolK0?ooo`00
8P3oool00`000000oooo0?ooo`1]0?ooo`800000o`3ooolM0?ooo`008P3oool00`000000oooo0?oo
o`1/0?ooo`030000003oool0oooo0?l0oooo7@3oool00280oooo00<000000?ooo`3oool0JP3oool2
00000?l0oooo803oool00280oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`3o0?oo
ob00oooo000R0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`00
8P3oool00`000000oooo0?ooo`1V0?ooo`800000o`3ooolT0?ooo`00103oool4000000H0oooo0P00
00080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?oo
o`3o0?ooob@0oooo00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2
000000P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo0?l0oooo9@3oool000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0HP3oool200000?l0oooo:03oool000<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0
oooo0`00001Q0?ooo`030000003oool0oooo0?l0oooo:03oool000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
H03oool00`000000oooo0?ooo`3o0?ooobT0oooo00030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo05h0oooo0P00
003o0?ooob`0oooo00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0o`3oool/
0?ooo`000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05`0oooo00<000000?oo
o`3oool0o`3oool]0?ooo`00103oool4000000d0oooo1P0000070?ooo`030000003oool0oooo05X0
oooo0P00003o0?oooc00oooo000R0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0
o`3oool`0?ooo`008P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0?l0oooo<@3o
ool00280oooo00<000000?ooo`3oool0EP3oool200000?l0oooo=03oool00280oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`3o0?oooc@0oooo000R0?ooo`030000003oool0oooo05@0
oooo00<000000?ooo`3oool0o`3ooole0?ooo`008P3oool2000005<0oooo0P00003o0?ooocP0oooo
000R0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0o`3ooolh0?ooo`008P3oool0
0`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0?l0oooo>@3oool00280oooo00<000000?oo
o`3oool0CP3oool200000?l0oooo?03oool00280oooo00<000000?ooo`3oool0C@3oool00`000000
oooo0?ooo`3o0?oooc`0oooo000R0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0
o`3ooolm0?ooo`008P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0oooo?P3o
ool00280oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`3o0?ooocl0oooo000R0?oo
o`030000003oool0oooo04P0oooo0P00003o0?oood80oooo000R0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool0o`3ooom20?ooo`008P3oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo0?l0oooo@`3oool00280oooo0P0000160?ooo`030000003oool0oooo0?l0ooooA03o
ool00280oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3o0?ooodD0oooo000R0?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool0o`3ooom60?ooo`008P3oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo0?l0ooooA`3oool00280oooo00<000000?ooo`3oool0
@03oool200000?l0ooooBP3oool00280oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`3o0?ooodX0oooo000R0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0o`3ooom;
0?ooo`008P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0?l0ooooC03oool00280
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`3o0?ooodd0oooo000R0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`008P3oool00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo0?l0ooooC`3oool00280oooo0P00000j0?ooo`030000003oool0
oooo0?l0ooooD03oool00280oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`3o0?oo
oe40oooo000R0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0o`3ooomB0?ooo`00
8P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0?l0ooooD`3oool00280oooo00<0
00000?ooo`3oool0=03oool200000?l0ooooEP3oool00280oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`3o0?oooeH0oooo000R0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool0o`3ooomG0?ooo`008P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0?l0
ooooF03oool00280oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`3o0?oooeT0oooo
000R0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`008P3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0ooooF`3oool00280oooo0P00000^0?oo
o`030000003oool0oooo0?l0ooooG03oool00280oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`3o0?oooed0oooo000R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
o`3ooomN0?ooo`008P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0ooooG`3o
ool00280oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooof00oooo000R0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`008P3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo0?l0ooooHP3oool00280oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`3o0?ooof<0oooo00040?ooo`@000001P3oool2000000H0oooo1000
00080?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0o`3ooomT0?ooo`000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo0?l0ooooI@3oool000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0?l0ooooIP3oool000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool300000280
oooo00<000000?ooo`3oool0o`3ooomW0?ooo`000`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00/0oooo100000080?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
o`3ooomX0?ooo`000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0o`3ooomY0?ooo`000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0o`3ooomZ0?ooo`000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0o`3ooom[0?ooo`00103oool4000000h0
oooo100000080?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0o`3ooom/0?ooo`00
8P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0ooooK@3oool00280oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`3o0?ooofh0oooo000R0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0o`3ooom_0?ooo`008P3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo0?l0ooooL03oool00280oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`3o0?ooog00oooo000R0?ooo`8000006@3oool00`000000oooo0?ooo`3o0?ooog40oooo
000R0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0o`3ooomb0?ooo`008P3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0ooooL`3oool00280oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`3o0?ooog@0oooo000R0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0o`3ooome0?ooo`008P3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo0?l0ooooMP3oool00280oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`3o0?ooogL0oooo000R0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooomh
0?ooo`008P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooN03oool00280
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?ooogT0oooo000R0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooomj0?ooo`008P3oool2000000l0oooo00<0
00000?ooo`3oool0o`3ooomk0?ooo`008P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0?l0ooooO03oool00280oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?oo
ogd0oooo000R0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooomn0?ooo`00
8P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooOP3oool00280oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?ooogl0oooo000R0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0o`3ooon00?ooo`008P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0?l0ooooP@3oool00280oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`3o0?oooh80oooo000R0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
o`3ooon20?ooo`008P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooP`3o
ool00280oooo0P0000060?ooo`030000003oool0oooo0?l0ooooQ03oool00280oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`3o0?ooohD0oooo000R0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0o`3ooon50?ooo`008P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0?l0ooooQP3oool00280oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`3o0?ooohH0oooo000R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooon7
0?ooo`008P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooQ`3oool00280
oooo00D000000?ooo`3oool0oooo0000003o0?ooohX0oooo000R0?ooo`050000003oool0oooo0?oo
o`000000o`3ooon:0?ooo`008P3oool01@000000oooo0?ooo`3oool000000?l0ooooRP3oool00280
oooo00@000000?ooo`3oool00000o`3ooon;0?ooo`008P3oool2000000030?ooo`000000oooo0?l0
ooooRP3oool00280oooo00@000000?ooo`3oool00000o`3ooon;0?ooo`008P3oool00`000000oooo
0000003o0?oooh`0oooo000R0?ooo`030000003oool000000?l0ooooS03oool00280oooo00<00000
0?ooo`000000o`3ooon<0?ooo`008P3oool00`000000oooo0000003o0?oooh`0oooo000R0?ooo`03
0000003oool000000?l0ooooS03oool00280oooo00<000000?ooo`000000o`3ooon<0?ooo`00103o
ool4000000H0oooo0P0000060?ooo`<000002@3oool00`000000oooo0000003o0?oooh`0oooo0003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000T0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0000003o0?oooh`0oooo00030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`800000o`3ooon=0?oo
o`000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0103oool300000?l0ooooS03oool000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0<0?ooo`D000001P3oool200000?l0ooooS@3oool000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool200000?l0ooooS@3oool000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool200000?l0ooooS@3oool0
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool200000?l0ooooS@3oool000@0oooo1000000?0?ooo`@0
00001`3oool200000?l0ooooS@3oool00280oooo0P00003o0?ooohd0oooo000R0?ooo`800000o`3o
oon=0?ooo`008P3oool200000?l0ooooS@3oool00280oooo0P00003o0?ooohd0oooo000R0?ooo`80
0000o`3ooon=0?ooo`008P3oool200000?l0ooooS@3oool00280oooo0P00003o0?ooohd0oooo000R
0?ooo`800000o`3ooon=0?ooo`008P3oool200000?l0ooooS@3oool00280oooo00<000000?ooo`3o
ool0o`3ooon<0?ooo`008P3oool00`000000oooo0?ooo`3o0?oooh`0oooo000R0?ooo`030000003o
ool0oooo0?l0ooooS03oool00280oooo00<000000?ooo`3oool0o`3ooon<0?ooo`008P3oool00`00
0000oooo0?ooo`3o0?oooh`0oooo000R0?ooo`030000003oool0oooo0?l0ooooS03oool00280oooo
00<000000?ooo`3oool0o`3ooon<0?ooo`008P3oool200000?l0ooooS@3oool00280oooo00<00000
0?ooo`3oool0o`3ooon<0?ooo`008P3oool00`000000oooo0?ooo`3o0?oooh`0oooo000R0?ooo`03
0000003oool0oooo0?l0ooooS03oool00280oooo00<000000?ooo`3oool0o`3ooon<0?ooo`008P3o
ool00`000000oooo0?ooo`3o0?oooh`0oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-8.99214, 0.466364, \
0.393718, 0.00272723}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[inputcos, inputconst, inputmultiple]\)], "Input",
  CellLabel->"In[34]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 4", "SubsubsectionIcon",
  CellTags->"Examples"],

Cell["\<\
Here is shown the retention  in each compartment of RT assuming a constant \
intake a (Bq/day) by inhalation (S, AMAD 5).\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(qRTConstant[int_, \ t1_] = 
      RespiratoryTract[int, AMADAdultW[5], S, \ t1, 0, 
        IntakeType \[Rule] "\<Constant\>"]\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \({q\_ET1[t1] \[Rule] 
        0.3386996`\ int - 0.3386996`\ \[ExponentialE]\^\(-t1\)\ int, 
      q\_AI[t1] \[Rule] 
        53.92899114028488`\ int - 
          1.590574749345051`*^-7\ \[ExponentialE]\^\(\(-100.11999999999999`\)\
\ t1\)\ int - 
          3.181753307248209`*^-7\ \[ExponentialE]\^\(\(-100.101`\)\ t1\)\ int \
- 5.302968797786916`*^-8\ \[ExponentialE]\^\(\(-100.10012`\)\ t1\)\ int - 
          0.7930733913238587`\ \[ExponentialE]\^\(\(-0.0201`\)\ t1\)\ int - 
          28.983227573835556`\ \[ExponentialE]\^\(\(-0.0011`\)\ t1\)\ int - 
          24.152689644862967`\ \[ExponentialE]\^\(\(-0.00022`\)\ t1\)\ int, 
      q\_bb1[t1] \[Rule] 
        0.026909922259104675`\ int - 
          6.247624939749402`*^-8\ \[ExponentialE]\^\(\(-102.1`\)\ t1\)\ int - 
          1.6066411609543618`*^-9\ \
\[ExponentialE]\^\(\(-100.11999999999999`\)\ t1\)\ int - 
          1.5916724898684324`*^-10\ \[ExponentialE]\^\(\(-100.101`\)\ t1\)\ \
int - 0.003192445514603719`\ \[ExponentialE]\^\(\(-2.0001`\)\ t1\)\ int - 
          0.008010842336604634`\ \[ExponentialE]\^\(\(-0.0201`\)\ t1\)\ int - 
          0.014498863218527043`\ \[ExponentialE]\^\(\(-0.0011`\)\ t1\)\ int - 
          0.0012077069446598278`\ \[ExponentialE]\^\(\(-0.00022`\)\ t1\)\ \
int, q\_bb2[t1] \[Rule] 
        0.1455025272461415`\ int - 
          4.3695646960093505`*^-8\ \[ExponentialE]\^\(\(-100.13`\)\ t1\)\ int \
- 0.14550248355049453`\ \[ExponentialE]\^\(\(-0.0301`\)\ t1\)\ int, 
      q\_bbseq[t1] \[Rule] 
        0.007637071336230146`\ int - 
          7.697260843969014`*^-10\ \[ExponentialE]\^\(\(-100.11`\)\ t1\)\ int \
- 0.007637070566504062`\ \[ExponentialE]\^\(\(-0.0101`\)\ t1\)\ int, 
      q\_BB1[t1] \[Rule] 
        0.006988349122294753`\ int - 
          9.121962424213835`*^-8\ \[ExponentialE]\^\(\(-110.1`\)\ t1\)\ int - 
          1.5619062349373505`*^-8\ \[ExponentialE]\^\(\(-102.1`\)\ t1\)\ int \
- 1.3148138503539838`*^-10\ \[ExponentialE]\^\(\(-100.13`\)\ t1\)\ int - 
          3.2197217654400695`*^-10\ \[ExponentialE]\^\(\(-100.11999999999999`\
\)\ t1\)\ int - 
          0.0010053233430690864`\ \[ExponentialE]\^\(\(-10.0001`\)\ t1\)\ int \
- 0.0007981113786509297`\ \[ExponentialE]\^\(\(-2.0001`\)\ t1\)\ int - 
          0.00043782091339165854`\ \[ExponentialE]\^\(\(-0.0301`\)\ t1\)\ int \
- 0.0016053792257724713`\ \[ExponentialE]\^\(\(-0.0201`\)\ t1\)\ int - 
          0.002900062649970405`\ \[ExponentialE]\^\(\(-0.0011`\)\ t1\)\ int - 
          0.0002415442874634151`\ \[ExponentialE]\^\(\(-0.00022`\)\ t1\)\ \
int, q\_BB2[t1] \[Rule] 
        0.19651470433950813`\ int - 
          5.901503778529722`*^-8\ \[ExponentialE]\^\(\(-100.13`\)\ t1\)\ int \
- 0.19651464532447036`\ \[ExponentialE]\^\(\(-0.0301`\)\ t1\)\ int, 
      q\_BBseq[t1] \[Rule] 
        0.012293373625358645`\ int - 
          1.2390260517512954`*^-9\ \[ExponentialE]\^\(\(-100.11`\)\ t1\)\ int \
- 0.012293372386332593`\ \[ExponentialE]\^\(\(-0.0101`\)\ t1\)\ int, 
      q\_LNth[t1] \[Rule] 
        6.82358222425647`\ int + 
          2.008752136148603`*^-9\ \[ExponentialE]\^\(\(-100.11`\)\ t1\)\ int \
+ 8.838281329648108`*^-9\ \[ExponentialE]\^\(\(-100.10012`\)\ t1\)\ int - 
          1.0847244735676417`*^-8\ \[ExponentialE]\^\(\(-100.1`\)\ t1\)\ int \
+ 0.019930442952836653`\ \[ExponentialE]\^\(\(-0.0101`\)\ t1\)\ int + 
          4.025448274143828`\ \[ExponentialE]\^\(\(-0.00022`\)\ t1\)\ int - 
          10.868960941352924`\ \[ExponentialE]\^\(\(-0.0001`\)\ t1\)\ int, 
      q\_ET2[t1] \[Rule] 
        0.004742794188988448`\ int - 
          1.9821042447733896`*^-6\ \[ExponentialE]\^\(\(-200.1`\)\ t1\)\ int \
- 1.0135513804690792`*^-8\ \[ExponentialE]\^\(\(-110.1`\)\ t1\)\ int - 
          1.59378187236286`*^-9\ \[ExponentialE]\^\(\(-102.1`\)\ t1\)\ int - 
          0.003970156784391367`\ \[ExponentialE]\^\(\(-100.0001`\)\ t1\)\ int \
- 0.00011170259367434292`\ \[ExponentialE]\^\(\(-10.0001`\)\ t1\)\ int - 
          0.00008143993659703364`\ \[ExponentialE]\^\(\(-2.0001`\)\ t1\)\ int \
- 0.00010276731513104627`\ \[ExponentialE]\^\(\(-0.0301`\)\ t1\)\ int - 
          0.00016057003658456406`\ \[ExponentialE]\^\(\(-0.0201`\)\ t1\)\ int \
- 0.0002900091650886914`\ \[ExponentialE]\^\(\(-0.0011`\)\ t1\)\ int - 
          0.000024154457731690787`\ \[ExponentialE]\^\(\(-0.00022`\)\ t1\)\ \
int, q\_ETseq[t1] \[Rule] 
        0.1811372277181665`\ int - 
          1.988508579876912`*^-9\ \[ExponentialE]\^\(\(-100.101`\)\ t1\)\ int \
- 0.18113722572965793`\ \[ExponentialE]\^\(\(-0.0011`\)\ t1\)\ int, 
      q\_LNet[t1] \[Rule] 
        1.8113722572965991`\ int + 
          1.988508579877724`*^-9\ \[ExponentialE]\^\(\(-100.101`\)\ t1\)\ int \
- 1.9885284450977607`*^-9\ \[ExponentialE]\^\(\(-100.1`\)\ t1\)\ int + 
          0.18113722572965793`\ \[ExponentialE]\^\(\(-0.0011`\)\ t1\)\ int - 
          1.992509483026237`\ \[ExponentialE]\^\(\(-0.0001`\)\ t1\)\ int}\)], \
"Output",
  CellLabel->"Out[35]="]
}, Open  ]],

Cell["\<\
The same function can be applied for computing the total disintegration Us \
for each retention compartments for different times. Ex.. 50 years\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(qRTConstant[3600*24, \ \ 365.24*50]\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \({q\_ET1[18262.`] \[Rule] 29263.64544`, 
      q\_AI[18262.`] \[Rule] 4.6219121995522855`*^6, 
      q\_bb1[18262.`] \[Rule] 2323.13953664583`, 
      q\_bb2[18262.`] \[Rule] 12571.418354066625`, 
      q\_bbseq[18262.`] \[Rule] 659.8429634502846`, 
      q\_BB1[18262.`] \[Rule] 603.4178103514166`, 
      q\_BB2[18262.`] \[Rule] 16978.8704549335`, 
      q\_BBseq[18262.`] \[Rule] 1062.1474812309868`, 
      q\_LNth[18262.`] \[Rule] 444601.86295457726`, 
      q\_ET2[18262.`] \[Rule] 409.73986250204996`, 
      q\_ETseq[18262.`] \[Rule] 15650.25644531526`, 
      q\_LNet[18262.`] \[Rule] 128781.77600813472`}\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[qRTConstant]\)], "Input",
  CellLabel->"In[37]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 5", "SubsubsectionIcon",
  CellTags->"Examples"],

Cell["\<\
The thoracic lung retention for a  daily constant intake \"1\" for different \
AMADs can be evaluated as follow\
\>", "MathCaption"],

Cell[BoxData[
    \({qLungs1SCronic[t1_], qLungs3SCronic[t1_], qLungs5SCronic[t1_], 
        qLungs10SCronic[t1_]} = \ 
      Map[LungsRetention[1, AMADAdultW[#], S, t1, 0, \ 
            IntakeType \[Rule] "\<Constant\>"] &, \ {1, \ 3, \ 5, \ 
          10}]; \)], "Input",
  CellLabel->"In[38]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{qLungs1SCronic[t], qLungs3SCronic[t], qLungs5SCronic[t], 
        qLungs10SCronic[t]}, \ {t, \ 0, \ 10000}, PlotStyle \[Rule] styles, \ 
      AxesLabel \[Rule] {"\<days\>", \ "\<r\>"}, \[IndentingNewLine]PlotLabel \
\[Rule] "\<Chronic intake lung retention fraction,\n class S, for different \
AMADs\>", \ PlotLegend \[Rule] {"\<1\>", "\<3\>", "\<5\>", \ "\<10\>"}, \ 
      LegendPosition \[Rule] \ {1, \ \(-0.3\)}, \ 
      LegendSize \[Rule] \ {0.3, \ 0.5}]\)], "Input",
  CellLabel->"In[39]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .52599 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.429078 0.405268 0.262993 0.405268 [
[ 0 0 0 0 ]
[ 1 .52599 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0125235 0.834347 0.513463 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 9.52381e-005 0.0147151 0.00542146 [
[.21429 .00222 -12 -9 ]
[.21429 .00222 12 0 ]
[.40476 .00222 -12 -9 ]
[.40476 .00222 12 0 ]
[.59524 .00222 -12 -9 ]
[.59524 .00222 12 0 ]
[.78571 .00222 -12 -9 ]
[.78571 .00222 12 0 ]
[.97619 .00222 -15 -9 ]
[.97619 .00222 15 0 ]
[1.025 .01472 0 -6.25 ]
[1.025 .01472 28 6.25 ]
[.01131 .12314 -12 -4.5 ]
[.01131 .12314 0 4.5 ]
[.01131 .23157 -12 -4.5 ]
[.01131 .23157 0 4.5 ]
[.01131 .34 -12 -4.5 ]
[.01131 .34 0 4.5 ]
[.01131 .44843 -12 -4.5 ]
[.01131 .44843 0 4.5 ]
[.01131 .55686 -18 -4.5 ]
[.01131 .55686 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12.5 ]
[.5 .63053 -119 0 ]
[.5 .63053 119 25.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2000)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4000)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6000)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8000)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10000)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .12314 m
.03006 .12314 L
s
[(20)] .01131 .12314 1 0 Mshowa
.02381 .23157 m
.03006 .23157 L
s
[(40)] .01131 .23157 1 0 Mshowa
.02381 .34 m
.03006 .34 L
s
[(60)] .01131 .34 1 0 Mshowa
.02381 .44843 m
.03006 .44843 L
s
[(80)] .01131 .44843 1 0 Mshowa
.02381 .55686 m
.03006 .55686 L
s
[(100)] .01131 .55686 1 0 Mshowa
.125 Mabswid
.02381 .04182 m
.02756 .04182 L
s
.02381 .06893 m
.02756 .06893 L
s
.02381 .09604 m
.02756 .09604 L
s
.02381 .15025 m
.02756 .15025 L
s
.02381 .17736 m
.02756 .17736 L
s
.02381 .20447 m
.02756 .20447 L
s
.02381 .25868 m
.02756 .25868 L
s
.02381 .28579 m
.02756 .28579 L
s
.02381 .3129 m
.02756 .3129 L
s
.02381 .36711 m
.02756 .36711 L
s
.02381 .39422 m
.02756 .39422 L
s
.02381 .42132 m
.02756 .42132 L
s
.02381 .47554 m
.02756 .47554 L
s
.02381 .50265 m
.02756 .50265 L
s
.02381 .52975 m
.02756 .52975 L
s
.02381 .58397 m
.02756 .58397 L
s
.02381 .61108 m
.02756 .61108 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -180 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Chronic) show
111.000 12.750 moveto
(intake) show
153.000 12.750 moveto
(lung) show
183.000 12.750 moveto
(retention) show
243.000 12.750 moveto
(fraction) show
291.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
69.000 25.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(class) show
105.000 25.875 moveto
(S) show
111.000 25.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
123.000 25.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(for) show
147.000 25.875 moveto
(different) show
207.188 25.875 moveto
(AMADs) show
237.188 25.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .01472 m
.04262 .09873 L
.06244 .16234 L
.08426 .21942 L
.10458 .26306 L
.14264 .32628 L
.18163 .37336 L
.22307 .41046 L
.263 .43785 L
.30142 .45896 L
.34228 .4775 L
.38164 .49262 L
.41947 .50529 L
.45976 .51722 L
.49853 .52751 L
.53975 .5374 L
.57946 .54607 L
.61766 .55372 L
.6583 .56122 L
.69743 .56788 L
.73901 .57441 L
.77908 .58023 L
.81763 .58543 L
.85863 .59056 L
.89812 .59515 L
.93609 .59927 L
.97619 .60332 L
s
0 1 0 r
1.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.04262 .07616 L
.06244 .12227 L
.08426 .16366 L
.10458 .19531 L
.14264 .24121 L
.18163 .27542 L
.22307 .30242 L
.263 .32238 L
.30142 .33778 L
.34228 .35133 L
.38164 .3624 L
.41947 .37167 L
.45976 .38043 L
.49853 .38798 L
.53975 .39525 L
.57946 .40162 L
.61766 .40725 L
.6583 .41277 L
.69743 .41768 L
.73901 .42249 L
.77908 .42679 L
.81763 .43063 L
.85863 .43442 L
.89812 .43781 L
.93609 .44086 L
.97619 .44386 L
s
0 0 1 r
2 Mabswid
[ 1 8 ] 0 Mabsdash
.02381 .01472 m
.04262 .05735 L
.06244 .08921 L
.08426 .1178 L
.10458 .13969 L
.14264 .17143 L
.18163 .19511 L
.22307 .21382 L
.263 .22767 L
.30142 .23837 L
.34228 .24779 L
.38164 .25549 L
.41947 .26195 L
.45976 .26806 L
.49853 .27333 L
.53975 .27841 L
.57946 .28286 L
.61766 .2868 L
.6583 .29066 L
.69743 .29409 L
.73901 .29747 L
.77908 .30048 L
.81763 .30317 L
.85863 .30583 L
.89812 .30821 L
.93609 .31035 L
.97619 .31246 L
s
0 g
2.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.04262 .03386 L
.06244 .04809 L
.08426 .06088 L
.10458 .07067 L
.14264 .08488 L
.18163 .09551 L
.22307 .10392 L
.263 .11016 L
.30142 .115 L
.34228 .11927 L
.38164 .12276 L
.41947 .1257 L
.45976 .12848 L
.49853 .13089 L
.53975 .13321 L
.57946 .13525 L
.61766 .13705 L
.6583 .13882 L
.69743 .1404 L
.73901 .14195 L
.77908 .14333 L
.81763 .14457 L
.85863 .1458 L
.89812 .1469 L
.93609 .14789 L
.97619 .14886 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.85461 .12115 m
.85461 .32378 L
.97619 .32378 L
.97619 .12115 L
F
1 g
.83435 .14141 m
.83435 .34405 L
.95593 .34405 L
.95593 .14141 L
F
0 g
.001 w
[ ] 0 setdash
.83435 .14141 m
.95593 .14141 L
.95593 .34405 L
.83435 .34405 L
.83435 .14141 L
s
% Start of sub-graphic
p
0.834347 0.141413 0.955927 0.344047 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0344353 0.344353 [
[ 0 0 0 0 ]
[ 1 1.66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.66667 L
0 1.66667 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0619835 0.35119 0.406336 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
2.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .23416 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.461433 0.35119 0.805785 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
2 Mabswid
[ 1 8 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .63361 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.860882 0.35119 1.20523 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
1.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 1.03306 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 1.26033 0.35119 1.60468 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 1.43251 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .52599 L
0 .52599 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[39]:=",
  ImageSize->{288, 151.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000hb000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00HP3oool6000000@0oooo100000050?ooo`@000001@3oool400000100
oooo100000040?ooo`@000001@3oool4000000D0oooo1000000A0?ooo`@00000103oool4000000D0
oooo100000050?ooo`@000003`3oool4000000D0oooo100000050?ooo`@000001@3oool4000000X0
oooo1`0000030?ooo`@000001@3oool4000000D0oooo100000050?ooo`@00000L03oool00680oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?oo
o`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?oo
o`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo06d0oooo001S0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000
103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0K@3oool006@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
0000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool02`3oool60000
00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00d0oooo0P0000030?ooo`040000003o
ool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?oo
o`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0K@3oool0
06D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0303o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0=0?oo
o`030000003oool00000008000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0303o
ool4000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@00
0000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo06d0oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo00`0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`05
0000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0K@3oool00680oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000
oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo06d0oooo001R0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool03@3oool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`080?ooo`<000001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo06d0oooo001S0?ooo`@000001@3oool4000000D0oooo1000
00050?ooo`@000004@3oool2000000D0oooo100000050?ooo`@000001@3oool4000001<0oooo0`00
00030?ooo`@000001@3oool4000000D0oooo1000000?0?ooo`@000001@3oool4000000D0oooo1000
00050?ooo`@000003@3oool00`000000oooo0?ooo`040?ooo`@000001@3oool4000000D0oooo1000
00050?ooo`@00000L03oool00?l0oooo/@3oool00?l0ooooD03oool3000005h0oooo003o0?oooe80
oooo00<000000?ooo`3oool0G03oool004@0oooo00<000000?ooo`3oool0o`3oool;0?ooo`030000
003oool0oooo05`0oooo00140?ooo`030000003oool0oooo0?H0oooo0`0000000`3oool000000000
00040?ooo`D000001@3oool2000000D0oooo1@00001C0?ooo`00@`3oool2000000030000o`3oool0
oooo0?@0oooo00@000000?ooo`3oool0oooo0P0000040?ooo`050000003oool0oooo0?ooo`000000
1P3oool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1@0?ooo`00?`3o
oood000000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000001@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0500
oooo00130?ooo`@000002@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`@000001@3oool010000000oooo
0?ooo`0000050?ooo`@00000D`3oool004@0oooo1000000[0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0303oool010000000oooo0?ooo`3oool2000000@0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo0500oooo00140?ooo`030000o`000000000000800000m03oool30000
00030?ooo`000000oooo00@0oooo0`0000040?ooo`<000000P3oool3000000<0oooo1@00001B0?oo
o`00A03oool00`0000000?l00000000300000?L0oooo00<000000?ooo`3oool0K03oool004@0oooo
00<00000003o0000o`001@00003e0?ooo`030000003oool0oooo06`0oooo00140?ooo`0400000000
o`000?l0003o00D00000l`3oool2000006h0oooo00140?ooo`8000000P00o`020?ooo`@00000o`3o
oomS0?ooo`00A03oool010000000oooo003o0000o`030?ooo`D00000o`3ooomQ0?ooo`00A03oool0
0`000000oooo003o0002003o00<0oooo1@00003o0?ooof00oooo00140?ooo`030000003oool0oooo
00800?l0103oool600000?l0ooooGP3oool004@0oooo00<000000?ooo`3oool00P00o`060?ooo`H0
0000o`3ooomL0?ooo`00A03oool00`000000oooo0?ooo`02003o0080003o1@3oool800000?l0oooo
F@3oool004@0oooo00@000000?ooo`3oool0o`0010000?l60?ooo`P00000o`3ooomG0?ooo`00A03o
ool2000000030?ooo`3o00000?l000@0003o1`3oool800000?l0ooooE@3oool004@0oooo00@00000
0?ooo`3oool0o`000P00o`030000o`X0oooo2000003o0?oooe80oooo00140?ooo`050000003oool0
oooo0?ooo`3o00000P00o`000`000?l0oooo0?ooo`0;0?ooo`P00000o`3ooom@0?ooo`00A03oool0
1@000000oooo0?ooo`3oool0o`0000<00?l03`3oool900000?l0ooooC@3oool004@0oooo00H00000
0?ooo`3oool0oooo0?l0003oool2003o0180oooo2`00003o0?ooodP0oooo00140?ooo`030000003o
ool0oooo00<0oooo0P00o`0D0?ooo`h00000o`3ooom30?ooo`00A03oool2000000@0oooo0`00o`0G
0?ooo`l00000o`3oooln0?ooo`00A03oool00`000000oooo0?ooo`040?ooo`800?l0703oool?0000
0?l0oooo>@3oool004@0oooo00<000000?ooo`3oool0103oool3003o0200oooo3`00003o0?oooc@0
oooo000`0?ooo`H00000103oool4000000H0oooo00<000000?ooo`3oool01@3oool2003o00<0oooo
0P000?lP0?oooa400000o`3oool]0?ooo`00<03oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00@0o`000?ooo`00o`000?l00P3oool40000ob@0oooo5@00003o0?ooob@0oooo000a0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<0o`000?ooo`3oool00P00o`020?ooo`@0003o:03ooolJ00000?l0oooo
6P3oool00380oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool0103o0000oooo003o0000o`030?ooo`<0003o
;`3ooolM00000<h0oooo=@00000<0?ooo`00<`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool3000000@0oooo00@0o`000?ooo`3oool00?l0
103oool00`000?l0oooo0?ooo`0g0?ooobL00000^`3ooole000000`0oooo000d0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<0o`000?ooo`3oool00P00o`170?oooc000000Z03ooole000000`0oooo000`
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01@3oool0103o0000oooo0?ooo`00o`1A0?ooocT00000
U@3ooole000000`0oooo000`0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`02003o06<0ooooA000001g0?ooocD00000303oool00340oooo100000050?ooo`@000001P3o
ool00`000000oooo0?ooo`090?ooo`03003o003oool0oooo07@0ooooCP00001J0?ooocD00000303o
ool004@0oooo00<000000?ooo`3oool02@3oool2003o00P0oooo0P000?mn0?oooeD00000@03ooole
000000`0oooo00140?ooo`030000003oool0oooo00X0oooo00<00?l00?ooo`3oool01@3oool40000
oi/0oooo=`0000100?ooocD00000303oool004@0oooo0P00000;0?ooo`800?l01`3oool40000okL0
oooo6P00000h0?ooocd00000303oool004@0oooo00<000000?ooo`3oool01P3oool00`3o0000oooo
0?ooo`020?ooo`03003o003oool0oooo00H0oooo0`000?oo0?ooo`X0oooo00<000000?ooo`3oool0
<@3oool9000000`0oooo00140?ooo`030000003oool0oooo00L0oooo00@0o`000?ooo`3oool0oooo
0P00o`080?ooo`030000o`3oool0oooo0?l0oooo2@3oool00`000000oooo0?ooo`0a0?ooo`T00000
303oool004@0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`020?ooo`03003o003o
ool0oooo0?l0oooo4P3oool00`000000oooo0?ooo`0a0?ooo`T00000303oool004@0oooo00<00000
0?ooo`3oool0203oool0103o0000oooo0?ooo`3oool2003o0?l0oooo4`3oool00`000000oooo0?oo
o`0a0?ooo`T00000303oool004@0oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`02
0?ooo`800?l0o`3ooolB0?ooo`030000003oool0oooo0340oooo2@00000<0?ooo`00A03oool20000
00X0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`0=0?ooo`80003oo`3oool10?oo
o`030000003oool0oooo0340oooo2@00000<0?ooo`00A03oool00`000000oooo0?ooo`090?ooo`03
0?l0003oool0oooo0080oooo0P00o`0=0?ooo`@0003oo`3oool00`000000oooo0?ooo`0a0?ooo`T0
0000303oool004@0oooo00<000000?ooo`3oool03`3oool2003o00d0oooo10000?on0?ooo`030000
003oool0oooo0340oooo2@00000<0?ooo`00A03oool00`000000oooo0?ooo`0@0?ooo`800?l03@3o
ool30000ooh0oooo00<000000?ooo`3oool0<@3oool9000000`0oooo00140?ooo`030000003oool0
oooo0140oooo00<00?l00?ooo`3oool0303oool00`000?l0oooo0?ooo`3m0?ooo`030000003oool0
oooo01D0oooo1`0000030?ooo`@000003P3oool9000000`0oooo00140?ooo`030000003oool0oooo
0140oooo0P00o`3o0?ooo`h0oooo00<000000?ooo`3oool0400000080?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`T00000303oool004@0
oooo00<000000?ooo`3oool04P3oool2003o0?l0oooo3@3oool00`000000oooo0?ooo`0@000000P0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo2@00000<0?ooo`00A03oool2000000`0oooo00<0o`000?ooo`3oool01@3oool2003o01D0oooo
10000?ob0?ooo`030000003oool0oooo01000000203oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02`3oool9000000`0oooo00140?ooo`030000003o
ool0oooo00/0oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?ooo`0C0?ooo`@0003olP3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0;0?ooo`T00000303oool004@0oooo00<000000?ooo`3oool0303oool0
0`3o0000oooo0?ooo`050?ooo`800?l0503oool40000oo80oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool9
000000`0oooo000b0?ooo`@00000103oool4000000H0oooo00<000000?ooo`3oool0303oool00`3o
0000oooo0?ooo`060?ooo`800?l0o`3oool:0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo2@00000<0?oo
o`00=03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00L0oooo0P00o`0N0?ooo`@0
003oiP3oool00`000000oooo0?ooo`0F0?ooo`<000001@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00/0oooo2@00000<0?ooo`00=03oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00L0oooo00<00?l00?ooo`3oool0703oool40000onH0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`040?ooo`@000003P3oool9000000`0oooo000`0?ooo`H000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0`00000G0?ooo`800?l07@3o
ool50000onD0oooo00<000000?ooo`3oool0<@3oool9000000`0oooo000a0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01P0oooo0P00o`0N0?ooo`<0003oi@3oool00`000000oooo0?ooo`0a0?ooo`T00000303o
ool00340oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool06@3oool2003o01h0oooo00<0003o0?ooo`3oool0203o
ool40000omP0oooo00<000000?ooo`3oool0<@3oool9000000`0oooo000b0?ooo`030000003oool0
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01X0oooo0P00o`0X0?ooo`@0003of03oool00`000000oooo0?ooo`0a0?ooo`T00000303oool0
0380oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool06P3oool3003o02L0oooo10000?oH0?ooo`030000003oool0oooo
0340oooo2@00000<0?ooo`00<`3oool2000000D0oooo100000060?ooo`030000003oool0oooo00l0
oooo00<0o`000?ooo`3oool02@3oool4003o0380oooo10000?o;0?ooo`030000003oool0oooo0340
oooo2@00000<0?ooo`00A03oool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00T0oooo
1000o`0a0?ooo`@0003ob`3oool00`000000oooo0?ooo`0a0?ooo`T00000303oool004@0oooo0P00
000A0?ooo`030?l0003oool0oooo00/0oooo0`00o`0`0?ooo`@0003o2@3oool50000okd0oooo00<0
00000?ooo`3oool0<@3oool9000000`0oooo00140?ooo`030000003oool0oooo0140oooo00<0o`00
0?ooo`3oool02`3oool3003o03`0oooo1@000?nm0?ooo`030000003oool0oooo0340oooo2@00000<
0?ooo`00A03oool00`000000oooo0?ooo`0A0?ooo`030?l0003oool0oooo00`0oooo1000o`0j0?oo
o`D0003o203oool50000ok00oooo00<000000?ooo`3oool0<@3oool9000000`0oooo00140?ooo`03
0000003oool0oooo0180oooo00<0o`000?ooo`3oool0303oool4003o04H0oooo1@000?n`0?ooo`03
0000003oool0oooo0340oooo2@00000<0?ooo`00A03oool00`000000oooo0?ooo`0S0?ooo`<00?l0
A@3oool50000o`T0oooo10000?nS0?ooo`030000003oool0oooo0340oooo2@00000<0?ooo`00A03o
ool00`000000oooo0?ooo`0T0?ooo`@00?l0D@3oool40000o`T0oooo1@000?nE0?ooo`030000003o
ool0oooo01H0oooo1000000G0?ooo`T00000303oool004@0oooo00<000000?ooo`3oool09@3oool4
003o0500oooo10000?l90?ooo`D0003o2@3oool20000ohX0oooo00<000000?ooo`3oool00`000?l9
0?ooo`@0003o1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo2@00000<
0?ooo`00A03oool2000002P0oooo1000o`1K0?ooo`D0003o203oool40000ohT0oooo00<000000?oo
o`3oool00`000?l90?ooo`@0003o2P3oool00`000000oooo0?ooo`0D0?ooo`T00000303oool004@0
oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`0@0?ooo`@00?l0J03oool40000o`T0
oooo1@000?mj0?ooo`030000003oool0oooo00<0003o2@3oool40000o`X0oooo00<000000?ooo`3o
ool0503oool9000000`0oooo00140?ooo`030000003oool0oooo01H0oooo00<0o`000?ooo`3oool0
4@3oool4003o06L0oooo0`000?l90?ooo`D0003o2@3oool40000ofd0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0D0?ooo`T00000303oool004@0oooo00<000000?ooo`3oool05P3o
ool00`3o0000oooo0?ooo`0B0?ooo`@00?l0I`3oool00`000?l0oooo0?ooo`080?ooo`D0003o2@3o
ool40000o`T0oooo1@000?mO0?ooo`030000003oool0oooo01H0oooo1000000G0?ooo`T00000303o
ool004@0oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`0C0?ooo`@00?l0OP3oool4
0000o`T0oooo1@000?l90?ooo`@0003o2@3oool50000od@0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0H0?ooo`T00000303oool004@0oooo00<000000?ooo`3oool05`3oool00`3o
0000oooo0?ooo`0D0?ooo`H00?l0R03oool50000o`T0oooo10000?l90?ooo`D0003o203oool40000
ocP0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0H0?ooo`T00000303oool004@0
oooo0P00000I0?ooo`030?l0003oool0oooo01D0oooo1P00o`2D0?ooo`@0003o2@3oool50000o`P0
oooo10000?lh0?ooo`030000003oool0oooo01H0oooo1@00000F0?ooo`T00000303oool004@0oooo
00<000000?ooo`3oool0<`3oool6003o0:/0oooo10000?lh0?ooo`030000003oool0oooo0340oooo
2@00000<0?ooo`00A03oool00`000000oooo0?ooo`0e0?ooo`H00?l0i@3oool00`000000oooo0?oo
o`0a0?ooo`T00000303oool00380oooo100000040?ooo`@000001P3oool00`000000oooo0?ooo`0h
0?ooo`D00?l0h`3oool00`000000oooo0?ooo`0a0?ooo`T00000303oool00340oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0>P3oool6003o0>00oooo00<000000?ooo`3oool0<@3oool9000000`0oooo000a0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool07@3oool6003o0=h0oooo00<00000
0?ooo`3oool0<@3oool9000000`0oooo000a0?ooo`8000000`3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`3o0000oooo0?ooo`0O
0?ooo`D00?l0g03oool00`000000oooo0?ooo`0a0?ooo`T00000303oool00340oooo00<000000?oo
o`0000000P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool30000
01h0oooo00<0o`000?ooo`3oool0803oool6003o0=T0oooo00<000000?ooo`3oool0<@3oool90000
00`0oooo000a0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01h0oooo00<0o`000?ooo`3oool08P3oool6003o0=L0
oooo00<000000?ooo`3oool0<@3oool9000000`0oooo000b0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo
00<0o`000?ooo`3oool0903oool6003o0=@0oooo00<000000?ooo`3oool0<@3oool9000000`0oooo
000c0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0200oooo00<0o`000?ooo`3oool09@3oool8003o0=00oooo00<0
00000?ooo`3oool0<@3oool9000000`0oooo000d0?ooo`<000000`3oool4000000H0oooo00<00000
0?ooo`3oool0B`3oool:003o0</0oooo00<000000?ooo`3oool0<@3oool9000000`0oooo00140?oo
o`030000003oool0oooo0500oooo2P00o`360?ooo`030000003oool0oooo01H0oooo1000000G0?oo
o`T00000303oool004@0oooo0P00001F0?ooo`T00?l0`P3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0503oool9000000`0oooo00140?ooo`030000
003oool0oooo02<0oooo00<0o`000?ooo`3oool0=03oool8003o0;h0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0D0?ooo`T00000303oool004@0oooo00<000000?ooo`3oool0903o
ool00`3o0000oooo0?ooo`0g0?ooo`L00?l0^`3oool00`000000oooo0?ooo`0@003o00X0oooo00<0
00000?ooo`3oool0503oool9000000`0oooo00140?ooo`030000003oool0oooo02D0oooo00<0o`00
0?ooo`3oool0>P3oool6003o0;P0oooo00<000000?ooo`3oool04000o`080?ooo`8000005`3oool9
000000`0oooo00140?ooo`030000003oool0oooo02H0oooo0P3o000m0?ooo``00?l0[`3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo01@0oooo2@00000<0?ooo`00A03oool00`000000
oooo0?ooo`0X0?ooo`030?l0003oool0oooo03d0oooo3P00o`2Z0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0503oool9000000`0oooo00140?ooo`030000003oool0oooo0740oooo
2P00o`2U0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0D0?ooo`T00000303oool004@0oooo0P00001g0?ooo`X00?l0X03oool00`000000oooo0?oo
o`0F0?ooo`@000005`3oool9000000`0oooo00140?ooo`030000003oool0oooo07/0oooo2P00o`2K
0?ooo`030000003oool0oooo0340oooo2@00000<0?ooo`00A03oool00`000000oooo0?ooo`0/0?oo
o`030?l0003oool0oooo0540oooo3P00o`2B0?ooo`030000003oool0oooo0340oooo2@00000<0?oo
o`00A03oool00`000000oooo0?ooo`0]0?ooo`030?l0003oool0oooo05D0oooo4`00o`280?ooo`03
0000003oool0oooo0340oooo2@00000<0?ooo`00A03oool00`000000oooo0?ooo`0^0?ooo`030?l0
003oool0oooo05d0oooo3`00o`230?ooo`030000003oool0oooo0340oooo2@00000<0?ooo`00A03o
ool00`000000oooo0?ooo`0_0?ooo`80o`00I`3oool:003o07h0oooo00<000000?ooo`3oool0<@3o
ool9000000`0oooo00140?ooo`030000003oool0oooo0340oooo00<0o`000?ooo`3oool0J@3oool?
003o07@0oooo00<000000?ooo`3oool0<@3oool9000000`0oooo00140?ooo`800000X`3ooolC003o
06/0oooo00<000000?ooo`3oool0<@3oool9000000`0oooo00140?ooo`030000003oool0oooo0:`0
oooo4`00o`1Q0?ooo`030000003oool0oooo0340oooo2@00000<0?ooo`00A03oool00`000000oooo
0?ooo`0f0?ooo`030?l0003oool0oooo07`0oooo5000o`1G0?ooo`030000003oool0oooo0340oooo
2@00000<0?ooo`00<@3oool4000000D0oooo100000060?ooo`030000003oool0oooo03L0oooo00<0
o`000?ooo`3oool0Q@3ooolC003o04h0oooo00<000000?ooo`3oool0<@3oool9000000`0oooo000`
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0>03oool20?l008l0oooo7@00o`0j0?ooo`030000003o
ool0oooo0340oooo2@00000<0?ooo`00<03oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03X0oooo0P3o
002F0?oooaD00?l0>@3oool00`000000oooo0?ooo`0a0?ooo`T00000303oool00300oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3o
ool300000>H0oooo00<00?l00?ooo`3oool0=`3oool00`000000oooo0?ooo`0E0?ooo`L000005@3o
ool9000000`0oooo000a0?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool05P3oool9000000`0oooo000`0?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0@03oool0
0`3o0000oooo0?ooo`3M0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool05P3oool9
000000`0oooo000`0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0@@3oool20?l00=d0oooo00<00000
0?ooo`3oool01`3o00050?ooo`@0o`00203oool00`000000oooo0?ooo`0F0?ooo`T00000303oool0
0300oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`130?ooo`80o`00f`3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo01H0oooo2@00000<0?ooo`00<@3oool4000000D0oooo100000060?oo
o`030000003oool0oooo04D0oooo0P3o003I0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool05P3oool9000000`0oooo00140?ooo`030000003oool0oooo0?l0oooo8@3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo01H0oooo2@00000<0?ooo`00A03oool2000004`0oooo
00<0o`000?ooo`3oool0dP3oool00`000000oooo0?ooo`0F0?ooo`<00000603oool9000000`0oooo
00140?ooo`030000003oool0oooo04`0oooo0P3o003B0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`00A03oool00`000000oooo0?ooo`1>
0?ooo`80o`00d03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0180oooo00140?oo
o`030000003oool0oooo0500oooo0P3o003>0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool04P3oool004@0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool04P3oool004@0oooo00<000000?ooo`3oool0E`3oool20?l00<L0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0B0?ooo`00A03oool2000005X0oooo0P3o
00350?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool04P3oool004@0oooo00<00000
0?ooo`3oool0F`3oool20?l00<<0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0B
0?ooo`00A03oool00`000000oooo0?ooo`1R0?ooo`80o`00_03ooole000001@0oooo00140?ooo`03
0000003oool0oooo06@0oooo0`3o003o0?ooo`<0oooo00140?ooo`030000003oool0oooo06L0oooo
0P3o003o0?ooo`40oooo00140?ooo`030000003oool0oooo0?l0ooooJP3oool004@0oooo00<00000
0?ooo`3oool0K@3oool50?l00?L0oooo00140?ooo`800000L`3oool20?l00?D0oooo00140?ooo`03
0000003oool0oooo07T0oooo00<0o`000?ooo`3oool0k@3oool004@0oooo00<000000?ooo`3oool0
NP3oool30?l00>`0oooo000W0?ooo`L000000`3oool4000000D0oooo100000060?ooo`030000003o
ool0oooo07d0oooo0`3o003Y0?ooo`00:P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0Q@3oool30?l00>40oooo000Z0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`280?ooo`@0o`00g@3oool002X0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0940oooo0`3o003E0?ooo`00:P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo00<0oooo0`00002D0?ooo`@0o`00d@3oool002X0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo09`0oooo0`3o003:0?ooo`00:P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0W`3oool40?l00<H0oooo000X0?ooo`<000001@3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0:P0oooo0P3o002o0?ooo`00:P3oool00`000000oooo0?ooo`04
0?ooo`@000001@3oool4000000H0oooo00<000000?ooo`3oool0ZP3oool50?l00;X0oooo00140?oo
o`030000003oool0oooo0;@0oooo103o002a0?ooo`00A03oool200000;T0oooo0`3o002^0?ooo`00
A03oool00`000000oooo0?ooo`300?ooo`<0o`00YP3oool004@0oooo00<000000?ooo`3oool0``3o
ool40?l000D0oooo0`3o002J0?ooo`00A03oool00`000000oooo0?ooo`3?0?ooo`@0o`00UP3oool0
04@0oooo00<000000?ooo`3oool0f03oool70?l008X0oooo00140?ooo`030000003oool0oooo0>@0
oooo0`3o00220?ooo`00A03oool00`000000oooo0?ooo`3o0?ooofX0oooo00140?ooo`800000o`3o
oom[0?ooo`00A03oool00`000000oooo0?ooo`3o0?ooofX0oooo00140?ooo`030000003oool0oooo
0?l0ooooJP3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool005<0oooo00<000000?ooo`3oool0o`3ooomK0?ooo`00D`3o
ool200000?l0ooooG03oool001D0oooo100000030?ooo`L00000103oool5000000<0oooo1@000004
0?ooo`D000003@3oool00`000000oooo00000002000000D0oooo00<000000?ooo`3oool03`3oool5
000000@0oooo100000040?ooo`D000003@3oool3000000030?ooo`00000000000080oooo1`000004
0?ooo`D00000103oool5000000@0oooo100000040?ooo`D000001@3oool4000000<0oooo0`000002
0?ooo`<00000103oool4000000X0oooo0`0000030?ooo`H000000`3oool6000000<0oooo0`000000
0`3oool0000000000003000000D0oooo1@00002T0?ooo`00503oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool02P3oool2000000<0oooo00<000000?ooo`3oool00P3oool200000140oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03@3oool010000000oooo0?ooo`3oool2000000H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`0000050?ooo`040000003oool0oooo000000D0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`2Q0?ooo`004`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo1@0000030?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool0oooo1@0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2Q0?ooo`004`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00D0oooo100000050?ooo`@000001@3oool4000000D0oooo
1@0000080?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo1P0000040?ooo`030000003oool0oooo00D0oooo
1P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000000`3oool01`000000oooo0000003oool00000
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`@00000Y03oool001@0oooo00@000000?ooo`3oool0oooo0P00
00050?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool4000001P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P00000>0?ooo`040000003oool0oooo0?oo
o`8000001P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000060?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000040?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0X@3oool001D0oooo
0`0000000`3oool000000?ooo`040?ooo`030000003oool0oooo00D0oooo0`0000060?ooo`D00000
103oool5000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01<0oooo1P0000040?ooo`@00000103oool2000000040?ooo`0000000000000000`0
oooo0`0000000`3oool000000?ooo`030?ooo`<000001P3oool6000000<0oooo1P0000040?ooo`@0
0000103oool2000000040?ooo`0000000000000000@0oooo100000030?ooo`80000000@0oooo0000
0000000000000`3oool7000000d0oooo00<000000?ooo`000000103oool01`000000oooo0000003o
ool000000?ooo`000000103oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool500000:<0oooo000O0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`3oool2000001L0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`800000
1@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000[@3oool001l0oooo
00<000000?ooo`3oool08@3oool2000000H0oooo0`0000000`3oool000000?ooo`0F0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool03`3oool2000000@0oooo0`0000030?ooo`<00000
0`3oool2000000D0oooo1@00002^0?ooo`007@3oool300000280oooo0P000000103oool000000000
0000000P0?ooo`<000008@3oool2000000H0oooo00<000000?ooo`3oool01`3oool3000000H0oooo
0`00003o0?ooo`L0oooo002D0?ooo`030000003oool0oooo0?l0oooo6P3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00:d0oooo1000003o0?ooo`00/@3oool00`000000oooo0?ooo`2]0?ooo`030000
003oool0oooo04`0oooo002a0?ooo`030000003oool0oooo0:d0oooo0P00001=0?ooo`00303oool4
000000<0oooo0`0000020?ooo`<000000P3oool5000000D0oooo100000030?ooo`<000000P3oool3
000000030?ooo`000000000000D00000103oool4000000`0oooo1`0000020?ooo`<000000P3oool3
000000@0oooo100000040?ooo`D000000P3oool200000080oooo0`0000040?ooo`@00000303oool7
000000@0oooo0`000000103oool000000000003oool300000080oooo0`0000020?ooo`<0000000<0
oooo0000003oool0303oool5000000D0oooo100000060?ooo`@00000103oool4000000<0oooo0`00
00020?ooo`<00000103oool400000080oooo1`0000040?ooo`@000000`3oool300000080oooo0`00
000<0?ooo`D000000`3oool5000000D0oooo1@0000040?ooo`@000001P3oool400000080oooo1`00
00040?ooo`@000000`3oool300000080oooo0`0000030?ooo`030000003oool0oooo04/0oooo000;
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000`3oool2000000h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3o
ool2000004`0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0D03oool000X0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`@00000103oool3000000H0oooo1P00000>0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00D0oooo1P0000040?ooo`030000003oool0oooo00D0oooo1P0000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo10000003
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo0500oooo000:0?ooo`030000003oool0oooo00L0oooo0P0000030?ooo`030000003oool0
oooo0080oooo0P0000060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P00
00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`3oool2000000h0oooo00<000000?ooo`3oool0103oool2000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000103oool010000000
oooo0?ooo`0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P000003
0?ooo`040000003oool0oooo000000<0oooo0P00000>0?ooo`8000001P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0
oooo0P0000060?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`3oool2
000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo0500oooo000:
0?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool0oooo0000003oool3000000@0oooo
0P000000103oool000000000000000040?ooo`@000000`3oool2000000040?ooo`00000000000000
00@0oooo0`0000070?ooo`<0000000<0oooo0000003oool02`3oool3000000D0oooo0P000000103o
ool000000000000000030?ooo`L00000103oool3000000D0oooo00<000000?ooo`0000000P000005
0?ooo`@000003`3oool00`000000oooo0?ooo`030?ooo`8000000`3oool200000080oooo0P000000
103oool000000000000000040?ooo`<0000000<0oooo000000000000303oool2000000040?ooo`00
00000000000000@0oooo100000030?ooo`L00000103oool4000000<0oooo0P000000103oool00000
0000000000030?ooo`L000000`3oool3000000L0oooo100000030?ooo`80000000@0oooo00000000
000000003@3oool6000000<0oooo0P000000103oool000000000000000040?ooo`<000001P3oool3
000000040?ooo`000000oooo0?ooo`L000000`3oool3000000L0oooo100000030?ooo`80000000@0
oooo0000000000000000D`3oool000/0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0K`3oool000`0oooo0`0000000`3oool000000?oo
o`020?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0K`3oool001<0oooo0P00000U
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool07P3oool2000001X0oooo0`00001R
0?ooo`030000003oool0oooo0280oooo0`00000Y0?ooo`030000003oool0oooo06D0oooo000j0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo06D0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000
\
\>"],
  ImageRangeCache->{{{0, 431}, {226.125, 0}} -> {-1.06191, -0.648943, \
0.00860958, 0.00860958}, {{10.75, 359.188}, {220.688, 5.375}} -> {-2969.91, \
-20.5232, 64.6318, 1.13538}, {{359.188, 411.5}, {165.313, 78.1875}} -> \
{-23.1884, -3.47834, 0.0964144, 0.0833295}, {{362, 377.563}, {162.063, \
144.063}} -> {-24.4493, -15.9524, 0.101206, 0.327509}, {{362, 377.563}, \
{141.188, 123.188}} -> {-24.4493, -20.5102, 0.101206, 0.327509}, {{362, \
377.563}, {120.25, 102.25}} -> {-24.4493, -25.0817, 0.101206, 0.327509}, \
{{362, 377.563}, {99.375, 81.375}} -> {-24.4493, -29.6396, 0.101206, \
0.327509}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[39]="]
}, Open  ]],

Cell["\<\
Input more complicated  can be evaluated. Here is supposed  a continuous \
input: 1+0.3 Cos[t] Bq/day \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RespiratoryTract[{1 + 0.3\ Cos[t], \ t}, AMADAdultW[5], S, \ t1, 0, 
      IntakeType \[Rule] "\<Continuous\>"]\)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \({q\_ET1[t1] \[Rule] \(\(0.3386996`\)\(\[InvisibleSpace]\)\) - 
          0.38950454`\ \[ExponentialE]\^\(-t1\) + 0.05080494`\ Cos[t1] + 
          0.05080494`\ Sin[t1], 
      q\_AI[t1] \[Rule] \(\(53.92899114028488`\)\(\[InvisibleSpace]\)\) - 
          2.067699575970074`*^-7\ \[ExponentialE]\^\(\(-100.11999999999999`\)\
\ t1\) - 4.13618404885183`*^-7\ \[ExponentialE]\^\(\(-100.101`\)\ t1\) - 
          6.893700681984995`*^-8\ \[ExponentialE]\^\(\(-100.10012`\)\ t1\) - 
          0.7931694753791881`\ \[ExponentialE]\^\(\(-0.0201`\)\ t1\) - 
          28.983238094734435`\ \[ExponentialE]\^\(\(-0.0011`\)\ t1\) - 
          24.152689995560003`\ \[ExponentialE]\^\(\(-0.00022`\)\ t1\) + 
          0.00010711471412078116`\ Cos[t1] + 0.0159388338148901`\ Sin[t1], 
      q\_bb1[t1] \[Rule] \(\(0.026909922259104675`\)\(\[InvisibleSpace]\)\) - 
          8.121732640976685`*^-8\ \[ExponentialE]\^\(\(-102.1`\)\ t1\) - 
          2.088585430272496`*^-9\ \[ExponentialE]\^\(\(-100.11999999999999`\)\
\ t1\) - 2.0691265877189862`*^-10\ \[ExponentialE]\^\(\(-100.101`\)\ t1\) - 
          0.0039586477610043126`\ \[ExponentialE]\^\(\(-2.0001`\)\ t1\) - 
          0.008011812882618062`\ \[ExponentialE]\^\(\(-0.0201`\)\ t1\) - 
          0.014498868481608022`\ \[ExponentialE]\^\(\(-0.0011`\)\ t1\) - 
          0.0012077069621957317`\ \[ExponentialE]\^\(\(-0.00022`\)\ t1\) + 
          0.0007671973437975979`\ Cos[t1] + 0.00043623235699064315`\ Sin[t1], 
      q\_bb2[t1] \[Rule] \(\(0.1455025272461415`\)\(\[InvisibleSpace]\)\) - 
          5.68030337107331`*^-8\ \[ExponentialE]\^\(\(-100.13`\)\ t1\) - 
          0.14554199576357083`\ \[ExponentialE]\^\(\(-0.0301`\)\ t1\) + 
          0.00003952532046305643`\ Cos[t1] + 0.0013126982397510614`\ Sin[t1], 
      q\_bbseq[t1] \[Rule] \(\(0.007637071336230146`\)\(\[InvisibleSpace]\)\) \
- 1.0006208709504774`*^-9\ \[ExponentialE]\^\(\(-100.11`\)\ t1\) - 
          0.007637304259935541`\ \[ExponentialE]\^\(\(-0.0101`\)\ t1\) + 
          2.3392432626633213`*^-7\ Cos[t1] + 
          0.000023137965819260172`\ Sin[t1], 
      q\_BB1[t1] \[Rule] \(\(0.006988349122294753`\)\(\[InvisibleSpace]\)\) - 
          1.1858325416390144`*^-7\ \[ExponentialE]\^\(\(-110.1`\)\ t1\) - 
          2.0304331602441712`*^-8\ \[ExponentialE]\^\(\(-102.1`\)\ t1\) - 
          1.7092186673241171`*^-10\ \[ExponentialE]\^\(\(-100.13`\)\ t1\) - 
          4.1855419444344666`*^-10\ \[ExponentialE]\^\(\(-100.11999999999999`\
\)\ t1\) - 0.0013039342961799981`\ \[ExponentialE]\^\(\(-10.0001`\)\ t1\) - 
          0.0009896619402510781`\ \[ExponentialE]\^\(\(-2.0001`\)\ t1\) - 
          0.000437939806710845`\ \[ExponentialE]\^\(\(-0.0301`\)\ t1\) - 
          0.0016055737239715551`\ \[ExponentialE]\^\(\(-0.0201`\)\ t1\) - 
          0.002900063702691873`\ \[ExponentialE]\^\(\(-0.0011`\)\ t1\) - 
          0.000241544290970638`\ \[ExponentialE]\^\(\(-0.00022`\)\ t1\) + 
          0.0004905081569297328`\ Cos[t1] + 0.00014023101777122188`\ Sin[t1], 
      q\_BB2[t1] \[Rule] \(\(0.19651470433950813`\)\(\[InvisibleSpace]\)\) - 
          7.671778344007501`*^-8\ \[ExponentialE]\^\(\(-100.13`\)\ t1\) - 
          0.19656801024546142`\ \[ExponentialE]\^\(\(-0.0301`\)\ t1\) + 
          0.00005338262373671468`\ Cos[t1] + 0.0017729211399557562`\ Sin[t1], 
      q\_BBseq[t1] \[Rule] \(\(0.012293373625358645`\)\(\[InvisibleSpace]\)\) \
- 1.6106967818365173`*^-9\ \[ExponentialE]\^\(\(-100.11`\)\ t1\) - 
          0.012293748562034048`\ \[ExponentialE]\^\(\(-0.0101`\)\ t1\) + 
          3.7654737218571607`*^-7\ Cos[t1] + 
          0.00003724512266862647`\ Sin[t1], 
      q\_LNth[t1] \[Rule] \(\(6.82358222425647`\)\(\[InvisibleSpace]\)\) + 
          2.6113176527875227`*^-9\ \[ExponentialE]\^\(\(-100.11`\)\ t1\) + 
          1.1489501136645882`*^-8\ \[ExponentialE]\^\(\(-100.10012`\)\ t1\) - 
          1.4101093421305661`*^-8\ \[ExponentialE]\^\(\(-100.1`\)\ t1\) + 
          0.019931052821969587`\ \[ExponentialE]\^\(\(-0.0101`\)\ t1\) + 
          4.025448332593334`\ \[ExponentialE]\^\(\(-0.00022`\)\ t1\) - 
          10.868960973959807`\ \[ExponentialE]\^\(\(-0.0001`\)\ t1\) - 
          6.357116931870391`*^-7\ Cos[t1] + 6.169277711842551`*^-9\ Sin[t1], 
      q\_ET2[t1] \[Rule] \(\(0.004742794188988448`\)\(\[InvisibleSpace]\)\) - 
          2.5767206676491033`*^-6\ \[ExponentialE]\^\(\(-200.1`\)\ t1\) - 
          1.317591712933376`*^-8\ \[ExponentialE]\^\(\(-110.1`\)\ t1\) - 
          2.071870571648877`*^-9\ \[ExponentialE]\^\(\(-102.1`\)\ t1\) - 
          0.005161084727152685`\ \[ExponentialE]\^\(\(-100.0001`\)\ t1\) - 
          0.0001448815884644442`\ \[ExponentialE]\^\(\(-10.0001`\)\ t1\) - 
          0.00010098591227051818`\ \[ExponentialE]\^\(\(-2.0001`\)\ t1\) - 
          0.00010279522231141635`\ \[ExponentialE]\^\(\(-0.0301`\)\ t1\) - 
          0.00016058949029521457`\ \[ExponentialE]\^\(\(-0.0201`\)\ t1\) - 
          0.00029000927036189095`\ \[ExponentialE]\^\(\(-0.0011`\)\ t1\) - 
          0.000024154458082413496`\ \[ExponentialE]\^\(\(-0.00022`\)\ t1\) + 
          0.0012442985335725297`\ Cos[t1] + 
          0.000026994929366548603`\ Sin[t1], 
      q\_ETseq[t1] \[Rule] \(\(0.1811372277181665`\)\(\[InvisibleSpace]\)\) - 
          2.5850016248447843`*^-9\ \[ExponentialE]\^\(\(-100.101`\)\ t1\) - 
          0.1811372914823913`\ \[ExponentialE]\^\(\(-0.0011`\)\ t1\) + 
          6.634922642402631`*^-8\ Cos[t1] + 0.00005977521812169233`\ Sin[t1], 
      q\_LNet[t1] \[Rule] \(\(1.8113722572965991`\)\(\[InvisibleSpace]\)\) + 
          2.5850016248458406`*^-9\ \[ExponentialE]\^\(\(-100.101`\)\ t1\) - 
          2.585027447847903`*^-9\ \[ExponentialE]\^\(\(-100.1`\)\ t1\) + 
          0.1811372914823913`\ \[ExponentialE]\^\(\(-0.0011`\)\ t1\) - 
          1.9925094890037656`\ \[ExponentialE]\^\(\(-0.0001`\)\ t1\) - 
          5.977519903197299`*^-8\ Cos[t1]}\)], "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell[TextData[{
  "Here is supposed a constant intake during  ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < T\)]],
  ", in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(t = T\)\)\)]],
  " it is cutted the intake. We want to know the retention in lungs (AMAD 5, \
and S) as function of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ". At the en of ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " the retention in lungs is qLungs5SCronic[T] that it must be multiplied by \
1/ qLungs5S[0] because  of the total intake only the fraction qLungs5S[0] is \
retained in Lungs."
}], "MathCaption"],

Cell[BoxData[
    \(qLungscutting[t1_, T_] := 
      If[t1 < T, 
        qLungs5SCronic[t1], \(\(\(1\)\(\ \)\)\/qLungs5S[0]\) 
          qLungs5SCronic[T] qLungs5S[t1\  - T\ ]]; \)], "Input",
  CellLabel->"In[41]:="],

Cell[TextData[{
  "Now we plot in log-scale the retention in Lungs assuming a constant intake \
during  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(T\)\(\ \)\(=\)\)\)]],
  "200 days"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LogPlot[qLungscutting[t, 200], \ {t, 0, 1000}]\)], "Input",
  CellLabel->"In[42]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000952381 0.330926 0.302959 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -12 -9 ]
[.97619 -0.0125 12 0 ]
[-0.0125 .02797 -22 -6.25 ]
[-0.0125 .02797 0 6.25 ]
[-0.0125 .11917 -22 -6.25 ]
[-0.0125 .11917 0 6.25 ]
[-0.0125 .23973 -22 -6.25 ]
[-0.0125 .23973 0 6.25 ]
[-0.0125 .33093 -10 -6.25 ]
[-0.0125 .33093 0 6.25 ]
[-0.0125 .42213 -10 -6.25 ]
[-0.0125 .42213 0 6.25 ]
[-0.0125 .54269 -10 -6.25 ]
[-0.0125 .54269 0 6.25 ]
[ -0.0005 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(200)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(400)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(600)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(800)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1000)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02797 m
.00625 .02797 L
s
gsave
-0.0125 .02797 -83 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11917 m
.00625 .11917 L
s
gsave
-0.0125 .11917 -83 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
81.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .23973 m
.00625 .23973 L
s
gsave
-0.0125 .23973 -83 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
81.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .33093 m
.00625 .33093 L
s
gsave
-0.0125 .33093 -71 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .42213 m
.00625 .42213 L
s
gsave
-0.0125 .42213 -71 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .54269 m
.00625 .54269 L
s
gsave
-0.0125 .54269 -71 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .17252 m
.00375 .17252 L
s
0 .21037 m
.00375 .21037 L
s
0 .26372 m
.00375 .26372 L
s
0 .284 m
.00375 .284 L
s
0 .30157 m
.00375 .30157 L
s
0 .31706 m
.00375 .31706 L
s
0 .47547 m
.00375 .47547 L
s
0 .51333 m
.00375 .51333 L
s
0 .56667 m
.00375 .56667 L
s
0 .58696 m
.00375 .58696 L
s
0 .60453 m
.00375 .60453 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02498 0 m
.02499 .00342 L
.02605 .0845 L
.02729 .13981 L
.02846 .17636 L
.03053 .22289 L
.03279 .25906 L
.03527 .28933 L
.0379 .31471 L
.04262 .3497 L
.04749 .37709 L
.05205 .39772 L
.06244 .43362 L
.07305 .46067 L
.08274 .48035 L
.10458 .51413 L
.12357 .53637 L
.14429 .55608 L
.16561 .57302 L
.18493 .58627 L
.19461 .59231 L
.1997 .59535 L
.20508 .59847 L
.2098 .60113 L
.21109 .60184 L
.21247 .60261 L
.21378 .60332 L
.21497 .57366 L
.21613 .56844 L
.21721 .56662 L
.21964 .56325 L
.22406 .55748 L
.24432 .53547 L
.26333 .52029 L
.2815 .5095 L
.30108 .50077 L
.32112 .49399 L
.34222 .4884 L
.38033 .48066 L
.42089 .47409 L
.45994 .46849 L
.50143 .46289 L
.54141 .45765 L
.57988 .45269 L
.6208 .44747 L
.6602 .44249 L
.69809 .43773 L
.73843 .4327 L
.77725 .42789 L
.81853 .42281 L
Mistroke
.85829 .41795 L
.89654 .41331 L
.93723 .40841 L
.97619 .40375 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[42]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00;03oool4000003/0oooo1P0000040?ooo`@000001@3oool4000003@0oooo100000040?oo
o`@000001@3oool4000003D0oooo100000040?ooo`@000001@3oool4000003<0oooo100000050?oo
o`@000001@3oool4000002h0oooo1`0000030?ooo`@000001@3oool4000000D0oooo100000040?oo
o`00:`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`010?ooo`00:`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00@3oool002/0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0;`3oool60000
00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool0<@3oool2000000<0oooo00@000000?ooo`3oool00000103oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`010?ooo`00:`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`0`0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo00000002000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool0<03oool4000000@0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`010?ooo`00:`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0`0?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool00@3oool002/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool00@3oool002/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0a0?ooo`030000003oool0000000@0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo02`0oooo0`0000050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`010?ooo`00
;03oool4000003`0oooo100000050?ooo`@000001@3oool4000003D0oooo0P0000050?ooo`@00000
1@3oool4000003L0oooo0`0000030?ooo`@000001@3oool4000003<0oooo100000050?ooo`@00000
1@3oool400000340oooo00<000000?ooo`3oool0103oool4000000D0oooo100000050?ooo`@00000
103oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool002D0ooooo`000023000000T0
oooo000U0?ooo`030000003oool0oooo00H0oooo0P00000A0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0403oool002D0oooo00<000000?ooo`3oool01P3oool2000004P0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`0@0?ooo`009@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0?l0ooooO`3oool002D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`3o0?ooogl0oooo000U0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0o`3ooomo0?ooo`009@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo
O`3oool002D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooogl0oooo0005
0?ooo`@000001P3oool2000000D0oooo1`0000080?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0o`3ooomo0?ooo`00103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo0P0000080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`3o0?ooogl0oooo00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0o`3ooomo0?ooo`00103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool02@3oool4000000H0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooO`3oool000@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooogl0oooo00040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00/0oooo0`00000;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0o`3ooomo0?ooo`001@3oool400000100oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0?l0ooooO`3oool002D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`3o0?ooogl0oooo000U0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0o`3ooomo0?ooo`009@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0?l0ooooO`3oool002D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooogl0
oooo000U0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`009@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooO`3oool002D0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooogl0oooo000U0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`009@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0?l0ooooO`3oool002D0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`3o0?ooogl0oooo000U0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3o
oomo0?ooo`009@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooO`3oool0
02D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooogl0oooo000U0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`009@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0?l0ooooO`3oool002D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`3o0?ooogl0oooo000U0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0o`3ooomo0?ooo`009@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0?l0ooooO`3oool002D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooogl0
oooo000U0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`009@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooO`3oool002D0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooogl0oooo000U0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`009@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0?l0ooooO`3oool002D0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`3o0?ooogl0oooo000U0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3o
oomo0?ooo`001@3oool4000000H0oooo0P0000050?ooo`H000002@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0?l0ooooO`3oool000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooogh0oooo00040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooomn0?ooo`00103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool4000000L0oooo
00<000000?ooo`3oool0o`3ooomn0?ooo`00103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0?l0ooooOP3oool000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o
0?ooogh0oooo00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`3o0?ooogh0oooo00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`3o0?ooogh0oooo00050?ooo`@000003P3oool4000000X0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooogh0oooo000U0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0o`3ooomn0?ooo`009@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0?l0ooooOP3oool002D0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`3o0?ooogh0oooo000U0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0o`3ooomn0?ooo`009@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo
OP3oool002D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooogh0oooo000U
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooomn0?ooo`009@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooOP3oool002D0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`3o0?ooogh0oooo000U0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0o`3ooomn0?ooo`009@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0?l0ooooOP3oool002D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o
0?ooogh0oooo000U0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooomn0?oo
o`009@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooOP3oool002D0oooo
0`0000080?ooo`030000003oool0oooo0?l0ooooOP3oool002D0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`3o0?ooogh0oooo000U0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0o`3ooomn0?ooo`009@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0?l0ooooOP3oool002D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooogh0
oooo000U0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooomn0?ooo`009@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooOP3oool002D0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooogh0oooo000U0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0o`3ooomn0?ooo`009@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0?l0ooooOP3oool002D0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`3o0?ooogh0oooo000U0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3o
oomn0?ooo`009@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0ooooO@3oool0
02D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooogd0oooo000U0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooomm0?ooo`009@3oool3000000T0oooo
00<000000?ooo`3oool0o`3ooomm0?ooo`009@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0?l0ooooO@3oool002D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o
0?ooogd0oooo000U0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooomm0?oo
o`009@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0ooooO@3oool002D0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooogd0oooo000U0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0o`3ooomm0?ooo`009@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0?l0ooooO@3oool000D0oooo100000060?ooo`8000001P3oool40000
00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooogd0oooo00040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0o`3ooomm0?ooo`00103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo
O@3oool000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00L0oooo100000080?ooo`030000003oool0oooo0?l0ooooO@3oool000@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooogd0oooo00040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02`3oool4000000X0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`3o0?ooog`0oooo00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0o`3oooml0?ooo`00103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo
O03oool000D0oooo1000000>0?ooo`D000002@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0?l0ooooO03oool002D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o
0?ooog`0oooo000U0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3oooml0?oo
o`009@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooO03oool002D0oooo
0`00000:0?ooo`030000003oool0oooo0?l0ooooO03oool002D0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`3o0?ooog`0oooo000U0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0o`3oooml0?ooo`009@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0?l0ooooO03oool002D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?ooog`0
oooo000U0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooomk0?ooo`009@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooN`3oool002D0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooog/0oooo000U0?ooo`<000002`3oool00`00
0000oooo0?ooo`3o0?ooog/0oooo000U0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0o`3ooomk0?ooo`009@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo
N`3oool002D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooog/0oooo000U
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooomk0?ooo`009@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooN`3oool002D0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`3o0?ooog/0oooo000U0?ooo`<000002`3oool00`000000oooo
0?ooo`3o0?ooog/0oooo000U0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3o
oomj0?ooo`009@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooNP3oool0
02D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooogX0oooo000U0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooomj0?ooo`009@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooNP3oool002D0oooo0`00000<0?ooo`030000003o
ool0oooo0?l0ooooNP3oool002D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o
0?ooogX0oooo000F0?ooo`L00000203oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0?l0ooooNP3oool001T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0?l0ooooN@3oool001T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooN@3oool001T0oooo00<000000?ooo`3oool02@3o
ool4000000`0oooo00<000000?ooo`3oool0o`3ooomi0?ooo`006@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooomi0?ooo`006@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooomi0?oo
o`006@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0o`3ooomi0?ooo`005`3oool3000000/0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`3o0?ooogP0oooo000I0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`3o0?ooogP0oooo000U0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0o`3ooomh0?ooo`009@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0?l0ooooN03oool002D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?ooogP0
oooo000U0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooomh0?ooo`009@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooM`3oool002D0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooogL0oooo000U0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0o`3ooomg0?ooo`009@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0?l0ooooM`3oool002D0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`3o0?ooogL0oooo000U0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3o
oomg0?ooo`009@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooMP3oool0
02D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?ooogH0oooo000U0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0o`3ooomf0?ooo`009@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooMP3oool002D0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`3o0?ooogH0oooo000U0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0o`3ooomf0?ooo`009@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0?l0ooooMP3oool002D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooogD0
oooo000U0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooome0?ooo`009@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooM@3oool002D0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooogD0oooo000U0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0o`3ooome0?ooo`009@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0?l0ooooGP3oool400000180oooo000U0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0o`3ooomF0?ooo`P000005P3oool002D0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`3o0?ooodl0oooo1`00000N0?ooo`009@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0?l0ooooA`3oool8000002D0oooo000F0?ooo`H000002@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0oooo?P3oool8000002d0oooo000F0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0?l0oooo=P3oool8000003D0oooo000G0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?ooob/0oooo2`00000m0?ooo`00603o
ool00`000000oooo0?ooo`0:0?ooo`@000004`3oool00`000000oooo0?ooo`3o0?oooal0oooo2`00
00180?ooo`006@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0o`3ooolG0?ooo`P00000D`3oool001X0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0oooo3`3oool8000005/0oooo000F0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo0?l0oooo1`3oool8000006<0oooo000F0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?h0oooo
1`00001[0?ooo`005`3oool4000000X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`3f0?ooo`P00000LP3oool002D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3_
0?ooo`L00000NP3oool002D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3V0?oo
o`P00000P@3oool002D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3O0?ooo`L0
0000R@3oool002D0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3F0?ooo`P00000
T03oool002D0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3?0?ooo`L00000V03o
ool002D0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`370?ooo`P00000W`3oool0
02D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`2n0?ooo`P00000Y`3oool002D0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`2f0?ooo`P00000[`3oool002D0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`2^0?ooo`L00000]`3oool002D0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`2V0?ooo`P00000_P3oool002D0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`2O0?ooo`L00000aP3oool002D0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`2F0?ooo`P00000c@3oool002D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`2>0?ooo`P00000e@3oool002D0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`250?ooo`P00000g@3oool002D0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`1o0?ooo`H00000i@3oool002D0oooo0`00000L0?ooo`030000003oool0
oooo07T0oooo1@00003[0?ooo`009@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
07<0oooo1P00003`0?ooo`009@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06d0
oooo1@00003f0?ooo`009@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo06P0oooo
1000003k0?ooo`009@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo06<0oooo1@00
003o0?ooo`009@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo05h0oooo1000003o
0?ooo`D0oooo000U0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0F@3oool40000
0?l0oooo2@3oool002D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1E0?ooo`@0
0000o`3oool=0?ooo`009@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0500oooo
1000003o0?oooa40oooo000U0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0C03o
ool300000?l0oooo5@3oool002D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`19
0?ooo`800000o`3ooolH0?ooo`009@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
04L0oooo0P00003o0?oooaX0oooo000U0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0A03oool200000?l0oooo703oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo0?l0oooo703oool002D0oooo0`00000U0?ooo`030000003o
ool0oooo0400oooo0P00003o0?oooal0oooo000U0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0?@3oool200000?l0oooo8@3oool002D0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`0j0?ooo`800000o`3ooolS0?ooo`009@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`009@3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`009@3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo03@0oooo0P00003o0?ooobL0oooo000U
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`3o
0?ooobL0oooo000U0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`3o0?ooobP0oooo000U0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0;@3oool200000?l0oooo:`3oool001L0oooo1000000:0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3o0?ooob/0oooo000F0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0o`3oool/0?ooo`006`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3o
0?ooobd0oooo000K0?ooo`030000003oool0oooo00L0oooo1000000_0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0o`3oool^0?ooo`006`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`3o0?ooobl0
oooo000G0?ooo`@000002P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0o`3oool`0?ooo`005`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?oooc40oooo000G
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo0?l0oooo<P3oool001L0oooo1@0000090?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`3o0?oooc<0oooo000U0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?oooc@0
oooo000U0?ooo`030000003oool0oooo03L0oooo0P00000I0?ooo`030000003oool0oooo0?l0oooo
=03oool002D0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0?l0oooo=@3oool002D0oooo0`00000j0?ooo`030000003oool0oooo01<0oooo0P00003o
0?ooocL0oooo000U0?ooo`030000003oool0oooo03/0oooo0P00000C0?ooo`030000003oool0oooo
0?l0oooo=P3oool002D0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0?l0oooo=P3oool002D0oooo00<000000?ooo`3oool0?P3oool200000100oooo
00<000000?ooo`3oool0o`3ooolf0?ooo`009@3oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`009@3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`009@3oool00`00
0000oooo0?ooo`120?ooo`800000303oool00`000000oooo0?ooo`3o0?ooocH0oooo000U0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooocH0
oooo000U0?ooo`<00000A@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo
=`3oool002D0oooo00<000000?ooo`3oool0AP3oool2000000L0oooo00<000000?ooo`3oool0o`3o
oolg0?ooo`009@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0o`3ooolg0?ooo`009@3oool00`000000oooo0?ooo`190?ooo`800000103oool00`00
0000oooo0?ooo`3o0?ooocL0oooo000U0?ooo`030000003oool0oooo04/0oooo0P0000020?ooo`03
0000003oool0oooo0?l0oooo=`3oool002D0oooo00<000000?ooo`3oool0C@3oool300000?l0oooo
>@3oool002D0oooo0`00001?0?ooo`030000003oool0oooo0?l0oooo=`3oool002D0oooo00<00000
0?ooo`3oool0o`3ooon90?ooo`009@3oool00`000000oooo0?ooo`3o0?ooohT0oooo000U0?ooo`03
0000003oool0oooo0?l0ooooR@3oool002D0oooo00<000000?ooo`3oool0o`3ooon90?ooo`009@3o
ool00`000000oooo0?ooo`3o0?ooohT0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-128.284, -1.2926, 4.0979, \
0.0128821}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[42]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[qLungs1SCronic, qLungs3SCronic, qLungs5SCronic, 
      qLungs10SCronic, \ qLungscutting]\)], "Input",
  CellLabel->"In[43]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 6", "SubsubsectionIcon",
  CellTags->"Examples"],

Cell[TextData[{
  "Here is evaluated the retention in RT for a child 10 y old (breathing rate \
1.12 m3/h) of a intake \"int\"  of U-238 (\[Lambda] = 0)  of aerosols type S  \
and AMAD = 1 \[Mu]m  in t = 0. Also, are changed same clearance rates. {",
  Cell[BoxData[
      \(k\_"ET2,ST" \[Rule] 50\)]],
  ", ",
  Cell[BoxData[
      \(k\_"AI3,bb1" \[Rule] 0.003\)]],
  "}"
}], "MathCaption",
  CellTags->"Examples"],

Cell[TextData[{
  "The fractional deposition ",
  Cell[BoxData[
      \({AI, bb\_\(fast + seq\), bb\_slow, \ BB\_\(fast + seq\)\ , \ 
        BB\_slow, \ \ ET\_2, \ ET\_1}\)]],
  " are taken from ICRP 66, Table F5 "
}], "SmallText"],

Cell["By default RespiratoryTract has the following options", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[RespiratoryTract]\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \({IntakeType \[Rule] "Acute", fAI1 \[Rule] 0.3`, fAI2 \[Rule] 0.6`, 
      fAI3 \[Rule] 0.1`, fbs \[Rule] 0.007`, fBs \[Rule] 0.007`, 
      fet2 \[Rule] 0.9995`, k\_"AI1,bb1" \[Rule] 0.02`, 
      k\_"AI2,bb1" \[Rule] 0.001`, k\_"AI3,bb1" \[Rule] 0.0001`, 
      k\_"AI3,TH" \[Rule] 0.00002`, k\_"bb1,BB1" \[Rule] 2, 
      k\_"bb2,BB1" \[Rule] 0.03`, k\_"bbseq,TH" \[Rule] 0.01`, 
      k\_"BB1,ET2" \[Rule] 10, k\_"BB2,ET2" \[Rule] 0.03`, 
      k\_"BBseq,TH" \[Rule] 0.01`, k\_"ET2,ST" \[Rule] 100, 
      k\_"ETseq,ET" \[Rule] 0.001`, k\_Env \[Rule] 1}\)], "Output",
  CellLabel->"Out[44]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RespiratoryTract[
      int, {8.0\ 10^\(-2\), \ 6.4\ 10^\(-3\), \ 6.3\ 10^\(-3\)\ , \ 
        6.8\ 10^\(-3\), 6.2\ 10^\(-3\), 2.7\ 10^\(-1\), 2.1\ 10^\(-1\)\ }, 
      S, \ t1, 0, \ k\_"\<ET2,ST\>" \[Rule] 50, 
      k\_"\<AI3,bb1\>" \[Rule] 0.003]\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \({q\_ET1[t1] \[Rule] 0.21000000000000002`\ \[ExponentialE]\^\(-t1\), 
      q\_AI[t1] \[Rule] 
        0.000023952071880189996`\ \[ExponentialE]\^\(\(-100.11999999999999`\)\
\ t1\) + 7.984023960062175`*^-6\ \[ExponentialE]\^\(\(-100.10302`\)\ t1\) + 
          0.00004790414376037999`\ \[ExponentialE]\^\(\(-100.101`\)\ t1\) + 
          0.02397604792811981`\ \[ExponentialE]\^\(\(-0.0201`\)\ t1\) + 
          0.007992015976039938`\ \[ExponentialE]\^\(\(-0.00312`\)\ t1\) + 
          0.04795209585623962`\ \[ExponentialE]\^\(\(-0.0011`\)\ t1\), 
      q\_bb1[t1] \[Rule] 
        6.020598380781367`*^-6\ \[ExponentialE]\^\(\(-102.1`\)\ t1\) + 
          2.4194012000189314`*^-7\ \
\[ExponentialE]\^\(\(-100.11999999999999`\)\ t1\) + 
          1.1994147102219194`*^-8\ \[ExponentialE]\^\(\(-100.10302`\)\ t1\) + 
          2.3964053907148618`*^-8\ \[ExponentialE]\^\(\(-100.101`\)\ t1\) + 
          0.006026625005789396`\ \[ExponentialE]\^\(\(-2.0001`\)\ t1\) + 
          0.00024218230230424055`\ \[ExponentialE]\^\(\(-0.0201`\)\ t1\) + 
          0.000012006153255475676`\ \[ExponentialE]\^\(\(-0.00312`\)\ t1\) + 
          0.000023988041949094356`\ \[ExponentialE]\^\(\(-0.0011`\)\ t1\), 
      q\_bb2[t1] \[Rule] 
        6.2874188685490065`*^-6\ \[ExponentialE]\^\(\(-100.13`\)\ t1\) + 
          0.006293712581131451`\ \[ExponentialE]\^\(\(-0.0301`\)\ t1\), 
      q\_bbseq[t1] \[Rule] 
        8.8722466256189`*^-8\ \[ExponentialE]\^\(\(-100.11`\)\ t1\) + 
          0.0000888112775337438`\ \[ExponentialE]\^\(\(-0.0101`\)\ t1\), 
      q\_BB1[t1] \[Rule] 
        5.115855646484202`*^-6\ \[ExponentialE]\^\(\(-110.1`\)\ t1\) + 
          1.5051495951959922`*^-6\ \[ExponentialE]\^\(\(-102.1`\)\ t1\) + 
          1.8919013646584486`*^-8\ \[ExponentialE]\^\(\(-100.13`\)\ t1\) + 
          4.8484993988360105`*^-8\ \
\[ExponentialE]\^\(\(-100.11999999999999`\)\ t1\) + 
          2.3995540857778008`*^-9\ \[ExponentialE]\^\(\(-100.10302`\)\ t1\) + 
          4.793290110439069`*^-9\ \[ExponentialE]\^\(\(-100.101`\)\ t1\) + 
          0.005120976623104616`\ \[ExponentialE]\^\(\(-10.0001`\)\ t1\) + 
          0.001506656251447349`\ \[ExponentialE]\^\(\(-2.0001`\)\ t1\) + 
          0.000018937951598188918`\ \[ExponentialE]\^\(\(-0.0301`\)\ t1\) + 
          0.000048533527515879866`\ \[ExponentialE]\^\(\(-0.0201`\)\ t1\) + 
          2.4019560418197646`*^-6\ \[ExponentialE]\^\(\(-0.00312`\)\ t1\) + 
          4.7980881986387344`*^-6\ \[ExponentialE]\^\(\(-0.0011`\)\ t1\), 
      q\_BB2[t1] \[Rule] 
        6.187618569047926`*^-6\ \[ExponentialE]\^\(\(-100.13`\)\ t1\) + 
          0.006193812381430953`\ \[ExponentialE]\^\(\(-0.0301`\)\ t1\), 
      q\_BBseq[t1] \[Rule] 
        9.081827254573088`*^-8\ \[ExponentialE]\^\(\(-100.11`\)\ t1\) + 
          0.00009090918172745429`\ \[ExponentialE]\^\(\(-0.0101`\)\ t1\), 
      q\_LNth[t1] \[Rule] \(-1.7954073880190632`*^-7\)\ \
\[ExponentialE]\^\(\(-100.11`\)\ t1\) - 
          5.287433086134506`*^-8\ \[ExponentialE]\^\(\(-100.10302`\)\ t1\) + 
          2.3241506966323105`*^-7\ \[ExponentialE]\^\(\(-100.1`\)\ t1\) - 
          0.00017972045926119813`\ \[ExponentialE]\^\(\(-0.0101`\)\ t1\) - 
          0.000052927258119469785`\ \[ExponentialE]\^\(\(-0.00312`\)\ t1\) + 
          0.0002326477173806679`\ \[ExponentialE]\^\(\(-0.0001`\)\ t1\), 
      q\_ET2[t1] \[Rule] 
        0.0002677149011332536`\ \[ExponentialE]\^\(\(-150.1`\)\ t1\) + 
          1.2789639116199663`*^-6\ \[ExponentialE]\^\(\(-110.1`\)\ t1\) + 
          3.1357283233261583`*^-7\ \[ExponentialE]\^\(\(-102.1`\)\ t1\) + 
          7.500874395382197`*^-9\ \[ExponentialE]\^\(\(-100.13`\)\ t1\) + 
          9.700879149330638`*^-9\ \[ExponentialE]\^\(\(-100.11999999999999`\)\
\ t1\) + 4.799398055199738`*^-10\ \[ExponentialE]\^\(\(-100.10302`\)\ t1\) + 
          9.586771956319952`*^-10\ \[ExponentialE]\^\(\(-100.101`\)\ t1\) + 
          0.26798288401734915`\ \[ExponentialE]\^\(\(-50.0001`\)\ t1\) + 
          0.0012802441557761544`\ \[ExponentialE]\^\(\(-10.0001`\)\ t1\) + 
          0.000313886719051531`\ \[ExponentialE]\^\(\(-2.0001`\)\ t1\) + 
          7.508382778163253`*^-6\ \[ExponentialE]\^\(\(-0.0301`\)\ t1\) + 
          9.710589739071601`*^-6\ \[ExponentialE]\^\(\(-0.0201`\)\ t1\) + 
          4.804202257455878`*^-7\ \[ExponentialE]\^\(\(-0.00312`\)\ t1\) + 
          9.596368324643963`*^-7\ \[ExponentialE]\^\(\(-0.0011`\)\ t1\), 
      q\_ETseq[t1] \[Rule] 
        1.3473040432604704`*^-7\ \[ExponentialE]\^\(\(-100.101`\)\ t1\) + 
          0.0001348652695956591`\ \[ExponentialE]\^\(\(-0.0011`\)\ t1\), 
      q\_LNet[t1] \[Rule] \(-1.3473040432604704`*^-7\)\ \
\[ExponentialE]\^\(\(-100.101`\)\ t1\) + 
          1.3473040432601994`*^-7\ \[ExponentialE]\^\(\(-100.1`\)\ t1\) - 
          0.0001348652695956591`\ \[ExponentialE]\^\(\(-0.0011`\)\ t1\) + 
          0.00013486526959565907`\ \[ExponentialE]\^\(\(-0.0001`\)\ t1\)}\)], \
"Output",
  CellLabel->"Out[45]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 7", "SubsubsectionIcon",
  CellTags->"Examples"],

Cell[TextData[{
  "Here is shown how can be a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function to evaluate the lung retention for an acute intake type S as \
function of  initial deposition values: ",
  Cell[BoxData[
      \({AI\)]],
  ", ",
  Cell[BoxData[
      \(bb\_\(fast + seq\)\)]],
  ", ",
  Cell[BoxData[
      \(\(\(bb\_slow\)\(,\)\)\)]],
  " ",
  Cell[BoxData[
      \(BB\_\(fast + seq\)\)]],
  " ",
  Cell[BoxData[
      \(\(\(,\)\(\ \)\(BB\_slow\)\(,\)\(\ \)\)\)]],
  " ",
  Cell[BoxData[
      \(\(\(ET\_2, \ ET\_1\)\(}\)\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(lung[{ai_, bbf_, \ bbs_, \ BBf_, \ BBs_, \ et2_, \ et1_}, \ t_\ ] = 
      LungsRetention[1, {ai, bbf, \ bbs, \ BBf, \ BBs, \ et2, \ et1}\ , S, \ 
        t, 0]\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \(1.6522149597360367`*^-7\ ai\ \[ExponentialE]\^\(\(-110.1`\)\ t\) - 
      0.0002477542435107005`\ bbf\ \[ExponentialE]\^\(\(-110.1`\)\ t\) + 
      0.000991016974042802`\ BBf\ \[ExponentialE]\^\(\(-110.1`\)\ t\) - 
      1.2565127978773384`*^-6\ bbs\ \[ExponentialE]\^\(\(-110.1`\)\ t\) - 
      6.98602096505397`*^-6\ BBs\ \[ExponentialE]\^\(\(-110.1`\)\ t\) - 
      4.160990610320783`*^-6\ ai\ \[ExponentialE]\^\(\(-102.1`\)\ t\) + 
      0.0012387712175536691`\ bbf\ \[ExponentialE]\^\(\(-102.1`\)\ t\) - 
      8.732526206318113`*^-6\ bbs\ \[ExponentialE]\^\(\(-102.1`\)\ t\) + 
      0.001001006013046979`\ bbs\ \[ExponentialE]\^\(\(-100.13`\)\ t\) + 
      0.0009980029950078517`\ BBs\ \[ExponentialE]\^\(\(-100.13`\)\ t\) + 
      0.0003030312124272516`\ ai\ \[ExponentialE]\^\(\(-100.11999999999999`\)\
\ t\) - 3.469446951953614`*^-18\ bbf\ \[ExponentialE]\^\(\(-100.11`\)\ t\) - 
      3.469446951953614`*^-18\ BBf\ \[ExponentialE]\^\(\(-100.11`\)\ t\) - 
      3.469446951953614`*^-18\ bbs\ \[ExponentialE]\^\(\(-100.11`\)\ t\) - 
      3.469446951953614`*^-18\ BBs\ \[ExponentialE]\^\(\(-100.11`\)\ t\) + 
      0.0005991612638047705`\ ai\ \[ExponentialE]\^\(\(-100.101`\)\ t\) + 
      0.00008317290463989713`\ ai\ \[ExponentialE]\^\(\(-100.10012`\)\ t\) + 
      0.000016633383250131556`\ ai\ \[ExponentialE]\^\(\(-100.1`\)\ t\) + 
      6.9860209650557045`*^-6\ bbf\ \[ExponentialE]\^\(\(-100.1`\)\ t\) + 
      6.9860209650557045`*^-6\ BBf\ \[ExponentialE]\^\(\(-100.1`\)\ t\) + 
      6.9860209650557045`*^-6\ bbs\ \[ExponentialE]\^\(\(-100.1`\)\ t\) + 
      6.9860209650557045`*^-6\ BBs\ \[ExponentialE]\^\(\(-100.1`\)\ t\) + 
      0.0001653868828564822`\ ai\ \[ExponentialE]\^\(\(-10.0001`\)\ t\) - 
      0.24800224575648927`\ bbf\ \[ExponentialE]\^\(\(-10.0001`\)\ t\) + 
      0.9920089830259572`\ BBf\ \[ExponentialE]\^\(\(-10.0001`\)\ t\) - 
      0.0012577705684458532`\ bbs\ \[ExponentialE]\^\(\(-10.0001`\)\ t\) - 
      0.006993013979034946`\ BBs\ \[ExponentialE]\^\(\(-10.0001`\)\ t\) - 
      0.004165155766087867`\ ai\ \[ExponentialE]\^\(\(-2.0001`\)\ t\) + 
      1.2400112287824465`\ bbf\ \[ExponentialE]\^\(\(-2.0001`\)\ t\) - 
      0.008741267473793682`\ bbs\ \[ExponentialE]\^\(\(-2.0001`\)\ t\) + 
      1.0020080210681968`\ bbs\ \[ExponentialE]\^\(\(-0.0301`\)\ t\) + 
      0.9990019970049921`\ BBs\ \[ExponentialE]\^\(\(-0.0301`\)\ t\) + 
      0.30333454697424916`\ ai\ \[ExponentialE]\^\(\(-0.0201`\)\ t\) + 
      8.673617379884035`*^-19\ bbf\ \[ExponentialE]\^\(\(-0.0101`\)\ t\) + 
      8.673617379884035`*^-19\ BBf\ \[ExponentialE]\^\(\(-0.0101`\)\ t\) + 
      8.673617379884035`*^-19\ bbs\ \[ExponentialE]\^\(\(-0.0101`\)\ t\) + 
      8.673617379884035`*^-19\ BBs\ \[ExponentialE]\^\(\(-0.0101`\)\ t\) + 
      0.599761024829842`\ ai\ \[ExponentialE]\^\(\(-0.0011`\)\ t\) + 
      0.08325616080071588`\ ai\ \[ExponentialE]\^\(\(-0.00022`\)\ t\) + 
      0.016650033283416535`\ ai\ \[ExponentialE]\^\(\(-0.0001`\)\ t\) + 
      0.006993013979034944`\ bbf\ \[ExponentialE]\^\(\(-0.0001`\)\ t\) + 
      0.006993013979034944`\ BBf\ \[ExponentialE]\^\(\(-0.0001`\)\ t\) + 
      0.006993013979034944`\ bbs\ \[ExponentialE]\^\(\(-0.0001`\)\ t\) + 
      0.006993013979034944`\ BBs\ \[ExponentialE]\^\(\(-0.0001`\)\ t\)\)], \
"Output",
  CellLabel->"Out[46]="]
}, Open  ]],

Cell["\<\
It can be used to compute very fast the lung retention for different AMADs \
(p)  and intakes (inp). For instance, it assumed an intake and AMAD {{3, \
5.7},{7, 7.2},{8, 4.4}} for three workers, it is computed the lung retention \
20 days after the intakes. \
\>", "MathCaption"],

Cell["\<\
modelAMAD[inp_, p_, t1_]:= inp Map[lung[AMADAdultW[#] ,t1]&, p]  \
\>", "Input",
  CellLabel->"In[47]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(modelAMAD[{3, \ 7, 8}, {5.7, \ 7.2, \ 4.4}, \ 20]\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \({0.14126705985563506`, 0.25946316584343754`, 
      0.4728268253789156`}\)], "Output",
  CellLabel->"Out[48]="]
}, Open  ]],

Cell["\<\
Here it is represented the lung retention as function of t and AMAD \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[lung[AMADAdultW[p], t], \ {p, \ 2, \ 10}, \ {t, \ 0, \ 1000}, 
      ViewPoint -> {\(-1.7\), \ \(-0.5\), \ 1}, Mesh \[Rule] False, 
      FaceGrids \[Rule] All, 
      AxesLabel \[Rule] {"\<AMAD\>", "\<time, in days \>", "\<IRF\>"}]\)], \
"Input",
  CellLabel->"In[49]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75332 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.4962e-016 1.15228 -0.117597 1.15228 [
[-0.003 .47984 -3.63853 0 ]
[-0.003 .47984 2.36147 9 ]
[.12082 .57621 -3.48484 0 ]
[.12082 .57621 2.51516 9 ]
[.21949 .653 -3.36969 0 ]
[.21949 .653 2.63031 9 ]
[.29998 .71563 -3.2802 0 ]
[.29998 .71563 2.7198 9 ]
[.36688 .76769 -6.41729 0 ]
[.36688 .76769 5.58271 9 ]
[.21069 .72448 -15.8305 0 ]
[.21069 .72448 12.357 12.5 ]
[.89804 -0.01426 -3.43365 -9 ]
[.89804 -0.01426 2.56635 0 ]
[.71146 .02509 -9.53741 -9 ]
[.71146 .02509 8.46259 0 ]
[.53571 .06224 -8.84203 -9 ]
[.53571 .06224 9.15797 0 ]
[.36985 .09737 -8.20608 -9 ]
[.36985 .09737 9.79392 0 ]
[.21307 .13063 -7.62226 -9 ]
[.21307 .13063 10.3777 0 ]
[.06462 .16216 -9.44589 -9 ]
[.06462 .16216 14.5541 0 ]
[.45546 .00814 -41.6392 -12.5 ]
[.45546 .00814 46.3608 0 ]
[.91515 .00366 0 -5.441 ]
[.91515 .00366 6 3.559 ]
[.92639 .08134 0 -5.38381 ]
[.92639 .08134 24 3.61619 ]
[.93843 .16458 0 -5.32277 ]
[.93843 .16458 24 3.67723 ]
[.95136 .25398 0 -5.25746 ]
[.95136 .25398 24 3.74254 ]
[1.00638 .13164 0 -7.41284 ]
[1.00638 .13164 22 5.08716 ]
[ 0 0 0 0 ]
[ 1 .75332 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .46575 m
.36788 .75332 L
s
0 .46575 m
.0015 .45871 L
s
[(2)] -0.003 .47984 .21284 -1 Mshowa
.12312 .56199 m
.12427 .55488 L
s
[(4)] .12082 .57621 .16161 -1 Mshowa
.22126 .63871 m
.22214 .63156 L
s
[(6)] .21949 .653 .12323 -1 Mshowa
.30132 .70129 m
.30199 .69412 L
s
[(8)] .29998 .71563 .0934 -1 Mshowa
.36788 .75332 m
.36838 .74614 L
s
[(10)] .36688 .76769 .06955 -1 Mshowa
.125 Mabswid
.03363 .49204 m
.03447 .4878 L
s
.06524 .51675 m
.06603 .5125 L
s
.09502 .54003 m
.09576 .53577 L
s
.14967 .58275 m
.15032 .57848 L
s
.17481 .6024 m
.17541 .59812 L
s
.19864 .62103 m
.1992 .61674 L
s
.24276 .65551 m
.24325 .65122 L
s
.26322 .67151 m
.26368 .66721 L
s
.28272 .68675 m
.28315 .68245 L
s
.31909 .71518 m
.31946 .71087 L
s
.33607 .72845 m
.33642 .72415 L
s
.35232 .74116 m
.35264 .73685 L
s
gsave
.21069 .72448 -76.8305 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(AMAD) show
87.188 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.9001 0 m
.06162 .17625 L
s
.9001 0 m
.90113 .00713 L
s
[(0)] .89804 -0.01426 .14455 1 Mshowa
.71232 .03947 m
.71275 .04666 L
s
[(200)] .71146 .02509 .05971 1 Mshowa
.53546 .07665 m
.53533 .08385 L
s
[(400)] .53571 .06224 -0.01755 1 Mshowa
.36859 .11172 m
.36796 .1189 L
s
[(600)] .36985 .09737 -0.08821 1 Mshowa
.21089 .14487 m
.2098 .15199 L
s
[(800)] .21307 .13063 -0.15308 1 Mshowa
.06162 .17625 m
.06012 .18329 L
s
[(1000)] .06462 .16216 -0.21284 1 Mshowa
.125 Mabswid
.85208 .01009 m
.8526 .01438 L
s
.80478 .02004 m
.80522 .02433 L
s
.7582 .02983 m
.75855 .03413 L
s
.66712 .04897 m
.66729 .05329 L
s
.62259 .05833 m
.62267 .06265 L
s
.5787 .06756 m
.57871 .07188 L
s
.49284 .0856 m
.49268 .08992 L
s
.45083 .09444 m
.4506 .09875 L
s
.40942 .10314 m
.40911 .10745 L
s
.32833 .12018 m
.32788 .12448 L
s
.28864 .12853 m
.28812 .13282 L
s
.24949 .13675 m
.24891 .14104 L
s
.17281 .15287 m
.17209 .15714 L
s
.13524 .16077 m
.13446 .16502 L
s
.09818 .16856 m
.09734 .1728 L
s
gsave
.45546 .00814 -102.639 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(time) show
87.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(in) show
117.000 12.750 moveto
(days) show
147.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.9001 0 m
.94573 .31565 L
s
.90106 .00661 m
.89401 .00808 L
s
[(0)] .91515 .00366 -1 .20911 Mshowa
.91226 .08412 m
.90519 .08551 L
s
[(0.02)] .92639 .08134 -1 .1964 Mshowa
.92427 .16717 m
.91718 .16847 L
s
[(0.04)] .93843 .16458 -1 .18284 Mshowa
.93716 .25637 m
.93006 .25757 L
s
[(0.06)] .95136 .25398 -1 .16832 Mshowa
.125 Mabswid
.90379 .0255 m
.89955 .02637 L
s
.90656 .04471 m
.90233 .04557 L
s
.90939 .06425 m
.90515 .06509 L
s
.91518 .10434 m
.91094 .10516 L
s
.91816 .12492 m
.91391 .12572 L
s
.92118 .14586 m
.91694 .14665 L
s
.9274 .18887 m
.92315 .18963 L
s
.9306 .21096 m
.92634 .21171 L
s
.93385 .23346 m
.92959 .23419 L
s
.94053 .27972 m
.93627 .28042 L
s
.94397 .3035 m
.93971 .30418 L
s
gsave
1.00638 .13164 -61 -11.4128 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(IRF) show
81.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4 g
.25 Mabswid
.90106 .00661 m
.06031 .18242 L
s
.91226 .08412 m
.04497 .25446 L
s
.92427 .16717 m
.0287 .33091 L
s
.93716 .25637 m
.0114 .4122 L
s
.9001 0 m
.94573 .31565 L
s
.71232 .03947 m
.73085 .34976 L
s
.53546 .07665 m
.53011 .38162 L
s
.36859 .11172 m
.34215 .41145 L
s
.21089 .14487 m
.16579 .43944 L
s
.06162 .17625 m
0 .46575 L
s
0 g
.9001 0 m
.94573 .31565 L
s
.94573 .31565 m
0 .46575 L
s
0 .46575 m
.06162 .17625 L
s
.06162 .17625 m
.9001 0 L
s
.4 g
.96568 .45367 m
1 .6911 L
s
.83994 .47083 m
.86268 .70462 L
s
.71909 .48732 m
.73115 .71756 L
s
.60285 .50317 m
.60506 .72998 L
s
.49097 .51844 m
.48407 .74189 L
s
.3832 .53314 m
.36788 .75332 L
s
.96643 .45888 m
.38286 .53801 L
s
.97515 .51917 m
.37895 .59424 L
s
.98426 .58221 m
.37488 .65278 L
s
.9938 .6482 m
.37063 .7138 L
s
0 g
.96568 .45367 m
.3832 .53314 L
s
.3832 .53314 m
.36788 .75332 L
s
.36788 .75332 m
1 .6911 L
s
1 .6911 m
.96568 .45367 L
s
.4 g
.90106 .00661 m
.96643 .45888 L
s
.91226 .08412 m
.97515 .51917 L
s
.92427 .16717 m
.98426 .58221 L
s
.93716 .25637 m
.9938 .6482 L
s
.9001 0 m
.94573 .31565 L
s
.9222 .15287 m
.96459 .44617 L
s
.9397 .27398 m
.97912 .54662 L
s
.95391 .37228 m
.99064 .62632 L
s
.96568 .45367 m
1 .6911 L
s
0 g
.9001 0 m
.94573 .31565 L
s
.94573 .31565 m
1 .6911 L
s
1 .6911 m
.96568 .45367 L
s
.96568 .45367 m
.9001 0 L
s
.4 g
.06162 .17625 m
0 .46575 L
s
.16662 .29278 m
.12312 .56199 L
s
.25218 .38774 m
.22126 .63871 L
s
.32324 .4666 m
.30132 .70129 L
s
.3832 .53314 m
.36788 .75332 L
s
.06031 .18242 m
.38286 .53801 L
s
.04497 .25446 m
.37895 .59424 L
s
.0287 .33091 m
.37488 .65278 L
s
.0114 .4122 m
.37063 .7138 L
s
0 g
.06162 .17625 m
.3832 .53314 L
s
.3832 .53314 m
.36788 .75332 L
s
.36788 .75332 m
0 .46575 L
s
0 .46575 m
.06162 .17625 L
s
.4 g
.9001 0 m
.06162 .17625 L
s
.9222 .15287 m
.16662 .29278 L
s
.9397 .27398 m
.25218 .38774 L
s
.95391 .37228 m
.32324 .4666 L
s
.96568 .45367 m
.3832 .53314 L
s
.9001 0 m
.96568 .45367 L
s
.71232 .03947 m
.83994 .47083 L
s
.53546 .07665 m
.71909 .48732 L
s
.36859 .11172 m
.60285 .50317 L
s
.21089 .14487 m
.49097 .51844 L
s
.06162 .17625 m
.3832 .53314 L
s
.94573 .31565 m
0 .46575 L
s
.96459 .44617 m
.12312 .56199 L
s
.97912 .54662 m
.22126 .63871 L
s
.99064 .62632 m
.30132 .70129 L
s
1 .6911 m
.36788 .75332 L
s
.94573 .31565 m
1 .6911 L
s
.73085 .34976 m
.86268 .70462 L
s
.53011 .38162 m
.73115 .71756 L
s
.34215 .41145 m
.60506 .72998 L
s
.16579 .43944 m
.48407 .74189 L
s
0 .46575 m
.36788 .75332 L
s
0 0 m
1 0 L
1 .75332 L
0 .75332 L
closepath
clip
newpath
.517 .808 .999 r
.39456 .54553 .37203 .54785 .38155 .55684 .40381 .55455 Mtetra
.516 .808 .999 r
.38505 .53626 .36224 .5386 .37203 .54785 .39456 .54553 Mtetra
.514 .807 .999 r
.37526 .52674 .35218 .52912 .36224 .5386 .38505 .53626 Mtetra
.512 .806 .999 r
.36519 .51698 .34183 .51939 .35218 .52912 .37526 .52674 Mtetra
.51 .806 .999 r
.35482 .50697 .33117 .50942 .34183 .51939 .36519 .51698 Mtetra
.507 .806 .999 r
.34414 .49674 .3202 .49921 .33117 .50942 .35482 .50697 Mtetra
.503 .805 .999 r
.33313 .48627 .30888 .48878 .3202 .49921 .34414 .49674 Mtetra
.5 .805 .999 r
.32178 .47557 .29721 .47812 .30888 .48878 .33313 .48627 Mtetra
.495 .804 1 r
.31005 .46466 .28517 .46724 .29721 .47812 .32178 .47557 Mtetra
.492 .804 1 r
.29795 .45347 .27273 .45608 .28517 .46724 .31005 .46466 Mtetra
.486 .803 1 r
.28543 .4421 .25988 .44474 .27273 .45608 .29795 .45347 Mtetra
.48 .803 1 r
.27248 .43055 .24658 .43322 .25988 .44474 .28543 .4421 Mtetra
.473 .802 1 r
.25906 .41882 .23281 .42151 .24658 .43322 .27248 .43055 Mtetra
.466 .801 .999 r
.24515 .4069 .21853 .4096 .23281 .42151 .25906 .41882 Mtetra
.458 .8 .999 r
.23073 .39478 .20373 .3975 .21853 .4096 .24515 .4069 Mtetra
.45 .799 .998 r
.21574 .38247 .18836 .38519 .20373 .3975 .23073 .39478 Mtetra
.442 .797 .997 r
.20017 .36994 .17239 .37267 .18836 .38519 .21574 .38247 Mtetra
.433 .795 .996 r
.18396 .35721 .15577 .35993 .17239 .37267 .20017 .36994 Mtetra
.422 .793 .994 r
.16708 .34429 .13847 .34699 .15577 .35993 .18396 .35721 Mtetra
.412 .79 .992 r
.14948 .33111 .12044 .3338 .13847 .34699 .16708 .34429 Mtetra
.403 .787 .991 r
.13112 .31764 .10163 .32029 .12044 .3338 .14948 .33111 Mtetra
.39 .783 .988 r
.11192 .30396 .08198 .30658 .10163 .32029 .13112 .31764 Mtetra
.382 .779 .986 r
.09188 .28978 .06147 .29237 .08198 .30658 .11192 .30396 Mtetra
.376 .775 .986 r
.07095 .27496 .04006 .27752 .06147 .29237 .09188 .28978 Mtetra
.515 .808 .999 r
.41728 .54323 .39456 .54553 .40381 .55455 .42626 .55228 Mtetra
.514 .807 .999 r
.40804 .53393 .38505 .53626 .39456 .54553 .41728 .54323 Mtetra
.512 .807 .999 r
.39854 .52438 .37526 .52674 .38505 .53626 .40804 .53393 Mtetra
.51 .806 .999 r
.38876 .51458 .36519 .51698 .37526 .52674 .39854 .52438 Mtetra
.507 .806 .999 r
.37869 .50455 .35482 .50697 .36519 .51698 .38876 .51458 Mtetra
.504 .805 .999 r
.36831 .49428 .34414 .49674 .35482 .50697 .37869 .50455 Mtetra
.501 .805 .999 r
.35761 .48378 .33313 .48627 .34414 .49674 .36831 .49428 Mtetra
.497 .804 1 r
.34657 .47305 .32178 .47557 .33313 .48627 .35761 .48378 Mtetra
.492 .804 1 r
.33518 .46211 .31005 .46466 .32178 .47557 .34657 .47305 Mtetra
.489 .803 1 r
.32341 .45088 .29795 .45347 .31005 .46466 .33518 .46211 Mtetra
.483 .803 1 r
.31124 .43949 .28543 .4421 .29795 .45347 .32341 .45088 Mtetra
.476 .802 1 r
.29864 .42792 .27248 .43055 .28543 .4421 .31124 .43949 Mtetra
.469 .801 .999 r
.28559 .41617 .25906 .41882 .27248 .43055 .29864 .42792 Mtetra
.462 .8 .999 r
.27206 .40423 .24515 .4069 .25906 .41882 .28559 .41617 Mtetra
.454 .799 .998 r
.25802 .39211 .23073 .39478 .24515 .4069 .27206 .40423 Mtetra
.445 .798 .997 r
.24343 .3798 .21574 .38247 .23073 .39478 .25802 .39211 Mtetra
.436 .796 .996 r
.22827 .36728 .20017 .36994 .21574 .38247 .24343 .3798 Mtetra
.427 .793 .995 r
.21248 .35456 .18396 .35721 .20017 .36994 .22827 .36728 Mtetra
.416 .791 .993 r
.19603 .34166 .16708 .34429 .18396 .35721 .21248 .35456 Mtetra
.406 .788 .991 r
.17888 .32851 .14948 .33111 .16708 .34429 .19603 .34166 Mtetra
.395 .784 .989 r
.16098 .31507 .13112 .31764 .14948 .33111 .17888 .32851 Mtetra
.383 .78 .986 r
.14225 .30143 .11192 .30396 .13112 .31764 .16098 .31507 Mtetra
.374 .776 .985 r
.12269 .28731 .09188 .28978 .11192 .30396 .14225 .30143 Mtetra
.368 .772 .984 r
.10226 .27252 .07095 .27496 .09188 .28978 .12269 .28731 Mtetra
.513 .808 .999 r
.44019 .54094 .41728 .54323 .42626 .55228 .4489 .55002 Mtetra
.512 .807 .999 r
.43123 .53162 .40804 .53393 .41728 .54323 .44019 .54094 Mtetra
.51 .806 .999 r
.42202 .52204 .39854 .52438 .40804 .53393 .43123 .53162 Mtetra
.507 .806 .999 r
.41253 .51221 .38876 .51458 .39854 .52438 .42202 .52204 Mtetra
.505 .805 .999 r
.40276 .50214 .37869 .50455 .38876 .51458 .41253 .51221 Mtetra
.502 .805 .999 r
.3927 .49184 .36831 .49428 .37869 .50455 .40276 .50214 Mtetra
.498 .804 .999 r
.38232 .48131 .35761 .48378 .36831 .49428 .3927 .49184 Mtetra
.494 .804 1 r
.3716 .47056 .34657 .47305 .35761 .48378 .38232 .48131 Mtetra
.489 .803 1 r
.36054 .45958 .33518 .46211 .34657 .47305 .3716 .47056 Mtetra
.486 .802 1 r
.34912 .44833 .32341 .45088 .33518 .46211 .36054 .45958 Mtetra
.479 .802 1 r
.3373 .43691 .31124 .43949 .32341 .45088 .34912 .44833 Mtetra
.472 .801 .999 r
.32507 .42532 .29864 .42792 .31124 .43949 .3373 .43691 Mtetra
.465 .8 .999 r
.3124 .41356 .28559 .41617 .29864 .42792 .32507 .42532 Mtetra
.457 .799 .999 r
.29925 .40162 .27206 .40423 .28559 .41617 .3124 .41356 Mtetra
.449 .798 .998 r
.28561 .3895 .25802 .39211 .27206 .40423 .29925 .40162 Mtetra
.44 .796 .997 r
.27143 .37718 .24343 .3798 .25802 .39211 .28561 .3895 Mtetra
.431 .794 .996 r
.25669 .36468 .22827 .36728 .24343 .3798 .27143 .37718 Mtetra
.421 .791 .994 r
.24134 .35198 .21248 .35456 .22827 .36728 .25669 .36468 Mtetra
.409 .789 .992 r
.22534 .33911 .19603 .34166 .21248 .35456 .24134 .35198 Mtetra
.398 .785 .99 r
.20864 .326 .17888 .32851 .19603 .34166 .22534 .33911 Mtetra
.388 .782 .988 r
.19122 .3126 .16098 .31507 .17888 .32851 .20864 .326 Mtetra
.374 .777 .984 r
.17298 .29902 .14225 .30143 .16098 .31507 .19122 .3126 Mtetra
.366 .773 .982 r
.15392 .28495 .12269 .28731 .14225 .30143 .17298 .29902 Mtetra
.359 .769 .981 r
.134 .27021 .10226 .27252 .12269 .28731 .15392 .28495 Mtetra
.511 .808 .999 r
.46329 .53867 .44019 .54094 .4489 .55002 .47172 .54777 Mtetra
.509 .807 .999 r
.45462 .52932 .43123 .53162 .44019 .54094 .46329 .53867 Mtetra
.507 .806 .999 r
.4457 .51971 .42202 .52204 .43123 .53162 .45462 .52932 Mtetra
.505 .805 .999 r
.43652 .50986 .41253 .51221 .42202 .52204 .4457 .51971 Mtetra
.502 .805 .999 r
.42706 .49976 .40276 .50214 .41253 .51221 .43652 .50986 Mtetra
.499 .804 .999 r
.41731 .48943 .3927 .49184 .40276 .50214 .42706 .49976 Mtetra
.495 .804 1 r
.40725 .47887 .38232 .48131 .3927 .49184 .41731 .48943 Mtetra
.491 .803 1 r
.39688 .46809 .3716 .47056 .38232 .48131 .40725 .47887 Mtetra
.486 .803 1 r
.38616 .45709 .36054 .45958 .3716 .47056 .39688 .46809 Mtetra
.482 .802 1 r
.37509 .44582 .34912 .44833 .36054 .45958 .38616 .45709 Mtetra
.475 .801 1 r
.36364 .43438 .3373 .43691 .34912 .44833 .37509 .44582 Mtetra
.468 .8 .999 r
.35178 .42277 .32507 .42532 .3373 .43691 .36364 .43438 Mtetra
.461 .799 .999 r
.33949 .411 .3124 .41356 .32507 .42532 .35178 .42277 Mtetra
.452 .798 .998 r
.32674 .39906 .29925 .40162 .3124 .41356 .33949 .411 Mtetra
.444 .796 .997 r
.3135 .38694 .28561 .3895 .29925 .40162 .32674 .39906 Mtetra
.434 .795 .996 r
.29975 .37464 .27143 .37718 .28561 .3895 .3135 .38694 Mtetra
.425 .792 .995 r
.28544 .36215 .25669 .36468 .27143 .37718 .29975 .37464 Mtetra
.414 .789 .993 r
.27054 .34948 .24134 .35198 .25669 .36468 .28544 .36215 Mtetra
.402 .786 .991 r
.255 .33664 .22534 .33911 .24134 .35198 .27054 .34948 Mtetra
.391 .783 .988 r
.23878 .32358 .20864 .326 .22534 .33911 .255 .33664 Mtetra
.38 .779 .986 r
.22185 .31023 .19122 .3126 .20864 .326 .23878 .32358 Mtetra
.366 .774 .982 r
.20412 .29672 .17298 .29902 .19122 .3126 .22185 .31023 Mtetra
.357 .769 .98 r
.18558 .28272 .15392 .28495 .17298 .29902 .20412 .29672 Mtetra
.35 .765 .979 r
.16619 .26804 .134 .27021 .15392 .28495 .18558 .28272 Mtetra
.509 .807 .999 r
.48659 .53642 .46329 .53867 .47172 .54777 .49473 .54553 Mtetra
.507 .806 .999 r
.47821 .52704 .45462 .52932 .46329 .53867 .48659 .53642 Mtetra
.505 .806 .999 r
.46959 .51741 .4457 .51971 .45462 .52932 .47821 .52704 Mtetra
.502 .805 .999 r
.46072 .50753 .43652 .50986 .4457 .51971 .46959 .51741 Mtetra
.499 .804 .999 r
.45157 .49741 .42706 .49976 .43652 .50986 .46072 .50753 Mtetra
.496 .804 .999 r
.44215 .48705 .41731 .48943 .42706 .49976 .45157 .49741 Mtetra
.492 .803 1 r
.43243 .47646 .40725 .47887 .41731 .48943 .44215 .48705 Mtetra
.488 .802 1 r
.42239 .46566 .39688 .46809 .40725 .47887 .43243 .47646 Mtetra
.483 .802 1 r
.41203 .45464 .38616 .45709 .39688 .46809 .42239 .46566 Mtetra
.479 .801 1 r
.40132 .44334 .37509 .44582 .38616 .45709 .41203 .45464 Mtetra
.472 .8 .999 r
.39024 .43189 .36364 .43438 .37509 .44582 .40132 .44334 Mtetra
.464 .799 .999 r
.37876 .42027 .35178 .42277 .36364 .43438 .39024 .43189 Mtetra
.456 .798 .999 r
.36687 .40849 .33949 .411 .35178 .42277 .37876 .42027 Mtetra
.447 .797 .998 r
.35453 .39655 .32674 .39906 .33949 .411 .36687 .40849 Mtetra
.438 .795 .997 r
.34171 .38444 .3135 .38694 .32674 .39906 .35453 .39655 Mtetra
.429 .793 .995 r
.32839 .37216 .29975 .37464 .3135 .38694 .34171 .38444 Mtetra
.418 .79 .994 r
.31453 .3597 .28544 .36215 .29975 .37464 .32839 .37216 Mtetra
.407 .787 .992 r
.3001 .34706 .27054 .34948 .28544 .36215 .31453 .3597 Mtetra
.395 .784 .989 r
.28504 .33427 .255 .33664 .27054 .34948 .3001 .34706 Mtetra
.383 .78 .987 r
.26931 .32126 .23878 .32358 .255 .33664 .28504 .33427 Mtetra
.371 .776 .984 r
.25288 .30798 .22185 .31023 .23878 .32358 .26931 .32126 Mtetra
.357 .771 .98 r
.23568 .29454 .20412 .29672 .22185 .31023 .25288 .30798 Mtetra
.347 .766 .978 r
.21768 .28062 .18558 .28272 .20412 .29672 .23568 .29454 Mtetra
.34 .761 .976 r
.19885 .26602 .16619 .26804 .18558 .28272 .21768 .28062 Mtetra
.506 .807 .999 r
.51009 .53418 .48659 .53642 .49473 .54553 .51794 .54332 Mtetra
.504 .806 .999 r
.50202 .52478 .47821 .52704 .48659 .53642 .51009 .53418 Mtetra
.502 .805 .999 r
.4937 .51513 .46959 .51741 .47821 .52704 .50202 .52478 Mtetra
.5 .804 .999 r
.48514 .50523 .46072 .50753 .46959 .51741 .4937 .51513 Mtetra
.497 .804 .999 r
.47632 .49508 .45157 .49741 .46072 .50753 .48514 .50523 Mtetra
.493 .803 1 r
.46723 .4847 .44215 .48705 .45157 .49741 .47632 .49508 Mtetra
.489 .802 1 r
.45784 .47409 .43243 .47646 .44215 .48705 .46723 .4847 Mtetra
.484 .802 1 r
.44816 .46326 .42239 .46566 .43243 .47646 .45784 .47409 Mtetra
.479 .801 1 r
.43816 .45222 .41203 .45464 .42239 .46566 .44816 .46326 Mtetra
.475 .8 1 r
.42782 .44091 .40132 .44334 .41203 .45464 .43816 .45222 Mtetra
.468 .799 .999 r
.41712 .42944 .39024 .43189 .40132 .44334 .42782 .44091 Mtetra
.46 .798 .999 r
.40604 .41782 .37876 .42027 .39024 .43189 .41712 .42944 Mtetra
.451 .797 .998 r
.39455 .40604 .36687 .40849 .37876 .42027 .40604 .41782 Mtetra
.442 .795 .997 r
.38263 .39411 .35453 .39655 .36687 .40849 .39455 .40604 Mtetra
.433 .793 .996 r
.37025 .38201 .34171 .38444 .35453 .39655 .38263 .39411 Mtetra
.423 .791 .995 r
.35738 .36975 .32839 .37216 .34171 .38444 .37025 .38201 Mtetra
.412 .788 .993 r
.34398 .35733 .31453 .3597 .32839 .37216 .35738 .36975 Mtetra
.4 .785 .99 r
.33002 .34473 .3001 .34706 .31453 .3597 .34398 .35733 Mtetra
.387 .781 .987 r
.31545 .332 .28504 .33427 .3001 .34706 .33002 .34473 Mtetra
.375 .777 .985 r
.30024 .31906 .26931 .32126 .28504 .33427 .31545 .332 Mtetra
.363 .772 .982 r
.28434 .30585 .25288 .30798 .26931 .32126 .30024 .31906 Mtetra
.347 .767 .977 r
.26768 .2925 .23568 .29454 .25288 .30798 .28434 .30585 Mtetra
.338 .761 .975 r
.25024 .27868 .21768 .28062 .23568 .29454 .26768 .2925 Mtetra
.33 .756 .973 r
.23199 .26416 .19885 .26602 .21768 .28062 .25024 .27868 Mtetra
.503 .807 .999 r
.5338 .53197 .51009 .53418 .51794 .54332 .54135 .54112 Mtetra
.502 .806 .999 r
.52603 .52255 .50202 .52478 .51009 .53418 .5338 .53197 Mtetra
.499 .805 .999 r
.51803 .51288 .4937 .51513 .50202 .52478 .52603 .52255 Mtetra
.497 .804 .999 r
.50979 .50295 .48514 .50523 .4937 .51513 .51803 .51288 Mtetra
.494 .803 1 r
.5013 .49278 .47632 .49508 .48514 .50523 .50979 .50295 Mtetra
.49 .802 1 r
.49254 .48238 .46723 .4847 .47632 .49508 .5013 .49278 Mtetra
.486 .802 1 r
.48351 .47175 .45784 .47409 .46723 .4847 .49254 .48238 Mtetra
.481 .801 1 r
.47418 .46091 .44816 .46326 .45784 .47409 .48351 .47175 Mtetra
.475 .8 1 r
.46455 .44985 .43816 .45222 .44816 .46326 .47418 .46091 Mtetra
.471 .799 .999 r
.45459 .43852 .42782 .44091 .43816 .45222 .46455 .44985 Mtetra
.463 .798 .999 r
.44428 .42704 .41712 .42944 .42782 .44091 .45459 .43852 Mtetra
.455 .797 .999 r
.43361 .41542 .40604 .41782 .41712 .42944 .44428 .42704 Mtetra
.446 .796 .998 r
.42254 .40365 .39455 .40604 .40604 .41782 .43361 .41542 Mtetra
.437 .794 .997 r
.41105 .39173 .38263 .39411 .39455 .40604 .42254 .40365 Mtetra
.427 .792 .995 r
.39911 .37966 .37025 .38201 .38263 .39411 .41105 .39173 Mtetra
.416 .789 .994 r
.3867 .36743 .35738 .36975 .37025 .38201 .39911 .37966 Mtetra
.405 .786 .991 r
.37378 .35505 .34398 .35733 .35738 .36975 .3867 .36743 Mtetra
.393 .782 .989 r
.36032 .3425 .33002 .34473 .34398 .35733 .37378 .35505 Mtetra
.379 .778 .986 r
.34626 .32984 .31545 .332 .33002 .34473 .36032 .3425 Mtetra
.366 .774 .982 r
.33158 .31697 .30024 .31906 .31545 .332 .34626 .32984 Mtetra
.354 .769 .979 r
.31623 .30385 .28434 .30585 .30024 .31906 .33158 .31697 Mtetra
.338 .763 .974 r
.30013 .29061 .26768 .2925 .28434 .30585 .31623 .30385 Mtetra
.327 .757 .972 r
.28328 .27689 .25024 .27868 .26768 .2925 .30013 .29061 Mtetra
.32 .752 .97 r
.26564 .26248 .23199 .26416 .25024 .27868 .28328 .27689 Mtetra
.501 .806 1 r
.55771 .52978 .5338 .53197 .54135 .54112 .56496 .53895 Mtetra
.499 .805 .999 r
.55025 .52034 .52603 .52255 .5338 .53197 .55771 .52978 Mtetra
.497 .804 1 r
.54257 .51065 .51803 .51288 .52603 .52255 .55025 .52034 Mtetra
.494 .803 1 r
.53466 .5007 .50979 .50295 .51803 .51288 .54257 .51065 Mtetra
.49 .802 1 r
.52651 .49052 .5013 .49278 .50979 .50295 .53466 .5007 Mtetra
.487 .802 1 r
.5181 .4801 .49254 .48238 .5013 .49278 .52651 .49052 Mtetra
.482 .801 1 r
.50942 .46945 .48351 .47175 .49254 .48238 .5181 .4801 Mtetra
.477 .8 1 r
.50047 .45859 .47418 .46091 .48351 .47175 .50942 .46945 Mtetra
.471 .799 .999 r
.49121 .44753 .46455 .44985 .47418 .46091 .50047 .45859 Mtetra
.467 .798 .999 r
.48164 .43618 .45459 .43852 .46455 .44985 .49121 .44753 Mtetra
.459 .797 .999 r
.47174 .4247 .44428 .42704 .45459 .43852 .48164 .43618 Mtetra
.45 .796 .998 r
.46148 .41308 .43361 .41542 .44428 .42704 .47174 .4247 Mtetra
.441 .794 .997 r
.45084 .40132 .42254 .40365 .43361 .41542 .46148 .41308 Mtetra
.431 .792 .996 r
.43979 .38942 .41105 .39173 .42254 .40365 .45084 .40132 Mtetra
.421 .79 .994 r
.42832 .37738 .39911 .37966 .41105 .39173 .43979 .38942 Mtetra
.409 .787 .992 r
.41639 .36519 .3867 .36743 .39911 .37966 .42832 .37738 Mtetra
.398 .784 .99 r
.40396 .35286 .37378 .35505 .3867 .36743 .41639 .36519 Mtetra
.385 .78 .987 r
.39101 .34038 .36032 .3425 .37378 .35505 .40396 .35286 Mtetra
.371 .775 .984 r
.37748 .32779 .34626 .32984 .36032 .3425 .39101 .34038 Mtetra
.357 .77 .98 r
.36335 .31501 .33158 .31697 .34626 .32984 .37748 .32779 Mtetra
.344 .765 .976 r
.34856 .30199 .31623 .30385 .33158 .31697 .36335 .31501 Mtetra
.327 .758 .971 r
.33306 .28887 .30013 .29061 .31623 .30385 .34856 .30199 Mtetra
.317 .752 .968 r
.31682 .27527 .28328 .27689 .30013 .29061 .33306 .28887 Mtetra
.309 .747 .967 r
.2998 .26099 .26564 .26248 .28328 .27689 .31682 .27527 Mtetra
.498 .806 1 r
.58184 .52761 .55771 .52978 .56496 .53895 .58878 .53679 Mtetra
.496 .805 1 r
.5747 .51816 .55025 .52034 .55771 .52978 .58184 .52761 Mtetra
.494 .804 1 r
.56734 .50845 .54257 .51065 .55025 .52034 .5747 .51816 Mtetra
.491 .803 1 r
.55977 .49849 .53466 .5007 .54257 .51065 .56734 .50845 Mtetra
.487 .802 1 r
.55196 .48829 .52651 .49052 .53466 .5007 .55977 .49849 Mtetra
.483 .801 1 r
.54391 .47785 .5181 .4801 .52651 .49052 .55196 .48829 Mtetra
.479 .8 1 r
.5356 .46719 .50942 .46945 .5181 .4801 .54391 .47785 Mtetra
.473 .799 1 r
.52702 .45632 .50047 .45859 .50942 .46945 .5356 .46719 Mtetra
.467 .798 .999 r
.51815 .44525 .49121 .44753 .50047 .45859 .52702 .45632 Mtetra
.462 .797 .999 r
.50898 .4339 .48164 .43618 .49121 .44753 .51815 .44525 Mtetra
.454 .796 .999 r
.49949 .42242 .47174 .4247 .48164 .43618 .50898 .4339 Mtetra
.445 .794 .998 r
.48966 .41081 .46148 .41308 .47174 .4247 .49949 .42242 Mtetra
.435 .792 .997 r
.47946 .39907 .45084 .40132 .46148 .41308 .48966 .41081 Mtetra
.425 .79 .995 r
.46888 .3872 .43979 .38942 .45084 .40132 .47946 .39907 Mtetra
.414 .788 .993 r
.45788 .37519 .42832 .37738 .43979 .38942 .46888 .3872 Mtetra
.402 .785 .991 r
.44644 .36305 .41639 .36519 .42832 .37738 .45788 .37519 Mtetra
.39 .781 .988 r
.43452 .35078 .40396 .35286 .41639 .36519 .44644 .36305 Mtetra
.377 .777 .985 r
.42209 .33837 .39101 .34038 .40396 .35286 .43452 .35078 Mtetra
.362 .772 .981 r
.40912 .32587 .37748 .32779 .39101 .34038 .42209 .33837 Mtetra
.348 .766 .977 r
.39555 .31319 .36335 .31501 .37748 .32779 .40912 .32587 Mtetra
.334 .76 .973 r
.38136 .30029 .34856 .30199 .36335 .31501 .39555 .31319 Mtetra
.316 .753 .967 r
.36647 .2873 .33306 .28887 .34856 .30199 .38136 .30029 Mtetra
.305 .747 .964 r
.35087 .27384 .31682 .27527 .33306 .28887 .36647 .2873 Mtetra
.297 .741 .963 r
.3345 .25969 .2998 .26099 .31682 .27527 .35087 .27384 Mtetra
.495 .805 1 r
.60618 .52547 .58184 .52761 .58878 .53679 .6128 .53466 Mtetra
.493 .804 1 r
.59937 .51601 .5747 .51816 .58184 .52761 .60618 .52547 Mtetra
.49 .803 1 r
.59235 .50629 .56734 .50845 .5747 .51816 .59937 .51601 Mtetra
.487 .802 1 r
.58512 .49632 .55977 .49849 .56734 .50845 .59235 .50629 Mtetra
.484 .801 1 r
.57766 .4861 .55196 .48829 .55977 .49849 .58512 .49632 Mtetra
.48 .8 1 r
.56997 .47565 .54391 .47785 .55196 .48829 .57766 .4861 Mtetra
.475 .799 1 r
.56204 .46498 .5356 .46719 .54391 .47785 .56997 .47565 Mtetra
.469 .798 .999 r
.55384 .4541 .52702 .45632 .5356 .46719 .56204 .46498 Mtetra
.463 .797 .999 r
.54537 .44303 .51815 .44525 .52702 .45632 .55384 .4541 Mtetra
.458 .796 .999 r
.53662 .43168 .50898 .4339 .51815 .44525 .54537 .44303 Mtetra
.449 .794 .998 r
.52755 .4202 .49949 .42242 .50898 .4339 .53662 .43168 Mtetra
.44 .793 .997 r
.51816 .40861 .48966 .41081 .49949 .42242 .52755 .4202 Mtetra
.43 .791 .996 r
.50842 .39689 .47946 .39907 .48966 .41081 .51816 .40861 Mtetra
.419 .788 .994 r
.4983 .38505 .46888 .3872 .47946 .39907 .50842 .39689 Mtetra
.407 .785 .992 r
.48779 .37309 .45788 .37519 .46888 .3872 .4983 .38505 Mtetra
.395 .782 .99 r
.47686 .36101 .44644 .36305 .45788 .37519 .48779 .37309 Mtetra
.382 .778 .987 r
.46547 .3488 .43452 .35078 .44644 .36305 .47686 .36101 Mtetra
.368 .773 .983 r
.4536 .33648 .42209 .33837 .43452 .35078 .46547 .3488 Mtetra
.352 .768 .979 r
.44119 .32408 .40912 .32587 .42209 .33837 .4536 .33648 Mtetra
.338 .762 .974 r
.42822 .31152 .39555 .31319 .40912 .32587 .44119 .32408 Mtetra
.323 .756 .97 r
.41464 .29875 .38136 .30029 .39555 .31319 .42822 .31152 Mtetra
.305 .748 .963 r
.40039 .28591 .36647 .2873 .38136 .30029 .41464 .29875 Mtetra
.294 .742 .96 r
.38545 .27261 .35087 .27384 .36647 .2873 .40039 .28591 Mtetra
.285 .736 .959 r
.36977 .25862 .3345 .25969 .35087 .27384 .38545 .27261 Mtetra
.492 .805 1 r
.63074 .52337 .60618 .52547 .6128 .53466 .63704 .53256 Mtetra
.49 .803 1 r
.62426 .5139 .59937 .51601 .60618 .52547 .63074 .52337 Mtetra
.487 .802 1 r
.61758 .50416 .59235 .50629 .59937 .51601 .62426 .5139 Mtetra
.484 .801 1 r
.6107 .49418 .58512 .49632 .59235 .50629 .61758 .50416 Mtetra
.48 .8 1 r
.60361 .48395 .57766 .4861 .58512 .49632 .6107 .49418 Mtetra
.476 .799 1 r
.5963 .4735 .56997 .47565 .57766 .4861 .60361 .48395 Mtetra
.471 .798 .999 r
.58874 .46282 .56204 .46498 .56997 .47565 .5963 .4735 Mtetra
.465 .797 .999 r
.58095 .45194 .55384 .4541 .56204 .46498 .58874 .46282 Mtetra
.458 .796 .999 r
.57289 .44086 .54537 .44303 .55384 .4541 .58095 .45194 Mtetra
.453 .794 .999 r
.56455 .42952 .53662 .43168 .54537 .44303 .57289 .44086 Mtetra
.444 .793 .998 r
.55592 .41805 .52755 .4202 .53662 .43168 .56455 .42952 Mtetra
.434 .791 .997 r
.54698 .40648 .51816 .40861 .52755 .4202 .55592 .41805 Mtetra
.423 .789 .995 r
.53771 .39479 .50842 .39689 .51816 .40861 .54698 .40648 Mtetra
.412 .786 .993 r
.52809 .383 .4983 .38505 .50842 .39689 .53771 .39479 Mtetra
.4 .783 .991 r
.51808 .37109 .48779 .37309 .4983 .38505 .52809 .383 Mtetra
.387 .779 .988 r
.50767 .35907 .47686 .36101 .48779 .37309 .51808 .37109 Mtetra
.373 .775 .985 r
.49683 .34695 .46547 .3488 .47686 .36101 .50767 .35907 Mtetra
.359 .77 .981 r
.48552 .33472 .4536 .33648 .46547 .3488 .49683 .34695 Mtetra
.343 .764 .976 r
.47371 .32244 .44119 .32408 .4536 .33648 .48552 .33472 Mtetra
.327 .758 .971 r
.46135 .31001 .42822 .31152 .44119 .32408 .47371 .32244 Mtetra
.312 .751 .966 r
.44841 .29738 .41464 .29875 .42822 .31152 .46135 .31001 Mtetra
.293 .743 .959 r
.43484 .28472 .40039 .28591 .41464 .29875 .44841 .29738 Mtetra
.281 .736 .956 r
.42059 .2716 .38545 .27261 .40039 .28591 .43484 .28472 Mtetra
.273 .729 .954 r
.40563 .25778 .36977 .25862 .38545 .27261 .42059 .2716 Mtetra
.488 .804 1 r
.65553 .52129 .63074 .52337 .63704 .53256 .66149 .53049 Mtetra
.486 .803 1 r
.64939 .51182 .62426 .5139 .63074 .52337 .65553 .52129 Mtetra
.484 .801 1 r
.64306 .50208 .61758 .50416 .62426 .5139 .64939 .51182 Mtetra
.48 .8 1 r
.63654 .49209 .6107 .49418 .61758 .50416 .64306 .50208 Mtetra
.476 .799 1 r
.62982 .48185 .60361 .48395 .6107 .49418 .63654 .49209 Mtetra
.472 .798 .999 r
.62289 .47139 .5963 .4735 .60361 .48395 .62982 .48185 Mtetra
.467 .797 .999 r
.61573 .46071 .58874 .46282 .5963 .4735 .62289 .47139 Mtetra
.46 .796 .999 r
.60834 .44983 .58095 .45194 .58874 .46282 .61573 .46071 Mtetra
.454 .794 .999 r
.6007 .43876 .57289 .44086 .58095 .45194 .60834 .44983 Mtetra
.448 .793 .998 r
.59279 .42742 .56455 .42952 .57289 .44086 .6007 .43876 Mtetra
.439 .791 .997 r
.58462 .41598 .55592 .41805 .56455 .42952 .59279 .42742 Mtetra
.428 .789 .996 r
.57614 .40443 .54698 .40648 .55592 .41805 .58462 .41598 Mtetra
.417 .787 .994 r
.56736 .39278 .53771 .39479 .54698 .40648 .57614 .40443 Mtetra
.405 .784 .992 r
.55823 .38104 .52809 .383 .53771 .39479 .56736 .39278 Mtetra
.392 .78 .989 r
.54875 .3692 .51808 .37109 .52809 .383 .55823 .38104 Mtetra
.379 .776 .986 r
.53889 .35726 .50767 .35907 .51808 .37109 .54875 .3692 Mtetra
.365 .771 .983 r
.52861 .34523 .49683 .34695 .50767 .35907 .53889 .35726 Mtetra
.35 .766 .978 r
.51789 .33311 .48552 .33472 .49683 .34695 .52861 .34523 Mtetra
.332 .76 .973 r
.50669 .32096 .47371 .32244 .48552 .33472 .51789 .33311 Mtetra
.316 .753 .968 r
.49498 .30867 .46135 .31001 .47371 .32244 .50669 .32096 Mtetra
.301 .746 .962 r
.48271 .29621 .44841 .29738 .46135 .31001 .49498 .30867 Mtetra
.281 .737 .955 r
.46983 .28374 .43484 .28472 .44841 .29738 .48271 .29621 Mtetra
.268 .729 .951 r
.4563 .27081 .42059 .2716 .43484 .28472 .46983 .28374 Mtetra
.26 .723 .949 r
.4421 .25719 .40563 .25778 .42059 .2716 .4563 .27081 Mtetra
.485 .803 1 r
.68055 .51925 .65553 .52129 .66149 .53049 .68617 .52845 Mtetra
.483 .802 1 r
.67475 .50978 .64939 .51182 .65553 .52129 .68055 .51925 Mtetra
.48 .801 1 r
.66879 .50003 .64306 .50208 .64939 .51182 .67475 .50978 Mtetra
.477 .799 1 r
.66263 .49004 .63654 .49209 .64306 .50208 .66879 .50003 Mtetra
.472 .798 .999 r
.65629 .4798 .62982 .48185 .63654 .49209 .66263 .49004 Mtetra
.468 .797 .999 r
.64975 .46934 .62289 .47139 .62982 .48185 .65629 .4798 Mtetra
.462 .796 .999 r
.643 .45866 .61573 .46071 .62289 .47139 .64975 .46934 Mtetra
.456 .794 .999 r
.63602 .44779 .60834 .44983 .61573 .46071 .643 .45866 Mtetra
.449 .793 .998 r
.62881 .43673 .6007 .43876 .60834 .44983 .63602 .44779 Mtetra
.443 .791 .998 r
.62136 .42541 .59279 .42742 .6007 .43876 .62881 .43673 Mtetra
.433 .789 .997 r
.61364 .41399 .58462 .41598 .59279 .42742 .62136 .42541 Mtetra
.422 .787 .995 r
.60565 .40247 .57614 .40443 .58462 .41598 .61364 .41399 Mtetra
.41 .785 .993 r
.59736 .39087 .56736 .39278 .57614 .40443 .60565 .40247 Mtetra
.398 .781 .991 r
.58876 .37919 .55823 .38104 .56736 .39278 .59736 .39087 Mtetra
.384 .777 .988 r
.57982 .36742 .54875 .3692 .55823 .38104 .58876 .37919 Mtetra
.37 .773 .984 r
.57052 .35557 .53889 .35726 .54875 .3692 .57982 .36742 Mtetra
.355 .768 .98 r
.56083 .34364 .52861 .34523 .53889 .35726 .57052 .35557 Mtetra
.34 .762 .975 r
.55072 .33165 .51789 .33311 .52861 .34523 .56083 .34364 Mtetra
.322 .755 .969 r
.54016 .31964 .50669 .32096 .51789 .33311 .55072 .33165 Mtetra
.305 .748 .964 r
.52911 .30752 .49498 .30867 .50669 .32096 .54016 .31964 Mtetra
.288 .74 .958 r
.51754 .29524 .48271 .29621 .49498 .30867 .52911 .30752 Mtetra
.268 .73 .95 r
.50539 .28298 .46983 .28374 .48271 .29621 .51754 .29524 Mtetra
.255 .722 .946 r
.49263 .27028 .4563 .27081 .46983 .28374 .50539 .28298 Mtetra
.246 .716 .944 r
.47921 .25688 .4421 .25719 .4563 .27081 .49263 .27028 Mtetra
.481 .803 1 r
.7058 .51725 .68055 .51925 .68617 .52845 .71107 .52645 Mtetra
.479 .801 1 r
.70036 .50778 .67475 .50978 .68055 .51925 .7058 .51725 Mtetra
.476 .8 1 r
.69476 .49804 .66879 .50003 .67475 .50978 .70036 .50778 Mtetra
.473 .798 .999 r
.68899 .48804 .66263 .49004 .66879 .50003 .69476 .49804 Mtetra
.468 .797 .999 r
.68303 .47781 .65629 .4798 .66263 .49004 .68899 .48804 Mtetra
.463 .796 .999 r
.67689 .46735 .64975 .46934 .65629 .4798 .68303 .47781 Mtetra
.457 .795 .999 r
.67055 .45668 .643 .45866 .64975 .46934 .67689 .46735 Mtetra
.451 .793 .998 r
.66401 .44582 .63602 .44779 .643 .45866 .67055 .45668 Mtetra
.443 .791 .998 r
.65724 .43478 .62881 .43673 .63602 .44779 .66401 .44582 Mtetra
.437 .789 .997 r
.65024 .42347 .62136 .42541 .62881 .43673 .65724 .43478 Mtetra
.427 .788 .996 r
.643 .41208 .61364 .41399 .62136 .42541 .65024 .42347 Mtetra
.415 .785 .994 r
.63551 .40061 .60565 .40247 .61364 .41399 .643 .41208 Mtetra
.403 .782 .992 r
.62774 .38907 .59736 .39087 .60565 .40247 .63551 .40061 Mtetra
.39 .779 .989 r
.61967 .37745 .58876 .37919 .59736 .39087 .62774 .38907 Mtetra
.376 .774 .986 r
.61129 .36576 .57982 .36742 .58876 .37919 .61967 .37745 Mtetra
.361 .769 .982 r
.60257 .35402 .57052 .35557 .57982 .36742 .61129 .36576 Mtetra
.346 .764 .978 r
.59349 .34221 .56083 .34364 .57052 .35557 .60257 .35402 Mtetra
.329 .757 .972 r
.58402 .33035 .55072 .33165 .56083 .34364 .59349 .34221 Mtetra
.31 .75 .966 r
.57413 .31851 .54016 .31964 .55072 .33165 .58402 .33035 Mtetra
.293 .742 .96 r
.56378 .30657 .52911 .30752 .54016 .31964 .57413 .31851 Mtetra
.276 .734 .953 r
.55293 .2945 .51754 .29524 .52911 .30752 .56378 .30657 Mtetra
.254 .723 .944 r
.54155 .28247 .50539 .28298 .51754 .29524 .55293 .2945 Mtetra
.241 .715 .94 r
.52958 .27002 .49263 .27028 .50539 .28298 .54155 .28247 Mtetra
.232 .708 .938 r
.51699 .25686 .47921 .25688 .49263 .27028 .52958 .27002 Mtetra
.477 .802 1 r
.73128 .5153 .7058 .51725 .71107 .52645 .7362 .52449 Mtetra
.475 .8 1 r
.72622 .50583 .70036 .50778 .7058 .51725 .73128 .5153 Mtetra
.472 .799 .999 r
.72099 .49609 .69476 .49804 .70036 .50778 .72622 .50583 Mtetra
.468 .797 .999 r
.7156 .4861 .68899 .48804 .69476 .49804 .72099 .49609 Mtetra
.464 .796 .999 r
.71005 .47588 .68303 .47781 .68899 .48804 .7156 .4861 Mtetra
.459 .795 .999 r
.70432 .46543 .67689 .46735 .68303 .47781 .71005 .47588 Mtetra
.453 .793 .998 r
.69841 .45477 .67055 .45668 .67689 .46735 .70432 .46543 Mtetra
.446 .791 .998 r
.6923 .44393 .66401 .44582 .67055 .45668 .69841 .45477 Mtetra
.438 .79 .997 r
.68599 .43291 .65724 .43478 .66401 .44582 .6923 .44393 Mtetra
.431 .788 .997 r
.67947 .42163 .65024 .42347 .65724 .43478 .68599 .43291 Mtetra
.42 .785 .995 r
.67272 .41028 .643 .41208 .65024 .42347 .67947 .42163 Mtetra
.408 .783 .993 r
.66573 .39886 .63551 .40061 .643 .41208 .67272 .41028 Mtetra
.395 .779 .991 r
.65849 .38738 .62774 .38907 .63551 .40061 .66573 .39886 Mtetra
.382 .775 .987 r
.65098 .37584 .61967 .37745 .62774 .38907 .65849 .38738 Mtetra
.367 .771 .984 r
.64318 .36425 .61129 .36576 .61967 .37745 .65098 .37584 Mtetra
.351 .765 .98 r
.63507 .35262 .60257 .35402 .61129 .36576 .64318 .36425 Mtetra
.335 .759 .975 r
.62662 .34095 .59349 .34221 .60257 .35402 .63507 .35262 Mtetra
.318 .752 .969 r
.61781 .32925 .58402 .33035 .59349 .34221 .62662 .34095 Mtetra
.298 .744 .962 r
.60862 .31759 .57413 .31851 .58402 .33035 .61781 .32925 Mtetra
.28 .736 .955 r
.59899 .30586 .56378 .30657 .57413 .31851 .60862 .31759 Mtetra
.262 .727 .948 r
.58891 .29401 .55293 .2945 .56378 .30657 .59899 .30586 Mtetra
.239 .716 .938 r
.57832 .28224 .54155 .28247 .55293 .2945 .58891 .29401 Mtetra
.226 .707 .933 r
.56719 .27006 .52958 .27002 .54155 .28247 .57832 .28224 Mtetra
.217 .699 .931 r
.55547 .25719 .51699 .25686 .52958 .27002 .56719 .27006 Mtetra
.473 .801 1 r
.75702 .5134 .73128 .5153 .7362 .52449 .76157 .52258 Mtetra
.471 .799 .999 r
.75232 .50394 .72622 .50583 .73128 .5153 .75702 .5134 Mtetra
.468 .797 .999 r
.74748 .49421 .72099 .49609 .72622 .50583 .75232 .50394 Mtetra
.464 .796 .999 r
.74249 .48423 .7156 .4861 .72099 .49609 .74748 .49421 Mtetra
.459 .794 .999 r
.73735 .47402 .71005 .47588 .7156 .4861 .74249 .48423 Mtetra
.453 .793 .999 r
.73204 .46358 .70432 .46543 .71005 .47588 .73735 .47402 Mtetra
.447 .791 .998 r
.72657 .45295 .69841 .45477 .70432 .46543 .73204 .46358 Mtetra
.44 .79 .997 r
.72092 .44213 .6923 .44393 .69841 .45477 .72657 .45295 Mtetra
.432 .788 .997 r
.71508 .43114 .68599 .43291 .6923 .44393 .72092 .44213 Mtetra
.425 .785 .996 r
.70904 .41989 .67947 .42163 .68599 .43291 .71508 .43114 Mtetra
.413 .783 .994 r
.7028 .40859 .67272 .41028 .67947 .42163 .70904 .41989 Mtetra
.401 .78 .992 r
.69634 .39723 .66573 .39886 .67272 .41028 .7028 .40859 Mtetra
.387 .776 .989 r
.68965 .38583 .65849 .38738 .66573 .39886 .69634 .39723 Mtetra
.373 .772 .985 r
.68271 .37438 .65098 .37584 .65849 .38738 .68965 .38583 Mtetra
.357 .767 .981 r
.67551 .36291 .64318 .36425 .65098 .37584 .68271 .37438 Mtetra
.341 .761 .977 r
.66803 .35141 .63507 .35262 .64318 .36425 .67551 .36291 Mtetra
.324 .754 .971 r
.66024 .33989 .62662 .34095 .63507 .35262 .66803 .35141 Mtetra
.305 .747 .965 r
.65212 .32836 .61781 .32925 .62662 .34095 .66024 .33989 Mtetra
.285 .738 .957 r
.64365 .3169 .60862 .31759 .61781 .32925 .65212 .32836 Mtetra
.266 .728 .949 r
.63478 .3054 .59899 .30586 .60862 .31759 .64365 .3169 Mtetra
.247 .719 .942 r
.6255 .29381 .58891 .29401 .59899 .30586 .63478 .3054 Mtetra
.224 .707 .931 r
.61575 .28233 .57832 .28224 .58891 .29401 .6255 .29381 Mtetra
.21 .698 .926 r
.6055 .27046 .56719 .27006 .57832 .28224 .61575 .28233 Mtetra
.2 .69 .924 r
.5947 .25789 .55547 .25719 .56719 .27006 .6055 .27046 Mtetra
.468 .799 .999 r
.78301 .51157 .75702 .5134 .76157 .52258 .78719 .52073 Mtetra
.466 .798 .999 r
.77869 .50213 .75232 .50394 .75702 .5134 .78301 .51157 Mtetra
.462 .796 .999 r
.77425 .49242 .74748 .49421 .75232 .50394 .77869 .50213 Mtetra
.458 .794 .999 r
.76967 .48245 .74249 .48423 .74748 .49421 .77425 .49242 Mtetra
.453 .793 .999 r
.76494 .47226 .73735 .47402 .74249 .48423 .76967 .48245 Mtetra
.448 .791 .998 r
.76007 .46184 .73204 .46358 .73735 .47402 .76494 .47226 Mtetra
.441 .789 .998 r
.75504 .45123 .72657 .45295 .73204 .46358 .76007 .46184 Mtetra
.433 .787 .997 r
.74986 .44044 .72092 .44213 .72657 .45295 .75504 .45123 Mtetra
.424 .785 .996 r
.7445 .4295 .71508 .43114 .72092 .44213 .74986 .44044 Mtetra
.418 .782 .995 r
.73897 .4183 .70904 .41989 .71508 .43114 .7445 .4295 Mtetra
.405 .78 .993 r
.73325 .40705 .7028 .40859 .70904 .41989 .73897 .4183 Mtetra
.392 .776 .99 r
.72733 .39577 .69634 .39723 .7028 .40859 .73325 .40705 Mtetra
.377 .772 .987 r
.72121 .38445 .68965 .38583 .69634 .39723 .72733 .39577 Mtetra
.362 .767 .983 r
.71487 .37312 .68271 .37438 .68965 .38583 .72121 .38445 Mtetra
.346 .762 .979 r
.7083 .36177 .67551 .36291 .68271 .37438 .71487 .37312 Mtetra
.329 .755 .973 r
.70147 .35042 .66803 .35141 .67551 .36291 .7083 .36177 Mtetra
.311 .748 .967 r
.69436 .33907 .66024 .33989 .66803 .35141 .70147 .35042 Mtetra
.291 .74 .96 r
.68696 .32775 .65212 .32836 .66024 .33989 .69436 .33907 Mtetra
.27 .73 .951 r
.67924 .31652 .64365 .3169 .65212 .32836 .68696 .32775 Mtetra
.25 .72 .943 r
.67118 .30528 .63478 .3054 .64365 .3169 .67924 .31652 Mtetra
.23 .709 .935 r
.66273 .29397 .6255 .29381 .63478 .3054 .67118 .30528 Mtetra
.206 .696 .923 r
.65387 .28282 .61575 .28233 .6255 .29381 .66273 .29397 Mtetra
.191 .687 .918 r
.64454 .2713 .6055 .27046 .61575 .28233 .65387 .28282 Mtetra
.182 .679 .916 r
.6347 .25908 .5947 .25789 .6055 .27046 .64454 .2713 Mtetra
.462 .797 .999 r
.80925 .50985 .78301 .51157 .78719 .52073 .81305 .51899 Mtetra
.459 .795 .999 r
.80533 .50043 .77869 .50213 .78301 .51157 .80925 .50985 Mtetra
.456 .793 .999 r
.8013 .49074 .77425 .49242 .77869 .50213 .80533 .50043 Mtetra
.452 .792 .998 r
.79713 .48081 .76967 .48245 .77425 .49242 .8013 .49074 Mtetra
.446 .79 .998 r
.79284 .47064 .76494 .47226 .76967 .48245 .79713 .48081 Mtetra
.44 .788 .998 r
.78841 .46025 .76007 .46184 .76494 .47226 .79284 .47064 Mtetra
.433 .786 .997 r
.78385 .44968 .75504 .45123 .76007 .46184 .78841 .46025 Mtetra
.425 .784 .996 r
.77914 .43894 .74986 .44044 .75504 .45123 .78385 .44968 Mtetra
.416 .781 .995 r
.77429 .42804 .7445 .4295 .74986 .44044 .77914 .43894 Mtetra
.408 .778 .994 r
.76927 .4169 .73897 .4183 .7445 .4295 .77429 .42804 Mtetra
.395 .775 .991 r
.76409 .40573 .73325 .40705 .73897 .4183 .76927 .4169 Mtetra
.381 .771 .988 r
.75874 .39453 .72733 .39577 .73325 .40705 .76409 .40573 Mtetra
.366 .767 .985 r
.75321 .38333 .72121 .38445 .72733 .39577 .75874 .39453 Mtetra
.349 .761 .98 r
.74749 .37213 .71487 .37312 .72121 .38445 .75321 .38333 Mtetra
.332 .755 .975 r
.74156 .36093 .7083 .36177 .71487 .37312 .74749 .37213 Mtetra
.314 .748 .969 r
.73541 .34976 .70147 .35042 .7083 .36177 .74156 .36093 Mtetra
.294 .739 .962 r
.72902 .33862 .69436 .33907 .70147 .35042 .73541 .34976 Mtetra
.274 .73 .955 r
.72237 .32752 .68696 .32775 .69436 .33907 .72902 .33862 Mtetra
.251 .719 .945 r
.71544 .31656 .67924 .31652 .68696 .32775 .72237 .32752 Mtetra
.23 .708 .936 r
.70821 .30562 .67118 .30528 .67924 .31652 .71544 .31656 Mtetra
.21 .697 .927 r
.70064 .29464 .66273 .29397 .67118 .30528 .70821 .30562 Mtetra
.184 .683 .914 r
.69271 .28387 .65387 .28282 .66273 .29397 .70064 .29464 Mtetra
.169 .672 .908 r
.68436 .27275 .64454 .2713 .65387 .28282 .69271 .28387 Mtetra
.159 .664 .906 r
.67554 .26094 .6347 .25908 .64454 .2713 .68436 .27275 Mtetra
.453 .794 .999 r
.83577 .50831 .80925 .50985 .81305 .51899 .83918 .51741 Mtetra
.451 .791 .998 r
.83226 .49893 .80533 .50043 .80925 .50985 .83577 .50831 Mtetra
.447 .789 .998 r
.82864 .48928 .8013 .49074 .80533 .50043 .83226 .49893 Mtetra
.442 .787 .998 r
.82491 .47938 .79713 .48081 .8013 .49074 .82864 .48928 Mtetra
.436 .785 .997 r
.82106 .46926 .79284 .47064 .79713 .48081 .82491 .47938 Mtetra
.43 .783 .997 r
.81709 .45892 .78841 .46025 .79284 .47064 .82106 .46926 Mtetra
.422 .78 .996 r
.81301 .44841 .78385 .44968 .78841 .46025 .81709 .45892 Mtetra
.413 .778 .995 r
.8088 .43773 .77914 .43894 .78385 .44968 .81301 .44841 Mtetra
.403 .775 .993 r
.80446 .42691 .77429 .42804 .77914 .43894 .8088 .43773 Mtetra
.395 .772 .992 r
.79997 .41585 .76927 .4169 .77429 .42804 .80446 .42691 Mtetra
.38 .768 .989 r
.79535 .40477 .76409 .40573 .76927 .4169 .79997 .41585 Mtetra
.365 .763 .986 r
.79059 .3937 .75874 .39453 .76409 .40573 .79535 .40477 Mtetra
.349 .757 .981 r
.78567 .38264 .75321 .38333 .75874 .39453 .79059 .3937 Mtetra
.331 .751 .976 r
.78059 .3716 .74749 .37213 .75321 .38333 .78567 .38264 Mtetra
.312 .744 .97 r
.77534 .3606 .74156 .36093 .74749 .37213 .78059 .3716 Mtetra
.293 .735 .964 r
.7699 .34964 .73541 .34976 .74156 .36093 .77534 .3606 Mtetra
.272 .726 .956 r
.76425 .33875 .72902 .33862 .73541 .34976 .7699 .34964 Mtetra
.25 .715 .947 r
.75839 .32794 .72237 .32752 .72902 .33862 .76425 .33875 Mtetra
.225 .703 .936 r
.7523 .31731 .71544 .31656 .72237 .32752 .75839 .32794 Mtetra
.203 .691 .926 r
.74594 .30673 .70821 .30562 .71544 .31656 .7523 .31731 Mtetra
.181 .678 .916 r
.73929 .29616 .70064 .29464 .70821 .30562 .74594 .30673 Mtetra
.153 .662 .902 r
.73235 .28585 .69271 .28387 .70064 .29464 .73929 .29616 Mtetra
.137 .65 .895 r
.72503 .27521 .68436 .27275 .69271 .28387 .73235 .28585 Mtetra
.127 .641 .893 r
.7173 .2639 .67554 .26094 .68436 .27275 .72503 .27521 Mtetra
.439 .786 .998 r
.8626 .50716 .83577 .50831 .83918 .51741 .8656 .51619 Mtetra
.435 .783 .997 r
.85951 .49784 .83226 .49893 .83577 .50831 .8626 .50716 Mtetra
.431 .781 .997 r
.85631 .48825 .82864 .48928 .83226 .49893 .85951 .49784 Mtetra
.425 .778 .996 r
.85303 .47843 .82491 .47938 .82864 .48928 .85631 .48825 Mtetra
.419 .775 .996 r
.84964 .46837 .82106 .46926 .82491 .47938 .85303 .47843 Mtetra
.411 .772 .995 r
.84615 .45812 .81709 .45892 .82106 .46926 .84964 .46837 Mtetra
.402 .769 .994 r
.84256 .4477 .81301 .44841 .81709 .45892 .84615 .45812 Mtetra
.392 .766 .992 r
.83886 .43712 .8088 .43773 .81301 .44841 .84256 .4477 Mtetra
.381 .762 .99 r
.83506 .42642 .80446 .42691 .8088 .43773 .83886 .43712 Mtetra
.372 .758 .989 r
.83113 .41548 .79997 .41585 .80446 .42691 .83506 .42642 Mtetra
.356 .753 .985 r
.82709 .40456 .79535 .40477 .79997 .41585 .83113 .41548 Mtetra
.338 .747 .981 r
.82293 .39366 .79059 .3937 .79535 .40477 .82709 .40456 Mtetra
.32 .74 .976 r
.81866 .3828 .78567 .38264 .79059 .3937 .82293 .39366 Mtetra
.3 .732 .969 r
.81425 .37199 .78059 .3716 .78567 .38264 .81866 .3828 Mtetra
.279 .722 .962 r
.80971 .36126 .77534 .3606 .78059 .3716 .81425 .37199 Mtetra
.257 .712 .954 r
.80501 .35061 .7699 .34964 .77534 .3606 .80971 .36126 Mtetra
.234 .7 .945 r
.80015 .34006 .76425 .33875 .7699 .34964 .80501 .35061 Mtetra
.21 .688 .935 r
.79512 .32964 .75839 .32794 .76425 .33875 .80015 .34006 Mtetra
.182 .673 .922 r
.78991 .31944 .7523 .31731 .75839 .32794 .79512 .32964 Mtetra
.157 .658 .91 r
.78448 .30935 .74594 .30673 .7523 .31731 .78991 .31944 Mtetra
.133 .643 .899 r
.77882 .29932 .73929 .29616 .74594 .30673 .78448 .30935 Mtetra
.103 .624 .882 r
.77292 .28962 .73235 .28585 .73929 .29616 .77882 .29932 Mtetra
.086 .611 .875 r
.7667 .27962 .72503 .27521 .73235 .28585 .77292 .28962 Mtetra
.073 .599 .872 r
.76012 .26897 .7173 .2639 .72503 .27521 .7667 .27962 Mtetra
.41 .768 .995 r
.88981 .50687 .8626 .50716 .8656 .51619 .89239 .51578 Mtetra
.405 .764 .994 r
.88715 .49768 .85951 .49784 .8626 .50716 .88981 .50687 Mtetra
.399 .761 .994 r
.8844 .48822 .85631 .48825 .85951 .49784 .88715 .49768 Mtetra
.392 .757 .993 r
.88158 .47853 .85303 .47843 .85631 .48825 .8844 .48822 Mtetra
.383 .753 .991 r
.87867 .46862 .84964 .46837 .85303 .47843 .88158 .47853 Mtetra
.374 .748 .99 r
.87568 .45853 .84615 .45812 .84964 .46837 .87867 .46862 Mtetra
.363 .743 .988 r
.87261 .44827 .84256 .4477 .84615 .45812 .87568 .45853 Mtetra
.35 .738 .986 r
.86945 .43788 .83886 .43712 .84256 .4477 .87261 .44827 Mtetra
.336 .732 .983 r
.86621 .42739 .83506 .42642 .83886 .43712 .86945 .43788 Mtetra
.325 .726 .98 r
.86286 .41668 .83113 .41548 .83506 .42642 .86621 .42739 Mtetra
.305 .718 .975 r
.85944 .40602 .82709 .40456 .83113 .41548 .86286 .41668 Mtetra
.284 .709 .969 r
.85593 .39542 .82293 .39366 .82709 .40456 .85944 .40602 Mtetra
.262 .699 .962 r
.85233 .3849 .81866 .3828 .82293 .39366 .85593 .39542 Mtetra
.238 .688 .954 r
.84864 .37448 .81425 .37199 .81866 .3828 .85233 .3849 Mtetra
.213 .675 .945 r
.84485 .36418 .80971 .36126 .81425 .37199 .84864 .37448 Mtetra
.187 .66 .934 r
.84095 .35401 .80501 .35061 .80971 .36126 .84485 .36418 Mtetra
.16 .645 .922 r
.83693 .34401 .80015 .34006 .80501 .35061 .84095 .35401 Mtetra
.131 .628 .909 r
.83279 .33419 .79512 .32964 .80015 .34006 .83693 .34401 Mtetra
.099 .608 .893 r
.82852 .32468 .78991 .31944 .79512 .32964 .83279 .33419 Mtetra
.07 .589 .878 r
.8241 .31535 .78448 .30935 .78991 .31944 .82852 .32468 Mtetra
.043 .569 .864 r
.8195 .30614 .77882 .29932 .78448 .30935 .8241 .31535 Mtetra
.009 .546 .844 r
.81473 .29736 .77292 .28962 .77882 .29932 .8195 .30614 Mtetra
0 .529 .835 r
.80971 .28834 .7667 .27962 .77292 .28962 .81473 .29736 Mtetra
0 .514 .83 r
.80439 .27871 .76012 .26897 .7667 .27962 .80971 .28834 Mtetra
.341 .721 .985 r
.91759 .50878 .88981 .50687 .89239 .51578 .91971 .51742 Mtetra
.333 .714 .983 r
.91539 .49985 .88715 .49768 .88981 .50687 .91759 .50878 Mtetra
.324 .708 .981 r
.91313 .49068 .8844 .48822 .88715 .49768 .91539 .49985 Mtetra
.313 .7 .979 r
.9108 .48128 .88158 .47853 .8844 .48822 .91313 .49068 Mtetra
.3 .693 .976 r
.90841 .47169 .87867 .46862 .88158 .47853 .9108 .48128 Mtetra
.286 .684 .973 r
.90596 .46194 .87568 .45853 .87867 .46862 .90841 .47169 Mtetra
.27 .675 .969 r
.90344 .45205 .87261 .44827 .87568 .45853 .90596 .46194 Mtetra
.252 .665 .964 r
.90087 .44207 .86945 .43788 .87261 .44827 .90344 .45205 Mtetra
.233 .654 .958 r
.89823 .43203 .86621 .42739 .86945 .43788 .90087 .44207 Mtetra
.216 .643 .953 r
.89552 .42179 .86286 .41668 .86621 .42739 .89823 .43203 Mtetra
.19 .629 .945 r
.89277 .41167 .85944 .40602 .86286 .41668 .89552 .42179 Mtetra
.162 .613 .934 r
.88997 .40167 .85593 .39542 .85944 .40602 .89277 .41167 Mtetra
.132 .596 .923 r
.88712 .39182 .85233 .3849 .85593 .39542 .88997 .40167 Mtetra
.101 .577 .909 r
.88421 .38215 .84864 .37448 .85233 .3849 .88712 .39182 Mtetra
.069 .556 .895 r
.88125 .37268 .84485 .36418 .84864 .37448 .88421 .38215 Mtetra
.036 .534 .878 r
.87824 .36344 .84095 .35401 .84485 .36418 .88125 .37268 Mtetra
.001 .51 .86 r
.87516 .35447 .83693 .34401 .84095 .35401 .87824 .36344 Mtetra
0 .484 .841 r
.87201 .34579 .83279 .33419 .83693 .34401 .87516 .35447 Mtetra
0 .456 .818 r
.86881 .33756 .82852 .32468 .83279 .33419 .87201 .34579 Mtetra
0 .429 .798 r
.86552 .32963 .8241 .31535 .82852 .32468 .86881 .33756 Mtetra
0 .403 .778 r
.86212 .32195 .8195 .30614 .8241 .31535 .86552 .32963 Mtetra
0 .373 .752 r
.85865 .31487 .81473 .29736 .8195 .30614 .86212 .32195 Mtetra
0 .35 .738 r
.85499 .30762 .80971 .28834 .81473 .29736 .85865 .31487 Mtetra
0 .33 .73 r
.8511 .29981 .80439 .27871 .80971 .28834 .85499 .30762 Mtetra
.168 .584 .936 r
.9465 .51655 .91759 .50878 .91971 .51742 .94811 .52458 Mtetra
.153 .57 .931 r
.94484 .50828 .91539 .49985 .91759 .50878 .9465 .51655 Mtetra
.135 .556 .924 r
.94313 .49979 .91313 .49068 .91539 .49985 .94484 .50828 Mtetra
.116 .54 .916 r
.94137 .49112 .9108 .48128 .91313 .49068 .94313 .49979 Mtetra
.095 .524 .908 r
.93958 .48231 .90841 .47169 .9108 .48128 .94137 .49112 Mtetra
.072 .506 .898 r
.93775 .4734 .90596 .46194 .90841 .47169 .93958 .48231 Mtetra
.047 .486 .887 r
.93589 .46442 .90344 .45205 .90596 .46194 .93775 .4734 Mtetra
.02 .466 .874 r
.934 .45542 .90087 .44207 .90344 .45205 .93589 .46442 Mtetra
0 .443 .86 r
.93209 .44645 .89823 .43203 .90087 .44207 .934 .45542 Mtetra
0 .422 .846 r
.93013 .43736 .89552 .42179 .89823 .43203 .93209 .44645 Mtetra
0 .395 .827 r
.92818 .42851 .89277 .41167 .89552 .42179 .93013 .43736 Mtetra
0 .367 .806 r
.92622 .41993 .88997 .40167 .89277 .41167 .92818 .42851 Mtetra
0 .337 .784 r
.92427 .41165 .88712 .39182 .88997 .40167 .92622 .41993 Mtetra
0 .307 .76 r
.92233 .40371 .88421 .38215 .88712 .39182 .92427 .41165 Mtetra
0 .275 .735 r
.9204 .39615 .88125 .37268 .88421 .38215 .92233 .40371 Mtetra
0 .243 .708 r
.91847 .38902 .87824 .36344 .88125 .37268 .9204 .39615 Mtetra
0 .21 .681 r
.91656 .38237 .87516 .35447 .87824 .36344 .91847 .38902 Mtetra
0 .178 .654 r
.91466 .37625 .87201 .34579 .87516 .35447 .91656 .38237 Mtetra
0 .144 .624 r
.91281 .37091 .86881 .33756 .87201 .34579 .91466 .37625 Mtetra
0 .113 .598 r
.91095 .36612 .86552 .32963 .86881 .33756 .91281 .37091 Mtetra
0 .084 .574 r
.9091 .36183 .86212 .32195 .86552 .32963 .91095 .36612 Mtetra
0 .054 .546 r
.90727 .35847 .85865 .31487 .86212 .32195 .9091 .36183 Mtetra
0 .139 .648 r
.90434 .347 .85499 .30762 .85865 .31487 .90727 .35847 Mtetra
0 .375 .838 r
.89972 .32296 .8511 .29981 .85499 .30762 .90434 .347 Mtetra
0 0 .416 r
.98474 .58556 .9465 .51655 .94811 .52458 .98547 .59061 Mtetra
0 0 .406 r
.98402 .58052 .94484 .50828 .9465 .51655 .98474 .58556 Mtetra
0 0 .395 r
.98329 .57552 .94313 .49979 .94484 .50828 .98402 .58052 Mtetra
0 0 .384 r
.98258 .57061 .94137 .49112 .94313 .49979 .98329 .57552 Mtetra
0 0 .373 r
.98189 .56584 .93958 .48231 .94137 .49112 .98258 .57061 Mtetra
0 0 .361 r
.98123 .56127 .93775 .4734 .93958 .48231 .98189 .56584 Mtetra
0 0 .349 r
.98061 .55694 .93589 .46442 .93775 .4734 .98123 .56127 Mtetra
0 0 .338 r
.98003 .55293 .934 .45542 .93589 .46442 .98061 .55694 Mtetra
0 0 .326 r
.9795 .54929 .93209 .44645 .934 .45542 .98003 .55293 Mtetra
0 0 .319 r
.97897 .54559 .93013 .43736 .93209 .44645 .9795 .54929 Mtetra
0 0 .306 r
.97855 .54271 .92818 .42851 .93013 .43736 .97897 .54559 Mtetra
0 0 .293 r
.97826 .5407 .92622 .41993 .92818 .42851 .97855 .54271 Mtetra
0 0 .34 r
.97693 .53152 .92427 .41165 .92622 .41993 .97826 .5407 Mtetra
0 0 .391 r
.97466 .51581 .92233 .40371 .92427 .41165 .97693 .53152 Mtetra
0 0 .415 r
.9723 .49946 .9204 .39615 .92233 .40371 .97466 .51581 Mtetra
0 0 .446 r
.96984 .48244 .91847 .38902 .9204 .39615 .9723 .49946 Mtetra
0 0 .486 r
.96727 .46469 .91656 .38237 .91847 .38902 .96984 .48244 Mtetra
0 0 .538 r
.96459 .44617 .91466 .37625 .91656 .38237 .96727 .46469 Mtetra
0 .045 .611 r
.9618 .42683 .91281 .37091 .91466 .37625 .96459 .44617 Mtetra
0 .176 .709 r
.95888 .40661 .91095 .36612 .91281 .37091 .9618 .42683 Mtetra
0 .373 .838 r
.95582 .38545 .9091 .36183 .91095 .36612 .95888 .40661 Mtetra
.28 .65 .968 r
.95262 .36329 .90727 .35847 .9091 .36183 .95582 .38545 Mtetra
.478 .816 .999 r
.94926 .34005 .90434 .347 .90727 .35847 .95262 .36329 Mtetra
.94573 .31565 .89972 .32296 .90434 .347 .94926 .34005 Mtetra
.4 g
.90106 .00661 m
.06031 .18242 L
s
.91226 .08412 m
.04497 .25446 L
s
.92427 .16717 m
.0287 .33091 L
s
.93716 .25637 m
.0114 .4122 L
s
.9001 0 m
.94573 .31565 L
s
.71232 .03947 m
.73085 .34976 L
s
.53546 .07665 m
.53011 .38162 L
s
.36859 .11172 m
.34215 .41145 L
s
.21089 .14487 m
.16579 .43944 L
s
.06162 .17625 m
0 .46575 L
s
0 g
.9001 0 m
.94573 .31565 L
s
.94573 .31565 m
0 .46575 L
s
0 .46575 m
.06162 .17625 L
s
.06162 .17625 m
.9001 0 L
s
.4 g
.90106 .00661 m
.96643 .45888 L
s
.91226 .08412 m
.97515 .51917 L
s
.92427 .16717 m
.98426 .58221 L
s
.93716 .25637 m
.9938 .6482 L
s
.9001 0 m
.94573 .31565 L
s
.9222 .15287 m
.96459 .44617 L
s
.9397 .27398 m
.97912 .54662 L
s
.95391 .37228 m
.99064 .62632 L
s
.96568 .45367 m
1 .6911 L
s
0 g
.9001 0 m
.94573 .31565 L
s
.94573 .31565 m
1 .6911 L
s
1 .6911 m
.96568 .45367 L
s
.96568 .45367 m
.9001 0 L
s
.4 g
.94573 .31565 m
0 .46575 L
s
.96459 .44617 m
.12312 .56199 L
s
.97912 .54662 m
.22126 .63871 L
s
.99064 .62632 m
.30132 .70129 L
s
1 .6911 m
.36788 .75332 L
s
.94573 .31565 m
1 .6911 L
s
.73085 .34976 m
.86268 .70462 L
s
.53011 .38162 m
.73115 .71756 L
s
.34215 .41145 m
.60506 .72998 L
s
.16579 .43944 m
.48407 .74189 L
s
0 .46575 m
.36788 .75332 L
s
0 g
.9001 0 m
.94573 .31565 L
s
.90106 .00661 m
.89401 .00808 L
s
[(0)] .91515 .00366 -1 .20911 Mshowa
.91226 .08412 m
.90519 .08551 L
s
[(0.02)] .92639 .08134 -1 .1964 Mshowa
.92427 .16717 m
.91718 .16847 L
s
[(0.04)] .93843 .16458 -1 .18284 Mshowa
.93716 .25637 m
.93006 .25757 L
s
[(0.06)] .95136 .25398 -1 .16832 Mshowa
.125 Mabswid
.90379 .0255 m
.89955 .02637 L
s
.90656 .04471 m
.90233 .04557 L
s
.90939 .06425 m
.90515 .06509 L
s
.91518 .10434 m
.91094 .10516 L
s
.91816 .12492 m
.91391 .12572 L
s
.92118 .14586 m
.91694 .14665 L
s
.9274 .18887 m
.92315 .18963 L
s
.9306 .21096 m
.92634 .21171 L
s
.93385 .23346 m
.92959 .23419 L
s
.94053 .27972 m
.93627 .28042 L
s
.94397 .3035 m
.93971 .30418 L
s
gsave
1.00638 .13164 -61 -11.4128 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(IRF) show
81.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[49]:=",
  ImageSize->{288, 216.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[49]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[lung, \ modelAMAD]\)], "Input",
  CellLabel->"In[50]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 8", "SubsubsectionIcon",
  CellTags->"Examples"],

Cell[TextData[{
  "Here is used the function ",
  StyleBox["AMADfit[x]", "Input"],
  " to get a fitted intake retention function as funtion of AMAD and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LungsRetention[1, AMADfit[x]\ , S, \ t, 0] // Chop\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \(\(-2.6744111608650476`*^-8\)\ \[ExponentialE]\^\(\(-110.1`\)\ t - \
4.353270952537328`\ x\) - 
      1.8586651555154462`*^-7\ \[ExponentialE]\^\(\(-102.1`\)\ t - \
4.353270952537328`\ x\) + 
      0.00002130580490632139`\ \[ExponentialE]\^\(\(-100.13`\)\ t - \
4.353270952537328`\ x\) + 
      1.4869321244125196`*^-7\ \[ExponentialE]\^\(\(-100.1`\)\ t - \
4.353270952537328`\ x\) - 
      0.00002677088249115705`\ \[ExponentialE]\^\(\(-10.0001`\)\ t - \
4.353270952537328`\ x\) - 
      0.00018605256811968248`\ \[ExponentialE]\^\(\(-2.0001`\)\ t - \
4.353270952537328`\ x\) + 
      0.021327132038364522`\ \[ExponentialE]\^\(\(-0.0301`\)\ t - \
4.353270952537328`\ x\) + 
      0.00014884205449574596`\ \[ExponentialE]\^\(\(-0.0001`\)\ t - \
4.353270952537328`\ x\) + 
      7.743249257250958`*^-8\ \[ExponentialE]\^\(\(-110.1`\)\ t - \
1.1114709327884795`\ x\) - 
      0.000011061784653215376`\ \[ExponentialE]\^\(\(-100.13`\)\ t - \
1.1114709327884795`\ x\) - 
      7.743249257252313`*^-8\ \[ExponentialE]\^\(\(-100.1`\)\ t - \
1.1114709327884795`\ x\) + 
      0.00007751000257509473`\ \[ExponentialE]\^\(\(-10.0001`\)\ t - \
1.1114709327884795`\ x\) - 
      0.011072857510727818`\ \[ExponentialE]\^\(\(-0.0301`\)\ t - \
1.1114709327884795`\ x\) - 
      0.00007751000257509471`\ \[ExponentialE]\^\(\(-0.0001`\)\ t - \
1.1114709327884795`\ x\) - 
      0.000017019528996169847`\ \[ExponentialE]\^\(\(-110.1`\)\ t - \
0.5667829354923091`\ x\) - 
      1.1997653874441653`*^-7\ \[ExponentialE]\^\(\(-100.1`\)\ t - \
0.5667829354923091`\ x\) - 
      0.017036565561733847`\ \[ExponentialE]\^\(\(-10.0001`\)\ t - \
0.5667829354923091`\ x\) - 
      0.00012009663537979547`\ \[ExponentialE]\^\(\(-0.0001`\)\ t - \
0.5667829354923091`\ x\) + 
      2.1179221904036374`*^-8\ \[ExponentialE]\^\(\(-110.1`\)\ t - \
0.17011061305604133`\ x\) - 
      5.333842485646511`*^-7\ \[ExponentialE]\^\(\(-102.1`\)\ t - \
0.17011061305604133`\ x\) + 
      0.00003884461434045666`\ \[ExponentialE]\^\(\(-100.11999999999999`\)\ t \
- 0.17011061305604133`\ x\) + 
      0.00007680459063545697`\ \[ExponentialE]\^\(\(-100.101`\)\ t - \
0.17011061305604133`\ x\) + 
      0.000010661672038446077`\ \[ExponentialE]\^\(\(-100.10012`\)\ t - \
0.17011061305604133`\ x\) + 
      2.1321808811470416`*^-6\ \[ExponentialE]\^\(\(-100.1`\)\ t - \
0.17011061305604133`\ x\) + 
      0.000021200422326368132`\ \[ExponentialE]\^\(\(-10.0001`\)\ t - \
0.17011061305604133`\ x\) - 
      0.000533918166731499`\ \[ExponentialE]\^\(\(-2.0001`\)\ t - \
0.17011061305604133`\ x\) + 
      0.03888349783829052`\ \[ExponentialE]\^\(\(-0.0201`\)\ t - \
0.17011061305604133`\ x\) + 
      0.07688147210756655`\ \[ExponentialE]\^\(\(-0.0011`\)\ t - \
0.17011061305604133`\ x\) + 
      0.010672344382830311`\ \[ExponentialE]\^\(\(-0.00022`\)\ t - \
0.17011061305604133`\ x\) + 
      0.0021343151963437667`\ \[ExponentialE]\^\(\(-0.0001`\)\ t - \
0.17011061305604133`\ x\) - 
      1.1572369185725587`*^-8\ \[ExponentialE]\^\(\(-110.1`\)\ t - \
0.14724386061421538`\ x\) - 
      8.042577628677191`*^-8\ \[ExponentialE]\^\(\(-102.1`\)\ t - \
0.14724386061421538`\ x\) + 
      9.219174814358716`*^-6\ \[ExponentialE]\^\(\(-100.13`\)\ t - \
0.14724386061421538`\ x\) + 
      6.43406210294338`*^-8\ \[ExponentialE]\^\(\(-100.1`\)\ t - \
0.14724386061421538`\ x\) - 
      0.000011583953138867041`\ \[ExponentialE]\^\(\(-10.0001`\)\ t - \
0.14724386061421538`\ x\) - 
      0.0000805062825693618`\ \[ExponentialE]\^\(\(-2.0001`\)\ t - \
0.14724386061421538`\ x\) + 
      0.009228403217579801`\ \[ExponentialE]\^\(\(-0.0301`\)\ t - \
0.14724386061421538`\ x\) + 
      0.00006440502605548942`\ \[ExponentialE]\^\(\(-0.0001`\)\ t - \
0.14724386061421538`\ x\) - 
      7.743249257250958`*^-8\ \[ExponentialE]\^\(\(-110.1`\)\ t - \
0.1235776148578769`\ x\) + 
      0.000011061784653215376`\ \[ExponentialE]\^\(\(-100.13`\)\ t - \
0.1235776148578769`\ x\) + 
      7.743249257252313`*^-8\ \[ExponentialE]\^\(\(-100.1`\)\ t - \
0.1235776148578769`\ x\) - 
      0.00007751000257509473`\ \[ExponentialE]\^\(\(-10.0001`\)\ t - \
0.1235776148578769`\ x\) + 
      0.011072857510727818`\ \[ExponentialE]\^\(\(-0.0301`\)\ t - \
0.1235776148578769`\ x\) + 
      0.00007751000257509471`\ \[ExponentialE]\^\(\(-0.0001`\)\ t - \
0.1235776148578769`\ x\) - 
      2.495804722963974`*^-6\ \[ExponentialE]\^\(\(-110.1`\)\ t - \
0.08789446045802779`\ x\) + 
      0.000012479023614819437`\ \[ExponentialE]\^\(\(-102.1`\)\ t - \
0.08789446045802779`\ x\) + 
      7.037515835146455`*^-8\ \[ExponentialE]\^\(\(-100.1`\)\ t - \
0.08789446045802779`\ x\) - 
      0.002498303025990488`\ \[ExponentialE]\^\(\(-10.0001`\)\ t - \
0.08789446045802779`\ x\) + 
      0.01249151512995244`\ \[ExponentialE]\^\(\(-2.0001`\)\ t - \
0.08789446045802779`\ x\) + 
      0.0000704456039554216`\ \[ExponentialE]\^\(\(-0.0001`\)\ t - \
0.08789446045802779`\ x\) + 
      0.000017019528996169847`\ \[ExponentialE]\^\(\(-110.1`\)\ t - \
0.05778349162703789`\ x\) + 
      1.1997653874441653`*^-7\ \[ExponentialE]\^\(\(-100.1`\)\ t - \
0.05778349162703789`\ x\) + 
      0.017036565561733847`\ \[ExponentialE]\^\(\(-10.0001`\)\ t - \
0.05778349162703789`\ x\) + 
      0.00012009663537979547`\ \[ExponentialE]\^\(\(-0.0001`\)\ t - \
0.05778349162703789`\ x\)\)], "Output",
  CellLabel->"Out[51]="]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{1016, 643},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageFooters->{{Inherited, Cell[ 
        TextData[ {
          "\[Copyright]2004 Guillermo Sanchez & ENUSA. All rights \
reserved."}], "PageFooter"], Inherited}, {Inherited, Cell[ 
        TextData[ {
          "\[Copyright]2004 Guillermo Sanchez & ENUSA . All rights \
reserved."}], "PageFooter"], Inherited}},
ShowSelection->True,
Magnification->1.5,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Introduction"->{
    Cell[2200, 74, 116, 3, 70, "Input",
      CellTags->"Introduction"],
    Cell[2319, 79, 119, 3, 70, "Print",
      CellTags->"Introduction"],
    Cell[116213, 1639, 1007, 28, 70, "DefinitionBox",
      CellTags->"Introduction"],
    Cell[117223, 1669, 958, 27, 70, "DefinitionBox",
      CellTags->"Introduction"],
    Cell[118184, 1698, 1071, 33, 70, "DefinitionBox",
      CellTags->"Introduction"],
    Cell[119258, 1733, 1077, 33, 70, "DefinitionBox",
      CellTags->"Introduction"],
    Cell[132534, 2168, 115, 3, 70, "Input",
      CellTags->"Introduction"],
    Cell[132652, 2173, 5596, 140, 70, "Print",
      CellTags->"Introduction"]},
  "Info3333717806-1192881"->{
    Cell[138434, 2324, 320, 5, 70, "Print",
      CellTags->"Info3333717806-1192881"]},
  "Info3333717806-3361058"->{
    Cell[140534, 2399, 116, 2, 70, "Print",
      CellTags->"Info3333717806-3361058"]},
  "Info3333717806-8086490"->{
    Cell[140754, 2410, 112, 2, 70, "Print",
      CellTags->"Info3333717806-8086490"]},
  "Examples"->{
    Cell[143734, 2538, 59, 1, 58, "SubsectionIcon",
      CellTags->"Examples"],
    Cell[143818, 2543, 62, 1, 35, "SubsubsectionIcon",
      CellTags->"Examples"],
    Cell[143883, 2546, 234, 5, 70, "MathCaption",
      CellTags->"Examples"],
    Cell[155582, 2807, 348, 10, 70, "MathCaption",
      CellTags->"Examples"],
    Cell[157624, 2874, 62, 1, 27, "SubsubsectionIcon",
      CellTags->"Examples"],
    Cell[229487, 4594, 62, 1, 27, "SubsubsectionIcon",
      CellTags->"Examples"],
    Cell[229552, 4597, 628, 18, 70, "MathCaption",
      CellTags->"Examples"],
    Cell[233286, 4691, 167, 4, 70, "Input",
      CellTags->"Examples"],
    Cell[233456, 4697, 38973, 1123, 70, 11940, 783, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Examples"],
    Cell[272432, 5822, 179, 5, 70, "Output",
      CellTags->"Examples"],
    Cell[300327, 6404, 62, 1, 27, "SubsubsectionIcon",
      CellTags->"Examples"],
    Cell[306812, 6539, 62, 1, 27, "SubsubsectionIcon",
      CellTags->"Examples"],
    Cell[413009, 9034, 62, 1, 27, "SubsubsectionIcon",
      CellTags->"Examples"],
    Cell[413074, 9037, 415, 11, 70, "MathCaption",
      CellTags->"Examples"],
    Cell[419878, 9171, 62, 1, 27, "SubsubsectionIcon",
      CellTags->"Examples"],
    Cell[484855, 11348, 62, 1, 27, "SubsubsectionIcon",
      CellTags->"Examples"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Introduction", 491820, 11511},
  {"Info3333717806-1192881", 492501, 11528},
  {"Info3333717806-3361058", 492619, 11531},
  {"Info3333717806-8086490", 492737, 11534},
  {"Examples", 492841, 11537}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 60, 0, 136, "Chapter"],
Cell[1839, 55, 59, 0, 47, "Commentary"],

Cell[CellGroupData[{
Cell[1923, 59, 65, 2, 40, "Input"],
Cell[1991, 63, 104, 2, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2132, 70, 43, 0, 35, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[2200, 74, 116, 3, 70, "Input",
  CellTags->"Introduction"],
Cell[2319, 79, 119, 3, 70, "Print",
  CellTags->"Introduction"]
}, Open  ]],
Cell[2453, 85, 88, 2, 70, "Input"],
Cell[2544, 89, 86, 2, 70, "Input"],
Cell[2633, 93, 325, 6, 70, "Input"],
Cell[2961, 101, 204, 4, 70, "Input"],
Cell[3168, 107, 100, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3305, 114, 63, 0, 39, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[3393, 118, 49, 0, 35, "SubsubsectionIcon"],
Cell[3445, 120, 796, 19, 70, "Text"],
Cell[4244, 141, 1979, 43, 70, "Text"],
Cell[6226, 186, 523, 15, 70, "Text"],
Cell[6752, 203, 146, 4, 70, "Text"],
Cell[6901, 209, 1734, 49, 70, "Commentary"],
Cell[8638, 260, 180, 5, 70, "Text"],
Cell[8821, 267, 382, 7, 70, "Commentary"],
Cell[9206, 276, 1864, 39, 70, "Output"],
Cell[11073, 317, 104145, 1288, 70, 104044, 1285, "GraphicsData", "Metafile", \
"Text"],
Cell[115221, 1607, 116, 4, 70, "Text"],
Cell[115340, 1613, 414, 9, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[115791, 1627, 68, 0, 27, "SubsubsectionIcon"],
Cell[115862, 1629, 348, 8, 70, "Text"],
Cell[116213, 1639, 1007, 28, 70, "DefinitionBox",
  CellTags->"Introduction"],
Cell[117223, 1669, 958, 27, 70, "DefinitionBox",
  CellTags->"Introduction"],
Cell[118184, 1698, 1071, 33, 70, "DefinitionBox",
  CellTags->"Introduction"],
Cell[119258, 1733, 1077, 33, 70, "DefinitionBox",
  CellTags->"Introduction"],
Cell[120338, 1768, 8480, 261, 70, "Text"],
Cell[128821, 2031, 871, 31, 70, "Text"],
Cell[129695, 2064, 336, 11, 70, "Commentary"],
Cell[130034, 2077, 893, 29, 70, "Text"],
Cell[130930, 2108, 118, 5, 70, "Text"],
Cell[131051, 2115, 166, 5, 70, "Text"],
Cell[131220, 2122, 1289, 42, 70, "Commentary"],

Cell[CellGroupData[{
Cell[132534, 2168, 115, 3, 70, "Input",
  CellTags->"Introduction"],
Cell[132652, 2173, 5596, 140, 70, "Print",
  CellTags->"Introduction"]
}, Open  ]],
Cell[138263, 2316, 74, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[138362, 2320, 69, 2, 70, "Input"],
Cell[138434, 2324, 320, 5, 70, "Print",
  CellTags->"Info3333717806-1192881"]
}, Open  ]],
Cell[138769, 2332, 102, 2, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[138896, 2338, 73, 2, 70, "Input"],
Cell[138972, 2342, 114, 2, 70, "Output"]
}, Open  ]],
Cell[139101, 2347, 72, 0, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[139198, 2351, 59, 2, 70, "Input"],
Cell[139260, 2355, 79, 2, 70, "Output"]
}, Open  ]],
Cell[139354, 2360, 274, 7, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[139653, 2371, 135, 4, 70, "Input"],
Cell[139791, 2377, 543, 9, 70, "Output"]
}, Open  ]],
Cell[140349, 2389, 88, 2, 70, "Text"],

Cell[CellGroupData[{
Cell[140462, 2395, 69, 2, 70, "Input"],
Cell[140534, 2399, 116, 2, 70, "Print",
  CellTags->"Info3333717806-3361058"]
}, Open  ]],

Cell[CellGroupData[{
Cell[140687, 2406, 64, 2, 70, "Input"],
Cell[140754, 2410, 112, 2, 70, "Print",
  CellTags->"Info3333717806-8086490"]
}, Open  ]],
Cell[140881, 2415, 214, 7, 70, "Text"],
Cell[141098, 2424, 886, 32, 70, "Text"],
Cell[141987, 2458, 1500, 65, 70, "Commentary"],
Cell[143490, 2525, 195, 7, 70, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[143734, 2538, 59, 1, 58, "SubsectionIcon",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[143818, 2543, 62, 1, 35, "SubsubsectionIcon",
  CellTags->"Examples"],
Cell[143883, 2546, 234, 5, 70, "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[144142, 2555, 203, 5, 70, "Input"],
Cell[144348, 2562, 4852, 74, 70, "Output"]
}, Open  ]],
Cell[149215, 2639, 177, 3, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[149417, 2646, 71, 2, 70, "Input"],
Cell[149491, 2650, 145, 3, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[149673, 2658, 59, 2, 70, "Input"],
Cell[149735, 2662, 79, 2, 70, "Output"]
}, Open  ]],
Cell[149829, 2667, 125, 3, 70, "MathCaption"],
Cell[149957, 2672, 213, 4, 70, "Input"],

Cell[CellGroupData[{
Cell[150195, 2680, 225, 4, 70, "Input"],
Cell[150423, 2686, 1609, 35, 70, "Output"]
}, Open  ]],
Cell[152047, 2724, 176, 3, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[152248, 2731, 169, 6, 70, "Input"],
Cell[152420, 2739, 543, 9, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[153000, 2753, 492, 12, 70, "Input"],
Cell[153495, 2767, 2072, 37, 70, "Output"]
}, Open  ]],
Cell[155582, 2807, 348, 10, 70, "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[155955, 2821, 131, 3, 70, "Input"],
Cell[156089, 2826, 1380, 38, 70, "Output"]
}, Open  ]],
Cell[157484, 2867, 103, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[157624, 2874, 62, 1, 27, "SubsubsectionIcon",
  CellTags->"Examples"],
Cell[157689, 2877, 221, 4, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[157935, 2885, 371, 9, 70, "Input"],
Cell[158309, 2896, 2911, 42, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[161257, 2943, 418, 7, 70, "Input"],
Cell[161678, 2952, 3607, 60, 70, "Output"]
}, Open  ]],
Cell[165300, 3015, 127, 3, 70, "Text"],
Cell[165430, 3020, 137, 3, 70, "MathCaption"],
Cell[165570, 3025, 444, 11, 70, "Input"],
Cell[166017, 3038, 95, 2, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[166137, 3044, 108, 2, 70, "Input"],
Cell[166248, 3048, 536, 9, 70, "Output"]
}, Open  ]],
Cell[166799, 3060, 107, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[166931, 3067, 500, 8, 70, "Input"],
Cell[167434, 3077, 61846, 1505, 70, 18914, 969, "GraphicsData", "PostScript", \
"Graphics"],
Cell[229283, 4584, 155, 4, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[229487, 4594, 62, 1, 27, "SubsubsectionIcon",
  CellTags->"Examples"],
Cell[229552, 4597, 628, 18, 70, "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[230205, 4619, 171, 4, 70, "Input"],
Cell[230379, 4625, 1082, 16, 70, "Output"]
}, Open  ]],
Cell[231476, 4644, 168, 5, 70, "Text"],
Cell[231647, 4651, 161, 5, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[231833, 4660, 190, 4, 70, "Input"],
Cell[232026, 4666, 1159, 18, 70, "Output"]
}, Open  ]],
Cell[233200, 4687, 61, 0, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[233286, 4691, 167, 4, 70, "Input",
  CellTags->"Examples"],
Cell[233456, 4697, 38973, 1123, 70, 11940, 783, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"Examples"],
Cell[272432, 5822, 179, 5, 70, "Output",
  CellTags->"Examples"]
}, Open  ]],
Cell[272626, 5830, 241, 4, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[272892, 5838, 214, 4, 70, "Input"],
Cell[273109, 5844, 1190, 18, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[274336, 5867, 99, 2, 70, "Input"],
Cell[274438, 5871, 25579, 517, 70, 3479, 239, "GraphicsData", "PostScript", \
"Graphics"],
Cell[300020, 6390, 155, 4, 70, "Output"]
}, Open  ]],
Cell[300190, 6397, 100, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[300327, 6404, 62, 1, 27, "SubsubsectionIcon",
  CellTags->"Examples"],
Cell[300392, 6407, 152, 3, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[300569, 6414, 184, 4, 70, "Input"],
Cell[300756, 6420, 4946, 82, 70, "Output"]
}, Open  ]],
Cell[305717, 6505, 174, 3, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[305916, 6512, 93, 2, 70, "Input"],
Cell[306012, 6516, 672, 13, 70, "Output"]
}, Open  ]],
Cell[306699, 6532, 76, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[306812, 6539, 62, 1, 27, "SubsubsectionIcon",
  CellTags->"Examples"],
Cell[306877, 6542, 142, 3, 70, "MathCaption"],
Cell[307022, 6547, 299, 6, 70, "Input"],

Cell[CellGroupData[{
Cell[307346, 6557, 525, 8, 70, "Input"],
Cell[307874, 6567, 58934, 1428, 70, 18142, 918, "GraphicsData", "PostScript", \
"Graphics"],
Cell[366811, 7997, 155, 4, 70, "Output"]
}, Open  ]],
Cell[366981, 8004, 133, 3, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[367139, 8011, 169, 3, 70, "Input"],
Cell[367311, 8016, 5915, 82, 70, "Output"]
}, Open  ]],
Cell[373241, 8101, 616, 17, 70, "MathCaption"],
Cell[373860, 8120, 216, 5, 70, "Input"],
Cell[374079, 8127, 205, 6, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[374309, 8137, 104, 2, 70, "Input"],
Cell[374416, 8141, 38231, 876, 70, 11275, 538, "GraphicsData", "PostScript", \
"Graphics"],
Cell[412650, 9019, 155, 4, 70, "Output"]
}, Open  ]],
Cell[412820, 9026, 152, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[413009, 9034, 62, 1, 27, "SubsubsectionIcon",
  CellTags->"Examples"],
Cell[413074, 9037, 415, 11, 70, "MathCaption",
  CellTags->"Examples"],
Cell[413492, 9050, 232, 6, 70, "SmallText"],
Cell[413727, 9058, 69, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[413821, 9062, 83, 2, 70, "Input"],
Cell[413907, 9066, 615, 10, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[414559, 9081, 307, 6, 70, "Input"],
Cell[414869, 9089, 4960, 76, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[419878, 9171, 62, 1, 27, "SubsubsectionIcon",
  CellTags->"Examples"],
Cell[419943, 9174, 579, 23, 81, "MathCaption"],

Cell[CellGroupData[{
Cell[420547, 9201, 218, 4, 66, "Input"],
Cell[420768, 9207, 3327, 46, 70, "Output"]
}, Open  ]],
Cell[424110, 9256, 289, 5, 70, "MathCaption"],
Cell[424402, 9263, 115, 3, 70, "Input"],

Cell[CellGroupData[{
Cell[424542, 9270, 107, 2, 70, "Input"],
Cell[424652, 9274, 131, 3, 70, "Output"]
}, Open  ]],
Cell[424798, 9280, 99, 2, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[424922, 9286, 299, 6, 70, "Input"],
Cell[425224, 9294, 59332, 2038, 70, 59180, 2033, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[484559, 11334, 162, 4, 70, "Output"]
}, Open  ]],
Cell[484736, 11341, 82, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[484855, 11348, 62, 1, 27, "SubsubsectionIcon",
  CellTags->"Examples"],
Cell[484920, 11351, 227, 7, 63, "MathCaption"],

Cell[CellGroupData[{
Cell[485172, 11362, 108, 2, 40, "Input"],
Cell[485283, 11366, 5340, 109, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

