(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    308707,       5710]*)
(*NotebookOutlinePosition[    310823,       5774]*)
(*  CellTagsIndexPosition[    310713,       5767]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Solving the ICRP 66 compartmental models ", "Chapter"],

Cell["Last update of this help. 2005-08-22", "SmallText"],

Cell[CellGroupData[{

Cell["Initialization", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \($Version\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("5.1 for Microsoft Windows (January 28, 2005)"\)], "Output",
  CellLabel->"Out[1]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Needs["\<Biokmod`Resptract`\>"]\)], "Input",
  CellLabel->"In[2]:=",
  CellTags->"Introduction"],

Cell[BoxData[
    \("Resptract 1.2 b1 2005-05-16"\)], "Print",
  CellTags->"Introduction"]
}, Open  ]],

Cell[BoxData[
    \(Needs["\<Graphics`Graphics`\>"]\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \(Needs["\<Graphics`Legend`\>"]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(styles = {{AbsoluteThickness[0.5], \ AbsoluteDashing[{4, 4}], 
          RGBColor[1, 0, 0]}, {AbsoluteThickness[1.5], 
          RGBColor[0, 1, 0]}, \ {AbsoluteThickness[2], \ 
          AbsoluteDashing[{1, 8}], RGBColor[0, 0, 1]}, \ 
        AbsoluteThickness[2.5]}; \)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(styles1 = {{AbsoluteThickness[1], \ AbsoluteDashing[{4, 4}], 
          RGBColor[1, 0, 1]}, {AbsoluteThickness[1], 
          RGBColor[0, 1, 0]}}; \)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(Off[General::spell1]; Off[General::spell]; \)], "Input",
  CellLabel->"In[7]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["The respiratory tract model description (ICRP 66)", "Section"],

Cell[TextData[{
  "ICRP 66 describes the compartmental model of the human respiratory tract \
(RT) applied to the intake of radioactive aerosols by inhalation (Fig.1). The \
respiratory tract is represented by five regions (fig. 1). The extrathoracic \
(ET) airways are divided into ",
  Cell[BoxData[
      \(TraditionalForm\`ET\_1\)]],
  "(nasal passage) and ",
  Cell[BoxData[
      \(TraditionalForm\`ET\_2\)]],
  " (posterior nasal and oral passages, the pharynx and the larynx) and the \
thoracic region is divided into BB (Bronchial), bronchiolar (bb), and \
alveolar-interstitial (AI: AI1, AI2, and AI3). ",
  Cell[BoxData[
      \(TraditionalForm\`LN\_ET\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`LN\_TH\)]],
  " represent extrathoracic and thoracic airways. "
}], "Text"],

Cell[TextData[{
  "In this model the material is deposited in the respiratory tract: in \
compartments labeled \[OpenCurlyDoubleQuote]Particles in Initial State\
\[CloseCurlyDoubleQuote] (PIS) and in ET1. From each PIS compartment the \
material is transferred into the body fluids,at a absorption rate sp.It is \
also simultaneously transferred from PIS (at a rate spt) to a corresponding \
compartment labeled \[OpenCurlyDoubleQuote]Particles in Transformed State\
\[CloseCurlyDoubleQuote] (PTS). The flow goes from 1, in PIS, to 1, in PTS, \
from 2, in PIS,to 2, in PTS,and so on. We can consider that each compartment \
1-13 in PIS has a mirror compartment 1-13 in PTS. In each compartment in PTS \
the isotope is dissolved at a constant rate ",
  Cell[BoxData[
      \(TraditionalForm\`s\_p\)]],
  " into the body fluids (usually the blood). For instance: the total \
transfer rate for AI2 in PIS will be ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(K\_AI2\),
            "TraditionalForm"], "=", 
          RowBox[{
            FormBox[\(k\_\(2, 4\)\),
              "TraditionalForm"], "+", 
            FormBox[\(s\_pt\),
              "TraditionalForm"], "+", 
            FormBox[\(s\_p\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  ", and for AI2, in PTS, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(K\_AI2\),
            "TraditionalForm"], "=", 
          RowBox[{
            FormBox[\(k\_\(2, 4\)\),
              "TraditionalForm"], "+", 
            FormBox[\(s\_t\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  ".This general model of RT is common to any element.\nThe initial \
deposition factor of inhaled aerosols are functions of AMAD (Activity Median \
Diameter) and AMTD  (Activity Median Thermodynamic Diameter).  Reference \
values for regional deposition are given in ICRP 66.  The transfer \
compartment  represents the body fluid (usually the blood). "
}], "Text"],

Cell[TextData[{
  "The values of ",
  Cell[BoxData[
      \(TraditionalForm\`s\_p\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`s\_pt\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`s\_t\)]],
  " depend on absorption, they ",
  "are related with the chemical form of the element",
  ". ICRP 66 consider tree type of compounds: Type F (fast absorption), type \
M (moderate absorption) and type S (Slow absorption). Default absorption \
rates, taken from Tabla 30 of ICRP 66, are given in table 1 "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Table1",
    FontWeight->"Bold"],
  ".- Absorption parameters values for metabolism F, M and S (ICRP 66) "
}], "Subsubsection"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          StyleBox[
            RowBox[{
              StyleBox["Default",
                FontWeight->"Bold"], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              StyleBox["absorption",
                FontWeight->"Bold"], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              StyleBox["parameters",
                FontWeight->"Bold"], " "}],
            FontSlant->"Plain",
            FontVariations->{"CompatibilityType"->0}], "s", 
          StyleBox["F",
            FontWeight->"Bold"], 
          StyleBox["M",
            FontWeight->"Bold"], 
          StyleBox["S",
            FontWeight->"Bold"]},
        {
          StyleBox[
            RowBox[{"Initial", " ", "disolution", " ", "rate", " ", 
              RowBox[{"(", 
                FormBox[\(d\^\(-1\)\),
                  "TraditionalForm"], ")"}]}],
            FontFamily->"Times New Roman"], \(s\_p\), "100", "10", "0.1"},
        {
          StyleBox[
            RowBox[{"Transformation", " ", "rate", " ", 
              RowBox[{"(", 
                FormBox[\(d\^\(-1\)\),
                  "TraditionalForm"], ")"}]}],
            FontFamily->"Times New Roman"], 
          FormBox[\(s\_pt\),
            "TraditionalForm"], "0", "90", "100"},
        {
          StyleBox[
            RowBox[{"Transformation", " ", "rate", " ", 
              RowBox[{"(", 
                FormBox[\(d\^\(-1\)\),
                  "TraditionalForm"], ")"}]}],
            FontFamily->"Times New Roman"], 
          FormBox[\(s\_t\),
            "TraditionalForm"], "0", "0.005", "0.0001"}
        },
      RowLines->True,
      ColumnLines->True]]]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Table 2",
    FontWeight->"Bold"],
  ".- Respiratory Tract model: Compartments numbering and rate transfer \
coefficients values (ICRP 66) "
}], "Subsubsection"],

Cell["\<\
k[i,j]-> K value means transfer coeffs. from compartment i to compartment j.
k[i,0]-> K value means transfer coeffs. from compartment i to out the system \
or Environment(0).
This notation has little differences with ICRP 66. Compartment 14 here \
represents the transfer compartment or Blood (in place of  ET1). 
Lungs include the compartments 1 to 10\
\>", "SmallText"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"AI1\"\>", "1", "\<\"bb1\"\>", "4", "\<\"k[1,4]->\"\>", 
            "0.02`"},
          {"\<\"AI2\"\>", "2", "\<\"bb1\"\>", "4", "\<\"k[2,4]->\"\>", 
            "0.001`"},
          {"\<\"AI3\"\>", "3", "\<\"bb1\"\>", "4", "\<\"k[3,4]->\"\>", 
            "0.0001`"},
          {"\<\"AI3\"\>", "3", "\<\"\\!\\(LN\\_TH\\)\"\>", 
            "10", "\<\"k[3,10]->\"\>", "0.00002`"},
          {"\<\"bb1\"\>", "4", "\<\"BB1\"\>", "7", "\<\"k[4,7]->\"\>", "2"},
          {"\<\"bb2\"\>", "5", "\<\"BB1\"\>", "7", "\<\"k[5,9]->\"\>", 
            "0.03`"},
          {"\<\"bbseq\"\>", "6", "\<\"\\!\\(LN\\_TH\\)\"\>", 
            "10", "\<\"k[6,10]->\"\>", "0.01`"},
          {"\<\"BB1\"\>", "7", "\<\"ET2\"\>", "11", "\<\"k[7,11]->\"\>", 
            "10"},
          {"\<\"BB2\"\>", "8", "\<\"ET2\"\>", "11", "\<\"k[8,11]->\"\>", 
            "0.03`"},
          {"\<\"BBseq\"\>", "9", "\<\"LN-TH\"\>", "10", "\<\"k[9,10]->\"\>", 
            "0.01`"},
          {"\<\"LN-TH\"\>", "10", "\<\"Blood\"\>", 
            "14", "\<\"k[10,14]->\"\>", "\<\"\\!\\(s\\_p\\)\"\>"},
          {"\<\"ET2\"\>", "11", "\<\"Gitract\"\>", "15", "\<\"k[11,15]->\"\>",
             "100"},
          {"\<\"ETseq\"\>", "12", "\<\"\\!\\(LN\\_ET\\)\"\>", 
            "13", "\<\"k[12,13]->\"\>", "0.001`"},
          {"\<\"\\!\\(LN\\_ET\\)\"\>", "13", "\<\"Blood\"\>", 
            "14", "\<\"k[13,14]->\"\>", "\<\"\\!\\(s\\_p\\)\"\>"},
          {"\<\"Blood\"\>", "14", "\<\"Env\"\>", "0", "\<\"k[14,0]->\"\>", 
            "0"},
          {"\<\"GItract(ST)\"\>", "15", "\<\"Env\"\>", 
            "0", "\<\"k[15,0]->\"\>", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Figure 1:",
    FontWeight->"Bold"],
  " Respiratory tract model (ICRP66). "
}], "Subsubsection"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@000Bc80@0006`0000;0000000000T200020`00
^0400000002@D@00N7P00215CDH00040b2`108l9000<0000000000000000000080<005P200100@00
l0000000000000000000003R1020Z@<0AP0002`0000P0000ADe6:`500@0L00004000004@`=/10000
H000060000160000G00005000015CDH[8T0400`0000000007T0100`000000000940100`000000000
8D0700`000000000<4020100000400000020?`A0000<0000000001P0000<0000000001T0000<0000
oooo01@0000<00003@000180000<00000P00024000080000500000`0000=0000<00000`0000?0020
AP0002P0000L0000AdA9@`80000:0000ooooo`/200040`00000004H0000`K@0096d004E=AR/Z@000
900001P00000080o000000000000080o00000000000Q@0D030000000000U@000400000@000000000
;40002@0000H0000iM02?`0008000020@F15?ooo;d40002024001Fa/001PK0000A30f`8000020000
>6`00=O=aYX00:L02@2V0_d2H0000000Q5L000402@000a`f000=02d0000000D000090P0000050000
0@;oool01@0000@13@0000D000020@800005000030;d0_l10`0001h01@0000/22@2W00D0000<0_@2
o`450000104=0000;@000?L000<D0000002000000800082000000800P0200020P030`<00`=c00:K:
l03ono00X:2T0820P03o00000?l00?oo00000?l0o`3o003oo`3oool0100003@2000@00009PH?01H0
ooooo`00Y`0000T0002V0P00o@8000L0003l0P00oooo0000100002d10@080000nP80004000000002
100002d10P0700006`A80?d19P360@L0003l0P00oooo0000100002d10`040000l04100P0003j0P00
0000000000040000;@4100@0003`0@801`000?`2003oool000040000;@4200P0003j0P000@000?oo
o`840000;@4400L0000K14<0mP4/0=T1100002d10`040000l04200@0000]0@4010000?0110030000
7P0700005PA20?<1;@3L0A`0003k0_?o00000000T04000000000045bJF5/0000kP8:hjF7kGN^Qneg
d6O_Mnh22^<000X0100002d10P0L0000n`;go`0000000901000000000211LVUQK0000?X32SBUQneg
[XO]Mm1WkgOj0`Xd000:00@0000]0@@0100002d10P040000;@4400@0000]0@801@0000810@0000X0
000b2Rl0g0420000AE@900L0100002d110090000<PXe0>`10@00035D1@0400009`7oo`<0000N00D0
00010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0
100002d10`070000o0800?ooo`0000@0000]0@D020000?X20001000000000P@0000]0@H01`0001/4
A`2F0RL0@P840000;@4300@0003`0@D0100002d10@040000l04600<0000N00L0000F14H0T`8X04D2
100002d10P040000;@4200D000040@d0000500000P4100006000038:;P180P/00015KWIYLVm^KFE^
M00900L01@0300@01`0700/01`0700@0100002L1ool300007P0500000@;oool01@0000T2000000L0
000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<01`000?`20030`<00
00040000;@4500P0003j0P000@00000000840000;@4600L0000K1;`1I`:K0A<2100002d10`040000
l04500@0000]0@4010000?011P0300007P0700005PBk0F@2W04F0Q`0003k0_?o00000000_0800000
0000845bJF5/0000?0@:6ZF7kGN^Qnegd6O_Mc`42QX000X0100002d11@040000;@4500D000040@d0
000500000P4100004`00038:X`4T0PP00017BB1DLV5SM0X0100400P01@0800L0100400009`7oo`<0
000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P0000050000
0@;oool0100002d10`070000o0800?ooo`0000@0000]0@H020000?X200010000oooo0P@0000]0@L0
1`0001/4/P7B0I/1/0440000;@4300@0003`0@H0100002d10@040000l04700<0000N00L0000F1;41
c`6L0K<1100002d10P040000;@4400@0000]0@80100002d110040000;@4200D000040@d000050000
0P4100002@00038:WP6c0@40001cE0L0100002d1100:0000<PZT0KX10P00071d1@0300@0000W0Ooo
0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D0
00010_ooo`040000;@4300L0003l0P00oooo0000100002d11P080000nP800040003oool2100002d1
1`0700006`BC0C`1O04J0@@0000]0@<010000?011P040000;@4100@0003`0@L00`0001h01`0001H4
TP4i0Gd17@440000;@4200@0000]0@@0100002d10P040000;@4400@0000]0@801@0000@13@0000D0
00020@4000090000<PYo0Ad10@0007=d1`040000;@4400T0000b2XD190410000L7@500@0000W0Ooo
0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D0
00010_ooo`040000;@430100000V1Pl05P3ooooo000;0@00L04001T1002K0@0020000?X200010000
000000@0000]0@H01`000?`2003oool000040000;@470180000T0`L0306?0@l1S`4?0G41505a0A@1
S`4G0Hl14@6I0@@0000]0@4010000?011P040000;@4300@0003`0@L0200002H63`060?ooool10100
000V1Pl05P3ooooo002T0000E@000942001f0@0020000?X200010000000000@0000]0@H01`000?`2
003oool000040000;@4700L0000K17<1SP9I0:P0100002d10@040000l04600@0000]0@<010000?01
1`0800009PH?00H0ooooo`400`0001h01`0001H4LP6:0UX0[00L0000n`;]o`000000090100000000
0211LVUQK0000:`32RJUQneg[XO]Mm1WkgN/0`XV000:00@0000]0@H01@0000@13@0000D000020@40
00090000<P[307L20@0005003@090000<P[K07/20@0004T01P090000<P[c07L20@0005<03@040000
9`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00
000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@L020000?X20001000000000P@0
000]0@P01`0001/4J05X0TH1_`440000;@4300@0003`0@L0100002d10@040000l04800L0003l0P00
oooo0000100002d11`080000nP80004000000002100002d1200700006`AX0Nh0_`3100@0000]0@<0
10000?011`040000;@4100@0003`0@P0400002H63`0F0?ooool00>`0001A0@00_P4005h100080000
nP80004000000000100002d11`070000o0810000000000@0000]0@P0200002D30P2l0EL1m@1G0@P0
003j0PD00@00000000040000;@4900@0003`0@L01`000?`20000000000040000;@4700X0000T0`<0
n01B0Nh0F07h05d1100002d10@040000;@4300@0003`0@L0200002H63`060?ooool100L0003l0P00
oooo0000100002d11`080000nP80004000000002100002d12P0700006`@V0FP2106n0@@0000]0@<0
10000?011`040000;@4100@0003`0@X01`000?`2003oool000040000;@4700P0003j0P000@000000
00840000;@4:00L0000K1>00I`:n0<01100002d10`040000l04700@0000]0@4010000?012P0@0000
9PH?01H0ooooo`00m04004D1003g0@00JP4000P0003j0P000@00000000040000;@4700@0000]0@P0
200002D30P3e0DH1m@5X0@@0000]0@4010000?011`040000;@4300P0000V1Pl01P3ooooo0@0@0000
9PH?01H0ooooo`00;08004H1000_0P00JP4000P0003j0P000@00000000040000;@4700@0000]0@P0
200002D30P0]0TL1;@9X0@@0000]0@4010000?011`040000;@4300P0000V1Pl01P3ooooo0@070000
o0800?ooo`0000@0000]0@L020000?X20001000000000P@0000]0@X01`0001/4SP1X0V`0_P440000
;@4300@0003`0@L0100002d10@040000l04:00L0003l0P00oooo0000100002d11`080000nP800040
003oool2100002d12P0700006`AQ0N`1C@7@0@@0000]0@<010000?011`040000;@4100@0003`0@X0
0`0001h01`0001H4H07Y0Dh1d`440000;@4200@0000]0@@0100002d10P040000;@4400@0000]0@80
1@0000@13@0000D000020@40000:0000<PY@0M<10P0004592@0300@0000]0@@02@00038:EP7O0@40
000cB@D0100002L1ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1
ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool000040000;@4700P0003j0P00
0@000?ooo`840000;@4:00L0000K16418@9=0@H2100002d10`040000l04700@0000]0@4010000?01
2P0300007P0700005PAP0Ah2CP490P@0000]0@80100002d110040000;@4200@0000]0@@0100002d1
0P050000104=00001@0000810@0000X0000b2U012@820000@DT900<0100002d110090000<PYF0AD2
0@0003991@0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P040000
9`7oo`D000090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@L020000?X2
00010000oooo0P@0000]0@X01`0001/4H`5G0Tl1?P840000;@4300@0003`0@L0100002d10@040000
l04:00<0000N00L0000F1681E09@0D42100002d10P040000;@4400@0000]0@80100002d110040000
;@4200D000040@d0000500000P4100002P00038:DP510P800011B@T00`040000;@4400T0000b2UP1
C@810000<DT500@0000W0Ooo0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0
000W0Ooo1@0000T2000000D000010_ooo`040000;@4300L0003l0P00oooo0000100002d11`080000
nP800040003oool2100002d12P0700006`@N0B<22P470P@0000]0@<010000?011`040000;@4100@0
003`0@X00`0001h01`0001H47@4P0P/12P840000;@4200@0000]0@@0100002d10P040000;@4400@0
000]0@801@0000@13@0000D000020@40000:0000<PX=0@X20P00069R1`0700@0000]0@@02@00038:
4`4H0P40000aHPD0100002L1ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0
100002L1ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool000040000;@4700P0
003j0P000@000?ooo`840000;@4:00L0000K1=T08@;500@2100002d10`040000l04700@0000]0@40
10000?012P0300007P0700005PCH01h2aP070P@0000]0@80100002d110040000;@4200@0000]0@@0
100002d10P050000104=00001@0000810@0000X0000b2/P01`820000@T8900T0100002d110090000
<P[>01T20@0003521@0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a40
6P0400009`7oo`D000090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@L0
20000?X200010000oooo0P@0000]0@X01`0001/4Q`0S0W001P840000;@4300@0003`0@L0100002d1
0@040000l04:00<0000N00L0000F18H0809a00T2100002d10P040000;@4400@0000]0@80100002d1
10040000;@4200D000040@d0000500000P4100002P00038:L`090P800015E0T01`040000;@4400T0
000b2WT06@810000<U@500@0000W0Ooo0`0001h01@000042oooo00D000090P00000700005PB<0@d3
4@0J00@0000W0Ooo1@0000T2000000D000010_ooo`040000;@4300L0003l0P00oooo0000100002d1
1`080000nP80004000000002100002d12P0700006`CQ09l1_`1a0@@0000]0@<010000?011`040000
;@4100@0003`0@X01`000?`2003oool000040000;@4700P0003j0P000@00000000840000;@4:00L0
000K12D1W`430G41100002d10`040000l04700@0000]0@4010000?012P070000o0800?ooo`0000@0
000]0@L020000?X20001000000000P@0000]0@X01`0001/4h@1;0Kl040440000;@4300@0003`0@L0
100002d10@040000l04:00L0003l0P00oooo0000100002d11`080000nP80004000000002100002d1
2P0700006`@U0D/10`4@0@@0000]0@<010000?011`040000;@4100@0003`0@X0400002H63`0F0?oo
ool008P1003M0000``4000@100080000nP80004000000000100002d11`040000;@4800P0000U0`80
R@420K/1h@040000;@4900@0003`0@L01`000?`20000000000040000;@4700X0000T0`<0^`7Y0<81
gP2f0N00100002d10@040000;@4300@0003`0@L0200002H63`060?ooool10100000V1Pl05P3ooooo
00270@00RP000<81002o000020000?X200010000000000@0000]0@L0100002d1200800009@<208P1
_@2k0I00100002d12@040000l04700L0003l0P0000000000100002d11`0:000090<30;d1U`300H`0
]@6?00@0000]0@40100002d10`040000l04700P0000V1Pl01P3ooooo0@0@00009PH?01H0ooooo`00
kP000</0000?0@00f00000P0003j0P000@00000000040000;@4700@0000]0@P0200002D30P0=0M40
m`3A00@0000]0@T010000?011`070000o0800000000000@0000]0@L02P0002@30`3j0<`0l03B0?X0
e`040000;@4100@0000]0@<010000?011`0800009PH?00H0ooooo`40400002H63`0F0?ooool00>d0
000>0@003P4001/100080000nP80004000000000100002d11`040000;@4800P0000U0`80304D0OH0
50440000;@4900@0003`0@L01`000?`20000000000040000;@4700X0000T0`<0n@0?0Nh0507i01X1
100002d10@040000;@4300@0003`0@L0200002H63`060?ooool100L0003l0P00oooo0000100002d1
1`080000nP80004000000002100002d12P0700006`B<0?00JP3200@0000]0@<010000?011`040000
;@4100@0003`0@X01`000?`2003oool000040000;@4700P0003j0P000@00000000840000;@4:00L0
000K18`0B@5Z0101100002d10`040000l04700@0000]0@4010000?012P070000o0800?ooo`0000@0
000]0@L020000?X200010000oooo0P@0000]0@X01`0001/4Q@130Fh06P440000;@4300@0003`0@L0
100002d10@040000l04:00<0000N00L0000F18@0@05_01d1100002d10P040000;@4400@0000]0@80
100002d110040000;@4200D000040@d0000500000P4100002P00038:L@0M0@800015E0T01`040000
;@4400`0000b2WL0;@430000LfEaN0D01@0500@0000W0Ooo0`0001h01@000042oooo00D000090P00
000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D000010_ooo`040000;@4300L0003l0P00
oooo0000100002d11`080000nP800040003oool2100002d12P0700006`CK0401a00G0@@0000]0@<0
10000?011`040000;@4100@0003`0@X00`0001h01`0001H4fP0m0LD06P440000;@4200@0000]0@@0
100002d10P040000;@4400@0000]0@801@0000@13@0000D000020@40000:0000<P[701X10P000492
2@0900@0000]0@@03000038:c@0/0@<0001cIG5i1@0500D0100002L1ool300007P0500000@;oool0
1@0000T2000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<0
1`000?`2003oool000040000;@4700P0003j0P000@000?ooo`840000;@4:00L0000K11l1?P480AD1
100002d10`040000l04700@0000]0@4010000?012P0300007P0700005P@N0C/12@4H0@@0000]0@80
100002d110040000;@4200@0000]0@@0100002d10P050000104=00001@0000810@0000X0000b2P/1
60420000HV8700L0100002d1100<0000<PXA0BH10`0007=ULGX500D01@0400009`7oo`<0000N00D0
00010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0
100002d10`070000o0800?ooo`0000@0000]0@L020000?X200010000oooo0P@0000]0@X01`0001/4
7@7/00H1``040000;@4300@0003`0@L0100002d10@040000l04:00<0000N00L0000F11`1j@070LH0
100002d10P040000;@4400@0000]0@80100002d110040000;@4200D000040@d0000500000P410000
2P00038:2@760080001<CPL02@040000;@4400X0000b2Pl1eP020000E4P500L0100002L1ool30000
7P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042
oooo00@0000]0@<01`000?`2003oool000040000;@4700P0003j0P000@000?ooo`840000;@4:00L0
000K18H0k@1_0<@0100002d10`040000l04700@0000]0@4010000?012P0300007P0700005PB50>X0
L03700@0000]0@80100002d110040000;@4200@0000]0@@0100002d10P050000104=00001@000081
0@0000X0000b2W80a`020000C4h700T0100002d1100:0000<PYh0=L00P0004ED1P0500@0000W0Ooo
0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D0
00010_ooo`040000;@430100000V1Pl05P3ooooo003^0000M@0000l10022000020000?X200010000
000000@0000]0@L0100002d1200800009@<200d1N`3g07/0100002d12@040000l04700L0003l0P00
00000000100002d11`0:000090<30?X0MP3`07`0nP2100@0000]0@40100002d10`040000l04700P0
000V1Pl01P3ooooo0@070000o0800?ooo`0000@0000]0@L020000?X200010000oooo0P@0000]0@X0
1`0001/4f@2C0LD0MP440000;@4300@0003`0@L0100002d10@040000l04:00<0000N00L0000F1=P0
T07607T1100002d10P040000;@4400@0000]0@80100002d110040000;@4200D000040@d000050000
0P4100002P00038:b01i0@800012@PT02@040000;@4400T0000b2/h0R`410000<T8500@0000W0Ooo
0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D0
00010_ooo`040000;@4300L0003l0P00oooo0000100002d11`080000nP800040003oool2100002d1
2P0700006`@L0ID1205i0@@0000]0@<010000?011`040000;@4100@0003`0@X00`0001h01`0001H4
6`6B0@T1O0440000;@4200@0000]0@@0100002d10P040000;@4400@0000]0@801@0000@13@0000D0
00020@40000:0000<PX;0G`10P00069R1`0700@0000]0@@02@00038:4@6:0@40000bHPD0100002L1
ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@800000
1@000042oooo00@0000]0@<01`000?`2003oool000040000;@4700P0003j0P000@00000000840000
;@4:00L0000K16L1kP1I0ML0100002d10`040000l04700@0000]0@4010000?012P0300007P070000
5PAV0N/0FP7J01`0003k0_Go00000000T04000000000845bJF5/0000B`@:7ZF7kGN^Qnegd6O_Md/4
2Qh000X0100002d11`040000;@4700D000040@d0000500000P4100002P00038:FP7J0080000a<0H0
1P0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D0
00090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X020000?X200010000
00000P@0000]0@/01`0001/4I`5X0UX1G@840000;@4300@0003`0@X0100002d10@040000l04;00<0
000N00L0000F16H1I@9K0F02100002d11`040000;@4700@0000]0@L01@0000@13@0000D000020@40
00090000<PYK0F020@00034`1P0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4
S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0
000]0@X020000?X20001000000000P@0000]0@/01`0001/4I`4^0UX18`840000;@4300@0003`0@X0
100002d10@040000l04;00<0000N00L0000F16H1:`9K0BH2100002d11`040000;@4700@0000]0@L0
1@0000@13@0000D000020@4000090000<PYK0BH20@00038`1P0400009`7oo`<0000N00D000010_oo
o`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d1
0`070000o0800?ooo`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4I`7e0EX1
jP440000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F16H1lP5K0Nd1100002d1
1`040000;@4700@0000]0@L01@0000@13@0000D000020@4000090000<PYK0Nd10@0003<`1P040000
9`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00
000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X020000?X20001000000000P@0
000]0@/01`0001/49@5W0QP1G0840000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0
000F12@1I08I0El2100002d11`040000;@4700@0000]0@L01@0000@13@0000D000020@4000090000
<PXI0El20@0003@`1P0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a40
6P0400009`7oo`D000090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X0
20000?X20001000000000P@0000]0@/01`0001/4g`1V0]80F`840000;@4300@0003`0@X0100002d1
0@040000l04;00<0000N00L0000F1=h0H`;C05h2100002d11`040000;@4700@0000]0@L01@0000@1
3@0000D000020@4000090000<P[C05h20@0003L`1P0400009`7oo`<0000N00D000010_ooo`050000
2@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d10`070000
o0800?ooo`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4h@2O0M40T@440000
;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F1>00W07B09@1100002d11`040000
;@4700D000040@d0000500000P4100002@00038:dP2D0@40000h<0H0100002L1ool300007P050000
0@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0
000]0@<01`000?`2003oool000040000;@4:00P0003j0P000@00000000840000;@4;00L0000K12D1
W`4G0I<1100002d10`040000l04:00@0000]0@4010000?012`0300007P0700005P@T0I`1606F0@@0
000]0@L0100002d11`050000104=00001@0000810@0000T0000b2QP1UP410000=C0600@0000W0Ooo
0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D0
00010_ooo`040000;@4300L0003l0P00oooo0000100002d12P080000nP80004000000002100002d1
2`0700006`CP04X1d00n0@@0000]0@<010000?012P040000;@4100@0003`0@/00`0001h01`0001H4
g`170M40@@440000;@4700@0000]0@L01@0000@13@0000D000020@4000090000<P[A04410@0003T`
1P0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D0
00090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X020000?X200010000
00000P@0000]0@/01`0001/49@5;0A@1?`440000;@4300@0003`0@X0100002d10@040000l04;00<0
000N00L0000F12@1B04E0D81100002d11`040000;@4700D000040@d0000500000P4100002@00038:
5@520@40000f<0H0100002L1ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0
100002L1ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool000040000;@4:00P0
003j0P000@00000000840000;@4;00L0000K1900D`6203`1100002d10`040000l04:00@0000]0@40
10000?012`0300007P0700005PB?0501P`0o0@@0000]0@L0100002d11`050000104=00001@000081
0@0000X0000b2X<0?`420000<C8600H0100002L1ool300007P0500000@;oool01@0000T2000000L0
000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool0
00040000;@4:00P0003j0P000@00000000840000;@4;00L0000K1900m`230>40100002d10`040000
l04:00@0000]0@4010000?012`0300007P0700005PB?0?@0Q03T00@0000]0@L0100002d11`050000
104=00001@0000810@0000X0000b2X@0i0020000<C<600H0100002L1ool300007P0500000@;oool0
1@0000T2000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<0
1`000?`2003oool000040000;@4:00P0003j0P000@00000000840000;@4;00L0000K18d0I`9o0502
100002d10`040000l04:00@0000]0@4010000?012`0300007P0700005PB<06@2P01C0P@0000]0@L0
100002d11`050000104=00001@0000810@0000X0000b2X00D`820000<C4600H0100002L1ool30000
7P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042
oooo00@0000]0@<0400002H63`0F0?ooool00:h0001J0000L`8005h000080000nP80004000000000
100002d12P040000;@4800P0000U0`80[`1L0742F`040000;@4100@0003`0@X0100002d10`080000
9PH?00H0ooooo`40400002H63`0F0?ooool000d2002<00006P800<0000080000nP80004000000000
100002d12P040000;@4800P0000U0`804`:n01<2U@040000;@4900@0003`0@X01`000?`200000000
00040000;@4:00X0000T0`<06@:H01@2SP0>0YP0100002d10@040000;@4300@0003`0@X0200002H6
3`060?ooool10100000V1Pl05P3ooooo000;0P00gP0001P200070@0020000?X200010000000000@0
000]0@X0100002d1200800009@<201421@4A0^L0100002d12@040000l04:00L0003l0P0000000000
100002d12P0:000090<301L2jP0B0^0030;Z00@0000]0@40100002d10`040000l04:00P0000V1Pl0
1P3ooooo0@0@00009PH?01H0ooooo`00e@400281003R0@00B@4000P0003j0P000@00000000040000
;@4:00@0000]0@P0200002D30P3K0DL1f`4[0@@0000]0@T010000?012P070000o0800000000000@0
000]0@X02P0002@30`3Q0Bh1g04T0MH1;P440000;@4100@0000]0@<010000?012P0800009PH?00H0
ooooo`40400002H63`0F0?ooool000X2000R0@005`8004T100080000nP80004000000000100002d1
2P040000;@4800P0000U0`8040970A02:`440000;@4900@0003`0@X01`000?`20000000000040000
;@4:00X0000T0`<05P8^0A02904;0Rh1100002d10@040000;@4300@0003`0@X0200002H63`060?oo
ool10100000V1Pl05P3ooooo00130P008P40050200190@0020000?X200010000000000@0000]0@X0
100002d1200800009@<204T2A`590R/1100002d12@040000l04:00L0003l0P0000000000100002d1
2P0:000090<304l2;P5:0R@1A08^0@@0000]0@40100002d10`040000l04:00P0000V1Pl01P3ooooo
0@0@00009PH?01H0ooooo`00X`000=l1002@0P0000<000P0003j0P000@00000000040000;@4:00L0
003l0P00oooo0000100002d12`0700006`Cm0Xd2h`6W00@0000]0@4010000?012P040000;@4300@0
003`0@/0200002H63`060?ooool100<0000N00L0000F1?`2R@;T0J/0100002d11P050000104=0000
1@0000810@0000T0000b2Td2MP810000D00=00T0000b2VD2M`810000E00<00T0000b2Wd2MP810000
D`0=00@0000W0Ooo0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo
1@0000T2000000D000010_ooo`040000;@4300L0003l0P00oooo0000100002d12P080000nP800040
00000002100002d12`0700006`Cb0VL2d0:n0@@0000]0@<010000?012P040000;@4100@0003`0@/0
1`000?`2003oool000040000;@4:00P0003j0P000@00000000840000;@4;00L0000K1?82k@190/00
100002d10`040000l04:00@0000]0@4010000?012`0@00009PH?01H0ooooo`00j`000=/2002m0@00
j08000P0003j0P000@00000000040000;@4:00@0000]0@P0200002D30P2k0N42m03Q0P@0000]0@T0
10000?012P070000o0800000000000@0000]0@X02P0002@30`3g0=`2k03R0_L0i`840000;@4100@0
000]0@<010000?012P0800009PH?00H0ooooo`401`000?`2003oool000040000;@4:00P0003j0P00
0@00000000840000;@4;00L0000K1;02I`:>0[d1100002d10`040000l04:00@0000]0@4010000?01
2`070000o0800?ooo`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4JP9V0TP2
_`440000;@4300@0003`0@X0100002d10@040000l04;0100000V1Pl05P3ooooo003c0@00c`800?H1
003d0P0020000?X200010000000000@0000]0@X0100002d1200800009@<20?@1d0;d0O82100002d1
0@040000l04:00@0000]0@<0200002H63`060?ooool10100000V1Pl05P3ooooo000[0P00d08002h2
003d0P0020000?X200010000000000@0000]0@X0100002d1200800009@<202`2d@8/0_82100002d1
0@040000l04:00@0000]0@<0200002H63`060?ooool100L0003l0P00oooo0000100002d12P080000
nP80004000000002100002d12`0700006`@H0VL2mP6m0@@0000]0@<010000?012P040000;@4100@0
003`0@/01`000?`2003oool000040000;@4:00P0003j0P000@000?ooo`840000;@4;00L0000K1>/2
j`7G0/l1100002d10`040000l04:00@0000]0@4010000?012`0300007P0700005PCZ0^P1f0;B0@@0
000]0@80100002d110040000;@4200@0000]0@@0100002d10P050000104=00001@0000810@0000X0
000b2]X2dP420000@DT900<0100002d110090000<P[P0]h10@0003=91@0400009`7oo`<0000N00D0
00010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0
100002d10`070000o0800?ooo`0000@0000]0@X020000?X200010000oooo0P@0000]0@/01`0001/4
j`8P0]L21@840000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F1>X27@;H0PP2
100002d10P040000;@4400@0000]0@80100002d110040000;@4200D000040@d0000500000P410000
2P00038:fP880P800011B@T00`040000;@4400T0000b2^0250810000<TT500@0000W0Ooo0`0001h0
1@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D000010_oo
o`040000;@4300L0003l0P00oooo0000100002d12P080000nP800040003oool2100002d12`070000
6`C]0UH2f@8m0P@0000]0@<010000?012P040000;@4100@0003`0@/00`0001h01`0001H4k09C0]X2
@0840000;@4200@0000]0@@0100002d10P040000;@4400@0000]0@801@0000@13@0000D000020@40
000:0000<P[L0T020P0004592@0300@0000]0@@02@00038:hP9<0P40000aB@D0100002L1ool30000
7P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042
oooo00@0000]0@<01`000?`2003oool000040000;@4:00P0003j0P000@000?ooo`840000;@4;00L0
000K1:P28P:D0PH2100002d10`040000l04:00@0000]0@4010000?012`0300007P0700005PBW0Ql2
U@890P@0000]0@80100002d110040000;@4200@0000]0@@0100002d10P050000104=00001@000081
0@0000X0000b2YL22@820000HV8700L0100002d110090000<PZM0QL20@00035R1@0400009`7oo`<0
000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P0000050000
0@;oool0100002d10`070000o0800?ooo`0000@0000]0@X020000?X200010000oooo0P@0000]0@/0
1`0001/4H`8P0Tl20`840000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F1682
7@9@0PH2100002d10P040000;@4400@0000]0@80100002d110040000;@4200D000040@d000050000
0P4100002P00038:DP860P800012@PT02@040000;@4400T0000b2UP260810000<D8500@0000W0Ooo
0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D0
00010_ooo`040000;@4300L0003l0P00oooo0000100002d12P080000nP800040003oool2100002d1
2`0700006`@A0R82nP450P@0000]0@<010000?012P040000;@4100@0003`0@/00`0001h01`0001H4
408O0_/120840000;@4200@0000]0@@0100002d10P040000;@4400@0000]0@801@0000@13@0000D0
00020@40000:0000<P[m0@P20P0004ED2@0700@0000]0@@02@00038:0`8H0P40000bE0D0100002L1
ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@800000
1@000042oooo00@0000]0@<01`000?`2003oool000040000;@4:00P0003j0P000@00000000840000
;@4;00L0000K16/2WP590W01100002d10`040000l04:00@0000]0@4010000?012`070000o0800?oo
o`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4[`:N0Hd2L0440000;@4300@0
003`0@X0100002d10@040000l04;00L0003l0P00oooo0000100002d12P080000nP80004000000002
100002d12`0700006`A[0TX1B@8?0@@0000]0@<010000?012P040000;@4100@0003`0@/01`000?`2
003oool000040000;@4:00P0003j0P000@00000000840000;@4;00L0000K1:l2BP6=0Pl1100002d1
0`040000l04:00@0000]0@4010000?012`0@00009PH?01H0ooooo`00Q`4006L200320@00SP8000P0
003j0P000@00000000040000;@4:00@0000]0@P0200002D30P280H`2^P5[0P@0000]0@T010000?01
2P070000o0800000000000@0000]0@X02P0002@30`2j0G<2`05X0[D1JP840000;@4100@0000]0@<0
10000?012P0800009PH?00H0ooooo`40400002H63`0F0?ooool008H1000D0P00`@4004T200080000
nP80004000000000100002d12P040000;@4800P0000U0`80Q`570[X16P840000;@4900@0003`0@X0
1`000?`20000000000040000;@4:00X0000T0`<0_04Q0/015P:d0AT2100002d10@040000;@4300@0
003`0@X0200002H63`060?ooool10100000V1Pl05P3ooooo003]0000E@8000h1001R0P0020000?X2
00010000000000@0000]0@X0100002d1200800009@<200`1F`;f05/2100002d12@040000l04:00L0
003l0P0000000000100002d12P0:000090<30?T0EP;^05`2n@1Q0P@0000]0@40100002d10`040000
l04:00P0000V1Pl01P3ooooo0@0@00009PH?01H0ooooo`00k00009P2000=0@00Y@8000P0003j0P00
0@00000000040000;@4:00@0000]0@P0200002D30P0;0Ih2m@2N0P@0000]0@T010000?012P070000
o0800000000000@0000]0@X02P0002@30`3h09T2kP2N0_P0Y0840000;@4100@0000]0@<010000?01
2P0800009PH?00H0ooooo`401`000?`2003oool000040000;@4:00P0003j0P000@00000000840000
;@4;00L0000K11H2k`3d0L40100002d10`040000l04:00@0000]0@4010000?012`070000o0800?oo
o`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/45P980O@13`440000;@4300@0
003`0@X0100002d10@040000l04;00L0003l0P00oooo0000100002d12P080000nP800040003oool2
100002d12`0700006`@?0T81n04I0@@0000]0@<010000?012P040000;@4100@0003`0@/00`0001h0
1`0001H43P8o0OT170440000;@4200@0000]0@@0100002d10P040000;@4400@0000]0@801@0000@1
3@0000D000020@40000:0000<P[k0A`10P0004ED2@0700@0000]0@@03000038:0@8/0@<0001cIG6/
1@0500D0100002L1ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1
ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool000040000;@4:00P0003j0P00
0@000?ooo`840000;@4;00L0000K16D2?`5>0QH1100002d10`040000l04:00@0000]0@4010000?01
2`0300007P0700005PAT0S`1C`8I0@@0000]0@80100002d110040000;@4200@0000]0@@0100002d1
0P050000104=00001@0000810@0000X0000b2U426@420000@T8900T0100002d1100<0000<PYG0R/1
0`0007=ULJd500D01@0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a40
6P0400009`7oo`D000090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X0
20000?X200010000oooo0P@0000]0@/01`0001/4Z@8m0I8250440000;@4300@0003`0@X0100002d1
0@040000l04;00<0000N00L0000F1:P2>P6C0QL1100002d10P040000;@4400@0000]0@80100002d1
10040000;@4200D000040@d0000500000P4100002P00038:U@8G0@80001RHPL01`040000;@4400`0
000b2Y/29@430000LfEa[PD01@0500@0000W0Ooo0`0001h01@000042oooo00D000090P0000070000
5PB<0@d34@0J00@0000W0Ooo1@0000T2000000D000010_ooo`040000;@4300L0003l0P00oooo0000
100002d12P080000nP800040003oool2100002d12`0700006`BW0^/0T0;200@0000]0@<010000?01
2P040000;@4100@0003`0@/00`0001h01`0001H4YP;X0942a@040000;@4200@0000]0@@0100002d1
0P040000;@4400@0000]0@801@0000@13@0000D000020@40000:0000<PZC0/D00P0004a>1`0900@0
000]0@@02P00038:V@;E0080001DB0D01`0400009`7oo`<0000N00D000010_ooo`0500002@800000
1`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d10`070000o0800?oo
o`0000@0000]0@X020000?X200010000oooo0P@0000]0@/01`0001/440;/0?T1``040000;@4300@0
003`0@X0100002d10@040000l04;00<0000N00L0000F10l2j@3j0LH0100002d10P040000;@4400@0
000]0@80100002d110040000;@4200D000040@d0000500000P4100002P00038:o0760080001<CPL0
2@040000;@4400X0000b2P82eP020000AE@600D0100002L1ool300007P0500000@;oool01@0000T2
000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<0400002H6
3`0F0?ooool00>d0003o0@003P4000`200080000nP80004000000000100002d12P040000;@4800P0
000U0`8030450_H01@840000;@4900@0003`0@X01`000?`20000000000040000;@4:00X0000T0`<0
n@000^h01P;i00/2100002d10@040000;@4300@0003`0@X0200002H63`060?ooool100L0003l0P00
oooo0000100002d12P080000nP800040003oool2100002d12`0700006`AT0Y81D09e0@@0000]0@<0
10000?012P040000;@4100@0003`0@/00`0001h01`0001H4H`:?0E42N0440000;@4200@0000]0@@0
100002d10P040000;@4400@0000]0@801@0000@13@0000D000020@40000:0000<PYC0WP10P000492
2@0900@0000]0@@02@00038:F@::0@40000b@PD0100002L1ool300007P0500000@;oool01@0000T2
000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<01`000?`2
003oool000040000;@4:00P0003j0P000@000?ooo`840000;@4;00L0000K1:H2U06B0WP1100002d1
0`040000l04:00@0000]0@4010000?012`0300007P0700005PBU0Y41T`9k0@@0000]0@80100002d1
10040000;@4200@0000]0@@0100002d10P050000104=00001@0000810@0000X0000b2YD2N`420000
HV8700L0100002d110090000<PZK0XT10@00039R1@0400009`7oo`<0000N00D000010_ooo`050000
2@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d10`070000
o0800?ooo`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4l@;]0><2eP040000
;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F1?02jP3T0]T0100002d11`040000
;@4700D000040@d0000500000P4100002P00038:i0;I0080000a<0H01P0400009`7oo`<0000N00D0
00010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0
100002d10`070000o0800?ooo`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4
l@9W0^@2G0840000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F1?02I0;U0Ul2
100002d11`040000;@4700@0000]0@L01@0000@13@0000D000020@4000090000<P[U0Ul20@00034`
1P0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D0
00090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X020000?X200010000
00000P@0000]0@/01`0001/4l@8]0^@28P840000;@4300@0003`0@X0100002d10@040000l04;00<0
000N00L0000F1?02:P;U0RD2100002d11`040000;@4700@0000]0@L01@0000@13@0000D000020@40
00090000<P[U0RD20@00038`1P0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4
S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0
000]0@X020000?X20001000000000P@0000]0@/01`0001/4l@;d0N@2j@440000;@4300@0003`0@X0
100002d10@040000l04;00<0000N00L0000F1?02l@7U0^`1100002d11`040000;@4700@0000]0@L0
1@0000@13@0000D000020@4000090000<P[U0^`10@0003<`1P0400009`7oo`<0000N00D000010_oo
o`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d1
0`070000o0800?ooo`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4[`9V0Z82
F`840000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F1:h2H`:S0Uh2100002d1
1`040000;@4700@0000]0@L01@0000@13@0000D000020@4000090000<PZS0Uh20@0003@`1P040000
9`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00
000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X020000?X20001000000000P@0
000]0@/01`0001/4JP9V0Ud2F`840000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0
000F16T2H`9N0Uh2100002d11`040000;@4700@0000]0@L01@0000@13@0000D000020@4000090000
<PYN0Uh20@0003L`1P0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a40
6P0400009`7oo`D000090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X0
20000?X20001000000000P@0000]0@/01`0001/4J`:N0E`2TP440000;@4300@0003`0@X0100002d1
0@040000l04;00<0000N00L0000F16X2V`5M0YD1100002d11`040000;@4700D000040@d000050000
0P4100002@00038:G@:E0@40000h<0H0100002L1ool300007P0500000@;oool01@0000T2000000L0
000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool0
00040000;@4:00P0003j0P000@00000000840000;@4;00L0000K1:l2WP6P0Y41100002d10`040000
l04:00@0000]0@4010000?012`0300007P0700005PB^0Y/1X@:D0@@0000]0@L0100002d11`050000
104=00001@0000810@0000T0000b2Z42U0410000=C0600@0000W0Ooo0`0001h01@000042oooo00D0
00090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D000010_ooo`040000;@4300L0
003l0P00oooo0000100002d12P080000nP80004000000002100002d12`0700006`A[0TT1G@8l0@@0
000]0@<010000?012P040000;@4100@0003`0@/00`0001h01`0001H4JP960Eh2?`440000;@4700@0
000]0@L01@0000@13@0000D000020@4000090000<PYN0Sl10@0003T`1P0400009`7oo`<0000N00D0
00010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0
100002d10`070000o0800?ooo`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4
[`9:0J02?@440000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F1:h2A`6Q0T01
100002d11`040000;@4700D000040@d0000500000P4100002@00038:X@900@40000f<0H0100002L1
ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@800000
1@000042oooo00@0000]0@<01`000?`2003oool000040000;@4:00P0003j0P000@00000000840000
;@4;00L0000K11X2DP4<0S/1100002d10`040000l04:00@0000]0@4010000?012`0300007P070000
5P@I0Tl13@8n0@@0000]0@L0100002d11`050000104=00001@0000810@0000X0000b2Pd2?P420000
<C8600H0100002L1ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1
ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool000040000;@4:00P0003j0P00
0@00000000840000;@4;00L0000K11X2mP0=0^00100002d10`040000l04:00@0000]0@4010000?01
2`0300007P0700005P@I0_<03P;S00@0000]0@L0100002d11`050000104=00001@0000810@0000X0
000b2Ph2h`020000<C<600H0100002L1ool300007P0500000@;oool01@0000T2000000L0000F18`1
3@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool000040000
;@4:00P0003j0P000@00000000840000;@4;00L0000K11L2IP890Tl2100002d10`040000l04:00@0
000]0@4010000?012`0300007P0700005P@F0V<22P9B0P@0000]0@L0100002d11`050000104=0000
1@0000810@0000X0000b2PX2DP820000<C4600H0100002L1ool300007P0500000@;oool01@0000T2
000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<0400002H6
3`0F0?ooool00:d0003T0@00LP800>P100080000nP80004000000000100002d12P040000;@4800P0
000U0`80[P3V0G02i@440000;@4100@0003`0@X0100002d10`0800009PH?00H0ooooo`40400002H6
3`0F0?ooool000`2000F0P006@8004X200080000nP80004000000000100002d12P040000;@4800P0
000U0`804P980Q827`840000;@4900@0003`0@X01`000?`20000000000040000;@4:00X0000T0`<0
608R0Q82608=0R82100002d10@040000;@4300@0003`0@X0200002H63`060?ooool10100000V1Pl0
5P3ooooo000:0P00J08001L2002A0P0020000?X200010000000000@0000]0@X0100002d120080000
9@<20102S`8@0W42100002d12@040000l04:00L0003l0P0000000000100002d12P0:000090<301H2
M08@0VX22`9d0P@0000]0@40100002d10`040000l04:00P0000V1Pl01P3ooooo0@0@00009PH?01H0
ooooo`00e0400:`2003Q0@00d`8000P0003j0P000@00000000040000;@4:00@0000]0@P0200002D3
0P3J0M42fP6e0P@0000]0@T010000?012P070000o0800000000000@0000]0@X02P0002@30`3P0KP2
fP6^0]D1^0840000;@4100@0000]0@<010000?012P0800009PH?00H0ooooo`40400002H63`0F0?oo
ool000T2002/0P005P800=<200080000nP80004000000000100002d12P040000;@4800P0000U0`80
3`;A0Pl2]@840000;@4900@0003`0@X01`000?`20000000000040000;@4:00X0000T0`<05@:h0Q02
[P8:0[P2100002d10@040000;@4300@0003`0@X0200002H63`060?ooool10100000V1Pl05P3ooooo
00120P00[08004l2003C0P0020000?X200010000000000@0000]0@X0100002d1200800009@<204P2
d@980[D2100002d12@040000l04:00L0003l0P0000000000100002d12P0:000090<304h2^0980Zh2
@`:h0P@0000]0@40100002d10`040000l04:00P0000V1Pl01P3ooooo0@070000o0800?ooo`0000@0
000]0@X020000?X200010000oooo0P@0000]0@/01`0001/4f`4k0L@16@440000;@4300@0003`0@X0
100002d10@040000l04;00<0000N00L0000F1=X1>0750A`1100002d10P040000;@4400@0000]0@80
100002d110040000;@4200D000040@d0000500000P4100002@00038:a`4L0@40001c00L0100002d1
10090000<P[=0B<10@0007@00`0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4
S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d10`0@00009PH?01H0ooooo`00
2@400;X1000G0@00iP4000P0003j0P000@00000000040000;@4:00L0003l0P00oooo0000100002d1
2`0B000090<700X1a@4=0LD13@7T0A81i04B0LD15@750@l1^`440000;@4100@0003`0@X0100002d1
0`040000l04;00P0000V1Pl01P3ooooo0@0@00009PH?01H0ooooo`00V`400701002]0@00i`4000@0
000]0@T01`000?`2003oool000040000;@4:0180000T0`L0W0780J01b06P0G41Y`5a0JL1b06[0LP1
X`7U0@@0000]0@40100002d10`040000l04:00@0000]0@T01`000?`20000000000040000;@4:00D0
00060@80000L000090<<09`1b06L0LP1W0780I`1c06M0L`1W@7<0Id1b06L0LP1W0790J01b@6P0LP1
X0780A00000T0`H0X0750J01a@6Q0LD1X@710J01`@6P0L41400002@31P2P0Kh1X06n0J41_P6Q0KX1
X06j0J01^P4@000090<60:01]`6P0KL1X@6g0J41/`6P0K<1X06c0A00000T0`H0X06`0J01/06Q0K01
X@6/0J01[06P0J`1400002@31P2P0JT1X06Y0J41Z@6Q0JD1X06U0J01Y@4@000090<60:01XP6P0J81
X@6R0J41WP6P0Ih1X06N0A00000T0`H0X06K0J01V`6Q0I/1X@6G0J01U`6P0IL1400002@31P2P0I@1
X06D0J41U06Q0I01X06@0J01T04@000090<60:01S@6P0Hd1X@6=0J41R@6P0HT1X0690A00000T0`H0
X0660J01QP6Q0HH1X@620J01PP6P0H81400002@31P2P0Gl1X05o0J41O`6Q0G/1X05k0J01N`4@0000
90<60:01N06P0GP1X@5h0J41M06P0G@1X05d0A00000T0`H0X05a0J01L@6P0G81Y05b0J@1L@6T0G41
400002@31P2X0G41Y`5a0JL1L@6W0GD1Y`5e0JP1M@4@000090<60:P1N06W0GL1Y`5h0JL1O06W0G`1
Z05l0A00000T0`H0Z05o0JL1OP6W0Gl1Y`630JL1P`6X0H<1400002@31P2X0HH1Y`650JL1QP6W0HX1
Y`6:0JP1RP4@000090<60:P1S@6W0H`1Y`6=0JL1T@6W0I41Z06A0A00000T0`H0Z06D0JL1T`6W0I@1
Y`6H0JL1V06X0IP1400002@31P2X0I/1Y`6J0JL1V`6W0Il1Y`6O0JP1W`4@000090<60:P1XP6W0J41
Y`6R0JL1YP6W0JH1Z06V0A00000T0`H0Z06Y0JL1Z06W0JT1Y`6]0JL1[@6X0Jd1400002@31P2X0K01
Y`6_0JL1/06W0K@1Y`6d0JP1]04@000090<60:P1]`6W0KH1Y`6g0JL1^`6W0K/1Z06k0A00000T0`H0
Z06n0JL1_@6W0Kh1Y`720JL1`P6X0L816P0002@32`2X0LD1Y`740JL1a@6W0LP1Y`790JP1b@6X0LP1
Z0780JL1b06W0LP1Z0780A00000T0`H0[0780J/1b06[0LP1Z@7<0JX1c06Z0L`1400002@31P2Z0Ll1
Z@7>0JT1c`6X0M<1Z07C0JT1d`4@000090<60:P1e@6W0MD1Y`7E0JH1f@6V0MX1Y`7I0A00000T0`H0
YP7L0JD1g06U0M`1Y07P0J@1h@6U0N017P0002@33@2T0N<1Y07R0J<1h`6S0ND1X`7U0J@1i@6S0N<1
X`7S0J81h`6S0ND1X`7U0J<1i@6T0ND1400002@31P2Q0N01XP7Q0J81h06Q0M`1X@7L0J01g04@0000
90<60:01f@6P0MX1X@7I0J01eP6O0MD1W`7F0A00000T0`H0WP7C0Il1d`6O0M<1WP7?0Ih1cP6M0Ll1
1@0000H10@0000@0000]0@40100002d10`040000l04:00P0000V1Pl01P3ooooo0@0@00009PH?01H0
ooooo`00n`40034000140P00?P0000P0003j0P000@00000000040000;@4:00@0000]0@P0200002D3
0P3l0CL0>P8g00@0000]0@T010000?012P070000o0800000000000@0000]0@X02P0002@30`0h0Sd0
@P8h03P2<P040000;@4100@0000]0@<010000?012P0800009PH?00H0ooooo`40400002H63`0F0?oo
ool003L2002j0@00P08000T200080000nP80004000000000100002d12P040000;@4800h0000U0`D0
IP870Wh21`9n0]P1?@;H0Cd2``440000;@4900@0003`0@X01`000?`20000000000040000;@4:00X0
000T0`<0@`;60Ch2_04h0/H1100002d10@040000;@4300@0003`0@X0200002H63`060?ooool10100
000V1Pl05P3ooooo002U0@008P000<L10012000020000?X200010000000000@0000]0@X01`000?`2
003oool000040000;@4;01H0000T0`T0a@4h0;/1;`2k0C@0/04d0;018`2V0B<0YP4l0;/1?02k0D00
100002d10@040000l04:00@0000]0@<010000?012`0800009PH?00H0ooooo`40400002H63`0F0?oo
ool009@1000R0000[P4005`000080000nP80004000000000100002d12P070000o0800?ooo`0000@0
000]0@/04P0002@31`2E0D`0V`5<09/18`2V0B<0YP5<0:`1C02P0EX0100002d10@040000l04:00@0
000]0@<010000?012`0800009PH?00H0ooooo`40400002H63`0F0?ooool006D2001l0000X`800;81
00080000nP80004000000000100002d12P040000;@4800`0000U0`@0I`9m0:42O@2Q0Z/1KP:[0@@0
000]0@T010000?012P070000o0800000000000@0000]0@X02P0002@30`1a0ZH1IP:/0G42/@440000
;@4100@0000]0@<010000?012P0800009PH?00H0ooooo`401`000?`20030`<0000040000;@4:00P0
003j0P000@00000000840000;@4;00L0000K1;`1>`6K0NL0100002d10`040000l04:00@0000]0@40
10000?012`0300007P0700005PBk0CP1W07Z00@0000]0@D0100002d11@050000104=00001@000081
0@0001T0000b2Z<1kP0<0000@VmTNB1VK7EYI7<P2@0800P01`0400@0100800@0200600@0100002L1
ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@800000
1@000042oooo00@0000]0@<01`000?`2003oool000040000;@4:00P0003j0P000@000?ooo`840000
;@4;00L0000K12<0_0490981100002d10`040000l04:00@0000]0@4010000?012`0300007P070000
5P@R0;P12P2F0A`0003k0_3o00000000_08000000000845bJF5/0000>@<::ZF7kGN^Qnegd6O_McT3
2RX000X0100002d12P0L0000n`;`o`0000000901000000000211LVUQK0000:d32TbUQneg[XO]Mm1W
kgN]0`Y<000:00@0000]0@/070000?/2l?l00000002@0@400000000P@G9YHF`0002J0`ZPYHO]Mjj7
kGO@InmgVP<:X0002P040000;@4<00@0000]0@/0100002d12P040000;@4;00@0000]0@X01@0000@1
3@0000D000020@4000090000<PX;09H10@0006802P040000;@4;00T0000b2P/0X0410000:00500@0
000]0@`02@00038:2P2U0@40001d00@0100002d12`090000<PX;0:`10@0002T01@0400009`7oo`<0
000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P0000050000
0@;oool0100002d10`0800009PH?00H0ooooo`401@0000T2000000D000010_ooo`040000;@4300@0
000W0Ooo0`000000240122@0000H00000A30f`400003000000000000000000006T00@2`0000P0000
0@000080000002M3000@@@20od<003e400000>P3j0<Q000020000680000<00000@00024000080000
HP0000`0000100004@0000`0000800002P000100002W00002@0000T0000@0000o`400?@2000<0000
400000/0000000002`000100003o0@000`<00240000800009@0000`0000700209@0000`000000020
5P0000`000000000600000`0000000006@0000`0003oool0500000`0000=0000DP00070100010000
400000L00000000000000;`2000000001`828U<0N@1c07@0I@1]0000000000000000000000000000
000000000000000000000000000000000000000000000780K`1c06l0IP1d0200C`1V06H0J@1S06D0
801H0000000hKLEg00000=l>8@lI0;01000@0640K00P06<0K`1^0200AP1b06l0KP1d0500H@1W06D0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000I7H02000000U0000
30000040000H000030000000000I000030000?ooo`0D0000300000d0000B000030000080000:0000
40000000000000002@000100003o0@00m0800240000800002P000100002W00002@0000T0000@0000
o`400?@2000D0000300000d0000W00006000008000000000oooo0000000U000030000080000V0000
700000<0000000000@000000000000009@0000`000030000:`0001P000360@009P000?`100170000
9`0001P00004000000000?ooo`0000009@0000`000040000:00000`0000200009P0001`000020000
0000000000000000000002D0000<00000P0002P0000<00000`0002L0000H00000`000000003oool0
000002D0000<00000`0002H0000L00001@0000000001000000000?ooo`0U0000300000D0000[0000
60000=T1000/0000m@400480000U0000300000@0000X0000300000<0000U000030000080000X0000
300000D0000Q0000200001h0000H0000g04002d0003c0@00@P000580001`0@001@000??oool00000
00000000002@0@00000000L000110780J@1Q06`00000000000000000000000000000000000000000
00000000000000000000000000000000000C0:A:bc3O3R4?23dm0Q/4001XcQ<00000090Fm7N8aC`2
CQKdMdP75@1Z5_Agi`h`0I35?0:@aC`2K`1c06l0IP1d0200C`1V06H0J@1S06D0801H0000000hKLEg
00000=l>8@lI0;01000@0640K00P06<0K`1^0200AP0001<00000090Fm7OhT_T6CQKdMoP85@1Z5_Ag
G9?i1/80_`L0ToT60000000000000000000000@0000P00000000000000000000000100005@2/cA<0
00000:3>4`05T?Igb=GeMooooomZ5_Agbf3UM`005@000000gV3UMfAf00P000009@0000`000050000
DP00070100030000moooo`000000000000000901000000001`008440LP1Y0640K000000000000000
000000000000000000000000000000000000000000000000000000000000024?6@2`0@00401Q06`0
801S06l0KP0P04H0000C0000002@5_Agn9;i1ThFm7Oh21D0JQKdMebCn@K20;l709?i1P0000000000
00000000000400008000000000000000000000000@0001D0[<dC0000002PcQ<01I3fM`00mGOooooo
JQKdMl]PiGL001D000000=iPiGMTMP080000002Cn@H0000000000000000000001000020000000000
0000000000000040000E0:c=4`000000X<hC00F@mWO8eOEgooooofXFm7O;H>Eg000E0000003NH>Eg
I7H02000000U0000300000<0000U0000300000D0000U0000300000<0000U0000300000D0000B0000
30000040001D0000F0000401000W0000C`4003H000010000000P@[</8d;L0@00;`000080001<0000
0000000000000000oooooooooom@0000A@1D00T0000700009@0000`000030000E00005@0001@0@00
;@0005@1000h00000@00000084:c;2=2k04003D000010000C00000000000000000000?oooooooooo
D0000340000500008P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
600001X0000A00003@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000
300000@0000W0000600000H000000000oooo0000000U0000300000H0000V0000700000L000000000
0@000000000000009@0000`000070000:`0001P000120P009`0009D2001600009@0000`000040000
:00000`0000600009@0000`000020000:00000`0000700008@0000P0000N0000600004D2000X0000
T`8004H0000U0000300000D0000U0000300000D0000D0000300000d0000B000030000040001D0000
T0000:`1000V0000lP4003D000010000000P@[</8d980P00;P0000/0001<00000000000000000000
oooooooooomT0000A@1^07H0J@1b06l0KP1]06D0KP1d00002@0000L0000500000`0000@000070000
1`0000/0000700001`0000@0000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000
000001h0000H00006P000140000=0`00S0400280000<0000oooooaP0000<0000000001T0000<0000
oooo02D0000<0000100002L0000H00001`0000000030`<00000002D0000<00001`0002H0000L0000
1P0000000001000000000000000U0000300000H0000[0000600001<2002K0@00IP800;/1000U0000
300000@0000X0000300000L0000U000030000080000X0000300000H0000Q0000200001h0000H0000
5P8009`1001T0P00^`400580001`0@001P000??oool0000000000000002l0P00000000L002110780
J@1Q06`0000000000000000000000000000000000000000000000000000000000000000000000000
000C0:A:bc3O3R4?23dm0Q/4001XcQ<00000090Fm7L0DCD2CQKdMdP75@1Z5_Agi`h`1`QA=@88DCD2
0000002Cn@H00000000004D0KP1f06T0LP1_06h0K@1U06h0M000000000000040000E0:c=4`000000
X<hC00F@mWL001<00000090Fm7L`YC`2CQKdMmP75@1Z5_AgYP>o1cRU?08hYC`20000000000000000
000000@0000P00000000000000000000YAl100005@2/cA<0YAo4MjDOa7O4l?eo0>3mO`0000000000
000000000032?LAg0P0006Af00P000009@0000`0000600009@0000`000060000500000`0000=0000
4P0000`000010000E00007`000280@00XP400;T1002a0@000@00000084:c;2=290800:<100080000
C00000000000000000000?ooooooooooG00004L0B@0P05@0LP1Q06<0M00:0000100000@000080000
1@0000P00007000010000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000400009`0001P00007000000000?ooo`0000009@0000`0000700009P0001`000080000
0000004000000000oooo02D0000<0000200002/0000H0000/04009/1003A0@00/@4002D0000<0000
100002P0000<00001`0002D0000<00000P0002P0000<000020000240000800007P0001P0002c0@00
W0400<l1002a0@009@0000`0000500009@0000`0000300009@0000`0000500009@0000`000030000
9@0000`000050000500000`0000=00004P0000`000010000E00005@0000G0@00W@4001d1002/0@00
0@00000084:c;2=2/`4009h100010000C00000000000000000000?ooooooooooD00007<000070000
9@0000`000030000E00005P0000N0@00X`4002D1002^0@000@00000084:c;2=2^P400:@100020000
C00000000000000000000?ooooooooooD0000700M00500000`000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009`0001P00008000000000?ooo`000000
9@0000`0000800009P0001`0000700000000004000000000oooo02D0000<00001`0002/0000H0000
6P4007`1000k0@00TP4002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<0000
1`000240000800007P0001P0000M0@00O@4003T1002B0@009@0000`0000500009@0000`000030000
9@0000`0000500009@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000
E00005@000210000O@4008L0002<0@000@00000084:c;2=27@4007l100010000C000000000000000
00000?ooooooooooD00007<0000700009@0000`000030000E00005@000280000Q04008`0002?0@00
0@00000084:c;2=2904008D100010000C00000000000000000000?ooooooooooD000070000050000
8P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A0000
3@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000300000@0000V0000
700000L0000000000@000000000000009@0000`0000700009`0001P00008000000000?ooo`000000
9@0000`000080000EP0003P0001`0000K`4007/0002H0@001`0000`1S`4?0Hl13`5a0A@1L@4D0Hl1
5`6?0A41V@4U000030000080000X0000300000L0000U0000300000@0000X0000300000P0000V0000
700000P0000000000@000000000000009@0000`0000800009`0001P00007000000000?ooo`000000
9@0000`000070000:`0001P0002X0000F@0008d2001b0@009@0000`000020000:00000`000080000
9@0000`000040000:00000`0000700008@0000P0000N000060000:`0001J0000RP800781001B0000
L04000L0003]oooo0000000000000000T04000000007000P@@1b06T0H@1/00000000000000000000
000000000000000000000000000000000000000000000000000000004`2TB//`g`hQ3`Pm?@8K1000
J<hC0000002@5_AgF;dl0ThFm7M81aD0JQKdMd0=40IP_C`2H;dl0SRU?08hYC`200000000001`07@0
801D0780H@1S07@00000000000000000YAl100005@2/cA<0YAo4MjDOa7O4l?eo000C0000002@5_Ag
h=_i1ThFm7L821D0JQKdM`L000000000j=_i1P000000000000000000000400008000000000000000
YAo4MjDO0@0001D0[<dC0000002PcQ<01I3fMlSEmGOoooooJQKdMl]PiGL001D000000=iPiGMTMP08
000002D0000<00001`0001@0000<00003@000180000<00000@0005@0001D0000f`400;h0003W0@00
d`00004000000212/b`S@WL2003300000@0004`00000000000000000003ooooooooooe00001@0000
3@0005@0001D0000g`400=H0003T0@00j`00004000000212/b`S@W/2003K00000@0004`000000000
00000000003ooooooooooe00001900001P0005@0001D0000f`400>l0003W0@001040004000000212
/b`S@WL2003c00000@0004`00000000000000000003ooooooooooe00001C00003@000280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000400009`0001P000080000
00000?ooo`0000009@0000`0000800009P0001`0000900000000004000000000000002D0000<0000
2@0002/0000H0000_`4004H1001W0P00I`4002D0000<0000100002P0000<0000200002D0000<0000
0P0002P0000<00002@0002L0000H00002@000000003oool0000002D0000<00002@0002H0000L0000
200000000001000000000000000U0000300000P0000[000060000<40002o0000k@0006L1000U0000
300000@0000X0000300000T0000U000030000080000X0000300000P0000V0000700000P000000000
0@000000000000009@0000`0000800009@0000`000050020E`0002@0001I0000E@400201001E0@00
0P000;`1E`7e05L19@0000`000080020:00000`0000800009`0001P0000800000000000000000000
9@0000`000080000EP0002P0001B0000D04005`0001K0@000`000?P0DP7^05P1n01M0BD0000<0000
0P0002D0000<0000100002P0000<0000200002L0000H000020000000003oool0000002D0000<0000
200002H0000L00002@0000000001000000000000000U0000300000T0000[000060000;h100040@00
I`8002D1000U0000300000@0000X0000300000P0000U000030000080000X0000300000T0000W0000
600000T000000000oooo0000000U0000300000T0000V0000700000P0000000000@00000000000000
9@0000`000080000:`0001P000300@00_P0006H2003O00009@0000`000040000:00000`000090000
9@0000`000020000:00000`0000800009P0001`0000800000000004000000000000002D0000<0000
200002D0000<00001@00P5L0000T0000F@4004<1001I0@00IP400080003e0DH1m@5X0BD0000<0000
0P0002P0000<0000200002D0000<0000100002H0000L0000200000000001000000000000000U0000
300000P0000U0000300000D0081G00009000094100140@00T@4006H100020000;@970Bd2J04U0000
30000080000X0000300000P0000U0000300000@0000W0000600000P000000000oooo0000000U0000
300000P0000V0000700000T0000000000@000000000000009@0000`000090000:`0001P0002n0@00
K00006L2002=00009@0000`000040000:00000`0000800009@0000`000020000:00000`000090000
9`0001P00009000000000?ooo`0000009@0000`0000900009P0001`0000800000000004000000000
oooo02D0000<0000200002/0000H0000d04004d1003[0@00H04002D0000<0000100002P0000<0000
2@0002D0000<00000P0002P0000<000020000240000800007P0001P0003C0@00CP400>T1001P0@00
9@0000`0000500009@0000`0000300009@0000`0000500009@0000`0000300009@0000`000050000
500000`0000=00004P0000`000010000E00005P0000g0@00CP400481001M0@000@00000084:c;2=2
d`40050100020000C00000000000000000000?ooooooooooD0000440B@0900000`0002D0000<0000
0`0005@0001D0000@`4005@100170@00G@40004000000212/b`S@]l1001F0@000@0004`000000000
00000000003ooooooooooe00000c00001@000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P00008000000000?ooo`0000009@0000`000080000
9P0001`0000900000000004000000000oooo02D0000<00002@0002/0000H00001P8004d1000P0P00
H04002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<00002@00024000080000
7P0001P000090P00CP4001h2001P0@009@0000`0000500009@0000`0000300009@0000`000050000
9@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000E00005P0001]0@00
CP4007P1001M0@000@00000084:c;2=22@80050100020000C00000000000000000000?oooooooooo
D0000440B@0900000`0002D0000<00000`0005@0001D0000N@4005@1001m0@00G@40004000000212
/b`S@QD2001F0@000@0004`00000000000000000003ooooooooooe00000b00001@000280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000400009`0001P000090000
00000?ooo`0000009@0000`0000900009P0001`0000800000000004000000000oooo02D0000<0000
200002/0000H0000?P8004l1001F0P00HP4002D0000<0000100002P0000<00002@0002D0000<0000
0P0002P0000<000020000240000800007P0001P000110P00D04005@2001R0@009@0000`000050000
9@0000`0000300009@0000`0000500009@0000`0000300009@0000`000050000500000`0000=0000
4P0000`000010000E00005P0002U0@00D0400;01001O0@000@00000084:c;2=2@@80058100020000
C00000000000000000000?ooooooooooD0000440B@0900000`0002D0000<00000`0005@0001D0000
/@4005H1002e0@00G`40004000000212/b`S@Td2001H0@000@0004`00000000000000000003ooooo
oooooe00000a00001@000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000400009`0001P00008000000000?ooo`0000009@0000`0000800009P0001`000090000
0000004000000000oooo02D0000<00002@0002/0000H00001`8000X1000R0P007@4002D0000<0000
100002P0000<0000200002D0000<00000P0002P0000<00002@000240000800007P0001P0000:0P00
2`400202000M0@009@0000`0000500009@0000`0000300009@0000`0000500009@0000`000030000
9@0000`000050000500000`0000=00004P0000`000010000E00005P0001^0@002@4007/1000H0@00
0@00000084:c;2=22P8000d100020000C00000000000000000000?ooooooooooD0000680HP070000
1`0002D0000<00000`0005@0001D0000O04000l100200@006040004000000212/b`S@QP2000C0@00
0@0004`00000000000000000003ooooooooooe00000a00001@000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009`0001P00009000000000?ooo`000000
9@0000`0000900009P0001`0000800000000004000000000oooo02D0000<0000200002/0000H0000
10800<D0000P0P00f00002D0000<0000100002P0000<00002@0002D0000<00000P0002P0000<0000
20000240000800007P0001P000070P00aP0001h2003H00009@0000`0000500009@0000`000030000
9@0000`0000500009@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000
E00005P0001[0@00``0007`1003B00000@00000084:c;2=21`800<P000020000C000000000000000
00000?ooooooooooD0000480@P0900002@0002D0000<00000`0005@0001D0000O@400<T000210@00
dP00004000000212/b`S@QT2003>00000@0004`00000000000000000003ooooooooooe00000a0000
1@000280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J0000
4@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000040000
9`0001P00008000000000?ooo`0000009@0000`0000800009P0001`0000900000000004000000000
oooo02D0000<00002@0002/0000H00001P800700000R0P00QP0002D0000<0000100002P0000<0000
200002D0000<00000P0002P0000<00002@000240000800007P0001P000090P00L@00020200260000
9@0000`0000500009@0000`0000300009@0000`0000500009@0000`0000300009@0000`000050000
500000`0000=00004P0000`000010000E00005P0001]0@00K00007`1001k00000@00000084:c;2=2
2@8007<000020000C00000000000000000000?ooooooooooD00004D0E00900001`0002D0000<0000
0`0005@0001D0000O@40078000210@00O@00004000000212/b`S@QT2001i00000@0004`000000000
00000000003ooooooooooe00000b00001@000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P00009000000000?ooo`0000009@0000`000090000
9P0001`0000800000000004000000000000002D0000<0000200002/0000H0000L@400;l0002N0@00
h00002D0000<0000100002P0000<00002@0002D0000<00000P0002P0000<0000200002L0000H0000
20000000003oool0000002D0000<0000200002H0000L00002@0000000001000000000000000U0000
300000T0000[00006000074100030@00WP4002@1000U0000300000@0000X0000300000P0000U0000
30000080000X0000300000T0000W0000600000T000000000oooo0000000U0000300000T0000V0000
700000P0000000000@000000000000009@0000`000080000:`0001P0000@0@00_`0004X1003P0000
9@0000`000040000:00000`0000900009@0000`000020000:00000`0000800009`0001P000080000
00000?ooo`0000009@0000`0000800009P0001`0000900000000004000000000000002D0000<0000
2@0002/0000H0000404000<1001:0@00904002D0000<0000100002P0000<0000200002D0000<0000
0P0002P0000<00002@0002H0000L00002@0000000001000000000000000U0000300000T0000U0000
300000D0081G000090000>d0003L00007`400?h000020000R@420K/1h@0U0000300000P0080X0000
300000T0000W0000600000T00000000000000000000U0000300000T0001F0000:00001X1003I0000
9P400>@000030000^`7Y0<81gP2f0N009@0000`0000200009@0000`000040000:00000`000090000
9P0001`0000900000000004000000000000002D0000<00002@0002D0000<00001@00P5L0000T0000
k00008X0000O0@00^000008000280Kd0^`6@02D0000<00002000P2P0000<00002@0002L0000H0000
2@00000000000000000002D0000<00002@0005H0000X00006@4008H0000T0@00T@0000<0002m0IL0
`06<0;D1S`0U000030000080000U0000300000@0000X0000300000T0000V0000700000T000000000
0@000000000000009@0000`0000900009@0000`000050020E`0002@0001K0000c0000740003<0000
0P0000d1d@3g0=409@0000`000080020:00000`0000900009`0001P0000900000000000000000000
9@0000`000090000EP0002P0001D0000a`0005h0003B00000`000?X0c03`0=80nP3G02D0000<0000
0P0002D0000<0000100002P0000<00002@0002H0000L00002@0000000001000000000000000U0000
300000T0000U0000300000D0081G0000900005X0000@0@00L000010100020000304D0OH0504U0000
300000P0080X0000300000T0000W0000600000T00000000000000000000U0000300000T0001F0000
:0000580000;0@00G@0001H100030000n@0?0Nh0507i01X19@0000`0000200009@0000`000040000
:00000`0000900009`0001P00009000000000?ooo`0000009@0000`0000900009P0001`000080000
0000004000000000000002D0000<0000200002/0000H0000`P0006X0003_0000R`0002D0000<0000
100002P0000<00002@0002D0000<00000P0002P0000<0000200002L0000H000020000000003oool0
000002D0000<0000200002H0000L00002@0000000001000000000000000U0000300000T0000[0000
60000101001Z0000B04008/0000U0000300000@0000X0000300000P0000U000030000080000X0000
300000T0000W0000600000T000000000oooo0000000U0000300000T0000V0000700000P000000000
0@000000003oool09@0000`000080000:`0001P0000J0@00KP000481002400009@0000`000040000
:00000`0000900009@0000`000020000:00000`0000800008@0000P0000N0000600001d1001_0000
@04008@0000U0000300000D0000U0000300000<0000U0000300000D0000U0000300000<0000U0000
300000D0000D0000300000d0000B000030000040001D0000F0000840001Z0000T00007T000010000
000P@[</8d8M0@00L@000080001<00000000000000000000oooooooooom@0000A@1D00T000070000
9@0000`000030000E0000600002A0000L00009l0001k00000@00000084:c;2=2;@4007L000030000
C00000000000000000000?ooooooooooE00007<0I@1a00001@0000D0000500008P0000`0003ooooo
8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R0000
30000?oooolH000030000000000I000030000?ooo`0U0000300000@0000W0000600000P000000000
oooo0000000U0000300000P0000V0000700000T0000000000@000000003oool09@0000`000090000
:`0001P0000G0@00a00003l1003J00009@0000`000040000:00000`0000800009@0000`000020000
:00000`0000900008@0000P0000N0000600001X100350000?@400=X0000U0000300000D0000U0000
300000<0000U0000300000D0000U0000300000<0000U0000300000D0000D0000300000d0000B0000
30000040001D0000F00007h000320000S`000=4000010000000P@[</8d8J0@00a`000080001<0000
0000000000000000oooooooooom@0000@P1200T0000900009@0000`000030000E0000600002@0000
b00009h0003C00000@00000084:c;2=2;0400<d000030000C00000000000000000000?oooooooooo
E00007<0I@1a00001@0000D0000500008P0000`0003ooooo8@0000P0000I000030000?ooo`0H0000
30000000000N0000600001X0000A00003@<008`1000R000030000?oooolH000030000000000I0000
30000?ooo`0U0000300000@0000W0000600000T000000000oooo0000000U0000300000T0000V0000
700000P0000000000@000000003oool09@0000`000080000:`0001P0000E0@00204003d1000N0@00
9@0000`000040000:00000`0000900009@0000`000020000:00000`0000800008@0000P0000N0000
600001P100090@00>`4001h1000U0000300000D0000U0000300000<0000U0000300000D0000U0000
300000<0000U0000300000D0000D0000300000d0000B000030000040001D0000F00007`000070@00
R@0001H100010000000P@[</8d8H0@002`400080001<00000000000000000000oooooooooom@0000
HP1R00L0000700009@0000`000030000E0000600002:00003@4009P0000H0@000@00000084:c;2=2
9P40014100030000C00000000000000000000?ooooooooooE00007<0I@1a00001@0000D000050000
8P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A0000
3@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000300000@0000W0000
600000P000000000oooo0000000U0000300000P0000V0000700000T0000000000@000000003oool0
9@0000`000090000:`0001P0003300001P400>/0000L0@009@0000`000040000:00000`000080000
9@0000`000020000:00000`0000900008@0000P0000N000060000<H000070@00j@0001`1000U0000
300000D0000U0000300000<0000U0000300000D0000U0000300000<0000U0000300000D0000D0000
300000d0000B000030000040001D0000F00002X000050@00>@0001@100010000000P@[</8d;60000
2@400080001<00000000000000000000oooooooooom@0000C01>00L0000900009@0000`000030000
E00005P0000j00002`4004D0000F0@000@00000084:c;2=2eP0000l100020000C000000000000000
00000?ooooooooooD00005@0B00500001`000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P00009000000000?ooo`0000009@0000`000090000
9P0001`0000800000000004000000000oooo02D0000<0000200002/0000H0000a00006l0003/0000
Q@0002D0000<0000100002P0000<00002@0002D0000<00000P0002P0000<00002000024000080000
7P0001P000370000L0000>X0002500009@0000`0000500009@0000`0000300009@0000`000050000
9@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000E00005P0000[0000
J`0003X0001j00000@00000084:c;2=2a`00078000020000C00000000000000000000?oooooooooo
D00004`0CP0700002@0002D0000<00000`0005@0001H0000>`00074000150000O000004000000212
/b`S@]L0001h00000P0004`00000000000000000003ooooooooooe00001505@01P0000D0000R0000
30000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H00006P000140000=0`00
S0400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000100002H0000L0000
200000000001000000000000000U0000300000P0000U0000300000D0081G0000900005/0001d0000
L@0007@0000200003@5k0?L0N`0U0000300000P0080X0000300000P0000W0000600000P000000000
00000000000U0000300000P0001F0000:00005@0001_0000GP0007X000030000nP1f0?00O03j0840
9@0000`0000200009@0000`000040000:00000`0000800009`0001P00008000000000?ooo`000000
9@0000`0000800009P0001`0000900000000004000000000oooo02D0000<00002@0002/0000H0000
MP400<D0002B0@00f00002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<0000
2@000240000800007P0001P0001i0@00aP000901003H00009@0000`0000500009@0000`000030000
9@0000`0000500009@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000
E00005P0003M0000``000>h0003B00000@00000084:c;2=2N@400<P000020000C000000000000000
00000?ooooooooooD0000480@P0900002@0002D0000<00000`0005@0001D0000k`000<T0003c0000
dP00004000000212/b`S@X/1003>00000@0004`00000000000000000003ooooooooooe00000b0000
1@000280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J0000
4@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000040000
9`0001P00009000000000?ooo`0000009@0000`0000900009P0001`0000800000000004000000000
oooo02D0000<0000200002/0000H0000N@4000P1002D0@006`4002D0000<0000100002P0000<0000
2@0002D0000<00000P0002P0000<000020000240000800007P0001P0001l0@002@400981000K0@00
9@0000`0000500009@0000`0000300009@0000`0000500009@0000`0000300009@0000`000050000
500000`0000=00004P0000`000010000E00005P0003P00001`400>d0000F0@000@00000084:c;2=2
O04000/100020000C00000000000000000000?ooooooooooD0000680HP0700001`0002D0000<0000
0`0005@0001D0000kP0000d1003b00005P40004000000212/b`S@XX1000A0@000@0004`000000000
00000000003ooooooooooe00000b00001@000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P00008000000000?ooo`0000009@0000`000080000
9P0001`0000900000000004000000000000002D0000<00002@0002/0000H0000e`0005T1003]0000
IP4002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<00002@00024000080000
7P0001P0003J0000FP400>/0001V0@00DP00070100090000mOooo`00000000000000090100000000
1`008440LP1Y0640K000000000000000000000000000000000000000000000000000000000000000
00000000000001<0Y4[;<=l>8@l8?Cd26`@006S>4`000000T1KdMmQCn@I>5_AgB0LE06XFm7O[3S0c
h5?i1^1Cn@H00000j=_i1P0000000000<P1R0740000400008000000000000000YAo4MjDO0@0001D0
[<dC0000002PcQ<01I3fM`004`000000T1KdMf0Y>`9>5_Agj0HE06XFm7LD8[l7J2Tk0VPY>`800000
00000000000000001000020000000000YAo4MjDOa7NU7`40000E0:c=4`2U7lAgYAo4MlC`oGl0h?eo
000000000000000000000<8ma7L20000I7H02000000U0000300000T0000U0000300000T0000D0000
300000d0000B000030000040001D0000F00003h0001H0@00B@0006<100010000000P@[</8d;J0000
FP400080001<00000000000000000000oooooooooom@0000<@0`00H0000600008P0000`0003ooooo
8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R0000
30000?oooolH000030000000000I000030000?ooo`0U0000300000@0000W0000600000P000000000
oooo0000000U0000300000P0000V0000700000X0000000000@000000000000009@0000`0000:0000
:`0001P0001M0P00FP4006L2001V0@009@0000`000040000:00000`0000800009@0000`000020000
:00000`0000:00008@0000P0000N000060000602001K0@00I@8006H1000U0000300000T0000U0000
300000T0000U0000300000T0000D0000300000d0000B000030000040001D0000E0000<@1001I0@00
b04006<100010000000P@[</8d9P0P00F`400040001<00000000000000000000oooooooooom@0000
<@0000H0000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H0000
6P000140000=0`00S0400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000
100002L0000H00002P000000003oool0000002D0000<00002P0002H0000L00002000000000010000
00000000000U0000300000P0000[0000600002<2001J0@00;@8006H1000U0000300000@0000X0000
300000X0000U000030000080000X0000300000P0000Q0000200001h0000H00009P8005/1000[0P00
IP4002D0000<00002@0002D0000<00002@0002D0000<00002@0001@0000<00003@000180000<0000
0@0005@0001D0000RP4005T1002>0@00H`40004000000212/b`S@RH2001K0@000@0004`000000000
00000000003ooooooooooe00000b00001P000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P00008000000000?ooo`0000009@0000`000080000
9P0001`0000:00000000004000000000000002D0000<00002P0002/0000H0000jP4005X1003d0@00
IP4002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<00002P00024000080000
7P0001P0003]0@00F`400?81001V0@009@0000`0000900009@0000`0000900009@0000`000090000
500000`0000=00004P0000`000010000E00005@0001A0@00F@4005D1001S0@000@00000084:c;2=2
k@4005/100010000C00000000000000000000?ooooooooooD00003<0000600008P0000`0003ooooo
8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R0000
30000?oooolH000030000000000I000030000?ooo`0U0000300000@0000W0000600000X000000000
oooo0000000U0000300000X0000V0000700000P0000000000@000000000000009@0000`000080000
:`0001P0001L0P00604006H2000T0@009@0000`000040000:00000`0000:00009@0000`000020000
:00000`0000800008@0000P0000N0000600005l2000I0@00I08002@1000U0000300000T0000U0000
300000T0000U0000300000T0000D0000300000d0000B000030000040001D0000E0000<<1000E0@00
a`40020100010000000P@[</8d9O0P006@400040001<00000000000000000000oooooooooom@0000
=00000H0000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H0000
6P000140000=0`00S0400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000
100002L0000H000020000000003oool0000002D0000<0000200002H0000L00002P00000000010000
00000000000U0000300000X0000[0000600005/2003B0000I@800=h0000U0000300000@0000X0000
300000P0000U000030000080000X0000300000X0000Q0000200001h0000H0000GP800=<0001S0P00
gP0002D0000<00002@0002D0000<00002@0002D0000<00002@0001@0000<00003@000180000<0000
0@0005@0001D0000`P400<h000360@00f000004000000212/b`S@Uh2003C00000@0004`000000000
00000000003ooooooooooe00000g00001P000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P0000:000000000?ooo`0000009@0000`0000:0000
9P0001`0000800000000004000000000000002D0000<0000200002/0000H0000T@400=40002N0@00
h00002D0000<0000100002P0000<00002P0002D0000<00000P0002P0000<00002000024000080000
7P0001P0002D0@00dP0009`1003P00009@0000`0000900009@0000`000090000500000`0000=0000
4P0000`000010000E00005@0003h0000c@000?d0003J00000@00000084:c;2=2U0400=8000010000
C00000000000000000000?ooooooooooD00003P0000600008P0000`0003ooooo8@0000P0000I0000
30000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R000030000?oooolH0000
30000000000I000030000?ooo`0U0000300000@0000W0000600000P000000000oooo0000000U0000
300000P0000V0000700000X0000000000@000000000000009@0000`0000:0000:`0001P0002C0@00
5`4009h1000T0@009@0000`000040000:00000`0000800009@0000`000020000:00000`0000:0000
8@0000P0000N0000600009H1000H0@00W04002@1000U0000300000T0000U0000300000T0000D0000
300000d0000B000030000040001D0000E0000?X0000D0@00o`00020100010000000P@[</8d:F0@00
60400040001<00000000000000000000oooooooooom@0000=@0000H0000R000030000?oooolQ0000
200001T0000<0000oooo01P0000<0000000001h0000H00006P000140000=0`00S0400280000<0000
oooooaP0000<0000000001T0000<0000oooo02D0000<0000100002L0000H00002P000000003oool0
000002D0000<00002P0002H0000L0000200000000001000000000000000U0000300000P0000[0000
600003h1003@0000B@400=l0000U0000300000@0000X0000300000X0000U000030000080000X0000
300000P0000Q0000200001h0000H0000@@400=4000170@00g`0002D0000<00002@0002D0000<0000
2@0001@0000<00003@000180000<00000@0005@0001D0000Y@000<`0002Z0000f@00004000000212
/b`S@T41003A00000@0004`00000000000000000003ooooooooooe00000i00001P000280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000400009`0001P000080000
00000?ooo`0000009@0000`0000800009P0001`0000:00000000004000000000000002D0000<0000
2P0002/0000H0000?`4001@1001:0@00904002D0000<0000100002P0000<0000200002D0000<0000
0P0002P0000<00002P000240000800007P0001P000120@005@4004P1000T0@009@0000`000090000
9@0000`000090000500000`0000=00004P0000`000010000E00005@0002V00004@400:/0000N0@00
0@00000084:c;2=2@P4001D100010000C00000000000000000000?ooooooooooD00003H000060000
8P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A0000
3@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000300000@0000W0000
600000X000000000oooo0000000U0000300000X0000V0000700000P0000000000@00000000000000
9@0000`000080000:`0001P0000l0@00PP000581002?00009@0000`000040000:00000`0000:0000
9@0000`000020000:00000`0000800008@0000P0000N0000600003l100230000D04008l0000U0000
300000T0000U0000300000T0000D0000300000d0000B000030000040001D0000F0000:<0001l0000
[P0008P000010000000P@[</8d8o0@00P`000080001<00000000000000000000oooooooooom@0000
<@0b00H0000600008P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
600001X0000A00003@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000
300000@0000W0000600000P000000000oooo0000000U0000300000P0000V0000700000X000000000
0@000000000000009@0000`0000:0000:`0001P0003Q0000P`000?H0002?00009@0000`000040000
:00000`0000800009@0000`000020000:00000`0000:00008@0000P0000N000060000>@000240000
m00008l0000U0000300000T0000U0000300000T0000D0000300000d0000B000030000040001D0000
F00004P0001m0000D`0008P000010000000P@[</8d;T0000Q0000080001<00000000000000000000
oooooooooom@0000<@0c00H0000600008P0000`0003ooooo8@0000P0000I000030000?ooo`0H0000
30000000000N0000600001X0000A00003@<008`1000R000030000?oooolH000030000000000I0000
30000?ooo`0U0000300000@0000W0000600000X000000000oooo0000000U0000300000X0000V0000
700000P0000000000@000000000000009@0000`000080000:`0001P0001@0P00O`0006H2002<0000
9@0000`000040000:00000`0000:00009@0000`000020000:00000`0000800008@0000P0000N0000
600005<200200000I08008`0000U0000300000T0000U0000300000T0000D0000300000d0000B0000
30000040001D0000F0000;L1001i0000`P4008D000010000000P@[</8d9C0P00P0000080001<0000
0000000000000000oooooooooom@0000<@0a00H0000600008P0000`0003ooooo8@0000P0000I0000
30000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R000030000?oooolH0000
30000000000I000030000?ooo`0U0000300000@0000V0000700000P0000000000@00000000000000
9@0000`0000800009@0000`000050020E`0002@0000C0000E0000=D1001E00000P000:l0G01a0U/0
9@0000`000020000:00000`0000800009@0000`0000400009P0001`0000800000000004000000000
000002D0000<0000200002D0000<00001@00P5L0000T0000M`4008l0001g0@00^@000080000C0[h0
4`:E02D0000<00002000P2P0000<0000200002L0000H00002000000000000000000002D0000<0000
200005H0000X0000LP4008P0001m0@00TP0000<0000I0YP050:>00h2V00U000030000080000U0000
300000@0000X0000300000P0000V0000700000P0000000000@000000000000009@0000`000080000
9@0000`000050020E`0002@0001e0@00hP0007D100010@000P0001421@4A0^L09@0000`000080020
:00000`0000800009`0001P00008000000000000000000009@0000`000080000EP0002P0001`0@00
f`0007/1003U00000`0001L2jP0B0^0030;Z02D0000<00000P0002D0000<0000100002P0000<0000
200002H0000L0000200000000001000000000000000U0000300000P0000U0000300000D0081G0000
900003l1000X0@00?`4004@100020000f`570M/1:`4U0000300000P0080X0000300000P0000W0000
600000P00000000000000000000U0000300000P0001F0000:00003X1000Q0@00A@4002/100030000
h@4^0M`1907F0Bh19@0000`0000200009@0000`000040000:00000`0000800009P0001`000080000
0000004000000000000002D0000<0000200002D0000<00001@00P5L0000T0000M04002P1001d0@00
A0400080000@0TL1408[0BD0000<00002000P2P0000<0000200002L0000H00002000000000000000
000002D0000<0000200005H0000X0000K`400241001j0@00:`4000<0000F0Rh1408T0@/2;P4U0000
30000080000U0000300000@0000X0000300000P0000V0000700000P0000000000@00000000000000
9@0000`0000800009@0000`000050020E`0002@0002]0@00:0400:d100140@000P0004T2A`590R/1
9@0000`000080020:00000`0000800009`0001P00008000000000000000000009@0000`000080000
EP0002P0002X0@008@400;<1000[0@000`0004l2;P5:0R@1A08^0BD0000<00000P0002D0000<0000
100002P0000<0000200002H0000L0000200000000001000000000000000U0000300000P0000W0000
600000X000000000oooo0000000U0000300000X0000[000060000:L0003S0@00S0800?`2000U0000
30000080000X0000300000P0000U0000300000@0000X0000300000X0000Q0000200001h0000H0000
Z`000>@100290P00o08002D0000<00001`0001@0000<00003@000180000<00000@0005@0001D0000
fP400502003V0@00I@80004000000212/b`S@WH2001=0P000@0004`00000000000000000003ooooo
oooooe00001@00003@0005@0001D0000f`4006P2003V0@00O@80004000000212/b`S@WL2001U0P00
0@0004`00000000000000000003ooooooooooe00001D0000300005@0001D0000fP400802003V0@00
U@80004000000212/b`S@WH2001m0P000@0004`00000000000000000003ooooooooooe00001C0000
3@000280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J0000
4@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000040000
9`0001P0000:000000000?ooo`0000009@0000`0000:00009P0001`0000800000000004000000000
000002D0000<0000200002/0000H0000_P400=02001V0P00l@8002D0000<0000100002P0000<0000
2P0002D0000<00000P0002P0000<0000200002L0000H000020000000003oool0000002D0000<0000
200002H0000L00002P0000000001000000000000000U0000300000X0000[000060000<0000190P00
k0000?42000U0000300000@0000X0000300000P0000U000030000080000X0000300000X0000V0000
700000X0000000000@000000000000009@0000`0000:00009@0000`000050020E`0002@0001H0000
iP8001l1003V0P000P000;/1h@;d0>429@0000`000080020:00000`0000:00009`0001P0000:0000
00000000000000009@0000`0000:0000EP0002P0001@0000h@8005/0003]0P000`000?L0g0;/0>82
m`3W0RD0000<00000P0002D0000<0000100002P0000<00002P0002L0000H00002P000000003oool0
000002D0000<00002P0002H0000L0000200000000001000000000000000U0000300000P0000[0000
60000;d1002>0P00IP800:l2000U0000300000@0000X0000300000X0000U000030000080000X0000
300000P0000W0000600000P000000000oooo0000000U0000300000P0000V0000700000X000000000
0@000000000000009@0000`0000:0000:`0001P0002o0@00B08006D2001Y0P009@0000`000040000
:00000`0000800009@0000`000020000:00000`0000:00009P0001`0000:00000000004000000000
000002D0000<00002P0002D0000<00001@00P5L0000T0000F0400=D2001H0@00n0800080003d0M02
m07b0RD0000<00000P0002P0000<00002P0002D0000<0000100002H0000L00002P00000000010000
00000000000U0000300000X0000U0000300000D0081G000090000901003F0P00T0400?P200020000
;0;A0R`2lP8U000030000080000X0000300000X0000U0000300000@0000W0000600000X000000000
oooo0000000U0000300000X0000V0000700000P0000000000@000000000000009@0000`000080000
:`0001P0002m0@00mP4006H2000G0P009@0000`000040000:00000`0000:00009@0000`000020000
:00000`0000800009`0001P00008000000000?ooo`0000009@0000`0000800009P0001`0000:0000
0000004000000000oooo02D0000<00002P0002/0000H0000c`400=L2003Z0@00jP8002D0000<0000
100002P0000<0000200002D0000<00000P0002P0000<00002P000240000800007P0001P0003B0@00
f0800>P1003Z0P009@0000`0000500009@0000`0000300009@0000`0000500009@0000`000030000
9@0000`000050000500000`0000=00004P0000`000010000E00005P0000f0@00g`800441003^0P00
0@00000084:c;2=2dP400=X200020000C00000000000000000000?ooooooooooD0000440B@090000
0`0002D0000<00000`0005@0001D0000@P400>D200160@00k`80004000000212/b`S@]h1003P0P00
0@0004`00000000000000000003ooooooooooe00000c00001@000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009`0001P0000:000000000?ooo`000000
9@0000`0000:00009P0001`0000800000000004000000000oooo02D0000<0000200002/0000H0000
1@800=L2000O0P00jP8002D0000<0000100002P0000<00002P0002D0000<00000P0002P0000<0000
20000240000800007P0001P000080P00f08001d2003Z0P009@0000`0000500009@0000`000030000
9@0000`0000500009@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000
E00005P0001/0@00g`8007L1003^0P000@00000084:c;2=220800=X200020000C000000000000000
00000?ooooooooooD0000440B@0900000`0002D0000<00000`0005@0001D0000N0400>D2001l0@00
k`80004000000212/b`S@Q@2003P0P000@0004`00000000000000000003ooooooooooe00000b0000
1@000280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J0000
4@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000040000
9`0001P00008000000000?ooo`0000009@0000`0000800009P0001`0000:00000000004000000000
oooo02D0000<00002P0002/0000H0000?@800=T2001E0P00k08002D0000<0000100002P0000<0000
200002D0000<00000P0002P0000<00002P000240000800007P0001P000100P00fP8005<2003/0P00
9@0000`0000500009@0000`0000300009@0000`0000500009@0000`0000300009@0000`000050000
500000`0000=00004P0000`000010000E00005P0002T0@00h@800:l1003`0P000@00000084:c;2=2
@0800=`200020000C00000000000000000000?ooooooooooD0000440B@0900000`0002D0000<0000
0`0005@0001D0000/0400>L2002d0@00l@80004000000212/b`S@T`2003R0P000@0004`000000000
00000000003ooooooooooe00000a00001@000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P0000:000000000?ooo`0000009@0000`0000:0000
9P0001`0000800000000004000000000oooo02D0000<0000200002/0000H00001P8009@2000Q0P00
Y`8002D0000<0000100002P0000<00002P0002D0000<00000P0002P0000<00002000024000080000
7P0001P000090P00U@8001l2002W0P009@0000`0000500009@0000`0000300009@0000`000050000
9@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000E00005P0001]0@00
V`8007X1002Z0P000@00000084:c;2=22@8009L200020000C00000000000000000000?oooooooooo
D0000680HP0700001`0002D0000<00000`0005@0001D0000N`400:42001o0@00ZP80004000000212
/b`S@QL2002M0P000@0004`00000000000000000003ooooooooooe00000a00001@000280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000400009`0001P000080000
00000?ooo`0000009@0000`0000800009P0001`0000:00000000004000000000oooo02D0000<0000
2P0002/0000H00000`8004l2000O0P00HP8002D0000<0000100002P0000<0000200002D0000<0000
0P0002P0000<00002P000240000800007P0001P000060P00D08001d2001R0P009@0000`000050000
9@0000`0000300009@0000`0000500009@0000`0000300009@0000`000050000500000`0000=0000
4P0000`000010000E00005P0001Z0@00E@8007/1001T0P000@00000084:c;2=21P80058200020000
C00000000000000000000?ooooooooooD0000480@P0900002@0002D0000<00000`0005@0001D0000
O04005/200200@00I080004000000212/b`S@QP2001H0P000@0004`00000000000000000003ooooo
oooooe00000a00001@000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000400009`0001P0000:000000000?ooo`0000009@0000`0000:00009P0001`000080000
0000004000000000oooo02D0000<0000200002/0000H00001@800?X1000Q0P00408002D0000<0000
100002P0000<00002P0002D0000<00000P0002P0000<000020000240000800007P0001P000080P00
n`4001l2000@0P009@0000`0000500009@0000`0000300009@0000`0000500009@0000`000030000
9@0000`000050000500000`0000=00004P0000`000010000E00005P0001/0@00oP4007/1000=0P00
0@00000084:c;2=220800?d100020000C00000000000000000000?ooooooooooD00004D0E0090000
1`0002D0000<00000`0005@0001D0000O04000@200200@003`80004000000212/b`S@QP200030P00
0@0004`00000000000000000003ooooooooooe00000b00001@000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009`0001P00008000000000?ooo`000000
9@0000`0000800009P0001`0000:00000000004000000000000002D0000<00002P0002/0000H0000
L04004T2002M0@00JP8002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<0000
2P0002L0000H00002P000000003oool0000002D0000<00002P0002H0000L00002000000000010000
00000000000U0000300000P0000[000060000701002=0P00W@400:h2000U0000300000@0000X0000
300000X0000U000030000080000X0000300000P0000W0000600000P000000000oooo0000000U0000
300000P0000V0000700000X0000000000@000000000000009@0000`0000:0000:`0001P0000?0@00
B@8004T1001Z0P009@0000`000040000:00000`0000800009@0000`000020000:00000`0000:0000
9`0001P0000:000000000?ooo`0000009@0000`0000:00009P0001`0000800000000004000000000
000002D0000<0000200002/0000H00003`4008d200190@00[P8002D0000<0000100002P0000<0000
2P0002D0000<00000P0002P0000<0000200002H0000L0000200000000001000000000000000U0000
300000P0000U0000300000D0081G000090000>`0001^0P007P40090200020000R06<0[X1J`8U0000
300000P0080X0000300000P0000W0000600000P00000000000000000000U0000300000P0001F0000
:00001T1001[0P00904007H200030000^P5c0/01J0:e0FX29@0000`0000200009@0000`000040000
:00000`0000800009P0001`0000800000000004000000000000002D0000<0000200002D0000<0000
1@00P5L0000T0000j`0001/2000N0@00B@80008000270DL2^P4J0RD0000<00002000P2P0000<0000
200002L0000H00002000000000000000000002D0000<0000200005H0000X0000604001L2000T0@00
8`8000<0002l0B42`04F0[@16@8U000030000080000U0000300000@0000X0000300000P0000V0000
700000P0000000000@000000000000009@0000`0000800009@0000`000050020E`0002@0001J0000
GP800700001N0P000P0000`1F`;f05/29@0000`000080020:00000`0000800009`0001P000080000
00000000000000009@0000`000080000EP0002P0001B0000F@8005d0001T0P000`000?T0EP;^05`2
n@1Q0RD0000<00000P0002D0000<0000100002P0000<0000200002H0000L00002000000000010000
00000000000U0000300000P0000U0000300000D0081G0000900005T0002R0P00K`000:8200020000
2`6N0_D0WP8U0000300000P0080X0000300000P0000W0000600000P00000000000000000000U0000
300000P0001F0000:0000580002M0P00G0000:P200030000n02I0^h0WP;h0:@29@0000`000020000
9@0000`000040000:00000`0000800009`0001P00008000000000?ooo`0000009@0000`000080000
9P0001`0000:00000000004000000000000002D0000<00002P0002/0000H0000`@000?@1003^0000
5@8002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<00002P0002L0000H0000
2P000000003oool0000002D0000<00002P0002H0000L0000200000000001000000000000000U0000
300000P0000[0000600000l1003d0@00A`4001D2000U0000300000@0000X0000300000X0000U0000
30000080000X0000300000P0000W0000600000P000000000oooo0000000U0000300000P0000V0000
700000X0000000000@000000003oool09@0000`0000:0000:`0001P0000I0@00n0400441000>0P00
9@0000`000040000:00000`0000800009@0000`000020000:00000`0000:00008@0000P0000N0000
600001`1003i0@00?`4000h2000U0000300000D0000U0000300000<0000U0000300000D0000U0000
300000<0000U0000300000D0000D0000300000d0000B000030000040001D0000F0000800003l0@00
S`0000/200010000000P@[</8d8L0@00n`400080001<00000000000000000000oooooooooom@0000
A@1D00T0000700009@0000`000030000E0000600002@00000P8009h0000=0P000@00000084:c;2=2
;040004200030000C00000000000000000000?ooooooooooE00007<0I@1a00001@0000D000050000
8P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A0000
3@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000300000@0000W0000
600000X000000000oooo0000000U0000300000X0000V0000700000P0000000000@000000003oool0
9@0000`000080000:`0001P0000F0@00CP8003h1001T0P009@0000`000040000:00000`0000:0000
9@0000`000020000:00000`0000800008@0000P0000N0000600001T1001?0P00?04006@2000U0000
300000D0000U0000300000<0000U0000300000D0000U0000300000<0000U0000300000D0000D0000
300000d0000B000030000040001D0000F00007d0001D0P00SP0006<200010000000P@[</8d8I0@00
D@800080001<00000000000000000000oooooooooom@0000@P1200T0000900009@0000`000030000
E0000600002?0000FP8009d0001U0P000@00000084:c;2=2:`4005L200030000C000000000000000
00000?ooooooooooE00007<0I@1a00001@0000D0000500008P0000`0003ooooo8@0000P0000I0000
30000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R000030000?oooolH0000
30000000000I000030000?ooo`0U0000300000@0000W0000600000P000000000oooo0000000U0000
300000P0000V0000700000X0000000000@000000003oool09@0000`0000:0000:`0001P0000D0@00
TP8003`1002X0P009@0000`000040000:00000`0000800009@0000`000020000:00000`0000:0000
8@0000P0000N0000600001L1002C0P00>P400:P2000U0000300000D0000U0000300000<0000U0000
300000D0000U0000300000<0000U0000300000D0000D0000300000d0000B000030000040001D0000
F00007/0002I0P00R0000:P200010000000P@[</8d8G0@00U@800080001<00000000000000000000
oooooooooom@0000HP1R00L0000700009@0000`000030000E000060000290000W`8009L0002Z0P00
0@00000084:c;2=29@4009/200030000C00000000000000000000?ooooooooooE00007<0I@1a0000
1@0000D0000500008P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
600001X0000A00003@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000
300000@0000W0000600000X000000000oooo0000000U0000300000X0000V0000700000P000000000
0@000000003oool09@0000`000080000:`0001P000320000T0800>X0002V0P009@0000`000040000
:00000`0000:00009@0000`000020000:00000`0000800008@0000P0000N000060000<D0002A0P00
j0000:H2000U0000300000D0000U0000300000<0000U0000300000D0000U0000300000<0000U0000
300000D0000D0000300000d0000B000030000040001D0000F00002T0002G0P00>0000:H200010000
000P@[</8d;50000T`800080001<00000000000000000000oooooooooom@0000C01>00L000090000
9@0000`000030000E00005P0000i0000W@8004@0002X0P000@00000084:c;2=2e@0009T200020000
C00000000000000000000?ooooooooooD00005@0B00500001`000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009`0001P00008000000000?ooo`000000
9@0000`0000800009P0001`0000:00000000004000000000oooo02D0000<00002P0002/0000H0000
``000?T1003[00003`8002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<0000
2P000240000800007P0001P000360000nP400>T0000?0P009@0000`0000500009@0000`000030000
9@0000`0000500009@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000
E00005P0000Z0000o@4003T0000<0P000@00000084:c;2=2aP000?`100020000C000000000000000
00000?ooooooooooD00004`0CP0700002@0002D0000<00000`0005@0001H0000>P0000<200140000
3P80004000000212/b`S@]H000020P000P0004`00000000000000000003ooooooooooe00001505@0
1P0000D0000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H0000
6P000140000=0`00S0400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000
100002H0000L00002P0000000001000000000000000U0000300000X0000U0000300000D0081G0000
900005X000060P00L00000H20002000030450_H01@8U0000300000P0080X0000300000X0000W0000
600000X00000000000000000000U0000300000X0001F0000:000058000010P00G@0000`200030000
n@000^h01P;i00/29@0000`0000200009@0000`000040000:00000`0000:00009`0001P0000:0000
00000?ooo`0000009@0000`0000:00009P0001`0000800000000004000000000oooo02D0000<0000
200002/0000H0000M@400502002A0@00H`8002D0000<0000100002P0000<00002P0002D0000<0000
0P0002P0000<000020000240000800007P0001P0001h0@00D@8008l1001S0P009@0000`000050000
9@0000`0000300009@0000`0000500009@0000`0000300009@0000`000050000500000`0000=0000
4P0000`000010000E00005P0003L0000EP800>d0001U0P000@00000084:c;2=2N04005<200020000
C00000000000000000000?ooooooooooD0000480@P0900002@0002D0000<00000`0005@0001D0000
kP0005`2003b0000I@80004000000212/b`S@XX1001I0P000@0004`00000000000000000003ooooo
oooooe00000b00001@000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000400009`0001P00008000000000?ooo`0000009@0000`0000800009P0001`0000:0000
0000004000000000oooo02D0000<00002P0002/0000H0000N0400982002C0@00Y@8002D0000<0000
100002P0000<0000200002D0000<00000P0002P0000<00002P000240000800007P0001P0001k0@00
T`800941002U0P009@0000`0000500009@0000`0000300009@0000`0000500009@0000`000030000
9@0000`000050000500000`0000=00004P0000`000010000E00005P0003O0000V@800>`0002X0P00
0@00000084:c;2=2N`4009D200020000C00000000000000000000?ooooooooooD0000680HP070000
1`0002D0000<00000`0005@0001D0000k@0009l2003a0000Z080004000000212/b`S@XT1002K0P00
0@0004`00000000000000000003ooooooooooe00000b00001@000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009`0001P0000:000000000?ooo`000000
9@0000`0000:00009P0001`0000800000000004000000000000002D0000<0000200002/0000H0000
eP000><2003/0000l08002D0000<0000100002P0000<00002P0002D0000<00000P0002P0000<0000
20000240000800007P0001P0003I0000i0800>X0003`0P009@0000`0000900009@0000`000090000
500000`0000=00004P0000`000010000E00005P0000m0000jP8004P0003e0P000@00000084:c;2=2
f@000>@200020000C00000000000000000000?ooooooooooD0000340<00600001P000280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000400009`0001P000080000
00000?ooo`0000009@0000`0000800009P0001`0000:00000000004000000000000002D0000<0000
2P0002/0000H0000G0800>@2001V0P00l08002D0000<0000100002P0000<0000200002D0000<0000
0P0002P0000<00002P000240000800007P0001P0001O0P00i@8006@2003`0P009@0000`000090000
9@0000`0000900009@0000`000090000500000`0000=00004P0000`000010000E00005@000330@00
j`800<L1003e0P000@00000084:c;2=2G`800>D200010000C00000000000000000000?oooooooooo
D0000340000600008P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
600001X0000A00003@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000
300000@0000W0000600000X000000000oooo0000000U0000300000X0000V0000700000P000000000
0@000000000000009@0000`000080000:`0001P0000R0P00i08002`2003`0P009@0000`000040000
:00000`0000:00009@0000`000020000:00000`0000800008@0000P0000N0000600002D2003U0P00
:P800?02000U0000300000T0000U0000300000T0000U0000300000T0000D0000300000d0000B0000
30000040001D0000E00008T1003[0P00S@400?D200010000000P@[</8d8U0P00i@800040001<0000
0000000000000000oooooooooom@0000<P0000H0000R000030000?oooolQ0000200001T0000<0000
oooo01P0000<0000000001h0000H00006P000140000=0`00S0400280000<0000oooooaP0000<0000
000001T0000<0000oooo02D0000<0000100002L0000H000020000000003oool0000002D0000<0000
200002H0000L00002P0000000001000000000000000U0000300000X0000[000060000>T1003T0P00
l`400?02000U0000300000@0000X0000300000P0000U000030000080000X0000300000X0000Q0000
200001h0000H0000k0400>D2003a0@00l08002D0000<00002@0002D0000<00002@0002D0000<0000
2@0001@0000<00003@000180000<00000@0005@0001D0000D0400>/2001D0@00m@80004000000212
/b`S@^`1003U0P000@0004`00000000000000000003ooooooooooe00000c00001P000280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000400009`0001P0000:0000
00000?ooo`0000009@0000`0000:00009P0001`0000800000000004000000000000002D0000<0000
200002/0000H0000F`800:82001U0P00[P8002D0000<0000100002P0000<00002P0002D0000<0000
0P0002P0000<000020000240000800007P0001P0001N0P00X`8006<2002^0P009@0000`000090000
9@0000`0000900009@0000`000090000500000`0000=00004P0000`000010000E00005@000320@00
Y`800<H1002a0P000@00000084:c;2=2GP800:<200010000C00000000000000000000?oooooooooo
D00003@0000600008P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
600001X0000A00003@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000
300000@0000W0000600000P000000000oooo0000000U0000300000P0000V0000700000X000000000
0@000000000000009@0000`0000:0000:`0001P0001K0P00G@8006D2001Y0P009@0000`000040000
:00000`0000800009@0000`000020000:00000`0000:00008@0000P0000N0000600005h2001N0P00
H`8006T2000U0000300000T0000U0000300000T0000U0000300000T0000D0000300000d0000B0000
30000040001D0000E0000<81001Q0P00aP4006/200010000000P@[</8d9N0P00GP800040001<0000
0000000000000000oooooooooom@0000=`0000H0000R000030000?oooolQ0000200001T0000<0000
oooo01P0000<0000000001h0000H00006P000140000=0`00S0400280000<0000oooooaP0000<0000
000001T0000<0000oooo02D0000<0000100002L0000H00002P000000003oool0000002D0000<0000
2P0002H0000L0000200000000001000000000000000U0000300000P0000[000060000981001L0P00
W@4006X2000U0000300000@0000X0000300000X0000U000030000080000X0000300000P0000Q0000
200001h0000H0000U@4005d2002K0@00JP8002D0000<00002@0002D0000<00002@0001@0000<0000
3@000180000<00000@0005@0001D0000n@000602003n0000K080004000000212/b`S@YD1001M0P00
0@0004`00000000000000000003ooooooooooe00000h00001P000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009`0001P00008000000000?ooo`000000
9@0000`0000800009P0001`0000:00000000004000000000000002D0000<00002P0002/0000H0000
T@400:02002M0@00[P8002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<0000
2P000240000800007P0001P0002D0@00X@8009/1002^0P009@0000`0000900009@0000`000090000
500000`0000=00004P0000`000010000E00005@0003h0000Y@800?d0002a0P000@00000084:c;2=2
U0400:4200010000C00000000000000000000?ooooooooooD00003D0000600008P0000`0003ooooo
8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R0000
30000?oooolH000030000000000I000030000?ooo`0U0000300000@0000W0000600000X000000000
oooo0000000U0000300000X0000V0000700000P0000000000@000000000000009@0000`000080000
:`0001P0000l0@00G@8004P1001Z0P009@0000`000040000:00000`0000:00009@0000`000020000
:00000`0000800008@0000P0000N0000600003l1001N0P00AP4006X2000U0000300000T0000U0000
300000T0000D0000300000d0000B000030000040001D0000E0000:<0001Q0P00Z00006`200010000
000P@[</8d8o0@00GP800040001<00000000000000000000oooooooooom@0000>@0000H0000R0000
30000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H00006P000140000=0`00
S0400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000100002L0000H0000
20000000003oool0000002D0000<0000200002H0000L00002P0000000001000000000000000U0000
300000X0000[0000600003d1002P0P00B@400:h2000U0000300000@0000X0000300000P0000U0000
30000080000X0000300000X0000Q0000200001h0000H0000@0400:4200170@00[P8002D0000<0000
2@0002D0000<00002@0001@0000<00003@000180000<00000@0005@0001D0000Y0000:D2002Y0000
/@80004000000212/b`S@T01002Q0P000@0004`00000000000000000003ooooooooooe00000f0000
1P000280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J0000
4@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000040000
9`0001P0000:000000000?ooo`0000009@0000`0000:00009P0001`0000800000000004000000000
000002D0000<0000200002/0000H0000>`4000`2001A0@006@8002D0000<0000100002P0000<0000
2P0002D0000<00000P0002P0000<000020000240000800007P0001P0000n0@003@8004l1000I0P00
9@0000`0000900009@0000`000090000500000`0000=00004P0000`000010000E00005P0002R0000
3P800:d0000I0P000@00000084:c;2=2?P4000d200020000C00000000000000000000?oooooooooo
D0000340<P0600001P000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000400009`0001P00008000000000?ooo`0000009@0000`0000800009P0001`0000:0000
0000004000000000000002D0000<00002P0002/0000H0000h00000d2003e00006@8002D0000<0000
100002P0000<0000200002D0000<00000P0002P0000<00002P000240000800007P0001P0003S0000
3P800?<0000I0P009@0000`0000900009@0000`000090000500000`0000=00004P0000`000010000
E00005P0001700003`800580000I0P000@00000084:c;2=2h`0000h200020000C000000000000000
00000?ooooooooooD0000340<`0600001P000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P0000:000000000?ooo`0000009@0000`0000:0000
9P0001`0000800000000004000000000000002D0000<0000200002/0000H0000C`8000T2001U0P00
5P8002D0000<0000100002P0000<00002P0002D0000<00000P0002P0000<00002000024000080000
7P0001P0001B0P002P8006<2000F0P009@0000`0000900009@0000`000090000500000`0000=0000
4P0000`000010000E00005P0002f0@002`800<41000F0P000@00000084:c;2=2DP8000X200020000
C00000000000000000000?ooooooooooD0000340<@0600001P000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009P0001`0000800000000004000000000
000002D0000<0000200002D0000<00001@00P5L0000T00004P000>D1003D0@00iP400080002^0>H1
L0;U0BD0000<00000P0002P0000<0000200002D0000<0000100002H0000L00002000000000010000
00000000000U0000300000P0000U0000300000D0081G0000900007H1000Q0P00MP4004X200020000
4P980Q827`8U0000300000P0080X0000300000P0000W0000600000P00000000000000000000U0000
300000P0001F0000:0000741000I0P00O04002@200030000608R0Q82608=0R829@0000`000020000
9@0000`000040000:00000`0000800009P0001`0000800000000004000000000000002D0000<0000
200002D0000<00001@00P5L0000T0000M04007@2001d0@00T`800080000@0Xl2409a0RD0000<0000
2000P2P0000<0000200002L0000H00002000000000000000000002D0000<0000200005H0000X0000
K`4006d2001j0@00M`8000<0000F0W@2409Z0P/2M08U000030000080000U0000300000@0000X0000
300000P0000V0000700000P0000000000@000000000000009@0000`0000800009@0000`000050020
E`0002@0000n0@00^P8003h1003F0P000P000=X1d@;J0KD29@0000`000080020:00000`000080000
9`0001P00008000000000000000000009@0000`000080000EP0002P0000i0@00/P8004@1002m0P00
0`000>01^0;J0Jh2e@6h0RD0000<00000P0002D0000<0000100002P0000<0000200002H0000L0000
200000000001000000000000000U0000300000P0000U0000300000D0081G0000900007<1002j0P00
L`400=H2000200003`;A0Pl2]@8U0000300000P0080X0000300000P0000W0000600000P000000000
00000000000U0000300000P0001F0000:00006h1002b0P00N@400;d2000300005@:h0Q02[P8:0[P2
9@0000`0000200009@0000`000040000:00000`0000800009P0001`0000800000000004000000000
000002D0000<0000200002D0000<00001@00P5L0000T0000[0400;X2002/0@00eP80008000180]42
B0:e0RD0000<00002000P2P0000<0000200002L0000H00002000000000000000000002D0000<0000
200005H0000X0000Y`400;82002b0@00_@8000<0001>0[P2B0:^0T<2^08U000030000080000U0000
300000@0000X0000300000P0000W0000600000P000000000oooo0000000U0000300000P0000V0000
700000X0000000000@000000003oool09@0000`0000:0000:`0001P0000I0@00a04003X1003J0@00
9@0000`000040000:00000`0000800009@0000`000020000:00000`0000:00008@0000P0000N0000
600001`100350@00>0400=X1000U0000300000D0000U0000300000<0000U0000300000D0000U0000
300000<0000U0000300000D0000D0000300000d0000B000030000040001D0000E000080000370@00
QP000=H100010000000P@[</8d8L0@00a`400040001<00000000000000000000oooooooooom@0000
L`0000L0000U0000300000<0001D0000E00008H0003=0@00R@000=P100010000000P@[</8d8S0@00
c@400040001<00000000000000000000oooooooooom@0000M00000<0000R000030000?oooolQ0000
200001T0000<0000oooo01P0000<0000000001h0000H00006P000140000=0`00S0400280000<0000
oooooaP0000<0000000001T0000<0000oooo02D0000<0000100002H0000L00002P00000000010000
00000000000U0000300000X0000W0000600000P000000000oooo0000000U0000300000P0001F0000
>00006h0002k0@00N@000>@1000700002P750@d1a@4=0N@14P7T0A81a@4E0LD13`6k0BD0000<0000
0P0002P0000<00002P0002D0000<0000100002P0000<0000200002D0000<00002000P2L0000H0000
20000000003oool0000002D0000<0000200005H0000h0000004006l1000?0@00i@4000L0002L0LP1
X0780J01L@6W0G41Y`780J/1b06S0ND19@0000`0000200009@0000`000040000:00000`000080000
9@0000`0000800209`0001P00008000000000000000000009@0000`0000800004`0000`000020000
EP0004`000000@00b04000@1003<0@00300009`1b06L0LP1W0780I`1c06M0L`1W@7<0Id1b06L0LP1
W0790J01b@6P0LP1X0780EH0000d000010400<4100050@00a@4000H0002P0LD1X0750J41a@6Q0L41
X0710J01`@5F0000=00000@1002j0@001@400;h100060000X06n0J01_P6Q0Kh1X@6j0J01^P6P0KX1
EP0003@000040@00/P4000D1002g0@001P000:01]`6P0KL1X@6g0J41/`6P0K<1X06c0EH0000d0000
10400:/100050@00[`4000H0002P0K01X06`0J41/06Q0J`1X06/0J01[05F0000=00000@1002T0@00
1@400:P100060000X06Y0J01Z@6Q0JT1X@6U0J01Y@6P0JD1EP0003@000040@00W@4000D1002Q0@00
1P000:01XP6P0J81X@6R0J41WP6P0Ih1X06N0EH0000d0000104009H100050@00VP4000H0002P0I/1
X06K0J41V`6Q0IL1X06G0J01U`5F0000=00000@1002?0@001@4009<100060000X06D0J01U06Q0I@1
X@6@0J01T06P0I01EP0003@000040@00R04000D1002<0@001P000:01S@6P0Hd1X@6=0J41R@6P0HT1
X0690EH0000d00001040084100050@00Q@4000H0002P0HH1X0660J41QP6Q0H81X0620J01PP5F0000
=00000@1001i0@001@4007d100060000X05o0J01O`6Q0Gl1X@5k0J01N`6P0G/1EP0003@000040@00
LP4000D1001f0@001P000:01N06P0GP1X@5h0J41M06P0G@1X05d0EH0000d0000104006l100080@00
L04000H0002P0G41X05a0J01LP6T0G81Y05a0J@1L@5F0000=00000/1001_0@00304007<100060000
Z05a0JL1L@6W0G41Y`5e0JL1M@6X0GD1EP0003@0000;0@00M@4000`1001j0@001P000:P1N06W0GL1
Y`5h0JL1O06W0G`1Z05l0EH0000d00002`4007`1000<0@00PP4000H0002X0Gl1Y`5n0JL1O`6W0H<1
Y`630JP1P`5F0000=00000/100240@00304008T100060000Z0660JL1Q@6W0HH1Y`6:0JL1RP6X0HX1
EP0003@0000;0@00R`4000`1002@0@001P000:P1S@6W0H`1Y`6=0JL1T@6W0I41Z06A0EH0000d0000
2`400981000<0@00U`4000H0002X0I@1Y`6C0JL1U06W0IP1Y`6H0JP1V05F0000=00000/1002I0@00
304009h100060000Z06K0JL1VP6W0I/1Y`6O0JL1W`6X0Il1EP0003@0000;0@00X04000`1002U0@00
1P000:P1XP6W0J41Y`6R0JL1YP6W0JH1Z06V0EH0000d00002`400:L1000<0@00[04000H0002X0JT1
Y`6X0JL1Z@6W0Jd1Y`6]0JP1[@5F0000=00000/1002^0@0030400;<100060000Z06`0JL1[`6W0K01
Y`6d0JL1]06X0K@1EP0003@0000;0@00]P4000`1002k0@001P000:P1]`6W0KH1Y`6g0JL1^`6W0K/1
Z06k0EH0000d00002`400;d1000<0@00`P4000H0002X0Kh1Y`6m0JL1_P6W0L81Y`720JP1`P5F0000
B00000/100340@0030400<T1000;0000Z0750JL1a06W0LD1Y`780JL1b@6X0LT1Z0780JP1b06W0LP1
Y`780JP1b05F0000=00000d100380@0040400<`100060000[0780J/1b06[0LP1Z@7<0JX1c06Z0L`1
EP0003@0000<0@00cP4000h1003C0@001P000:X1c`6Y0Lh1Z@7?0JP1d`6X0M<1Z@7C0EH0000d0000
2P400=D1000<0@00fP4000H0002X0MD1Y`7E0JL1e@6V0MT1YP7J0JL1f@5F0000=00000P1003L0@00
2P400>4100060000YP7L0JD1g06U0M`1Y07P0J@1h@6U0N01EP00050000060@00hP4000P1003U0@00
3@000:@1h`6T0N81X`7S0J<1i@6S0ND1Y07U0J<1h`6S0N<1XP7S0J<1i@6S0ND1X`7U0J@1i@5F0000
=00000@1003L0@001P400>4100060000X@7P0J81h@6R0N01X@7L0J41g06P0M`1EP0003@000030@00
e@4000D1003J0@001P000:01f@6P0MX1X@7I0J01eP6O0MD1W`7F0EH0000d00000@400<h100030@00
d`4000H0002N0M<1W`7C0Il1d`6N0Ll1WP7>0Id1c`4C000030000040000U000030000080000U0000
300000@0000X0000300000P0000V0000700000P0000000000@000000000000009@0000`000080000
9@0000`000050020E`0002@0001P0@00;`0009h1000_00000P000?`1=`0j0SL09@0000`000080020
:00000`0000800009`0001P00008000000000000000000009@0000`000080000EP0002P0002L0@00
:P000:H1000e00000`0003P2?@120SP0>08b02D0000<00000P0002D0000<0000100002P0000<0000
200002H0000L0000200000000001000000000000000U0000300000P0000U0000300000D0081G0000
<0000:4100330@00hP4000P200050000IP870Wh21`9n0]P1?@;H0Cd2``4U0000300000P0080X0000
300000P0000W0000600000P00000000000000000000U0000300000P0001F0000:00009`1002l0@00
Y`400<H100030000@`;60Ch2_04h0/H19@0000`0000200009@0000`000040000:00000`000080000
9P0001`0000800000000004000000000000002D0000<0000200002L0000H00002P000000003oool0
000002D0000<00002P0005H0001000002P4001/0000Y0@00>00000T000350CP0^`4_0;/1=02`0C@0
/04S0:H18`2V0C`0^`4l0;/1@00U000030000080000X0000300000P0000U0000300000@0000X0000
300000X0000V0000700000X0000000000@000000000000009@0000`0000:00009`0001P000080000
00000?ooo`0000009@0000`000080000EP0003P0003i00006`000101001C00001`0009D1C02K0D`0
V`4S0:H18`2V0D`0[05<0:01FP0U000030000080000X0000300000X0000U0000300000@0000X0000
300000P0000V0000700000P0000000000@000000000000009@0000`0000800009@0000`000050020
E`0002`0003;0@00MP0000D2002Z0@00100006L2O@2Q0Wd0X@:[0Fh2Z`4U0000300000P0080X0000
300000P0000W0000600000P00000000000000000000U0000300000P0001F0000:0000<X1002U0@00
e@400;0100030000L@:V0FH2[05a0[419@0000`0000200009@0000`000040000:00000`000080000
9`0001P00008000000000<30`00000009@0000`0000800009P0001`0000:00000000004000000000
000002D0000<00002P0002/0000H0000i`0009/1000j0@00^`4002D0000<0000100002P0000<0000
200002D0000<00000P0002P0000<00002P000240000800007P0001P0003Z0000W04003P1002k0@00
9@0000`0000600009@0000`000060000500000`0000=00004P0000`000010000E00009@0001B0000
XP4009/0002a0@000@00000084:c;2=2kP000:<1000<0000C00000000000000000000?oooooooooo
I0000480K`1T07T0801V06`0M@1Y06@0L`0P00T000080000200000L000040000100000@000080000
100000P00006000010000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000400009`0001P0000:000000000?ooo`0000009@0000`0000:00009P0001`000080000
0000004000000000oooo02D0000<0000200002/0000H0000TP4000T0002k0@008P0002D0000<0000
100002P0000<00002P0002D0000<00000P0002P0000<000020000240000800007P0001P0002F0@00
2P000;P1000R0000DP00070100080000l?ooo`000000000000000;`2000000001`008440LP1Y0640
K00000000000000000000000000000000000000000000000000000000000000000000000000001<0
Y4[;<=l>8@l8?Cd26`@006S>4`000000T1KdMaS?>`9>5_AgB0LE06XFm7O/3S0Q8<lk0R3?>`9X:C/2
J2Tk0P0000000000@P1_06@0N@0P06H0K01e06T0I01c0200YAo4MjDO0@0001D0[<dC0:DOa7NU7lAg
a?3mO`004`000000T1KdMc2U?09>5_Agf0LE06XFm7MjJKl7>:Dl0SRU?081800000000000002h??X6
1000020000000000YAo4MjDOa7NU7`40000E0:c=4`2U7lAgYAo4MlC`oGl0h?eo0000000000000000
00000<8ma7L20000I7H02000000U0000300000P0001B0000L04000X0003`oooo0000000000000000
T04000000007000P@@1b06T0H@1/0000000000000000000000000000000000000000000000000000
000000000000000000000000a7NU7`40000E0:c=4`2U7lAgYAo4MlC`oGl001<00000090Fm7L`YC`2
CQKdMmP75@1Z5_AgNVVo1cRU?08hYC`20B00000000000000^3cj1P@0000P000000000:DOa7NU7lAg
YAl100005@2/cA<0YAo4MjDOa7O4l?eo003mO`0000000000000000000032?LAg0P0006Af00P00000
>:Dl0P4P0000000000000;PlnPH4000080000000002U7lAgYAo4MjDO0@0001D0[<dC0:DOa7NU7lAg
a?3mO`3PoGl000000000000000000000`Sg4M`80001TMP08000002D0000<00002P000580001`0@00
2`000?3oool0000000000000002@0@000@0000L002110780J@1Q06`0000000000000000000000000
0000000000000000000000000000000000000000000000000034MjDO0@0001D0[<dC0:DOa7NU7lAg
a?3mO`00oGl000000000000000000000`Sg4M`80001TMP08000003RU?081800000000000002h??X6
1000020000000000YAo4MjDOa7NU7`40000E0:c=4`2U7lAgYAo4MlC`oGl00?eo0000000000000000
00000<8ma7L20000I7H02000000hYC`20B00000000000000^3cj1P@0000P000000000:DOa7NU7lAg
YAl100005@2/cA<0YAo4MjDOa7O4l?eo0>3mO`0000000000000000000032?LAg0P0006Af00P00000
9@0000`0000;00009@0000`0000:00009@0000`0000800009@0000`0000:00009@0000`000080000
500000`0000=00004P0000`000010000E00005@0003j00000P0000<1000D00000@00000084:c;2=2
UP4000/000010000C00000000000000000000?ooooooooooD0000680000:00009@0000`0000:0000
E00005@000040@000P0000P1000C00000@00000084:c;2=2X04000/000010000C000000000000000
00000?ooooooooooD00002P0000500009@0000`0000;0000E00005@000090@000@0000`1000C0000
0@00000084:c;2=2Y@4000X000010000C00000000000000000000?ooooooooooD00007@000040000
9@0000`0000:0000E00005@0000@0@000P0001@1000C00000@00000084:c;2=2[04000/000010000
C00000000000000000000?ooooooooooD00002T0000500008P0000`0003ooooo8@0000P0000I0000
30000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R000030000?oooolH0000
30000000000I000030000?ooo`0U0000300000@0000H000030000000000I000030000?ooo`0U0000
300000@0000R000030000?oooolU0000300000L0080U000030000000080`0000300000l0080U0000
300000d0081;00004000000000050000:00000`000020000:00000`000050000:00000`000040000
:00000`000030000:00000`000060000:00000`000070000:00000`000090000:00000`000080000
:00000`0000:0000:00000`0000;00009@0000`0000000209@0000`0000700208P0000`0003ooooo
9@0000`0000=0020:00000`0000100008P0000`0003ooooo8P0000`0003oooooAP0003P0000/0000
ADe6:bI0000@000010000000000Q@0L0300000000004@0003000000000160000500000P00017A4U3
0`0001P0000<0000000001T0000<0000oooo02D0000<00000000P2D0000<00003@00P280000<0000
ooooodH0000d0000:00004E=AR/Z@000900001P00000080o0000P0000800080o0000P000080Q0000
20000680000<00000@0004`0001T00002`00000000090P000P<000/000000000o`4000<3000Y0:X0
000000000000080o000000000000080o0000000000000000000000000000000000000000000R0000
30000?oooom60000700001000015CDH[0T0000`0000000003P0001@000000000400001@0
\>"], "Text",
  ImageSize->{384.875, 581.188},
  ImageMargins->{{0, 0}, {0, 63}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Function for solving the ICRP 66 model ", "Section"],

Cell[TextData[{
  "The package  included the specific functions used for evaluated the  \
contents in each compartment ot the respiratory tract and the lung retention \
",
  StyleBox["for persons exposed to inhalation ",
    CharacterEncoding->"WindowsANSI"],
  "of aerosols as function ",
  StyleBox["of the activity median aerodynamic diameter (AMAD).",
    CharacterEncoding->"WindowsANSI"]
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      RowBox[{
        StyleBox["RespiratoryTract",
          "Input"], 
        StyleBox["[",
          "Input"], 
        StyleBox[\(I\_0, \ IFD\ , \ FRA, \ t, \ \[Lambda], \ options\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["]",
          "Input"]}]]],
  " for one specific nuclide, gives the retention in compartments  of the \
respiratory tract (see fig.1) for  an intake",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(I\)\)\)]],
  " by inhalation. By default an acute intake is assumed. Other type of \
intake can be chosen with Options. For each type of intake mush be used a \
format for intake data input."
}], "DefinitionBox",
  CellTags->"Introduction"],

Cell[TextData[{
  Cell[BoxData[
      RowBox[{
        StyleBox["LungsRetention",
          "Input"], 
        StyleBox["[",
          "Input"], 
        StyleBox[\(I\_0, \ IFD\ , \ FRA, \ t, \ \[Lambda], \ options\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["]",
          "Input"]}]]],
  " for one specific nuclide, gives the retention in Lungs for  an intake",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(I\)\)\)]],
  " by inhalation. By default an acute intake is assumed. Other type of \
intake can be chosen with Options. For each type of intake mush be used a \
format for intake data input."
}], "DefinitionBox",
  CellTags->"Introduction"],

Cell[TextData[{
  " ",
  StyleBox["Intake", "Text",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`I\_0\)]],
  " for an Acute input (Bq);",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`I\_d\)]],
  " for a Constant input (Bq/day); ",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`{I(t), \ t}\)]],
  " for a continuous input; {",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["{",
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False,
            "StrikeThrough"->False,
            "Masked"->False,
            "CompatibilityType"->0,
            "RotationAngle"->0}], 
          RowBox[{
            StyleBox[\(I\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False,
              "StrikeThrough"->False,
              "Masked"->False,
              "CompatibilityType"->0,
              "RotationAngle"->0}], ",", " ", "0"}], "}"}], ",", " ", 
        RowBox[{"{", 
          StyleBox[\(I\_1, \[Tau]\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False,
            "StrikeThrough"->False,
            "Masked"->False,
            "CompatibilityType"->0,
            "RotationAngle"->0}], 
          StyleBox["}",
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False,
            "StrikeThrough"->False,
            "Masked"->False,
            "CompatibilityType"->0,
            "RotationAngle"->0}]}], 
        StyleBox[",",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["...",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox[",",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        RowBox[{
          StyleBox["{",
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False,
            "StrikeThrough"->False,
            "Masked"->False,
            "CompatibilityType"->0,
            "RotationAngle"->0}], 
          RowBox[{
            StyleBox[\(I\_n\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False,
              "StrikeThrough"->False,
              "Masked"->False,
              "CompatibilityType"->0,
              "RotationAngle"->0}], ",", " ", 
            StyleBox[\(\[Tau]\_n\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False,
              "StrikeThrough"->False,
              "Masked"->False,
              "CompatibilityType"->0,
              "RotationAngle"->0}]}], 
          StyleBox["}",
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False,
            "StrikeThrough"->False,
            "Masked"->False,
            "CompatibilityType"->0,
            "RotationAngle"->0}]}]}]]],
  "} for multi acute inputs (This option only works with LungsRetention. "
}], "SmallText",
  CellDingbat->None],

Cell[TextData[{
  " ",
  StyleBox["Intake type", "Text",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" ", "Text"],
  "can be chosen with Options: \n",
  StyleBox["IntakeType",
    FontFamily->"Courier New"],
  "\[Rule] \"Acute\" or  ",
  StyleBox["IntakeType",
    FontFamily->"Courier New"],
  "\[Rule]\"Constant\" or  ",
  StyleBox["IntakeType",
    FontFamily->"Courier New"],
  "\[Rule]\"Continuous\" or ",
  StyleBox["IntakeType",
    FontFamily->"Courier New"],
  "\[Rule]\"MultiInputs\"  ; by default it is applied an acute intake. \
\"Constant\" means a daily chronic intake ",
  Cell[BoxData[
      \(I\_d\)]],
  " ;  \"Continuous\" mean a daily continuous intake  ",
  Cell[BoxData[
      \(TraditionalForm\`I(t)\)]],
  ";   \"MultiInputs\" means multiple single intakes {",
  Cell[BoxData[
      \(I\_0\)]],
  ", ..., ",
  Cell[BoxData[
      \(I\_n\)]],
  "} at time 0<",
  Cell[BoxData[
      \(\[Tau]\_1\)]],
  "< ...<",
  Cell[BoxData[
      \(\[Tau]\_n\)]],
  ", in this case  the function give he retention in Lungs  after the last \
intake ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{
          StyleBox[\(I\_n\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False,
            "StrikeThrough"->False,
            "Masked"->False,
            "CompatibilityType"->0,
            "RotationAngle"->0}], ",", " ", 
          StyleBox[\(\[Tau]\_n\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False,
            "StrikeThrough"->False,
            "Masked"->False,
            "CompatibilityType"->0,
            "RotationAngle"->0}]}], 
        StyleBox["}",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}]}]]],
  ". "
}], "SmallText",
  CellDingbat->None],

Cell[TextData[{
  StyleBox["IFD",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[": Initial fractional  deposition values ",
    FontSlant->"Italic"],
  StyleBox["as function of AMAD",
    FontVariations->{"CompatibilityType"->0}],
  ".- It can be directly written the values with this pattern { ",
  Cell[BoxData[
      \(AI\)]],
  ", ",
  Cell[BoxData[
      \(bb\_\(fast + seq\)\)]],
  ", ",
  Cell[BoxData[
      \(\(\(bb\_slow\)\(,\)\)\)]],
  " ",
  Cell[BoxData[
      \(BB\_\(fast + seq\)\)]],
  " ",
  Cell[BoxData[
      \(\(\(,\)\(\ \)\(BB\_slow\)\(,\)\(\ \)\)\)]],
  " ",
  Cell[BoxData[
      \(ET\_2, \ ET\_1\)]],
  "} (i.e: {0.12, 0.011, 0.011, 0.0039, 0.004, 0.11, 0.089} or choosing the \
AMADAdultW[x] for workers,  AMADAdultW[x] for adult member of the public, \
AMADyr1[x] for clidren 1 yr old,  AMADyr10[x]  for clidren 10 yr old, where x \
is the AMAD\nRecommended fractional  deposition values for other reference \
subjects and AMADs can be obtained from Annex F of ICRP 66."
}], "SmallText",
  CellDingbat->None],

Cell[TextData[{
  StyleBox["FRA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[": Fractional rate of absorption.- It can be chose F, M, or S (the \
table 1 values are applied) or writting directely the ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`{s\_p, \ s\_pt, \ s\_t}\)]],
  StyleBox[" values. ",
    FontSlant->"Italic"]
}], "SmallText",
  CellDingbat->None],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " always in days. "
}], "SmallText",
  CellDingbat->None],

Cell[TextData[{
  "\[Lambda]: Radioactive Decay constant in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(day\)\(\ \)\)\^\(-1\)\)]]
}], "SmallText",
  CellDingbat->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples ", "Section",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell["Example 1", "Subsubsection",
  CellTags->"Examples"],

Cell["\<\
The  retention in the Respiratory tract compartments supposing  a single \
intake 1 Bq   of aerosols type S and AMAD = 5 \[Mu]m  in t = 0 with lambda \
\[Rule] 0 for reference workers is obtained that follows\
\>", "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["RespiratoryTract",
        "Input"], "[", \(1, AMADAdultW[5], S, \ t, 0\), "]"}]], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \({q\_ET1[t] \[Rule] 0.3386996`\ \[ExponentialE]\^\(-t\), 
      q\_AI[t] \[Rule] 
        0.00001592483439044265`\ \[ExponentialE]\^\(\(-100.11999999999999`\)\ \
t\) + 0.0000318496687808853`\ \[ExponentialE]\^\(\(-100.101`\)\ t\) + 
          5.308278130147261`*^-6\ \[ExponentialE]\^\(\(-100.10012`\)\ t\) + 
          0.015940775165609558`\ \[ExponentialE]\^\(\(-0.0201`\)\ t\) + 
          0.031881550331219116`\ \[ExponentialE]\^\(\(-0.0011`\)\ t\) + 
          0.005313591721869853`\ \[ExponentialE]\^\(\(-0.00022`\)\ t\), 
      q\_bb1[t] \[Rule] 
        6.378825063484139`*^-6\ \[ExponentialE]\^\(\(-102.1`\)\ t\) + 
          1.608569130347507`*^-7\ \[ExponentialE]\^\(\(-100.11999999999999`\)\
\ t\) + 1.5932800790831997`*^-8\ \[ExponentialE]\^\(\(-100.101`\)\ t\) + 
          2.6542983229730416`*^-10\ \[ExponentialE]\^\(\(-100.10012`\)\ t\) + 
          0.006385210273758899`\ \[ExponentialE]\^\(\(-2.0001`\)\ t\) + 
          0.00016101793096575314`\ \[ExponentialE]\^\(\(-0.0201`\)\ t\) + 
          0.00001594874954037975`\ \[ExponentialE]\^\(\(-0.0011`\)\ t\) + 
          2.6569552782516216`*^-7\ \[ExponentialE]\^\(\(-0.00022`\)\ t\), 
      q\_bb2[t] \[Rule] 
        4.375245130114162`*^-6\ \[ExponentialE]\^\(\(-100.13`\)\ t\) + 
          0.004379624754869886`\ \[ExponentialE]\^\(\(-0.0301`\)\ t\), 
      q\_bbseq[t] \[Rule] 
        7.70572783089738`*^-8\ \[ExponentialE]\^\(\(-100.11`\)\ t\) + 
          0.00007713441272169102`\ \[ExponentialE]\^\(\(-0.0101`\)\ t\), 
      q\_BB1[t] \[Rule] 
        0.000010043280629059431`\ \[ExponentialE]\^\(\(-110.1`\)\ t\) + 
          1.5947062658710348`*^-6\ \[ExponentialE]\^\(\(-102.1`\)\ t\) + 
          1.316523108359444`*^-8\ \[ExponentialE]\^\(\(-100.13`\)\ t\) + 
          3.223585431558597`*^-8\ \[ExponentialE]\^\(\(-100.11999999999999`\)\
\ t\) + 3.186878846052369`*^-9\ \[ExponentialE]\^\(\(-100.101`\)\ t\) + 
          5.308660349870766`*^-11\ \[ExponentialE]\^\(\(-100.10012`\)\ t\) + 
          0.010053333963025171`\ \[ExponentialE]\^\(\(-10.0001`\)\ t\) + 
          0.0015963025684397247`\ \[ExponentialE]\^\(\(-2.0001`\)\ t\) + 
          0.000013178409493088923`\ \[ExponentialE]\^\(\(-0.0301`\)\ t\) + 
          0.000032268122438026674`\ \[ExponentialE]\^\(\(-0.0201`\)\ t\) + 
          3.1900689149674457`*^-6\ \[ExponentialE]\^\(\(-0.0011`\)\ t\) + 
          5.313974324195133`*^-8\ \[ExponentialE]\^\(\(-0.00022`\)\ t\), 
      q\_BB2[t] \[Rule] 
        5.90917573344181`*^-6\ \[ExponentialE]\^\(\(-100.13`\)\ t\) + 
          0.005915090824266558`\ \[ExponentialE]\^\(\(-0.0301`\)\ t\), 
      q\_BBseq[t] \[Rule] 
        1.240388980408222`*^-7\ \[ExponentialE]\^\(\(-100.11`\)\ t\) + 
          0.00012416306110195918`\ \[ExponentialE]\^\(\(-0.0101`\)\ t\), 
      q\_LNth[t] \[Rule] \(-2.0109617634983664`*^-7\)\ \
\[ExponentialE]\^\(\(-100.11`\)\ t\) - 
          8.847130216915354`*^-7\ \[ExponentialE]\^\(\(-100.10012`\)\ t\) + 
          1.0858091980412094`*^-6\ \[ExponentialE]\^\(\(-100.1`\)\ t\) - 
          0.00020129747382365018`\ \[ExponentialE]\^\(\(-0.0101`\)\ t\) - 
          0.0008855986203116422`\ \[ExponentialE]\^\(\(-0.00022`\)\ t\) + 
          0.0010868960941352924`\ \[ExponentialE]\^\(\(-0.0001`\)\ t\), 
      q\_ET2[t] \[Rule] 
        0.0003966190593791552`\ \[ExponentialE]\^\(\(-200.1`\)\ t\) + 
          1.115920069896456`*^-6\ \[ExponentialE]\^\(\(-110.1`\)\ t\) + 
          1.62725129168248`*^-7\ \[ExponentialE]\^\(\(-102.1`\)\ t\) + 
          3.090202889150656`*^-9\ \[ExponentialE]\^\(\(-100.13`\)\ t\) + 
          3.2242302777305`*^-9\ \[ExponentialE]\^\(\(-100.11999999999999`\)\ \
t\) + 3.1869107152511164`*^-10\ \[ExponentialE]\^\(\(-100.101`\)\ t\) + 
          5.308666721005103`*^-12\ \[ExponentialE]\^\(\(-100.10012`\)\ t\) + 
          0.39701607545481515`\ \[ExponentialE]\^\(\(-100.0001`\)\ t\) + 
          0.0011170371070027966`\ \[ExponentialE]\^\(\(-10.0001`\)\ t\) + 
          0.00016288801718772702`\ \[ExponentialE]\^\(\(-2.0001`\)\ t\) + 
          3.093296185444493`*^-6\ \[ExponentialE]\^\(\(-0.0301`\)\ t\) + 
          3.2274577353497375`*^-6\ \[ExponentialE]\^\(\(-0.0201`\)\ t\) + 
          3.190100815975606`*^-7\ \[ExponentialE]\^\(\(-0.0011`\)\ t\) + 
          5.313980700971974`*^-9\ \[ExponentialE]\^\(\(-0.00022`\)\ t\), 
      q\_ETseq[t] \[Rule] 
        1.9905169735425876`*^-7\ \[ExponentialE]\^\(\(-100.101`\)\ t\) + 
          0.00019925094830262376`\ \[ExponentialE]\^\(\(-0.0011`\)\ t\), 
      q\_LNet[t] \[Rule] \(-1.9905169735434007`*^-7\)\ \
\[ExponentialE]\^\(\(-100.101`\)\ t\) + 
          1.9905169735428586`*^-7\ \[ExponentialE]\^\(\(-100.1`\)\ t\) - 
          0.00019925094830262376`\ \[ExponentialE]\^\(\(-0.0011`\)\ t\) + 
          0.0001992509483026237`\ \[ExponentialE]\^\(\(-0.0001`\)\ t\)}\)], \
"Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell[" Default parameters can be modified ", "MathCaption"],

Cell[CellGroupData[{

Cell["\<\
LungsRetention[A, {AI, 0.006, 0.004, 0.01, 0.005, 0.3, 0.5}, S, t, \
Log[2]/100, AI1 -> 0.2*AI, Subscript[k, \"bb2,BB1\"] -> 0.05]\
\>", "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(8.375639833795023`*^-6\ 2\^\(\(-t\)/100\)\ A\ \
\[ExponentialE]\^\(\(-110.1`\)\ t\) + 
      1.6522149597360367`*^-7\ 2\^\(\(-t\)/100\)\ A\ AI\ \
\[ExponentialE]\^\(\(-110.1`\)\ t\) + 
      7.3976972004945185`*^-6\ 2\^\(\(-t\)/100\)\ A\ \
\[ExponentialE]\^\(\(-102.1`\)\ t\) - 
      4.160990610320783`*^-6\ 2\^\(\(-t\)/100\)\ A\ AI\ \
\[ExponentialE]\^\(\(-102.1`\)\ t\) + 
      4.012072341740523`*^-6\ 2\^\(\(-t\)/100\)\ A\ \
\[ExponentialE]\^\(\(-100.14999999999999`\)\ t\) + 
      4.990014975039293`*^-6\ 2\^\(\(-t\)/100\)\ A\ \
\[ExponentialE]\^\(\(-100.13`\)\ t\) + 
      0.0003030312124272516`\ 2\^\(\(-t\)/100\)\ A\ AI\ \
\[ExponentialE]\^\(\(-100.11999999999999`\)\ t\) + 
      0.`\ 2\^\(\(-t\)/100\)\ A\ \[ExponentialE]\^\(\(-100.11`\)\ t\) + 
      0.0005991612638047705`\ 2\^\(\(-t\)/100\)\ A\ AI\ \
\[ExponentialE]\^\(\(-100.101`\)\ t\) + 
      0.00008317290463989713`\ 2\^\(\(-t\)/100\)\ A\ AI\ \
\[ExponentialE]\^\(\(-100.10012`\)\ t\) + 
      1.7465052412634925`*^-7\ 2\^\(\(-t\)/100\)\ A\ \
\[ExponentialE]\^\(\(-100.1`\)\ t\) + 
      0.000016633383250131556`\ 2\^\(\(-t\)/100\)\ A\ AI\ \[ExponentialE]\^\(\
\(-100.1`\)\ t\) + 
      0.008384023857653642`\ 2\^\(\(-t\)/100\)\ A\ \
\[ExponentialE]\^\(\(-10.0001`\)\ t\) + 
      0.0001653868828564822`\ 2\^\(\(-t\)/100\)\ A\ AI\ \
\[ExponentialE]\^\(\(-10.0001`\)\ t\) + 
      0.0074051023027995036`\ 2\^\(\(-t\)/100\)\ A\ \
\[ExponentialE]\^\(\(-2.0001`\)\ t\) - 
      0.004165155766087867`\ 2\^\(\(-t\)/100\)\ A\ AI\ \
\[ExponentialE]\^\(\(-2.0001`\)\ t\) + 
      0.004016088430170823`\ 2\^\(\(-t\)/100\)\ A\ \
\[ExponentialE]\^\(\(-0.050100000000000006`\)\ t\) + 
      0.004995009985024961`\ 2\^\(\(-t\)/100\)\ A\ \
\[ExponentialE]\^\(\(-0.0301`\)\ t\) + 
      0.30333454697424916`\ 2\^\(\(-t\)/100\)\ A\ AI\ \
\[ExponentialE]\^\(\(-0.0201`\)\ t\) + 
      0.`\ 2\^\(\(-t\)/100\)\ A\ \[ExponentialE]\^\(\(-0.0101`\)\ t\) + 
      0.599761024829842`\ 2\^\(\(-t\)/100\)\ A\ AI\ \
\[ExponentialE]\^\(\(-0.0011`\)\ t\) + 
      0.08325616080071588`\ 2\^\(\(-t\)/100\)\ A\ AI\ \
\[ExponentialE]\^\(\(-0.00022`\)\ t\) + 
      0.00017482534947587362`\ 2\^\(\(-t\)/100\)\ A\ \
\[ExponentialE]\^\(\(-0.0001`\)\ t\) + 
      0.016650033283416535`\ 2\^\(\(-t\)/100\)\ A\ AI\ \
\[ExponentialE]\^\(\(-0.0001`\)\ t\)\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2", "Subsubsection",
  CellTags->"Examples"],

Cell[TextData[{
  "Not only single intakes  can be calculated. For instance, if we to \
estimate the retention of the lungs   for an daily constant intake (AMAD 5 \
\[Mu]m and S, and \[Lambda]=0) with ",
  Cell[BoxData[
      \(TraditionalForm\`I\_c\)]],
  "= 0.3 Bq/day, the first step is to evaluate the retention for an acute \
unit intake  ",
  Cell[BoxData[
      \(TraditionalForm\`I\_0\)]],
  "= 1 in ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  "=0. Now it can be calculated for a constant intake  ",
  Cell[BoxData[
      \(TraditionalForm\`I\_c\)]],
  "= 0.3 Bq/day."
}], "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell["\<\
LungsRetention[0.3, AMADAdultW[5], S, t, 0, IntakeType -> \"Constant\"]\
\>", "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(\(\(18.344525793741155`\)\(\[InvisibleSpace]\)\) - 
      2.73658872726415`*^-8\ \[ExponentialE]\^\(\(-110.1`\)\ t\) - 
      2.3428593524055162`*^-8\ \[ExponentialE]\^\(\(-102.1`\)\ t\) - 
      3.085264983912681`*^-8\ \[ExponentialE]\^\(\(-100.13`\)\ t\) - 
      4.8295826481595195`*^-8\ \[ExponentialE]\^\(\(-100.11999999999999`\)\ t\
\) - 9.550990038218429`*^-8\ \[ExponentialE]\^\(\(-100.101`\)\ t\) - 
      1.3258376588035858`*^-8\ \[ExponentialE]\^\(\(-100.10012`\)\ t\) - 
      3.254173420702925`*^-9\ \[ExponentialE]\^\(\(-100.1`\)\ t\) - 
      0.0003015970029207259`\ \[ExponentialE]\^\(\(-10.0001`\)\ t\) - 
      0.0011971670679763945`\ \[ExponentialE]\^\(\(-2.0001`\)\ t\) - 
      0.10273648493650696`\ \[ExponentialE]\^\(\(-0.0301`\)\ t\) - 
      0.2408068838658707`\ \[ExponentialE]\^\(\(-0.0201`\)\ t\) - 
      8.700187949911216`\ \[ExponentialE]\^\(\(-0.0011`\)\ t\) - 
      6.038607186585378`\ \[ExponentialE]\^\(\(-0.00022`\)\ t\) - 
      3.260688282405877`\ \[ExponentialE]\^\(\(-0.0001`\)\ t\)\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell[TextData[{
  "We can supposed other kinds of intakes: continuous ",
  Cell[BoxData[
      \(TraditionalForm\`I(t)\)]],
  " or multiple single intakes "
}], "Text"],

Cell[TextData[{
  " Here it assumed a periodic (",
  Cell[BoxData[
      \(TraditionalForm\`I(t)\ \  = \ 0.3 + 0.3\ Cos[t]\)]],
  ") intake. "
}], "MathCaption"],

Cell[CellGroupData[{

Cell["\<\
LungsRetention[{0.3 + 0.3*Cos[t], t}, AMADAdultW[5], S, t, 0, IntakeType -> \
\"Continuous\"]\
\>", "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(\(\(18.344525793741155`\)\(\[InvisibleSpace]\)\) - 
      5.4729517194404586`*^-8\ \[ExponentialE]\^\(\(-110.1`\)\ t\) - 
      4.68549397893911`*^-8\ \[ExponentialE]\^\(\(-102.1`\)\ t\) - 
      6.170222272624019`*^-8\ \[ExponentialE]\^\(\(-100.13`\)\ t\) - 
      9.65868354313092`*^-8\ \[ExponentialE]\^\(\(-100.11999999999999`\)\ t\) \
- 1.9101026998929587`*^-7\ \[ExponentialE]\^\(\(-100.101`\)\ t\) - 
      2.651543012132943`*^-8\ \[ExponentialE]\^\(\(-100.10012`\)\ t\) - 
      6.50802210633217`*^-9\ \[ExponentialE]\^\(\(-100.1`\)\ t\) - 
      0.0006002079560316375`\ \[ExponentialE]\^\(\(-10.0001`\)\ t\) - 
      0.002154919875977137`\ \[ExponentialE]\^\(\(-2.0001`\)\ t\) - 
      0.10282948096389351`\ \[ExponentialE]\^\(\(-0.0301`\)\ t\) - 
      0.24090413296541266`\ \[ExponentialE]\^\(\(-0.0201`\)\ t\) - 
      8.700198477125898`\ \[ExponentialE]\^\(\(-0.0011`\)\ t\) - 
      6.038607478853952`\ \[ExponentialE]\^\(\(-0.00022`\)\ t\) - 
      3.2606883150127595`\ \[ExponentialE]\^\(\(-0.0001`\)\ t\) + 
      0.0014577029200076464`\ Cos[t] + 
      0.019661305794627937`\ Sin[t]\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell["\<\
 Here are assumed multiples intake: 3 Bq the at the beginning, that is \[Tau] \
= 0, follow 5 Bq the third day {\[Tau] = 3}, 6  Bq at \[Tau] =5. Then the \
lung retention starting when ceased the intake will be:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell["\<\
LungsRetention[{{3, 0}, {5, 3}, {6, 5}}, AMADAdultW[5], S, t1, 0, IntakeType \
-> \"MultiInputs\"]\
\>", "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \(0.00006025968377435659`\ \[ExponentialE]\^\(\(-110.1`\)\ t1\) + 
      0.000047841187976120636`\ \[ExponentialE]\^\(\(-102.1`\)\ t1\) + 
      0.00006178551656783535`\ \[ExponentialE]\^\(\(-100.13`\)\ t1\) + 
      0.0000967075629467462`\ \[ExponentialE]\^\(\(-100.11999999999999`\)\ t1\
\) - 4.87890977618477`*^-19\ \[ExponentialE]\^\(\(-100.11`\)\ t1\) + 
      0.0001912127307631406`\ \[ExponentialE]\^\(\(-100.101`\)\ t1\) + 
      0.0000265433017493516`\ \[ExponentialE]\^\(\(-100.10012`\)\ t1\) + 
      6.514855188247256`*^-6\ \[ExponentialE]\^\(\(-100.1`\)\ t1\) + 
      0.06032000388173764`\ \[ExponentialE]\^\(\(-10.0001`\)\ t1\) + 
      0.048620949953282915`\ \[ExponentialE]\^\(\(-2.0001`\)\ t1\) + 
      0.13697865709077264`\ \[ExponentialE]\^\(\(-0.0301`\)\ t1\) + 
      0.2180702598855114`\ \[ExponentialE]\^\(\(-0.0201`\)\ t1\) + 
      3.727561621969548`*^-19\ \[ExponentialE]\^\(\(-0.0101`\)\ t1\) + 
      0.44573420970293176`\ \[ExponentialE]\^\(\(-0.0011`\)\ t1\) + 
      0.061972021577385926`\ \[ExponentialE]\^\(\(-0.00022`\)\ t1\) + 
      0.015213828593859231`\ \[ExponentialE]\^\(\(-0.0001`\)\ t1\)\)], \
"Output",
  CellLabel->"Out[12]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 3", "Subsubsection",
  CellTags->"Examples"],

Cell["\<\
Here it is represented the lung retention as function of t and AMAD \
\>", "Text"],

Cell[BoxData[
    \(lung[{ai_, bbf_, \ bbs_, \ BBf_, \ BBs_, \ et2_, \ et1_}, \ t_\ ] = 
      LungsRetention[1, {ai, bbf, \ bbs, \ BBf, \ BBs, \ et2, \ et1}\ , S, \ 
        t, 0]; \)], "Input",
  CellLabel->"In[13]:="],

Cell["modelAMAD[inp_, p_, t1_]:= inp lung[AMADfit[p] ,t1]  ", "Input",
  CellLabel->"In[14]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[modelAMAD[1, p, t], \ {p, \ 2, \ 10}, \ {t, \ 0, \ 1000}, 
      ViewPoint -> {\(-1.7\), \ \(-0.5\), \ 1}, Mesh \[Rule] False, 
      FaceGrids \[Rule] All, 
      AxesLabel \[Rule] {"\<AMAD\>", "\<time, in days \>", "\<IRF\>"}]\)], \
"Input",
  CellLabel->"In[15]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75332 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.4962e-016 1.15228 -0.117597 1.15228 [
[-0.003 .47984 -3.63853 0 ]
[-0.003 .47984 2.36147 9 ]
[.12082 .57621 -3.48484 0 ]
[.12082 .57621 2.51516 9 ]
[.21949 .653 -3.36969 0 ]
[.21949 .653 2.63031 9 ]
[.29998 .71563 -3.2802 0 ]
[.29998 .71563 2.7198 9 ]
[.36688 .76769 -6.41729 0 ]
[.36688 .76769 5.58271 9 ]
[.21069 .72448 -15.8305 0 ]
[.21069 .72448 12.357 12.5 ]
[.89804 -0.01426 -3.43365 -9 ]
[.89804 -0.01426 2.56635 0 ]
[.71146 .02509 -9.53741 -9 ]
[.71146 .02509 8.46259 0 ]
[.53571 .06224 -8.84203 -9 ]
[.53571 .06224 9.15797 0 ]
[.36985 .09737 -8.20608 -9 ]
[.36985 .09737 9.79392 0 ]
[.21307 .13063 -7.62226 -9 ]
[.21307 .13063 10.3777 0 ]
[.06462 .16216 -9.44589 -9 ]
[.06462 .16216 14.5541 0 ]
[.45546 .00814 -41.6392 -12.5 ]
[.45546 .00814 46.3608 0 ]
[.91515 .00366 0 -5.441 ]
[.91515 .00366 6 3.559 ]
[.9264 .0814 0 -5.38377 ]
[.9264 .0814 24 3.61623 ]
[.93845 .1647 0 -5.32268 ]
[.93845 .1647 24 3.67732 ]
[.95139 .25418 0 -5.25731 ]
[.95139 .25418 24 3.74269 ]
[1.00638 .13164 0 -7.41284 ]
[1.00638 .13164 22 5.08716 ]
[ 0 0 0 0 ]
[ 1 .75332 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .46575 m
.36788 .75332 L
s
0 .46575 m
.0015 .45871 L
s
[(2)] -0.003 .47984 .21284 -1 Mshowa
.12312 .56199 m
.12427 .55488 L
s
[(4)] .12082 .57621 .16161 -1 Mshowa
.22126 .63871 m
.22214 .63156 L
s
[(6)] .21949 .653 .12323 -1 Mshowa
.30132 .70129 m
.30199 .69412 L
s
[(8)] .29998 .71563 .0934 -1 Mshowa
.36788 .75332 m
.36838 .74614 L
s
[(10)] .36688 .76769 .06955 -1 Mshowa
.125 Mabswid
.03363 .49204 m
.03447 .4878 L
s
.06524 .51675 m
.06603 .5125 L
s
.09502 .54003 m
.09576 .53577 L
s
.14967 .58275 m
.15032 .57848 L
s
.17481 .6024 m
.17541 .59812 L
s
.19864 .62103 m
.1992 .61674 L
s
.24276 .65551 m
.24325 .65122 L
s
.26322 .67151 m
.26368 .66721 L
s
.28272 .68675 m
.28315 .68245 L
s
.31909 .71518 m
.31946 .71087 L
s
.33607 .72845 m
.33642 .72415 L
s
.35232 .74116 m
.35264 .73685 L
s
gsave
.21069 .72448 -76.8305 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(AMAD) show
87.188 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.9001 0 m
.06162 .17625 L
s
.9001 0 m
.90113 .00713 L
s
[(0)] .89804 -0.01426 .14455 1 Mshowa
.71232 .03947 m
.71275 .04666 L
s
[(200)] .71146 .02509 .05971 1 Mshowa
.53546 .07665 m
.53533 .08385 L
s
[(400)] .53571 .06224 -0.01755 1 Mshowa
.36859 .11172 m
.36796 .1189 L
s
[(600)] .36985 .09737 -0.08821 1 Mshowa
.21089 .14487 m
.2098 .15199 L
s
[(800)] .21307 .13063 -0.15308 1 Mshowa
.06162 .17625 m
.06012 .18329 L
s
[(1000)] .06462 .16216 -0.21284 1 Mshowa
.125 Mabswid
.85208 .01009 m
.8526 .01438 L
s
.80478 .02004 m
.80522 .02433 L
s
.7582 .02983 m
.75855 .03413 L
s
.66712 .04897 m
.66729 .05329 L
s
.62259 .05833 m
.62267 .06265 L
s
.5787 .06756 m
.57871 .07188 L
s
.49284 .0856 m
.49268 .08992 L
s
.45083 .09444 m
.4506 .09875 L
s
.40942 .10314 m
.40911 .10745 L
s
.32833 .12018 m
.32788 .12448 L
s
.28864 .12853 m
.28812 .13282 L
s
.24949 .13675 m
.24891 .14104 L
s
.17281 .15287 m
.17209 .15714 L
s
.13524 .16077 m
.13446 .16502 L
s
.09818 .16856 m
.09734 .1728 L
s
gsave
.45546 .00814 -102.639 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(time) show
87.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(in) show
117.000 12.750 moveto
(days) show
147.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.9001 0 m
.94573 .31565 L
s
.90106 .00661 m
.89401 .00808 L
s
[(0)] .91515 .00366 -1 .20911 Mshowa
.91227 .08418 m
.9052 .08557 L
s
[(0.02)] .9264 .0814 -1 .19639 Mshowa
.92428 .16729 m
.9172 .16859 L
s
[(0.04)] .93845 .1647 -1 .18282 Mshowa
.93719 .25657 m
.93009 .25777 L
s
[(0.06)] .95139 .25418 -1 .16829 Mshowa
.125 Mabswid
.90379 .02551 m
.89956 .02638 L
s
.90657 .04473 m
.90233 .04559 L
s
.90939 .06429 m
.90516 .06513 L
s
.91519 .10441 m
.91095 .10523 L
s
.91817 .12501 m
.91393 .12581 L
s
.9212 .14596 m
.91695 .14675 L
s
.92742 .18901 m
.92317 .18977 L
s
.93062 .21112 m
.92636 .21187 L
s
.93387 .23364 m
.92962 .23437 L
s
.94057 .27994 m
.9363 .28064 L
s
.94401 .30374 m
.93974 .30443 L
s
gsave
1.00638 .13164 -61 -11.4128 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(IRF) show
81.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4 g
.25 Mabswid
.90106 .00661 m
.06031 .18242 L
s
.91227 .08418 m
.04496 .25451 L
s
.92428 .16729 m
.02868 .33103 L
s
.93719 .25657 m
.01136 .41238 L
s
.9001 0 m
.94573 .31565 L
s
.71232 .03947 m
.73085 .34976 L
s
.53546 .07665 m
.53011 .38162 L
s
.36859 .11172 m
.34215 .41145 L
s
.21089 .14487 m
.16579 .43944 L
s
.06162 .17625 m
0 .46575 L
s
0 g
.9001 0 m
.94573 .31565 L
s
.94573 .31565 m
0 .46575 L
s
0 .46575 m
.06162 .17625 L
s
.06162 .17625 m
.9001 0 L
s
.4 g
.96568 .45367 m
1 .6911 L
s
.83994 .47083 m
.86268 .70462 L
s
.71909 .48732 m
.73115 .71756 L
s
.60285 .50317 m
.60506 .72998 L
s
.49097 .51844 m
.48407 .74189 L
s
.3832 .53314 m
.36788 .75332 L
s
.96643 .45888 m
.38286 .53801 L
s
.97515 .51921 m
.37894 .59428 L
s
.98427 .5823 m
.37487 .65287 L
s
.99382 .64835 m
.37062 .71394 L
s
0 g
.96568 .45367 m
.3832 .53314 L
s
.3832 .53314 m
.36788 .75332 L
s
.36788 .75332 m
1 .6911 L
s
1 .6911 m
.96568 .45367 L
s
.4 g
.90106 .00661 m
.96643 .45888 L
s
.91227 .08418 m
.97515 .51921 L
s
.92428 .16729 m
.98427 .5823 L
s
.93719 .25657 m
.99382 .64835 L
s
.9001 0 m
.94573 .31565 L
s
.9222 .15287 m
.96459 .44617 L
s
.9397 .27398 m
.97912 .54662 L
s
.95391 .37228 m
.99064 .62632 L
s
.96568 .45367 m
1 .6911 L
s
0 g
.9001 0 m
.94573 .31565 L
s
.94573 .31565 m
1 .6911 L
s
1 .6911 m
.96568 .45367 L
s
.96568 .45367 m
.9001 0 L
s
.4 g
.06162 .17625 m
0 .46575 L
s
.16662 .29278 m
.12312 .56199 L
s
.25218 .38774 m
.22126 .63871 L
s
.32324 .4666 m
.30132 .70129 L
s
.3832 .53314 m
.36788 .75332 L
s
.06031 .18242 m
.38286 .53801 L
s
.04496 .25451 m
.37894 .59428 L
s
.02868 .33103 m
.37487 .65287 L
s
.01136 .41238 m
.37062 .71394 L
s
0 g
.06162 .17625 m
.3832 .53314 L
s
.3832 .53314 m
.36788 .75332 L
s
.36788 .75332 m
0 .46575 L
s
0 .46575 m
.06162 .17625 L
s
.4 g
.9001 0 m
.06162 .17625 L
s
.9222 .15287 m
.16662 .29278 L
s
.9397 .27398 m
.25218 .38774 L
s
.95391 .37228 m
.32324 .4666 L
s
.96568 .45367 m
.3832 .53314 L
s
.9001 0 m
.96568 .45367 L
s
.71232 .03947 m
.83994 .47083 L
s
.53546 .07665 m
.71909 .48732 L
s
.36859 .11172 m
.60285 .50317 L
s
.21089 .14487 m
.49097 .51844 L
s
.06162 .17625 m
.3832 .53314 L
s
.94573 .31565 m
0 .46575 L
s
.96459 .44617 m
.12312 .56199 L
s
.97912 .54662 m
.22126 .63871 L
s
.99064 .62632 m
.30132 .70129 L
s
1 .6911 m
.36788 .75332 L
s
.94573 .31565 m
1 .6911 L
s
.73085 .34976 m
.86268 .70462 L
s
.53011 .38162 m
.73115 .71756 L
s
.34215 .41145 m
.60506 .72998 L
s
.16579 .43944 m
.48407 .74189 L
s
0 .46575 m
.36788 .75332 L
s
0 0 m
1 0 L
1 .75332 L
0 .75332 L
closepath
clip
newpath
.519 .808 .998 r
.39458 .54526 .37205 .54758 .38156 .55662 .40383 .55433 Mtetra
.516 .808 .999 r
.38506 .536 .36226 .53836 .37205 .54758 .39458 .54526 Mtetra
.513 .808 .999 r
.37527 .52655 .3522 .52894 .36226 .53836 .38506 .536 Mtetra
.51 .807 .999 r
.3652 .51691 .34184 .51932 .3522 .52894 .37527 .52655 Mtetra
.506 .807 .999 r
.35482 .50706 .33117 .5095 .34184 .51932 .3652 .51691 Mtetra
.502 .807 .999 r
.34412 .49701 .32017 .49948 .33117 .5095 .35482 .50706 Mtetra
.499 .806 1 r
.33309 .48675 .30884 .48924 .32017 .49948 .34412 .49701 Mtetra
.494 .806 1 r
.32171 .47626 .29714 .47879 .30884 .48924 .33309 .48675 Mtetra
.49 .805 1 r
.30996 .46556 .28507 .46811 .29714 .47879 .32171 .47626 Mtetra
.485 .804 1 r
.29783 .45463 .27261 .4572 .28507 .46811 .30996 .46556 Mtetra
.48 .803 1 r
.28528 .44346 .25972 .44606 .27261 .4572 .29783 .45463 Mtetra
.475 .803 1 r
.27231 .43206 .2464 .43467 .25972 .44606 .28528 .44346 Mtetra
.469 .801 .999 r
.25887 .42041 .23261 .42304 .2464 .43467 .27231 .43206 Mtetra
.463 .8 .999 r
.24495 .4085 .21832 .41115 .23261 .42304 .25887 .42041 Mtetra
.457 .799 .999 r
.23052 .39634 .20352 .399 .21832 .41115 .24495 .4085 Mtetra
.45 .797 .998 r
.21554 .38391 .18815 .38658 .20352 .399 .23052 .39634 Mtetra
.443 .796 .997 r
.19999 .37121 .1722 .37388 .18815 .38658 .21554 .38391 Mtetra
.435 .794 .996 r
.18381 .35823 .15561 .3609 .1722 .37388 .19999 .37121 Mtetra
.427 .792 .995 r
.16698 .34495 .13836 .34763 .15561 .3609 .18381 .35823 Mtetra
.418 .789 .994 r
.14944 .33139 .12039 .33406 .13836 .34763 .16698 .34495 Mtetra
.409 .786 .992 r
.13114 .31751 .10166 .32017 .12039 .33406 .14944 .33139 Mtetra
.399 .783 .991 r
.11204 .30332 .0821 .30597 .10166 .32017 .13114 .31751 Mtetra
.389 .78 .988 r
.09206 .28881 .06166 .29143 .0821 .30597 .11204 .30332 Mtetra
.378 .776 .986 r
.07115 .27396 .04027 .27655 .06166 .29143 .09206 .28881 Mtetra
.517 .808 .998 r
.41729 .54295 .39458 .54526 .40383 .55433 .42628 .55205 Mtetra
.514 .808 .999 r
.40806 .53366 .38506 .536 .39458 .54526 .41729 .54295 Mtetra
.511 .807 .999 r
.39855 .52419 .37527 .52655 .38506 .536 .40806 .53366 Mtetra
.507 .807 .999 r
.38876 .51451 .3652 .51691 .37527 .52655 .39855 .52419 Mtetra
.504 .807 .999 r
.37868 .50464 .35482 .50706 .3652 .51691 .38876 .51451 Mtetra
.5 .806 1 r
.36829 .49456 .34412 .49701 .35482 .50706 .37868 .50464 Mtetra
.496 .806 1 r
.35757 .48427 .33309 .48675 .34412 .49701 .36829 .49456 Mtetra
.491 .805 1 r
.34651 .47377 .32171 .47626 .33309 .48675 .35757 .48427 Mtetra
.487 .804 1 r
.33509 .46304 .30996 .46556 .32171 .47626 .34651 .47377 Mtetra
.482 .804 1 r
.3233 .45209 .29783 .45463 .30996 .46556 .33509 .46304 Mtetra
.477 .803 1 r
.3111 .44091 .28528 .44346 .29783 .45463 .3233 .45209 Mtetra
.471 .802 .999 r
.29848 .42949 .27231 .43206 .28528 .44346 .3111 .44091 Mtetra
.465 .801 .999 r
.28541 .41782 .25887 .42041 .27231 .43206 .29848 .42949 Mtetra
.459 .799 .999 r
.27187 .40591 .24495 .4085 .25887 .42041 .28541 .41782 Mtetra
.452 .798 .998 r
.25782 .39374 .23052 .39634 .24495 .4085 .27187 .40591 Mtetra
.445 .796 .998 r
.24324 .3813 .21554 .38391 .23052 .39634 .25782 .39374 Mtetra
.438 .794 .997 r
.22809 .3686 .19999 .37121 .21554 .38391 .24324 .3813 Mtetra
.43 .792 .996 r
.21233 .35562 .18381 .35823 .19999 .37121 .22809 .3686 Mtetra
.421 .79 .994 r
.19593 .34235 .16698 .34495 .18381 .35823 .21233 .35562 Mtetra
.412 .787 .993 r
.17884 .3288 .14944 .33139 .16698 .34495 .19593 .34235 Mtetra
.402 .784 .991 r
.161 .31494 .13114 .31751 .14944 .33139 .17884 .3288 Mtetra
.392 .781 .989 r
.14236 .30077 .11204 .30332 .13114 .31751 .161 .31494 Mtetra
.381 .777 .987 r
.12287 .28629 .09206 .28881 .11204 .30332 .14236 .30077 Mtetra
.37 .773 .984 r
.10245 .27147 .07115 .27396 .09206 .28881 .12287 .28629 Mtetra
.515 .808 .999 r
.4402 .54065 .41729 .54295 .42628 .55205 .44891 .54978 Mtetra
.512 .807 .999 r
.43124 .53134 .40806 .53366 .41729 .54295 .4402 .54065 Mtetra
.508 .807 .999 r
.42203 .52183 .39855 .52419 .40806 .53366 .43124 .53134 Mtetra
.505 .807 .999 r
.41254 .51214 .38876 .51451 .39855 .52419 .42203 .52183 Mtetra
.501 .806 .999 r
.40276 .50224 .37868 .50464 .38876 .51451 .41254 .51214 Mtetra
.497 .806 1 r
.39268 .49214 .36829 .49456 .37868 .50464 .40276 .50224 Mtetra
.493 .805 1 r
.38228 .48183 .35757 .48427 .36829 .49456 .39268 .49214 Mtetra
.488 .804 1 r
.37155 .4713 .34651 .47377 .35757 .48427 .38228 .48183 Mtetra
.483 .804 1 r
.36047 .46056 .33509 .46304 .34651 .47377 .37155 .4713 Mtetra
.478 .803 1 r
.34901 .44959 .3233 .45209 .33509 .46304 .36047 .46056 Mtetra
.473 .802 1 r
.33717 .43839 .3111 .44091 .3233 .45209 .34901 .44959 Mtetra
.467 .801 .999 r
.32492 .42696 .29848 .42949 .3111 .44091 .33717 .43839 Mtetra
.461 .799 .999 r
.31222 .41528 .28541 .41782 .29848 .42949 .32492 .42696 Mtetra
.454 .798 .998 r
.29907 .40336 .27187 .40591 .28541 .41782 .31222 .41528 Mtetra
.447 .796 .998 r
.28542 .39119 .25782 .39374 .27187 .40591 .29907 .40336 Mtetra
.44 .795 .997 r
.27125 .37875 .24324 .3813 .25782 .39374 .28542 .39119 Mtetra
.432 .793 .996 r
.25652 .36605 .22809 .3686 .24324 .3813 .27125 .37875 Mtetra
.424 .79 .995 r
.2412 .35308 .21233 .35562 .22809 .3686 .25652 .36605 Mtetra
.415 .788 .993 r
.22524 .33983 .19593 .34235 .21233 .35562 .2412 .35308 Mtetra
.405 .785 .992 r
.2086 .32629 .17884 .3288 .19593 .34235 .22524 .33983 Mtetra
.395 .782 .99 r
.19124 .31246 .161 .31494 .17884 .3288 .2086 .32629 Mtetra
.384 .778 .988 r
.17309 .29833 .14236 .30077 .161 .31494 .19124 .31246 Mtetra
.373 .774 .985 r
.15409 .28388 .12287 .28629 .14236 .30077 .17309 .29833 Mtetra
.361 .77 .982 r
.13419 .26912 .10245 .27147 .12287 .28629 .15409 .28388 Mtetra
.513 .807 .999 r
.4633 .53837 .4402 .54065 .44891 .54978 .47173 .54752 Mtetra
.509 .807 .999 r
.45463 .52903 .43124 .53134 .4402 .54065 .4633 .53837 Mtetra
.506 .807 .999 r
.44571 .5195 .42203 .52183 .43124 .53134 .45463 .52903 Mtetra
.502 .806 .999 r
.43652 .50978 .41254 .51214 .42203 .52183 .44571 .5195 Mtetra
.498 .806 1 r
.42705 .49986 .40276 .50224 .41254 .51214 .43652 .50978 Mtetra
.494 .805 1 r
.41729 .48974 .39268 .49214 .40276 .50224 .42705 .49986 Mtetra
.49 .805 1 r
.40722 .47941 .38228 .48183 .39268 .49214 .41729 .48974 Mtetra
.485 .804 1 r
.39682 .46887 .37155 .4713 .38228 .48183 .40722 .47941 Mtetra
.48 .803 1 r
.38609 .45811 .36047 .46056 .37155 .4713 .39682 .46887 Mtetra
.474 .802 1 r
.37499 .44713 .34901 .44959 .36047 .46056 .38609 .45811 Mtetra
.469 .801 .999 r
.36351 .43592 .33717 .43839 .34901 .44959 .37499 .44713 Mtetra
.463 .8 .999 r
.35163 .42448 .32492 .42696 .33717 .43839 .36351 .43592 Mtetra
.456 .798 .999 r
.33933 .4128 .31222 .41528 .32492 .42696 .35163 .42448 Mtetra
.449 .797 .998 r
.32657 .40087 .29907 .40336 .31222 .41528 .33933 .4128 Mtetra
.442 .795 .997 r
.31333 .3887 .28542 .39119 .29907 .40336 .32657 .40087 Mtetra
.434 .793 .996 r
.29958 .37627 .27125 .37875 .28542 .39119 .31333 .3887 Mtetra
.426 .791 .995 r
.28528 .36358 .25652 .36605 .27125 .37875 .29958 .37627 Mtetra
.417 .788 .994 r
.2704 .35063 .2412 .35308 .25652 .36605 .28528 .36358 Mtetra
.408 .785 .992 r
.25491 .3374 .22524 .33983 .2412 .35308 .2704 .35063 Mtetra
.398 .782 .991 r
.23874 .32389 .2086 .32629 .22524 .33983 .25491 .3374 Mtetra
.388 .779 .988 r
.22187 .31009 .19124 .31246 .2086 .32629 .23874 .32389 Mtetra
.376 .775 .986 r
.20422 .296 .17309 .29833 .19124 .31246 .22187 .31009 Mtetra
.365 .771 .983 r
.18575 .28161 .15409 .28388 .17309 .29833 .20422 .296 Mtetra
.352 .766 .98 r
.16638 .2669 .13419 .26912 .15409 .28388 .18575 .28161 Mtetra
.51 .807 .999 r
.4866 .5361 .4633 .53837 .47173 .54752 .49474 .54528 Mtetra
.507 .807 .999 r
.47823 .52674 .45463 .52903 .4633 .53837 .4866 .5361 Mtetra
.503 .806 .999 r
.4696 .51719 .44571 .5195 .45463 .52903 .47823 .52674 Mtetra
.499 .806 1 r
.46072 .50745 .43652 .50978 .44571 .5195 .4696 .51719 Mtetra
.495 .805 1 r
.45157 .49751 .42705 .49986 .43652 .50978 .46072 .50745 Mtetra
.491 .805 1 r
.44213 .48737 .41729 .48974 .42705 .49986 .45157 .49751 Mtetra
.486 .804 1 r
.4324 .47702 .40722 .47941 .41729 .48974 .44213 .48737 Mtetra
.481 .803 1 r
.42235 .46647 .39682 .46887 .40722 .47941 .4324 .47702 Mtetra
.476 .802 1 r
.41196 .4557 .38609 .45811 .39682 .46887 .42235 .46647 Mtetra
.471 .801 .999 r
.40123 .44471 .37499 .44713 .38609 .45811 .41196 .4557 Mtetra
.465 .8 .999 r
.39013 .43349 .36351 .43592 .37499 .44713 .40123 .44471 Mtetra
.458 .799 .999 r
.37863 .42204 .35163 .42448 .36351 .43592 .39013 .43349 Mtetra
.452 .797 .998 r
.36672 .41036 .33933 .4128 .35163 .42448 .37863 .42204 Mtetra
.444 .795 .998 r
.35437 .39844 .32657 .40087 .33933 .4128 .36672 .41036 Mtetra
.437 .793 .997 r
.34155 .38628 .31333 .3887 .32657 .40087 .35437 .39844 Mtetra
.429 .791 .996 r
.32823 .37386 .29958 .37627 .31333 .3887 .34155 .38628 Mtetra
.42 .789 .994 r
.31438 .36119 .28528 .36358 .29958 .37627 .32823 .37386 Mtetra
.411 .786 .993 r
.29997 .34826 .2704 .35063 .28528 .36358 .31438 .36119 Mtetra
.401 .783 .991 r
.28495 .33506 .25491 .3374 .2704 .35063 .29997 .34826 Mtetra
.391 .78 .989 r
.26927 .32158 .23874 .32389 .25491 .3374 .28495 .33506 Mtetra
.38 .776 .987 r
.2529 .30783 .22187 .31009 .23874 .32389 .26927 .32158 Mtetra
.368 .772 .984 r
.23578 .29379 .20422 .296 .22187 .31009 .2529 .30783 Mtetra
.356 .767 .981 r
.21784 .27946 .18575 .28161 .20422 .296 .23578 .29379 Mtetra
.343 .762 .977 r
.19903 .26483 .16638 .2669 .18575 .28161 .21784 .27946 Mtetra
.508 .807 .999 r
.5101 .53385 .4866 .5361 .49474 .54528 .51795 .54305 Mtetra
.504 .806 .999 r
.50202 .52447 .47823 .52674 .4866 .5361 .5101 .53385 Mtetra
.501 .806 .999 r
.49371 .5149 .4696 .51719 .47823 .52674 .50202 .52447 Mtetra
.497 .805 1 r
.48514 .50514 .46072 .50745 .4696 .51719 .49371 .5149 Mtetra
.492 .805 1 r
.47632 .49519 .45157 .49751 .46072 .50745 .48514 .50514 Mtetra
.488 .804 1 r
.46721 .48503 .44213 .48737 .45157 .49751 .47632 .49519 Mtetra
.483 .803 1 r
.45782 .47467 .4324 .47702 .44213 .48737 .46721 .48503 Mtetra
.478 .802 1 r
.44812 .4641 .42235 .46647 .4324 .47702 .45782 .47467 Mtetra
.472 .801 .999 r
.4381 .45333 .41196 .4557 .42235 .46647 .44812 .4641 Mtetra
.466 .8 .999 r
.42774 .44233 .40123 .44471 .41196 .4557 .4381 .45333 Mtetra
.46 .799 .999 r
.41702 .43111 .39013 .43349 .40123 .44471 .42774 .44233 Mtetra
.454 .797 .998 r
.40592 .41967 .37863 .42204 .39013 .43349 .41702 .43111 Mtetra
.447 .796 .998 r
.39442 .40799 .36672 .41036 .37863 .42204 .40592 .41967 Mtetra
.439 .794 .997 r
.38248 .39608 .35437 .39844 .36672 .41036 .39442 .40799 Mtetra
.431 .792 .996 r
.3701 .38393 .34155 .38628 .35437 .39844 .38248 .39608 Mtetra
.423 .789 .995 r
.35723 .37153 .32823 .37386 .34155 .38628 .3701 .38393 Mtetra
.414 .787 .993 r
.34384 .35888 .31438 .36119 .32823 .37386 .35723 .37153 Mtetra
.404 .784 .992 r
.3299 .34598 .29997 .34826 .31438 .36119 .34384 .35888 Mtetra
.394 .781 .99 r
.31537 .33282 .28495 .33506 .29997 .34826 .3299 .34598 Mtetra
.383 .777 .987 r
.3002 .31939 .26927 .32158 .28495 .33506 .31537 .33282 Mtetra
.371 .773 .985 r
.28436 .3057 .2529 .30783 .26927 .32158 .3002 .31939 Mtetra
.359 .768 .982 r
.26777 .29172 .23578 .29379 .2529 .30783 .28436 .3057 Mtetra
.346 .763 .978 r
.2504 .27747 .21784 .27946 .23578 .29379 .26777 .29172 Mtetra
.333 .758 .974 r
.23216 .26292 .19903 .26483 .21784 .27946 .2504 .27747 Mtetra
.505 .806 .999 r
.5338 .53162 .5101 .53385 .51795 .54305 .54136 .54084 Mtetra
.502 .806 .999 r
.52603 .52222 .50202 .52447 .5101 .53385 .5338 .53162 Mtetra
.498 .805 1 r
.51803 .51264 .49371 .5149 .50202 .52447 .52603 .52222 Mtetra
.494 .805 1 r
.50979 .50286 .48514 .50514 .49371 .5149 .51803 .51264 Mtetra
.489 .804 1 r
.50129 .49289 .47632 .49519 .48514 .50514 .50979 .50286 Mtetra
.484 .803 1 r
.49253 .48272 .46721 .48503 .47632 .49519 .50129 .49289 Mtetra
.479 .802 1 r
.48349 .47236 .45782 .47467 .46721 .48503 .49253 .48272 Mtetra
.474 .801 1 r
.47415 .46178 .44812 .4641 .45782 .47467 .48349 .47236 Mtetra
.468 .8 .999 r
.4645 .451 .4381 .45333 .44812 .4641 .47415 .46178 Mtetra
.462 .799 .999 r
.45452 .44 .42774 .44233 .4381 .45333 .4645 .451 Mtetra
.455 .798 .999 r
.4442 .42878 .41702 .43111 .42774 .44233 .45452 .44 Mtetra
.449 .796 .998 r
.4335 .41735 .40592 .41967 .41702 .43111 .4442 .42878 Mtetra
.441 .794 .997 r
.42242 .40568 .39442 .40799 .40592 .41967 .4335 .41735 Mtetra
.433 .792 .996 r
.41092 .39378 .38248 .39608 .39442 .40799 .42242 .40568 Mtetra
.425 .79 .995 r
.39898 .38165 .3701 .38393 .38248 .39608 .41092 .39378 Mtetra
.416 .787 .994 r
.38657 .36928 .35723 .37153 .3701 .38393 .39898 .38165 Mtetra
.407 .785 .992 r
.37366 .35667 .34384 .35888 .35723 .37153 .38657 .36928 Mtetra
.397 .781 .99 r
.36021 .34381 .3299 .34598 .34384 .35888 .37366 .35667 Mtetra
.386 .778 .988 r
.34619 .33069 .31537 .33282 .3299 .34598 .36021 .34381 Mtetra
.375 .774 .986 r
.33155 .31732 .3002 .31939 .31537 .33282 .34619 .33069 Mtetra
.363 .769 .983 r
.31624 .30369 .28436 .3057 .3002 .31939 .33155 .31732 Mtetra
.35 .764 .979 r
.30022 .28979 .26777 .29172 .28436 .3057 .31624 .30369 Mtetra
.337 .759 .975 r
.28343 .27562 .2504 .27747 .26777 .29172 .30022 .28979 Mtetra
.322 .753 .971 r
.2658 .26118 .23216 .26292 .2504 .27747 .28343 .27562 Mtetra
.503 .806 .999 r
.55771 .52942 .5338 .53162 .54136 .54084 .56496 .53865 Mtetra
.499 .805 1 r
.55026 .52 .52603 .52222 .5338 .53162 .55771 .52942 Mtetra
.495 .805 1 r
.54258 .5104 .51803 .51264 .52603 .52222 .55026 .52 Mtetra
.49 .804 1 r
.53466 .50061 .50979 .50286 .51803 .51264 .54258 .5104 Mtetra
.486 .803 1 r
.52651 .49063 .50129 .49289 .50979 .50286 .53466 .50061 Mtetra
.481 .803 1 r
.51809 .48046 .49253 .48272 .50129 .49289 .52651 .49063 Mtetra
.475 .802 1 r
.50941 .47008 .48349 .47236 .49253 .48272 .51809 .48046 Mtetra
.47 .801 .999 r
.50044 .4595 .47415 .46178 .48349 .47236 .50941 .47008 Mtetra
.464 .799 .999 r
.49117 .44872 .4645 .451 .47415 .46178 .50044 .4595 Mtetra
.457 .798 .999 r
.48159 .43773 .45452 .44 .4645 .451 .49117 .44872 Mtetra
.451 .796 .998 r
.47167 .42652 .4442 .42878 .45452 .44 .48159 .43773 Mtetra
.443 .795 .997 r
.46139 .41509 .4335 .41735 .4442 .42878 .47167 .42652 Mtetra
.436 .793 .997 r
.45074 .40344 .42242 .40568 .4335 .41735 .46139 .41509 Mtetra
.428 .79 .996 r
.43968 .39157 .41092 .39378 .42242 .40568 .45074 .40344 Mtetra
.419 .788 .994 r
.4282 .37946 .39898 .38165 .41092 .39378 .43968 .39157 Mtetra
.41 .785 .993 r
.41627 .36713 .38657 .36928 .39898 .38165 .4282 .37946 Mtetra
.4 .782 .991 r
.40385 .35455 .37366 .35667 .38657 .36928 .41627 .36713 Mtetra
.389 .779 .989 r
.39091 .34174 .36021 .34381 .37366 .35667 .40385 .35455 Mtetra
.378 .775 .986 r
.37741 .32868 .34619 .33069 .36021 .34381 .39091 .34174 Mtetra
.366 .77 .984 r
.36332 .31538 .33155 .31732 .34619 .33069 .37741 .32868 Mtetra
.354 .766 .98 r
.34858 .30183 .31624 .30369 .33155 .31732 .36332 .31538 Mtetra
.34 .76 .977 r
.33314 .28802 .30022 .28979 .31624 .30369 .34858 .30183 Mtetra
.326 .755 .972 r
.31695 .27395 .28343 .27562 .30022 .28979 .33314 .28802 Mtetra
.311 .748 .968 r
.29995 .25963 .2658 .26118 .28343 .27562 .31695 .27395 Mtetra
.5 .805 .999 r
.58184 .52724 .55771 .52942 .56496 .53865 .58877 .53649 Mtetra
.496 .805 1 r
.5747 .51781 .55026 .52 .55771 .52942 .58184 .52724 Mtetra
.492 .804 1 r
.56735 .50819 .54258 .5104 .55026 .52 .5747 .51781 Mtetra
.487 .804 1 r
.55977 .4984 .53466 .50061 .54258 .5104 .56735 .50819 Mtetra
.482 .803 1 r
.55196 .48841 .52651 .49063 .53466 .50061 .55977 .4984 Mtetra
.477 .802 1 r
.5439 .47823 .51809 .48046 .52651 .49063 .55196 .48841 Mtetra
.471 .801 .999 r
.53559 .46785 .50941 .47008 .51809 .48046 .5439 .47823 Mtetra
.466 .8 .999 r
.527 .45727 .50044 .4595 .50941 .47008 .53559 .46785 Mtetra
.459 .798 .999 r
.51812 .4465 .49117 .44872 .50044 .4595 .527 .45727 Mtetra
.453 .797 .998 r
.50894 .43551 .48159 .43773 .49117 .44872 .51812 .4465 Mtetra
.446 .795 .998 r
.49944 .42431 .47167 .42652 .48159 .43773 .50894 .43551 Mtetra
.438 .793 .997 r
.48959 .4129 .46139 .41509 .47167 .42652 .49944 .42431 Mtetra
.43 .791 .996 r
.47938 .40128 .45074 .40344 .46139 .41509 .48959 .4129 Mtetra
.421 .789 .995 r
.46879 .38943 .43968 .39157 .45074 .40344 .47938 .40128 Mtetra
.412 .786 .993 r
.45778 .37736 .4282 .37946 .43968 .39157 .46879 .38943 Mtetra
.403 .783 .992 r
.44634 .36507 .41627 .36713 .4282 .37946 .45778 .37736 Mtetra
.392 .779 .99 r
.43442 .35254 .40385 .35455 .41627 .36713 .44634 .36507 Mtetra
.381 .776 .987 r
.42201 .33979 .39091 .34174 .40385 .35455 .43442 .35254 Mtetra
.37 .772 .985 r
.40906 .3268 .37741 .32868 .39091 .34174 .42201 .33979 Mtetra
.357 .767 .981 r
.39553 .31358 .36332 .31538 .37741 .32868 .40906 .3268 Mtetra
.344 .762 .978 r
.38137 .30011 .34858 .30183 .36332 .31538 .39553 .31358 Mtetra
.33 .756 .974 r
.36655 .28641 .33314 .28802 .34858 .30183 .38137 .30011 Mtetra
.316 .75 .969 r
.35099 .27246 .31695 .27395 .33314 .28802 .36655 .28641 Mtetra
.3 .743 .964 r
.33464 .25827 .29995 .25963 .31695 .27395 .35099 .27246 Mtetra
.497 .805 1 r
.60618 .52508 .58184 .52724 .58877 .53649 .6128 .53435 Mtetra
.493 .804 1 r
.59936 .51564 .5747 .51781 .58184 .52724 .60618 .52508 Mtetra
.488 .804 1 r
.59235 .50602 .56735 .50819 .5747 .51781 .59936 .51564 Mtetra
.484 .803 1 r
.58512 .49621 .55977 .4984 .56735 .50819 .59235 .50602 Mtetra
.479 .802 1 r
.57766 .48622 .55196 .48841 .55977 .4984 .58512 .49621 Mtetra
.473 .801 1 r
.56997 .47604 .5439 .47823 .55196 .48841 .57766 .48622 Mtetra
.467 .8 .999 r
.56203 .46567 .53559 .46785 .5439 .47823 .56997 .47604 Mtetra
.461 .798 .999 r
.55383 .4551 .527 .45727 .53559 .46785 .56203 .46567 Mtetra
.455 .797 .999 r
.54536 .44433 .51812 .4465 .527 .45727 .55383 .4551 Mtetra
.448 .795 .998 r
.53659 .43335 .50894 .43551 .51812 .4465 .54536 .44433 Mtetra
.44 .793 .997 r
.52751 .42218 .49944 .42431 .50894 .43551 .53659 .43335 Mtetra
.432 .791 .996 r
.51811 .41079 .48959 .4129 .49944 .42431 .52751 .42218 Mtetra
.424 .789 .995 r
.50836 .39919 .47938 .40128 .48959 .4129 .51811 .41079 Mtetra
.415 .786 .994 r
.49823 .38738 .46879 .38943 .47938 .40128 .50836 .39919 Mtetra
.405 .783 .992 r
.48772 .37536 .45778 .37736 .46879 .38943 .49823 .38738 Mtetra
.395 .78 .99 r
.47678 .36311 .44634 .36507 .45778 .37736 .48772 .37536 Mtetra
.384 .777 .988 r
.46539 .35065 .43442 .35254 .44634 .36507 .47678 .36311 Mtetra
.373 .773 .985 r
.45352 .33796 .42201 .33979 .43442 .35254 .46539 .35065 Mtetra
.361 .768 .982 r
.44114 .32506 .40906 .3268 .42201 .33979 .45352 .33796 Mtetra
.348 .763 .979 r
.42819 .31192 .39553 .31358 .40906 .3268 .44114 .32506 Mtetra
.334 .757 .975 r
.41465 .29856 .38137 .30011 .39553 .31358 .42819 .31192 Mtetra
.32 .751 .97 r
.40046 .28498 .36655 .28641 .38137 .30011 .41465 .29856 Mtetra
.304 .745 .965 r
.38556 .27117 .35099 .27246 .36655 .28641 .40046 .28498 Mtetra
.288 .737 .96 r
.36989 .25713 .33464 .25827 .35099 .27246 .38556 .27117 Mtetra
.494 .804 1 r
.63073 .52296 .60618 .52508 .6128 .53435 .63703 .53223 Mtetra
.49 .804 1 r
.62425 .51351 .59936 .51564 .60618 .52508 .63073 .52296 Mtetra
.485 .803 1 r
.61758 .50388 .59235 .50602 .59936 .51564 .62425 .51351 Mtetra
.48 .802 1 r
.6107 .49407 .58512 .49621 .59235 .50602 .61758 .50388 Mtetra
.475 .801 1 r
.60361 .48408 .57766 .48622 .58512 .49621 .6107 .49407 Mtetra
.469 .8 .999 r
.5963 .4739 .56997 .47604 .57766 .48622 .60361 .48408 Mtetra
.463 .799 .999 r
.58875 .46353 .56203 .46567 .56997 .47604 .5963 .4739 Mtetra
.456 .797 .999 r
.58095 .45297 .55383 .4551 .56203 .46567 .58875 .46353 Mtetra
.45 .796 .998 r
.57288 .44222 .54536 .44433 .55383 .4551 .58095 .45297 Mtetra
.442 .794 .997 r
.56454 .43127 .53659 .43335 .54536 .44433 .57288 .44222 Mtetra
.435 .792 .997 r
.55591 .42011 .52751 .42218 .53659 .43335 .56454 .43127 Mtetra
.426 .79 .995 r
.54696 .40876 .51811 .41079 .52751 .42218 .55591 .42011 Mtetra
.417 .787 .994 r
.53768 .3972 .50836 .39919 .51811 .41079 .54696 .40876 Mtetra
.408 .784 .993 r
.52804 .38543 .49823 .38738 .50836 .39919 .53768 .3972 Mtetra
.398 .781 .991 r
.51803 .37346 .48772 .37536 .49823 .38738 .52804 .38543 Mtetra
.388 .777 .989 r
.50762 .36127 .47678 .36311 .48772 .37536 .51803 .37346 Mtetra
.376 .773 .986 r
.49677 .34888 .46539 .35065 .47678 .36311 .50762 .36127 Mtetra
.364 .769 .983 r
.48547 .33627 .45352 .33796 .46539 .35065 .49677 .34888 Mtetra
.352 .764 .98 r
.47367 .32346 .44114 .32506 .45352 .33796 .48547 .33627 Mtetra
.338 .759 .976 r
.46133 .31043 .42819 .31192 .44114 .32506 .47367 .32346 Mtetra
.324 .753 .972 r
.44842 .29719 .41465 .29856 .42819 .31192 .46133 .31043 Mtetra
.309 .746 .967 r
.43489 .28374 .40046 .28498 .41465 .29856 .44842 .29719 Mtetra
.293 .739 .961 r
.42068 .27008 .38556 .27117 .40046 .28498 .43489 .28374 Mtetra
.276 .731 .955 r
.40573 .25622 .36989 .25713 .38556 .27117 .42068 .27008 Mtetra
.491 .804 1 r
.65552 .52087 .63073 .52296 .63703 .53223 .66148 .53015 Mtetra
.486 .803 1 r
.64938 .51141 .62425 .51351 .63073 .52296 .65552 .52087 Mtetra
.481 .802 1 r
.64306 .50178 .61758 .50388 .62425 .51351 .64938 .51141 Mtetra
.476 .801 1 r
.63654 .49197 .6107 .49407 .61758 .50388 .64306 .50178 Mtetra
.471 .8 .999 r
.62982 .48199 .60361 .48408 .6107 .49407 .63654 .49197 Mtetra
.465 .799 .999 r
.62289 .47182 .5963 .4739 .60361 .48408 .62982 .48199 Mtetra
.458 .798 .999 r
.61574 .46146 .58875 .46353 .5963 .4739 .62289 .47182 Mtetra
.452 .796 .998 r
.60835 .45091 .58095 .45297 .58875 .46353 .61574 .46146 Mtetra
.444 .794 .998 r
.60071 .44018 .57288 .44222 .58095 .45297 .60835 .45091 Mtetra
.437 .792 .997 r
.59281 .42925 .56454 .43127 .57288 .44222 .60071 .44018 Mtetra
.429 .79 .996 r
.58462 .41813 .55591 .42011 .56454 .43127 .59281 .42925 Mtetra
.42 .788 .995 r
.57614 .40681 .54696 .40876 .55591 .42011 .58462 .41813 Mtetra
.411 .785 .993 r
.56735 .3953 .53768 .3972 .54696 .40876 .57614 .40681 Mtetra
.401 .782 .991 r
.55822 .38358 .52804 .38543 .53768 .3972 .56735 .3953 Mtetra
.391 .778 .989 r
.54873 .37167 .51803 .37346 .52804 .38543 .55822 .38358 Mtetra
.379 .774 .987 r
.53886 .35956 .50762 .36127 .51803 .37346 .54873 .37167 Mtetra
.368 .77 .984 r
.52858 .34724 .49677 .34888 .50762 .36127 .53886 .35956 Mtetra
.355 .765 .981 r
.51786 .33473 .48547 .33627 .49677 .34888 .52858 .34724 Mtetra
.342 .76 .977 r
.50666 .32202 .47367 .32346 .48547 .33627 .51786 .33473 Mtetra
.328 .754 .973 r
.49496 .30911 .46133 .31043 .47367 .32346 .50666 .32202 Mtetra
.313 .748 .968 r
.48272 .29601 .44842 .29719 .46133 .31043 .49496 .30911 Mtetra
.297 .741 .963 r
.46987 .28271 .43489 .28374 .44842 .29719 .48272 .29601 Mtetra
.28 .733 .957 r
.45638 .26923 .42068 .27008 .43489 .28374 .46987 .28271 Mtetra
.263 .724 .95 r
.44218 .25556 .40573 .25622 .42068 .27008 .45638 .26923 Mtetra
.488 .803 1 r
.68053 .51881 .65552 .52087 .66148 .53015 .68615 .52809 Mtetra
.483 .802 1 r
.67474 .50935 .64938 .51141 .65552 .52087 .68053 .51881 Mtetra
.478 .801 1 r
.66877 .49972 .64306 .50178 .64938 .51141 .67474 .50935 Mtetra
.472 .8 .999 r
.66263 .48992 .63654 .49197 .64306 .50178 .66877 .49972 Mtetra
.466 .799 .999 r
.6563 .47994 .62982 .48199 .63654 .49197 .66263 .48992 Mtetra
.46 .798 .999 r
.64976 .46978 .62289 .47182 .62982 .48199 .6563 .47994 Mtetra
.453 .796 .998 r
.64301 .45944 .61574 .46146 .62289 .47182 .64976 .46978 Mtetra
.446 .795 .998 r
.63605 .44892 .60835 .45091 .61574 .46146 .64301 .45944 Mtetra
.439 .793 .997 r
.62884 .43821 .60071 .44018 .60835 .45091 .63605 .44892 Mtetra
.431 .791 .996 r
.62139 .42731 .59281 .42925 .60071 .44018 .62884 .43821 Mtetra
.422 .788 .995 r
.61367 .41623 .58462 .41813 .59281 .42925 .62139 .42731 Mtetra
.413 .785 .994 r
.60567 .40496 .57614 .40681 .58462 .41813 .61367 .41623 Mtetra
.404 .782 .992 r
.59738 .3935 .56735 .3953 .57614 .40681 .60567 .40496 Mtetra
.393 .779 .99 r
.58877 .38184 .55822 .38358 .56735 .3953 .59738 .3935 Mtetra
.382 .775 .988 r
.57982 .37 .54873 .37167 .55822 .38358 .58877 .38184 Mtetra
.371 .771 .985 r
.57051 .35797 .53886 .35956 .54873 .37167 .57982 .37 Mtetra
.359 .767 .982 r
.56081 .34575 .52858 .34724 .53886 .35956 .57051 .35797 Mtetra
.345 .761 .979 r
.5507 .33334 .51786 .33473 .52858 .34724 .56081 .34575 Mtetra
.332 .756 .975 r
.54014 .32075 .50666 .32202 .51786 .33473 .5507 .33334 Mtetra
.317 .749 .97 r
.5291 .30798 .49496 .30911 .50666 .32202 .54014 .32075 Mtetra
.301 .743 .965 r
.51754 .29503 .48272 .29601 .49496 .30911 .5291 .30798 Mtetra
.285 .735 .959 r
.50542 .28191 .46987 .28271 .48272 .29601 .51754 .29503 Mtetra
.268 .727 .952 r
.49268 .26862 .45638 .26923 .46987 .28271 .50542 .28191 Mtetra
.249 .717 .945 r
.47927 .25516 .44218 .25556 .45638 .26923 .49268 .26862 Mtetra
.484 .802 1 r
.70577 .51679 .68053 .51881 .68615 .52809 .71105 .52608 Mtetra
.479 .802 1 r
.70034 .50734 .67474 .50935 .68053 .51881 .70577 .51679 Mtetra
.474 .801 1 r
.69475 .49771 .66877 .49972 .67474 .50935 .70034 .50734 Mtetra
.468 .799 .999 r
.68898 .48792 .66263 .48992 .66877 .49972 .69475 .49771 Mtetra
.462 .798 .999 r
.68304 .47795 .6563 .47994 .66263 .48992 .68898 .48792 Mtetra
.455 .797 .999 r
.67691 .46781 .64976 .46978 .6563 .47994 .68304 .47795 Mtetra
.448 .795 .998 r
.67058 .45749 .64301 .45944 .64976 .46978 .67691 .46781 Mtetra
.441 .793 .997 r
.66404 .447 .63605 .44892 .64301 .45944 .67058 .45749 Mtetra
.433 .791 .996 r
.65729 .43632 .62884 .43821 .63605 .44892 .66404 .447 Mtetra
.425 .789 .995 r
.6503 .42546 .62139 .42731 .62884 .43821 .65729 .43632 Mtetra
.416 .786 .994 r
.64306 .41443 .61367 .41623 .62139 .42731 .6503 .42546 Mtetra
.406 .783 .992 r
.63557 .40321 .60567 .40496 .61367 .41623 .64306 .41443 Mtetra
.396 .78 .991 r
.62779 .39181 .59738 .3935 .60567 .40496 .63557 .40321 Mtetra
.385 .776 .988 r
.61972 .38023 .58877 .38184 .59738 .3935 .62779 .39181 Mtetra
.374 .772 .986 r
.61133 .36847 .57982 .37 .58877 .38184 .61972 .38023 Mtetra
.362 .768 .983 r
.6026 .35653 .57051 .35797 .57982 .37 .61133 .36847 Mtetra
.349 .763 .98 r
.59351 .34442 .56081 .34575 .57051 .35797 .6026 .35653 Mtetra
.335 .757 .976 r
.58403 .33213 .5507 .33334 .56081 .34575 .59351 .34442 Mtetra
.321 .751 .971 r
.57413 .31968 .54014 .32075 .5507 .33334 .58403 .33213 Mtetra
.305 .744 .966 r
.56378 .30706 .5291 .30798 .54014 .32075 .57413 .31968 Mtetra
.289 .737 .961 r
.55293 .29428 .51754 .29503 .5291 .30798 .56378 .30706 Mtetra
.272 .729 .954 r
.54156 .28135 .50542 .28191 .51754 .29503 .55293 .29428 Mtetra
.254 .72 .947 r
.52961 .26828 .49268 .26862 .50542 .28191 .54156 .28135 Mtetra
.235 .71 .939 r
.51703 .25507 .47927 .25516 .49268 .26862 .52961 .26828 Mtetra
.48 .802 1 r
.73126 .51482 .70577 .51679 .71105 .52608 .73618 .5241 Mtetra
.475 .801 1 r
.72619 .50537 .70034 .50734 .70577 .51679 .73126 .51482 Mtetra
.469 .799 .999 r
.72097 .49576 .69475 .49771 .70034 .50734 .72619 .50537 Mtetra
.463 .798 .999 r
.7156 .48598 .68898 .48792 .69475 .49771 .72097 .49576 Mtetra
.457 .797 .999 r
.71006 .47603 .68304 .47795 .68898 .48792 .7156 .48598 Mtetra
.45 .795 .998 r
.70434 .46591 .67691 .46781 .68304 .47795 .71006 .47603 Mtetra
.443 .793 .998 r
.69845 .45562 .67058 .45749 .67691 .46781 .70434 .46591 Mtetra
.435 .791 .997 r
.69235 .44515 .66404 .447 .67058 .45749 .69845 .45562 Mtetra
.427 .789 .996 r
.68606 .43452 .65729 .43632 .66404 .447 .69235 .44515 Mtetra
.418 .786 .994 r
.67955 .42371 .6503 .42546 .65729 .43632 .68606 .43452 Mtetra
.409 .784 .993 r
.67281 .41273 .64306 .41443 .6503 .42546 .67955 .42371 Mtetra
.399 .78 .991 r
.66583 .40157 .63557 .40321 .64306 .41443 .67281 .41273 Mtetra
.388 .777 .989 r
.65858 .39024 .62779 .39181 .63557 .40321 .66583 .40157 Mtetra
.377 .773 .987 r
.65107 .37875 .61972 .38023 .62779 .39181 .65858 .39024 Mtetra
.365 .768 .984 r
.64326 .36708 .61133 .36847 .61972 .38023 .65107 .37875 Mtetra
.352 .764 .981 r
.63513 .35525 .6026 .35653 .61133 .36847 .64326 .36708 Mtetra
.339 .758 .977 r
.62667 .34326 .59351 .34442 .6026 .35653 .63513 .35525 Mtetra
.324 .752 .973 r
.61784 .33111 .58403 .33213 .59351 .34442 .62667 .34326 Mtetra
.309 .746 .968 r
.60863 .31881 .57413 .31968 .58403 .33213 .61784 .33111 Mtetra
.293 .738 .962 r
.599 .30636 .56378 .30706 .57413 .31968 .60863 .31881 Mtetra
.276 .73 .956 r
.58891 .29378 .55293 .29428 .56378 .30706 .599 .30636 Mtetra
.259 .721 .949 r
.57832 .28107 .54156 .28135 .55293 .29428 .58891 .29378 Mtetra
.24 .712 .941 r
.5672 .26824 .52961 .26828 .54156 .28135 .57832 .28107 Mtetra
.22 .701 .933 r
.55549 .2553 .51703 .25507 .52961 .26828 .5672 .26824 Mtetra
.476 .801 1 r
.75699 .5129 .73126 .51482 .73618 .5241 .76155 .52217 Mtetra
.471 .8 .999 r
.75229 .50346 .72619 .50537 .73126 .51482 .75699 .5129 Mtetra
.465 .798 .999 r
.74746 .49386 .72097 .49576 .72619 .50537 .75229 .50346 Mtetra
.458 .797 .999 r
.74249 .4841 .7156 .48598 .72097 .49576 .74746 .49386 Mtetra
.452 .795 .998 r
.73736 .47418 .71006 .47603 .7156 .48598 .74249 .4841 Mtetra
.444 .793 .998 r
.73207 .46409 .70434 .46591 .71006 .47603 .73736 .47418 Mtetra
.437 .791 .997 r
.72662 .45383 .69845 .45562 .70434 .46591 .73207 .46409 Mtetra
.429 .789 .996 r
.72098 .44341 .69235 .44515 .69845 .45562 .72662 .45383 Mtetra
.42 .787 .995 r
.71516 .43282 .68606 .43452 .69235 .44515 .72098 .44341 Mtetra
.411 .784 .993 r
.70915 .42207 .67955 .42371 .68606 .43452 .71516 .43282 Mtetra
.401 .781 .992 r
.70292 .41115 .67281 .41273 .67955 .42371 .70915 .42207 Mtetra
.391 .777 .99 r
.69647 .40007 .66583 .40157 .67281 .41273 .70292 .41115 Mtetra
.379 .773 .987 r
.68978 .38883 .65858 .39024 .66583 .40157 .69647 .40007 Mtetra
.368 .769 .985 r
.68284 .37742 .65107 .37875 .65858 .39024 .68978 .38883 Mtetra
.355 .764 .981 r
.67563 .36587 .64326 .36708 .65107 .37875 .68284 .37742 Mtetra
.342 .759 .978 r
.66813 .35416 .63513 .35525 .64326 .36708 .67563 .36587 Mtetra
.328 .753 .974 r
.66032 .3423 .62667 .34326 .63513 .35525 .66813 .35416 Mtetra
.313 .747 .969 r
.65218 .33031 .61784 .33111 .62667 .34326 .66032 .3423 Mtetra
.297 .739 .964 r
.64368 .31818 .60863 .31881 .61784 .33111 .65218 .33031 Mtetra
.28 .732 .958 r
.63479 .30593 .599 .30636 .60863 .31881 .64368 .31818 Mtetra
.262 .723 .951 r
.62549 .29357 .58891 .29378 .599 .30636 .63479 .30593 Mtetra
.244 .714 .943 r
.61573 .2811 .57832 .28107 .58891 .29378 .62549 .29357 Mtetra
.224 .703 .935 r
.60548 .26854 .5672 .26824 .57832 .28107 .61573 .2811 Mtetra
.204 .692 .926 r
.59468 .25591 .55549 .2553 .5672 .26824 .60548 .26854 Mtetra
.472 .799 .999 r
.78297 .51105 .75699 .5129 .76155 .52217 .78716 .52031 Mtetra
.466 .798 .999 r
.77866 .50163 .75229 .50346 .75699 .5129 .78297 .51105 Mtetra
.459 .797 .999 r
.77422 .49205 .74746 .49386 .75229 .50346 .77866 .50163 Mtetra
.453 .795 .998 r
.76966 .48232 .74249 .4841 .74746 .49386 .77422 .49205 Mtetra
.446 .793 .998 r
.76495 .47242 .73736 .47418 .74249 .4841 .76966 .48232 Mtetra
.438 .791 .997 r
.76011 .46237 .73207 .46409 .73736 .47418 .76495 .47242 Mtetra
.43 .789 .996 r
.75511 .45216 .72662 .45383 .73207 .46409 .76011 .46237 Mtetra
.421 .787 .995 r
.74995 .44179 .72098 .44341 .72662 .45383 .75511 .45216 Mtetra
.412 .784 .994 r
.74461 .43126 .71516 .43282 .72098 .44341 .74995 .44179 Mtetra
.402 .781 .992 r
.7391 .42057 .70915 .42207 .71516 .43282 .74461 .43126 Mtetra
.392 .777 .99 r
.7334 .40973 .70292 .41115 .70915 .42207 .7391 .42057 Mtetra
.381 .773 .988 r
.7275 .39874 .69647 .40007 .70292 .41115 .7334 .40973 Mtetra
.369 .769 .985 r
.72139 .38759 .68978 .38883 .69647 .40007 .7275 .39874 Mtetra
.357 .764 .982 r
.71504 .3763 .68284 .37742 .68978 .38883 .72139 .38759 Mtetra
.344 .759 .979 r
.70845 .36487 .67563 .36587 .68284 .37742 .71504 .3763 Mtetra
.33 .753 .975 r
.70161 .3533 .66813 .35416 .67563 .36587 .70845 .36487 Mtetra
.315 .747 .97 r
.69448 .34161 .66032 .3423 .66813 .35416 .70161 .3533 Mtetra
.299 .74 .965 r
.68705 .32979 .65218 .33031 .66032 .3423 .69448 .34161 Mtetra
.282 .732 .959 r
.6793 .31786 .64368 .31818 .65218 .33031 .68705 .32979 Mtetra
.265 .723 .952 r
.6712 .30583 .63479 .30593 .64368 .31818 .6793 .31786 Mtetra
.246 .714 .945 r
.66272 .29372 .62549 .29357 .63479 .30593 .6712 .30583 Mtetra
.227 .704 .937 r
.65383 .28153 .61573 .2811 .62549 .29357 .66272 .29372 Mtetra
.207 .693 .928 r
.64448 .26928 .60548 .26854 .61573 .2811 .65383 .28153 Mtetra
.186 .681 .918 r
.63465 .257 .59468 .25591 .60548 .26854 .64448 .26928 Mtetra
.466 .797 .999 r
.80921 .5093 .78297 .51105 .78716 .52031 .81301 .51854 Mtetra
.459 .796 .999 r
.80529 .4999 .77866 .50163 .78297 .51105 .80921 .5093 Mtetra
.453 .794 .998 r
.80126 .49036 .77422 .49205 .77866 .50163 .80529 .4999 Mtetra
.446 .792 .998 r
.79712 .48066 .76966 .48232 .77422 .49205 .80126 .49036 Mtetra
.438 .79 .997 r
.79285 .47081 .76495 .47242 .76966 .48232 .79712 .48066 Mtetra
.43 .788 .996 r
.78846 .4608 .76011 .46237 .76495 .47242 .79285 .47081 Mtetra
.421 .786 .995 r
.78393 .45065 .75511 .45216 .76011 .46237 .78846 .4608 Mtetra
.412 .783 .994 r
.77925 .44034 .74995 .44179 .75511 .45216 .78393 .45065 Mtetra
.403 .78 .992 r
.77443 .42989 .74461 .43126 .74995 .44179 .77925 .44034 Mtetra
.392 .776 .99 r
.76944 .41928 .7391 .42057 .74461 .43126 .77443 .42989 Mtetra
.381 .772 .988 r
.76429 .40854 .7334 .40973 .7391 .42057 .76944 .41928 Mtetra
.369 .768 .986 r
.75895 .39765 .7275 .39874 .7334 .40973 .76429 .40854 Mtetra
.357 .763 .983 r
.75343 .38662 .72139 .38759 .7275 .39874 .75895 .39765 Mtetra
.344 .758 .979 r
.74771 .37547 .71504 .3763 .72139 .38759 .75343 .38662 Mtetra
.33 .752 .975 r
.74177 .36418 .70845 .36487 .71504 .3763 .74771 .37547 Mtetra
.315 .746 .971 r
.73559 .35278 .70161 .3533 .70845 .36487 .74177 .36418 Mtetra
.299 .738 .966 r
.72918 .34127 .69448 .34161 .70161 .3533 .73559 .35278 Mtetra
.282 .731 .96 r
.72249 .32967 .68705 .32979 .69448 .34161 .72918 .34127 Mtetra
.265 .722 .953 r
.71552 .31797 .6793 .31786 .68705 .32979 .72249 .32967 Mtetra
.246 .713 .946 r
.70824 .3062 .6712 .30583 .6793 .31786 .71552 .31797 Mtetra
.227 .702 .938 r
.70062 .29437 .66272 .29372 .6712 .30583 .70824 .3062 Mtetra
.206 .691 .929 r
.69264 .28251 .65383 .28153 .66272 .29372 .70062 .29437 Mtetra
.185 .679 .919 r
.68427 .27063 .64448 .26928 .65383 .28153 .69264 .28251 Mtetra
.163 .666 .908 r
.67545 .25875 .63465 .257 .64448 .26928 .68427 .27063 Mtetra
.457 .794 .999 r
.83572 .50773 .80921 .5093 .81301 .51854 .83914 .51694 Mtetra
.451 .792 .998 r
.83221 .49838 .80529 .4999 .80921 .5093 .83572 .50773 Mtetra
.443 .79 .998 r
.8286 .48888 .80126 .49036 .80529 .4999 .83221 .49838 Mtetra
.436 .788 .997 r
.82489 .47923 .79712 .48066 .80126 .49036 .8286 .48888 Mtetra
.427 .785 .996 r
.82107 .46944 .79285 .47081 .79712 .48066 .82489 .47923 Mtetra
.419 .783 .995 r
.81714 .4595 .78846 .4608 .79285 .47081 .82107 .46944 Mtetra
.409 .78 .994 r
.8131 .44942 .78393 .45065 .78846 .4608 .81714 .4595 Mtetra
.399 .776 .992 r
.80892 .4392 .77925 .44034 .78393 .45065 .8131 .44942 Mtetra
.389 .773 .99 r
.80462 .42884 .77443 .42989 .77925 .44034 .80892 .4392 Mtetra
.378 .769 .988 r
.80018 .41835 .76944 .41928 .77443 .42989 .80462 .42884 Mtetra
.366 .764 .985 r
.79559 .40772 .76429 .40854 .76944 .41928 .80018 .41835 Mtetra
.353 .759 .982 r
.79085 .39697 .75895 .39765 .76429 .40854 .79559 .40772 Mtetra
.339 .753 .979 r
.78595 .3861 .75343 .38662 .75895 .39765 .79085 .39697 Mtetra
.325 .747 .975 r
.78087 .37511 .74771 .37547 .75343 .38662 .78595 .3861 Mtetra
.31 .741 .97 r
.7756 .36402 .74177 .36418 .74771 .37547 .78087 .37511 Mtetra
.294 .733 .965 r
.77013 .35283 .73559 .35278 .74177 .36418 .7756 .36402 Mtetra
.277 .725 .959 r
.76446 .34155 .72918 .34127 .73559 .35278 .77013 .35283 Mtetra
.259 .716 .953 r
.75855 .3302 .72249 .32967 .72918 .34127 .76446 .34155 Mtetra
.24 .706 .945 r
.7524 .3188 .71552 .31797 .72249 .32967 .75855 .3302 Mtetra
.22 .696 .937 r
.74598 .30735 .70824 .3062 .71552 .31797 .7524 .3188 Mtetra
.199 .684 .928 r
.73928 .29588 .70062 .29437 .70824 .3062 .74598 .30735 Mtetra
.177 .671 .918 r
.73226 .28441 .69264 .28251 .70062 .29437 .73928 .29588 Mtetra
.154 .658 .907 r
.7249 .27297 .68427 .27063 .69264 .28251 .73226 .28441 Mtetra
.131 .643 .895 r
.71717 .26158 .67545 .25875 .68427 .27063 .7249 .27297 Mtetra
.443 .786 .998 r
.86254 .50654 .83572 .50773 .83914 .51694 .86555 .51569 Mtetra
.435 .784 .997 r
.85945 .49726 .83221 .49838 .83572 .50773 .86254 .50654 Mtetra
.427 .781 .996 r
.85627 .48783 .8286 .48888 .83221 .49838 .85945 .49726 Mtetra
.418 .779 .995 r
.85301 .47827 .82489 .47923 .8286 .48888 .85627 .48783 Mtetra
.409 .775 .994 r
.84966 .46857 .82107 .46944 .82489 .47923 .85301 .47827 Mtetra
.399 .772 .993 r
.84621 .45874 .81714 .4595 .82107 .46944 .84966 .46857 Mtetra
.389 .768 .991 r
.84267 .44877 .8131 .44942 .81714 .4595 .84621 .45874 Mtetra
.377 .764 .989 r
.83901 .43868 .80892 .4392 .8131 .44942 .84267 .44877 Mtetra
.365 .759 .987 r
.83526 .42847 .80462 .42884 .80892 .4392 .83901 .43868 Mtetra
.353 .754 .984 r
.83138 .41813 .80018 .41835 .80462 .42884 .83526 .42847 Mtetra
.339 .748 .981 r
.82738 .40768 .79559 .40772 .80018 .41835 .83138 .41813 Mtetra
.325 .742 .977 r
.82326 .39712 .79085 .39697 .79559 .40772 .82738 .40768 Mtetra
.309 .735 .973 r
.819 .38647 .78595 .3861 .79085 .39697 .82326 .39712 Mtetra
.293 .727 .968 r
.81459 .37572 .78087 .37511 .78595 .3861 .819 .38647 Mtetra
.276 .719 .962 r
.81003 .36489 .7756 .36402 .78087 .37511 .81459 .37572 Mtetra
.258 .71 .956 r
.80531 .35399 .77013 .35283 .7756 .36402 .81003 .36489 Mtetra
.239 .699 .949 r
.80041 .34303 .76446 .34155 .77013 .35283 .80531 .35399 Mtetra
.219 .689 .941 r
.79533 .33204 .75855 .3302 .76446 .34155 .80041 .34303 Mtetra
.198 .677 .932 r
.79004 .32102 .7524 .3188 .75855 .3302 .79533 .33204 Mtetra
.175 .664 .923 r
.78453 .31001 .74598 .30735 .7524 .3188 .79004 .32102 Mtetra
.152 .65 .912 r
.77879 .29902 .73928 .29588 .74598 .30735 .78453 .31001 Mtetra
.128 .635 .9 r
.7728 .28808 .73226 .28441 .73928 .29588 .77879 .29902 Mtetra
.103 .619 .888 r
.76652 .27723 .7249 .27297 .73226 .28441 .7728 .28808 Mtetra
.078 .603 .874 r
.75994 .2665 .71717 .26158 .7249 .27297 .76652 .27723 Mtetra
.414 .769 .995 r
.88973 .50622 .86254 .50654 .86555 .51569 .89233 .51526 Mtetra
.405 .765 .994 r
.88708 .49706 .85945 .49726 .86254 .50654 .88973 .50622 Mtetra
.395 .761 .993 r
.88435 .48778 .85627 .48783 .85945 .49726 .88708 .49706 Mtetra
.384 .757 .991 r
.88156 .47837 .85301 .47827 .85627 .48783 .88435 .48778 Mtetra
.372 .752 .989 r
.8787 .46884 .84966 .46857 .85301 .47827 .88156 .47837 Mtetra
.36 .747 .987 r
.87576 .45919 .84621 .45874 .84966 .46857 .8787 .46884 Mtetra
.347 .741 .985 r
.87274 .44943 .84267 .44877 .84621 .45874 .87576 .45919 Mtetra
.333 .734 .982 r
.86964 .43957 .83901 .43868 .84267 .44877 .87274 .44943 Mtetra
.318 .727 .978 r
.86645 .4296 .83526 .42847 .83901 .43868 .86964 .43957 Mtetra
.302 .72 .974 r
.86317 .41953 .83138 .41813 .83526 .42847 .86645 .4296 Mtetra
.286 .711 .97 r
.8598 .40937 .82738 .40768 .83138 .41813 .86317 .41953 Mtetra
.268 .702 .964 r
.85632 .39914 .82326 .39712 .82738 .40768 .8598 .40937 Mtetra
.25 .692 .959 r
.85275 .38884 .819 .38647 .82326 .39712 .85632 .39914 Mtetra
.23 .682 .952 r
.84906 .37848 .81459 .37572 .819 .38647 .85275 .38884 Mtetra
.209 .67 .944 r
.84525 .36807 .81003 .36489 .81459 .37572 .84906 .37848 Mtetra
.187 .657 .936 r
.84132 .35764 .80531 .35399 .81003 .36489 .84525 .36807 Mtetra
.164 .643 .927 r
.83725 .3472 .80041 .34303 .80531 .35399 .84132 .35764 Mtetra
.14 .629 .916 r
.83305 .33677 .79533 .33204 .80041 .34303 .83725 .3472 Mtetra
.116 .613 .905 r
.82869 .32638 .79004 .32102 .79533 .33204 .83305 .33677 Mtetra
.09 .596 .893 r
.82416 .31605 .78453 .31001 .79004 .32102 .82869 .32638 Mtetra
.063 .578 .879 r
.81946 .30581 .77879 .29902 .78453 .31001 .82416 .31605 Mtetra
.035 .559 .865 r
.81457 .2957 .7728 .28808 .77879 .29902 .81946 .30581 Mtetra
.007 .539 .849 r
.80948 .28577 .76652 .27723 .7728 .28808 .81457 .2957 Mtetra
0 .518 .832 r
.80415 .27604 .75994 .2665 .76652 .27723 .80948 .28577 Mtetra
.346 .722 .986 r
.9175 .5081 .88973 .50622 .89233 .51526 .91964 .51687 Mtetra
.333 .715 .983 r
.91531 .49921 .88708 .49706 .88973 .50622 .9175 .5081 Mtetra
.318 .707 .98 r
.91307 .49023 .88435 .48778 .88708 .49706 .91531 .49921 Mtetra
.302 .699 .977 r
.91078 .48114 .88156 .47837 .88435 .48778 .91307 .49023 Mtetra
.286 .69 .973 r
.90844 .47197 .8787 .46884 .88156 .47837 .91078 .48114 Mtetra
.269 .68 .968 r
.90605 .46271 .87576 .45919 .8787 .46884 .90844 .47197 Mtetra
.25 .67 .963 r
.9036 .45337 .87274 .44943 .87576 .45919 .90605 .46271 Mtetra
.231 .658 .957 r
.9011 .44396 .86964 .43957 .87274 .44943 .9036 .45337 Mtetra
.21 .646 .951 r
.89853 .43448 .86645 .4296 .86964 .43957 .9011 .44396 Mtetra
.188 .632 .944 r
.8959 .42495 .86317 .41953 .86645 .4296 .89853 .43448 Mtetra
.165 .618 .935 r
.89321 .41538 .8598 .40937 .86317 .41953 .8959 .42495 Mtetra
.141 .602 .926 r
.89046 .40579 .85632 .39914 .8598 .40937 .89321 .41538 Mtetra
.116 .586 .916 r
.88763 .39618 .85275 .38884 .85632 .39914 .89046 .40579 Mtetra
.09 .568 .905 r
.88473 .38657 .84906 .37848 .85275 .38884 .88763 .39618 Mtetra
.063 .549 .892 r
.88176 .377 .84525 .36807 .84906 .37848 .88473 .38657 Mtetra
.035 .529 .879 r
.8787 .36747 .84132 .35764 .84525 .36807 .88176 .377 Mtetra
.005 .507 .864 r
.87557 .35801 .83725 .3472 .84132 .35764 .8787 .36747 Mtetra
0 .485 .848 r
.87234 .34866 .83305 .33677 .83725 .3472 .87557 .35801 Mtetra
0 .462 .831 r
.86902 .33944 .82869 .32638 .83305 .33677 .87234 .34866 Mtetra
0 .437 .813 r
.86561 .3304 .82416 .31605 .82869 .32638 .86902 .33944 Mtetra
0 .412 .794 r
.86208 .32157 .81946 .30581 .82416 .31605 .86561 .3304 Mtetra
0 .387 .774 r
.85844 .31301 .81457 .2957 .81946 .30581 .86208 .32157 Mtetra
0 .36 .754 r
.85468 .30476 .80948 .28577 .81457 .2957 .85844 .31301 Mtetra
0 .334 .732 r
.85078 .29688 .80415 .27604 .80948 .28577 .85468 .30476 Mtetra
.173 .586 .938 r
.94641 .51586 .9175 .5081 .91964 .51687 .94804 .52401 Mtetra
.15 .57 .93 r
.94475 .50765 .91531 .49921 .9175 .5081 .94641 .51586 Mtetra
.126 .552 .921 r
.94308 .49939 .91307 .49023 .91531 .49921 .94475 .50765 Mtetra
.101 .534 .911 r
.94137 .49109 .91078 .48114 .91307 .49023 .94308 .49939 Mtetra
.075 .515 .9 r
.93964 .48277 .90844 .47197 .91078 .48114 .94137 .49109 Mtetra
.048 .495 .888 r
.93789 .47442 .90605 .46271 .90844 .47197 .93964 .48277 Mtetra
.02 .473 .875 r
.93611 .46607 .9036 .45337 .90605 .46271 .93789 .47442 Mtetra
0 .45 .861 r
.93431 .45773 .9011 .44396 .9036 .45337 .93611 .46607 Mtetra
0 .426 .845 r
.93248 .44941 .89853 .43448 .9011 .44396 .93431 .45773 Mtetra
0 .402 .829 r
.93063 .44113 .8959 .42495 .89853 .43448 .93248 .44941 Mtetra
0 .376 .811 r
.92876 .43292 .89321 .41538 .8959 .42495 .93063 .44113 Mtetra
0 .349 .792 r
.92686 .4248 .89046 .40579 .89321 .41538 .92876 .43292 Mtetra
0 .322 .772 r
.92495 .41679 .88763 .39618 .89046 .40579 .92686 .4248 Mtetra
0 .293 .751 r
.92301 .40893 .88473 .38657 .88763 .39618 .92495 .41679 Mtetra
0 .265 .729 r
.92106 .40125 .88176 .377 .88473 .38657 .92301 .40893 Mtetra
0 .236 .707 r
.91909 .39378 .8787 .36747 .88176 .377 .92106 .40125 Mtetra
0 .207 .684 r
.9171 .38657 .87557 .35801 .8787 .36747 .91909 .39378 Mtetra
0 .178 .66 r
.9151 .37966 .87234 .34866 .87557 .35801 .9171 .38657 Mtetra
0 .149 .636 r
.91309 .37312 .86902 .33944 .87234 .34866 .9151 .37966 Mtetra
0 .12 .612 r
.91107 .36699 .86561 .3304 .86902 .33944 .91309 .37312 Mtetra
0 .093 .589 r
.90903 .36134 .86208 .32157 .86561 .3304 .91107 .36699 Mtetra
0 .066 .566 r
.90699 .35623 .85844 .31301 .86208 .32157 .90903 .36134 Mtetra
0 .101 .611 r
.90434 .347 .85468 .30476 .85844 .31301 .90699 .35623 Mtetra
0 .336 .815 r
.89972 .32296 .85078 .29688 .85468 .30476 .90434 .347 Mtetra
0 0 .412 r
.98473 .58548 .94641 .51586 .94804 .52401 .98544 .59034 Mtetra
0 0 .399 r
.98405 .58076 .94475 .50765 .94641 .51586 .98473 .58548 Mtetra
0 0 .387 r
.98339 .5762 .94308 .49939 .94475 .50765 .98405 .58076 Mtetra
0 0 .374 r
.98276 .57184 .94137 .49109 .94308 .49939 .98339 .5762 Mtetra
0 0 .362 r
.98216 .5677 .93964 .48277 .94137 .49109 .98276 .57184 Mtetra
0 0 .351 r
.9816 .56382 .93789 .47442 .93964 .48277 .98216 .5677 Mtetra
0 0 .339 r
.98108 .56021 .93611 .46607 .93789 .47442 .9816 .56382 Mtetra
0 0 .328 r
.98061 .55693 .93431 .45773 .93611 .46607 .98108 .56021 Mtetra
0 0 .317 r
.98018 .55401 .93248 .44941 .93431 .45773 .98061 .55693 Mtetra
0 0 .307 r
.97982 .5515 .93063 .44113 .93248 .44941 .98018 .55401 Mtetra
0 0 .297 r
.97952 .54945 .92876 .43292 .93063 .44113 .97982 .5515 Mtetra
.97912 .54662 .92686 .4248 .92876 .43292 .97952 .54945 Mtetra
0 0 .382 r
.97693 .53152 .92495 .41679 .92686 .4248 .97912 .54662 Mtetra
0 0 .403 r
.97466 .51581 .92301 .40893 .92495 .41679 .97693 .53152 Mtetra
0 0 .429 r
.9723 .49946 .92106 .40125 .92301 .40893 .97466 .51581 Mtetra
0 0 .461 r
.96984 .48244 .91909 .39378 .92106 .40125 .9723 .49946 Mtetra
0 0 .501 r
.96727 .46469 .9171 .38657 .91909 .39378 .96984 .48244 Mtetra
0 0 .554 r
.96459 .44617 .9151 .37966 .9171 .38657 .96727 .46469 Mtetra
0 .061 .623 r
.9618 .42683 .91309 .37312 .9151 .37966 .96459 .44617 Mtetra
0 .185 .715 r
.95888 .40661 .91107 .36699 .91309 .37312 .9618 .42683 Mtetra
0 .366 .834 r
.95582 .38545 .90903 .36134 .91107 .36699 .95888 .40661 Mtetra
.242 .615 .956 r
.95262 .36329 .90699 .35623 .90903 .36134 .95582 .38545 Mtetra
.478 .816 .999 r
.94926 .34005 .90434 .347 .90699 .35623 .95262 .36329 Mtetra
.94573 .31565 .89972 .32296 .90434 .347 .94926 .34005 Mtetra
.4 g
.90106 .00661 m
.06031 .18242 L
s
.91227 .08418 m
.04496 .25451 L
s
.92428 .16729 m
.02868 .33103 L
s
.93719 .25657 m
.01136 .41238 L
s
.9001 0 m
.94573 .31565 L
s
.71232 .03947 m
.73085 .34976 L
s
.53546 .07665 m
.53011 .38162 L
s
.36859 .11172 m
.34215 .41145 L
s
.21089 .14487 m
.16579 .43944 L
s
.06162 .17625 m
0 .46575 L
s
0 g
.9001 0 m
.94573 .31565 L
s
.94573 .31565 m
0 .46575 L
s
0 .46575 m
.06162 .17625 L
s
.06162 .17625 m
.9001 0 L
s
.4 g
.90106 .00661 m
.96643 .45888 L
s
.91227 .08418 m
.97515 .51921 L
s
.92428 .16729 m
.98427 .5823 L
s
.93719 .25657 m
.99382 .64835 L
s
.9001 0 m
.94573 .31565 L
s
.9222 .15287 m
.96459 .44617 L
s
.9397 .27398 m
.97912 .54662 L
s
.95391 .37228 m
.99064 .62632 L
s
.96568 .45367 m
1 .6911 L
s
0 g
.9001 0 m
.94573 .31565 L
s
.94573 .31565 m
1 .6911 L
s
1 .6911 m
.96568 .45367 L
s
.96568 .45367 m
.9001 0 L
s
.4 g
.94573 .31565 m
0 .46575 L
s
.96459 .44617 m
.12312 .56199 L
s
.97912 .54662 m
.22126 .63871 L
s
.99064 .62632 m
.30132 .70129 L
s
1 .6911 m
.36788 .75332 L
s
.94573 .31565 m
1 .6911 L
s
.73085 .34976 m
.86268 .70462 L
s
.53011 .38162 m
.73115 .71756 L
s
.34215 .41145 m
.60506 .72998 L
s
.16579 .43944 m
.48407 .74189 L
s
0 .46575 m
.36788 .75332 L
s
0 g
.9001 0 m
.94573 .31565 L
s
.90106 .00661 m
.89401 .00808 L
s
[(0)] .91515 .00366 -1 .20911 Mshowa
.91227 .08418 m
.9052 .08557 L
s
[(0.02)] .9264 .0814 -1 .19639 Mshowa
.92428 .16729 m
.9172 .16859 L
s
[(0.04)] .93845 .1647 -1 .18282 Mshowa
.93719 .25657 m
.93009 .25777 L
s
[(0.06)] .95139 .25418 -1 .16829 Mshowa
.125 Mabswid
.90379 .02551 m
.89956 .02638 L
s
.90657 .04473 m
.90233 .04559 L
s
.90939 .06429 m
.90516 .06513 L
s
.91519 .10441 m
.91095 .10523 L
s
.91817 .12501 m
.91393 .12581 L
s
.9212 .14596 m
.91695 .14675 L
s
.92742 .18901 m
.92317 .18977 L
s
.93062 .21112 m
.92636 .21187 L
s
.93387 .23364 m
.92962 .23437 L
s
.94057 .27994 m
.9363 .28064 L
s
.94401 .30374 m
.93974 .30443 L
s
gsave
1.00638 .13164 -61 -11.4128 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(IRF) show
81.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 216.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001AB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooomN0?ooo`@00000C`3oool00?l0ooooG@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo04`0oooo003o0?oooed0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1<0?ooo`00o`3ooomM0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0C03oool00?l0ooooG@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
04`0oooo003Q0?ooo`<00000N03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04`0
oooo002R0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0MP3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo04`0oooo002R0?ooo`800000?`3oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0C03oool00800oooo10000002
0?ooo`L0000000D0oooo00000000000000000?ooo`02000000030?ooo`000000000000<0oooo1000
00050?ooo`030000003oool0oooo00d0oooo1`0000020?ooo`<000000P3oool3000000/0oooo0`00
00000`3oool00000000000040?ooo`D000001@3oool2000000D0oooo1@00001^0?ooo`@00000C`3o
ool007l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool00P3oool200000140oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool0oooo0P0000040?ooo`05
0000003oool0oooo0?ooo`0000001P3oool2000000D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`2n0?ooo`00O`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000001`0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001@3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0;h0oooo001o0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo0?ooo`H000005`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo100000050?ooo`040000003oool0oooo000000D0oooo100000310?ooo`00O`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo0P0000001@3oool000000000003oool00000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00@0oooo0P0000030?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool0oooo0P000004
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`2n0?ooo`00O@3oool7000000<0oooo0`00
00040?ooo`80000000D0oooo0000003oool0oooo000000050?ooo`@000005P3oool3000000D0oooo
0P000000103oool0000000000000000=0?ooo`<0000000<0oooo0000003oool0103oool3000000@0
oooo0`0000020?ooo`<000000`3oool5000007P0oooo100000140?ooo`00O`3oool00`000000oooo
0?ooo`1A0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`110?ooo`00O`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo03H0oooo1P00
00040?ooo`@000001@3oool4000004@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`110?ooo`00R@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01T0oooo0P00000h
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0@@3oool008T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool0>@3oool3000000D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`110?ooo`00o`3oool?0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
=03oool500000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0440oooo003o0?oooa00oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0`0?ooo`@00000
1`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
@@3oool00?l0oooo4@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02/0oooo1@0000080?ooo`@00000
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo003o0?ooo`d0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo02H0oooo1@0000090?ooo`D0IVIV0P3oool00`1VIVH0
00000?ooo`040?ooo`@00000A03oool00?l0oooo3@3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool08@3oool500000080oooo00<000000?ooo`3oool0103oool506IVIPL0oooo00<0IVIV0000
003oool0C03oool00?l0oooo3P3oool4000000D0oooo100000050?ooo`@00000803oool4000000P0
oooo00<000000?ooo`1VIVH00`1VIVH<0?ooo`0306IVIP000000oooo04`0oooo003o0?ooocl0oooo
1@0000090?ooo`D0IVIV4@3oool00`000000oooo0?ooo`1;0?ooo`00o`3ooolj0?ooo`D000002@3o
ool506IVIQH0oooo00<000000?ooo`3oool0B`3oool00?l0oooo=@3oool5000000@0oooo00<00000
0?ooo`3oool00P3oool506IVIQ/0oooo00<000000?ooo`3oool0B`3oool00?l0oooo<@3oool40000
00T0oooo1@1VIVHO0?ooo`800000C@3oool00?l0oooo;03oool5000000P0oooo1@1VIVHU0?ooo`03
06IVIP000000oooo04/0oooo003<0?ooo`@00000103oool4000000D0oooo100000150?ooo`H00000
1`3oool506IVIRX0oooo00<0IVIV0000003oool0B`3oool00<h0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`0m0?ooo`D000001@3oool010000000oooo0?ooo`3oool406IVIRl0oooo00<0IVIV0000003o
ool0B`3oool00<h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0h0?ooo`D000002@3oool506IVIS@0
oooo00<000000?ooo`3oool0BP3oool00<X0oooo1P0000030?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo03@0oooo100000090?ooo`D0
IVIV>@3oool00`000000oooo0?ooo`1:0?ooo`00b`3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
02l0oooo1@0000000`3oool0IVIV0?ooo`050?ooo`D0IVIV?P3oool00`000000oooo0?ooo`1:0?oo
o`00b`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo02X0oooo1@0000060?ooo`L0IVIV@P3oool2
000004`0oooo003<0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool09@3oool5000000P0oooo1@1VIVI8
0?ooo`0306IVIP000000oooo04X0oooo003<0?ooo`030000003oool0000000@0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool08@3oool4
000000T0oooo101VIVH30?ooo`80IVIVB03oool00`1VIVH000000?ooo`1:0?ooo`00c@3oool20000
00D0oooo100000050?ooo`@000007`3oool5000000<0oooo00<000000?ooo`3oool00P3oool506IV
IPL0oooo0P1VIVI80?ooo`0306IVIP000000oooo04X0oooo003k0?ooo`D00000203oool506IVIP`0
oooo00<0IVIV0?ooo`1VIVH0B03oool00`000000oooo0?ooo`190?ooo`00mP3oool5000000P0oooo
1@1VIVHA0?ooo`0306IVIP3oool0IVIV04P0oooo00<000000?ooo`3oool0B@3oool00?80oooo1000
00000`3oool000000?ooo`050?ooo`D0IVIV5P3oool00`1VIVH0oooo06IVIP180?ooo`030000003o
ool0oooo04T0oooo003]0?ooo`D000001@3oool00`000000oooo06IVIP0406IVIQ`0oooo00<0IVIV
0?ooo`1VIVH0A`3oool00`000000oooo0?ooo`190?ooo`00SP3oool4000000@0oooo100000050?oo
o`@00000A@3oool5000000L0oooo1@1VIVHQ0?ooo`0306IVIP3oool0IVIV04H0oooo00<0000006IV
IP000000BP3oool008d0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0m0?ooo`D00000203oool4
06IVIRH0oooo00<0IVIV0?ooo`1VIVH0A`3oool00`1VIVH000000?ooo`060?ooo`@000001P3oool2
000000H0oooo100000040?ooo`H000008`3oool008d0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`0i0?ooo`@00000103oool010000000oooo0?ooo`3oool506IVIRX0oooo00@0IVIV0?ooo`3oool0
IVIVAP3oool00`1VIVH000000?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool2000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool08@3oool008d0oooo0P0000030?ooo`040000003oool0oooo0000
00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo03@0oooo1@000007
0?ooo`D0IVIV;`3oool0101VIVH0oooo0?ooo`1VIVI70?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0U0?ooo`00S@3oool00`000000oooo00000002
000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool0;`3oool5000000L0oooo1@1VIVHd0?ooo`0406IVIP3oool0oooo06IVITL0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02@0oooo
002=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool0:P3oool5000000030?ooo`1VIVH0oooo00@0oooo
1@1VIVHi0?ooo`0406IVIP3oool0oooo06IVITL0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo002>0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool09P3oool4000000H0oooo1P1VIVHn0?ooo`0506IVIP3oool0oooo0?ooo`1VIVH0AP3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08P3oool008l0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`0Q0?ooo`D000001P3oool606IVIT80oooo00D0IVIV0?oo
o`3oool0oooo06IVIP140?ooo`80IVIV0P0000050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`0Q0?ooo`00T03oool3000000<0oooo100000050?ooo`@000007`3oool5
000000L0oooo101VIVH40?ooo`0306IVIP3oool0IVIV0440oooo00D0IVIV0?ooo`3oool0oooo06IV
IP0o0?ooo`D0IVIV0P0000000`1VIVH000000?ooo`040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`0Q0?ooo`00_@3oool5000000@0oooo00<000000?ooo`3oool01@1V
IVH80?ooo`0306IVIP3oool0IVIV0440oooo00<0IVIV0?ooo`3oool00P3oool00`1VIVH0oooo0?oo
o`0g0?ooo`D0IVIV1`3oool00`1VIVH000000?ooo`050?ooo`@000003P3oool4000000D0oooo1000
000T0?ooo`00^03oool5000000L0oooo1@1VIVH=0?ooo`0406IVIP3oool0oooo06IVIT00oooo00<0
IVIV0?ooo`3oool00P3oool00`1VIVH0oooo0?ooo`0b0?ooo`D0IVIV303oool00`1VIVH000000?oo
o`180?ooo`00]03oool4000000L0oooo1@1VIVHB0?ooo`0406IVIP3oool0oooo06IVIT00oooo00<0
IVIV0?ooo`3oool00P3oool00`1VIVH0oooo0?ooo`0]0?ooo`D0IVIV4P3oool00`000000oooo0?oo
o`170?ooo`00[`3oool500000080oooo00@000000?ooo`3oool0oooo1@1VIVHG0?ooo`0506IVIP3o
ool0oooo0?ooo`1VIVH0?`3oool00`1VIVH0oooo0?ooo`030?ooo`0306IVIP3oool0oooo02L0oooo
1@1VIVHG0?ooo`030000003oool0oooo04L0oooo001B0?ooo`@000001@3oool4000000D0oooo1000
00120?ooo`D000001P3oool506IVIQ`0oooo00D0IVIV0?ooo`3oool0oooo06IVIP0o0?ooo`0306IV
IP3oool0oooo00<0oooo00<0IVIV0?ooo`3oool08P3oool506IVIQ`0oooo00<000000?ooo`3oool0
A`3oool00540oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo03X0oooo1@0000070?ooo`@0
IVIV8@3oool01@1VIVH0oooo0?ooo`3oool0IVIV03l0oooo00<0IVIV0?ooo`3oool00`3oool00`1V
IVH0oooo0?ooo`0M0?ooo`D0IVIV8@3oool00`1VIVH000000?ooo`170?ooo`00D@3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool0=P3oool4000000030?ooo`000000oooo00@0oooo1@1VIVHU
0?ooo`0306IVIP3oool0oooo0080oooo00<0IVIV0?ooo`3oool0?03oool00`1VIVH0oooo0?ooo`03
0?ooo`0306IVIP3oool0oooo01L0oooo1P1VIVHU0?ooo`<00000B03oool00540oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo0340oooo1@0000050?ooo`030000001VIVH0IVIV00<0IVIV:P3o
ool00`1VIVH0oooo0?ooo`020?ooo`0306IVIP3oool0oooo03d0oooo00<0IVIV0?ooo`3oool00`3o
ool00`1VIVH0oooo0?ooo`0A0?ooo`D0IVIV;03oool00`1VIVH000000?ooo`170?ooo`00DP3oool4
000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool0;03oool5000000H0oooo1@1VIVH_0?ooo`0306IVIP3oool0oooo00<0oooo00<0
IVIV0?ooo`3oool0?03oool00`1VIVH0oooo0?ooo`030?ooo`0306IVIP3oool0oooo00`0oooo1@1V
IVHa0?ooo`0306IVIP000000oooo04L0oooo001A0?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`0W0?ooo`D0000000<0IVIV0?ooo`3oool00`3oool506IVIS@0oooo00<0IVIV0?ooo`3oool0
0`3oool00`1VIVH0oooo0?ooo`0l0?ooo`0306IVIP3oool0oooo00<0oooo00<0IVIV0?ooo`3oool0
1`3oool506IVISL0oooo00<000000?ooo`3oool0AP3oool00540oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo02<0oooo100000040?ooo`030000001VIVH0IVIV00@0IVIV>@3oool00`1VIVH0
oooo0?ooo`040?ooo`0306IVIP3oool0oooo03/0oooo00<0IVIV0?ooo`3oool0103oool0101VIVH0
oooo0?ooo`3oool506IVIS`0oooo00<000000?ooo`3oool0AP3oool00540oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo01h0oooo1@0000050?ooo`H0IVIV?@3oool00`1VIVH0oooo0?ooo`04
0?ooo`0306IVIP3oool0oooo03/0oooo00<0IVIV0?ooo`3oool00`3oool506IVIT40oooo0P000017
0?ooo`00DP3oool4000000D0oooo100000050?ooo`@00000703oool5000000H0oooo101VIVH40?oo
o`0306IVIP3oool0IVIV03`0oooo00<0IVIV0?ooo`3oool01@3oool00`1VIVH0oooo0?ooo`0j0?oo
o`H0IVIV00<0oooo06IVIP3oool0@`3oool00`1VIVH000000?ooo`0S0?ooo`L000000P3oool30000
00<0oooo0P0000000`3oool0000000000002000000d0oooo001o0?ooo`D000000`3oool00`000000
oooo0?ooo`0506IVIPP0oooo00<0IVIV0?ooo`1VIVH0?03oool00`1VIVH0oooo0?ooo`050?ooo`03
06IVIP3oool0oooo03H0oooo1@1VIVH70?ooo`0306IVIP3oool0oooo0440oooo00<0IVIV0000003o
ool09P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo0000000?0?ooo`00N`3oool4000000H0oooo1@1VIVH=0?ooo`0406IVIP3oool0oooo06IV
IS/0oooo00<0IVIV0?ooo`3oool01P3oool00`1VIVH0oooo0?ooo`0`0?ooo`D0IVIV103oool00`1V
IVH0oooo0?ooo`050?ooo`0306IVIP3oool0oooo0400oooo0`00000W0?ooo`030000003oool0oooo
00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00d0oooo001f0?oo
o`D000001@3oool506IVIQ40oooo00<0IVIV0?ooo`3oool00P3oool00`1VIVH0oooo0?ooo`0h0?oo
o`0306IVIP3oool0oooo00H0oooo00<0IVIV0?ooo`3oool0:`3oool506IVIPT0oooo00<0IVIV0?oo
o`3oool01@3oool00`1VIVH0oooo0?ooo`110?ooo`0306IVIP000000oooo02H0oooo00<000000?oo
o`3oool0103oool4000000D0oooo00@000000?ooo`3oool00000303oool001H0oooo1`0000030?oo
o`@000001@3oool4000000D0oooo1000000k0?ooo`D000000P3oool00`000000oooo0?ooo`0506IV
IQH0oooo00<0IVIV0?ooo`3oool00P3oool00`1VIVH0oooo0?ooo`0h0?ooo`0306IVIP3oool0oooo
00H0oooo00<0IVIV0?ooo`3oool09P3oool506IVIPh0oooo00<0IVIV0?ooo`3oool01@3oool00`1V
IVH0oooo0?ooo`120?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0103oool01@00
0000oooo0?ooo`3oool0000000@0oooo1000000<0?ooo`006@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`0c0?ooo`D000001@3oool506IVIQ/0oooo00<0
IVIV0?ooo`3oool00`3oool00`1VIVH0oooo0?ooo`0g0?ooo`0306IVIP3oool0oooo00L0oooo00<0
IVIV0?ooo`3oool0803oool506IVIQ<0oooo00<0IVIV0?ooo`3oool01P3oool00`1VIVH0oooo0?oo
o`110?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0103oool01@000000oooo0?oo
o`3oool0000000@0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`006@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0_0?ooo`@000001P3oool4
06IVIR00oooo00<0IVIV0?ooo`3oool00`3oool00`1VIVH0oooo0?ooo`0g0?ooo`0306IVIP3oool0
oooo00L0oooo00<0IVIV0?ooo`3oool06`3oool506IVIQP0oooo00<0IVIV0?ooo`3oool01P3oool0
0`1VIVH0oooo0?ooo`110?ooo`8000009P3oool00`000000oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo000I
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02X0oooo
1@0000000`3oool000000?ooo`020?ooo`D0IVIV903oool00`1VIVH0oooo0?ooo`040?ooo`0306IV
IP3oool0oooo03H0oooo00<0IVIV0?ooo`3oool0203oool00`1VIVH0oooo0?ooo`0E0?ooo`D0IVIV
7@3oool00`1VIVH0oooo0?ooo`060?ooo`0306IVIP3oool0oooo0440oooo00<0IVIV0000003oool0
8P3oool700000080oooo1@0000040?ooo`L000002P3oool001T0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool09@3oool5000000D0oooo1@1VIVHY0?ooo`03
06IVIP3oool0oooo00D0oooo00<0IVIV0?ooo`3oool0=@3oool00`1VIVH0oooo0?ooo`080?ooo`03
06IVIP3oool0oooo0100oooo1@1VIVHR0?ooo`0306IVIP3oool0oooo00L0oooo00<0IVIV0?ooo`3o
ool0@03oool00`1VIVH000000?ooo`150?ooo`006@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`0P0?ooo`D000001@3oool506IVIRh0oooo00<0IVIV0?oo
o`3oool01@3oool00`1VIVH0oooo0?ooo`0e0?ooo`0306IVIP3oool0oooo00T0oooo00<0IVIV0?oo
o`3oool02P3oool506IVIRL0oooo00<0IVIV0?ooo`3oool01`3oool00`1VIVH0oooo0?ooo`100?oo
o`0306IVIP000000oooo04D0oooo000I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo01/0oooo1@0000020?ooo`80IVIV00<0oooo06IVIP1VIVH00`1VIVHc
0?ooo`0306IVIP3oool0oooo00H0oooo00<0IVIV0?ooo`3oool0=03oool00`1VIVH0oooo0?ooo`09
0?ooo`0306IVIP3oool0oooo00@0oooo1P1VIVH/0?ooo`0306IVIP3oool0oooo00L0oooo00<0IVIV
0?ooo`3oool0?`3oool3000004H0oooo000G0?ooo`<000001@3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool05`3oool4000000D0oooo1@1VIVHh0?ooo`0306IVIP3oool0oooo00H0oooo00<0
IVIV0?ooo`3oool0=03oool00`1VIVH0oooo0?ooo`0:0?ooo`H0IVIV<P3oool00`1VIVH0oooo0?oo
o`080?ooo`0306IVIP3oool0oooo0400oooo00<000000?ooo`3oool0A03oool001T0oooo00<00000
0?ooo`3oool0103oool4000000D0oooo100000050?ooo`@000005@3oool5000000@0oooo1@1VIVH0
1@3oool0000006IVIP3oool0IVIV03P0oooo00<0IVIV0?ooo`3oool01`3oool00`1VIVH0oooo0?oo
o`0b0?ooo`0306IVIP3oool0oooo00L0oooo1@1VIVHh0?ooo`0306IVIP3oool0oooo00L0oooo00<0
IVIV0?ooo`3oool0?P3oool206IVIP030000003oool0oooo00D0oooo100000060?ooo`8000001P3o
ool4000000H0oooo1000000O0?ooo`00AP3oool5000000030?ooo`000000oooo0080oooo101VIVH6
0?ooo`0506IVIP3oool0oooo0?ooo`1VIVH0=`3oool00`1VIVH0oooo0?ooo`080?ooo`0306IVIP3o
ool0oooo0340oooo00<0IVIV0?ooo`3oool00P3oool506IVIP@0oooo00<0IVIV0?ooo`3oool0=P3o
ool00`1VIVH0oooo0?ooo`070?ooo`0306IVIP3oool0oooo03P0oooo1P1VIVH20?ooo`8000001@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0N0?ooo`00@@3oool5
000000D0oooo1@1VIVH:0?ooo`0306IVIP3oool0oooo0080oooo00<0IVIV0?ooo`3oool0=03oool0
0`1VIVH0oooo0?ooo`080?ooo`0306IVIP3oool0oooo0340oooo1@1VIVH:0?ooo`0306IVIP3oool0
oooo03D0oooo00<0IVIV0?ooo`3oool01`3oool00`1VIVH0oooo0?ooo`0c0?ooo`D0IVIV203oool2
000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0N0?ooo`00?@3oool40000
00D0oooo1@1VIVH?0?ooo`0306IVIP3oool0oooo0080oooo00<0IVIV0?ooo`3oool0<`3oool00`1V
IVH0oooo0?ooo`0:0?ooo`0306IVIP3oool0oooo02/0oooo1P1VIVH>0?ooo`0306IVIP3oool0oooo
03D0oooo00<0IVIV0?ooo`3oool0203oool00`1VIVH0oooo0?ooo`0]0?ooo`D0IVIV3@3oool00`1V
IVH000000?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`H000007`3oool003P0oooo1@000000103o
ool000000?ooo`3oool506IVIQ@0oooo00<0IVIV0?ooo`3oool00`3oool00`1VIVH0oooo0?ooo`0b
0?ooo`0306IVIP3oool0oooo00X0oooo00<0IVIV0?ooo`3oool09P3oool506IVIPD0oooo00<0IVIV
0?ooo`3oool03@3oool00`1VIVH0oooo0?ooo`0d0?ooo`0306IVIP3oool0oooo00P0oooo00<0IVIV
0?ooo`3oool09`3oool606IVIQ80oooo00<0IVIV0000003oool0103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000200oooo000c0?ooo`D00000103oool506IVIQT0oooo00<0IVIV
0?ooo`3oool0103oool00`1VIVH0oooo0?ooo`0a0?ooo`0306IVIP3oool0oooo00/0oooo00<0IVIV
0?ooo`3oool0803oool506IVIPX0oooo00<0IVIV0?ooo`3oool03@3oool00`1VIVH0oooo0?ooo`0d
0?ooo`0306IVIP3oool0oooo00P0oooo00<0IVIV0?ooo`3oool08P3oool506IVIQP0oooo00<0IVIV
0000003oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000200oooo000^
0?ooo`D00000103oool506IVIQh0oooo00<0IVIV0?ooo`3oool01@3oool00`1VIVH0oooo0?ooo`0`
0?ooo`0306IVIP3oool0oooo00`0oooo00<0IVIV0?ooo`3oool06P3oool506IVIPl0oooo00<0IVIV
0?ooo`3oool03P3oool00`1VIVH0oooo0?ooo`0c0?ooo`0306IVIP3oool0oooo00T0oooo00<0IVIV
0?ooo`3oool06`3oool606IVIQ/0oooo100000050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`000000803oool002X0oooo10000000103oool000000?ooo`3oool506IVIR80oooo00<0IVIV
0?ooo`3oool01P3oool00`1VIVH0oooo0?ooo`0`0?ooo`0306IVIP3oool0oooo00`0oooo00<0IVIV
0?ooo`3oool05@3oool506IVIQ@0oooo00<0IVIV0?ooo`3oool03P3oool00`1VIVH0oooo0?ooo`0c
0?ooo`0306IVIP3oool0oooo00T0oooo00<0IVIV0?ooo`3oool05P3oool506IVIQ`0oooo1P1VIVH2
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000P
0?ooo`009@3oool5000000@0oooo101VIVHW0?ooo`0306IVIP3oool0oooo00L0oooo00<0IVIV0?oo
o`3oool0;`3oool00`1VIVH0oooo0?ooo`0=0?ooo`0306IVIP3oool0oooo00l0oooo1@1VIVHI0?oo
o`0306IVIP3oool0oooo00l0oooo00<0IVIV0?ooo`3oool0<P3oool00`1VIVH0oooo0?ooo`090?oo
o`0306IVIP3oool0oooo0100oooo1P1VIVHL0?ooo`D0IVIV203oool2000000D0oooo1000000>0?oo
o`@000001`3oool200000200oooo000R0?ooo`<00000103oool506IVIR/0oooo00<0IVIV0?ooo`3o
ool0203oool00`1VIVH0oooo0?ooo`0^0?ooo`0306IVIP3oool0oooo00d0oooo00<0IVIV0?ooo`3o
ool02P3oool506IVIQh0oooo00<0IVIV0?ooo`3oool03`3oool00`1VIVH0oooo0?ooo`0b0?ooo`03
06IVIP3oool0oooo00X0oooo00<0IVIV0?ooo`3oool02P3oool506IVIQ`0oooo1P1VIVH=0?ooo`80
0000A03oool00280oooo00<0000006IVIP1VIVH0101VIVH`0?ooo`0306IVIP3oool0oooo00T0oooo
00<0IVIV0?ooo`3oool0;@3oool00`1VIVH0oooo0?ooo`0>0?ooo`0306IVIP3oool0oooo00@0oooo
1@1VIVHS0?ooo`0306IVIP3oool0oooo00l0oooo00<0IVIV0?ooo`3oool0<P3oool00`1VIVH0oooo
0?ooo`0:0?ooo`0306IVIP3oool0oooo00D0oooo1@1VIVHL0?ooo`D0IVIV4`3oool00`1VIVH00000
0?ooo`130?ooo`008@3oool0101VIVH0000006IVIP1VIVHd0?ooo`0306IVIP3oool0oooo00T0oooo
00<0IVIV0?ooo`3oool0;@3oool00`1VIVH0oooo0?ooo`0?0?ooo`H0IVIV:03oool00`1VIVH0oooo
0?ooo`0@0?ooo`0306IVIP3oool0oooo0340oooo00<0IVIV0?ooo`3oool02P3oool00`1VIVH0oooo
06IVIP0506IVIQ/0oooo1P1VIVHH0?ooo`0306IVIP000000oooo04<0oooo000Q0?ooo`050000001V
IVH0oooo0?ooo`1VIVH0<`3oool00`1VIVH0oooo0?ooo`0:0?ooo`0306IVIP3oool0oooo02`0oooo
00<0IVIV0?ooo`3oool02`3oool506IVIRd0oooo00<0IVIV0?ooo`3oool0403oool00`1VIVH0oooo
0?ooo`0a0?ooo`0306IVIP3oool0oooo00L0oooo1@1VIVHL0?ooo`D0IVIV7P3oool00`1VIVH00000
0?ooo`130?ooo`008@3oool00`000000oooo06IVIP020?ooo`0306IVIP3oool0oooo02l0oooo00<0
IVIV0?ooo`3oool0303oool00`1VIVH0oooo0?ooo`0[0?ooo`0306IVIP3oool0oooo00H0oooo1@1V
IVH50?ooo`0306IVIP3oool0oooo02X0oooo00<0IVIV0?ooo`3oool04@3oool00`1VIVH0oooo0?oo
o`0`0?ooo`0406IVIP3oool0oooo0?ooo`H0IVIV103oool00`1VIVH0oooo0?ooo`0D0?ooo`H0IVIV
903oool00`000000oooo0?ooo`120?ooo`008@3oool01P000000oooo0?ooo`1VIVH0oooo06IVIS40
oooo00<0IVIV0?ooo`3oool03@3oool00`1VIVH0oooo0?ooo`0Y0?ooo`0306IVIP3oool0oooo0080
oooo1@1VIVH:0?ooo`0306IVIP3oool0oooo02X0oooo00<0IVIV0?ooo`3oool04@3oool00`1VIVH0
oooo0?ooo`0_0?ooo`D0IVIV2P3oool00`1VIVH0oooo0?ooo`0?0?ooo`D0IVIV:@3oool2000004@0
oooo000Q0?ooo`070000003oool0oooo0?ooo`1VIVH0oooo06IVIP0`0?ooo`0306IVIP3oool0oooo
00d0oooo00<0IVIV0?ooo`3oool0:03oool606IVIQ00oooo00<0IVIV0?ooo`3oool0:@3oool00`1V
IVH0oooo0?ooo`0B0?ooo`0306IVIP3oool0oooo02T0oooo1@1VIVH00`3oool0IVIV0?ooo`0<0?oo
o`0306IVIP3oool0oooo00T0oooo1P1VIVH_0?ooo`800000@`3oool00200oooo00<000000?ooo`3o
ool00`3oool00`1VIVH0oooo06IVIP0_0?ooo`0306IVIP3oool0oooo00h0oooo00<0IVIV0?ooo`3o
ool08P3oool506IVIP030?ooo`1VIVH0oooo01@0oooo00<0IVIV0?ooo`3oool0:03oool00`1VIVH0
oooo0?ooo`0B0?ooo`0306IVIP3oool0oooo02<0oooo1P1VIVH60?ooo`0306IVIP3oool0oooo00`0
oooo00<0IVIV0?ooo`3oool00`3oool506IVISD0oooo0P0000130?ooo`00803oool00`000000oooo
0?ooo`030?ooo`0406IVIP3oool0oooo06IVIRh0oooo00<0IVIV0?ooo`3oool03`3oool00`1VIVH0
oooo0?ooo`0L0?ooo`D0IVIV1P3oool00`1VIVH0oooo0?ooo`0C0?ooo`0306IVIP3oool0oooo02P0
oooo00<0IVIV0?ooo`3oool04`3oool00`1VIVH0oooo0?ooo`0M0?ooo`D0IVIV3@3oool00`1VIVH0
oooo0?ooo`0;0?ooo`H0IVIV>P3oool00`1VIVH000000?ooo`120?ooo`00803oool00`000000oooo
0?ooo`040?ooo`0406IVIP3oool0oooo06IVIRd0oooo00<0IVIV0?ooo`3oool0403oool00`1VIVH0
oooo0?ooo`0F0?ooo`D0IVIV2`3oool00`1VIVH0oooo0?ooo`0D0?ooo`0306IVIP3oool0oooo02L0
oooo00<0IVIV0?ooo`3oool04`3oool00`1VIVH0oooo0?ooo`0G0?ooo`H0IVIV4P3oool00`1VIVH0
oooo0?ooo`060?ooo`H0IVIV?`3oool00`1VIVH000000?ooo`120?ooo`00803oool00`000000oooo
0?ooo`050?ooo`0406IVIP3oool0oooo06IVIR/0oooo00<0IVIV0?ooo`3oool04@3oool00`1VIVH0
oooo0?ooo`0A0?ooo`D0IVIV403oool00`1VIVH0oooo0?ooo`0D0?ooo`0306IVIP3oool0oooo02L0
oooo00<0IVIV0?ooo`3oool0503oool00`1VIVH0oooo0?ooo`0A0?ooo`D0IVIV603oool00`1VIVH0
oooo0?ooo`0606IVIPH0oooo00<0IVIV0?ooo`3oool0?@3oool00`000000oooo0?ooo`110?ooo`00
803oool00`000000oooo0?ooo`060?ooo`0406IVIP3oool0oooo06IVIRX0oooo00<0IVIV0?ooo`3o
ool04P3oool00`1VIVH0oooo0?ooo`0;0?ooo`D0IVIV5@3oool00`1VIVH0oooo0?ooo`0E0?ooo`03
06IVIP3oool0oooo02H0oooo00<0IVIV0?ooo`3oool0503oool00`1VIVH0oooo0?ooo`0;0?ooo`H0
IVIV6`3oool506IVIP`0oooo00<0IVIV0?ooo`3oool0?@3oool00`000000oooo0?ooo`110?ooo`00
7`3oool00`000000oooo0?ooo`080?ooo`0406IVIP3oool0oooo06IVIRT0oooo00<0IVIV0?ooo`3o
ool04`3oool00`1VIVH0oooo0?ooo`050?ooo`D0IVIV6P3oool00`1VIVH0oooo0?ooo`0F0?ooo`03
06IVIP3oool0oooo02D0oooo00<0IVIV0?ooo`3oool0503oool00`1VIVH0oooo0?ooo`060?ooo`D0
IVIV6`3oool606IVIP80oooo00<0IVIV0?ooo`3oool0303oool00`1VIVH0oooo0?ooo`0m0?ooo`03
0000003oool0oooo0440oooo000O0?ooo`030000003oool0oooo00T0oooo00@0IVIV0?ooo`3oool0
IVIV:03oool00`1VIVH0oooo0?ooo`0D0?ooo`0306IVIP3oool0IVIV00@0IVIV7`3oool00`1VIVH0
oooo0?ooo`0F0?ooo`0306IVIP3oool0oooo02D0oooo00<0IVIV0?ooo`3oool05@3oool00`1VIVH0
oooo0?ooo`0506IVIQ/0oooo1@1VIVH80?ooo`0306IVIP3oool0oooo00`0oooo00<0IVIV0?ooo`3o
ool0?@3oool200000480oooo000O0?ooo`030000003oool0oooo00X0oooo00@0IVIV0?ooo`3oool0
IVIV9`3oool00`1VIVH0oooo0?ooo`0A0?ooo`D0IVIV903oool00`1VIVH0oooo0?ooo`0G0?ooo`03
06IVIP3oool0oooo02@0oooo00<0IVIV0?ooo`3oool04P3oool606IVIQX0oooo1P1VIVH=0?ooo`03
06IVIP3oool0oooo00d0oooo00<0IVIV0?ooo`3oool0>`3oool300000480oooo000O0?ooo`030000
003oool0oooo00/0oooo00<0IVIV0?ooo`1VIVH09`3oool00`1VIVH0oooo0?ooo`0<0?ooo`D0IVIV
103oool00`1VIVH0oooo0?ooo`0R0?ooo`0306IVIP3oool0oooo01L0oooo00<0IVIV0?ooo`3oool0
903oool00`1VIVH0oooo0?ooo`0=0?ooo`D0IVIV103oool00`1VIVH0oooo0?ooo`0D0?ooo`D0IVIV
4`3oool00`1VIVH0oooo0?ooo`0=0?ooo`0306IVIP3oool0oooo03`0oooo00<0IVIV0000003oool0
@@3oool001l0oooo00<000000?ooo`3oool0303oool00`1VIVH0oooo06IVIP0U0?ooo`0306IVIP3o
ool0oooo00P0oooo1@1VIVH:0?ooo`0306IVIP3oool0oooo0200oooo00<0IVIV0?ooo`3oool06@3o
ool00`1VIVH0oooo0?ooo`0S0?ooo`0306IVIP3oool0oooo00L0oooo1P1VIVH90?ooo`0306IVIP3o
ool0oooo00h0oooo1P1VIVHH0?ooo`0306IVIP3oool0oooo00d0oooo00<0IVIV0?ooo`3oool0?03o
ool00`1VIVH000000?ooo`110?ooo`007P3oool00`000000oooo0?ooo`0>0?ooo`0306IVIP3oool0
IVIV02@0oooo00<0IVIV0?ooo`3oool00`3oool506IVIQ00oooo00<0IVIV0?ooo`3oool07`3oool0
0`1VIVH0oooo0?ooo`0J0?ooo`0306IVIP3oool0oooo0280oooo00<0IVIV0?ooo`3oool00P3oool5
06IVIQ00oooo00<0IVIV0?ooo`3oool0203oool506IVIQh0oooo00<0IVIV0?ooo`3oool03P3oool0
0`1VIVH0oooo0?ooo`0l0?ooo`030000003oool0oooo0400oooo000N0?ooo`030000003oool0oooo
00h0oooo00@0IVIV0?ooo`3oool0IVIV8`3oool606IVIQD0oooo00<0IVIV0?ooo`3oool07`3oool0
0`1VIVH0oooo0?ooo`0J0?ooo`0306IVIP3oool0oooo0280oooo1@1VIVHE0?ooo`0306IVIP3oool0
oooo0080oooo1P1VIVHS0?ooo`0306IVIP3oool0oooo00h0oooo00<0IVIV0?ooo`3oool0?03oool0
0`000000oooo0?ooo`100?ooo`007P3oool00`000000oooo0?ooo`0?0?ooo`0406IVIP3oool0oooo
06IVIQh0oooo1@1VIVHK0?ooo`0306IVIP3oool0oooo01h0oooo00<0IVIV0?ooo`3oool06`3oool0
0`1VIVH0oooo0?ooo`0K0?ooo`L0IVIV6@3oool506IVIRT0oooo00<0IVIV0?ooo`3oool03P3oool0
0`1VIVH0oooo0?ooo`0l0?ooo`030000003oool0oooo0400oooo000N0?ooo`030000003oool0oooo
0100oooo00@0IVIV0?ooo`3oool0IVIV603oool506IVIP@0oooo00<0IVIV0?ooo`3oool06P3oool0
0`1VIVH0oooo0?ooo`0M0?ooo`0306IVIP3oool0oooo01/0oooo00<0IVIV0?ooo`3oool05P3oool5
06IVIPH0oooo00<0IVIV0?ooo`3oool04@3oool606IVIP030?ooo`1VIVH0oooo02/0oooo00<0IVIV
0?ooo`3oool03`3oool00`1VIVH0oooo0?ooo`0k0?ooo`800000@@3oool001d0oooo00<000000?oo
o`3oool04P3oool0101VIVH0oooo0?ooo`1VIVHB0?ooo`D0IVIV2@3oool00`1VIVH0oooo0?ooo`0K
0?ooo`0306IVIP3oool0oooo01`0oooo00<0IVIV0?ooo`3oool0703oool00`1VIVH0oooo0?ooo`0?
0?ooo`H0IVIV2`3oool00`1VIVH0oooo0?ooo`0<0?ooo`D0IVIV1`3oool00`1VIVH0oooo0?ooo`0Z
0?ooo`0306IVIP3oool0oooo00l0oooo00<0IVIV0?ooo`3oool0>`3oool200000440oooo000M0?oo
o`030000003oool0oooo01<0oooo00@0IVIV0?ooo`3oool0IVIV2`3oool606IVIPh0oooo00<0IVIV
0?ooo`3oool06`3oool00`1VIVH0oooo0?ooo`0L0?ooo`0306IVIP3oool0oooo01d0oooo00<0IVIV
0?ooo`3oool02@3oool506IVIQ40oooo00<0IVIV0?ooo`3oool01P3oool606IVIPd0oooo00<0IVIV
0?ooo`3oool0:@3oool00`1VIVH0oooo0?ooo`0?0?ooo`0306IVIP3oool0oooo03X0oooo0`000011
0?ooo`007@3oool00`000000oooo0?ooo`0D0?ooo`0406IVIP3oool0oooo06IVIPD0oooo1@1VIVHC
0?ooo`0306IVIP3oool0oooo01d0oooo00<0IVIV0?ooo`3oool06`3oool00`1VIVH0oooo0?ooo`0M
0?ooo`0306IVIP3oool0oooo00@0oooo1@1VIVHF0?ooo`0406IVIP3oool0oooo0?ooo`D0IVIV4`3o
ool00`1VIVH0oooo0?ooo`0Y0?ooo`0306IVIP3oool0oooo00l0oooo00<0IVIV0?ooo`3oool0>`3o
ool00`1VIVH000000?ooo`100?ooo`007@3oool00`000000oooo0?ooo`0E0?ooo`0306IVIP3oool0
oooo00D0IVIV603oool00`1VIVH0oooo0?ooo`0N0?ooo`0306IVIP3oool0oooo01X0oooo00<0IVIV
0?ooo`3oool07P3oool606IVIQT0oooo1P1VIVHI0?ooo`0306IVIP3oool0oooo02T0oooo00<0IVIV
0?ooo`3oool03`3oool00`1VIVH0oooo0?ooo`0k0?ooo`030000003oool0oooo03l0oooo000M0?oo
o`030000003oool0oooo01<0oooo1P1VIVHL0?ooo`0306IVIP3oool0oooo01l0oooo00<0IVIV0?oo
o`3oool06@3oool00`1VIVH0oooo0?ooo`0I0?ooo`H0IVIV6@3oool506IVIP80oooo00<0IVIV0?oo
o`3oool06P3oool00`1VIVH0oooo0?ooo`0Y0?ooo`0306IVIP3oool0oooo00l0oooo00<0IVIV0?oo
o`3oool0>`3oool00`000000oooo0?ooo`050?ooo`@000001P3oool2000000H0oooo100000060?oo
o`@000006P3oool001`0oooo00<000000?ooo`3oool03`3oool506IVIP@0oooo00<0IVIV0?ooo`1V
IVH06`3oool00`1VIVH0oooo0?ooo`0O0?ooo`0306IVIP3oool0oooo01T0oooo00<0IVIV0?ooo`3o
ool04`3oool606IVIPH0oooo00<0IVIV0?ooo`3oool0403oool606IVIPL0oooo00<0IVIV0?ooo`3o
ool06`3oool00`1VIVH0oooo0?ooo`0X0?ooo`0306IVIP3oool0oooo00l0oooo00<0IVIV0?ooo`3o
ool0>`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool001`0oooo00<000000?ooo`3oool0
2P3oool506IVIPX0oooo00<0IVIV0?ooo`1VIVH06P3oool00`1VIVH0oooo0?ooo`0P0?ooo`0306IV
IP3oool0oooo01P0oooo00<0IVIV0?ooo`3oool03P3oool506IVIPd0oooo00<0IVIV0?ooo`3oool0
2P3oool506IVIPd0oooo00<0IVIV0?ooo`3oool06`3oool00`1VIVH0oooo0?ooo`0X0?ooo`0306IV
IP3oool0oooo0100oooo00<0IVIV0?ooo`3oool0>P3oool2000000D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo000L0?ooo`030000003o
ool0oooo00D0oooo1@1VIVH@0?ooo`0306IVIP3oool0IVIV01T0oooo00<0IVIV0?ooo`3oool08@3o
ool00`1VIVH0oooo0?ooo`0F0?ooo`0306IVIP3oool0oooo00T0oooo1P1VIVHB0?ooo`0306IVIP3o
ool0oooo00@0oooo1P1VIVHB0?ooo`0306IVIP3oool0oooo01`0oooo00<0IVIV0?ooo`3oool09`3o
ool00`1VIVH0oooo0?ooo`0@0?ooo`0306IVIP3oool0oooo03X0oooo0P0000050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo0P0000030?ooo`030000003oool0oooo01L0oooo000L0?ooo`030000003oool0
oooo00D0IVIV5@3oool0101VIVH0oooo0?ooo`1VIVHG0?ooo`0306IVIP3oool0oooo02<0oooo00<0
IVIV0?ooo`3oool05@3oool00`1VIVH0oooo0?ooo`040?ooo`D0IVIV6@3oool606IVIQP0oooo00<0
IVIV0?ooo`3oool0703oool00`1VIVH0oooo0?ooo`0W0?ooo`0306IVIP3oool0oooo0100oooo00<0
IVIV0?ooo`3oool0>P3oool00`1VIVH000000?ooo`040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000000P00000J0?ooo`006`3oool010000000IVIV06IVIP1VIVHK0?ooo`0406IVIP3o
ool0oooo06IVIQH0oooo00<0IVIV0?ooo`3oool08`3oool00`1VIVH0oooo0?ooo`0E0?ooo`0306IV
IP3oool0IVIV00@0IVIV6@3oool606IVIQd0oooo00<0IVIV0?ooo`3oool07@3oool00`1VIVH0oooo
0?ooo`0V0?ooo`0306IVIP3oool0oooo0100oooo00<0IVIV0?ooo`3oool0>P3oool00`1VIVH00000
0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0703oool001/0oooo00<0
00000?ooo`1VIVH07@3oool0101VIVH0oooo0?ooo`1VIVHE0?ooo`0306IVIP3oool0oooo02@0oooo
00<0IVIV0?ooo`3oool0403oool606IVIP<0oooo3`16^o@704>il`D0IVIV0P13^O<>03ngl@h0?;G`
1@0h/nh00`1VIVH0>;?^03RckP0703RckPl0=;7]3P0_[^/R0?ooo`0306IVIP3oool0oooo0140oooo
00<0IVIV0?ooo`3oool0=`3oool4000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0K0?ooo`006`3oool010000000oooo0?ooo`1VIVHM0?ooo`0406IVIP3oool0oooo06IVIQ@0
oooo00<0IVIV0?ooo`3oool09@3oool00`1VIVH0C;kf04bnmP0<04bnmPL0BKce00<0IVIV04Vlm@19
_?D01019_?D>04Jkm0H0IVIV2013^O<>03ngl@h0?;G`100h/nh00`1VIVH0>;?^03RckP0803RckPl0
=;7]3P0_[^/?02VZj0L08JCU2`3oool00`1VIVH0oooo0?ooo`0A0?ooo`0306IVIP3oool0oooo0380
oooo1P1VIVH20?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0J0?ooo`006`3oool01@000000oooo0?ooo`3oool0IVIV01d0oooo00@0IVIV0?ooo`3o
ool0IVIV4`3oool00`1VIVH0oooo0?ooo`0<0?ooo`h0D/3h3P1?_oL=04bnmPH0BKce00<0IVIV04Vl
m@19_?D01@19_?D804Jkm0D0IVIV00<0A[_d04>il`13^O<03013^O<>03ngl@h0?;G`0`0h/nh00`1V
IVH0>;?^03RckP0903RckPl0=;7]3P0_[^/?02VZj0h08JCU0`3oool00`1VIVH0oooo0?ooo`0A0?oo
o`0306IVIP3oool0oooo02`0oooo1P1VIVH80?ooo`030000003oool0oooo00@0oooo1000000>0?oo
o`@00000203oool3000001T0oooo000K0?ooo`030000003oool0oooo0080oooo00<0IVIV0?ooo`3o
ool06`3oool00`1VIVH0oooo06IVIP0C0?ooo`0306IVIP3oool0EL;i00h0EL;i3@1B`?P>04nom`d0
C;kf1@19_?D00`1VIVH0BKce04Vlm@0604Vlm@0304Jkm01VIVH0IVIV00@0IVIV1`16^o@>04>il`h0
?kOa3P0l]O0203RckP0306IVIP0h/nh0>;?^00X0>;?^3`0d/Nd>02n^j`l0:J[X3P0QY>D201>Jg`03
06IVIP0CV]l04i[O00X04i[O203oool00`1VIVH0oooo0?ooo`0U0?ooo`H0IVIV3P3oool2000003l0
oooo000J0?ooo`030000003oool0oooo00@0oooo00<0IVIV0?ooo`3oool06`3oool00`1VIVH0oooo
06IVIP080?ooo`T0El?j00<0IVIV05O3nP1G`oX00P1G`oX>05G2n@d0D/3h3P1?_oL=04bnmP@0BKce
00<0IVIV04Vlm@19_?D00P19_?D506IVIPh0A[_d3P13^O<>03ngl@h0?;G`00<0>;?^06IVIP0h/nh0
2`0h/nh?03Bak@l0;jk[3`0YZ^P>026Ti@0301>Jg`1VIVH04i[O00`04i[O1000Q=@30?ooo`0306IV
IP3oool0oooo01l0oooo1P1VIVHD0?ooo`800000?`3oool001X0oooo00<000000?ooo`3oool01@3o
ool00`1VIVH0oooo0?ooo`0<0?ooo`h0G<Gk3@1Ja?X705O3nP0306IVIP1G`oX0El?j00<0El?j3P1E
`_T=05;0n0h0Ckog3@1<__H204Vlm@H0IVIV1P19_?D=04Jkm0l0Ak_d3P14^_<>046hlP0306IVIP0m
]_00?KK`00/0?KK`3`0i/nl?03Bak@h0;jg[3`0QY>D00`1VIVH04i[O01>Jg`0<01>Jg`L008CD6`3o
ool606IVIQX0oooo00<0IVIV0000003oool0?P3oool001X0oooo00<000000?ooo`3oool01P3oool0
0`1VIVH0oooo05k5n`0=05k5n`d0G<Gk3@1Ja?X605O3nP0306IVIP1G`oX0El?j00D0El?j3@1E`_T=
05;0n0h0Ckog2@1<__H506IVIP0304fnm`1VIVH0CKkg00/0CKkg3@1;_OH>04Nkm0h0A;[c3@11^?80
0`1VIVH0?KK`03ffl00<03ffl0l0>K?_3`0d/Nd>02n]j`h09jSX00<0IVIV01>Jg`0CV]l03@0CV]l:
0024e140oooo1P1VIVHO0?ooo`80IVIV00<000000?ooo`3oool0?@3oool001X0oooo00<000000636
o01Pa_`02P1Pa_`=05k5n`d0G<Gk3P1Ja?X405O3nP0306IVIP1G`oX0El?j00H0El?j3@1E`_T=05;0
n0h0Dl7h0P1@_oP606IVIPH0D;oh00<0IVIV04fnm`1=__L02`1=__L=04^mmPh0Ak_d3P14^_<<046h
lP0306IVIP11^?80?KK`00d0?KK`3`0i/nl>03Bak@l0;jg[3@0WZ>P00`1VIVH06YkS01ZNh`0=01ZN
h`h008CD1`3oool606IVIQl0oooo1P1VIVH20?ooo`030000003oool0oooo03d0oooo000I0?ooo`03
0000003oool0oooo00`0H<Kl3@1NaO/>05c5n`d0F/Cj0`1G`oX00`1VIVH0El?j05O3nP0705O3nPd0
EL;i3P1F`_T905?1n0D0IVIV2`1@_oP00`1VIVH0D;oh04fnm`0=04fnm`d0Bkgf3P17^o@>04Bjl`/0
@KSb00<0IVIV046hlP11^?803P0m]_0?03Vck`h0=;7]3`0_[N/<02NXj00306IVIP0WZ>P06YkS00h0
6YkS0`01RMT;0024e0H0IVIV7`3oool606IVIPP0oooo00<000000?ooo`3oool0?@3oool001T0oooo
00@000000?ooo`3oool0oooo301Pa_`>05k5n`d0G<Gk3@1Ja?X205_4n`0306IVIP1Ka?/0FlCk00T0
FlCk3@1H`oX=05K2n@80Dl7h1P1VIVH505?1n0/0D;oh00<0IVIV052on01@_oP03P1=__L=04^mmPh0
Ak_d3P14^_<:046hlP0306IVIP11^?80@KSb00h0?KK`3`0i/nl>03Bak@l0;jg[300WZ>P00`1VIVH0
9jSX02NXj00>01ZNh`L00HWI00<008CD06IVIP1VIVH0101VIVH4001E^a/0oooo1P1VIVH=0?ooo`80
0000?`3oool001T0oooo00<000000?ooo`3oool00P3oool=0636o0d0G/Gk3@1LaO/=05g5n`0306IV
IP1Ka?/0FlCk00/0FlCk3@1H`oX905K2n@D0IVIV301C`OP:052on00406IVIP1@_oP0D;oh052on0h0
CKkg3@1;_OH=04Nkm0l0B;ce2@15^_@0101VIVH0AK[d04Fjm015^_@>04:hlPl0?[Ka3P0j]>l?03B`
k@`0;J_[00<0IVIV02f[j`0JW^<03P0JW^<00`01RMT0IVIV06IVIP0406IVIP<00HWI1000Q=@5001E
^a<0oooo1P1VIVHD0?ooo`800000?P3oool001T0oooo00<000000?ooo`3oool0103oool<0636o0d0
G/Gk3P1Oa_`;05g5n`0306IVIP1MaO/0FlCk00`0FlCk3@1H`oX205K2n@H0IVIV1P1F`_T<05?1n0T0
D;oh00<0IVIV052on01@_oP00P1@_oP>0570n0d0Ckkg3@1<_OH?04Rlm@P0AK[d00<0IVIV04Fjm015
^_@00P15^_@>04:hlPl0?[Ka3P0j]>l?03B`k@/0;J_[00<0IVIV02f[j`0]Zn/01`0PX^H201ZNh`H0
IVIV3@01RMT7001E^`/0oooo1P1VIVHJ0?ooo`800000?P3oool001T0oooo00<000000?ooo`3oool0
1@3oool<0636o0h0HLKl3@1Oa_`:05g5n`0306IVIP1MaO/0GLGk00d0FlCk2@1H`oX506IVIPd0E/;i
301C`OP805C1n@0306IVIP1D`OT0E<7i00<0E<7i3P1A`?P=04nnm`d0C;gf3`18_?D704Fjm00306IV
IP15^_@0AK[d00<0AK[d3P12^?8>03jfl@h0>[C_3`0d/>d;02f[j`0406IVIP0]Zn/0;J_[02f[j`80
8:;V1P1VIVH5022RiPl00HWI0P00G<47001E^`80oooo1P1VIVHP0?ooo`0306IVIP000000oooo03d0
oooo000H0?ooo`030000003oool0oooo00L0oooo3@1Sao`>0676o0`0GlKl2@1MaO/0101VIVH0GLGk
05g5n`1MaO/=05_4n`80F<?j1P1VIVH505S3nPh0FL?j3@1G`_X605C1n@0306IVIP1D`OT0E<7i00@0
E<7i3P1A`?P=04nnm`d0C;gf3`18_?D604Fjm00306IVIP15^_@0AK[d00@0AK[d3P12^?8>03jfl@h0
>[C_3`0d/>d:02f[j`H0IVIV300PX^H500R?g@T00HWI1000G<47001E^bH0oooo00<0IVIV0000003o
ool0?@3oool001P0oooo00<000000?ooo`3oool02@3oool=06?7o0d0HLKl301Oa_`805g5n`0306IV
IP1MaO/0GLGk0080GLGk2@1Ka?/506IVIPd0FlCk3@1I`oX=05O2nPD0E<7i00<0IVIV05C1n@1D`OT0
1@1D`OT>0570n0d0Ckkg3@1<_OH>04Rlm@H0AK[d00<0IVIV04Fjm015^_@01@15^_@=04:hlPh0?[Ka
3P0j]>l?03B`k@@0;J_[1`1VIVH402f[j`h08:;V2@08Smd50069f@H005c11P00EK/U0?ooo`030000
003oool0oooo03`0oooo000H0?ooo`030000003oool0oooo00/0oooo301Sao`>0676o0/0GlKl1`1M
aO/00`1VIVH0GLGk05g5n`0305g5n`80G/Gk1P1VIVH605k5n`d0FlCk3@1I`oX=05O2nP@0E<7i00<0
IVIV05C1n@1D`OT01P1D`OT>0570n0d0Ckkg3@1<_OH>04fnm`D0BKcf00<0IVIV04VlmP19_?H01P19
_?H=04Jjm0h0@kWc3P0n]_4<03Zcl0H0IVIV1P0b[nd00`1VIVH0<Zo]03:_k@0203:_k@l08:;V3@08
Smd8001L`@H005Fk8`3oool00`000000oooo0?ooo`0l0?ooo`00603oool00`000000oooo0?ooo`0<
0?ooo`d0HlOl3@1Qa_`;05o6o0H0H<Kl00<0IVIV0636o01Pa_`01@1VIVH=05k5n`h0FlCk301I`oX=
05O2nP<0E<7i00<0IVIV05C1n@1D`OT01`1D`OT=0570n0h0D/3h3@1@_oL>04fnm`@0BKcf00<0IVIV
04VlmP19_?H01`19_?H=04Jjm0h0@kWc3P0n]_4503Zcl0H0IVIV100j/o0803:_k@0306IVIP0b[nd0
<Zo]00<0<Zo]3P0VY^T>00R?g@8006?62000G<44001E^`03001Fd03oool0oooo01l0oooo00<00000
0?ooo`3oool0?03oool001P0oooo00<000000?ooo`3oool03P3oool<06?7o0h0I<Om2`1Rao`00`1P
a_`0IVIV06IVIP0406IVIPH0H<Kl3P1NaO/=05_4n``0FL?j3@1G`_X205S3nP0306IVIP1H`oX0F<?j
00T0F<?j301E`OT>05;0n0d0D;og3P1=__L304VlmP0306IVIP19_?H0BKcf00P0BKcf3@16^_@>04>i
l``0?[Ka1P1VIVH;03Zcl0L0<Zo]00<0IVIV03:_k@0b[nd00`0b[nd?02JVj@L049?Q1`08Smd4001S
aPL005c10P00EK/3001Fd1l0oooo0P00000m0?ooo`005`3oool00`000000oooo0?ooo`0@0?ooo`d0
I/Sm3@1Taod606;7o0D0IVIV0P1Pa_`00`1VIVH0H<Kl0636o0090636o0d0G/Gk3@1Ka?/<05W3nPh0
F/Cj00<0IVIV05S3nP1H`oX02P1H`oX<05G1n@h0D/3h3@1@_oL>04fnm`0304VlmP1VIVH0BKcf00/0
BKcf3@16^_@>04>il`D0?[Ka1P1VIVH303jfl@h0>[?`1`0b[nd00`1VIVH0<Zo]03:_k@0403:_k@h0
9ZKY3P0@Tn47001SaPH005c11@00E]0L0?ooo`<00000?@3oool001L0oooo00<000000?ooo`3oool0
4P3oool<06K8o@`0I<Om1P1VIVH706;7o00306IVIP1Pa_`0H<Kl00X0H<Kl3@1NaO/=05k5o0d0G<Ck
301Ja?X00`1VIVH0F<?j05S3nP0;05S3nP`0EL7i3P1B`?P=052om`h0CKkg00<0IVIV04VlmP19_?H0
2P19_?H=04Jjm0d0Ak_e1P1VIVH:04>il`h0?[Kb1P0h/^l00`1VIVH0>;;_03Rbk`0403Rbk`l09ZKY
3P0@Tn42001Yb`L006?61000G<400`006I`005K@001Fd003001Fd1/0oooo00<0IVIV0000003oool0
?03oool001L0oooo00<000000?ooo`3oool04`3oool<06K8o@H0I<Om1@1VIVH206C7o@/0H/Ol00<0
IVIV0636o01Pa_`02`1Pa_`>0676o0`0G/Gl3@1La?/:05[4nP0306IVIP1Ja?X0F/Cj00d0F<?j301E
`OT>05;0n0d0D;og3@1A_oP00`1VIVH0C[kg04jnm`0;04jnm`d0Bkcf1P17^oD606IVIP<0Ak_e3P13
^O<>03jflPD0>;;_00<0IVIV03Rbk`0h/^l01@0h/^l>02bYk0h049?Q1@00JL/7001SaP8005c100<0
01VL001Fd000E]001000E]0I0?ooo`0306IVIP000000oooo03`0oooo000G0?ooo`030000003oool0
oooo01@0oooo2`1Vb?d606IVIPP0I<Om2P1Rao`00`1VIVH0H/Ol06?7o00=06?7o0d0HLKl301NaO`=
05c4n`T0F/Cj00@0IVIV05[4nP1Ja?X0F/Cj3@1H`oX<05G1n@h0E/;i3@1C`OT<056on00306IVIP1A
_oP0C[kg00`0C[kg301;_?H606IVIPT0Ak_e3P13^O<>03jflPD0>;;_00<0IVIV03Rbk`0h/^l01P0h
/^l>02bYk0L05iST1`0@Tn46001Yb`L006?60P006I`7001Fd1P0oooo00<000000?ooo`3oool0>`3o
ool001H0oooo00<000000?ooo`3oool05P3oool506K8o@D0IVIV0P1Vb?d=06C7o@T0ILSm00@0IVIV
06G8o@1Ub?d0ILSm3@1Sao`=0676o0`0G/Gl3@1La?/805[4nP0306IVIP1Ja?X0F/Cj0080F/Cj3@1K
a?/<05W3nPh0E/;i3@1C`OT;056on00306IVIP1A_oP0DKoh00d0C[kg1@1;_?H606IVIP80Bkcf3P17
^oD>04>il`h0?[Kb100h/^l00`1VIVH0>;;_03Rbk`0703Rbk`d0;:W/3P0GV>@9001Yb`D006?600<0
012@000IW000E]001`00E]0C0?ooo`<0IVIV00<000000?ooo`3oool0>`3oool001H0oooo00<00000
0?ooo`3oool05@3oool606IVIQH0I/Sm1P1Ub?d00`1VIVH0ILSm06G8o@0306G8o@d0HlOl3@1Qa_`<
05k5o0d0G<Ck1`1MaO/00`1VIVH0GLGk05g5n`0305g5n`d0FlCk301I`oX>05K2n@d0Dl7i2P1A_oP0
101VIVH0DKoh056on01A_oP;04jnm`H0IVIV2@1;_?H=04Nkm@h0@kWc3P0n]_8403Rbk`0306IVIP0h
/^l0>;;_00L0>;;_3P0/ZN`>01NHi08006o@2@00JL/2001SaP80012@00<001VL001Fd000E]001`00
E]0;0?ooo`H0IVIV0`1jd?l00`1VIVH0oooo0?ooo`0k0?ooo`005P3oool00`000000oooo0?ooo`0@
0?ooo`D0IVIV0`3oool=06S9o@d0I/Sm1@1Ub?d00`1VIVH0ILSm06G8o@0506G8o@`0HlOl3@1Qa_`<
05k5o0d0GlKl1P1MaO/00`1VIVH0GLGk05g5n`0405g5n`d0FlCk301I`oX>05K2n@d0Dl7i2@1A_oP0
101VIVH0DKoh056on01A_oP504jnm`H0IVIV0P1>__L>04nnm`d0C;gf3P18^oD>04>hl`<0?KCa00<0
IVIV03fdl@0m]?40200m]?4=03:]kPh05iST1@00Km08001Yb`<0012@0P006I`9001Fd0<0oooo1P1V
IVH907[@o`0306IVIP000000oooo03/0oooo000F0?ooo`030000003oool0oooo00X0oooo1P1VIVH:
0?ooo``0J<Wm3@1Vb?d406G8o@0306IVIP1Ub?d0ILSm00H0ILSm301Sao`>06C7o@/0H/Kl3@1Oa_`5
05g5n`0306IVIP1MaO/0GLGk00D0GLGk3@1Ka?/<05W3nPh0E/;i301C`OT905C1n@0306IVIP1D`OT0
E<7i00H0IVIV2@1B`?P>04nnm`d0C;gf3P18^oD=04>hl`<0?KCa00<0IVIV03fdl@0m]?40200m]?4>
03:]kPL07IcW1`0GV>@6001_d0L006W;00<001NF000@T00049000P006I`4001Fd0L0IVIV3`1jd?l0
0`1VIVH000000?ooo`0k0?ooo`005P3oool00`000000oooo0?ooo`050?ooo`D0IVIV4@3oool=06S9
o@`0I/Sm0`1Ub?d00`1VIVH0ILSm06G8o@0D06G8o@d0I<Om2`1Ra_`=05o6o0@0GLGk00<0IVIV05g5
n`1MaO/01P1MaO/=05_4n``0FL?j3P1J`oX<05O2nPD0E<7i1P1VIVH305C1n@d0D/3h3@1?__L=04bm
mPl0B;_e3@13^?<203fdl@0306IVIP0m]?40?KCa00T0?KCa3@0b[Nh>01fLi`T006o@1000JL/2000G
UP03000@T01VIVH0IVIV00@0IVIV1P00E]0@07[@o`80IVIV?03oool001D0oooo00<000000?ooo`3o
ool01P1VIVHH0?ooo``0J<Wm301Vb?d206O8o@0306IVIP1Wb?d0IlSm00T0IlSm301Ub?d=06C7o@/0
H/Kl3@1Oa_`305g5n`0306IVIP1MaO/0GLGk00L0GLGk3@1NaO`<05c4n`h0F/?j2P1G`_X606IVIP<0
E<7i00<0IVIV05C1n@1D`OT0101D`OT=05;0n0d0Ckkg3@1<_OH>04Rkm@d0@kSc0`0m]?400`1VIVH0
?KCa03fdl@0803fdl@h0<Zg^3P0MW>L2001fe0L006o@1P1VIVH2000@T08001VL2000E]0@07[@o`80
IVIV?03oool001D0oooo00<0000006IVIP1VIVH07`3oool<06S9o@d0JLWn00<0IVIV06O8o@1Wb?d0
2P1Wb?d<06G8o@d0I<Om2`1Ra_`=05o6o080H<Kl00<0IVIV0636o01Pa_`0201Pa_`=05k5o0`0G<Ck
3P1J`oX305O2nPH0IVIV0`1G`_X605C1n@0306IVIP1D`OT0E<7i00D0E<7i3@1B`?P<04nnm`d0C;gf
3`1<_OL=04Rkm@80@[Oc00<0IVIV04:gl`12]o<02012]o<>03:]kPh07IcW0P00M]@706IVIP@006o@
0`005iH2000@T08001VL1`00E]0A07[@o`0306IVIP3oool0oooo03X0oooo000E0?ooo`030000001V
IVH0oooo0200oooo3@1[bOh:06W9oP0306IVIP1YbOh0IlSm00`0IlSm301Ub?d=06C7o@/0H/Kl3@1R
ao`00`1Pa_`0IVIV0636o00:0636o0d0G/Gl301La?/;05[3nPD0IVIV2P1G`_X505C1n@0306IVIP1D
`OT0E<7i00D0E<7i3P1E`OT<05;0n@d0D;oh3`1<_OL=04Rkm@0304:gl`1VIVH0@[Oc00X0@[Oc3P0h
/?0602>QjP<07IcW1P1VIVH6001fe0H006o@00<001jL000GUP005iH00P004903000IW0D005K@4@1j
d?l00`1VIVH0oooo0?ooo`0j0?ooo`005@3oool00`000000oooo06IVIP0R0?ooo``0JlWn2@1YbOh0
101VIVH0JLWn06W9oP1YbOh<06O8o@`0ILSm3P1Vb?d;06C7o@`0H/Ol00<0IVIV0636o01Pa_`02P1P
a_`=05k5o0`0G<Ck101J`oX606IVIP<0F/?j3@1J`o/405S2nP0306IVIP1H`_X0F<;j00H0F<;j3P1E
`OT<05;0n@d0D;oh3P1<_OL=04Rkm@0304:gl`1VIVH0@[Oc00X0@[Oc3P0h/?0302>QjPH0IVIV100S
XNX;001fe0<006o@0P007Y`3000GUP04000@T0006I`001VL000IW0@005K@4@1jd?l00`1VIVH0oooo
0?ooo`0j0?ooo`00503oool01@000000oooo0?ooo`3oool0IVIV0280oooo3@1[bOh706W9oP0306IV
IP1YbOh0JLWn0080JLWn301Wb?d=06S8o@d0I/Sm2`1Taod:06;7o00306IVIP1Rao`0H<Kl00`0H<Kl
3@1NaO`905c4n`H0IVIV2P1Ma?/=05[3n`<0F<;j00<0IVIV05S2nP1H`_X01`1H`_X=05G1n@d0D/3i
3@1@_oP>04bmm`d0B;_e00<0IVIV04:gl`12]o<02P12]o<:03R`l0H0IVIV2`0SXNX2001lf@/007KD
0`007Y`3000GUP04000@T0006I`001VL000IW0<005K@4@1jd?l00`1VIVH000000?ooo`0j0?ooo`00
503oool00`000000oooo0?ooo`020?ooo`0306IVIP3oool0oooo0200oooo00<0IVIV06_9oP1[bOh0
2P1[bOh606W9oP0306IVIP1YbOh0JLWn00<0JLWn3@1ZbOh<06S8o@d0I/Sm2`1Taod906;7o00306IV
IP1Rao`0H/Ol00d0H<Kl3@1Qa_`205o5o0H0IVIV101OaO`=05g4n`d0F/?k0P1H`_X00`1VIVH0F<;j
05S2nP0805S2nPd0EL7i3@1B`?T=052on0d0C;gg3@18^oD00`1VIVH0@[Oc04:gl`0:04:gl`<0>;3`
1`1VIVH403R`l0d08j7Z1@00O=T9001fe003000VXP007Y`001jL00<001NF00@0012@000IW0006I`0
01VL0P00E]0A07[@o`0306IVIP000000oooo03X0oooo000D0?ooo`030000003oool0oooo00<0oooo
00<0IVIV0?ooo`3oool0803oool00`1VIVH0JlWn06_9oP0:06_9oPD0Jl[n00<0IVIV06_:oP1[b_h0
1@1[b_h<06[9oP`0J<Sm3@1Vb?d;06C7o@P0H/Ol00@0IVIV06;7o01Rao`0H/Ol3@1Saod80676o0H0
IVIV2`1OaO`=05g4n`d0F/?k00<0F<;j06IVIP1H`_X02P1H`_X<05G1n@d0D/3i3P1C`?T=052on0`0
C;cg00<0IVIV04Jim@16^OD01`16^OD606IVIP/0?K;b3P0SXNX7001lf@H007KD0P009Z83000NW080
01NF00D0012@000IW0006I`001VL001Fd00A07[@o`80IVIV>`3oool001@0oooo00<000000?ooo`3o
ool0103oool206IVIR40oooo00<0IVIV06g:oP1]b_h02`1]b_h306_:oP0306IVIP1[b_h0Jl[n00H0
Jl[n301ZbOh<06S8o@d0I/Sm2`1Taod706G7o@0306IVIP1Uaod0ILOm00<0ILOm301Saod00`1Qa_`0
IVIV06IVIP0406IVIPH0HLKl301OaO`=05g4n``0F/?k00<0F<;j06IVIP1H`_X02P1H`_X=05W3nPd0
E/;j3P1C`?T<052on0`0C;cg00@0IVIV04Jim@16^OD0A[We1P1VIVH404Jim@h0?K;b3@0YY>d:001l
f@<007KD0`009Z83000NW08001NF00@0012@000IW0006I`001VL4@1jd?l206IVIS/0oooo000D0?oo
o`030000003oool0oooo00H0oooo00<0IVIV0?ooo`3oool07`3oool00`1VIVH0oooo06g:oP0;06g:
oP0306_:oP1VIVH0Jl[n00T0Jl[n301ZbOh<06S8o@d0JLWn2`1Wb?d606G7o@0306IVIP1Uaod0ILOm
00@0ILOm1P1Saod606IVIPd0HLKl301OaO`<05g4n`d0G/Gk00<0IVIV05_4n`1Ka?/02P1Ka?/=05W3
nPd0E/;j3@1C`?T=052on0P0C;cg1`1VIVH;04Jim@d0?K;b3P0YY>d30061g@T007cI1@009Z82000N
W0<001NF0`006I`A07[@o`0306IVIP3oool0oooo03T0oooo000C0?ooo`030000003oool0oooo00P0
oooo00<0IVIV0?ooo`3oool07`3oool00`1VIVH0oooo06g:oP0;06g:oP0306IVIP1[b_h0Jl[n00T0
Jl[n6@1ZbOh<06W9oP/0IlSm1@1Uaod00`1VIVH0ILOm06G7o@0406G7o@H0IVIV1`1Saod=0676o0`0
H/Kl301PaO`<05k5n`0306IVIP1Ka?/0FlCk00/0FlCk3@1I`oX=05K2nPd0Dl3i301@_oP204blm`H0
IVIV0`1<_?L00`1VIVH0C;cg04Jim@0<04Jim@h0?K;b3@0YY>d60061g@L007cI00<002fX000VXP00
9Z800P009Z82000NW0<001NF0P006I`A07[@o`0306IVIP3oool0oooo03T0oooo000C0?ooo`030000
003oool0oooo00T0oooo00<0IVIV0?ooo`3oool07`3oool00`1VIVH0oooo0?ooo`0:06g:oP0306IV
IP1[b_h0Jl[n00X0Jl[n3@1/b_h<06[9oP`0JLWn2`1Wb?d406G7o@L0IVIV0P1Uaod<06?7o@d0I<Om
301Ra_`<0635o0/0G/Gk00<0IVIV05k5n`1Ka?/0301Ka?/=05W3nP`0E/;j3@1C`?T805C0n@H0IVIV
2P1@__P00`1VIVH0D;kh04^km`0<04^km`d0@[Gd3@0YY>d:0061g@<007cI0P00;JP4000VXP8001jL
0`005iH00`006I`0N]3o07[@o`0?07[@o`0306IVIP000000oooo03T0oooo000C0?ooo`030000003o
ool0oooo00X0oooo00<0IVIV0?ooo`3oool07`3oool00`1VIVH0oooo0?ooo`0906g:oP0306IVIP1]
b_h0K/[n00`0K/[n301/b_h<06[9oP`0JLWn2@1Wb?d606IVIPT0ILOm301Vb?d=06C7o@`0H/Kl301P
aO`:05k5n`0306IVIP1NaO/0G/Gk00`0FlCk3@1I`oX=05[3n`d0El;j1`1VIVH605C0n@X0D;kh00<0
IVIV052nn01@__P0301;^oL>04:em0`0;jS_3@01PMd4000]Z0@002JR0P007Y`2000GUQ40N]3o00<0
IVIV0000003oool0>@3oool001<0oooo00<000000?ooo`3oool02`3oool00`1VIVH0oooo0?ooo`0O
0?ooo`0306IVIP3oool0oooo00P0Kl_n00@0IVIV06o;oP1_boh0Kl_n301^b_h<06c:oP`0J/Wn301Y
bOh206O8o@H0IVIV0`1Wb?d206S8o@0306IVIP1Xb?d0J<Sm00P0J<Sm301Vb?d=06C7o@`0H/Kl301P
aO`905k5n`0306IVIP1NaO/0G/Gk00d0G/Gl3@1La?/=05[3n`H0El;j1P1VIVH=05C0n@/0D;kh00<0
IVIV052nn01;^oL0301;^oL=04:em0d0;jS_0`08Qn4:0061g@04000d[`00;JP002fX000]Z0@002JR
0P007Y`2000GUPP0?Igd201jd?l00`1VIVH000000?ooo`0i0?ooo`004`3oool00`000000oooo0?oo
o`0<0?ooo`0306IVIP3oool0oooo01l0oooo00@0IVIV0?ooo`1VIVH0oooo1P1_boh00`1VIVH0Kl_n
06o;oP0206o;oP`0K/[n301/b_h<06[9oPL0JlWn1P1VIVH;06W9oP0306IVIP1Xb?d0J<Sm00T0J<Sm
301Vb?d=06C7o@`0H/Kl301Sa_d80676o00406IVIP1Qa_`0HLKl0676o0d0G/Gl3@1La?/<05[3n`H0
IVIV1`1G`_X=05C0n@X0D;kh00<0IVIV052nn01@__P0301;^oL=04:em0d0;jS_1`08Qn460061g@80
03B_1000;JP3000VXP8001jL0P005iH00`00GMD0?Igd03fMm00<03fMm080IVIV>P3oool00180oooo
00<000000?ooo`3oool03P3oool00`1VIVH0oooo0?ooo`0O0?ooo`0406IVIP3oool0oooo0?ooo`@0
Kl_n00<0IVIV06o;oP1_boh0101_boh<06k:oP`0K<[n301]b_h606IVIPH0JlWn2`1YbOh00`1VIVH0
J<Sm06S8o@0:06S8o@`0I/Sm301Taod=06G7o@`0HlKm1`1Qa_`00`1VIVH0HLKl0676o0020676o0d0
G/Gl3@1La?/405[3n`L0IVIV00<0F/?k05O2nP1G`_X02P1G`_X=05C0n@X0D;kh00<0IVIV052nn01@
__P03@1?_OP<04JhmPh0;jS_2P08Qn430061g@<003B_0`00;JP4000VXP03000NW0005iH005gE0080
05gE300mWO@206IVISX0oooo000B0?ooo`030000003oool0oooo00l0oooo00<0IVIV0?ooo`3oool0
7P3oool206IVIP<0oooo0`1_boh00`1VIVH0Kl_n06o;oP0506o;oP`0K/[n3@1^boh406g:oPH0IVIV
00<0KL[n06_9oP1[bOh02P1[bOh906W9oP0306IVIP1YbOh0JLWn00`0J<Sm301Vb?d<06O8o@d0ILOm
301Sa_d60676o00306IVIP1Qa_`0HLKl00<0HLKl3@1NaO`:05c4n`H0IVIV5@1J`o/=05S2nPX0E<3i
00<0IVIV05C0n@1D`?T0301?_OP=04JhmPd0=J_a3@08Qn44000d[`@002fX0`009Z800`007Y`005gE
001Me@03001Me@/0?Igd00<0IVIV0?ooo`3oool0>03oool00180oooo00<000000?ooo`3oool0403o
ool00`1VIVH0oooo0?ooo`0M0?ooo`0306IVIP3oool0IVIV00<0oooo0P1_boh00`1VIVH0Kl_n06o;
oP0606o;oPd0L<_o2@1^boh606IVIPP0KL[n301[bOh806W9oP0406IVIP1YbOh0JLWn06W9oP`0J/Wn
301Xb?h<06O8o@d0ILOm301Sa_d50676o00306IVIP1Qa_`0HLKl00@0HLKl301NaO`405o5o0H0IVIV
0`1OaO`<05g4n`d0F/?k301H`_X:05C0n@0306IVIP1D`?T0E<3i00d0Ckgh3016^?H>03F[l@@048cT
2@08Qn400`00?;@003B_000d[`02000d[`<002fX0`009Z800`007Y`002ng001Me@04001Me@T0?Igd
00<0IVIV0?ooo`3oool0>03oool00180oooo00<000000?ooo`3oool04@3oool00`1VIVH0oooo0?oo
o`0L0?ooo`0406IVIP3oool0oooo06IVIP<0oooo00<0LL_o06IVIP1abol02@1abol<073;o`80K/_n
1P1VIVH406k;oP/0KL[n301[bOh706c9oP0306IVIP1/bOh0K<Wn0080K<Wn301ZbOh<06S8oP`0IlSm
3@1Uaod;06?6o@D0I<Om00<0IVIV06C7o@1Taod01@1Taod80676o0L0IVIV2P1OaO`<05g4n``0F/?k
3@1H`_X905C0n@0406IVIP1D`?T0E<3i05C0n@`0Ckgh3@16^?H=03F[l@T048cT1008Qn42000l]0@0
03B_1000;JP2000VXP8002ng1@00GMD803fMm00306IVIP000000oooo03P0oooo000A0?ooo`030000
003oool0oooo01<0oooo00<0IVIV0?ooo`3oool06`3oool01@1VIVH0oooo0?ooo`3oool0IVIV00<0
oooo00<0IVIV077;o`1abol02@1abol7073;o`H0IVIV2`1^bohG06g:oPH0K<Wn00<0IVIV06c9oP1/
bOh00`1/bOh<06[9oP`0J<Sn301Wb?dH06G7o@@0I<Om00<0IVIV06C7o@1Taod01P1Taod00`1Qa_`0
IVIV06IVIP0406IVIPD0HLKl301OaO`=05g4n``0F/?k301H`_X:05C0n@0306IVIP1D`?T0E<3i00`0
Ckgh3@16^?H=03F[l@d048cT1000?;@4000d[`<002fX00@002JR000?W`00;kL002ng1P00GMD603fM
m00306IVIP000000oooo03P0oooo000A0?ooo`030000003oool0oooo01@0oooo0P1VIVHK0?ooo`03
06IVIP3oool0oooo0080oooo00D0IVIV0?ooo`3oool0IVIV0?ooo`0;077;o`H0IVIV1P1`bol<06k;
oP`0Kl_n2`1]b_h506c9oP0306IVIP1/bOh0K<Wn00@0K<Wn301ZbOh<06S8oQP0IlSm301Uaod306C7
o@0406IVIP1Taod0I<Om06C7o@H0IVIV301Qa_`<05o5o0`0GLCk301J`o/=05_3n`T0F<;j00@0IVIV
05S2nP1H`_X0F<;j301C_oT=04^jm``0>Zkc3P0@S>@01000@kX003bd000l]000?;@4000d[`<002fX
0P003il2000_]`L005gE100mWO@206IVIST0oooo000A0?ooo`030000003oool0oooo01H0oooo00<0
IVIV0?ooo`3oool05`3oool00`1VIVH0oooo0?ooo`040?ooo`0306IVIP3oool0IVIV0080oooo101a
bol606IVIP03077;o`1`bol0L<_o01H0L<_o301_boh;06g:oP@0K<Wn00<0IVIV06c9oP1/bOh01@1/
bOh<06[9oP`0JlWn301YbOh<06O8o@/0ILOm1`1VIVH706C7o@/0HLKl301OaO`=0635o0`0G/Cl3@1K
`o/905S2nP0306IVIP1H`_X0F<;j00`0Dkoi3@1;^_L=03Z^l`@05i7W2@0@S>@20013^P@003bd1000
=:l2000]Z08000nO0P00;kL8001Me@80?Igd0P1VIVHi0?ooo`004@3oool00`000000oooo0?ooo`0G
0?ooo`0306IVIP3oool0oooo01H0oooo00<0IVIV0?ooo`3oool01@3oool00`1VIVH0oooo06IVIP05
06IVIQ@0LL_o301`bol<06o;oP/0KL[n0`1/bOh00`1VIVH0K<Wn06c9oP0606c9oP`0K<[n301[bOh<
06W9oP`0IlSm101Uaod606IVIP80ILOm0P1Taod00`1VIVH0I<Om06C7o@0C06C7o@`0H/Kl3@1PaO`<
05k4o0d0Fl?k201H`_X0101VIVH0F<;j05S2nP1H`_X<05>on@d0Bk[g300j[_<901NAi`@048cT1000
@kX3000l]0@003B_00@002fX0000S@003il000nO0`00;kL8001Me@80IVIV>@3oool00140oooo00<0
00000?ooo`3oool0603oool00`1VIVH0oooo0?ooo`0E0?ooo`0406IVIP3oool0oooo0?ooo`H0IVIV
103oool<07?<o`/0LL_o301`bol<06o;oP/0KL[n0P1^b_h00`1VIVH0K/[n06k:oP0706k:oP`0K<[n
301[bOh<06W9oPT0IlSm1P1VIVH806G7o@80I/Sm00<0IVIV06K8o@1Vb?d0201Vb?d<06C7o@`0H/Kl
3@1PaO`<05k4o0`0Fl?k201H`_X0101VIVH0F<;j05S2nP1H`_X<05>on@d0Bk[g3@0j[_<<01NAi`D0
04>j1000?;@3000d[`80002=0P003il3000_]`P005gE00<0IVIV0?ooo`3oool0=`3oool00100oooo
00<000000?ooo`3oool06P3oool00`1VIVH0oooo0?ooo`0B0?ooo`H0IVIV103oool00`1VIVH0oooo
06IVIP050?ooo`/0Llco2`1abol<073;o``0Kl_n2`1_bol00`1^b_h0IVIV06k:oP0906k:oP`0K<[n
301[bOh<06W9oP80J/Wn1P1VIVH406[9oP/0J<Sn0P1Vb?d00`1VIVH0I/Sm06K8o@0806K8o@`0I<Om
301Ra_`<0635o1T0G/Cl201K`o/0101VIVH0Fl?k05_3n`1K`o/<05K0nPd0Ckci300o/OD=01NAi`03
001;`000@kX004>j00<004>j0`00?;@3000d[`040000S@003il000nO000?W`<002ng1`00GMD00`1V
IVH0oooo0?ooo`0g0?ooo`00403oool00`000000oooo0?ooo`0K0?ooo`0306IVIP3oool0oooo00/0
oooo1P1VIVH20?ooo`0306IVIP3oool0oooo00D0oooo00@0IVIV0?ooo`3oool0IVIV1@3oool;07?<
o`/0LL_o301`bol=077;o`X0Kl_o00<0IVIV06k:oP1^b_h02@1^b_h<06c:oQ80JlWn1`1VIVH;06[9
oP/0J<Sn00<0I/Sm06IVIP1Vb?d02P1Vb?d<06C7o@/0H/Kl3@1Sa_d<0675o0`0G/Cl201K`o/0101V
IVH0Fl?k05_3n`1K`o/<05K0nPd0Ckci3@0o/OD401fFjPP05i7W0`00Bl040013^P@003bd00<003B_
0000P00008d00`003il3000_]`H005gE00<0IVIV0000003oool0=`3oool00100oooo00<000000?oo
o`3oool0703oool00`1VIVH0oooo0?ooo`040?ooo`H0IVIV203oool00`1VIVH0oooo0?ooo`050?oo
o`0506IVIP3oool0oooo0?ooo`1VIVH01@3oool;07?<o`/0LL_o3@1bbol<077;o`T0Kl_o00<0IVIV
06k:oP1^b_h02P1^b_h<06c:oP/0KL[n1P1VIVH706_9oP`0J/Wn2`1Xb?h00`1Vb?d0IVIV06K8o@09
06K8o@`0I<Om301Uaod=06?6o@/0HLGl3@1Na?`705_3n`0306IVIP1K`o/0Fl?k0080Fl?k301F`?X=
04nln@`0?k7e200MU^X401NAi`@004_01@00@kX3000l]0030000P00008d0002=00<000nO0`00;kL5
001Me@0306IVIP000000oooo03L0oooo000@0?ooo`030000003oool0oooo01d0oooo1P1VIVH=0?oo
o`0306IVIP3oool0oooo00H0oooo00<0IVIV0?ooo`3oool00P3oool00`1VIVH0oooo0?ooo`030?oo
oaL0Llco301bbol<077;o`P0Kl_o00<0IVIV06o;o`1^b_h05`1^b_h406g:oPH0IVIV0P1]b_h<06_9
oP`0J/Wn2`1Xb?h00`1Yb?h0IVIV06W8oP0906W8oP`0IlSm301Uaod<06?6o@`0HLGl301Na?`805_3
n`0406IVIP1K`o/0Fl?k05_3n``0E/3j3@1?_?T<03nam@`07IKZ1P00Bl040013^P<003bd00<00020
0000S@0008d00`003il4000_]`<005gE0P1VIVHh0?ooo`003`3oool00`000000oooo0?ooo`0H0?oo
o`H0IVIV00<0oooo06IVIP3oool0403oool00`1VIVH0oooo0?ooo`050?ooo`0306IVIP3oool0oooo
00@0oooo00<0IVIV0?ooo`3oool00`3oool<07C<o`/0Llco301bbol<077;o`H0Kl_o00@0IVIV06o;
o`1_bol0Kl_o301`bol806k:oPL0IVIV2@1]b_h<06_9oQL0J/Wn00<0IVIV06W8oP1Yb?h02@1Yb?h<
06O8o@`0ILOm301Sa_d;0675o1@0G/Cl00<0IVIV05k4o01Na?`00P1Na?`<05[2n`d0Dkgj2`14/oH=
01fFjP03001Ba@00Bl0004_000<004_01@00@kX01000?;@0001f0000P00008d3000?W`D002ng0P00
GMD206IVISP0oooo000?0?ooo`030000003oool0oooo0180oooo1P1VIVH80?ooo`0306IVIP3oool0
oooo00h0oooo00<0IVIV0?ooo`3oool01@3oool00`1VIVH0oooo0?ooo`050?ooo`0306IVIP3oool0
oooo00@0oooo2`1dc?l<07?<o`/0L/_o301bc?l5077;o`0306IVIP1abol0LL_o00<0LL_o2`1`bol0
0`1^b_h0IVIV06IVIP0406IVIPD0K/[n301]b_h;06_9oP`0K<Wn301ZbOh00`1VIVH0JLSn06W8oP09
06W8oP`0IlSm2`1Uaod<06?6o@`0I<Km301QaO`805k4o00406IVIP1Na?`0G/Cl05k4o0`0F/;k3@1C
_OX<04BcmPH099[]1P0MU^X3001Ba@D004_01000@kX0100007H000200000S@0008d3000?W`D002ng
00<005gE06IVIP1VIVH0>03oool000l0oooo00<000000?ooo`3oool0303oool606IVIPl0oooo00<0
IVIV0?ooo`3oool03@3oool00`1VIVH0oooo0?ooo`050?ooo`0306IVIP3oool0oooo00H0oooo00<0
IVIV0?ooo`3oool0103oool<07C<o`/0Llco2`1dc?l<07;<o`@0LL_o00<0IVIV077;o`1abol0101a
bol5073;o`H0IVIV301^b_h<06o;o`/0K/[n301/bOh;06[9oP0306IVIP1Yb?h0JLSn00X0JLSn5`1W
b?d<06K7o@`0I<Km2`1QaO`805k4o00306IVIP1Na?`0G/Cl0080G/Cl301J`_/<05>mnP`0A;?f300T
V^d5001Ba@@004_00`00@kX00`0006d0001f0000P0020000S@<000nO1@00;kL00`00GMD0IVIV0?oo
o`0g0?ooo`003`3oool00`000000oooo0?ooo`060?ooo`H0IVIV5P3oool00`1VIVH0oooo0?ooo`0<
0?ooo`0306IVIP3oool0oooo00D0oooo00<0IVIV0?ooo`3oool01`3oool00`1VIVH0oooo0?ooo`04
0?ooo``0M<co2`1ec?l;07C<o``0L/co0`1abol00`1VIVH0LL_o077;o`02077;o`L0IVIV4`1`bol<
06o;o`/0K/[n301/bOh;06[9oP0306IVIP1Yb?h0JLSn01D0JLSn301Wb?d;06K7o@d0I<Km2`1QaO`7
05k4o00306IVIP1Na?`0G/Cl0080G/Cl301J`_/<05>mnP`0A;?f3@0TV^d00`00FLX005;5001Ba@02
001Ba@D004_000<004>j0000K@0006d00P0008020000S@<000nO1@00;kL00`1VIVH0oooo0?ooo`0f
0?ooo`003`3oool00`000000oooo0?ooo`0606IVIQd0oooo00<0IVIV0?ooo`3oool02`3oool00`1V
IVH0oooo0?ooo`050?ooo`0306IVIP3oool0oooo00P0oooo00<0IVIV0?ooo`3oool0103oool<07K<
o`/0MLco2`1dc?l<07;<o`03077;o`1VIVH0IVIV00@0IVIV101abol;07;;o``0L<_o301_bol;06k:
oP/0K<Wn301]b_h00`1VIVH0JlWn06_9oP0906_9oP`0JLSn2`1Wb?d<06K7o@`0I<Km4`1QaO`00`1V
IVH0HLGl0675o0020675o0`0GL?l301F_o/;04Vfn0d099[]0`00FLX4001Ba@@004_00P0006d01000
07H000200000S@0008d4000?W`@002ng00<0IVIV0000003oool0=P3oool000h0oooo00@0000006IV
IP1VIVH0IVIV903oool206IVIPX0oooo00<0IVIV0?ooo`3oool01P3oool00`1VIVH0oooo0?ooo`09
0?ooo`0306IVIP3oool0oooo00D0oooo2`1fc?l;07G<o`/0M<co1P1bc?l606IVIP0307?<o`1VIVH0
Llco00P0Llco2`1bbol<073;o``0Kl_o5P1^b_h;06g:oP0306IVIP1[bOh0JlWn00X0JlWn301Yb?h;
06O8oAP0I/Om2`1Ta_d70675o00306IVIP1QaO`0HLGl0080HLGl301M`o`<05Jon``0BKKh1P0ZW^l6
02BJk@D005W:1000D/D3001;`080001]0P0008020000S@@000nO0`00;kL00`1VIVH000000?ooo`0f
0?ooo`003P3oool00`000000oooo06IVIP0W0?ooo`0306IVIP3oool0oooo00L0oooo00<0IVIV0?oo
o`3oool01@3oool00`1VIVH0oooo0?ooo`0;0?ooo`0306IVIP3oool0oooo00D0oooo2`1fc?l;07G<
o`T0M<co1`1VIVH707C<o`0307?<o`1VIVH0Llco00P0Llco2`1bbol<073;o`/0Kl_o301`bol;06k:
oP/0KL[n00<0IVIV06_9oP1[bOh02P1[bOh;06W8oP/0IlSm301Xb?h<06K7o@`0I<Km1P1QaO`00`1V
IVH0HLGl0675o0030675o0`0GL?l301F_o/;04Vfn0`0:Yk_1P00FLX5001Ba@05001;`00006d0001]
0000MP0008000`0008d4000?W`8002ng0P1VIVHg0?ooo`003P3oool010000000oooo0?ooo`1VIVHW
0?ooo`0306IVIP3oool0oooo00H0oooo00<0IVIV0?ooo`3oool01@3oool00`1VIVH0oooo0?ooo`0<
0?ooo`0306IVIP3oool0oooo00D0oooo2`1fc?l;07G<o`80M/co1P1VIVH407K<o`/0M<co00<0Llco
06IVIP1cc?l0201cc?l;07;;o`/0L<_o301abol<073;o`/0K/[n2P1]b_h00`1VIVH0KL[n06_9oP0:
06_9oP`0K<Wn2`1ZbOh<06S8oP`0I/Om301Ta_d60675o00306IVIP1QaO`0HLGl0080HLGl301M`o`<
05Jon``0BKKh300ZW^l00`00H<l005W:001IbP04001IbP@005;500D0001W0000K@0006d0001f0000
P0020000S@D000nO00<002ng06IVIP1VIVH0=`3oool000h0oooo00@000000?ooo`3oool0oooo0P1V
IVHV0?ooo`0306IVIP3oool0oooo00D0oooo00<0IVIV0?ooo`3oool01@3oool00`1VIVH0oooo0?oo
o`0=0?ooo`0306IVIP3oool0oooo00D0oooo2`1fc?l607O=o`H0IVIV2`1fc?l;07C<o`0306IVIP1c
c?l0Llco00P0Llco5P1bbol<077;o``0L<_o2`1^b_h:06g:oP0306IVIP1]b_h0KL[n00X0KL[n301/
bOh;06[9oP`0J<Sn2`1VaodB06C6o@0306IVIP1Ta_d0I<Km00<0I<Km301Pa?`<05[1n`/0CKSi300Z
W^l3001Pc`H005W:0`00D/D20000K@030000MP00080000200080002=1@003il00`00;kL0IVIV0?oo
o`0f0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`0306IVIP3oool0oooo02@0oooo00<0IVIV
0?ooo`3oool0103oool00`1VIVH0oooo0?ooo`050?ooo`0306IVIP3oool0oooo00h0oooo00<0IVIV
0?ooo`3oool01@3oool907S=o`L0IVIV1`1gcOl;07K<o`/0M<co00<0IVIV07?<o`1cc?l01`1cc?l<
07C<o`/0L/_o301abol;073;o`/0K/[n2P1_b_l00`1VIVH0Kl[o06g:oP0;06g:oP/0K<Wn301ZbOh;
06S8oQP0I/Om1P1Ta_d00`1VIVH0I<Km06C6o@0206C6o@`0H<Cl301J`O/<04fhn@D0<:7a1P0ZW^l5
001Pc`H005W:00H005;50000I`0006d0001]0000MP0008030000S@D000nO00<0IVIV0?ooo`3oool0
=@3oool000d0oooo00<000000?ooo`3oool01@3oool00`1VIVH0oooo0?ooo`0T0?ooo`0306IVIP3o
ool0oooo00<0oooo00<0IVIV0?ooo`3oool01@3oool00`1VIVH0oooo0?ooo`0?0?ooo`0306IVIP3o
ool0oooo00H0oooo00<0N<go06IVIP1VIVH0101VIVH407S=o`/0Mlgo5P1fc?l00`1VIVH0MLco07G<
o`0807G<o`/0M<co2`1bbol<077;o`/0L/_o2`1`bol:06o:o`0306IVIP1_b_l0KL[n00/0KL[n2`1/
bOh;06[9oP`0JlWn2`1Yb?h<06K7o@H0I<Km00<0IVIV06C6o@1Ta_d00`1Ta_d;0634o0`0F/7k301=
^?T;032Ql@L0063?1@00FLX010000640001]0000K@0007H20000P0<0002=10003il00`1VIVH0oooo
0?ooo`0e0?ooo`003@3oool00`000000oooo0?ooo`060?ooo`0306IVIP3oool0oooo02@0oooo00D0
IVIV0?ooo`3oool0oooo06IVIP080?ooo`0306IVIP3oool0oooo0100oooo00<0IVIV0?ooo`3oool0
1P1VIVH;07S=oaH0Mlgo2`1fc?l00`1VIVH0MLco07G<o`0807G<o`/0M<co2`1bbol<07?;o`/0L/_o
2`1`bol:06o:o`0306IVIP1_b_l0KL[n00X0KL[n5`1/bOh;06_9oP/0JLSn3@1Vaod506C6o@0306IV
IP1Ta_d0I<Km00<0I<Km2`1Pa?`<05[1n``0CKSi300`XO42001Ve0H0063?1000FLX0100006L0001]
0000K@0007H20000P080002=10003il00`1VIVH000000?ooo`0e0?ooo`003@3oool00`000000oooo
0?ooo`070?ooo`0306IVIP3oool0oooo02@0oooo00@0IVIV0?ooo`3oool0IVIV1`3oool00`1VIVH0
oooo0?ooo`0=0?ooo`L0IVIV1`3ooolF07S=o`/0Mlgo2`1fc?l00`1VIVH0MLco07G<o`0807G<oaH0
M<co301cbol;07;;o`/0L<_o2@1_b_l00`1VIVH0Kl[o06o:o`0;06o:o`/0K/[n2`1/bOh<06_9oP/0
JLSn301Vaod606C6o@0306IVIP1Ta_d0I<Km0080I<Km301SaOd<05g2o0`0DK[j1@0eYO<6032Ql@@0
06KD1P00H<l2001IbP040000H@0006d0001]0000MP8000200`0008d3000?W`0306IVIP000000oooo
03D0oooo000=0?ooo`030000003oool0oooo00P0oooo0P1VIVHU0?ooo`0306IVIP3oool0IVIV00L0
oooo00<0IVIV0?ooo`3oool01`3oool606IVIPH0oooo00<0IVIV0?ooo`3oool01P3oool;07W=o`/0
N<go2`1gcOl;07K<o`0306IVIP1ec?l0MLco01<0MLco2`1dc?l<07?;o`/0L/_o2`1`bol9077;o`03
06IVIP1abol0Kl[o00/0Kl[o2`1^b_h;06c9oP/0JlWn601Yb?h506O7o@0306IVIP1Waod0IlOm00<0
IlOm2`1SaOd<05g2o0`0DK[j2`0eYO<6001Ve0H0063?00D0001<0000I`0006d0001]0000MP020000
P0<0002=0P003il206IVISH0oooo000<0?ooo`030000003oool0oooo00/0oooo00<0IVIV0?ooo`3o
ool08`3oool206IVIPL0oooo00@0IVIV0?ooo`3oool0oooo1P1VIVH=0?ooo`0306IVIP3oool0oooo
00D0oooo00<0IVIV07W=o`1icOl02@1icOl;07S=o`/0Mlgo2P1fc?l00`1VIVH0Mlco07O<o`0907O<
o`/0MLco2`1dc?l<07?;oaH0L/_o201abol00`1VIVH0LL_o077;o`0<06o:o`/0K/[n2P1/bOh<06g9
oP/0JlWn301Yb?h506O7o@0306IVIP1Waod0IlOm00<0IlOm301SaOd<05g2o0/0DK[j300eYO<2001]
f0D006KD1000H<l01@0004`0001Q0000K@0006d0001f00<000200`0008d00`003il0IVIV06IVIP0f
0?ooo`00303oool00`000000oooo0?ooo`0<0?ooo`0306IVIP3oool0oooo02<0oooo00<0IVIV0?oo
o`3oool00`3oool606IVIQ@0oooo00<0IVIV0?ooo`3oool0103oool00`1VIVH0oooo07W=o`0:07W=
o`/0N<go2`1gcOl:07S=o`0306IVIP1gc?l0Mlco00T0Mlco2`1ec?l;07C<o`/0Ll_o2`1cc?l<07;;
o`P0LL_o00<0IVIV077;o`1abol02`1_b_lF06k:oP`0KLWn2`1[bOh<06W8oPD0IlOm00<0IVIV06O7
o@1Waod00`1Waod;06?5o@`0GL;l2`1A^_X<03FUl`@006gH1@00I]@2001Pc`80001<00@0001W0000
K@0006d0001f0P0008030000S@8000nO00<0IVIV0?ooo`3oool0=03oool000`0oooo00<000000?oo
o`3oool03@3oool00`1VIVH0oooo0?ooo`0Q0?ooo`L0IVIV0`3oool00`1VIVH0oooo0?ooo`0E0?oo
o`0306IVIP3oool0oooo00<0oooo00<0IVIV0?ooo`3oool02`1icOl;07S=o`/0NLgo2P1hcOl00`1V
IVH0Mlco07O<o`0907O<o`/0MLco2`1fc?l;07C<o`/0Llco301bbol8077;o`0306IVIP1abol0LL_o
00/0LL_o2`1`bol;06k:oP`0KLWn2`1[bOh;06W8oPD0IlOm00<0IVIV06O7o@1Waod00`1Waod<06K6
o@`0H<?m2`1E^o/503^Xm0H0=JGc1P00KMP5001Ve080001<00<0001Q0000K@0006d00P0007H20000
P0<0002=00<000nO06IVIP3oool0=@3oool000`0oooo00<000000?ooo`3oool03P3oool00`1VIVH0
oooo0?ooo`0J0?ooo`L0IVIV0P3oool206IVIPH0oooo00<0IVIV0?ooo`3oool05@3oool00`1VIVH0
oooo0?ooo`020?ooo`0406IVIP3oool0oooo0?ooo`/0NLgo2`1jcOl;07W=o`X0N<go00<0IVIV07O<
o`1gc?l0501gc?l;07K<o`/0M<co2`1cc?l;07;;o`P0Ll_o00<0IVIV07?;o`1cbol0301abol:073;
o``0K/[n2`1]bOhG06_9oPD0JLSn00<0IVIV06W8oP1Yb?h00`1Yb?h;06K6o@`0H<?m2`1E^o/;03^X
m0P006gH1000I]@20000C0040000I`0006d0001]0000MP800020100008d00`1VIVH0oooo0?ooo`0d
0?ooo`00303oool00`000000oooo0?ooo`0?0?ooo`0306IVIP3oool0oooo01<0oooo1P1VIVH60?oo
o`0306IVIP3oool0oooo0080oooo00<0IVIV0?ooo`3oool0103oool00`1VIVH0oooo0?ooo`0E0?oo
o`0406IVIP3oool0oooo06IVIPD0oooo5P1jcOl;07W=o`X0N<go00<0IVIV07S=o`1hcOl02@1hcOl;
07O<o`/0M/co2`1dc?l:07?<o``0M<co201cbol00`1VIVH0Ll_o07?;o`0;077;o`/0L<_o2`1^b_h<
06o:o`/0KLWn2`1[bOh506W8oP0306IVIP1Yb?h0JLSn00@0JLSn2`1Va_d;0633o@/0EK_k300kZ?@2
001cg0L006gH0P00I]@20000C0030000H@0006d0001]0080001f0P00080406IVIP030000003oool0
oooo03<0oooo000;0?ooo`030000003oool0oooo0140oooo0P1VIVH<0?ooo`L0IVIV303oool00`1V
IVH0oooo0?ooo`030?ooo`0306IVIP3oool0oooo00@0oooo00<0IVIV0?ooo`3oool05@3oool00`1V
IVH0oooo06IVIP070?oooaD0N/go5@1icOl00`1VIVH0N<go07S=o`0907S=o`/0Mlco2`1fc?l:07C<
o`/0MLco301dc?l707?;o`0406IVIP1cbol0Ll_o07?;o`/0LL_o5P1`bol;06o:o`/0KLWn301[bOh4
06W8oP0306IVIP1Yb?h0JLSn00@0JLSn2`1Va_d;0633o@/0EK_k300kZ?@5001cg0H006gH00<0001>
0000C01VIVH01P1VIVH01@000800002=0000S@1VIVH0000003D0oooo000;0?ooo`030000003oool0
oooo01<0oooo00<0IVIV0?ooo`3oool00`3oool606IVIQ<0oooo00<0IVIV0?ooo`3oool0103oool0
0`1VIVH0oooo0?ooo`040?ooo`0306IVIP3oool0oooo01D0oooo0P1VIVH80?ooob40N/go201icOl0
0`1VIVH0NLgo07S=o`0:07S=o`/0Mlco5@1fc?l;07G<o``0M<co1`1cbol00`1VIVH0Ll_o07?;o`0;
077;o`/0L/_o2`1`bol<06o:o`/0KLWn401[bOh00`1VIVH0JlWn06_9oP0406_9oP/0J<On2`1Sa?d;
05Rmo0/0?j_f1@00Lm`806IVIP040000C0000640001]0000K@80001f0P0008020000S@80IVIV=@3o
ool000/0oooo00<000000?ooo`3oool04`3oool606IVIQT0oooo00<0IVIV0?ooo`3oool01@3oool0
0`1VIVH0oooo0?ooo`040?ooo`0306IVIP3oool0oooo01D0oooo00<0IVIV0?ooo`3oool01`3oool;
07[=o`/0Nlgo2`1jcOl807W=o`0306IVIP1icOl0N<go01D0N<go2P1gc?l;07K<o`/0MLco4`1dc?l0
0`1VIVH0M<co07C<o`0;07?;o`/0L/_o2`1`bol;06o:o`/0KLWn301^bOh406_9oP0306IVIP1[bOh0
JlWn00@0JlWn2`1Xaoh;06?4o@/0F;gl2@0oZoH706IVIPD007?L0P00KMP0100004h0001<0000H@00
06L20000K@050000MP00080000200000P00008d00P1VIVHe0?ooo`002`3oool00`000000oooo0?oo
o`0<0?ooo`L0IVIV0P3oool00`1VIVH0oooo0?ooo`0J0?ooo`0306IVIP3oool0oooo00H0oooo00<0
IVIV0?ooo`3oool0103oool00`1VIVH0oooo0?ooo`0D0?ooo`80IVIV2@3oool;07c=o`/0Nlgo2`1j
cOl807W=o`0306IVIP1icOl0NLgo00X0NLgo2`1hcOl:07O<o`/0M/co2`1ec?l;07K<o`L0M<co00@0
IVIV07C<o`1dc?l0M<co2`1cbol;07;;o`X0L<_o301abol;06o:o`/0K/Wn101[bOh00`1VIVH0JlWn
06_9oP0406_9oP/0J<On2`1Sa?d;05Rmo080?j_f1`1VIVH303n[mP@01GWO1`00Lm`010000540001<
0000C00006L20000K@80001f0`0008000`0008d0IVIV0?ooo`0d0?ooo`002P3oool2000000P0oooo
1P1VIVH:0?ooo`0306IVIP3oool0oooo01P0oooo00<0IVIV0?ooo`3oool0203oool00`1VIVH0oooo
0?ooo`040?ooo`80IVIV503oool00`1VIVH0oooo06IVIP0:0?ooo`X0O<go2`1kcOlC07[=o`0306IV
IP1jcOl0NLgo00X0NLgo2`1hcOl:07O<o`/0M/co2`1gc?l;07K<o`L0M<co00@0IVIV07C<o`1dc?l0
M<co2`1cbolE07;;o`/0LL_o2`1_b_l<06k9oP@0JlWn00<0IVIV06_9oP1[bOh00`1[bOh;06S7oP/0
HlCm1P1H_O`706IVIPX0?j_f1`05NMl4001cg0050000D`0004h0001<0000H@0006L00P0006d01P00
07H000200000P0000800002=06IVISD0oooo000:0?ooo`040000003oool0oooo0?ooo`H0IVIV4@3o
ool206IVIQP0oooo00<0IVIV0?ooo`3oool02@3oool00`1VIVH0oooo0?ooo`050?ooo`0306IVIP3o
ool0oooo0140oooo00@0IVIV0?ooo`3oool0IVIV2P3oool:07c=oaH0Nlgo201jcOl00`1VIVH0N/go
07W=o`0:07W=o`/0N<go2P1gc?l;07S=o`/0Mlco2`1fc?l607C<o`0406IVIP1dc?l0M<co07C<oaH0
Ll_o2`1bbol;077;o`/0Kl[o3`1^bOh00`1VIVH0K/Wn06k9oP0406k9oP/0JlSn201VaOh806IVIPH0
G;ol2`14[_L900Eig`8007?L00D0001C0000D@0004`0001<0000I`020000K@80001f0`0008000`1V
IVH0oooo0?ooo`0c0?ooo`002P3oool406IVIQT0oooo00<0IVIV0?ooo`3oool05@3oool00`1VIVH0
oooo0?ooo`0:0?ooo`0306IVIP3oool0oooo00D0oooo00<0IVIV0?ooo`3oool0403oool01@1VIVH0
oooo0?ooo`3oool0IVIV00X0oooo5@1lcOl;07_=o`P0N/go00<0IVIV07[=o`1icOl02P1icOl:07S=
o`/0NLgo2`1hcOl;07O<oa40M/co00@0IVIV07K<o`1fc?l0M/co2`1ec?l;07?;o`/0L/_o2P1abol;
06o:o``0L<[o101^bOh00`1VIVH0K/Wn06k9oP0306k9oP/0JlSn00<0I/Gn06IVIP1VIVH01@1VIVH4
06K5oP/0G;ol2`14[_L200anh`P01GWO0P0005<0100004h0001<0000H@0006L20000K@80001f0P00
08000`1VIVH000000?ooo`0c0?ooo`002`3oool00`1VIVH0oooo0?ooo`0J0?ooo`0306IVIP3oool0
oooo01@0oooo00<0IVIV0?ooo`3oool02`3oool00`1VIVH0oooo0?ooo`050?ooo`0306IVIP3oool0
oooo00l0oooo00<0IVIV0?ooo`3oool00P3oool00`1VIVH0oooo0?ooo`080?ooo`/0OLko2P1lcOl;
07_=o`L0N/go00<0IVIV07[=o`1jcOl02`1kcOl:07[=o`/0NLgo2`1hcOlE07O<o`L0M/co00@0IVIV
07K<o`1fc?l0M/co2`1ec?l;07?;o`X0L/_o2`1cbol;077;o`/0L<[o101^bOh00`1VIVH0K/Wn06k9
oP0406k9oP@0JlSn1`1VIVH;06K5oP/0G;ol2`14[_L500anh`H01GWO00D0001C0000D@0004`0001Q
0000I`020000K@80001f0P00080206IVIS@0oooo000<0?ooo`80IVIV6`3oool00`1VIVH0oooo0?oo
o`0C0?ooo`0306IVIP3oool0oooo00`0oooo00<0IVIV0?ooo`3oool01@3oool00`1VIVH0oooo0?oo
o`0=0?ooo`0306IVIP3oool0oooo00@0oooo00<0IVIV0?ooo`3oool0203oool;07g>o`X0O<go2`1k
cOl707c=o`0306IVIP1lcOl0O<go00/0Nlgo2P1jcOl;07W=oaD0N<go2`1gc?l607K<o`0306IVIP1f
c?l0M/co0080M/co2P1ec?l;07?;o`/0M<co2P1cbol<077;o`X0L<[o101^bOh00`1VIVH0K/Wn06k9
oP0806IVIPL0JlSn301Xa_h;05o0o@D0BK3i1@14[_L800anh`<01GWO0P0005<20000C0040000H@00
06L0001]0000K@80001f00<0002006IVIP1VIVH0=03oool000h0oooo00<0IVIV0?ooo`3oool06@3o
ool00`1VIVH0oooo0?ooo`0B0?ooo`0306IVIP3oool0oooo00d0oooo00<0IVIV0?ooo`3oool01@3o
ool00`1VIVH0oooo0?ooo`0<0?ooo`0306IVIP3oool0oooo00D0oooo00<0IVIV0?ooo`3oool0203o
ool;07g>oa`0O<go00<0IVIV07c=o`1lcOl02`1kcOl:07[=oaD0NLgo2`1hcOl;07O<o`H0M/co00@0
IVIV07K<o`1fc?l0M/co2`1gc?l;07G<o`X0M<co2`1cbol;077;o`X0L<[o1`1VIVH5073:o`/0KLSn
2`1Xa_h;05o0o@X0BK3i2`0<O^<01P0005H0001C0000D@0004`0001Q0000I`80001]0P0007H00`00
0800IVIV06IVIP0d0?ooo`003`3oool00`1VIVH0oooo0?ooo`0I0?ooo`0306IVIP3oool0oooo0100
oooo00<0IVIV0?ooo`3oool03`3oool206IVIPH0oooo00<0IVIV0?ooo`3oool02`3oool00`1VIVH0
oooo0?ooo`060?ooo`0306IVIP3oool0oooo00P0oooo5@1mc_lB07c=o`0306IVIP1lcOl0O<go00/0
Nlgo501jcOl;07W=o`/0N<go2P1gc?l607S<o`0306IVIP1hc?l0N<co0080N<co2`1gc?l:07G<o`/0
M<co5P1cbol207;;o`L0IVIV00<0L/_o073:o`1`b_l00P1`b_l00`1VIVH0L<[o073:o`04073:o`/0
KLSn2`1Xa_h;05o0o@/0BK3i0P0CPnH900anh`80001C0P0004`010000640001W0000K@0006d20000
MP030000P01VIVH0oooo03<0oooo000@0?ooo`0306IVIP3oool0oooo01T0oooo0P1VIVH@0?ooo`03
06IVIP3oool0oooo0140oooo00<0IVIV0?ooo`3oool0103oool00`1VIVH0oooo0?ooo`0:0?ooo`03
06IVIP3oool0oooo00L0oooo00<0IVIV0?ooo`3oool0203oool;07k>o`X0OLko4P1lcOl00`1VIVH0
O<go07c=o`0;07c=o`X0Nlgo2P1jcOl;07W=o`X0N<go2`1icOl607S<o`0306IVIP1hc?l0N<co0080
N<co2`1gc?l:07G<oaD0M<co1P1cbol706IVIPT0L/_o101`b_l00`1VIVH0L<[o073:o`04073:o`X0
KLSn2`1Xa_h;05o0o@/0BK3i1@0CPnH600anh`060000EP0005<0001>0000C0000640001W0P0006d2
0000MP030000P01VIVH0oooo03<0oooo000A0?ooo`80IVIV6`3oool00`1VIVH0oooo0?ooo`0=0?oo
o`0306IVIP3oool0oooo0180oooo00<0IVIV0?ooo`3oool0103oool00`1VIVH0oooo0?ooo`090?oo
o`0306IVIP3oool0oooo00P0oooo00<0IVIV0?ooo`3oool02@3oool:07k>o`X0OLko2`1lcOl607g>
o`0406IVIP1mc_l0OLko07g>o`/0O<go2P1kcOl:07[=o`X0NLgo2`1jcOl;07W=o`H0N<co00<0IVIV
07S<o`1hc?l00P1hc?l:07O<o`X0MLco2`1fc?l807C<o`P0IVIV1P1cbol:07;;o`@0L<[o00<0IVIV
073:o`1`b_l0101`b_l;06o9o`/0JlOn2`1R`Od:04fbnPP04h?V0`0<O^<00`0005T0001C0000D`02
0000C0040000H@0006L0001]0000K@80001f00<0IVIV0?ooo`3oool0<P3oool001<0oooo00<0IVIV
0?ooo`3oool06@3oool00`1VIVH0oooo0?ooo`0<0?ooo`0306IVIP3oool0oooo01<0oooo00<0IVIV
0?ooo`3oool0103oool00`1VIVH0oooo0?ooo`080?ooo`0306IVIP3oool0oooo00T0oooo00<0IVIV
0?ooo`3oool02@3oool:07k>o`X0OLko2`1nc_l607g>o`0406IVIP1mc_l0OLko07g>o`/0O<go2P1k
cOl:07[=o`X0Nlgo2`1jcOl;07W=o`D0N<co00<0IVIV07S<o`1hc?l03@1hc?l:07O<o`X0M/co00<0
M<co06IVIP1VIVH01@1VIVH407C<oaD0Ll_o0`1bb_l00`1VIVH0L/[o07;:o`0507;:o`X0KlWo2`1[
aoh;06;1o@/0CK;j0P0IR>T801>3iP070000F@0005H0001C0000CP0004`0001Q0000I`020000K@80
001f00<0IVIV0000003oool0<P3oool001@0oooo00<0IVIV0?ooo`3oool06@3oool00`1VIVH0oooo
0?ooo`0;0?ooo`0306IVIP3oool0oooo01@0oooo00<0IVIV0?ooo`3oool0103oool00`1VIVH0oooo
0?ooo`070?ooo`0306IVIP3oool0oooo00X0oooo00<0IVIV0?ooo`3oool02@3ooolO07k>o`H0OLko
00@0IVIV07g>o`1mc_l0OLko2`1lcOlN07_=o`/0N/go401icOl00`1VIVH0NLgo07W=o`0207W=o`/0
N<co2P1gc?l307K<o`L0IVIV2`1dc?l;07G<o`X0Ll_o101bb_l00`1VIVH0L/[o07;:o`0407;:o`/0
KlWo2P1[aoh;06;1o@/0CK;j1@0IR>T501>3iP050000G00005T0001C0000D@0004`00P0006401000
06L0001]0000K@0007H206IVIS<0oooo000E0?ooo`80IVIV00<0oooo0000003oool05`3oool00`1V
IVH0oooo0?ooo`0:0?ooo`0306IVIP3oool0oooo01D0oooo00<0IVIV0?ooo`3oool0103oool00`1V
IVH0oooo0?ooo`060?ooo`0306IVIP3oool0oooo00/0oooo00<0IVIV0?ooo`3oool02@3oool:07o>
oaD0O/ko1P1mc_l00`1VIVH0OLko07g>o`0<07g>o`X0O<go501kcOlE07[=o`D0NLgo00<0IVIV07W=
o`1icOl00`1icOl;07S<o`D0Mlco1`1VIVHC07K<o`X0MLco2`1cbol307;:o`0306IVIP1bb_l0L/[o
00@0L/[o2`1_bOl:06_7oP/0H/7m2`1=/_X801V8j@804h?V00P0001L0000F@0005H0001C0000CP00
04`0001Q0000I`80001]00<0001f06IVIP1VIVH0<`3oool001L0oooo00<0IVIV0?ooo`3oool0603o
ool206IVIPT0oooo00<0IVIV0?ooo`3oool05`3oool00`1VIVH0oooo0?ooo`040?ooo`0306IVIP3o
ool0oooo00@0oooo00<0IVIV0?ooo`3oool03@3oool00`1VIVH0oooo0?ooo`090?ooo`X0Olko6`1n
c_l0101VIVH0O/ko07k>o`1nc_l;07g>o`X0O<go7P1kcOl;07[=o`D0NLgo00<0IVIV07W=o`1icOl0
0`1icOl707S<o`P0IVIV1@1hc?l:07O<o`/0M/co2`1ec?l:07?;o`<0L/[o00<0IVIV07;:o`1bb_l0
101bb_l<077:o`X0KLOn2`1U`_h;056dnP8088g[1`0IR>T20000G0040000F@0005<0001A0000C080
001Q00<0001W0000K@0006d00P1VIVHc0?ooo`001@3oool6000000d0oooo00<0IVIV0?ooo`3oool0
6@3oool00`1VIVH0oooo0?ooo`060?ooo`0306IVIP3oool0oooo01P0oooo00<0IVIV0?ooo`3oool0
103oool00`1VIVH0oooo0?ooo`030?ooo`0306IVIP3oool0oooo00h0oooo00<0IVIV0?ooo`3oool0
2@3oool:07o>o`X0O/ko2`1oc_l607k>o`0406IVIP1nc_l0O/ko07k>o`/0OLko2P1lcOl:07g=o`X0
O<go2P1kcOl;07[=o`D0NLgo00<0IVIV07W=o`1icOl00P1icOl706IVIP@0NLgo2P1hc?l:07O<o`/0
M/co5@1ec?l307?;o`0306IVIP1cbol0Ll_o00@0Ll_o2`1ab_l:06g7oP/0IL;n2`1A]?X5022=j`D0
6HSY00P0001L0000F@0005H0001C0000CP0004`0001Q0000I`80001]00<0001f06IVIP3oool0<P3o
ool000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`0306IVIP3oool0
oooo01T0oooo00<0IVIV0?ooo`3oool01@3oool00`1VIVH0oooo0?ooo`0I0?ooo`0306IVIP3oool0
oooo00@0oooo00<0IVIV0?ooo`3oool00P3oool00`1VIVH0oooo0?ooo`0?0?ooo`0306IVIP3oool0
oooo00T0oooo7`1oc_l507k>o`0306IVIP1nc_l0O/ko0080O/ko5@1mc_l:07g=o`X0O<go2P1kcOl=
07[=o`L0IVIV00<0N/go07W=o`1icOl0201icOl;07S<o`X0Mlco2P1fc?l;07O<o`X0MLco0`1cbol0
0`1VIVH0Ll_o07?;o`0507?;o`X0LL[o2P1]aoh;06G2oP/0DKCj200PSN/201V8j@070000G`0005`0
001I0000D`000540001<0000H@020000I`80001]00<0IVIV0?ooo`3oool0<@3oool000H0oooo00<0
00000?ooo`3oool04@3oool206IVIQX0oooo00<0IVIV0?ooo`3oool0103oool00`1VIVH0oooo0?oo
o`0J0?ooo`0306IVIP3oool0oooo00@0oooo00D0IVIV0?ooo`3oool0oooo06IVIP0B0?ooo`0306IV
IP3oool0oooo00T0oooo2P20c_lE07o>o`D0O/ko00<0IVIV07k>o`1nc_l0301nc_l;07g>o`X0OLgo
2P1lcOl>07_=o`P0IVIV0`1jcOl00`1VIVH0N/go07[=o`0207[=o`/0NLgo2P1hc?l;07W=o`X0N<co
2P1gc?l;07G<o`<0Ll_o00<0IVIV07?;o`1cbol0101cbol:077:o`/0KlSo2`1W`oh:05Fgn`X088g[
00D0001O0000G00005T0001F0000D`020000C0050000H@0006L0001]0000K@1VIVH0<`3oool000L0
oooo00<000000?ooo`3oool04P3oool00`1VIVH0oooo0?ooo`0H0?ooo`0306IVIP3oool0oooo00<0
oooo00<0IVIV0?ooo`3oool06`3oool00`1VIVH0oooo0?ooo`040?ooo`0406IVIP3oool0oooo06IV
IQ<0oooo00<0IVIV0?ooo`3oool0203oool00`1VIVH0P<ko083>o`08083>oaX0Olko00<0IVIV07o>
o`1oc_l00P1oc_l:07k>o`/0OLko501mcOl607c=o`L0IVIV1`1kcOl407[=o`0306IVIP1jcOl0N/go
00<0N/go2P1icOl;07[=o`X0NLgo2`1hc?l:07O<o`X0MLco0`1ebol00`1VIVH0ML_o07G;o`0507G;
o`X0Ll[o2P1_b?l;06O3oPX0EKOk100VTNh7022=j`070000G`0005`0001I0000D`0004h0001<0000
H@020000I`030000K@1VIVH000000380oooo00080?ooo`030000003oool0oooo0180oooo00<0IVIV
0?ooo`3oool0603oool00`1VIVH0oooo0?ooo`020?ooo`0306IVIP3oool0oooo01`0oooo00<0IVIV
0?ooo`3oool0103oool306IVIQ@0oooo00<0IVIV0?ooo`3oool01`3oool00`1VIVH0oooo083>o`09
083>o`X0Olko2`20c_l507o>o`0306IVIP1oc_l0Olko0080Olko2P1nc_l:07g>o`X0O/ko2@1mcOl7
06IVIP@0O<go2`1kcOl407[=o`0306IVIP1jcOl0N/go0080N/go2`1kcOl:07[=o`/0NLgo2P1hc?lE
07O<o`80ML_o00<0IVIV07G;o`1ebol01@1ebol:07?:o`X0KlSo2`1W`oh:05Fgn`P09Y7^0`0PSN/0
1@0006<0001L0000F@0005H0001C0080001<00<0001Q0000I`0006d00P1VIVHb0?ooo`002@3oool0
0`000000oooo0?ooo`0B0?ooo`0306IVIP3oool0oooo01P0oooo0P1VIVH00`3oool0IVIV0?ooo`0O
0?ooo`80IVIV1P3oool00`1VIVH0oooo0?ooo`0C0?ooo`0306IVIP3oool0oooo00H0oooo00<0IVIV
0?ooo`3oool02P20c_l:087>o`/0P<ko1@1oc_l00`1VIVH0Olko07o>o`0207o>o`X0O/ko2P1oc_l:
07k>o`0307g=o`1VIVH0IVIV00D0IVIV0`1mcOlG07c=o`0306IVIP1lcOl0O<go00<0O<go2P1kcOl;
07[=oaD0NLgo2P1hc?l:07O<o`<0ML_o00<0IVIV07G;o`1ebol0101ebol:07?:o`X0KlSo2`1W`oh:
05Fgn`/09Y7^00P0001S0000G`0005`0001I0000D`0004h0001<0000H@80001W0P1VIVHb0?ooo`00
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0180oooo0P1VIVHJ0?ooo`80IVIV
8P3oool00`1VIVH0oooo0?ooo`030?ooo`80IVIV503oool00`1VIVH0oooo0?ooo`050?ooo`0306IV
IP3oool0oooo0080oooo5021c_l;083>o`D0Olko00<0IVIV07o>o`1oc_l05P1oc_l207k>o`P0IVIV
501mcOl>07c=o`0306IVIP1lcOl0O<go00<0O<go2P1kcOlE07[=o`X0NLgo2P1hc?l:07O<o`<0ML_o
00<0IVIV07G;o`1ebol0101ebol;07C;o`X0LLWo2`1Ya?h:05Rho0<0;9K`1`0VTNh01`0006H0001S
0000G00005T0001F0000D@0004`00P0006400`0006L0IVIV06IVIP0b0?ooo`001@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo00@0IVIV0?ooo`3oool000005`3oool00`1V
IVH0oooo0?ooo`0Q0?ooo`0306IVIP3oool0oooo0080oooo00<0IVIV0?ooo`1VIVH0503oool00`1V
IVH0oooo0?ooo`040?ooo`0306IVIP3oool0oooo00<0oooo5021c_l?083>o`0306IVIP20c_l0P<ko
0080P<ko3`1oc_l706IVIQ<0O/ko2P1mcOl>07c=o`0306IVIP1lcOl0O<go00<0O<go501kcOl:07[=
o`/0NLgo501hc?l207O<o`0306IVIP1gc?l0Mlco00D0Mlco2P1dbol;0779o`X0JLCn2P1H^?`702bF
l0<09Y7^0P0006H01`0005l0001L0000F@0005<0001>0000C00006400P0006L00`1VIVH0oooo0?oo
o`0`0?ooo`001P3oool4000001P0oooo00<0IVIV0000003oool05`3oool206IVIR<0oooo00@0IVIV
0?ooo`3oool0IVIV0`3oool00`1VIVH0oooo0?ooo`0B0?ooo`0306IVIP3oool0oooo00<0oooo00<0
IVIV0?ooo`3oool0103ooolO087>o`@0P<ko00<0IVIV083>o`20c_l00P20c_l707o>o`L0IVIV401o
c_l;07k>o`X0OLgo2@1lcOl407g=o`0306IVIP1mcOl0OLgo00@0OLgo2@1lcOl;07_=o`X0N/go501i
cOl:07S<o`<0Mlco00<0IVIV07O<o`1gc?l01@1gc?l:07C;o`X0LLWo2P1Ya?h:05Rho0X0;9K`0P00
06H01P0006<0001L0000F@0005H0001A0000C080001Q00<0001W06IVIP3oool0<@3oool002<0oooo
0P1VIVHG0?ooo`0306IVIP3oool0IVIV02<0oooo00<0IVIV0?ooo`1VIVH0103oool00`1VIVH0oooo
0?ooo`0B0?ooo`0306IVIP3oool0oooo0080oooo00<0IVIV0?ooo`3oool01@3ooolO087>o`@0P<ko
00@0IVIV083>o`20c_l0P<ko1`1VIVH407o>o`X0P<ko2P1oc_l;07k>o`T0OLgo2P1ncOl407g=o`03
06IVIP1mcOl0OLgo00<0OLgo2P1lcOl:07_=oaD0N/go2@1icOl;07S<o`80Mlco00<0IVIV07O<o`1g
c?l01@1gc?l:07C;o`80oooo00<0IVIV0?ooo`3oool06@3oool;02bFl080001V00T0001O0000G000
05T0001C0000CP0004`0001Q0000I`1VIVH0<P3oool002D0oooo00<0IVIV0?ooo`3oool0503oool0
0`1VIVH0oooo0?ooo`0206IVIR80oooo0P1VIVH50?ooo`0306IVIP3oool0oooo0180oooo00D0IVIV
0?ooo`3oool0oooo06IVIP080?ooo`/0P/ko4`21c_l806IVIQH0P<ko2P1oc_lD07k>o`X0O/go0`1m
cOl00`1VIVH0OLgo07g=o`0407g=oa@0O<go2P1kcOl:07[=o`X0NLgo2P1hc?l30?ooo`0306IVIP3o
ool0oooo0100oooo00<0IVIV0?ooo`3oool07`3oool502bFl0080000J@0006H0001S0000G00005T0
001F0000D@0004`20000H@0306IVIP000000oooo0300oooo000V0?ooo`0306IVIP3oool0oooo0180
oooo00<0IVIV0?ooo`3oool00`3oool00`1VIVH0oooo0?ooo`0P0?ooo`0306IVIP3oool0oooo00@0
oooo00<0IVIV0?ooo`3oool04P3oool0101VIVH0oooo0?ooo`1VIVH:0?ooo`X0P/ko2P21c_l00`22
c_l0IVIV06IVIP0506IVIP80P/ko1021c_l00`1VIVH0PLko087>o`02087>oa@0P<ko501oc_l:07k>
o`X0O/go0`1mcOl00`1VIVH0OLgo07g=o`0>07g=o`T0O<go2`1kcOl907[=o`X0NLgo3@3oool00`1V
IVH0oooo0?ooo`0@0?ooo`0306IVIP3oool0oooo0280oooo0P1VIVH02P0006T0001V0000IP0005l0
001L0000F@0005<0001>0000C000064206IVIS40oooo000W0?ooo`0306IVIP3oool0oooo0140oooo
00<0IVIV0?ooo`3oool0103oool00`1VIVH0oooo0?ooo`0O0?ooo`80IVIV1P3oool00`1VIVH0oooo
0?ooo`0B0?ooo`0306IVIP3oool0IVIV00/0oooo3@22c_l706IVIPX0P/ko1021c_l00`1VIVH0PLko
087>o`02087>oad0P<ko2`1oc_l:07k>o`d0O/go00<0IVIV07k=o`1ncOl00`1ncOl:07g=o`X0O<go
2P1kcOl40?ooo`0306IVIP3oool0oooo01T0oooo00<0IVIV0?ooo`3oool0403oool00`1VIVH0oooo
0?ooo`0J0?ooo`P0IVIV0`3oool02@0006T0001V0000H`0005`0001I0000EP000540001<0000H@02
06IVIS40oooo000X0?ooo`80IVIV4@3oool00`1VIVH0oooo0?ooo`050?ooo`0306IVIP3oool0oooo
01h0oooo00<0IVIV0?ooo`1VIVH01P3oool00`1VIVH0oooo0?ooo`0B0?ooo`80IVIV303oool408?>
o`P0IVIV4P22c_l3087>o`0306IVIP21c_l0PLko01H0PLko2P20c_l;07o>o`T0O/ko2P1oc_l307k=
o`0306IVIP1ncOl0O/go00@0O/go2P1mcOl907c=o`h0oooo00<0IVIV0?ooo`3oool06P3oool00`1V
IVH0oooo0?ooo`0?0?ooo`0306IVIP3oool0oooo0180oooo201VIVH<0?ooo`80001V00D0001O0000
G00005T0001C0000C0020000H@0306IVIP3oool0oooo02l0oooo000Z0?ooo`0306IVIP3oool0oooo
00h0oooo00<0IVIV0?ooo`3oool01P3oool00`1VIVH0oooo0?ooo`0M0?ooo`0406IVIP3oool0oooo
06IVIPH0oooo00<0IVIV0?ooo`3oool04P3oool00`1VIVH0oooo0?ooo`070?ooo`L0IVIV1`23c_lG
08;>o`0306IVIP22c_l0P/ko00<0P/ko4`21c_lE083>oa<0Olko0`1ncOl00`1VIVH0O/go07k=o`04
07k=o`T0OLgo5`3oool00`1VIVH0oooo0?ooo`0J0?ooo`0306IVIP3oool0oooo00l0oooo00<0IVIV
0?ooo`3oool02P3oool806IVIQ@0oooo00X0001Y0000IP0006<0001L0000F@0005H0001>0000C000
0640IVIV<@3oool002/0oooo00<0IVIV0?ooo`3oool03@3oool00`1VIVH0oooo0?ooo`070?ooo`03
06IVIP3oool0oooo01`0oooo00D0IVIV0?ooo`3oool0oooo06IVIP060?ooo`0306IVIP3oool0oooo
0140oooo0P1VIVH00`3oool0IVIV06IVIP0506IVIPD0oooo2P23c_l:08;>o`T0Plko1022c_l00`1V
IVH0P/ko08;>o`0308;>oad0PLko2P20c_lC07o>o`<0oooo00<0IVIV0?ooo`3oool0903oool00`1V
IVH0oooo0?ooo`0J0?ooo`0306IVIP3oool0oooo00l0oooo00<0IVIV0?ooo`3oool00P3oool806IV
IQd0oooo0P0006H01`0005l0001L0000F@000540001<0000H@1VIVH0<@3oool002`0oooo00@0IVIV
0?ooo`3oool000002`3oool00`1VIVH0oooo0?ooo`080?ooo`80IVIV703oool00`1VIVH0oooo0?oo
o`020?ooo`0306IVIP3oool0oooo00@0oooo00<0IVIV0?ooo`3oool0303oool706IVIPd0oooo7@23
c_l408;>o`0306IVIP22c_l0P/ko00<0P/ko2@21c_l:08;>o`X0PLko2P20c_l907o>o`H0oooo00<0
IVIV0?ooo`3oool0103oool00`1VIVH0oooo0?ooo`0S0?ooo`0306IVIP3oool0oooo01/0oooo00<0
IVIV0?ooo`3oool02`3oool806IVIRD0oooo00P0001Y0000IP0006<0001L0000F@0005H0001>0000
C080IVIV<03oool002d0oooo0P1VIVH00`000000oooo0?ooo`080?ooo`0306IVIP3oool0oooo00/0
oooo00<0IVIV0?ooo`3oool0603oool00`1VIVH0oooo0?ooo`040?ooo`80IVIV1@3oool00`1VIVH0
oooo0?ooo`030?ooo`P0IVIV103oool0101VIVH0oooo0?ooo`1VIVH=0?ooo`X0Q<ko4`23c_l408;>
o`0306IVIP22c_l0P/ko01H0P/ko2P21c_l9083>o`l0oooo00<0IVIV0?ooo`3oool01@3oool00`1V
IVH0oooo0?ooo`0R0?ooo`0306IVIP3oool0oooo01/0oooo00<0IVIV0?ooo`3oool00`3oool806IV
IP@0oooo00<0IVIV0?ooo`3oool09`3oool20000IP070000G`0005`0001I0000D@0004`0IVIV0000
000`0?ooo`00;`3oool00`1VIVH0oooo0?ooo`080?ooo`0306IVIP3oool0oooo00`0oooo00<0IVIV
0?ooo`3oool05`3oool00`1VIVH0oooo0?ooo`060?ooo`0406IVIP3oool0oooo0?ooo`L0IVIV2`3o
ool00`1VIVH0oooo0?ooo`020?ooo`0306IVIP3oool0oooo00`0oooo2@24c_lF08?>o`0306IVIP23
c_l0Plko00@0Plko4`22c_l9087>oaP0oooo00<0IVIV0?ooo`3oool01@3oool00`1VIVH0oooo0?oo
o`0R0?ooo`0306IVIP3oool0oooo01T0oooo201VIVH<0?ooo`0306IVIP3oool0oooo02L0oooo00L0
001Y0000IP0006<0001L0000F@0005H0001>0080IVIV<03oool00300oooo00<0IVIV0?ooo`3oool0
1`3oool00`1VIVH0oooo0?ooo`0=0?ooo`0306IVIP3oool0oooo01H0oooo00<0IVIV0?ooo`3oool0
0`3oool706IVIP<0oooo00<0IVIV0?ooo`3oool0303oool00`1VIVH0oooo0?ooo`030?ooo`0306IV
IP3oool0oooo00`0oooo2@24c_lF08?>o`0306IVIP23c_l0Plko00@0Plko4P22c_lQ0?ooo`0306IV
IP3oool0oooo00H0oooo00<0IVIV0?ooo`3oool08@3oool00`1VIVH0oooo0?ooo`0A0?ooo`P0IVIV
0`3oool00`1VIVH0oooo0?ooo`0>0?ooo`0306IVIP3oool0oooo02P0oooo00H0001Y0000IP0005l0
001L0000F@00054206IVIS00oooo000a0?ooo`80IVIV1`3oool00`1VIVH0oooo0?ooo`0>0?ooo`03
06IVIP3oool0oooo01@0oooo1`1VIVH50?ooo`0306IVIP3oool0oooo00<0oooo0P1VIVH<0?ooo`03
06IVIP3oool0oooo00@0oooo00<0IVIV0?ooo`3oool0303ooolC08C>o``0Plko00<0IVIV08?>o`23
c_l01023c_l70?ooo`0306IVIP3oool0oooo02P0oooo00<0IVIV0?ooo`3oool01P3oool00`1VIVH0
oooo0?ooo`0Q0?ooo`0306IVIP3oool0oooo00T0oooo201VIVH;0?ooo`0306IVIP3oool0oooo00h0
oooo00<0IVIV0?ooo`3oool0:03oool00`0006T0001V0000IP0506IVIS00oooo000c0?ooo`0306IV
IP3oool0oooo00@0oooo00<0IVIV0?ooo`3oool03`3oool206IVIP`0oooo201VIVH00`3oool0IVIV
0?ooo`0:0?ooo`0306IVIP3oool0oooo00@0oooo00<0IVIV0?ooo`3oool02@3oool00`1VIVH0oooo
0?ooo`050?ooo`0306IVIP3oool0oooo00`0oooo4`24c_l908?>o`<0oooo00<0IVIV0?ooo`3oool0
2P3oool00`1VIVH0oooo0?ooo`0X0?ooo`0306IVIP3oool0oooo00L0oooo00<0IVIV0?ooo`3oool0
803oool0101VIVH0oooo0?ooo`3oool806IVIQ@0oooo00<0IVIV0?ooo`3oool03@3oool00`1VIVH0
oooo0?ooo`0S0?ooo`P0IVIV00D0001O0000G00005T0001A06IVIP0`0?ooo`00=03oool00`1VIVH0
oooo0?ooo`030?ooo`0306IVIP3oool0oooo0140oooo00<0IVIV0?ooo`3oool00P3oool706IVIPT0
oooo00<0IVIV0?ooo`3oool02P3oool00`1VIVH0oooo0?ooo`040?ooo`0306IVIP3oool0oooo00P0
oooo00<0IVIV0?ooo`3oool01P3oool00`1VIVH0oooo0?ooo`0<0?oooa<0Q<ko303oool00`1VIVH0
oooo0?ooo`090?ooo`0306IVIP3oool0oooo02P0oooo00<0IVIV0?ooo`3oool0203oool00`1VIVH0
oooo0?ooo`0K0?ooo`P0IVIV703oool00`1VIVH0oooo0?ooo`0=0?ooo`0306IVIP3oool0oooo01/0
oooo201VIVH60?ooo`070000J@0006H0001V0000G00005T0001F06IVIP0`0?ooo`00=@3oool01P1V
IVH0oooo0?ooo`3oool0IVIV00000140oooo1`1VIVH@0?ooo`0306IVIP3oool0oooo00/0oooo00<0
IVIV0?ooo`3oool0103oool00`1VIVH0oooo0?ooo`070?ooo`0306IVIP3oool0oooo00L0oooo00<0
IVIV0?ooo`3oool0303oool908C>oaH0oooo00<0IVIV0?ooo`3oool0203oool00`1VIVH0oooo0?oo
o`0X0?ooo`0306IVIP3oool0oooo00P0oooo00<0IVIV0?ooo`3oool04`3oool806IVIP@0oooo00<0
IVIV0?ooo`3oool07@3oool00`1VIVH0oooo0?ooo`0=0?ooo`0306IVIP3oool0oooo01<0oooo201V
IVH?0?ooo`050000J@0006H0001O0000G00005T00P1VIVH_0?ooo`00=P3oool206IVIP030?ooo`1V
IVH0000000T0oooo201VIVH40?ooo`0306IVIP3oool0oooo0100oooo00<0IVIV0?ooo`3oool0303o
ool00`1VIVH0oooo0?ooo`040?ooo`0306IVIP3oool0oooo00H0oooo00<0IVIV0?ooo`3oool0203o
ool00`1VIVH0oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<0IVIV0?ooo`3oool0203o
ool00`1VIVH0oooo0?ooo`0X0?ooo`0306IVIP3oool0oooo00T0oooo00<0IVIV0?ooo`3oool02@3o
ool906IVIP`0oooo00<0IVIV0?ooo`3oool07P3oool00`1VIVH0oooo0?ooo`0<0?ooo`0306IVIP3o
ool0oooo00X0oooo2@1VIVHG0?ooo`050000J@0006H0001V0000G00005T00P1VIVH_0?ooo`00>03o
ool206IVIP<0oooo1`1VIVH=0?ooo`0306IVIP3oool0oooo00h0oooo00<0IVIV0?ooo`3oool03P3o
ool00`1VIVH0oooo0?ooo`040?ooo`0306IVIP3oool0oooo00D0oooo00<0IVIV0?ooo`3oool02@3o
ool00`1VIVH0oooo0?ooo`0:0?ooo`030000003oool0oooo01d0oooo00<0IVIV0?ooo`3oool01`3o
ool00`1VIVH0oooo0?ooo`0X0?ooo`0306IVIP3oool0oooo00T0oooo00@0IVIV0?ooo`3oool0oooo
201VIVHE0?ooo`0306IVIP3oool0oooo01h0oooo00<0IVIV0?ooo`3oool0303oool00`1VIVH0oooo
0?ooo`020?ooo`P0IVIV8@3oool0100006T0001V0000G`0005`206IVIRl0oooo000i0?ooo`@0IVIV
5@3oool00`1VIVH0oooo0?ooo`0=0?ooo`0306IVIP3oool0oooo00l0oooo00<0IVIV0?ooo`3oool0
103oool00`1VIVH0oooo0?ooo`040?ooo`0306IVIP3oool0oooo00X0oooo00<0IVIV0?ooo`3oool0
2@3oool00`000000oooo0?ooo`0N0?ooo`0306IVIP3oool0oooo00H0oooo00<0IVIV0?ooo`3oool0
:03oool00`1VIVH0oooo0?ooo`050?ooo`P0IVIV7@3oool00`1VIVH0oooo0?ooo`0O0?ooo`0306IV
IP3oool0oooo00P0oooo201VIVHZ0?ooo`80001V00<0001L06IVIP1VIVH0;`3oool003X0oooo00<0
IVIV0?ooo`3oool05P3oool206IVIPd0oooo00<0IVIV0?ooo`3oool0403oool00`1VIVH0oooo0?oo
o`040?ooo`0306IVIP3oool0oooo00<0oooo00<0IVIV0?ooo`3oool02`3oool00`1VIVH0oooo0?oo
o`080?ooo`030000003oool0oooo01l0oooo00<0IVIV0?ooo`3oool01@3oool00`1VIVH0oooo0?oo
o`0X0?ooo`P0IVIV1P3oool00`1VIVH0oooo0?ooo`0L0?ooo`0306IVIP3oool0oooo01l0oooo00<0
IVIV0?ooo`3oool0201VIVH40?ooo`0306IVIP3oool0oooo02/0oooo00<0001Y0000IP0005l00P1V
IVH_0?ooo`00>`3oool206IVIQP0oooo00<0IVIV0?ooo`3oool02P3oool00`1VIVH0oooo0?ooo`0A
0?ooo`0306IVIP3oool0oooo00@0oooo00<0IVIV0?ooo`3oool00P3oool00`1VIVH0oooo0?ooo`0<
0?ooo`0306IVIP3oool0oooo00L0oooo00<000000?ooo`3oool0803oool00`1VIVH0oooo0?ooo`04
0?ooo`0306IVIP3oool0oooo0200oooo2@1VIVH=0?ooo`0306IVIP3oool0oooo01`0oooo00<0IVIV
0?ooo`3oool06P3oool806IVIP`0oooo00<0IVIV0?ooo`3oool0;03oool0100006T0001V0000G01V
IVH_0?ooo`00?@3oool00`1VIVH0oooo0?ooo`0F0?ooo`0306IVIP3oool0oooo00T0oooo00<0IVIV
0?ooo`3oool04P3oool00`1VIVH0oooo0?ooo`040?ooo`0406IVIP3oool0oooo06IVIQ00oooo00<0
IVIV0?ooo`3oool01P3oool00`000000oooo0?ooo`0Q0?ooo`0306IVIP3oool0oooo00<0oooo00<0
IVIV0?ooo`3oool0603oool806IVIPP0oooo00<0IVIV0?ooo`3oool0303oool00`1VIVH0oooo0?oo
o`0K0?ooo`0306IVIP3oool0oooo0140oooo2@1VIVH60?ooo`0306IVIP3oool0oooo00/0oooo00<0
IVIV0?ooo`3oool0;03oool0100006T0001V0000G`1VIVH_0?ooo`00?P3oool00`1VIVH0oooo0?oo
o`0F0?ooo`0306IVIP3oool0oooo00P0oooo00<0IVIV0?ooo`3oool04`3oool206IVIPD0oooo00<0
IVIV0?ooo`1VIVH04@3oool00`1VIVH0oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<0
IVIV0?ooo`3oool00`3oool00`1VIVH0oooo0?ooo`0@0?ooo`P0IVIV403oool00`1VIVH0oooo0?oo
o`0<0?ooo`0306IVIP3oool0oooo01/0oooo00<0IVIV0?ooo`3oool02@3oool806IVIPl0oooo00<0
IVIV0?ooo`3oool02`3oool00`1VIVH0oooo0?ooo`0]0?ooo`040000J@0006H0IVIV06IVIRh0oooo
000o0?ooo`80IVIV5`3oool00`1VIVH0oooo0?ooo`070?ooo`0306IVIP3oool0oooo01D0oooo00<0
IVIV0?ooo`3oool00`3oool206IVIQ80oooo00<0IVIV0?ooo`3oool0103oool00`000000oooo0?oo
o`0R0?ooo`0506IVIP3oool0oooo0?ooo`1VIVH02`3oool806IVIQP0oooo00<0IVIV0?ooo`3oool0
3@3oool00`1VIVH0oooo0?ooo`0K0?ooo`0306IVIP3oool0oooo00P0IVIV5`3oool00`1VIVH0oooo
0?ooo`0;0?ooo`0306IVIP3oool0oooo02d0oooo00@0001Y0000IP1VIVH0IVIV;P3oool00440oooo
00@0IVIV0?ooo`3oool00000503oool206IVIPL0oooo00<0IVIV0?ooo`3oool05P3oool00`1VIVH0
oooo0?ooo`030?ooo`0306IVIP3oool0oooo0140oooo00<0IVIV0?ooo`3oool00`3oool00`000000
oooo0?ooo`0S0?ooo`0406IVIP3oool0oooo06IVIP<0oooo201VIVHP0?ooo`0306IVIP3oool0oooo
00h0oooo00<0IVIV0?ooo`3oool05@3oool806IVIR00oooo00<0IVIV0?ooo`3oool02P3oool00`1V
IVH0oooo0?ooo`0^0?ooo`030000J@1VIVH0IVIV02h0oooo00120?ooo`0306IVIP000000oooo01H0
oooo00<0IVIV0?ooo`3oool0103oool00`1VIVH0oooo0?ooo`0G0?ooo`0306IVIP3oool0oooo0080
oooo0P1VIVHC0?ooo`0306IVIP3oool0oooo0080oooo00<000000?ooo`3oool08P3oool806IVIRP0
oooo00<0IVIV0?ooo`3oool03P3oool00`1VIVH0oooo0?ooo`0<0?ooo`T0IVIV1@3oool00`1VIVH0
oooo0?ooo`0P0?ooo`0306IVIP3oool0oooo00X0oooo00<0IVIV0?ooo`3oool0;03oool206IVIP03
0000J@1VIVH0IVIV02h0oooo00130?ooo`0306IVIP3oool0oooo01H0oooo00<0IVIV0?ooo`3oool0
0P3oool00`1VIVH0oooo0?ooo`0I0?ooo`0706IVIP3oool0oooo0?ooo`1VIVH0oooo06IVIP0C0?oo
o`0506IVIP3oool0oooo0?ooo`000000703oool806IVIP<0oooo0P1VIVH[0?ooo`0306IVIP3oool0
oooo00l0oooo00<0IVIV0?ooo`3oool00`3oool806IVIPh0oooo00<0IVIV0?ooo`3oool08@3oool0
0`1VIVH0oooo0?ooo`090?ooo`0306IVIP3oool0oooo02@0oooo201VIVH30?ooo`80IVIV;P3oool0
04@0oooo0P1VIVHG0?ooo`0506IVIP3oool0oooo0?ooo`1VIVH0703oool0101VIVH0oooo0?ooo`1V
IVH20?ooo`0306IVIP3oool0oooo0140oooo00@0IVIV0?ooo`3oool00000503oool806IVIP`0oooo
00<0IVIV0?ooo`3oool0:@3oool00`1VIVH0oooo0?ooo`0=0?ooo`P0IVIV5P3oool00`1VIVH0oooo
0?ooo`0Q0?ooo`0306IVIP3oool0oooo00T0oooo00<0IVIV0?ooo`3oool06`3oool906IVIP/0oooo
00<0001Y06IVIP3oool0;@3oool003H0oooo1000000<0?ooo`0306IVIP3oool0oooo01D0oooo00@0
IVIV0?ooo`3oool0IVIV7@3oool00`1VIVH0oooo06IVIP030?ooo`0306IVIP3oool0oooo0140oooo
00<0IVIV0000003oool0303oool806IVIQ@0oooo00<0IVIV0?ooo`3oool0:@3oool00`1VIVH0oooo
0?ooo`050?ooo`P0IVIV0`3oool00`1VIVH0oooo0?ooo`0H0?ooo`0306IVIP3oool0oooo0240oooo
00<0IVIV0?ooo`3oool02P3oool00`1VIVH0oooo0?ooo`0A0?ooo`T0IVIV5@3oool00`1VIVH0oooo
0?ooo`0/0?ooo`00>03oool00`000000oooo0?ooo`0<0?ooo`0306IVIP3oool0oooo01D0oooo0`1V
IVHN0?ooo`80IVIV103oool206IVIQ80oooo00<000000?ooo`3oool00`3oool806IVIQ`0oooo0P1V
IVHZ0?ooo`P0IVIV2`3oool00`1VIVH0oooo0?ooo`0H0?ooo`0306IVIP3oool0oooo0280oooo00<0
IVIV0?ooo`3oool02@3oool00`1VIVH0oooo0?ooo`090?ooo`P0IVIV7P3oool00`1VIVH000000?oo
o`0/0?ooo`00>03oool00`000000oooo0?ooo`0=0?ooo`0306IVIP3oool0oooo01H0oooo00<0IVIV
0?ooo`3oool07@3oool00`1VIVH0oooo0?ooo`040?ooo`0306IVIP3oool0oooo00l0oooo00<00000
06IVIP1VIVH00`1VIVHT0?ooo`0306IVIP3oool0IVIV0200oooo2P1VIVHC0?ooo`0306IVIP3oool0
oooo01L0oooo00<0IVIV0?ooo`3oool08P3oool00`1VIVH0oooo0?ooo`090?ooo`0306IVIP3oool0
oooo00T0IVIV9P3oool206IVIRd0oooo000d0?ooo`H000003`3oool206IVIQH0oooo0P1VIVHN0?oo
o`80IVIV1P3oool00`1VIVH0oooo0?ooo`0>0?ooo`030000003oool0oooo02L0oooo00@0IVIV0?oo
o`3oool0IVIV5`3oool806IVIPT0oooo00<0IVIV0?ooo`3oool04P3oool00`1VIVH0oooo0?ooo`0F
0?ooo`0306IVIP3oool0oooo02<0oooo00<0IVIV0?ooo`3oool00`3oool806IVIRl0oooo0P1VIVH]
0?ooo`00=@3oool010000000oooo0?ooo`00000B0?ooo`0306IVIP3oool0000001<0oooo00<0IVIV
0?ooo`1VIVH0703oool0101VIVH0oooo0?ooo`1VIVH60?ooo`0306IVIP3oool0oooo00d0oooo00<0
00000?ooo`3oool09`3oool01@1VIVH0oooo0?ooo`3oool0IVIV00h0oooo201VIVHA0?ooo`0306IV
IP3oool0oooo0180oooo00<0IVIV0?ooo`3oool05P3oool00`1VIVH0oooo0?ooo`0P0?ooo`T0IVIV
1@3oool00`1VIVH0oooo0?ooo`0_0?ooo`80IVIV;@3oool003D0oooo00@000000?ooo`3oool00000
4`3oool00`1VIVH000000?ooo`0B0?ooo`0406IVIP3oool0oooo06IVIQ/0oooo00D0IVIV0?ooo`3o
ool0oooo06IVIP060?ooo`0306IVIP3oool0oooo00`0oooo00<000000?ooo`3oool09`3oool00`1V
IVH0oooo0?ooo`020?ooo`0306IVIP3oool0oooo00<0oooo201VIVHI0?ooo`0306IVIP3oool0oooo
01<0oooo00<0IVIV0?ooo`3oool05@3oool00`1VIVH0oooo0?ooo`0G0?ooo`T0IVIV0`3oool00`1V
IVH0oooo0?ooo`080?ooo`0306IVIP3oool0oooo02l0oooo0P1VIVH]0?ooo`00=P3oool00`000000
oooo0000000D0?ooo`80IVIV4P3oool01@1VIVH0oooo0?ooo`3oool0IVIV01X0oooo00<0IVIV0?oo
o`3oool00P3oool206IVIPD0oooo00<0IVIV0?ooo`3oool02`3oool00`000000oooo0?ooo`0W0?oo
o`0306IVIP3oool0IVIV00P0IVIV8@3oool00`1VIVH0oooo0?ooo`0C0?ooo`0306IVIP3oool0oooo
01D0oooo00<0IVIV0?ooo`3oool03`3oool806IVIPd0oooo00<0IVIV0?ooo`3oool01`3oool00`1V
IVH0oooo0?ooo`0`0?ooo`0306IVIP3oool0oooo02/0oooo000f0?ooo`030000003oool0000001H0
oooo00<0IVIV0?ooo`3oool03P3oool00`1VIVH0oooo0?ooo`030?ooo`80IVIV603oool00`1VIVH0
oooo0?ooo`040?ooo`0306IVIP3oool0oooo00<0oooo00<0IVIV0?ooo`3oool02P3oool00`000000
oooo0?ooo`0Q0?ooo`P0IVIV103oool00`1VIVH0oooo0?ooo`0S0?ooo`0306IVIP3oool0oooo01@0
oooo00<0IVIV0?ooo`3oool0503oool00`1VIVH0oooo0?ooo`060?ooo`T0IVIV5@3oool00`1VIVH0
oooo0?ooo`070?ooo`0306IVIP3oool0oooo0300oooo00<0IVIV0?ooo`3oool0:`3oool003L0oooo
0P00000G0?ooo`0306IVIP3oool0oooo00d0oooo00<0IVIV0?ooo`3oool01@3oool00`1VIVH0oooo
0?ooo`0E0?ooo`0306IVIP3oool0oooo00D0oooo00<0IVIV0?ooo`3oool00`3oool00`1VIVH0oooo
0?ooo`090?ooo`030000003oool0oooo01T0oooo201VIVH60?ooo`0306IVIP3oool0oooo00@0oooo
00<0IVIV0?ooo`3oool08P3oool00`1VIVH0oooo0?ooo`0E0?ooo`0306IVIP3oool0oooo01<0oooo
2@1VIVHN0?ooo`0306IVIP3oool0oooo00L0oooo00<0IVIV0?ooo`3oool0<03oool00`1VIVH00000
0?ooo`0[0?ooo`00D@3oool00`1VIVH0oooo0?ooo`0<0?ooo`0306IVIP3oool0oooo00H0oooo00<0
IVIV0?ooo`3oool0503oool00`1VIVH0oooo0?ooo`060?ooo`0306IVIP3oool0oooo00<0oooo00<0
IVIV0?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`P0IVIV3P3oool00`1VIVH0oooo0?oo
o`050?ooo`0306IVIP3oool0oooo0240oooo00<0IVIV0?ooo`3oool05@3oool00`1VIVH0oooo0?oo
o`0;0?ooo`T0IVIV9`3oool00`1VIVH0oooo0?ooo`060?ooo`0306IVIP3oool0oooo0300oooo0P1V
IVH/0?ooo`00DP3oool206IVIP`0oooo00<0IVIV0?ooo`3oool01`3oool00`1VIVH0oooo0?ooo`0C
0?ooo`0306IVIP3oool0oooo00L0oooo00<0IVIV0?ooo`3oool00`3oool00`1VIVH0oooo0?ooo`07
0?ooo`030000003oool0oooo00P0oooo2@1VIVHF0?ooo`0306IVIP3oool0oooo00H0oooo00<0IVIV
0?ooo`3oool0803oool00`1VIVH0oooo0?ooo`0F0?ooo`0306IVIP3oool0oooo0080oooo201VIVH8
0?ooo`0306IVIP3oool0oooo02D0oooo00<0IVIV0?ooo`3oool01`3oool00`1VIVH0oooo0?ooo`0_
0?ooo`80IVIV;03oool005@0oooo00<0IVIV0?ooo`0000002@3oool00`1VIVH0oooo0?ooo`080?oo
o`0306IVIP3oool0oooo0180oooo00<0IVIV0?ooo`3oool0203oool00`1VIVH0oooo0?ooo`030?oo
o`0306IVIP3oool0oooo00H0oooo00<000000?ooo`3oool0201VIVHO0?ooo`0306IVIP3oool0oooo
00H0oooo00<0IVIV0?ooo`3oool08@3oool00`1VIVH0oooo0?ooo`0A0?ooo`T0IVIV403oool00`1V
IVH0oooo0?ooo`0V0?ooo`0306IVIP3oool0oooo00H0oooo00<0IVIV0?ooo`3oool0;`3oool206IV
IR`0oooo001E0?ooo`0306IVIP000000oooo00P0oooo00<0IVIV0?ooo`3oool02@3oool206IVIQ80
oooo00<0IVIV0?ooo`3oool02@3oool00`1VIVH0oooo0?ooo`030?ooo`0306IVIP3oool0oooo00P0
IVIV9`3oool00`1VIVH0oooo0?ooo`070?ooo`0306IVIP3oool0oooo0200oooo00<0IVIV0?ooo`3o
ool0203oool906IVIPD0oooo00<0IVIV0?ooo`3oool04@3oool00`1VIVH0oooo0?ooo`0V0?ooo`03
06IVIP3oool0oooo00H0oooo00<0IVIV0?ooo`3oool0;`3oool206IVIR`0oooo001F0?ooo`0306IV
IP3oool0oooo00L0oooo00<0IVIV0?ooo`3oool02`3oool00`1VIVH0oooo0?ooo`0?0?ooo`0306IV
IP3oool0oooo00X0oooo201VIVH50?ooo`030000003oool0oooo02L0oooo00<0IVIV0?ooo`3oool0
203oool00`1VIVH0oooo0?ooo`0O0?ooo`0306IVIP3oool0oooo00P0IVIV3`3oool00`1VIVH0oooo
0?ooo`0@0?ooo`0306IVIP3oool0oooo02H0oooo00<0IVIV0?ooo`3oool01P3oool00`1VIVH0oooo
0?ooo`0`0?ooo`0306IVIP3oool0oooo02X0oooo001G0?ooo`80IVIV1`3oool00`1VIVH0oooo0?oo
o`0<0?ooo`0306IVIP3oool0oooo00h0oooo00<0IVIV0?ooo`3oool00P3oool806IVIP030?ooo`1V
IVH0oooo00@0oooo00<0IVIV0?ooo`3oool00P3oool00`000000oooo0?ooo`0X0?ooo`0306IVIP3o
ool0oooo00T0oooo00<0IVIV0?ooo`3oool0603oool906IVIQL0oooo00<0IVIV0?ooo`3oool0403o
ool00`1VIVH0oooo0?ooo`0W0?ooo`0306IVIP3oool0oooo00D0oooo00<0IVIV0?ooo`3oool0;03o
ool506IVIR`0oooo001I0?ooo`0306IVIP3oool0oooo00<0oooo00<0IVIV0?ooo`3oool03P3oool0
0`1VIVH0oooo0?ooo`090?ooo`T0IVIV2P3oool00`1VIVH0oooo0?ooo`030?ooo`0506IVIP3oool0
oooo0?ooo`000000:P3oool00`1VIVH0oooo0?ooo`0:0?ooo`0306IVIP3oool0oooo00l0oooo201V
IVH60?ooo`0306IVIP3oool0oooo01P0oooo00<0IVIV0?ooo`3oool03`3oool00`1VIVH0oooo0?oo
o`0W0?ooo`0306IVIP3oool0oooo00D0oooo00<0IVIV0?ooo`3oool08`3oool906IVIP@0oooo00<0
IVIV0000003oool0:P3oool005X0oooo00<0IVIV0?ooo`3oool00P3oool00`1VIVH0oooo0?ooo`0?
0?ooo`0306IVIP3oool0oooo00P0IVIV0`3oool00`1VIVH0oooo0?ooo`0>0?ooo`0306IVIP3oool0
oooo00<0oooo00@0IVIV0?ooo`3oool00000:P3oool00`1VIVH0oooo0?ooo`0;0?ooo`0306IVIP3o
ool0oooo00D0oooo2@1VIVH>0?ooo`0306IVIP3oool0oooo01P0oooo00<0IVIV0?ooo`3oool03`3o
ool00`1VIVH0oooo0?ooo`0W0?ooo`0306IVIP3oool0oooo00D0oooo00<0IVIV0?ooo`3oool06P3o
ool906IVIPd0oooo0P1VIVH[0?ooo`00F`3oool206IVIP80oooo00<0IVIV0?ooo`3oool02P3oool8
06IVIP/0oooo00<0IVIV0?ooo`3oool03`3oool00`1VIVH0oooo0?ooo`030?ooo`80IVIV00<00000
0?ooo`3oool0:03oool00`1VIVH0oooo0?ooo`0:0?ooo`T0IVIV5`3oool00`1VIVH0oooo0?ooo`0I
0?ooo`0306IVIP3oool0oooo00l0oooo00<0IVIV0?ooo`3oool09`3oool00`1VIVH0oooo0?ooo`04
0?ooo`0306IVIP3oool0oooo0140oooo2@1VIVHF0?ooo`80IVIV:`3oool005d0oooo00<0IVIV0?oo
o`1VIVH0103oool806IVIPL0oooo0P1VIVH:0?ooo`0306IVIP3oool0oooo0100oooo0P1VIVH50?oo
o`0306IVIP3oool0oooo02P0oooo00<0IVIV0?ooo`3oool00P3oool806IVIP80oooo00<0IVIV0?oo
o`3oool06`3oool00`1VIVH0oooo0?ooo`0J0?ooo`0306IVIP3oool0oooo00h0oooo00<0IVIV0?oo
o`3oool09`3oool00`1VIVH0oooo0?ooo`040?ooo`0306IVIP3oool0oooo00P0oooo2@1VIVHO0?oo
o`80IVIV:`3oool005h0oooo1P1VIVHA0?ooo`0306IVIP3oool0oooo00L0oooo00<0IVIV0?ooo`3o
ool04P3oool00`1VIVH0oooo0?ooo`020?ooo`030000001VIVH0oooo02@0oooo2@1VIVH;0?ooo`03
06IVIP3oool0oooo01X0oooo00<0IVIV0?ooo`3oool06P3oool00`1VIVH0oooo0?ooo`0>0?ooo`03
06IVIP3oool0oooo02P0oooo00<0IVIV0?ooo`3oool00`3oool00`1VIVH0oooo06IVIP0806IVIRP0
oooo0P1VIVH[0?ooo`00G`3oool00`1VIVH0oooo0?ooo`0D0?ooo`0306IVIP3oool0oooo00H0oooo
00<0IVIV0?ooo`3oool04`3oool01`1VIVH0oooo0?ooo`3oool000000?ooo`1VIVH0703oool806IV
IP@0oooo00<0IVIV0?ooo`3oool03P3oool00`1VIVH0oooo0?ooo`0I0?ooo`0306IVIP3oool0oooo
01/0oooo00<0IVIV0?ooo`3oool03@3oool00`1VIVH0oooo0?ooo`0W0?ooo`T0IVIV<P3oool00`1V
IVH0oooo0?ooo`0Y0?ooo`00H03oool206IVIQD0oooo00<0IVIV0?ooo`3oool01@3oool00`1VIVH0
oooo0?ooo`0D0?ooo`0406IVIP3oool0oooo00000080oooo00<0IVIV0?ooo`3oool0403oool906IV
IP`0oooo00<0IVIV0?ooo`3oool03`3oool00`1VIVH0oooo0?ooo`0H0?ooo`0306IVIP3oool0oooo
01/0oooo00<0IVIV0?ooo`3oool03@3oool00`1VIVH0oooo0?ooo`0N0?ooo`T0IVIV00<0oooo06IV
IP3oool01@3oool00`1VIVH0oooo0?ooo`0`0?ooo`0306IVIP3oool0oooo02T0oooo001R0?ooo`03
06IVIP3oool0oooo01<0oooo00<0IVIV0?ooo`3oool0103oool00`1VIVH0oooo0?ooo`0E0?ooo`03
06IVIP3oool0000000<0oooo00<0IVIV0?ooo`3oool01P3oool906IVIQD0oooo00<0IVIV0?ooo`3o
ool0403oool00`1VIVH0oooo0?ooo`0G0?ooo`0306IVIP3oool0oooo01`0oooo00<0IVIV0?ooo`3o
ool0303oool00`1VIVH0oooo0?ooo`0E0?ooo`T0IVIV2`3oool00`1VIVH0oooo0?ooo`030?ooo`03
06IVIP3oool0oooo0300oooo0P1VIVHZ0?ooo`00H`3oool00`1VIVH0oooo0?ooo`0C0?ooo`80IVIV
103oool00`1VIVH0oooo0?ooo`0F0?ooo`0306IVIP000000oooo00<0oooo201VIVHN0?ooo`0306IV
IP3oool0oooo0100oooo00<0IVIV0?ooo`3oool05`3oool00`1VIVH0oooo0?ooo`0M0?ooo`0306IV
IP3oool0oooo00/0oooo00<0IVIV0?ooo`3oool0303oool906IVIQ@0oooo00<0IVIV0?ooo`3oool0
0`3oool00`1VIVH0oooo0?ooo`0/0?ooo`H0IVIV:P3oool006@0oooo00@0IVIV0?ooo`3oool00000
4`3oool01@1VIVH0oooo0?ooo`3oool0IVIV01T0oooo00<0000006IVIP1VIVH00P1VIVH00`3oool0
IVIV0?ooo`0S0?ooo`0306IVIP3oool0oooo0140oooo00<0IVIV0?ooo`3oool05P3oool00`1VIVH0
oooo0?ooo`0M0?ooo`0306IVIP3oool0oooo00/0oooo00<0IVIV0?ooo`3oool00`3oool906IVIQd0
oooo00<0IVIV0?ooo`3oool00`3oool00`1VIVH0oooo0?ooo`0R0?ooo`X0IVIV1@3oool00`1VIVH0
oooo0?ooo`0X0?ooo`00I@3oool206IVIP030000003oool0oooo0180oooo00@0IVIV0?ooo`3oool0
IVIV6@3oool00`000000oooo0?ooo`040?ooo`0306IVIP3oool0oooo0240oooo00<0IVIV0?ooo`3o
ool04P3oool00`1VIVH0oooo0?ooo`0E0?ooo`0306IVIP3oool0oooo01h0oooo00<0IVIV0?ooo`3o
ool01`3oool906IVIRL0oooo00<0IVIV0?ooo`3oool00P3oool00`1VIVH0oooo0?ooo`0I0?ooo`T0
IVIV3`3oool00`1VIVH0oooo0?ooo`0X0?ooo`00I`3oool00`1VIVH0oooo0?ooo`0C0?ooo`0306IV
IP3oool0IVIV01T0oooo00<000000?ooo`3oool01@3oool00`1VIVH0oooo0?ooo`0P0?ooo`0306IV
IP3oool0oooo01<0oooo00<0IVIV0?ooo`3oool0503oool00`1VIVH0oooo0?ooo`0N0?ooo`X0IVIV
0`3oool00`1VIVH0oooo0?ooo`0Z0?ooo`0306IVIP3oool0oooo0080oooo00<0IVIV0?ooo`3oool0
3`3oool:06IVIQP0oooo00<0IVIV0?ooo`3oool0:03oool006P0oooo00<0IVIV0?ooo`3oool04`3o
ool00`1VIVH0oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo00<0IVIV0?ooo`3oool07`3o
ool00`1VIVH0oooo0?ooo`0D0?ooo`0306IVIP3oool0oooo01<0oooo00<0IVIV0?ooo`3oool05P3o
ool:06IVIP/0oooo00<0IVIV0?ooo`3oool0:`3oool01@1VIVH0oooo0?ooo`3oool0IVIV00P0oooo
2@1VIVHR0?ooo`0306IVIP3oool0oooo02P0oooo001Y0?ooo`80IVIV4`3oool206IVIQP0oooo00<0
00000?ooo`3oool0203oool00`1VIVH0oooo0?ooo`0N0?ooo`0306IVIP3oool0oooo01D0oooo00<0
IVIV0?ooo`3oool04P3oool00`1VIVH0oooo0?ooo`0=0?ooo`T0IVIV2P3oool00`1VIVH0oooo0?oo
o`080?ooo`0306IVIP3oool0oooo02/0oooo00<0IVIV0?ooo`3oool02P1VIVH[0?ooo`0306IVIP3o
ool0oooo02P0oooo001L0?ooo`@000002`3oool00`1VIVH0oooo0?ooo`0@0?ooo`0406IVIP3oool0
IVIV06IVIQH0oooo00<000000?ooo`3oool02@3oool00`1VIVH0oooo0?ooo`0M0?ooo`0306IVIP3o
ool0oooo01D0oooo00<0IVIV0?ooo`3oool04P3oool00`1VIVH0oooo0?ooo`030?ooo`X0IVIV4`3o
ool00`1VIVH0oooo0?ooo`080?ooo`0306IVIP3oool0oooo02D0oooo2@1VIVH00`3oool0IVIV0?oo
o`0c0?ooo`0306IVIP3oool0oooo02L0oooo001K0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02@3oool0101VIVH0oooo0?ooo`00000>0?ooo`0506IVIP3oool0oooo0?ooo`1VIVH0
5@3oool00`000000oooo0?ooo`0:0?ooo`0306IVIP3oool0oooo01`0oooo00<0IVIV0?ooo`3oool0
5P3oool00`1VIVH0oooo0?ooo`0>0?ooo`T0IVIV7P3oool00`1VIVH0oooo0?ooo`070?ooo`0306IV
IP3oool0oooo01/0oooo2P1VIVH70?ooo`0506IVIP3oool0oooo0?ooo`1VIVH0<`3oool00`1VIVH0
oooo0?ooo`0W0?ooo`00F`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo
00<0IVIV0?ooo`0000003P3oool00`1VIVH0oooo0?ooo`020?ooo`0306IVIP3oool0oooo0180oooo
00<000000?ooo`3oool02`3oool00`1VIVH0oooo0?ooo`0K0?ooo`0306IVIP3oool0oooo01L0oooo
00<0IVIV0?ooo`3oool0103oool906IVIP<0oooo00<0IVIV0?ooo`3oool08@3oool00`1VIVH0oooo
0?ooo`070?ooo`0306IVIP3oool0oooo0180oooo2@1VIVHA0?ooo`0506IVIP3oool0oooo0?ooo`1V
IVH0<`3oool00`1VIVH0oooo0?ooo`0W0?ooo`00F`3oool2000000<0oooo00<000000?ooo`3oool0
2`3oool206IVIPh0oooo00<0IVIV0?ooo`3oool00`3oool00`1VIVH0oooo0?ooo`0A0?ooo`030000
003oool0oooo00`0oooo00<0IVIV0?ooo`3oool06P3oool00`1VIVH0oooo0?ooo`0E0?ooo`T0IVIV
303oool00`1VIVH0oooo0?ooo`0R0?ooo`0306IVIP3oool0oooo00H0oooo00<0IVIV0?ooo`3oool0
203oool:06IVIQX0oooo00D0IVIV0?ooo`3oool0oooo06IVIP0c0?ooo`0306IVIP3oool0oooo02L0
oooo001K0?ooo`030000003oool0000000800000403oool00`1VIVH0oooo0?ooo`0;0?ooo`0306IV
IP3oool0oooo00@0oooo00<0IVIV0?ooo`3oool0403oool00`000000oooo0?ooo`0=0?ooo`80IVIV
6P3oool00`1VIVH0oooo0?ooo`0<0?ooo`T0IVIV103oool00`1VIVH0oooo0?ooo`0>0?ooo`0306IV
IP3oool0oooo0280oooo00<0IVIV0?ooo`3oool01P3oool00`1VIVH0oooo06IVIP0806IVIRD0oooo
00@0IVIV0?ooo`3oool0IVIV<`3oool00`1VIVH0oooo0?ooo`0W0?ooo`00F`3oool00`000000oooo
0?ooo`0C0?ooo`0306IVIP3oool0oooo00X0oooo00<0IVIV0?ooo`3oool01@3oool206IVIQ00oooo
00<000000?ooo`3oool03`3oool00`1VIVH0oooo0?ooo`0G0?ooo`0306IVIP3oool0oooo00<0oooo
2@1VIVH=0?ooo`0306IVIP3oool0oooo00h0oooo00<0IVIV0?ooo`3oool08`3oool:06IVIRh0oooo
00@0IVIV0?ooo`3oool0IVIV<`3oool00`1VIVH0oooo0?ooo`0W0?ooo`00G03oool00`000000oooo
0?ooo`0C0?ooo`0306IVIP3oool0oooo00T0oooo00<0IVIV0?ooo`3oool01`3oool00`1VIVH0oooo
0?ooo`0=0?ooo`030000003oool0oooo0100oooo00<0IVIV0?ooo`3oool04`3oool906IVIQL0oooo
00<0IVIV0?ooo`3oool03@3oool00`1VIVH0oooo0?ooo`0J0?ooo`T0IVIV00<0oooo06IVIP3oool0
1@3oool00`1VIVH0oooo0?ooo`0^0?ooo`0306IVIP3oool0IVIV03<0oooo00<0IVIV0?ooo`3oool0
9`3oool005d0oooo00<000000?ooo`3oool04`3oool206IVIP030?ooo`000000oooo00H0oooo00<0
IVIV0?ooo`3oool0203oool00`1VIVH0oooo0?ooo`0<0?ooo`030000003oool0oooo0140oooo00<0
IVIV0?ooo`3oool02@3oool906IVIP<0oooo00<0IVIV0?ooo`3oool06`3oool00`1VIVH0oooo0?oo
o`0<0?ooo`0306IVIP3oool0oooo0140oooo2@1VIVH:0?ooo`0306IVIP3oool0oooo00@0oooo00<0
IVIV0?ooo`3oool0;P3oool00`1VIVH0oooo06IVIP0d0?ooo`0306IVIP3oool0oooo02H0oooo001N
0?ooo`<00000503oool00`1VIVH000000?ooo`060?ooo`0306IVIP3oool0oooo00T0oooo00<0IVIV
0?ooo`3oool02`3oool00`000000oooo0?ooo`0B0?ooo`0306IVIP3oool0IVIV00P0IVIV2`3oool0
0`1VIVH0oooo0?ooo`0M0?ooo`0306IVIP3oool0oooo00/0oooo00<0IVIV0?ooo`3oool01`3oool:
06IVIQ@0oooo00<0IVIV0?ooo`3oool00`3oool00`1VIVH0oooo0?ooo`0^0?ooo`0306IVIP3oool0
IVIV03@0oooo00<0IVIV0?ooo`3oool09P3oool007H0oooo00<0IVIV0?ooo`3oool0103oool00`1V
IVH0oooo0?ooo`0;0?ooo`0306IVIP3oool0oooo00X0oooo00<000000?ooo`3oool02`3oool906IV
IQ@0oooo00<0IVIV0?ooo`3oool07P3oool00`1VIVH0oooo0?ooo`0:0?ooo`X0IVIV7P3oool00`1V
IVH0oooo0?ooo`030?ooo`0306IVIP3oool0oooo02l0oooo0P1VIVHd0?ooo`0306IVIP3oool0oooo
02H0oooo001g0?ooo`80IVIV103oool00`1VIVH0oooo0?ooo`0<0?ooo`0306IVIP3oool0oooo00T0
oooo00<000000?ooo`3oool00P3oool906IVIPT0oooo00<0IVIV0?ooo`3oool04@3oool00`1VIVH0
oooo0?ooo`0O0?ooo`0306IVIP3oool0oooo00X0IVIV:03oool00`1VIVH0oooo0?ooo`030?ooo`03
06IVIP3oool0oooo02h0oooo0P1VIVH_0?ooo`H0IVIV:03oool007T0oooo00D0IVIV0?ooo`3oool0
oooo06IVIP0?0?ooo`80IVIV1@3oool906IVIQ<0oooo00<0IVIV0?ooo`3oool0403oool00`1VIVH0
oooo0?ooo`0I0?ooo`T0IVIV2@3oool00`1VIVH0oooo0?ooo`0W0?ooo`0306IVIP3oool0oooo0080
oooo00<0IVIV0?ooo`3oool0;P3oool00`1VIVH0oooo06IVIP0T0?ooo`X0IVIV;P3oool007X0oooo
00@0IVIV0?ooo`3oool0IVIV3@3oool906IVIP@0oooo00<000000?ooo`3oool05P3oool00`1VIVH0
oooo0?ooo`0?0?ooo`0306IVIP3oool0oooo00l0oooo2P1VIVH70?ooo`0306IVIP3oool0oooo00P0
oooo00<0IVIV0?ooo`3oool09`3oool00`1VIVH0oooo0?ooo`020?ooo`0306IVIP3oool0oooo02l0
oooo0P1VIVHJ0?ooo`X0IVIV>03oool007/0oooo00<0IVIV0?ooo`1VIVH0103oool906IVIPD0oooo
00<0IVIV0?ooo`3oool0103oool00`000000oooo0?ooo`0H0?ooo`0306IVIP3oool0oooo00h0oooo
00<0IVIV0?ooo`3oool01P3oool906IVIQ80oooo00<0IVIV0?ooo`3oool01`3oool00`1VIVH0oooo
0?ooo`0X0?ooo`0506IVIP3oool0oooo0?ooo`1VIVH0<@3oool206IVIQ00oooo2P1VIVI20?ooo`00
O03oool606IVIPl0oooo00<0IVIV0?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`0306IV
IP3oool0oooo00`0oooo2P1VIVHL0?ooo`0306IVIP3oool0oooo00H0oooo00<0IVIV0?ooo`3oool0
:03oool01@1VIVH0oooo0?ooo`3oool0IVIV0380oooo00<0IVIV0?ooo`3oool0103oool:06IVIT`0
oooo001n0?ooo`0306IVIP3oool0oooo0140oooo00<0IVIV0?ooo`3oool00P3oool00`000000oooo
0?ooo`0J0?ooo`0306IVIP3oool0oooo0080oooo2@1VIVH00`3oool0IVIV0?ooo`0T0?ooo`0306IV
IP3oool0oooo00D0oooo00<0IVIV0?ooo`3oool0:@3oool0101VIVH0oooo0?ooo`1VIVH_0?ooo`X0
IVIVEP3oool007l0oooo00<0IVIV0?ooo`3oool04@3oool206IVIP80oooo00<000000?ooo`3oool0
5@3oool:06IVIPX0oooo00<0IVIV0?ooo`3oool0903oool00`1VIVH0oooo0?ooo`040?ooo`0306IV
IP3oool0oooo02X0oooo00<0IVIV0?ooo`1VIVH09@3oool:06IVIV00oooo00200?ooo`0506IVIP3o
ool0oooo0?ooo`000000403oool00`1VIVH0oooo0000000>0?ooo`T0IVIV1`3oool00`1VIVH0oooo
0?ooo`0:0?ooo`0306IVIP3oool0oooo02@0oooo00<0IVIV0?ooo`3oool0103oool00`1VIVH0oooo
0?ooo`0Z0?ooo`0306IVIP3oool0IVIV01/0oooo2P1VIVIZ0?ooo`00P@3oool206IVIP030?ooo`00
0000oooo0100oooo00<0IVIV0000003oool00`3oool:06IVIQ40oooo00<0IVIV0?ooo`3oool02@3o
ool00`1VIVH0oooo0?ooo`0U0?ooo`0306IVIP3oool0oooo00<0oooo00<0IVIV0?ooo`3oool0:`3o
ool206IVIQ40oooo2P1VIVId0?ooo`00P`3oool00`1VIVH000000?ooo`0A0?ooo`030000001VIVH0
IVIV0080IVIV703oool00`1VIVH0oooo0?ooo`080?ooo`0306IVIP3oool0oooo02H0oooo00<0IVIV
0?ooo`3oool00P3oool00`1VIVH0oooo0?ooo`0[0?ooo`80IVIV1`3oool:06IVIWh0oooo00240?oo
o`0306IVIP3oool0oooo0100oooo00<000000?ooo`3oool07`3oool00`1VIVH0oooo0?ooo`070?oo
o`0306IVIP3oool0oooo02L0oooo00D0IVIV0?ooo`3oool0oooo06IVIP0/0?ooo`X0IVIVR03oool0
08D0oooo0P1VIVH@0?ooo`030000003oool0oooo0200oooo0P1VIVH70?ooo`0306IVIP3oool0oooo
02P0oooo00@0IVIV0?ooo`3oool0IVIV8P3oool:06IVIY80oooo00270?ooo`0406IVIP3oool0oooo
000000`0oooo00<000000?ooo`3oool08P3oool00`1VIVH0oooo0?ooo`040?ooo`0306IVIP3oool0
oooo02T0oooo00<0IVIV0?ooo`1VIVH0603oool:06IVIY`0oooo00280?ooo`0306IVIP3oool00000
00`0oooo00<000000?ooo`3oool08`3oool00`1VIVH0oooo0?ooo`030?ooo`0306IVIP3oool0oooo
02T0oooo00<0IVIV0?ooo`1VIVH03P3oool:06IVIZH0oooo001j0?ooo`@000002`3oool00`1VIVH0
00000?ooo`0;0?ooo`030000003oool0oooo02@0oooo00<0IVIV0?ooo`3oool00P3oool00`1VIVH0
oooo0?ooo`0Z0?ooo`80IVIV103oool:06IVI[00oooo001i0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02@3oool206IVIP/0oooo00<000000?ooo`3oool09@3oool01@1VIVH0oooo
0?ooo`3oool0IVIV02P0oooo2P1VIVJj0?ooo`00N@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00/0oooo00<0IVIV0?ooo`3oool0203oool00`000000oooo0?ooo`0V0?ooo`0406IV
IP3oool0oooo06IVIQh0oooo2P1VIVK40?ooo`00N@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00`0oooo00D0IVIV0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02P0
oooo00<0IVIV0?ooo`1VIVH0503oool:06IVI/h0oooo001j0?ooo`@00000403oool00`1VIVH0oooo
000000050?ooo`030000003oool0oooo02T0oooo0P1VIVH:0?ooo`X0IVIVf03oool004H0oooo0`00
00030?ooo`H000000`3oool6000000<0oooo0`0000000`3oool000000000000300000180oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`80IVIV1@3oool00`000000oooo0?oo
o`0Z0?ooo`/0IVIVhP3oool004L0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00050?ooo`040000003oool0oooo000000D0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`03
06IVIP3oool0oooo0080oooo00<000000?ooo`3oool08@3oool:06IVI^`0oooo00180?ooo`D00000
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0?ooo`D00000103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0A0?ooo`0406IVIP3oool0oooo0?ooo`800000603oool:06IVI_H0oooo00180?oo
o`050000003oool0oooo0?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0?0?ooo`@000005@3oool206IVIP030?ooo`000000000000h0oooo2P1VIVKo0?ooo`40
oooo00190?ooo`030000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool00000
00@0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02X0oooo00<0IVIV0000003oool0103oool:06IVI_l0oooo2`3oool004T0oooo00<000000?ooo`00
0000103oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo00000005
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:`3oool606IVI_l0oooo5@3oool0
04X0oooo00<000000?ooo`3oool00`3oool2000000<0oooo0P0000050?ooo`030000003oool0oooo
00@0oooo00D000000?ooo`3oool0oooo0000003o0?ooodT0oooo00190?ooo`800000103oool30000
00<0oooo0`0000030?ooo`8000001@3oool500000?l0ooooBP3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool008d0oooo1`0000030?ooo`@00000o`3ooolF0?ooo`00T03oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooolC0?ooo`00T03oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooolC0?oo
o`00T03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0o`3ooolC0?ooo`00T03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0o`3ooolC0?ooo`00T03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0o`3ooolC0?ooo`00T03oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooolC0?ooo`00SP3oool30000
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?oooa<0oooo002@0?ooo`03
0000003oool0oooo00@0oooo1000003o0?oooaH0oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {324.375, 0}} -> {-0.0249619, 0.0588697, \
0.00342304, 0.00342304}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[lung, \ modelAMAD]\)], "Input",
  CellLabel->"In[16]:="]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{1016, 648},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageFooters->{{Inherited, Cell[ 
        TextData[ {
          "\[Copyright]2004 Guillermo Sanchez & ENUSA. All rights \
reserved."}], "PageFooter"], Inherited}, {Inherited, Cell[ 
        TextData[ {
          "\[Copyright]2004 Guillermo Sanchez & ENUSA . All rights \
reserved."}], "PageFooter"], Inherited}},
ShowSelection->True,
CellLabelAutoDelete->True,
Magnification->1.5,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Introduction"->{
    Cell[2194, 74, 116, 3, 40, "Input",
      CellTags->"Introduction"],
    Cell[2313, 79, 90, 2, 32, "Print",
      CellTags->"Introduction"],
    Cell[115859, 1633, 1005, 28, 70, "DefinitionBox",
      CellTags->"Introduction"],
    Cell[116867, 1663, 956, 27, 70, "DefinitionBox",
      CellTags->"Introduction"]},
  "Examples"->{
    Cell[127451, 2009, 52, 1, 54, "Section",
      CellTags->"Examples"],
    Cell[127528, 2014, 58, 1, 50, "Subsubsection",
      CellTags->"Examples"],
    Cell[127589, 2017, 263, 5, 80, "MathCaption",
      CellTags->"Examples"],
    Cell[135562, 2172, 58, 1, 41, "Subsubsection",
      CellTags->"Examples"],
    Cell[135623, 2175, 628, 18, 70, "MathCaption",
      CellTags->"Examples"],
    Cell[140831, 2302, 58, 1, 41, "Subsubsection",
      CellTags->"Examples"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Introduction", 309879, 5741},
  {"Examples", 310214, 5750}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 60, 0, 136, "Chapter"],
Cell[1839, 55, 57, 0, 34, "SmallText"],

Cell[CellGroupData[{
Cell[1921, 59, 39, 0, 50, "Subsubsection"],

Cell[CellGroupData[{
Cell[1985, 63, 65, 2, 40, "Input"],
Cell[2053, 67, 104, 2, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2194, 74, 116, 3, 40, "Input",
  CellTags->"Introduction"],
Cell[2313, 79, 90, 2, 32, "Print",
  CellTags->"Introduction"]
}, Open  ]],
Cell[2418, 84, 88, 2, 40, "Input"],
Cell[2509, 88, 86, 2, 40, "Input"],
Cell[2598, 92, 325, 6, 92, "Input"],
Cell[2926, 100, 204, 4, 66, "Input"],
Cell[3133, 106, 100, 2, 40, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3270, 113, 68, 0, 54, "Section"],
Cell[3341, 115, 796, 19, 70, "Text"],
Cell[4140, 136, 1979, 43, 70, "Text"],
Cell[6122, 181, 523, 15, 70, "Text"],

Cell[CellGroupData[{
Cell[6670, 200, 155, 4, 70, "Subsubsection"],
Cell[6828, 206, 1728, 49, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8593, 260, 189, 5, 70, "Subsubsection"],
Cell[8785, 267, 381, 7, 70, "SmallText"],
Cell[9169, 276, 1862, 39, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11068, 320, 125, 4, 70, "Subsubsection"],
Cell[11196, 326, 104145, 1288, 70, 104044, 1285, "GraphicsData", "Metafile", \
"Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[115390, 1620, 58, 0, 54, "Section"],
Cell[115451, 1622, 405, 9, 70, "Text"],
Cell[115859, 1633, 1005, 28, 70, "DefinitionBox",
  CellTags->"Introduction"],
Cell[116867, 1663, 956, 27, 70, "DefinitionBox",
  CellTags->"Introduction"],
Cell[117826, 1692, 5536, 171, 70, "SmallText"],
Cell[123365, 1865, 2290, 77, 70, "SmallText"],
Cell[125658, 1944, 1050, 32, 70, "SmallText"],
Cell[126711, 1978, 403, 12, 70, "SmallText"],
Cell[127117, 1992, 123, 5, 70, "SmallText"],
Cell[127243, 1999, 171, 5, 70, "SmallText"]
}, Closed]],

Cell[CellGroupData[{
Cell[127451, 2009, 52, 1, 54, "Section",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[127528, 2014, 58, 1, 50, "Subsubsection",
  CellTags->"Examples"],
Cell[127589, 2017, 263, 5, 80, "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[127877, 2026, 158, 4, 40, "Input"],
Cell[128038, 2032, 4851, 74, 646, "Output"]
}, Open  ]],
Cell[132904, 2109, 59, 0, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[132988, 2113, 179, 4, 70, "Input"],
Cell[133170, 2119, 2343, 47, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[135562, 2172, 58, 1, 41, "Subsubsection",
  CellTags->"Examples"],
Cell[135623, 2175, 628, 18, 70, "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[136276, 2197, 121, 3, 70, "Input"],
Cell[136400, 2202, 1082, 16, 70, "Output"]
}, Open  ]],
Cell[137497, 2221, 168, 5, 70, "Text"],
Cell[137668, 2228, 161, 5, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[137854, 2237, 143, 4, 70, "Input"],
Cell[138000, 2243, 1159, 18, 70, "Output"]
}, Open  ]],
Cell[139174, 2264, 242, 4, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[139441, 2272, 148, 4, 70, "Input"],
Cell[139592, 2278, 1190, 18, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[140831, 2302, 58, 1, 41, "Subsubsection",
  CellTags->"Examples"],
Cell[140892, 2305, 92, 2, 34, "Text"],
Cell[140987, 2309, 220, 4, 66, "Input"],
Cell[141210, 2315, 95, 1, 43, "Input"],

Cell[CellGroupData[{
Cell[141330, 2320, 295, 6, 92, "Input"],
Cell[141628, 2328, 166777, 3366, 335, 59077, 2032, "GraphicsData", \
"PostScript", "Graphics"],
Cell[308408, 5696, 162, 4, 38, "Output"]
}, Open  ]],
Cell[308585, 5703, 82, 2, 40, "Input"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

