(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1318581,      42122]*)
(*NotebookOutlinePosition[   1320315,      42176]*)
(*  CellTagsIndexPosition[   1320156,      42168]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Biokinetic model for almost all Current ICRP isotopes  ", "Chapter"],

Cell["Last update of this help. 2005-09-04", "Commentary"],

Cell[CellGroupData[{

Cell["Initialization", "SubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Needs["\<Biokmod`Biokdata`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("Resptract 1.2 b1 2005-05-16"\)], "Print",
  CellLabel->"From In[1]:="],

Cell[BoxData[
    \("SysModel, guillermo@usal.es, version 1.3.   2005-08-24"\)], "Print",
  CellLabel->"From In[1]:="],

Cell[BoxData[
    \("Humorap 3.3 b1 2005-06-17"\)], "Print",
  CellLabel->"From In[1]:="],

Cell[BoxData[
    \("Biokdata 1.2.2 2004-09-3 (Lite version. The full version includes all \
ICRP models)"\)], "Print",
  CellLabel->"From In[1]:="]
}, Open  ]],

Cell[BoxData[
    \(Off[General::spell1]; Off[General::spell];\)], "Input",
  CellLabel->"In[2]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Biokdata functions", "SubsectionIcon"],

Cell[TextData[{
  "In this notebook are shown and solved different biokinetic models of \
ICRP78. We will need the  ",
  StyleBox["Biokdata", "Input"],
  " package (it has been downloaded in the section Initialization). "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?"\<Biokmod`Biokdata`*\>"\)\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[GridBox[{
        {
          StyleBox["Biokmod`Biokdata`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["BiokdataReport",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345389163-1321197", 
                    "Biokmod`Biokdata`BiokdataReport"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["compartMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345389163-1321197", 
                    "Biokmod`Biokdata`compartMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["ElementICRP",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345389163-1321197", 
                    "Biokmod`Biokdata`ElementICRP"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["SSEU235",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345389163-1321197", 
                    "Biokmod`Biokdata`SSEU235"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["TransferRatesE",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345389163-1321197", 
                    "Biokmod`Biokdata`TransferRatesE"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], ""},
              {
                ButtonBox[
                  StyleBox["caesium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345389163-1321197", 
                    "Biokmod`Biokdata`caesium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["compartMatrixE",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345389163-1321197", 
                    "Biokmod`Biokdata`compartMatrixE"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["iodine",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345389163-1321197", 
                    "Biokmod`Biokdata`iodine"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["SSEU238",
                    "Hyperlink"],
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345389163-1321197", 
                    "Biokmod`Biokdata`SSEU238"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["Unknown",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345389163-1321197", 
                    "Biokmod`Biokdata`Unknown"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], ""},
              {
                ButtonBox[
                  StyleBox["cobalt",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345389163-1321197", 
                    "Biokmod`Biokdata`cobalt"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["CompartNumbers",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345389163-1321197", 
                    "Biokmod`Biokdata`CompartNumbers"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["SSEU234",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345389163-1321197", 
                    "Biokmod`Biokdata`SSEU234"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["TransferRates",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345389163-1321197", 
                    "Biokmod`Biokdata`TransferRates"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["uranium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3345389163-1321197", 
                    "Biokmod`Biokdata`uranium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], ""}
              },
            RowMinHeight->{1, 1, 1.05}]}
        },
      RowSpacings->{2, 3},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->RGBColor[0.964706, 0.929412, 0.839216],
  ButtonBoxOptions->{Active->True},
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Open  ]],

Cell["\<\
The available elements included at the  present full version of Biokdata are \
the following:\
\>", "Text"],

Cell[BoxData[GridBox[{
        {
          StyleBox["Biokmod`Biokdata`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["actinium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`actinium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["cerium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`cerium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["gallium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`gallium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["mercuryorg",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`mercuryorg"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["radium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`radium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["terbium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`terbium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"]},
              {
                ButtonBox[
                  StyleBox["aluminium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`aluminium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["chlorine",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`chlorine"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["germanium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`germanium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["molybdenum",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`molybdenum"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["rhenium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`rhenium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["thallium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`thallium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"]},
              {
                ButtonBox[
                  StyleBox["americium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`americium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["chromium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`chromium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["gold",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`gold"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["neodymium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`neodymium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["rhodium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`rhodium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["thorium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`thorium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"]},
              {
                ButtonBox[
                  StyleBox["antimony",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`antimony"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["cobalt",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`cobalt"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["hafnium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`hafnium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["neptunium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`neptunium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["rubidium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`rubidium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["thulium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`thulium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"]},
              {
                ButtonBox[
                  StyleBox["arsenic",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`arsenic"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["compartMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`compartMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["holmium",
                    "Hyperlink"],
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`holmium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["nickel",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`nickel"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["ruthenium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`ruthenium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["tin",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`tin"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"]},
              {
                ButtonBox[
                  StyleBox["astatine",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`astatine"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["compartMatrixE",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`compartMatrixE"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["indium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`indium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["niobium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`niobium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["samarium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`samarium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["titanium",
                    "Hyperlink"],
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`titanium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"]},
              {
                ButtonBox[
                  StyleBox["barium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`barium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["CompartNumbers",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`CompartNumbers"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["iodine",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`iodine"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["osmium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`osmium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["scandium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`scandium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["TransferRates",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`TransferRates"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"]},
              {
                ButtonBox[
                  StyleBox["berkelium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`berkelium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["copper",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`copper"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["iridium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`iridium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["paladium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`paladium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["selenium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`selenium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["TransferRatesE",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`TransferRatesE"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"]},
              {
                ButtonBox[
                  StyleBox["beryllium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`beryllium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["curium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`curium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["iron",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`iron"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["phosphorus",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`phosphorus"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["silicon",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`silicon"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["tungstem",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`tungstem"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"]},
              {
                ButtonBox[
                  StyleBox["BiokdataReport",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`BiokdataReport"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["dysprosium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`dysprosium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["lanthanum",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`lanthanum"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["platinum",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`platinum"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["silver",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`silver"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["Unknown",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`Unknown"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"]},
              {
                ButtonBox[
                  StyleBox["bismuth",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`bismuth"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["einstenium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`einstenium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["lead",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`lead"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["plutonium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`plutonium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["sodium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`sodium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["uranium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`uranium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"]},
              {
                ButtonBox[
                  StyleBox["bromine",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`bromine"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["ElementICRP",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`ElementICRP"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["lutetium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`lutetium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["polonium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`polonium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["strontium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`strontium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["vanadium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`vanadium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"]},
              {
                ButtonBox[
                  StyleBox["cadmium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`cadmium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["erbium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`erbium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["magnesium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`magnesium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["potassium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`potassium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["sulfur",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`sulfur"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["ytterbium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`ytterbium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"]},
              {
                ButtonBox[
                  StyleBox["caesium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`caesium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["europium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`europium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["manganese",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`manganese"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["praseodymium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`praseodymium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["tantalum",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`tantalum"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["yttrium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`yttrium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"]},
              {
                ButtonBox[
                  StyleBox["calcium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`calcium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["fermium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`fermium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["mendelevium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`mendelevium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["promethium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`promethium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["technetium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`technetium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["zinc",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`zinc"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"]},
              {
                ButtonBox[
                  StyleBox["californium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`californium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["gadolinium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`gadolinium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["mercuryinorg",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`mercuryinorg"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["protactinium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`protactinium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["tellurium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`tellurium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"], 
                ButtonBox[
                  StyleBox["zirconium",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333717958-3528797", 
                    "Biokmod`Biokdata`zirconium"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Biokdata`"]}
              },
            
            RowMinHeight->{
              1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1.05}]}
        },
      RowSpacings->{2, 3},
      ColumnsEqual->True]], "Text",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->RGBColor[0.964706, 0.929412, 0.839216],
  ButtonBoxOptions->{Active->True},
  GridBoxOptions->{ColumnAlignments->{Left}},
  CellTags->"Introduction"],

Cell[TextData[{
  Cell[BoxData[
      RowBox[{"BioakdataReport", "[", 
        RowBox[{
          StyleBox["element",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[",",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[" ",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox["\"\<IntakeWay\>\"",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[",",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox["\"\<IntakeType\>\"",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[",",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[" ",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox["\"\<Report\>\"",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[",",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[" ",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox["Intake",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[",",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[" ",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox["IFD",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[",",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox["FRA",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[",",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox["f1",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[",",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox["t",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[",",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox["\[Lambda]",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[",",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox["options",
            FontWeight->"Plain",
            FontSlant->"Italic"]}], 
        StyleBox["]",
          "Text"]}]], "Input"],
  " \ngives for element the Bioassayreport  defined with   \"IntakeWay\", \
\"IntakeType\", \"Report\". \n\nIf \"IntakeWay\" is \"Injection\" or \
\"Ingestion\"  IFD and FRA are unnecessary, then BioakdataReport can be also \
written: \n\n",
  Cell[BoxData[
      RowBox[{"BiokdataReport", "[", 
        RowBox[{
          StyleBox["element",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[",",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[" ",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox["\"\<IntakeWay\>\"",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[",",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox["\"\<IntakeType\>\"",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[",",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[" ",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox["\"\<Report\>\"",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[",",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[" ",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox["Intake",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[",",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[" ",
            "Text",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox["f1",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[",",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox["t",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[",",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox["\[Lambda]",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[",",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox["options",
            FontWeight->"Plain",
            FontSlant->"Italic"]}], 
        StyleBox["]",
          "Text"]}]], "Input"],
  " \ngives for element the Bioassayreport  defined with   \"IntakeWay\", \
\"IntakeType\", \"Report\". "
}], "DefinitionBox"],

Cell[TextData[{
  StyleBox["\nelement",
    FontWeight->"Bold"],
  " write the name of the element as appeared in  ",
  StyleBox["?\"Biokmod`Biokdata`*\"",
    FontWeight->"Bold"],
  "\n\n",
  StyleBox["IntakeWay ",
    FontWeight->"Bold"],
  "write \"Injection\" or \"Ingestion\" or \"Inhalation\"; \n\n",
  StyleBox["IntakeType",
    FontWeight->"Bold"],
  " write \"Acute\" or \"Constant\", \"Continuous\" or \"MultiInputs\"; \n",
  StyleBox["\[CenterDot]\t",
    FontFamily->"Symbol"],
  "\"Acute\" is a single intake at t = 0, \n",
  StyleBox["\[CenterDot]\t",
    FontFamily->"Symbol"],
  "\"Constant\" (or Chronic) means a constant daily intake (all days the \
same). \n",
  StyleBox["\[CenterDot]\t",
    FontFamily->"Symbol"],
  "\"Continuous\" is an intake variable in the time, ej: 0.1 Exp[- 0.02 t] \
(not available for inhalation).\n",
  StyleBox["\[CenterDot]\t",
    FontFamily->"Symbol"],
  "\"MultiInputs\" are multi single (or acute) inputs.\n\n",
  StyleBox["Report",
    FontWeight->"Bold"],
  " write:  \"Automatic\" or \"BioassayTable\" or \"GraphicsReport\" , or \
\"CompartmentContent\" or \"Disintegrations\". \n",
  StyleBox["\[CenterDot]\t",
    FontFamily->"Symbol"],
  "\"Automatic\" gives the Lungs (only by inhation) and whole body retention \
, daily urine and faecal excretion as function of t\n",
  StyleBox["\[CenterDot]\t",
    FontFamily->"Symbol"],
  "\"BioassayTable\" gives the Lungs (only by inhalation) and whole body \
retention , daily urine and faecal excretion for different days.\n",
  StyleBox["\[CenterDot]\t",
    FontFamily->"Symbol"],
  "\"GraphicsReport\" gives the graphics representation as function of time \
of  the Lungs  retention (only by inhalation), the daily urine and faecal \
excretion, from 0 to t (chosen with\"Time\").\n",
  StyleBox["\[CenterDot]\t",
    FontFamily->"Symbol"],
  "\"CompartmentContent\" gives the retention in each compartment of the \
model as function of t.\n",
  StyleBox["\[CenterDot]\t",
    FontFamily->"Symbol"],
  "\"Disintegrations\" gives the total disintegration accumulated at time t \
(that is: Us or SA values.)\n\n",
  StyleBox["Intake",
    FontWeight->"Bold"],
  ".- The input format depends on the \"Intake type\" chosen. \n",
  StyleBox["\[CenterDot]\t",
    FontFamily->"Symbol"],
  "For \"Acute\" write the number of Bq in t = 0\n",
  StyleBox["\[CenterDot]\t",
    FontFamily->"Symbol"],
  "For \"Constant\" write the number of Bq/day.\n",
  StyleBox["\[CenterDot]\t",
    FontFamily->"Symbol"],
  "For \"Continuous\" write {",
  StyleBox["f",
    FontSlant->"Italic"],
  "(",
  StyleBox["t)",
    FontSlant->"Italic"],
  " , ",
  StyleBox["t",
    FontSlant->"Italic"],
  "} where f(t) is the input functions. Ej.: {0.1 Exp[- 0.02 t], t} \n",
  StyleBox["\[CenterDot]\t",
    FontFamily->"Symbol"],
  "For \"MultiInputs\" write {{I",
  StyleBox["0",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  ", t",
  StyleBox["0",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  "}, {I",
  StyleBox["1",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  ", t",
  StyleBox["1",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  "}, .... {I",
  StyleBox["j",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  ", t",
  StyleBox["j",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  "},\[Ellipsis],{I",
  StyleBox["n",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  ", t",
  StyleBox["n",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  "}} (where I",
  StyleBox["j",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  ", represents the intake the day t",
  StyleBox["j",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  ", and t",
  StyleBox["1",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  "<t",
  StyleBox["2",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  "<..<t",
  StyleBox["n",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  " ). Ej.:  {{3, 0},{7, 3}}. The retention is given as function of t after \
the last intake (t",
  StyleBox["n",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  "=0); Note: The length of the list {{I",
  StyleBox["0",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  ", t",
  StyleBox["0",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  "},....., {I",
  StyleBox["n",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  ", t",
  StyleBox["n",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  "}} can be hundred of elements, it will be computed in a few seconds. It \
can be copied from a ASCII standard program (ej: Notebook)\n\n",
  StyleBox["IFD",
    FontWeight->"Bold"],
  ": (only by Inhalation) write AMADxx, being xx the AMAD value which you \
wish (chose one of the included  in  ",
  StyleBox["?\"Biokmod`Biokdata`*\")",
    FontWeight->"Bold"],
  ". Then the program will select the appropriated Initial fractional \
Deposition (IFD) values. If you wish, you  can be directly written the IFD \
values with this pattern ",
  Cell[BoxData[
      \({AI\)]],
  ", ",
  Cell[BoxData[
      \(bb\_\(fast + seq\)\)]],
  ", ",
  Cell[BoxData[
      \(\(\(bb\_slow\)\(,\)\)\)]],
  " ",
  Cell[BoxData[
      \(BB\_\(fast + seq\)\)]],
  " ",
  Cell[BoxData[
      \(\(\(,\)\(\ \)\(BB\_slow\)\(,\)\(\ \)\)\)]],
  " ",
  Cell[BoxData[
      \(\(\(ET\_2, \ ET\_1\)\(}\)\)\)]],
  " (i.e: {0.12, 0.011, 0.011, 0.0039, 0.004, 0.11, 0.089}) \n\n",
  StyleBox["FRA",
    FontWeight->"Bold"],
  " (only by Inhalation) .",
  StyleBox["FRA: Fractional rate of absorption",
    FontSlant->"Italic"],
  "  of material into the blood. Write: F or M or S, then the program will \
select the appropriate fractional rate of absorption: type F:{100, 0, 0};  \
type M: {10, 90, 0.005};  type S: {0.1, 100, 0.0001}. If you wish, you  can \
be directly written the FRA values with this pattern {",
  Cell[BoxData[
      StyleBox[\(s\_p, s\_pt, s\_t\),
        "Input"]]],
  "} (i.e.: {10, 90, 0.005}) \n\n",
  StyleBox["f1",
    FontWeight->"Bold"],
  ": fraction from GI (SI) to Blood. By default are given the included in \
ICRPs, but you can change this value.\n",
  StyleBox["t",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  " always in days. The meaning depends on the \"Intake type\" chosen.\n",
  StyleBox["\[CenterDot]\t",
    FontFamily->"Symbol"],
  "For \"Acute\" means time after the intake. Write ",
  StyleBox["t",
    FontSlant->"Italic"],
  " (symbolic solution) or the numeric number of days (ej: 2 ).\n",
  StyleBox["\[CenterDot]\t",
    FontFamily->"Symbol"],
  "For \"Constant\" means time after starting the intake. Write ",
  StyleBox["t",
    FontSlant->"Italic"],
  " (symbolic solution) or the numeric number of days (ej: 2 )\n",
  StyleBox["\[CenterDot]\t",
    FontFamily->"Symbol"],
  "For \"Continuous\" means time after starting the intake. Write ",
  StyleBox["t",
    FontSlant->"Italic"],
  " (symbolic solution) or the numeric number of days (ej: 2 )   \n",
  StyleBox["\[CenterDot]\t",
    FontFamily->"Symbol"],
  "For \"MultiInputs\" means the time after last intake. Write ",
  StyleBox["t",
    FontSlant->"Italic"],
  " (symbolic solution) or the numeric number of days (ej: 2 ).\n\tNote: If \
in ",
  StyleBox["Output Report",
    FontWeight->"Bold"],
  " you has chosen \"GraphicsReport\" or \"Retention Functions\" must be \
chosen a numeric value for Time\n\n",
  StyleBox["\[Lambda]",
    FontFamily->"Times New Roman Greek",
    FontWeight->"Bold"],
  " is the radioactive decay constant, in day",
  StyleBox["-1",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  ". If you know the half-life T, as ",
  StyleBox["\[Lambda]",
    FontFamily->"Times New Roman Greek",
    FontWeight->"Bold"],
  " = Log[t]/T you can write: Log[2]/T, ej.: For T = 8.2 year, then write: \
Log[2]/(365.24*8.2) .\n\nCompartNumbers and  TransferRates options: ",
  StyleBox["(",
    FontSlant->"Italic"],
  "By default: CompartNumbers \[Rule] \"False\", TransferRates\[Rule] \"False\
\" ) : If CompartNumbers \[Rule] \"True\", TransferRates\[Rule] \"True\" \
gives a report where is indicated the relation between the number and the  \
name of compartments, and also the Tranfer Rates. It a good idea to choose \
this option if  in REPORT has been chosen  \"CompartmentContent\" or \
\"Desintegration\"\n"
}], "Text"],

Cell[TextData[{
  "Other funtions (push on the blue names) ",
  Cell[BoxData[
      ButtonBox[
        StyleBox["CompartNumbers",
          FontColor->RGBColor[0, 0, 1],
          FontVariations->{"Underline"->True}],
        ButtonFunction:>(Internal`PutInformation[ #, LongForm -> False]&),
        ButtonEvaluator->Automatic,
        ButtonData:>{"Info3263734794-7542638", 
          "Biokmod`Biokdata`CompartNumbers"},
        ButtonFrame->"None",
        ButtonNote->"Biokmod`Biokdata`"]],
    CellMargins->{{20, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
    Background->GrayLevel[0.930022],
    ButtonBoxOptions->{Active->True}],
  ", ",
  Cell[BoxData[
      ButtonBox[
        StyleBox["TransferRates",
          FontColor->RGBColor[0, 0, 1],
          FontVariations->{"Underline"->True}],
        ButtonFunction:>(Internal`PutInformation[ #, LongForm -> False]&),
        ButtonEvaluator->Automatic,
        ButtonData:>{"Info3263734794-7542638", 
          "Biokmod`Biokdata`TransferRates"},
        ButtonFrame->"None",
        ButtonNote->"Biokmod`Biokdata`"]],
    CellMargins->{{20, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
    Background->GrayLevel[0.930022],
    ButtonBoxOptions->{Active->True}],
  ", ",
  Cell[BoxData[
      ButtonBox[
        StyleBox["TransferRatesE",
          FontColor->RGBColor[0, 0, 1],
          FontVariations->{"Underline"->True}],
        ButtonFunction:>(Internal`PutInformation[ #, LongForm -> False]&),
        ButtonEvaluator->Automatic,
        ButtonData:>{"Info3263734794-7542638", 
          "Biokmod`Biokdata`TransferRatesE"},
        ButtonFrame->"None",
        ButtonNote->"Biokmod`Biokdata`"]],
    CellMargins->{{20, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
    Background->GrayLevel[0.930022],
    ButtonBoxOptions->{Active->True}],
  ", ",
  Cell[BoxData[
      ButtonBox[
        StyleBox["compartMatrix",
          FontColor->RGBColor[0, 0, 1],
          FontVariations->{"Underline"->True}],
        ButtonFunction:>(Internal`PutInformation[ #, LongForm -> False]&),
        ButtonEvaluator->Automatic,
        ButtonData:>{"Info3263734794-7542638", 
          "Biokmod`Biokdata`compartMatrix"},
        ButtonFrame->"None",
        ButtonNote->"Biokmod`Biokdata`"]],
    CellMargins->{{20, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
    Background->GrayLevel[0.930022],
    ButtonBoxOptions->{Active->True}],
  " and ",
  Cell[BoxData[
      ButtonBox[
        StyleBox["compartMatrixE",
          FontColor->RGBColor[0, 0, 1],
          FontVariations->{"Underline"->True}],
        ButtonFunction:>(Internal`PutInformation[ #, LongForm -> False]&),
        ButtonEvaluator->Automatic,
        ButtonData:>{"Info3263734794-7542638", 
          "Biokmod`Biokdata`compartMatrixE"},
        ButtonFrame->"None",
        ButtonNote->"Biokmod`Biokdata`"]],
    CellMargins->{{20, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
    Background->GrayLevel[0.930022],
    ButtonBoxOptions->{Active->True}],
  ". "
}], "DefinitionBox"],

Cell[BoxData[
    \("TransferRatesE[element] gives for element the  transfer rate constants \
for adult workers for biokinetic model defined in  ICRP, including GI tract \
rates"\)], "Print",
  CellTags->"Info3263734794-7542638"]
}, Closed]],

Cell[CellGroupData[{

Cell[" Iodine", "Section"],

Cell[TextData[{
  "Here are shown how work",
  StyleBox[" IntakeType", "Input"],
  ", ",
  StyleBox["IntakeWay", "Input"],
  " and ",
  StyleBox["ShowReport", "Input"],
  ". All examples of this section are made using the iodine model."
}], "Text"],

Cell[CellGroupData[{

Cell["The model", "SubsectionIcon"],

Cell[TextData[{
  "Also, we will need the following information: We suppose the nuclide \
iodine 131 (half-life = 8.0 days),  taken  f1 = 1 (f1 is called fn1) , and \
(by inhalation) AMAD = 5 \[Mu]m and class F. The examples included for kind \
of intake: a) Acute input: 1 Bq in t=0, b) Constant intake =1 Bq/day all \
days), c)  A continuous intake 1.2 Exp[-0.3 t] and b) Multiple single intakes \
 {{1,0}, {3,4}, {7, 6}} [remember: {",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                FormBox[\(I\_1\),
                  "TraditionalForm"], ",", " ", \(t\_1\)}], "}"}], 
            ",", \(\(...\)\(.\)\), ","}]}], TraditionalForm]]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\({I\_j, \ \ t\_j}\)\(,\)\(\ \)\)\)]],
  "..., ",
  Cell[BoxData[
      \(TraditionalForm\`{I\_n, \ \ t\_n}\)]],
  "}  ",
  Cell[BoxData[
      \(TraditionalForm\`I\_j\)]],
  " = intake de day ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  "]. "
}], "Text"],

Cell["We define the values to be used in the esamples", "MathCaption"],

Cell[BoxData[
    \(\(element = \ iodine;\)\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(lambda\  = \ Log[2]/8.0; \ fn1\  = \ 1; \ amad = \ AMADAdultW[5]; 
    class\  = \ F; \ inputs1\  = {1.2\ Exp[\(-0.3\)\ t], t}; 
    inputs2\  = \ {{1, 0}, {3, 4}, {7, 6}};\)], "Input",
  CellLabel->"In[5]:="],

Cell[TextData[{
  "This figure represent the model of Iodine ICRP 78, compartment 1 \
represents the blood, compartment 2 the thyroid, 3 rest of body, and 4 the \
bladder, ",
  Cell[BoxData[
      \(TraditionalForm\`k\_40\)]],
  " means the rate transfer out of system  to urine) and ",
  Cell[BoxData[
      \(TraditionalForm\`k\_30\)]],
  "means the rate transfer out of system  to ULI in GI system (see fig 6.). "
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .90909 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 0.17316 0.627706 0.17316 [
[ 0 0 0 0 ]
[ 1 .90909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .90909 L
0 .90909 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125  moveto 0 0 lineto 
-0.05 -0.0125  lineto stroke
} ifelse
grestore
} def
/MAarrowhead2 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.11039 .88745 m
.11039 .71429 L
s
% Start of user PostScript
0 1.5 0 0.5 MAarrowhead1
% End of user PostScript
gsave
.04113 .80087 -80.3438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
75.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.688 12.813 moveto
(H) show
85.688 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 12.813 moveto
(L) show
97.688 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.11039 .62771 .08658 0 365.73 arc
s
gsave
.11039 .62771 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.19697 .62771 m
.62987 .62771 L
s
% Start of user PostScript
0.5 0 3. 0 MAarrowhead2
% End of user PostScript
newpath
.11039 .28139 .08658 0 365.73 arc
s
gsave
.11039 .28139 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .19481 m
.11039 .02165 L
s
% Start of user PostScript
0 -2.5 0 -3.5 MAarrowhead2
% End of user PostScript
gsave
.16234 .14286 -70.4375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.41342 .69697 -70.4375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .54113 m
.11039 .36797 L
s
% Start of user PostScript
0 -0.5 0 -1.5 MAarrowhead2
% End of user PostScript
gsave
.16234 .48918 -70.4375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.71645 .62771 .08658 0 365.73 arc
s
gsave
.71645 .62771 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.71645 .54113 m
.71645 .36797 L
s
% Start of user PostScript
3.5 -0.5 3.5 -1.5 MAarrowhead2
% End of user PostScript
gsave
.6645 .45455 -70.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.71645 .28139 .08658 0 365.73 arc
s
gsave
.71645 .28139 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.62987 .31602 m
.17965 .57576 L
s
% Start of user PostScript
3. -1.8 0.4 -0.3 MAarrowhead2
% End of user PostScript
gsave
.45671 .45455 -70.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(31) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.80303 .28139 m
.97619 .28139 L
s
% Start of user PostScript
4. -2. 5. -2. MAarrowhead2
% End of user PostScript
gsave
.85498 .28139 -70.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[15]:=",
  ImageSize->{288, 261.813},
  ImageMargins->{{1, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00011B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`007`3oool00`001000oooo0?ooo`3n0?ooo`007`3oool00`001000oooo0?ooo`3n0?ooo`00
7`3oool200040?l0oooo000N0?ooo`<000@0o`3oool001h0oooo0`00103o0?ooo`007P3oool30004
0?l0oooo000N0?ooo`@000@0oP3oool001d0oooo1@00103n0?ooo`007@3oool500040?h0oooo000M
0?ooo`H000@0o@3oool001d0oooo1P00103m0?ooo`007@3oool600040?d0oooo000L0?ooo`L000@0
o@3oool001`0oooo2000103l0?ooo`00703oool800040?`0oooo000O0?ooo`030004003oool0oooo
0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo
000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?oo
o`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004
003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0
oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0
oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O
0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`03
0004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo00d0oooo00<000@00?ooo`3oool0
0P00103/0?ooo`007`3oool00`001000oooo0?ooo`050?ooo`8000@000<0oooo0004000010000P3o
ool200040080oooo0P00103/0?ooo`007`3oool00`001000oooo0?ooo`060?ooo`030004003oool0
00@000<0oooo0P0010020?ooo`8000@0k03oool001l0oooo00<000@00?ooo`3oool01P3oool30004
00@0oooo00<000@00?ooo`3oool00P00103/0?ooo`007`3oool00`001000oooo0?ooo`060?ooo`04
0004003oool000@000040?@0oooo000O0?ooo`030004003oool0oooo00H0oooo00<000@00?ooo`3o
ool0m@3oool001l0oooo00<000@00?ooo`3oool01@3oool200040?L0oooo000O0?ooo`030004003o
ool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo
0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo
000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?oo
o`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004
003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000I0?ooo``000@0XP3oool<
000404d0oooo000G0?ooo`8000@0303oool5000409/0oooo0P00100<0?ooo`@000@0B@3oool001D0
oooo0P00100C0?ooo`8000@0U`3oool200040180oooo0P0010170?ooo`004`3oool2000401L0oooo
00<000@00?ooo`3oool0TP3oool2000401H0oooo0P0010150?ooo`004@3oool2000401X0oooo00<0
00@00?ooo`3oool0S`3oool2000401X0oooo00<000@00?ooo`3oool0@P3oool00100oooo00<000@0
0?ooo`3oool06`3oool2000408h0oooo00<000@00?ooo`3oool06`3oool200040480oooo000?0?oo
o`030004003oool0oooo01h0oooo00<000@00?ooo`3oool0RP3oool00`001000oooo0?ooo`0M0?oo
o`030004003oool0oooo0400oooo000>0?ooo`030004003oool0oooo0200oooo00<000@00?ooo`3o
ool0R03oool00`001000oooo0?ooo`0O0?ooo`030004003oool0oooo03l0oooo000=0?ooo`030004
003oool0oooo0280oooo00<000@00?ooo`3oool0QP3oool00`001000oooo0?ooo`0Q0?ooo`8000@0
?`3oool000/0oooo0P00100V0?ooo`030004003oool0oooo08<0oooo0P00100V0?ooo`030004003o
ool0oooo03`0oooo000:0?ooo`030004003oool0oooo02L0oooo00<000@00?ooo`3oool0P@3oool0
0`001000oooo0?ooo`0W0?ooo`030004003oool0oooo03/0oooo000:0?ooo`030004003oool0oooo
02L0oooo00<000@00?ooo`3oool0P@3oool00`001000oooo0?ooo`0W0?ooo`030004003oool0oooo
03/0oooo000:0?ooo`030004003oool0oooo02P0oooo00<000@00?ooo`3oool0P03oool00`001000
oooo0?ooo`0X0?ooo`030004003oool0oooo03X0oooo00090?ooo`030004003oool0oooo02T0oooo
00<000@00?ooo`3oool0O`3oool00`001000oooo0?ooo`0Y0?ooo`030004003oool0oooo03X0oooo
00090?ooo`030004003oool0oooo02T0oooo00<000@00?ooo`3oool0O`3oool00`001000oooo0?oo
o`0Y0?ooo`030004003oool0oooo03X0oooo00080?ooo`030004003oool0oooo02/0oooo00<000@0
0?ooo`3oool0O@3oool00`001000oooo0?ooo`0[0?ooo`030004003oool0oooo03T0oooo00080?oo
o`030004003oool0oooo02/0oooo00<000@00?ooo`3oool0O@3oool00`001000oooo0?ooo`0[0?oo
o`030004003oool0oooo03T0oooo00070?ooo`030004003oool0oooo02d0oooo00<000@00?ooo`3o
ool0N`3oool00`001000oooo0?ooo`0]0?ooo`030004003oool0oooo03P0oooo00070?ooo`030004
003oool0oooo02d0oooo00<000@00?ooo`3oool0N`3oool00`001000oooo0?ooo`0]0?ooo`030004
003oool0oooo03P0oooo00070?ooo`030004003oool0oooo02h0oooo00<000@00?ooo`3oool0NP3o
ool00`001000oooo0?ooo`0]0?ooo`030004003oool0oooo03P0oooo00070?ooo`030004003oool0
oooo02h0oooo00<000@00?ooo`3oool0NP3oool00`001000oooo0?ooo`0]0?ooo`030004003oool0
oooo03P0oooo00070?ooo`030004003oool0oooo02h0oooo00<000@00?ooo`3oool0NP3oool00`00
1000oooo0?ooo`0^0?ooo`030004003oool0oooo0200oooo0`00100D0?ooo`001P3oool00`001000
oooo0?ooo`0_0?ooo`030004003oool0oooo07T0oooo00<000@00?ooo`3oool0;`3oool00`001000
oooo0?ooo`0P0?ooo`P000@03`3oool000H0oooo00<000@00?ooo`3oool05P3oool3000401H0oooo
00<000@00?ooo`3oool0N@3oool00`001000oooo0?ooo`0E0?ooo`8000@0603oool00`001000oooo
0?ooo`0P0?ooo`d000@02P3oool000H0oooo00<000@00?ooo`3oool05`3oool00`001000oooo0?oo
o`0E0?ooo`030004003oool0oooo07T0oooo00<000@00?ooo`3oool0503oool010001000oooo0?oo
o`00100G0?oooc<000@01`3oool000H0oooo00<000@00?ooo`3oool0503oool5000401H0oooo00<0
00@00?ooo`3oool0N@3oool00`001000oooo0?ooo`0F0?ooo`030004003oool0oooo01H0oooo00<0
00@00?ooo`3oool0803oool>000400T0oooo00060?ooo`030004003oool0oooo01@0oooo00@000@0
0?ooo`3oool000@05`3oool00`001000oooo0?ooo`1i0?ooo`030004003oool0oooo01L0oooo00<0
00@00?ooo`3oool05@3oool00`001000oooo0?ooo`0P0?ooo`X000@03@3oool000H0oooo00<000@0
0?ooo`3oool05@3oool00`001000oooo0004000G0?ooo`030004003oool0oooo07T0oooo00<000@0
0?ooo`3oool0503oool010001000oooo0?ooo`00100G0?ooo`030004003oool0oooo0200oooo1P00
100A0?ooo`001`3oool00`001000oooo0?ooo`0E0?ooo`8000@05`3oool00`001000oooo0?ooo`1j
0?ooo`030004003oool0oooo01@0oooo0P00100G0?ooo`030004003oool0oooo00`0oooo0`001000
0`3oool000@00004000?0?ooo`8000@05@3oool000L0oooo00<000@00?ooo`3oool0;P3oool00`00
1000oooo0?ooo`1j0?ooo`030004003oool0oooo02d0oooo00<000@00?ooo`3oool01@3oool20004
00030?ooo`00100000@000@0oooo00@000@00?ooo`00100000@09P3oool000L0oooo00<000@00?oo
o`3oool0;P3oool00`001000oooo0?ooo`1j0?ooo`030004003oool0oooo02d0oooo00<000@00?oo
o`3oool01P3oool00`001000oooo000400040?ooo`030004003oool0oooo008000@09P3oool000L0
oooo00<000@00?ooo`3oool0;@3oool00`001000oooo0?ooo`1k0?ooo`030004003oool0oooo02d0
oooo00<000@00?ooo`3oool01P3oool3000400<0oooo0`0010000`3oool000@00004000V0?ooo`00
1`3oool00`001000oooo0?ooo`0]0?ooo`030004003oool0oooo07/0oooo00<000@00?ooo`3oool0
;@3oool00`001000oooo0?ooo`060?ooo`040004003oool000@0000402h0oooo00080?ooo`030004
003oool0oooo02/0oooo00<000@00?ooo`3oool0O@3oool00`001000oooo0?ooo`0[0?ooo`030004
003oool0oooo00L0oooo00<000@00?ooo`3oool0;`3oool000P0oooo00<000@00?ooo`3oool0:`3o
ool00`001000oooo0?ooo`1k0?ooo`030004003oool000@002d0oooo00<000@00?ooo`3oool01P3o
ool200040340oooo00090?ooo`030004003oool0oooo02T0oooo00<000@00?ooo`3oool0NP3oool2
000400<0oooo00<000@00?ooo`3oool0:@3oool00`001000oooo0?ooo`0j0?ooo`002@3oool00`00
1000oooo0?ooo`0Y0?ooo`030004003oool0oooo07P0oooo0P0010050?ooo`030004003oool0oooo
02T0oooo00<000@00?ooo`3oool0>P3oool000X0oooo00<000@00?ooo`3oool09`3oool00`001000
oooo0?ooo`1g0?ooo`8000@0203oool00`001000oooo0?ooo`0W0?ooo`030004003oool0oooo03/0
oooo000:0?ooo`030004003oool0oooo02L0oooo00<000@00?ooo`3oool0MP3oool00`001000oooo
0?ooo`080?ooo`030004003oool0oooo02L0oooo00<000@00?ooo`3oool0>`3oool000/0oooo00<0
00@00?ooo`3oool09@3oool00`001000oooo0?ooo`1e0?ooo`8000@0303oool00`001000oooo0?oo
o`0U0?ooo`030004003oool0oooo03`0oooo000<0?ooo`030004003oool0oooo02<0oooo00<000@0
0?ooo`3oool0M03oool2000400l0oooo00<000@00?ooo`3oool08`3oool00`001000oooo0?ooo`0m
0?ooo`003@3oool00`001000oooo0?ooo`0Q0?ooo`030004003oool0oooo07@0oooo00<000@00?oo
o`3oool0403oool00`001000oooo0?ooo`0Q0?ooo`030004003oool0oooo03h0oooo000>0?ooo`03
0004003oool0oooo0200oooo00<000@00?ooo`3oool0LP3oool2000401@0oooo00<000@00?ooo`3o
ool07`3oool00`001000oooo0?ooo`0o0?ooo`003`3oool00`001000oooo0?ooo`0N0?ooo`030004
003oool0oooo0740oooo0P00100G0?ooo`030004003oool0oooo01d0oooo00<000@00?ooo`3oool0
@03oool00100oooo00<000@00?ooo`3oool0703oool00`001000oooo0?ooo`1`0?ooo`8000@06P3o
ool00`001000oooo0?ooo`0L0?ooo`030004003oool0oooo0400oooo000A0?ooo`030004003oool0
oooo01T0oooo0P00101b0?ooo`030004003oool0oooo01/0oooo00<000@00?ooo`3oool06@3oool2
000404<0oooo000B0?ooo`8000@0603oool00`001000oooo0?ooo`1`0?ooo`8000@07`3oool20004
01L0oooo0P0010150?ooo`00503oool2000401@0oooo0P00101a0?ooo`8000@08`3oool2000401@0
oooo00<000@00?ooo`3oool0A@3oool001H0oooo0`00100=0?ooo`@000@0LP3oool00`001000oooo
0?ooo`0U0?ooo`<000@0303oool5000404P0oooo000I0?ooo`d000@0M03oool2000402/0oooo3000
101=0?ooo`007`3oool00`001000oooo0?ooo`1f0?ooo`8000@0<`3oool00`001000oooo0?ooo`1@
0?ooo`007`3oool2000407D0oooo0P00100d0?ooo`<000@0D@3oool001h0oooo0`00101d0?ooo`03
0004003oool0oooo03@0oooo0`00101A0?ooo`007P3oool300040780oooo0P00100g0?ooo`<000@0
D@3oool001h0oooo0`00101`0?ooo`8000@0>@3oool300040540oooo000N0?ooo`@000@0KP3oool0
0`001000oooo0?ooo`0h0?ooo`D000@0D03oool001h0oooo1000101/0?ooo`8000@0>`3oool50004
0500oooo000M0?ooo`D000@0JP3oool2000403d0oooo1@00101@0?ooo`007@3oool5000406P0oooo
0P00100o0?ooo`D000@0D03oool001d0oooo1P00101V0?ooo`030004003oool0oooo03h0oooo1`00
101?0?ooo`007@3oool6000406@0oooo0P0010110?ooo`L000@0C`3oool001d0oooo1P00101R0?oo
o`8000@0@`3oool7000404l0oooo000L0?ooo`L000@0H03oool2000404D0oooo1`00101?0?ooo`00
703oool8000405h0oooo00<000@00?ooo`3oool0A03oool9000404h0oooo000L0?ooo`P000@0G03o
ool2000404L0oooo2@00101>0?ooo`007`3oool00`001000oooo0?ooo`1L0?ooo`8000@0C@3oool0
0`001000oooo0?ooo`1@0?ooo`007`3oool00`001000oooo0?ooo`1K0?ooo`030004003oool0oooo
04d0oooo00<000@00?ooo`3oool0D03oool001l0oooo00<000@00?ooo`3oool0F@3oool200040500
oooo00<000@00?ooo`3oool0D03oool001l0oooo00<000@00?ooo`3oool0E`3oool200040580oooo
00<000@00?ooo`3oool0D03oool001l0oooo00<000@00?ooo`3oool0E@3oool2000405@0oooo00<0
00@00?ooo`3oool0D03oool001l0oooo00<000@00?ooo`3oool0E03oool00`001000oooo0?ooo`1D
0?ooo`030004003oool0oooo0500oooo000O0?ooo`030004003oool0oooo0580oooo0P00101G0?oo
o`030004003oool0oooo0500oooo000O0?ooo`030004003oool0oooo0500oooo0P00101I0?ooo`03
0004003oool0oooo0500oooo000O0?ooo`030004003oool0oooo04l0oooo00<000@00?ooo`3oool0
F@3oool00`001000oooo0?ooo`1@0?ooo`007`3oool00`001000oooo0?ooo`1=0?ooo`8000@0G03o
ool00`001000oooo0?ooo`1@0?ooo`007`3oool00`001000oooo0?ooo`1;0?ooo`8000@0GP3oool0
0`001000oooo0?ooo`1@0?ooo`007`3oool00`001000oooo0?ooo`190?ooo`8000@0H03oool00`00
1000oooo0?ooo`1@0?ooo`007`3oool00`001000oooo0?ooo`180?ooo`030004003oool0oooo01D0
oooo0`0010000`3oool000@00004000f0?ooo`8000@00P3oool3000400P0oooo00<000@00?ooo`3o
ool0D03oool001l0oooo00<000@00?ooo`3oool0AP3oool2000401X0oooo00@000@00?ooo`3oool0
00@0=P3oool00`001000oooo0?ooo`030?ooo`030004003oool0oooo00H0oooo00<000@00?ooo`3o
ool0D03oool001l0oooo00<000@00?ooo`3oool0A03oool2000401<0oooo0P0010000`3oool000@0
000400030?ooo`050004003oool0oooo0?ooo`001000;`3oool2000400030?ooo`00100000@000<0
oooo00D000@00?ooo`3oool0oooo000400090?ooo`030004003oool0oooo0500oooo000O0?ooo`03
0004003oool0oooo04<0oooo00<000@00?ooo`3oool0503oool00`001000oooo000400030?ooo`<0
00@000<0oooo000400001000<03oool00`001000oooo000400030?ooo`8000@00P3oool3000400P0
oooo00<000@00?ooo`3oool0D03oool001l0oooo00<000@00?ooo`3oool0303oool2000400<0oooo
00<000@00?ooo`3oool0;@3oool2000401L0oooo0`00100i0?ooo`<000@04P3oool00`001000oooo
0?ooo`1@0?ooo`007`3oool00`001000oooo0?ooo`050?ooo`8000@000<0oooo0004000010000`3o
ool00`001000oooo0?ooo`02000402d0oooo0P00100I0?ooo`040004003oool000@0000403P0oooo
00@000@00?ooo`00100000@04@3oool00`001000oooo0?ooo`1@0?ooo`007`3oool00`001000oooo
0?ooo`060?ooo`030004003oool000@000@0oooo00<000@00?ooo`3oool00P00100[0?ooo`8000@0
6`3oool00`001000oooo0?ooo`0i0?ooo`030004003oool0oooo0180oooo00<000@00?ooo`3oool0
D03oool001l0oooo00<000@00?ooo`3oool01P3oool3000400<0oooo0P0010030?ooo`030004003o
ool0oooo02P0oooo00<000@00?ooo`3oool06P3oool2000403X0oooo0P00100D0?ooo`030004003o
ool0oooo0500oooo000O0?ooo`030004003oool0oooo00H0oooo00@000@00?ooo`00100000@0<03o
ool2000406l0oooo00<000@00?ooo`3oool0D03oool001l0oooo00<000@00?ooo`3oool01P3oool0
0`001000oooo0?ooo`0_0?ooo`8000@0L@3oool00`001000oooo0?ooo`1@0?ooo`007`3oool00`00
1000oooo0?ooo`050?ooo`8000@0;`3oool2000407<0oooo00<000@00?ooo`3oool0D03oool001l0
oooo00<000@00?ooo`3oool0=@3oool00`001000oooo0?ooo`1c0?ooo`030004003oool0oooo0500
oooo000O0?ooo`030004003oool0oooo03<0oooo0P00101f0?ooo`030004003oool0oooo0500oooo
000O0?ooo`030004003oool0oooo0340oooo0P00101h0?ooo`030004003oool0oooo0500oooo000O
0?ooo`030004003oool0oooo0300oooo00<000@00?ooo`3oool0N03oool00`001000oooo0?ooo`1@
0?ooo`007`3oool00`001000oooo0?ooo`0^0?ooo`8000@0N`3oool00`001000oooo0?ooo`1@0?oo
o`007`3oool00`001000oooo0?ooo`0/0?ooo`8000@0O@3oool00`001000oooo0?ooo`1@0?ooo`00
7`3oool00`001000oooo0?ooo`0Z0?ooo`8000@0O`3oool00`001000oooo0?ooo`1@0?ooo`007`3o
ool00`001000oooo0?ooo`0Y0?ooo`030004003oool0oooo07l0oooo00<000@00?ooo`3oool0D03o
ool001l0oooo00<000@00?ooo`3oool09`3oool200040880oooo00<000@00?ooo`3oool0D03oool0
01l0oooo00<000@00?ooo`3oool09@3oool2000408@0oooo00<000@00?ooo`3oool0D03oool001l0
oooo00<000@00?ooo`3oool0903oool00`001000oooo0?ooo`240?ooo`030004003oool0oooo0500
oooo000L0?ooo`T000@06@3oool00`001000oooo0?ooo`030?ooo`8000@0Q03oool9000404d0oooo
000G0?ooo`D000@02@3oool2000401H0oooo0P0010030?ooo`8000@0P@3oool5000400T0oooo0P00
101;0?ooo`005@3oool200040100oooo0`00100B0?ooo`H000@0P@3oool200040100oooo0P001019
0?ooo`004`3oool2000401D0oooo0P00100?0?ooo`D000@0P@3oool2000401@0oooo0`0010160?oo
o`004P3oool00`001000oooo0?ooo`0G0?ooo`8000@0303oool7000407l0oooo00<000@00?ooo`3o
ool05`3oool2000404@0oooo000A0?ooo`030004003oool0oooo01X0oooo0P0010080?ooo`T000@0
OP3oool00`001000oooo0?ooo`0J0?ooo`8000@0@P3oool000l0oooo0P00100O0?ooo`030004003o
ool0oooo00@0oooo2`00101k0?ooo`8000@07P3oool00`001000oooo0?ooo`100?ooo`003P3oool0
0`001000oooo0?ooo`0P0?ooo`030004003oool0oooo0080oooo2P00101l0?ooo`030004003oool0
oooo01l0oooo00<000@00?ooo`3oool0?`3oool000d0oooo00<000@00?ooo`3oool08@3oool01000
1000oooo0?ooo`3oool7000407l0oooo00<000@00?ooo`3oool08@3oool00`001000oooo0?ooo`0n
0?ooo`00303oool00`001000oooo0?ooo`0S0?ooo`030004003oool000@000@000@0P@3oool00`00
1000oooo0?ooo`0S0?ooo`030004003oool0oooo03d0oooo000;0?ooo`030004003oool0oooo02D0
oooo0P0010240?ooo`030004003oool0oooo02D0oooo00<000@00?ooo`3oool0?03oool000X0oooo
00<000@00?ooo`3oool09`3oool00`001000oooo0?ooo`210?ooo`030004003oool0oooo02L0oooo
00<000@00?ooo`3oool0>`3oool000X0oooo00<000@00?ooo`3oool09`3oool00`001000oooo0?oo
o`210?ooo`030004003oool0oooo02L0oooo00<000@00?ooo`3oool0>`3oool000T0oooo00<000@0
0?ooo`3oool0:@3oool00`001000oooo0?ooo`1o0?ooo`030004003oool0oooo02T0oooo00<000@0
0?ooo`3oool0>P3oool000T0oooo00<000@00?ooo`3oool0:@3oool00`001000oooo0?ooo`1o0?oo
o`030004003oool0oooo02T0oooo00<000@00?ooo`3oool0>P3oool000P0oooo00<000@00?ooo`3o
ool0:`3oool00`001000oooo0?ooo`1m0?ooo`030004003oool0oooo02/0oooo00<000@00?ooo`3o
ool0>@3oool000P0oooo00<000@00?ooo`3oool0:`3oool00`001000oooo0?ooo`1m0?ooo`030004
003oool0oooo02/0oooo00<000@00?ooo`3oool0>@3oool000P0oooo00<000@00?ooo`3oool0;03o
ool00`001000oooo0?ooo`1l0?ooo`030004003oool0oooo02`0oooo00<000@00?ooo`3oool0>03o
ool000L0oooo00<000@00?ooo`3oool0;@3oool00`001000oooo0?ooo`1k0?ooo`030004003oool0
oooo02d0oooo00<000@00?ooo`3oool0>03oool000L0oooo00<000@00?ooo`3oool0;P3oool00`00
1000oooo0?ooo`1j0?ooo`030004003oool0oooo02d0oooo00<000@00?ooo`3oool0>03oool000L0
oooo00<000@00?ooo`3oool0;P3oool00`001000oooo0?ooo`1j0?ooo`030004003oool0oooo02d0
oooo00<000@00?ooo`3oool0>03oool000L0oooo00<000@00?ooo`3oool0;P3oool00`001000oooo
0?ooo`1[0?ooo`8000@03@3oool00`001000oooo0?ooo`0]0?ooo`030004003oool0oooo03P0oooo
00070?ooo`030004003oool0oooo02h0oooo00<000@00?ooo`3oool0J`3oool6000400T0oooo00<0
00@00?ooo`3oool0;P3oool00`001000oooo0?ooo`0g0?ooo`001P3oool00`001000oooo0?ooo`0D
0?ooo`D000@05P3oool00`001000oooo0?ooo`1[0?ooo`T000@01@3oool00`001000oooo0?ooo`0D
0?ooo`@000@05`3oool00`001000oooo0?ooo`0g0?ooo`001P3oool00`001000oooo0?ooo`0F0?oo
o`030004003oool0oooo01H0oooo00<000@00?ooo`3oool0J`3oool=000400030?ooo`001000oooo
01D0oooo00<000@00?ooo`3oool0603oool00`001000oooo0?ooo`0g0?ooo`001P3oool00`001000
oooo0?ooo`0F0?ooo`030004003oool0oooo01H0ooooO@00100G0?ooo`030004003oool0oooo01L0
oooo00<000@00?ooo`3oool0=`3oool000H0oooo00<000@00?ooo`3oool05P3oool00`001000oooo
0?ooo`0F0?ooo`030004003oool0oooo06/0oooo300010020?ooo`030004003oool0oooo01H0oooo
00<000@00?ooo`3oool05P3oool00`001000oooo0?ooo`0g0?ooo`001P3oool00`001000oooo0?oo
o`0F0?ooo`030004003oool0oooo01H0oooo00<000@00?ooo`3oool0J`3oool8000400H0oooo00<0
00@00?ooo`3oool0503oool010001000oooo0?ooo`00100G0?ooo`030004003oool0oooo03L0oooo
00070?ooo`030004003oool0oooo01@0oooo0P00100H0?ooo`030004003oool0oooo06/0oooo0`00
100<0?ooo`030004003oool0oooo01@0oooo0P00100H0?ooo`030004003oool0oooo03L0oooo0007
0?ooo`030004003oool0oooo02h0oooo00<000@00?ooo`3oool0NP3oool00`001000oooo0?ooo`0]
0?ooo`030004003oool0oooo03P0oooo00070?ooo`030004003oool0oooo02h0oooo00<000@00?oo
o`3oool0NP3oool00`001000oooo0?ooo`0]0?ooo`030004003oool0oooo03P0oooo00070?ooo`03
0004003oool0oooo02d0oooo00<000@00?ooo`3oool0N`3oool00`001000oooo0?ooo`0]0?ooo`03
0004003oool0oooo03P0oooo00070?ooo`030004003oool0oooo02d0oooo00<000@00?ooo`3oool0
N`3oool00`001000oooo0?ooo`0]0?ooo`030004003oool0oooo03P0oooo00080?ooo`030004003o
ool0oooo02/0oooo00<000@00?ooo`3oool0O@3oool00`001000oooo0?ooo`0[0?ooo`030004003o
ool0oooo03T0oooo00080?ooo`030004003oool0oooo02/0oooo00<000@00?ooo`3oool0O@3oool0
0`001000oooo0?ooo`0[0?ooo`030004003oool0oooo03T0oooo00090?ooo`030004003oool0oooo
02X0oooo00<000@00?ooo`3oool0OP3oool00`001000oooo0?ooo`0Z0?ooo`030004003oool0oooo
03T0oooo00090?ooo`030004003oool0oooo02T0oooo00<000@00?ooo`3oool0O`3oool00`001000
oooo0?ooo`0Y0?ooo`030004003oool0oooo03X0oooo00090?ooo`030004003oool0oooo02T0oooo
00<000@00?ooo`3oool0O`3oool00`001000oooo0?ooo`0Y0?ooo`030004003oool0oooo03X0oooo
000:0?ooo`030004003oool0oooo02L0oooo00<000@00?ooo`3oool0P@3oool00`001000oooo0?oo
o`0W0?ooo`030004003oool0oooo03/0oooo000:0?ooo`030004003oool0oooo02L0oooo00<000@0
0?ooo`3oool0P@3oool00`001000oooo0?ooo`0W0?ooo`030004003oool0oooo03/0oooo000;0?oo
o`030004003oool0oooo02D0oooo00<000@00?ooo`3oool0P`3oool00`001000oooo0?ooo`0U0?oo
o`030004003oool0oooo03`0oooo000<0?ooo`030004003oool0oooo02<0oooo00<000@00?ooo`3o
ool0Q@3oool00`001000oooo0?ooo`0S0?ooo`030004003oool0oooo03d0oooo000=0?ooo`030004
003oool0oooo0240oooo00<000@00?ooo`3oool0@P3oool200040080oooo0P00100o0?ooo`030004
003oool0oooo0240oooo00<000@00?ooo`3oool0?P3oool000h0oooo0P00100Q0?ooo`030004003o
ool0oooo03/0oooo0P0010000`3oool000@0000400030?ooo`040004003oool0oooo00040440oooo
0P00100P0?ooo`030004003oool0oooo03l0oooo000@0?ooo`030004003oool0oooo01`0oooo0P00
100o0?ooo`030004003oool000@000@0oooo00D000@00?ooo`3oool0oooo000400120?ooo`030004
003oool0oooo01`0oooo00<000@00?ooo`3oool0@03oool00140oooo00<000@00?ooo`3oool06P3o
ool00`001000oooo0?ooo`0o0?ooo`<000@00`3oool200040080oooo0P0010130?ooo`030004003o
ool0oooo01X0oooo00<000@00?ooo`3oool0@@3oool00180oooo0P00100I0?ooo`030004003oool0
oooo0400oooo00@000@00?ooo`00100000@0C03oool2000401P0oooo0P0010140?ooo`00503oool2
000401@0oooo0`0010130?ooo`030004003oool0oooo04l0oooo0P00100D0?ooo`8000@0AP3oool0
01H0oooo0`00100?0?ooo`8000@0A@3oool2000405<0oooo0`00100?0?ooo`8000@0B03oool001T0
oooo1@0010050?ooo`D000@0W`3oool4000400H0oooo1@00101:0?ooo`007P3oool500040:P0oooo
1P00101?0?ooo`007`3oool00`001000oooo0?ooo`3n0?ooo`007`3oool200040?l0oooo000N0?oo
o`<000@0o`3oool001h0oooo0`00103o0?ooo`007P3oool300040?l0oooo000N0?ooo`8000@000<0
oooo0004003oool0o@3oool001d0oooo00D000@00?ooo`001000oooo0004003n0?ooo`007@3oool0
1@001000oooo0004003oool000@00?h0oooo000M0?ooo`030004003oool000@00080oooo00<000@0
0?ooo`3oool0n`3oool001d0oooo00<000@00?ooo`0010000P3oool00`001000oooo0?ooo`3k0?oo
o`007@3oool00`001000oooo000400020?ooo`030004003oool0oooo0?/0oooo000L0?ooo`040004
003oool0oooo00040080oooo00<000@00?ooo`3oool0n`3oool001`0oooo00@000@00?ooo`3oool0
00@00`3oool00`001000oooo0?ooo`3j0?ooo`00703oool010001000oooo0?ooo`0010030?ooo`03
0004003oool0oooo0?X0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003o
ool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo
0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo
000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?oo
o`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004
003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000?0?ooo`030004003oool0
oooo00H0oooo00<000@00?ooo`3oool0103oool00`001000oooo0?ooo`3n0?ooo`001`3oool20004
00D0oooo00<000@00?ooo`3oool0203oool00`001000oooo0?ooo`030?ooo`030004003oool0oooo
0?h0oooo0004000400@0oooo00<000@00?ooo`3oool00P3oool00`001000oooo0?ooo`030?ooo`80
00@01@3oool00`001000oooo0?ooo`020?ooo`030004003oool0oooo0?h0oooo00001@3oool000@0
0?ooo`3oool000@000<0oooo00<000@00?ooo`3oool00P3oool00`001000oooo0?ooo`020?ooo`04
0004003oool0oooo000400@0oooo00<000@00?ooo`3oool00P3oool00`001000oooo0?ooo`3n0?oo
o`0000D0oooo0004003oool0oooo000400020?ooo`8000@0103oool00`001000oooo0?ooo`020?oo
o`030004003oool0oooo00D0oooo00<000@00?ooo`3oool00P3oool00`001000oooo0?ooo`3n0?oo
o`0000@0oooo00040000100000@02@3oool010001000oooo0?ooo`3oool5000400@0oooo00<000@0
0?ooo`3oool00P3oool00`001000oooo0?ooo`3n0?ooo`0000<0oooo0004003oool02`3oool01@00
1000oooo0?ooo`3oool000@000H0oooo00<000@00?ooo`3oool00`3oool00`001000oooo0?ooo`3n
0?ooo`000P00100=0?ooo`030004003oool0oooo00H0oooo00<000@00?ooo`3oool0103oool00`00
1000oooo0?ooo`3n0?ooo`007`3oool00`001000oooo0?ooo`3n0?ooo`007`3oool00`001000oooo
0?ooo`3n0?ooo`007`3oool00`001000oooo0?ooo`3n0?ooo`007`3oool00`001000oooo0?ooo`3n
0?ooo`007`3oool00`001000oooo0?ooo`3n0?ooo`007`3oool00`001000oooo0?ooo`3n0?ooo`00
7`3oool00`001000oooo0?ooo`3n0?ooo`007`3oool00`001000oooo0?ooo`3n0?ooo`007`3oool0
0`001000oooo0?ooo`3n0?ooo`007`3oool00`001000oooo0?ooo`3n0?ooo`007`3oool00`001000
oooo0?ooo`3n0?ooo`007`3oool00`001000oooo0?ooo`3n0?ooo`007`3oool00`001000oooo0?oo
o`3n0?ooo`007`3oool00`001000oooo0?ooo`3n0?ooo`007`3oool00`001000oooo0?ooo`3n0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{94, 381}, {334.813, 74}} -> {-2.53078, -2.13544, \
0.0201296, 0.0201296}}],

Cell["Biokinetic data for iodine (taken from Publication 78/56): ", "Text"],

Cell["\<\
The compartments has been numbered as follow (Compartments 5-8 are not \
represented in the above figure) \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CompartNumbers[iodine]\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "\<\"Blood\"\>"},
          {"2", "\<\"Thyroid\"\>"},
          {"3", "\<\"Rest\"\>"},
          {"4", "\<\"Bladder\"\>"},
          {"5", "\<\"Urine\"\>"},
          {"6", "\<\"ULI\"\>"},
          {"7", "\<\"LLI\"\>"},
          {"8", "\<\"FEC\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[6]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "The halt-life of  the blood is 0.25 days, the uptake to thyroid is 30% and \
to the bladder is  70%,  the halt-life of Thyroid is 80 days, and the \
halt-life of \"Rest of Body\" is 12 days to 20 % faecal excretion and 80% to \
blood, therefore the rate transfer are, in ",
  Cell[BoxData[
      \(TraditionalForm\`d\^\(-1\)\)]],
  ": Blood (Log[2]/0.25), Thyroid (Log[2]/80),  and Rest of body (Log[2]/12. \
As usual, the rate transfers from bladder is 12 ",
  Cell[BoxData[
      \(TraditionalForm\`d\^\(-1\)\)]],
  ", so the transfer rate are"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[TransferRates[iodine], 
      TableHeadings \[Rule] {None, {"\<From\>", \ "\<to\>", \*"\"\<Tranfer \
Rates(\!\(days\^\(-1\)\))\>\""}}]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"From\"\>", "\<\"to\"\>", "\<\"Tranfer \
Rates(\\!\\(days\\^\\(-1\\)\\))\"\>"},
          {"1", "2", "0.8317766166719344`"},
          {"1", "4", "1.9408121055678467`"},
          {"2", "3", \(Log[2]\/80\)},
          {"3", "6", "0.011552453009332421`"},
          {"3", "1", "0.046209812037329684`"},
          {"4", "5", "12"},
          {"6", "7", \(k\_ULI\)},
          {"7", "8", \(k\_LLI\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"From", "to", 
          "Tranfer Rates(\!\(days\^\(-1\)\))"}}]]]], "Output",
  CellLabel->"Out[7]//TableForm="]
}, Open  ]],

Cell["Here is the coefficients matrix of iodine", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(compartMatrix[iodine]\  // MatrixForm\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-2.772588722239781`\), "0", "0.046209812037329684`", "0", "0", 
              "0", "0", "0"},
            {"0.8317766166719344`", \(-\(Log[2]\/80\)\), "0", "0", "0", "0", 
              "0", "0"},
            {"0", \(Log[2]\/80\), \(-0.057762265046662105`\), "0", "0", "0", 
              "0", "0"},
            {"1.9408121055678467`", "0", "0", \(-12\), "0", "0", "0", "0"},
            {"0", "0", "0", "12", "0", "0", "0", "0"},
            {"0", "0", "0.011552453009332421`", "0", "0", \(-k\_ULI\), "0", 
              "0"},
            {"0", "0", "0", "0", "0", \(k\_ULI\), \(-k\_LLI\), "0"},
            {"0", "0", "0", "0", "0", "0", \(k\_LLI\), "0"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[8]//MatrixForm="]
}, Open  ]],

Cell["\<\
By default are applied the following values for GI tract rate transfer\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[qGI]\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \({k\_ST \[Rule] 24, f\_B \[Rule] f1\/\(1 - f1\), k\_SI \[Rule] 6, 
      k\_ULI \[Rule] 1.8`, k\_LLI \[Rule] 1}\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Injection", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Injection\",ShowReport\[Rule] \"Automatic\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
        element, "\<Injection\>", \ "\<Acute\>", "\<Automatic\>", 1, fn1, t1, 
        lambda] // Chop\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \({qDailyUrine[
          t1] \[Rule] \(-34232.18489959334`\)\ \
\[ExponentialE]\^\(\(-12.086643397569993`\)\ t1\) + 
          13.654916357254258`\ \[ExponentialE]\^\(\(-2.8591877362402407`\)\ \
t1\) - 0.0016907734626698152`\ \[ExponentialE]\^\(\(-0.14679047567382672`\)\ \
t1\) + 0.001575117502530976`\ \[ExponentialE]\^\(\(-0.0929673078393539`\)\ t1\
\), qDailyFaecal[t1] \[Rule] 
        0.0000626807950263629`\ \[ExponentialE]\^\(\(-2.8591877362402407`\)\ \
t1\) - 0.00017314960229548447`\ \[ExponentialE]\^\(\(-1.8866433975699932`\)\ \
t1\) + 0.00019444261986620694`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ \
t1\) - 0.0006470236360488265`\ \[ExponentialE]\^\(\(-0.14679047567382672`\)\ \
t1\) + 0.0005665235164631771`\ \[ExponentialE]\^\(\(-0.0929673078393539`\)\ \
t1\), qWholebody[
          t1] \[Rule] \(-0.21033110566047453`\)\ \
\[ExponentialE]\^\(\(-12.086643397569993`\)\ t1\) + 
          0.9103750343200603`\ \[ExponentialE]\^\(\(-2.8591877362402407`\)\ \
t1\) - 0.00003428944367220578`\ \[ExponentialE]\^\(\(-1.8866433975699932`\)\ \
t1\) + 0.00011316107558477938`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ \
t1\) - 0.037710826146865106`\ \[ExponentialE]\^\(\(-0.14679047567382672`\)\ \
t1\) + 0.33758802585536707`\ \[ExponentialE]\^\(\(-0.0929673078393539`\)\ \
t1\)}\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Injection\>", \ "\<Constant\>", "\<Automatic\>", 1, fn1, 
      t1, lambda]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \({qDailyUrine[
          t1] \[Rule] \(\(0.6510615822290919`\)\(\[InvisibleSpace]\)\) + 
          2832.2325540336283`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t1\) - 4.775802646387299`\ \[ExponentialE]\^\(\(-2.8591877362402407`\)\ t1\) \
+ 0.011518277700978213`\ \[ExponentialE]\^\(\(-0.14679047567382672`\)\ t1\) - 
          0.016942703183926877`\ \[ExponentialE]\^\(\(-0.0929673078393539`\)\ \
t1\) + 1.7763568394002505`*^-15\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\
\ t1\), qDailyFaecal[
          t1] \[Rule] \(\(0.0017945794413077101`\)\(\[InvisibleSpace]\)\) - 
          0.00002192258809447278`\ \
\[ExponentialE]\^\(\(-2.8591877362402407`\)\ t1\) + 
          0.00009177653949787337`\ \
\[ExponentialE]\^\(\(-1.8866433975699932`\)\ t1\) - 
          0.00017893875792281935`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) + 
          0.004407803933318771`\ \[ExponentialE]\^\(\(-0.14679047567382672`\)\
\ t1\) - 0.006093792857184921`\ \[ExponentialE]\^\(\(-0.0929673078393539`\)\ \
t1\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\), 
      qWholebody[
          t1] \[Rule] \(\(3.6754402547765213`\)\(\[InvisibleSpace]\)\) + 
          0.01740194516723819`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t1\) - 0.3184033782675566`\ \[ExponentialE]\^\(\(-2.8591877362402407`\)\ t1\) \
+ 0.000018174840945761543`\ \[ExponentialE]\^\(\(-1.8866433975699932`\)\ t1\) \
- 0.00010413818906720999`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) \
+ 0.2569024044220676`\ \[ExponentialE]\^\(\(-0.14679047567382672`\)\ t1\) - 
          3.631255262750149`\ \[ExponentialE]\^\(\(-0.0929673078393539`\)\ t1\
\)}\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
        element, "\<Injection\>", \ "\<Continuous\>", "\<Automatic\>", 
        inputs1, fn1, t, lambda] // Chop\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \({qDailyUrine[t] \[Rule] 
        3485.1840760687687`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t\) \
- 6.402773581893601`\ \[ExponentialE]\^\(\(-2.8591877362402407`\)\ t\) + 
          1.0369968346811014`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.013242833068813159`\ \[ExponentialE]\^\(\(-0.14679047567382672`\)\
\ t\) + 0.009129674078577343`\ \[ExponentialE]\^\(\(-0.09296730783935392`\)\ \
t\), qDailyFaecal[
          t] \[Rule] \(-0.00002939094813815352`\)\ \
\[ExponentialE]\^\(\(-2.8591877362402407`\)\ t\) + 
          0.00013095540124063407`\ \
\[ExponentialE]\^\(\(-1.8866433975699932`\)\ t\) - 
          0.00029661615995281676`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t\) + 
          0.0019785147327131165`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.005067755197814119`\ \[ExponentialE]\^\(\(-0.14679047567382672`\)\
\ t\) + 0.0032836756971130754`\ \[ExponentialE]\^\(\(-0.09296730783935392`\)\ \
t\), qWholebody[t] \[Rule] 
        0.021413842625000873`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t\
\) - 0.4268737403333351`\ \[ExponentialE]\^\(\(-2.8591877362402407`\)\ t\) + 
          0.00002593357301941047`\ \
\[ExponentialE]\^\(\(-1.8866433975699932`\)\ t\) - 
          0.00017262369597356567`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t\) - 
          1.2557497162165507`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.29536669848212177`\ \[ExponentialE]\^\(\(-0.14679047567382672`\)\ \
t\) + 1.956723002529961`\ \[ExponentialE]\^\(\(-0.09296730783935392`\)\ \
t\)}\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
        element, "\<Injection\>", \ "\<MultiInputs\>", "\<Automatic\>", 
        inputs2, fn1, t, lambda] // Chop\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \({qDailyUrine[
          t] \[Rule] \(-239625.29430041352`\)\ \
\[ExponentialE]\^\(\(-12.086643397569993`\)\ t\) + 
          95.71898595576609`\ \[ExponentialE]\^\(\(-2.8591877362402407`\)\ \
t\) - 0.016318063001443436`\ \[ExponentialE]\^\(\(-0.14679047567382672`\)\ \
t\) + 0.01585111395594818`\ \[ExponentialE]\^\(\(-0.0929673078393539`\)\ t\), 
      qDailyFaecal[t] \[Rule] 
        0.0004393832947674764`\ \[ExponentialE]\^\(\(-2.8591877362402407`\)\ \
t\) - 0.0012239843903959872`\ \[ExponentialE]\^\(\(-1.8866433975699932`\)\ \
t\) + 0.0014277693570356258`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ \
t\) - 0.00624458136443417`\ \[ExponentialE]\^\(\(-0.14679047567382672`\)\ t\) \
+ 0.0057011802635376085`\ \[ExponentialE]\^\(\(-0.0929673078393539`\)\ t\), 
      qWholebody[
          t] \[Rule] \(-1.4723177396433524`\)\ \
\[ExponentialE]\^\(\(-12.086643397569993`\)\ t\) + 
          6.381597136497156`\ \[ExponentialE]\^\(\(-2.8591877362402407`\)\ \
t\) - 0.0002423900676278761`\ \[ExponentialE]\^\(\(-1.8866433975699932`\)\ \
t\) + 0.0008309285085765292`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ \
t\) - 0.36395629011667113`\ \[ExponentialE]\^\(\(-0.14679047567382672`\)\ t\) \
+ 3.39729973122551`\ \[ExponentialE]\^\(\(-0.0929673078393539`\)\ t\)}\)], \
"Output",
  CellLabel->"Out[13]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Injection\",ShowReport\[Rule] \"BioassayTable\"\
\>", "SubsubsectionIcon"],

Cell[TextData[StyleBox["Appart the defauld days included in the \
BioassayTable, we chose the day 180 ", "Theorem"]], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Injection\>", \ "\<Acute\>", "\<BioassayTable\>", 1, fn1, 
      180, lambda]\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nstart intake"\), \("Urine\n24 hours"\), \("Faecal\n\
24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "0.5897376338194583`", "4.819844605271434`*^-7", 
            "0.32726592740075267`"},
          {"2", "0.04490314572121778`", "6.342350389486901`*^-6", 
            "0.25519469055800925`"},
          {"3", "0.0026742325030671556`", "0.000018961269225882826`", 
            "0.23132136927376648`"},
          {"4", "0.00029340745961023814`", "0.000033331757658328366`", 
            "0.21179589168641605`"},
          {"5", "0.00018640926219397`", "0.0000461706259307928`", 
            "0.19398510912245737`"},
          {"6", "0.0002014003989701308`", "0.00005642425826207614`", 
            "0.1776273047295606`"},
          {"7", "0.0002165686624309332`", "0.00006405716118298112`", 
            "0.1626043307969413`"},
          {"8", "0.00022621169513183104`", "0.00006937187566536523`", 
            "0.14881324521258785`"},
          {"9", "0.00023107636747747915`", "0.00007274180457057936`", 
            "0.13615852937030318`"},
          {"10", "0.0002321043723207358`", "0.0000745214989202843`", 
            "0.12455129607812898`"},
          {"20", "0.00015560374183477328`", "0.0000539008748308555`", 
            "0.050585606733999464`"},
          {"30", "0.00007615931837327268`", "0.000026916427401407222`", 
            "0.020294140395147587`"},
          {"40", "0.000033456177495147336`", "0.000011923566736009306`", 
            "0.00808552199682052`"},
          {"50", "0.000013987364818688866`", "5.005582989301254`*^-6", 
            "0.003208675066712108`"},
          {"60", "5.700931991757317`*^-6", "2.0446374146657546`*^-6", 
            "0.0012704313492615995`"},
          {"70", "2.291615868232727`*^-6", "8.228858684231875`*^-7", 
            "0.0005023441721747014`"},
          {"80", "9.140361282623268`*^-7", "3.284429636720099`*^-7", 
            "0.00019848012257229645`"},
          {"90", "3.629604063757363`*^-7", "1.3047500632393693`*^-7", 
            "0.000078385880099344`"},
          {"100", "1.4376251236231487`*^-7", "5.16907507307766`*^-8", 
            "0.000030948889671903005`"},
          {"180", "8.506483511137133`*^-11", "3.0595193191000915`*^-11", 
            "1.8232660399238097`*^-8"},
          {"200", "1.3251509327179593`*^-11", "4.766171892206848`*^-12", 
            "2.840195599746936`*^-9"},
          {"300", "1.2155036700073907`*^-15", "4.3718097710544427`*^-16", 
            "2.605135947376215`*^-13"},
          {"400", "1.1149039146088426`*^-19", "4.0099820184112694`*^-20", 
            "2.389524661545035`*^-17"},
          {"500", "1.0226300759410536`*^-23", "3.678100114639899`*^-24", 
            "2.1917581892348688`*^-21"},
          {"600", "9.379931831069915`*^-28", "3.3736860625216536`*^-28", 
            "2.010359648991663`*^-25"},
          {"700", "8.603611728742937`*^-32", "3.094466516319637`*^-32", 
            "1.8439743663984432`*^-29"},
          {"800", "7.891542935715265`*^-36", "2.8383562795014836`*^-36", 
            "1.691359785121033`*^-33"},
          {"900", "7.23840776056679`*^-40", "2.6034427346032047`*^-40", 
            "1.551376187680991`*^-37"},
          {"1000", "6.639328624964952`*^-44", "2.387971559915963`*^-44", 
            "1.4229781841072793`*^-41"},
          {"2000", "0", "0", "0"},
          {"3000", "0", "0", "0"},
          {"4000", "0", "0", "0"},
          {"5000", "0", "0", "0"},
          {"6000", "0", "0", "0"},
          {"7000", "0", "0", "0"},
          {"8000", "0", "0", "0"},
          {"9000", "0", "0", "0"},
          {"10000", "0", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nstart intake", 
          "Urine\n24 hours", "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
  CellLabel->"Out[14]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Injection\>", \ "\<Constant\>", "\<BioassayTable\>", 1, 
      fn1, 180, lambda]\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nstart intake"\), \("Urine\n24 hours"\), \("Faecal\n\
24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "0.3877997512457796`", "9.195224249614009`*^-8", 
            "0.5701029990616227`"},
          {"2", "0.6298928547765074`", "2.815762636441212`*^-6", 
            "0.850793926903116`"},
          {"3", "0.6447587260281542`", "0.000015107728924726361`", 
            "1.0933104794067035`"},
          {"4", "0.6457320346738606`", "0.00004128921954947808`", 
            "1.3146996484602176`"},
          {"5", "0.6459434480802917`", "0.00008123545949412713`", 
            "1.5174630519576389`"},
          {"6", "0.6461363469904642`", "0.00013275837977445377`", 
            "1.7031534909482602`"},
          {"7", "0.646345785055285`", "0.00019320716676270129`", 
            "1.8731624874353003`"},
          {"8", "0.6465676148816528`", "0.0002600993918981113`", 
            "2.0287727025435833`"},
          {"9", "0.6467966160082406`", "0.0003313029388377302`", 
            "2.171167694288299`"},
          {"10", "0.6470284903918091`", "0.0004050534316351577`", 
            "2.3014388525739355`"},
          {"20", "0.6490338211519857`", "0.0010793225061751233`", 
            "3.123421831149201`"},
          {"30", "0.6501608092429843`", "0.0014738394960422327`", 
            "3.4553276800045585`"},
          {"40", "0.6506829180716256`", "0.0016591319633678069`", 
            "3.5880494099551576`"},
          {"50", "0.650906797328739`", "0.0017390799492795726`", 
            "3.640829658498787`"},
          {"60", "0.6509992626081127`", "0.0017722045547708537`", 
            "3.6617526458198184`"},
          {"70", "0.6510367026506341`", "0.0017856401234209451`", 
            "3.6700316777958375`"},
          {"80", "0.6510516974607503`", "0.0017910262853715123`", 
            "3.673304128051914`"},
          {"90", "0.6510576658526537`", "0.001793171320704303`", 
            "3.674596827262127`"},
          {"100", "0.6510600330401468`", "0.0017940223552816471`", 
            "3.675107291276537`"},
          {"180", "0.6510615813140719`", "0.0017945791122029008`", 
            "3.67544005865697`"},
          {"200", "0.6510615820865517`", "0.0017945793900400742`", 
            "3.675440224226018`"},
          {"300", "0.6510615822290786`", "0.001794579441303009`", 
            "3.675440254773719`"},
          {"400", "0.6510615822290919`", "0.0017945794413077101`", 
            "3.675440254776521`"},
          {"500", "0.6510615822290919`", "0.0017945794413077101`", 
            "3.6754402547765213`"},
          {"600", "0.6510615822290919`", "0.0017945794413077101`", 
            "3.6754402547765213`"},
          {"700", "0.6510615822290919`", "0.0017945794413077101`", 
            "3.6754402547765213`"},
          {"800", "0.6510615822290919`", "0.0017945794413077101`", 
            "3.6754402547765213`"},
          {"900", "0.6510615822290919`", "0.0017945794413077101`", 
            "3.6754402547765213`"},
          {"1000", "0.6510615822290919`", "0.0017945794413077101`", 
            "3.6754402547765213`"},
          {"2000", "0.6510615822290919`", "0.0017945794413077101`", 
            "3.6754402547765213`"},
          {"3000", "0.6510615822290919`", "0.0017945794413077101`", 
            "3.6754402547765213`"},
          {"4000", "0.6510615822290919`", "0.0017945794413077101`", 
            "3.6754402547765213`"},
          {"5000", "0.6510615822290919`", "0.0017945794413077101`", 
            "3.6754402547765213`"},
          {"6000", "0.6510615822290919`", "0.0017945794413077101`", 
            "3.6754402547765213`"},
          {"7000", "0.6510615822290919`", "0.0017945794413077101`", 
            "3.6754402547765213`"},
          {"8000", "0.6510615822290919`", "0.0017945794413077101`", 
            "3.6754402547765213`"},
          {"9000", "0.6510615822290919`", "0.0017945794413077101`", 
            "3.6754402547765213`"},
          {"10000", "0.6510615822290919`", "0.0017945794413077101`", 
            "3.6754402547765213`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nstart intake", 
          "Urine\n24 hours", "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
  CellLabel->"Out[15]//TableForm="]
}, Open  ]],

Cell["Nota: Incluir Chop para esta opcion en Humorap", "Commentary"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Injection\>", \ "\<Continuous\>", "\<BioassayTable\>", 
      inputs1, fn1, 180, lambda]\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nstart intake"\), \("Urine\n24 hours"\), \("Faecal\n\
24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "0.41777006124674715`", "1.0531989573980871`*^-7", 
            "0.5731669997528437`"},
          {"2", "0.5457895662949874`", "3.0540990929208474`*^-6", 
            "0.7139081441709533`"},
          {"3", "0.4187878560014304`", "0.000015335675623858825`", 
            "0.7796913105186277`"},
          {"4", "0.31120102402938543`", "0.00003887722323341244`", 
            "0.8066251694793389`"},
          {"5", "0.23076024917633808`", "0.00007054665508911505`", 
            "0.8073122847958885`"},
          {"6", "0.17115179293184912`", "0.00010594244967427162`", 
            "0.7901588625230056`"},
          {"7", "0.12700988941927127`", "0.00014135006441656886`", 
            "0.7612284441139722`"},
          {"8", "0.09432146574027511`", "0.00017420078830072912`", 
            "0.7249005205369529`"},
          {"9", "0.07011259703014772`", "0.00020295659632972005`", 
            "0.6843169461939934`"},
          {"10", "0.05218110565808809`", "0.00022685881931366002`", 
            "0.6417098823713399`"},
          {"20", "0.0032895962092294173`", "0.00024738141766974414`", 
            "0.28601440894537283`"},
          {"30", "0.0005272974881576631`", "0.00014014153518643194`", 
            "0.11653438742738881`"},
          {"40", "0.00019058690390388877`", "0.00006541028829268672`", 
            "0.04664106273801712`"},
          {"50", "0.00007915497581494069`", "0.000028158373292048338`", 
            "0.018547830630989894`"},
          {"60", "0.00003254435341312409`", "0.00001165401003877227`", 
            "0.007352148536927963`"},
          {"70", "0.000013164734620867147`", "4.724183355036887`*^-6", 
            "0.0029090322197267305`"},
          {"80", "5.270616976093406`*^-6", "1.8932519994544427`*^-6", 
            "0.0011498177544741822`"},
          {"90", "2.097487347294197`*^-6", "7.53846289946173`*^-7", 
            "0.00045419861272685054`"},
          {"100", "8.318226474833025`*^-7", "2.990536663239364`*^-7", 
            "0.0001793531432033243`"},
          {"180", "4.930400789438836`*^-10", "1.7733101906106547`*^-10", 
            "1.0567963448602606`*^-7"},
          {"200", "7.680760122062031`*^-11", "2.7625384728836396`*^-11", 
            "1.646228843124699`*^-8"},
          {"300", "7.045285144801278`*^-15", "2.533982177408878`*^-15", 
            "1.5099852551338322`*^-12"},
          {"400", "6.462190504019907`*^-19", "2.3242601789159493`*^-19", 
            "1.3850129483795798`*^-16"},
          {"500", "5.927354169621688`*^-23", "2.131895253594205`*^-23", 
            "1.2703838218172738`*^-20"},
          {"600", "5.436782992936688`*^-27", "1.955451205686779`*^-27", 
            "1.1652418531649443`*^-24"},
          {"700", "4.986813418979717`*^-31", "1.7936103621216877`*^-31", 
            "1.0688018479521735`*^-28"},
          {"800", "4.574085096275552`*^-35", "1.6451641039427795`*^-35", 
            "9.80343597411348`*^-33"},
          {"900", "4.195515795708063`*^-39", "1.5090038428276603`*^-39", 
            "8.992065000887007`*^-37"},
          {"1000", "3.8482783972786104`*^-43", "1.3841127425411706`*^-43", 
            "8.247846285086804`*^-41"},
          {"2000", "1.6221022300970051`*^-83", "5.834219952700793`*^-84", 
            "3.476576309189609`*^-81"},
          {"3000", "6.861141823109303`*^-124", "2.4612379954489616`*^-124", 
            "1.4654229014272983`*^-121"},
          {"4000", "8.492718366562857`*^-164", "1.5160723282162928`*^-164", 
            "6.176951371242119`*^-162"},
          {"5000", "1.3204539871214057`*^-201", "1.1322733464446837`*^-202", 
            "2.603666709830167`*^-202"},
          {
            "6000", \(-1.889617985508495`*^-239\), \
\(-1.6121740749378033`*^-240\), "1.0974799587121016`*^-242"},
          {
            "7000", \(-4.407212831701244`*^-277\), \(-3.79020303526307`*^-278\
\), "4.626023197313723`*^-283"},
          {"8000", 
            "4.45950677945045509972626418592346`15.954589770191005*^-314", 
            "3.8233224944637963099418947133033`15.954589770191005*^-315", 
            "1.949929969308759664264400673269057`15.954589770190996*^-323"},
          {
            "9000", \(-2.44729792840942`1.9866321321741267*^-352\), \
\(-2.0976839386365`1.9866321321740625*^-353\), 
            "8.219212751497591691623771008048`15.95458977019102*^-364"},
          {"10000", "2.4625551899398`2.6180807201295493*^-389", 
            "2.11076159137697`2.6180807201295178*^-390", 
            "3.46450689602604964598254539925`15.954589770190978*^-404"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nstart intake", 
          "Urine\n24 hours", "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
  CellLabel->"Out[16]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Injection\>", \ "\<MultiInputs\>", "\<BioassayTable\>", 
      inputs2, fn1, 180, lambda]\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nlast intake"\), \("Urine\n24 hours"\), \("Faecal\n\
24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "4.136402702907841`", "0.00012431486008420304`", 
            "3.1474299304235096`"},
          {"2", "0.31542845412248843`", "0.00021376360136689373`", 
            "2.570563754177901`"},
          {"3", "0.019509931675530164`", "0.00034398256694422903`", 
            "2.3373634416540408`"},
          {"4", "0.002890157786503772`", "0.0004771165773148639`", 
            "2.140004452071723`"},
          {"5", "0.0021846709475481707`", "0.0005903877589741206`", 
            "1.9596176763192454`"},
          {"6", "0.0023141721565637227`", "0.000677592884577945`", 
            "1.79398556727895`"},
          {"7", "0.0024287729334075137`", "0.0007398255465421102`", 
            "1.641923420165674`"},
          {"8", "0.0024918414928951594`", "0.000780451834077295`", 
            "1.5023781215973935`"},
          {"9", "0.0025113971346887136`", "0.0008031711976157771`", 
            "1.3743722435947452`"},
          {"10", "0.002496352783074403`", "0.0008113846974069538`", 
            "1.2569971667641757`"},
          {"20", "0.0016029096762869078`", "0.0005565875868556505`", 
            "0.5098908821566921`"},
          {"30", "0.0007749503364448785`", "0.0002741344040094395`", 
            "0.20441917748873104`"},
          {"40", "0.0003386487364688515`", "0.00012074386458461098`", 
            "0.08141204430583154`"},
          {"50", "0.0001412136967086502`", "0.000050546616139117015`", 
            "0.032300430547115164`"},
          {"60", "0.00005747531154773315`", "0.000020616007577811785`", 
            "0.012787246281318297`"},
          {"70", "0.00002308558433450777`", "8.290263826875989`*^-6", 
            "0.005055850605774492`"},
          {"80", "9.203891316245194`*^-6", "3.3073872884929053`*^-6", 
            "0.0019975179718570235`"},
          {"90", "3.6539088596024114`*^-6", "1.3135166143343956`*^-6", 
            "0.0007888607200922092`"},
          {"100", "1.4470405283887552`*^-6", "5.202996728928205`*^-7", 
            "0.0003114591137594946`"},
          {"180", "8.560479262984365`*^-10", "3.078940460001823`*^-10", 
            "1.834834920247381`*^-7"},
          {"200", "1.3335600632006743`*^-10", "4.796417306665577`*^-11", 
            "2.8582165070163276`*^-8"},
          {"300", "1.2232158704677153`*^-14", "4.3995482926402604`*^-15", 
            "2.6216651598754736`*^-12"},
          {"400", "1.1219778189477046`*^-18", "4.035424775252529`*^-19", 
            "2.404685850415291`*^-16"},
          {"500", "1.0291185160791492`*^-22", "3.701437128650752`*^-23", 
            "2.2056645783962446`*^-20"},
          {"600", "9.439446143850621`*^-27", "3.395091613337536`*^-27", 
            "2.023115090614056`*^-24"},
          {"700", "8.658200402618308`*^-31", "3.114100459443013`*^-31", 
            "1.8556741174333394`*^-28"},
          {"800", "7.941613635977645`*^-35", "2.8563652401627873`*^-35", 
            "1.7020912186794174`*^-32"},
          {"900", "7.284334412536823`*^-39", "2.6199612027523553`*^-39", 
            "1.56121944553102`*^-36"},
          {"1000", "6.681454206452614`*^-43", "2.4031228945856413`*^-43", 
            "1.4320067751687853`*^-40"},
          {"2000", "0", "0", "0"},
          {"3000", "0", "0", "0"},
          {"4000", "0", "0", "0"},
          {"5000", "0", "0", "0"},
          {"6000", "0", "0", "0"},
          {"7000", "0", "0", "0"},
          {"8000", "0", "0", "0"},
          {"9000", "0", "0", "0"},
          {"10000", "0", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nlast intake", 
          "Urine\n24 hours", "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
  CellLabel->"Out[17]//TableForm="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Injection\",ShowReport\[Rule] \"GraphicReport\"\
\>", "SubsubsectionIcon"],

Cell[TextData[StyleBox["We chose the day 180 as the upper limit to be \
represented ", "Theorem"]], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Injection\>", \ "\<Acute\>", "\<GraphicReport\>", 1, fn1, 
      180, lambda]\)], "Input",
  CellLabel->"In[18]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.616444 0.0572293 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .10138 -46.5 -6.6875 ]
[-0.0125 .10138 0 6.6875 ]
[-0.0125 .21584 -46.5 -6.625 ]
[-0.0125 .21584 0 6.625 ]
[-0.0125 .3303 -46 -6.28125 ]
[-0.0125 .3303 0 6.28125 ]
[-0.0125 .44476 -34 -6.28125 ]
[-0.0125 .44476 0 6.28125 ]
[-0.0125 .55921 -22 -6.28125 ]
[-0.0125 .55921 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10138 m
.00625 .10138 L
s
gsave
-0.0125 .10138 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .21584 m
.00625 .21584 L
s
gsave
-0.0125 .21584 -107.5 -10.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.500 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.313 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
105.000 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .3303 m
.00625 .3303 L
s
gsave
-0.0125 .3303 -107 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00001) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .44476 m
.00625 .44476 L
s
gsave
-0.0125 .44476 -95 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .55921 m
.00625 .55921 L
s
gsave
-0.0125 .55921 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .04868 m
.00375 .04868 L
s
0 .06485 m
.00375 .06485 L
s
0 .07457 m
.00375 .07457 L
s
0 .08153 m
.00375 .08153 L
s
0 .08697 m
.00375 .08697 L
s
0 .09143 m
.00375 .09143 L
s
0 .0952 m
.00375 .0952 L
s
0 .09848 m
.00375 .09848 L
s
0 .16314 m
.00375 .16314 L
s
0 .17931 m
.00375 .17931 L
s
0 .18903 m
.00375 .18903 L
s
0 .19599 m
.00375 .19599 L
s
0 .20143 m
.00375 .20143 L
s
0 .20589 m
.00375 .20589 L
s
0 .20966 m
.00375 .20966 L
s
0 .21294 m
.00375 .21294 L
s
0 .2776 m
.00375 .2776 L
s
0 .29377 m
.00375 .29377 L
s
0 .30348 m
.00375 .30348 L
s
0 .31045 m
.00375 .31045 L
s
0 .31589 m
.00375 .31589 L
s
0 .32034 m
.00375 .32034 L
s
0 .32412 m
.00375 .32412 L
s
0 .3274 m
.00375 .3274 L
s
0 .39206 m
.00375 .39206 L
s
0 .40823 m
.00375 .40823 L
s
0 .41794 m
.00375 .41794 L
s
0 .42491 m
.00375 .42491 L
s
0 .43034 m
.00375 .43034 L
s
0 .4348 m
.00375 .4348 L
s
0 .43858 m
.00375 .43858 L
s
0 .44186 m
.00375 .44186 L
s
0 .50652 m
.00375 .50652 L
s
0 .52269 m
.00375 .52269 L
s
0 .5324 m
.00375 .5324 L
s
0 .53937 m
.00375 .53937 L
s
0 .5448 m
.00375 .5448 L
s
0 .54926 m
.00375 .54926 L
s
0 .55304 m
.00375 .55304 L
s
0 .55632 m
.00375 .55632 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Acute) show
99.000 12.813 moveto
(intake) show
141.000 12.813 moveto
(in) show
159.000 12.813 moveto
(t) show
171.000 12.813 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
183.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
189.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .60332 m
.06042 .59384 L
.08838 .58024 L
.13894 .5483 L
.20509 .49081 L
.23444 .45893 L
.26115 .42924 L
.2711 .41977 L
.28123 .41214 L
.29174 .40687 L
.30107 .40429 L
.31076 .40316 L
.31951 .40301 L
.32703 .40325 L
.3349 .4037 L
.3657 .40584 L
.37818 .40659 L
.39062 .40723 L
.40085 .40766 L
.41107 .408 L
.41665 .40815 L
.42258 .40827 L
.42782 .40836 L
.43257 .40841 L
.43539 .40844 L
.43803 .40845 L
.44036 .40846 L
.44287 .40846 L
.44555 .40846 L
.44836 .40844 L
.45072 .40843 L
.4533 .4084 L
.45784 .40834 L
.46191 .40827 L
.47076 .40806 L
.47823 .40781 L
.48577 .4075 L
.49904 .40679 L
.51058 .406 L
.53436 .40383 L
.55551 .40123 L
.57346 .39848 L
.60295 .39274 L
.65211 .37929 L
.69305 .36361 L
.72536 .34774 L
.75184 .33207 L
.77637 .3151 L
.79724 .29858 L
.8171 .2809 L
Mistroke
.83439 .26378 L
.84961 .24727 L
.86452 .22967 L
.87782 .2127 L
.89097 .19465 L
.90281 .17724 L
.91352 .16049 L
.92426 .14267 L
.93405 .12551 L
.94299 .109 L
.95205 .09142 L
.96037 .0745 L
.96882 .05652 L
.97619 .04013 L
Mfstroke
0 0 1 r
[ ] 0 setdash
.02381 .25493 m
.13894 .31377 L
.20509 .33968 L
.2577 .35531 L
.30107 .36506 L
.33772 .37128 L
.3667 .37502 L
.38932 .37723 L
.41107 .37881 L
.42166 .37939 L
.43106 .37979 L
.44084 .3801 L
.44612 .38022 L
.45081 .3803 L
.45313 .38033 L
.45556 .38035 L
.45783 .38037 L
.45987 .38038 L
.46224 .38038 L
.46477 .38038 L
.46713 .38037 L
.46927 .38036 L
.4731 .38032 L
.47524 .38029 L
.47721 .38026 L
.4811 .38018 L
.48524 .38007 L
.4924 .37984 L
.49894 .37957 L
.51059 .37895 L
.52332 .37805 L
.53436 .37708 L
.57035 .37262 L
.58806 .36961 L
.60327 .36656 L
.6526 .3533 L
.69364 .33768 L
.72602 .32181 L
.75256 .30609 L
.77713 .28905 L
.79803 .27246 L
.8179 .25469 L
.83521 .23749 L
.85045 .22089 L
.86538 .20319 L
.87869 .18612 L
.89064 .1697 L
.90256 .1522 L
.91334 .13536 L
.92415 .11744 L
Mistroke
.934 .10018 L
.94299 .08358 L
.9521 .0659 L
.96046 .04889 L
.96895 .03081 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[18]:=",
  ImageSize->{600, 294.25},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Injection\>", \ "\<Constant\>", "\<GraphicReport\>", 1, 
      fn1, 180, lambda]\)], "Input",
  CellLabel->"In[19]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.619334 0.085927 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .01784 -46.5 -6.625 ]
[-0.0125 .01784 0 6.625 ]
[-0.0125 .1897 -46 -6.28125 ]
[-0.0125 .1897 0 6.28125 ]
[-0.0125 .36155 -34 -6.28125 ]
[-0.0125 .36155 0 6.28125 ]
[-0.0125 .53341 -22 -6.28125 ]
[-0.0125 .53341 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01784 m
.00625 .01784 L
s
gsave
-0.0125 .01784 -107.5 -10.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.500 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.313 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
105.000 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .1897 m
.00625 .1897 L
s
gsave
-0.0125 .1897 -107 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00001) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .36155 m
.00625 .36155 L
s
gsave
-0.0125 .36155 -95 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .53341 m
.00625 .53341 L
s
gsave
-0.0125 .53341 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .11058 m
.00375 .11058 L
s
0 .13485 m
.00375 .13485 L
s
0 .14944 m
.00375 .14944 L
s
0 .1599 m
.00375 .1599 L
s
0 .16806 m
.00375 .16806 L
s
0 .17475 m
.00375 .17475 L
s
0 .18043 m
.00375 .18043 L
s
0 .18535 m
.00375 .18535 L
s
0 .28243 m
.00375 .28243 L
s
0 .30671 m
.00375 .30671 L
s
0 .32129 m
.00375 .32129 L
s
0 .33175 m
.00375 .33175 L
s
0 .33992 m
.00375 .33992 L
s
0 .34661 m
.00375 .34661 L
s
0 .35228 m
.00375 .35228 L
s
0 .3572 m
.00375 .3572 L
s
0 .45428 m
.00375 .45428 L
s
0 .47856 m
.00375 .47856 L
s
0 .49315 m
.00375 .49315 L
s
0 .50361 m
.00375 .50361 L
s
0 .51177 m
.00375 .51177 L
s
0 .51846 m
.00375 .51846 L
s
0 .52413 m
.00375 .52413 L
s
0 .52906 m
.00375 .52906 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Constant) show
117.000 12.813 moveto
(intake) show
153.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .58398 m
.06042 .59355 L
.08838 .59795 L
.1161 .60048 L
.13894 .60168 L
.15779 .60227 L
.17363 .60257 L
.18958 .60277 L
.20509 .60288 L
.21944 .60294 L
.23372 .60297 L
.24625 .60299 L
.25701 .603 L
.26883 .60301 L
.2752 .60301 L
.28092 .60301 L
.30107 .60302 L
.33501 .60303 L
.36579 .60304 L
.41107 .60306 L
.45102 .60309 L
.48098 .60311 L
.53436 .60316 L
.6058 .60323 L
.65542 .60327 L
.69308 .60329 L
.70978 .6033 L
.72615 .60331 L
.7414 .60331 L
.75476 .60331 L
.76709 .60331 L
.7778 .60332 L
.78805 .60332 L
.79874 .60332 L
.80824 .60332 L
.81796 .60332 L
.82683 .60332 L
.83574 .60332 L
.84369 .60332 L
.8508 .60332 L
.8584 .60332 L
.86504 .60332 L
.87166 .60332 L
.87857 .60332 L
.88494 .60332 L
.89145 .60332 L
.8973 .60332 L
.90262 .60332 L
.90833 .60332 L
.9134 .60332 L
Mistroke
.91846 .60332 L
.92382 .60332 L
.92877 .60332 L
.93391 .60332 L
.93901 .60332 L
.94368 .60332 L
.94822 .60332 L
.9523 .60332 L
.95637 .60332 L
.96073 .60332 L
.96476 .60332 L
.96898 .60332 L
.97272 .60332 L
.97619 .60332 L
Mfstroke
0 0 1 r
[ ] 0 setdash
.02381 .01472 m
.20509 .18919 L
.30107 .25722 L
.41107 .31383 L
.48498 .34133 L
.53436 .35551 L
.60287 .36986 L
.63172 .37411 L
.65536 .37686 L
.67446 .37863 L
.69343 .38002 L
.71037 .38099 L
.72677 .38171 L
.74071 .38219 L
.75461 .38255 L
.76768 .3828 L
.77929 .38297 L
.79007 .38309 L
.79954 .38316 L
.80955 .38323 L
.81819 .38327 L
.82671 .3833 L
.8355 .38332 L
.84355 .38334 L
.85168 .38335 L
.85895 .38336 L
.86548 .38336 L
.87248 .38337 L
.87863 .38337 L
.88474 .38337 L
.89118 .38337 L
.8971 .38337 L
.90319 .38337 L
.90866 .38337 L
.91365 .38337 L
.91901 .38337 L
.92378 .38337 L
.92854 .38337 L
.93361 .38337 L
.93829 .38337 L
.94316 .38337 L
.94799 .38337 L
.95243 .38337 L
.95675 .38337 L
.96063 .38337 L
.9645 .38337 L
.96867 .38337 L
.97233 .38337 L
.97619 .38337 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[19]:=",
  ImageSize->{600, 294.25},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
        element, "\<Injection\>", \ "\<Continuous\>", "\<GraphicReport\>", 
        inputs1, fn1, 180, lambda] // Chop\)], "Input",
  CellLabel->"In[20]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.618325 0.061901 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .12312 -46.5 -6.6875 ]
[-0.0125 .12312 0 6.6875 ]
[-0.0125 .24692 -46.5 -6.6875 ]
[-0.0125 .24692 0 6.6875 ]
[-0.0125 .37072 -40 -6.28125 ]
[-0.0125 .37072 0 6.28125 ]
[-0.0125 .49452 -28 -6.28125 ]
[-0.0125 .49452 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12312 m
.00625 .12312 L
s
gsave
-0.0125 .12312 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .24692 m
.00625 .24692 L
s
gsave
-0.0125 .24692 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .37072 m
.00625 .37072 L
s
gsave
-0.0125 .37072 -101 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0001) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .49452 m
.00625 .49452 L
s
gsave
-0.0125 .49452 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .06612 m
.00375 .06612 L
s
0 .08361 m
.00375 .08361 L
s
0 .09412 m
.00375 .09412 L
s
0 .10165 m
.00375 .10165 L
s
0 .10753 m
.00375 .10753 L
s
0 .11235 m
.00375 .11235 L
s
0 .11644 m
.00375 .11644 L
s
0 .11998 m
.00375 .11998 L
s
0 .18992 m
.00375 .18992 L
s
0 .20741 m
.00375 .20741 L
s
0 .21792 m
.00375 .21792 L
s
0 .22545 m
.00375 .22545 L
s
0 .23133 m
.00375 .23133 L
s
0 .23615 m
.00375 .23615 L
s
0 .24024 m
.00375 .24024 L
s
0 .24379 m
.00375 .24379 L
s
0 .31372 m
.00375 .31372 L
s
0 .33121 m
.00375 .33121 L
s
0 .34172 m
.00375 .34172 L
s
0 .34925 m
.00375 .34925 L
s
0 .35513 m
.00375 .35513 L
s
0 .35995 m
.00375 .35995 L
s
0 .36404 m
.00375 .36404 L
s
0 .36759 m
.00375 .36759 L
s
0 .43752 m
.00375 .43752 L
s
0 .45501 m
.00375 .45501 L
s
0 .46552 m
.00375 .46552 L
s
0 .47306 m
.00375 .47306 L
s
0 .47894 m
.00375 .47894 L
s
0 .48376 m
.00375 .48376 L
s
0 .48784 m
.00375 .48784 L
s
0 .49139 m
.00375 .49139 L
s
0 .56133 m
.00375 .56133 L
s
0 .57882 m
.00375 .57882 L
s
0 .58932 m
.00375 .58932 L
s
0 .59686 m
.00375 .59686 L
s
0 .60274 m
.00375 .60274 L
s
0 .60756 m
.00375 .60756 L
s
0 .61165 m
.00375 .61165 L
s
0 .61519 m
.00375 .61519 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Continuous) show
129.000 12.813 moveto
(intake) show
165.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .59486 m
.06042 .60086 L
.08838 .60295 L
.1161 .60332 L
.13894 .60267 L
.15779 .60161 L
.17363 .60043 L
.20509 .59735 L
.25791 .59028 L
.30107 .58264 L
.3616 .5684 L
.41107 .55276 L
.48481 .52046 L
.53436 .49133 L
.60255 .4438 L
.65487 .41143 L
.69419 .39125 L
.72541 .3742 L
.75367 .35614 L
.77729 .33849 L
.79945 .31947 L
.81854 .30099 L
.83519 .28309 L
.8514 .26398 L
.86575 .24553 L
.87857 .22775 L
.8913 .20881 L
.90277 .19056 L
.91423 .17115 L
.92462 .15245 L
.9341 .13445 L
.94367 .1153 L
.95243 .09686 L
.96048 .07913 L
.96868 .06024 L
.97619 .04221 L
s
0 0 1 r
[ ] 0 setdash
.02381 .18641 m
.13894 .26912 L
.20509 .30944 L
.30107 .35469 L
.36239 .37516 L
.41107 .38684 L
.43247 .3907 L
.45317 .39367 L
.47079 .39561 L
.47862 .39629 L
.48567 .39681 L
.49228 .39721 L
.49812 .3975 L
.5044 .39773 L
.50777 .39783 L
.51092 .3979 L
.51389 .39794 L
.51701 .39797 L
.51991 .39798 L
.5225 .39798 L
.52407 .39797 L
.5255 .39796 L
.52707 .39794 L
.5287 .39792 L
.53142 .39786 L
.53436 .39779 L
.53963 .39761 L
.5452 .39736 L
.5549 .39676 L
.56388 .39603 L
.57182 .39523 L
.58864 .39305 L
.60496 .39029 L
.63121 .38441 L
.65285 .37814 L
.69164 .36332 L
.72549 .34616 L
.75308 .32885 L
.77619 .31176 L
.79796 .29328 L
.81673 .27529 L
.83477 .25605 L
.85062 .23743 L
.86467 .21946 L
.87853 .20031 L
.89095 .18185 L
.90215 .16408 L
.91337 .14516 L
.92355 .12693 L
.93379 .10755 L
Mistroke
.94314 .08888 L
.95171 .07092 L
.96041 .05181 L
.96841 .0334 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[20]:=",
  ImageSize->{600, 294.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;^0001Ka000`40O003h00Oogooogool7oo003o
OoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogoo
l7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00
ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomo
oo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool0
0?mooomooo1oo`00Fgoo1@00=7oo1@00B7oo1000<Woo1@000goo1000;Goo1@0017oo1000@Goo1000
17oo1000:Woo1@000goo100017oo100097oo1@0017oo100017oo1000cGoo001MOol00`00Oomoo`0d
Ool01@00Oomoogoo0000Agoo00<007ooOol00Woo00<007ooOol0<Goo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol0:Woo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo03eoo`03
001oogoo009oo`04001oogoo0004Ool00`00Oomoo`0YOol00`00Oomoo`02Ool00`00Oomoo`02Ool0
1000Oomoo`0017oo00<007ooOol08Goo00D007ooOomoo`0000=oo`03001oogoo009oo`04001oogoo
0004Ool00`00Oomoo`3:Ool005eoo`03001oogoo03Eoo`03001oogoo04eoo`03001oogoo035oo`03
001oogoo009oo`03001oogoo009oo`03001oogoo02]oo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo049oo`04001oogoo0004Ool00`00Oomoo`0YOol00`00Oomoo`02Ool00`00Oomoo`02Ool0
1000Oomoo`0017oo00<007ooOol08Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol000Ao
o`03001oogoo0<Yoo`00GGoo00<007ooOol0=Woo00<007ooOol0C7oo00<007ooOol0<Goo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol0;7oo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool0@Woo00@007ooOol000Aoo`03001oogoo02Uoo`03001oogoo009oo`03001oogoo009oo`04001o
ogoo0004Ool00`00Oomoo`0SOol00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<0
07ooOol0bWoo001MOol00`00Oomoo`0gOol00`00Oomoo`17Ool4000dOol00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`0]Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0nOol40003
Ool00`00Oomoo`02Ool00`00Oomoo`0YOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`00
17oo00<007ooOol097oo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo
0<Yoo`00GGoo00<007ooOol0>7oo00<007ooOol0AWoo00<007ooOol0=Goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol0;Woo00D007ooOomoo`0000Aoo`03001oogoo03ioo`03001oogoo00Ao
o`03001oogoo009oo`03001oogoo02Uoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004
Ool00`00Oomoo`0UOol01@00Oomoogoo000017oo00@007ooOol000Aoo`03001oogoo0<Yoo`00Fgoo
0`00=Woo00D007ooOomoo`0004Qoo`03001oogoo03=oo`<000Aoo`03001oogoo009oo`03001oogoo
02Yoo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0nOol00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Oomoo`0WOol30004Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol0
8Goo00D007ooOomoo`0000=oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`3:Ool005eo
o`03001oogoo03Eoo`<004Uoo`D003=oo`03001oogoo00=oo`@002ioo`<000Eoo`@0045oo`D000=o
o`@002aoo`03001oogoo00=oo`@000Aoo`@002Eoo`<000Eoo`@000Aoo`@00<eoo`00ogooogool7oo
003oOoooOoo`Ool00?mooomooo1oo`00ogooogoo>goo0`00/Woo003oOoooOolmOol00`00Oomoo`2`
Ool00?mooomoob]oo`<00003Ool00000009oo`<00003Ool0000000Aoo`03001oogoo009oo`D00:Uo
o`00ogooogoo:Woo00@007ooOomoo`80009oo`04001oogooOol20004Ool00`00Ool00003Ool00`00
Oomoo`02Ool00`00Oomoo`2VOol00?mooomoobYoo`03001oogoo009oo`04001oogoo0004Ool00`00
Oomoo`02Ool00`00Ool00008Ool00`00Oomoo`2VOol0059oool00<T000ioo`03001oogoo009oo`04
001oogooOol50003Ool01@00Oomoogoo00000goo1000ZGoo001BOol00`00Oomoo`08Ool00`00Oomo
o`0fOol00`00Oomoo`0OOol00`00Oomoo`0EOol00`00Oomoo`0@Ool00`00Oomoo`0<Ool00`00Oomo
o`0:Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0gOol00`00Oomo
o`0NOol00`00Oomoo`0EOol00`00Oomoo`0@Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomo
o`08Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0gOol00`00Oomoo`0>Ool01000Oomo
ogoo0P000Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`04001oogoo0004Ool00`00Oomoo`2V
Ool0059oo`03001oogoo00Qoo`03001oogoo03Ioo`03001oogoo04Yoo`03001oogoo03Moo`03001o
ogoo03Moo`03001oogoo04Uoo`03001oogoo03Moo`03001oogoo03Moo`03001oogoo00moo`<00003
Ool007oo009oo`@000=oo`<00004Ool000000002Ool5002XOol0059oo`03001oogoo00Qoo`03001o
ogoo03Ioo`03001oogoo04Yoo`03001oogoo03Moo`03001oogoo03Moo`03001oogoo04Uoo`03001o
ogoo03Moo`03001oogoo03Moo`03001oogoo01=oo`03001oogoo0;ioo`00DWoo00<007ooOol0ogoo
f7oo0P00`7oo001BOol00`00Oomoo`3oOoooOonKOol0059oo`03001oogoo0?mookYoo`0301moogoo
0=eoo`00DWoo00<007ooOol0ogoo^Woo00<07gooOol0gGoo001BOol00`00Oomoo`3oOoniOol00`0O
Oomoo`3NOol0059oo`03001oogoo0?mookUoo`0301moogoo0=ioo`00DWoo00<007ooOol0ogoo^7oo
00<07gooOol0ggoo001BOol00`00Oomoo`3oOonhOol00`0OOomoo`3OOol0059oo`03001oogoo0?mo
okMoo`0301moogoo0>1oo`00DWoo00<007ooOol0ogoo]goo00<07gooOol0h7oo001BOol00`00Oomo
o`3oOonfOol00`0OOomoo`3QOol0059oo`03001oogoo0?mookIoo`0301moogoo0>5oo`00DWoo00<0
07ooOol0ogoo]Woo00<07gooOol0hGoo001BOol00`00Oomoo`3oOoneOol00`0OOomoo`3ROol0059o
o`03001oogoo0?mookEoo`0301moogoo0>9oo`00DWoo00<007ooOol0ogoo]7oo00<07gooOol0hgoo
001BOol00`00Oomoo`3oOondOol00`0OOomoo`02Ool00g`0Oomoo`3NOol0059oo`03001oogoo0?mo
okAoo`0301moogoo009oo`03O01oogoo0=ioo`00DWoo00<007ooOol0ogoo/goo00<07gooOol00Woo
00=l07ooOol0ggoo001BOol00`00Oomoo`3oOoncOol00`0OOomoo`02Ool00g`0Oomoo`3OOol0059o
o`03001oogoo0?mook=oo`0501moogooOoml003ROol0059oo`03001oogoo0?mook9oo`0301moogoo
009oo`03O01oogoo0>1oo`00DWoo00<007ooOol0ogoo/Woo00<07gooOol0iGoo001BOol00`00Oomo
o`3oOonaOol00`0OOomoo`3VOol0059oo`03001oogoo0?mook5oo`0301moogoo0>Ioo`00DWoo00<0
07ooOol0ogoo/7oo00<07gooOol0igoo001BOol2003oOonaOol00`0OOomoo`02Ool00g`0Oomoo`3R
Ool0059oo`03001oogoo0?moojmoo`0301moogoo009oo`03O01oogoo0>=oo`00DWoo00<007ooOol0
ogoo[goo00<07gooOol00Woo00=l07ooOol0hgoo001BOol00`00Oomoo`3oOon^Ool00`0OOomoo`02
Ool00g`0Oomoo`3TOol0059oo`03001oogoo0?moojioo`0301moogoo009oo`03O01oogoo0>Aoo`00
DWoo00<007ooOol0ogoo[Goo00<07gooOol0jWoo001BOol00`00Oomoo`3oOon]Ool00`0OOomoo`3Z
Ool0059oo`03001oogoo0?moojaoo`0301moogoo0>]oo`00DWoo0P00ogoo[Goo00<07gooOol0jgoo
001BOol00`00Oomoo`3oOon[Ool00`0OOomoo`03Ool00g`0Oomoo`3VOol0059oo`03001oogoo0?mo
oj]oo`0301moogoo009oo`03O01oogoo0>Moo`00DWoo00<007ooOol0ogooZgoo00<07gooOol00Woo
00=l07ooOol0igoo001BOol2003oOon[Ool00`0OOomoo`02Ool00g`0Oomoo`3XOol0059oo`03001o
ogoo0?moojYoo`0301moogoo009oo`03O01oogoo0>Qoo`00DWoo00<007ooOol0ogooZGoo00<07goo
Ool0kWoo001BOol00`00Oomoo`3oOonYOol00`0OOomoo`3^Ool0059oo`800?moojUoo`0301moogoo
0>moo`00DWoo00<007ooOol0ogooZ7oo00<07gooOol0kgoo001BOol00`00Oomoo`3oOonWOol00`0O
Oomoo`03Ool00g`0Oomoo`3ZOol0059oo`800?moojQoo`0301moogoo009oo`03O01oogoo0>]oo`00
DWoo00<007ooOol0ogooYWoo00<07gooOol00goo00=l07ooOol0jgoo001BOol2003oOonWOol00`0O
Oomoo`02Ool00g`0Oomoo`3/Ool0059oo`03001oogoo0?moojEoo`0301moogoo00=oo`03O01oogoo
0>aoo`005Woo1@0017oo0P001Woo00D007ooOomoo`0000Eoo`D000=oo`@001Eoo`800?moojEoo`03
01moogoo0?=oo`0067oo00<007ooOol017oo0P001goo00<007oo000027oo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol04Woo0P00ogooYGoo00<07gooOol0DWooS@0057oo000HOol00`00Oomo
o`0>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomo
o`3oOonSOol00`0OOomoo`1COon=000DOol001Qoo`03001oogoo00eoo`03001oo`0000Qoo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo019oo`@00?mooj9oo`0301moogoo05=oohd001Aoo`00
67oo00<007ooOol037oo00D007ooOomoo`0000Moo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo019oo`03001oogoo0?mooj9oo`0301moogoo00Aoo`03O01oogoo04eoohd001Aoo`0067oo00<0
07ooOol067oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol02Goo00<0
07ooOol0ogooXGoo00<07gooOol017oo00=l07ooOol0B7ooT`0057oo000FOol3000HOol30004Ool0
0`00Oomoo`02Ool00`00Ool000030002Ool00`00Ool0000:Ool00`00Oomoo`3oOonQOol00`0OOomo
o`04Ool00g`0Oomoo`18Ool00`00Oomoo`2:Ool6000DOol001Qoo`03001oogoo01Qoo`03001oogoo
00=oo`@000Qoo`03001oo`0000Yoo`03001oogoo0?mooj1oo`0301moogoo00Aoo`03O01oogoo04Uo
o`03001oogoo08Yoo`H001Aoo`00AWoo00<007ooOol02Goo00<007ooOol0ogooX7oo00<07gooOol0
17oo00=l07ooOol0BGoo00<007ooOol0RWoo1P0057oo0015Ool00`00Ool0000:Ool00`00Oomoo`3o
OonOOol00`0OOomoo`1AOol00`00Oomoo`2:Ool6000DOol004Ioo`03001oogoo00Uoo`03001oogoo
0?mooimoo`0301moogoo055oo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogooWWoo00<0
7gooOol0DWoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOonNOol00`0OOomoo`1BOol0
0`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?mooieoo`0301moogoo00Aoo`03O01oogoo04ao
o`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogooW7oo00<07gooOol017oo00=l07ooOol0
CGoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOonLOol00`0OOomoo`04Ool00g`0Oomo
o`1=Ool00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?mooi]oo`0301moogoo00Aoo`03O01o
ogoo04ioo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogooVWoo00<07gooOol01Goo00=l
07ooOol0CWoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOonJOol00`0OOomoo`1FOol0
0`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?mooiUoo`0301moogoo05Moo`03001oogoo08Yo
o`H001Aoo`00DWoo00<007ooOol0ogooVGoo00<07gooOol0Egoo00<007ooOol0RWoo1P0057oo001B
Ool00`00Oomoo`3oOonHOol00`0OOomoo`1HOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo
0?mooiMoo`0301moogoo00Eoo`03O01oogoo055oo`03001oogoo08Yoo`H001Aoo`00DWoo00<007oo
Ool0ogooUgoo00<07gooOol01Goo00=l07ooOol0DGoo00<007ooOol0RWoo1P0057oo001BOol00`00
Oomoo`3oOonFOol00`0OOomoo`05Ool00g`0Oomoo`1BOol00`00Oomoo`2:Ool6000DOol0059oo`03
001oogoo0?mooiEoo`0301moogoo00Ioo`03O01oogoo059oo`03001oogoo08Yoo`H001Aoo`00DWoo
00<007ooOol0ogooUGoo00<07gooOol01Goo00=l07ooOol0Dgoo00<007ooOol0RWoo1P0057oo001B
Ool00`00Oomoo`3oOonDOol00`0OOomoo`1LOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo
0?mooiAoo`0301moogoo05aoo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogooTgoo00<0
7gooOol0GGoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOonBOol00`0OOomoo`05Ool0
0g`0Oomoo`1FOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo00Qoo`0301moogoo0?moohMo
o`0301moogoo00Eoo`03O01oogoo05Ioo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol02Goo
0P0OogooQWoo00<07gooOol01Goo00=l07ooOol0Egoo00<007ooOol0RWoo1P0057oo001BOol2000<
Ool00`0OOomoo`3oOon2Ool00`0OOomoo`06Ool00g`0Oomoo`1GOol00`00Oomoo`0mOol60002Ool2
0002Ool20003Ool40003Ool50004Ool50004Ool30004Ool50003Ool40003Ool3000017oo00000000
1Woo1P0057oo001BOol00`00Oomoo`0<Ool00`0OOomoo`3oOon1Ool00`0OOomoo`05Ool00g`0Oomo
o`1HOol00`00Oomoo`0nOol01@00Oomoogoo00000goo00@007ooOol000=oo`03001oogoo009oo`05
001oogooOol00006Ool00`00Oomoo`06Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007oo
Ool00Woo00D007ooOomoo`0000=oo`03001oogoo00Eoo`H001Aoo`00DWoo00<007ooOol03Goo0P0O
ogooP7oo00<07gooOol0HGoo00<007ooOol0?Woo00<007ooOol01Woo0P0017oo00<007ooOol01Woo
00<007ooOol017oo00<007ooOol01Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol00Woo
00D007ooOomoo`0000=oo`03001oogoo00Eoo`H001Aoo`00DWoo00<007ooOol03goo00<07gooOol0
ogooO7oo00<07gooOol0HWoo00<007ooOol0?Woo00<007oo00001Woo0P0017oo00<007ooOol01Woo
00<007ooOol017oo1P000goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol00Woo00D007oo
Oomoo`0000=oo`03001oogoo00Eoo`H001Aoo`00DWoo00<007ooOol047oo00<07gooOol0ogooNgoo
00<07gooOol0HWoo00<007ooOol0?Woo0`001Goo00@007ooOol000=oo`04001oogooOol20003Ool2
0005Ool00`00Oomoo`02Ool01@00Oomoogoo00002Goo00<007ooOol00Woo00<007ooOol00Woo00@0
07ooOomoo`80009oo`03001oogoo00Eoo`H001Aoo`00DWoo00<007ooOol04Goo0P0OogooNWoo00<0
7gooOol0Hgoo00<007ooOol0?Woo00<007oo000017oo0P000Woo0P000goo0`0000Aoo`00Oomoo`80
0004Ool000000003Ool40003Ool50004Ool30005Ool40003Ool200000goo00000008Ool6000DOol0
059oo`03001oogoo01=oo`0301moogoo0?moogIoo`0301moogoo00Ioo`03O01oogoo05]oo`03001o
ogoo03ioo`05001oogooOol0000SOol00`00Oomoo`0QOol6000DOol0059oo`03001oogoo01Aoo`03
01moogoo0?moogEoo`0301moogoo00Eoo`03O01oogoo05aoo`03001oogoo03eoo`H002eoo`03001o
ogoo01Moo`H001Aoo`00DWoo0P005Woo0P0OogooM7oo00<07gooOol01Woo00=l07ooOol0G7oo00<0
07ooOol0RWoo1P0057oo001BOol00`00Oomoo`0GOol00`0OOomoo`3oOom`Ool00`0OOomoo`06Ool0
0g`0Oomoo`1MOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo01Qoo`807omoog1oo`0301mo
ogoo00Eoo`03O01oogoo05ioo`03001oogoo00Yoo`Il00Aoo`Il00Aoo`Il00Aoo`Il05aoo`H001Ao
o`00DWoo00<007ooOol06Woo00<07gooOol0ogooK7oo00<07gooOol0Igoo00<007ooOol0RWoo1P00
57oo001BOol00`00Oomoo`0KOol00`0OOomoo`3oOomZOol00`0OOomoo`1XOol00`00Oomoo`2:Ool6
000DOol0059oo`8001eoo`807omoofYoo`0301moogoo06Qoo`03001oogoo08Yoo`H001Aoo`00DWoo
00<007ooOol07Woo00<07gooOol0ogooIWoo00<07gooOol01Woo00=l07ooOol0H7oo00<007ooOol0
RWoo1P0057oo001BOol00`00Oomoo`0OOol00`0OOomoo`3oOomTOol00`0OOomoo`06Ool00g`0Oomo
o`1QOol00`00Oomoo`2:Ool6000DOol0059oo`80025oo`807omoof=oo`0301moogoo00Ioo`03O01o
ogoo069oo`03001oogoo03moo`<000=oo`D000Aoo`D0009oo`<00004Ool000000002Ool5000WOol6
000DOol0059oo`03001oogoo029oo`0301moogoo0?moof1oo`0301moogoo00Eoo`03O01oogoo06=o
o`03001oogoo03ioo`05001oogooOol00003Ool00`00Oomoo`07Ool00`00Oomoo`03Ool01@00Oomo
ogoo00000Woo00<007ooOol0:Woo1P0057oo001BOol00`00Oomoo`0SOol201ooOomOOol00`0OOomo
o`06Ool00g`0Oomoo`1SOol00`00Oomoo`0nOol01@00Oomoogoo00000goo00<007ooOol01goo00<0
07ooOol00goo00D007ooOomoo`00009oo`03001oogoo02Yoo`H001Aoo`00DWoo0P009Woo00<07goo
Ool0ogooFgoo00<07gooOol0KGoo00<007ooOol0?Woo00D007ooOomoo`0000=oo`03001oogoo00Mo
o`03001oogoo00=oo`05001oogooOol00002Ool6000WOol6000DOol0059oo`03001oogoo02Ioo`03
01moogoo0?mooeUoo`0301moogoo06ioo`03001oogoo03ioo`05001oogooOol00003Ool20008Ool0
0`00Oomoo`03Ool20002Ool01000Oomoo`0017oo00<007ooOol09Goo1P0057oo001BOol2000XOol2
01ooOomIOol00`0OOomoo`1^Ool00`00Oomoo`0nOol01@00Oomoogoo00000Woo0P0000Aoo`000000
00=oo`<000Aoo`800003Ool0000000Aoo`@002Qoo`H001Aoo`00DWoo00<007ooOol0:Goo00<07goo
Ool0ogooEGoo00<07gooOol01Woo00=l07ooOol0IWoo00<007ooOol0?Woo00D007ooOomoo`0004Mo
o`H001Aoo`005Woo1@0017oo0P001Woo00D007ooOomoo`0000Eoo`D000=oo`@001Eoo`8002]oo`03
01moogoo0?mooe=oo`0301moogoo00Ioo`03O01oogoo06Moo`03001oogoo03eoo`<00004Ool00000
000<Ool00`00Oomoo`0gOol6000DOol001Qoo`03001oogoo00Aoo`8000Moo`03001oo`0000Qoo`03
001oogoo009oo`03001oogoo009oo`03001oogoo019oo`03001oogoo02]oo`807omooe9oo`0301mo
ogoo00Moo`03O01oogoo06Moo`03001oogoo08Yoo`H001Aoo`0067oo00<007ooOol03Woo00<007oo
Ool01goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol04Woo0P00;Woo00<07gooOol0ogoo
CWoo00<07gooOol01goo00=l07ooOol0J7oo00<007ooOol0RWoo1P0057oo000HOol00`00Oomoo`0=
Ool00`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0BOol4000]Ool00`0O
Oomoo`3oOom<Ool00`0OOomoo`07Ool00g`0Oomoo`1YOol00`00Oomoo`2:Ool6000DOol001Qoo`03
001oogoo00aoo`05001oogooOol00007Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0B
Ool00`00Oomoo`0_Ool201ooOom<Ool00`0OOomoo`1cOol00`00Oomoo`2:Ool6000DOol001Qoo`03
001oogoo01Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo019oo`03001oogoo035oo`03
01moogoo0?moodQoo`0301moogoo07Aoo`03001oogoo08Yoo`H001Aoo`005Woo0`0067oo0`0017oo
00<007ooOol00Woo00<007ooOol01Goo0P002goo00<007ooOol0<Woo0P0OogooAgoo00<07gooOol0
MGoo00<007ooOol0RWoo1P0057oo000HOol00`00Oomoo`0HOol00`00Oomoo`03Ool40002Ool40002
Ool00`00Ool0000:Ool00`00Oomoo`0dOol00`0OOomoo`3oOom3Ool00`0OOomoo`07Ool00g`0Oomo
o`1/Ool00`00Oomoo`2:Ool6000DOol004Eoo`03001oo`0000Yoo`03001oogoo03Eoo`0301moogoo
0?mood5oo`0301moogoo00Moo`03O01oogoo06eoo`03001oogoo08Yoo`H001Aoo`00AGoo0P002goo
00<007ooOol0=Woo0P0Oogoo@7oo00<07gooOol01goo00=l07ooOol0KWoo00<007ooOol0RWoo1P00
57oo0015Ool00`00Oomoo`0:Ool00`00Oomoo`0hOol00`0OOomoo`3oOollOol00`0OOomoo`08Ool0
0g`0Oomoo`1^Ool00`00Oomoo`2:Ool6000DOol004Ioo`8000Yoo`03001oogoo03Uoo`0301moogoo
0?moocYoo`0301moogoo00Qoo`03O01oogoo06moo`03001oogoo08Yoo`H001Aoo`00DWoo00<007oo
Ool0>Woo0P0Oogoo>Goo00<07gooOol0Ngoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`0l
Ool00`0OOomoo`3oOoleOol00`0OOomoo`1lOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo
03eoo`807omoocAoo`0301moogoo07eoo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0?goo
0P0Oogoo<Goo00<07gooOol02Goo00=l07ooOol0LWoo00<007ooOol0RWoo1P0057oo001BOol00`00
Oomoo`11Ool00`0OOomoo`3oOol]Ool00`0OOomoo`09Ool00g`0Oomoo`1cOol00`00Oomoo`2:Ool6
000DOol0059oo`03001oogoo049oo`807omoobaoo`0301moogoo00Uoo`03O01oogoo07Aoo`03001o
ogoo08Yoo`H001Aoo`00DWoo00<007ooOol0A7oo0P0Oogoo:Goo00<07gooOol02Goo00=l07ooOol0
MGoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`16Ool00`0OOomoo`3oOolUOol00`0OOomo
o`09Ool00g`0Oomoo`1fOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo04Moo`807omoobAo
o`0301moogoo08=oo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0BGoo0P0Oogoo8Goo00<0
7gooOol0Q7oo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`1;Ool00`0OOomoo`3oOolMOol0
0`0OOomoo`09Ool00g`0Oomoo`1iOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo04aoo`80
7omooaaoo`0301moogoo00Uoo`03O01oogoo07Yoo`03001oogoo08Yoo`H001Aoo`00DWoo00<007oo
Ool0CWoo0P0Oogoo6Goo00<07gooOol02Goo00=l07ooOol0Ngoo00<007ooOol0RWoo1P0057oo001B
Ool00`00Oomoo`1@Ool00`0OOomoo`3oOolEOol00`0OOomoo`0:Ool00g`0Oomoo`1kOol00`00Oomo
o`2:Ool6000DOol0059oo`03001oogoo055oo`807omooaAoo`0301moogoo00Yoo`03O01oogoo07ao
o`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0Dgoo0P0Oogoo4Goo00<07gooOol0RWoo00<0
07ooOol0RWoo1P0057oo001BOol00`00Oomoo`1EOol00`0OOomoo`3oOol=Ool00`0OOomoo`2;Ool0
0`00Oomoo`2:Ool6000DOol0059oo`03001oogoo05Ioo`807omoo`]oo`807hioo`03001oogoo08Yo
o`H001Aoo`00DWoo00<007ooOol0F7oo0P0Oogoo27oo00<07gooOol02goo00=l07ooOol0P7oo00<0
07ooOol0RWoo1P0057oo001BOol00`00Oomoo`1JOol201ooOol5Ool00`0OOomoo`0;Ool00g`0Oomo
o`21Ool00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo05aoo`807omoo`9oo`0301moogoo00Yo
o`9l08Aoo`03001oogoo08Yoo`H001Aoo`00DWoo0P00Ggoo0P0OoWoo00<07gooOol02Woo00=l07oo
Ool0Q7oo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`1POol201ojOol201nDOol00`00Oomo
o`2:Ool6000DOol0059oo`03001oogoo069oo`807oMoo`0301moogoo09Aoo`03001oogoo08Yoo`H0
01Aoo`00DWoo00<007ooOol0I7oo0P0Olgoo0P0OUgoo00<007ooOol0RWoo1P0057oo001BOol00`00
Oomoo`1VOol201o_Ool201l?Ool00g`0Oomoo`27Ool00`00Oomoo`2:Ool6000DOol0059oo`03001o
ogoo06Qoo`807naoo`0301moogoo00ioo`03O01oogoo08Qoo`03001oogoo08Yoo`H001Aoo`00DWoo
00<007ooOol0JWoo0P0Oj7oo0P0O3goo0W`0Rgoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomo
o`1/Ool201oUOol00`0OOomoo`0>Ool00g`0Oomoo`2;Ool00`00Oomoo`2:Ool6000DOol0059oo`80
06moo`807n5oo`807imoo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0L7oo0`0OgGoo00<0
7gooOol0Wgoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`1cOol201oIOol201l@Ool00g`0
Oomoo`2?Ool00`00Oomoo`0mOol60002Ool20002Ool20003Ool40003Ool50004Ool50004Ool30004
Ool50003Ool40003Ool3000017oo000000001Woo1P0057oo001BOol00`00Oomoo`1eOol201oFOol0
0`0OOomoo`0?Ool00g`0Oomoo`2@Ool00`00Oomoo`0nOol01@00Oomoogoo00000goo00@007ooOol0
00=oo`03001oogoo009oo`05001oogooOol00006Ool00`00Oomoo`06Ool01@00Oomoogoo00001Goo
00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00Eoo`H001Aoo`00
DWoo00<007ooOol0Mgoo0P0OdWoo0P0O4Goo00=l07ooOol0TGoo00<007ooOol0?Woo00<007ooOol0
1Woo0P0017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol01goo00<0
07ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00Eoo`H001Aoo`00DWoo
0P00NWoo0P0Ocgoo00<07gooOol03goo0W`0U7oo00<007ooOol0?Woo00<007oo00001Woo0P0017oo
00<007ooOol01Woo00<007ooOol017oo1P000goo00<007ooOol01goo00<007ooOol00Woo00<007oo
Ool00Woo00D007ooOomoo`0000=oo`03001oogoo00Eoo`H001Aoo`00DWoo00<007ooOol0Ngoo0P0O
bgoo0P0OZ7oo00<007ooOol0?Woo0`001Goo00@007ooOol000=oo`04001oogooOol20003Ool20005
Ool00`00Oomoo`02Ool01@00Oomoogoo00002Goo00<007ooOol00Woo00<007ooOol00Woo00@007oo
Oomoo`80009oo`03001oogoo00Eoo`H001Aoo`00DWoo00<007ooOol0OGoo0P0Ob7oo00<07gooOol0
Z7oo00<007ooOol0?Woo00<007oo000017oo0P000Woo0P000goo0`0000Aoo`00Oomoo`800004Ool0
00000003Ool40003Ool50004Ool30005Ool40003Ool200000goo00000008Ool6000DOol0059oo`03
001oogoo07moo`807lAoo`807a5oo`03O01oogoo09Moo`03001oogoo03ioo`05001oogooOol0000S
Ool00`00Oomoo`0QOol6000DOol0059oo`80089oo`807l1oo`807a9oo`03O01oogoo09Qoo`03001o
ogoo03eoo`H002eoo`03001oogoo01Moo`H001Aoo`00DWoo00<007ooOol0Pgoo0P0O_7oo0P0O4Woo
0W`0Vgoo00<007ooOol0RWoo1P0057oo001BOol20026Ool301ngOol201lCOol00g`0Oomoo`2KOol0
0`00Oomoo`2:Ool6000DOol0059oo`03001oogoo08Qoo`<07k9oo`807k=oo`03001oogoo00YoobH0
7eYoo`H001Aoo`00DWoo0P00S7oo0`0O[Goo0P0O]Goo00<007ooOol0RWoo1P0057oo001BOol00`00
Oomoo`2>Ool301nXOol201lEOol00g`0Oomoo`2OOol00`00Oomoo`2:Ool6000DOol0059oo`80099o
o`<07j9oo`<07aIoo`03O01oogoo0:1oo`03001oogoo08Yoo`H001Aoo`007goo10001Goo0P001Goo
100017oo100017oo100017oo1@001Woo00<007ooOol0U7oo100OW7oo0P0O5goo0W`0Xgoo00<007oo
Ool0RWoo1P0057oo000NOol00`00Oomoo`02Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`02Ool0
1000Oomoo`0017oo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo00Ioo`8009Uoo`<07iIo
o`<07aQoo`03O01oogoo0:=oo`03001oogoo08Yoo`H001Aoo`007Woo00<007ooOol00Woo00<007oo
Ool027oo00<007ooOol00Woo00@007ooOol000Aoo`04001oogoo0004Ool00`00Oomoo`03Ool00`00
Oomoo`06Ool4002JOol301nAOol201o1Ool00`00Oomoo`0mOol30006Ool300000goo00000002Ool5
0003Ool40004Ool300000goo00000002Ool5000OOol6000DOol001ioo`03001oogoo009oo`03001o
ogoo00Qoo`03001oogoo009oo`04001oogoo0004Ool01000Oomoo`0017oo00<007ooOol00goo00<0
07ooOol01Woo00<007ooOol0WWoo0`0OS7oo0P0O6Goo00=l07ooOol0Ygoo00<007ooOol0?Woo00<0
07ooOol017oo00@007ooOomoo`80009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0003
Ool20005Ool00`00Oomoo`0OOol6000DOol001ioo`03001oogoo009oo`03001oogoo00Qoo`03001o
ogoo009oo`04001oogoo0004Ool01000Oomoo`0017oo00<007ooOol00goo00<007ooOol01Woo00<0
07ooOol0XGoo0`0OQWoo0`0O6Woo00=l07ooOol0Z7oo00<007ooOol0?Woo00<007ooOol017oo00<0
07ooOol00Woo00@007ooOol000Moo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo01moo`H001Aoo`007Woo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00@0
07ooOol000Aoo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`2TOol4
01n0Ool201lKOol2O02[Ool00`00Oomoo`0nOol00`00Ool00005Ool50002Ool60002Ool00`00Oomo
o`06Ool50005Ool00`00Oomoo`0OOol6000DOol001ioo`03001oogoo009oo`03001oogoo00Qoo`03
001oogoo009oo`04001oogoo0004Ool01000Oomoo`0017oo00@007ooOomoo`<000Qoo`03001oogoo
0:Qoo`@07gUoo`<07a]oo`9l0:eoo`03001oogoo03ioo`<000Aoo`03001oogoo009oo`04001oogoo
0004Ool01000Oomoo`000goo0P000Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol07goo
1P0057oo000OOol4000<Ool40004Ool40004Ool40006Ool00`00Oomoo`06Ool00`00Oomoo`2/Ool3
01mcOol301o=Ool00`00Oomoo`0nOol00`00Ool00005Ool40004Ool40004Ool300000goo001oo`02
Ool40006Ool00`00Oomoo`0OOol6000DOol0059oo`03001oogoo0:moo`@07f]oo`@07aeoo`03O01o
ogoo0;1oo`03001oogoo03ioo`05001oogooOol0000UOol00`00Oomoo`0OOol6000DOol0059oo`03
001oogoo0;=oo`@07f=oo`@07b1oo`03O01oogoo0;5oo`03001oogoo03eoo`H002Aoo`80025oo`H0
01Aoo`00DWoo00<007ooOol0]goo1P0OEgoo1P0O8Woo0W`0]7oo00<007ooOol0RWoo1P0057oo001B
Ool00`00Oomoo`2mOol701m;Ool501lWOol00g`0Oomoo`2dOol00`00Oomoo`2:Ool6000DOol0059o
o`03001oogoo0<Aoo`D07d9oo`@07n=oo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0bGoo
1P0O=goo1@0O:goo00=l07ooOol0^Goo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3?Ool?
01lFOolB01l^Ool2O02lOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0=iooaH07cioo`9l
0;ioo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogoolgoo00<007ooOol0RWoo1P0057oo
001BOol00`00Oomoo`3oOoocOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?moobioo`03
O01oogoo0<9oo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogoo;7oo0W`0aGoo00<007oo
Ool0RWoo1P0057oo001BOol00`00Oomoo`3oOolZOol2O037Ool00`00Oomoo`2:Ool6000DOol0059o
o`03001oogoo0?mooo=oo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogoo9Goo00=l07oo
Ool0bgoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOolTOol00g`0Oomoo`3<Ool00`00
Oomoo`2:Ool6000DOol0059oo`03001oogoo0?moob9oo`9l0<moo`03001oogoo08Yoo`H001Aoo`00
DWoo00<007ooOol0ogoo8Goo00=l07ooOol0cgoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomo
o`3oOoocOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?mooo=oo`03001oogoo08Yoo`H0
01Aoo`00DWoo00<007ooOol0ogoo7Goo00=l07ooOol0dgoo00<007ooOol0RWoo1P0057oo001BOol0
0`00Oomoo`3oOolKOol2O03FOol00`00Oomoo`2:Ool00`00Oomoo`0GOol0059oo`03001oogoo0?mo
oaUoo`9l0=Qoo`03001oogoo08Yoo`03001oogoo01Moo`00DWoo00<007ooOol0ogoolgoo00<007oo
Ool0RWoo00<007ooOol05goo001BOol00`00Oomoo`3oOoocOol00`00Oomoo`2:Ool00`00Oomoo`0G
Ool0059oo`800?mooaEoo`03O01oogoo0=aoo`03001oogoo08Yoo`03001oogoo01Moo`00DWoo00<0
07ooOol0ogoo4Woo0W`0ggooSP006Goo001BOol00`00Oomoo`3oOol@Ool2O03oOon9Ool0059oo`03
001oogoo0?mooomooi]oo`00DWoo00<007ooOol0ogooogooVgoo001BOol00`00Oomoo`3oOol<Ool0
0g`0Oomoo`3oOon<Ool0059oo`03001oogoo0?moo`]oo`03O01oogoo0?mooheoo`00DWoo00<007oo
Ool0ogoo2Goo0W`0ogooT7oo001BOol2003oOol9Ool00g`0Oomoo`3oOon@Ool0059oo`03001oogoo
0?mooomooi]oo`00DWoo00<007ooOol0ogooogooVgoo001BOol00`00Oomoo`3oOol4Ool00g`0Oomo
o`3oOonDOol0059oo`800?moo`Aoo`03O01oogoo0?mooiEoo`00DWoo00<007ooOol0ogoo0Goo0W`0
ogooV7oo001BOol00`00Oomoo`3oOol00g`0Oomoo`3oOonHOol0059oo`03001oogoo0?mooomooi]o
o`00DWoo0P00ogooogooW7oo001BOol00`00Oomoo`3kOol00g`0Oomoo`3oOonLOol0059oo`03001o
ogoo0?Yoo`03O01oogoo0?mooieoo`00DWoo0P00nGoo0W`0ogooX7oo001BOol00`00Oomoo`3gOol0
0g`0Oomoo`3oOonPOol0059oo`800?mooomooiaoo`00DWoo00<007ooOol0lWoo00=l07ooOol0ogoo
YGoo001BOol2003bOol00g`0Oomoo`3oOonVOol002ioo`@000Eoo`8000Eoo`@000Aoo`D000Moo`80
0?5oo`03O01oogoo0?moojMoo`00;Goo00<007ooOol00Woo00<007ooOol00Woo0P0017oo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol0kWoo0W`0ogooZWoo000]Ool00`00
Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`07Ool4003o
OoooOonJOol002eoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo00Moo`03001oogoo0?mooomooi]oo`00;Goo00<007ooOol00Woo00<007ooOol027oo
00<007ooOol00Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol0jWoo00=l07ooOol0ogoo
[Goo000]Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`07Ool00`00Oomoo`3XOol2O03oOon`Ool002eoo`03001oogoo009oo`03001oogoo00Qoo`03
001oogoo009oo`04001oogooOol30009Ool00`00Oomoo`3VOol2O03oOonbOol002ioo`@000aoo`@0
00Ioo`03001oogoo00Moo`03001oogoo0?mooomooi]oo`00DWoo00<007ooOol0ogooogooVgoo001B
Ool00`00Oomoo`3QOol00g`0Oomoo`3oOonfOol0059oo`03001oogoo0=moo`9l0?mookUoo`00DWoo
00<007ooOol0gGoo0W`0ogoo^goo001BOol00`00Oomoo`3oOoooOonKOol0059oo`03001oogoo0?mo
oomooi]oo`00DWoo00<007ooOol0f7oo0W`0ogoo`7oo001BOol00`00Oomoo`3FOol2O03oOoo2Ool0
059oo`03001oogoo0=Aoo`9l0?moolAoo`00DWoo00<007ooOol0ogooogooVgoo001BOol00`00Oomo
o`3?Ool2O03oOoo9Ool0059oo`03001oogoo0<eoo`9l0?mool]oo`00DWoo00<007ooOol0bgoo0W`0
ogoocGoo001BOol00`00Oomoo`3oOoooOonKOol0059oo`03001oogoo0<Ioo`03O01oogoo0?moom5o
o`00DWoo00<007ooOol0a7oo0W`0ogooe7oo001BOol00`00Oomoo`32Ool2O03oOooFOol0059oo`03
001oogoo0?mooomooi]oo`00DWoo00<007ooOol0_Goo00=l07ooOol0ogoofWoo001BOol00`00Oomo
o`2kOol2O03oOooMOol0059oo`03001oogoo0;Uoo`9l0?moommoo`00DWoo00<007ooOol0/goo0W`0
ogooiGoo001BOol00`00Oomoo`2aOol2O03oOooWOol0059oo`03001oogoo0:moo`9l0?moonUoo`00
DWoo0P00Zgoo00=l07ooOol0ogookGoo001BOol00`00Oomoo`2XOol2O03oOoo`Ool0059oo`03001o
ogoo0:Ioo`9l0?mooo9oo`00DWoo00<007ooOol0X7oo0W`0ogoon7oo001BOol00`00Oomoo`2NOol2
O03oOoojOol0059oo`03001oogoo09aoo`9l0?moooaoo`00DWoo00<007ooOol0UGoo0g`0ogooogoo
0goo001BOol00`00Oomoo`2BOol3O03oOoooOol6Ool0059oo`8008eoo`9l0?mooomoo`eoo`00DWoo
00<007ooOol0RGoo0g`0ogooogoo3goo001BOol00`00Oomoo`22Ool3O03oOoooOolFOol0059oo`03
001oogoo07moo`=l0?mooomooaUoo`00DWoo00<007ooOol0N7oo0g`0ogooogoo87oo001BOol2001f
Ool3O03oOoooOolSOol0059oo`03001oogoo06]oo`Il0?mooomoobYoo`00DWoo00<007ooOol027oo
0W`0FWoo0g`0ogooogoo=7oo001BOol2000;Ool3O01<Ool4O004Ool3O03oOoooOolgOol0059oo`03
001oogoo015oo`=l03aoo`=l00Aoo`9l0?mooomood9oo`00DWoo00<007ooOol057oo0g`017oo0g`0
9Woo1G`017oo0g`0ogooogooBgoo001BOol2000OOol3O004Ool6O004Ool6O004Ool6O004Ool00g`0
Oomoo`3oOoooOomEOol0059oo`03001oogoo0?mooomooi]oo`00DWoo0P00ogooogooW7oo001BOol0
0`00Oomoo`3oOoooOonKOol0059oo`800?mooomooiaoo`00DWoo00<007ooOol0ogooogooVgoo001B
Ool2003oOoooOonLOol0059oo`03001oogoo0?mooomooi]oo`00ogooogool7oo003oOoooOoo`Ool0
0?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOooo
Ooo`Ool00?mooomooo1oo`00ogooogool7oo003hOol30004Ool40003Ool3000017oo000000000goo
0`0017oo1@000Woo0`0000Aoo`00000000=oo`800003Ool00000009oo`@000Eoo`800004Ool00000
Ool50007Ool50002Ool3000017oo000000000goo0`0017oo0`0000Aoo`00001oo`80009oo`<0009o
o`D00?moogQoo`00mgoo00D007ooOomoo`00009oo`03001oogoo009oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000=oo`03001o
ogoo0080009oo`03001oogoo009oo`05001oogooOol00002Ool20002Ool00`00Oomoo`02Ool00`00
Oomoo`06Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`04001oogoo
Ool20003Ool01000Oomoo`000goo00<007ooOol0ogooNgoo003fOol00`00Oomoo`05Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Uoo`03001oogoo00=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00Eo
o`03001oogoo00Ioo`03001oogoo00=oo`05001oogooOol00003Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo0?moog]oo`00mWoo00<007ooOol01Goo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00009Ool00`00Oomoo`03Ool01@00Oomo
ogoo00000goo00D007ooOomoo`00009oo`03001oogoo009oo`05001oogooOol00003Ool01000Oomo
ogoo10002Goo00<007ooOol00goo00D007ooOomoo`0000=oo`03001oogoo00Eoo`D000=oo`<000Ao
o`H00?moogQoo`00Egoo0`00W7oo00<007ooOol01Goo00<007ooOol00Woo00@007ooOomoo`80009o
o`05001oogooOol00009Ool00`00Oomoo`03Ool20002Ool01@00Oomoogoo00000goo00@007ooOol0
00Aoo`05001oogooOol00003Ool01000Oomoo`0017oo00<007ooOol01Woo00<007ooOol00goo0P00
0Woo00D007ooOomoo`0000Ioo`03001oogoo009oo`05001oogooOol00002Ool01@00Oomoogoo0000
17oo00<007ooOol0ogooMWoo001HOol00`00Oomoo`2KOol00`00Oomoo`06Ool40003Ool200000goo
00000003Ool50004Ool30004Ool200000goo00000003Ool20002Ool20003Ool40003Ool20002Ool2
0003Ool50006Ool30004Ool200000goo00000003Ool50004Ool40004Ool00`00Ool000030002Ool4
003oOomiOol004]oo`D000Aoo`<00003Ool007oo09eoo`05001oogooOol0000COol00`00Oomoo`18
Ool00`00Oomoo`0=Ool00`00Oomoo`3oOon2Ool004aoo`05001oogooOol00002Ool01000Oomoogoo
0P00Wgoo10007Goo00<007ooOol0<7oo00<007ooOol06Woo0P00ogooQ7oo001<Ool01@00Oomoogoo
00000Woo00<007ooOol00Woo00<007ooOol0ogooogooUGoo001<Ool01@00Oomoogoo00000Woo00<0
07ooOol00Woo00<007ooOol0ogooogooUGoo001<Ool40003Ool01000Oomoogoo0P00ogooogooUgoo
001<Ool01@00Oomoogoo00000goo0`0000=oo`000000ogooogooUWoo001<Ool01@00Oomoogoo0000
ogooogooWgoo001;Ool5003oOoooOonPOol00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool0
0?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOooo
Ooo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo
003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogoo
ogool7oo003oOoooOoo`Ool00001\
\>"],
  ImageRangeCache->{{{0, 749}, {366.813, 0}} -> {-1.06507, -0.648943, \
0.00442282, 0.00442282}, {{18.375, 583.625}, {358.063, 8.6875}} -> \
{-0.484085, -11.4081, 0.0065048, 0.044376}, {{583.625, 724.938}, {268.188, \
126.875}} -> {-14.9683, -2.1938, 0.0318446, 0.0265372}, {{595.375, 634.625}, \
{254, 206.938}} -> {-15.9524, -11.8034, 0.0334398, 0.108214}, {{595.375, \
634.625}, {188.063, 141}} -> {-15.9524, -17.5117, 0.0334398, 0.108214}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Injection\>", \ "\<MultiInputs\>", "\<GraphicReport\>", 
      inputs2, fn1, 180, lambda]\)], "Input",
  CellLabel->"In[21]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.567484 0.0581152 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .10256 -46.5 -6.6875 ]
[-0.0125 .10256 0 6.6875 ]
[-0.0125 .21879 -46.5 -6.6875 ]
[-0.0125 .21879 0 6.6875 ]
[-0.0125 .33502 -40 -6.28125 ]
[-0.0125 .33502 0 6.28125 ]
[-0.0125 .45125 -28 -6.28125 ]
[-0.0125 .45125 0 6.28125 ]
[-0.0125 .56748 -10 -6.28125 ]
[-0.0125 .56748 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10256 m
.00625 .10256 L
s
gsave
-0.0125 .10256 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .21879 m
.00625 .21879 L
s
gsave
-0.0125 .21879 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .33502 m
.00625 .33502 L
s
gsave
-0.0125 .33502 -101 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0001) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .45125 m
.00625 .45125 L
s
gsave
-0.0125 .45125 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .56748 m
.00625 .56748 L
s
gsave
-0.0125 .56748 -71 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .04905 m
.00375 .04905 L
s
0 .06547 m
.00375 .06547 L
s
0 .07533 m
.00375 .07533 L
s
0 .08241 m
.00375 .08241 L
s
0 .08793 m
.00375 .08793 L
s
0 .09245 m
.00375 .09245 L
s
0 .09629 m
.00375 .09629 L
s
0 .09962 m
.00375 .09962 L
s
0 .16528 m
.00375 .16528 L
s
0 .1817 m
.00375 .1817 L
s
0 .19156 m
.00375 .19156 L
s
0 .19864 m
.00375 .19864 L
s
0 .20416 m
.00375 .20416 L
s
0 .20868 m
.00375 .20868 L
s
0 .21252 m
.00375 .21252 L
s
0 .21585 m
.00375 .21585 L
s
0 .28151 m
.00375 .28151 L
s
0 .29793 m
.00375 .29793 L
s
0 .30779 m
.00375 .30779 L
s
0 .31487 m
.00375 .31487 L
s
0 .32039 m
.00375 .32039 L
s
0 .32492 m
.00375 .32492 L
s
0 .32875 m
.00375 .32875 L
s
0 .33208 m
.00375 .33208 L
s
0 .39774 m
.00375 .39774 L
s
0 .41416 m
.00375 .41416 L
s
0 .42403 m
.00375 .42403 L
s
0 .4311 m
.00375 .4311 L
s
0 .43662 m
.00375 .43662 L
s
0 .44115 m
.00375 .44115 L
s
0 .44498 m
.00375 .44498 L
s
0 .44831 m
.00375 .44831 L
s
0 .51397 m
.00375 .51397 L
s
0 .53039 m
.00375 .53039 L
s
0 .54026 m
.00375 .54026 L
s
0 .54733 m
.00375 .54733 L
s
0 .55285 m
.00375 .55285 L
s
0 .55738 m
.00375 .55738 L
s
0 .56121 m
.00375 .56121 L
s
0 .56454 m
.00375 .56454 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Multi) show
99.000 12.813 moveto
(Inputs) show
135.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .60332 m
.20509 .48946 L
.23623 .45627 L
.2498 .44206 L
.26149 .43118 L
.2715 .42369 L
.28154 .41831 L
.29109 .41514 L
.30107 .41345 L
.31022 .41288 L
.31516 .41282 L
.31957 .41287 L
.32783 .41312 L
.33536 .41346 L
.36608 .41496 L
.37752 .41542 L
.38897 .4158 L
.39525 .41597 L
.40077 .4161 L
.40617 .4162 L
.41107 .41627 L
.41625 .41633 L
.41893 .41635 L
.42177 .41637 L
.42469 .41638 L
.42742 .41638 L
.42984 .41638 L
.43243 .41637 L
.43704 .41634 L
.43933 .41632 L
.44182 .41629 L
.44613 .41623 L
.4501 .41615 L
.4594 .41593 L
.46754 .41566 L
.48465 .41488 L
.49747 .41408 L
.51055 .41307 L
.53436 .41069 L
.55504 .40797 L
.57199 .40526 L
.60516 .39853 L
.65547 .38405 L
.69357 .36893 L
.72693 .35213 L
.75417 .33552 L
.77703 .31929 L
.7986 .30184 L
.8172 .28494 L
.83511 .26689 L
Mistroke
.85084 .24945 L
.86481 .23265 L
.87858 .21475 L
.89093 .19749 L
.9032 .17915 L
.9143 .16147 L
.92438 .14446 L
.93452 .12636 L
.94378 .10892 L
.95227 .09216 L
.9609 .07431 L
.96883 .05713 L
.97619 .04052 L
Mfstroke
0 0 1 r
[ ] 0 setdash
.02381 .34052 m
.20509 .36285 L
.30107 .37762 L
.33536 .38165 L
.36608 .38447 L
.37932 .38544 L
.39101 .38617 L
.41107 .38712 L
.42093 .38745 L
.42637 .3876 L
.4312 .3877 L
.43616 .38778 L
.43884 .38781 L
.44135 .38784 L
.44572 .38786 L
.44815 .38787 L
.45038 .38787 L
.4546 .38785 L
.45849 .38782 L
.46191 .38778 L
.46554 .38773 L
.47345 .38755 L
.48043 .38734 L
.49442 .38673 L
.50863 .38587 L
.52239 .38478 L
.53436 .38362 L
.55537 .38107 L
.57328 .37834 L
.60275 .37261 L
.6518 .3591 L
.69268 .34328 L
.72495 .32727 L
.75139 .31143 L
.77591 .29427 L
.79676 .27757 L
.8166 .25967 L
.83388 .24236 L
.84908 .22566 L
.86399 .20784 L
.87729 .19067 L
.89043 .1724 L
.90226 .15479 L
.91297 .13784 L
.92371 .11981 L
.93349 .10244 L
.94242 .08573 L
.95148 .06794 L
.9598 .05082 L
.96824 .03262 L
Mistroke
.97603 .01509 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[21]:=",
  ImageSize->{600, 294.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;^0001Ka000`40O003h00Oogooogool7oo003o
OoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogoo
l7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00
ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomo
oo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool0
0?mooomooo1oo`00Fgoo1@00=7oo1@00B7oo1000<Woo1@000goo1000;Goo1@0017oo1000@Goo1000
17oo1000:Woo1@000goo100017oo100097oo1@0017oo100017oo1000cGoo001MOol00`00Oomoo`0d
Ool01@00Oomoogoo0000Agoo00<007ooOol00Woo00<007ooOol0<Goo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol0:Woo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo03eoo`03
001oogoo009oo`04001oogoo0004Ool00`00Oomoo`0YOol00`00Oomoo`02Ool00`00Oomoo`02Ool0
1000Oomoo`0017oo00<007ooOol08Goo00D007ooOomoo`0000=oo`03001oogoo009oo`04001oogoo
0004Ool00`00Oomoo`3:Ool005eoo`03001oogoo03Eoo`03001oogoo04eoo`03001oogoo035oo`03
001oogoo009oo`03001oogoo009oo`03001oogoo02]oo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo049oo`04001oogoo0004Ool00`00Oomoo`0YOol00`00Oomoo`02Ool00`00Oomoo`02Ool0
1000Oomoo`0017oo00<007ooOol08Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol000Ao
o`03001oogoo0<Yoo`00GGoo00<007ooOol0=Woo00<007ooOol0C7oo00<007ooOol0<Goo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol0;7oo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool0@Woo00@007ooOol000Aoo`03001oogoo02Uoo`03001oogoo009oo`03001oogoo009oo`04001o
ogoo0004Ool00`00Oomoo`0SOol00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<0
07ooOol0bWoo001MOol00`00Oomoo`0gOol00`00Oomoo`17Ool4000dOol00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`0]Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0nOol40003
Ool00`00Oomoo`02Ool00`00Oomoo`0YOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`00
17oo00<007ooOol097oo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo
0<Yoo`00GGoo00<007ooOol0>7oo00<007ooOol0AWoo00<007ooOol0=Goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol0;Woo00D007ooOomoo`0000Aoo`03001oogoo03ioo`03001oogoo00Ao
o`03001oogoo009oo`03001oogoo02Uoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004
Ool00`00Oomoo`0UOol01@00Oomoogoo000017oo00@007ooOol000Aoo`03001oogoo0<Yoo`00Fgoo
0`00=Woo00D007ooOomoo`0004Qoo`03001oogoo03=oo`<000Aoo`03001oogoo009oo`03001oogoo
02Yoo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0nOol00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Oomoo`0WOol30004Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol0
8Goo00D007ooOomoo`0000=oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`3:Ool005eo
o`03001oogoo03Eoo`<004Uoo`D003=oo`03001oogoo00=oo`@002ioo`<000Eoo`@0045oo`D000=o
o`@002aoo`03001oogoo00=oo`@000Aoo`@002Eoo`<000Eoo`@000Aoo`@00<eoo`00ogooogool7oo
003oOoooOoo`Ool00?mooomooo1oo`00ogooogoo>goo0`00/Woo003oOoooOolmOol00`00Oomoo`2`
Ool00?mooomoob]oo`<00003Ool00000009oo`<00003Ool0000000Aoo`03001oogoo009oo`D00:Uo
o`00ogooogoo:Woo00@007ooOomoo`80009oo`04001oogooOol20004Ool00`00Ool00003Ool00`00
Oomoo`02Ool00`00Oomoo`2VOol00?mooomoobYoo`03001oogoo009oo`04001oogoo0004Ool00`00
Oomoo`02Ool00`00Ool00008Ool00`00Oomoo`2VOol0059oool00<T000ioo`03001oogoo009oo`04
001oogooOol50003Ool01@00Oomoogoo00000goo1000ZGoo001BOol00`00Oomoo`08Ool00`00Oomo
o`0fOol00`00Oomoo`0OOol00`00Oomoo`0EOol00`00Oomoo`0@Ool00`00Oomoo`0<Ool00`00Oomo
o`0:Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0gOol00`00Oomo
o`0NOol00`00Oomoo`0EOol00`00Oomoo`0@Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomo
o`08Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0gOol00`00Oomoo`0>Ool01000Oomo
ogoo0P000Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`04001oogoo0004Ool00`00Oomoo`2V
Ool0059oo`03001oogoo00Qoo`03001oogoo03Ioo`03001oogoo04Yoo`03001oogoo03Moo`03001o
ogoo03Moo`03001oogoo04Uoo`03001oogoo03Moo`03001oogoo03Moo`03001oogoo00moo`<00003
Ool007oo009oo`@000=oo`<00004Ool000000002Ool5002XOol0059oo`03001oogoo00Qoo`03001o
ogoo03Ioo`03001oogoo04Yoo`03001oogoo03Moo`03001oogoo03Moo`03001oogoo04Uoo`03001o
ogoo03Moo`03001oogoo03Moo`03001oogoo01=oo`03001oogoo0;ioo`00DWoo00<007ooOol0ogoo
f7oo0P00`7oo001BOol00`00Oomoo`3oOoooOonKOol0059oo`03001oogoo0?mookYoo`0301moogoo
0=eoo`00DWoo00<007ooOol0ogoo^Woo00<07gooOol0gGoo001BOol00`00Oomoo`3oOoniOol00`0O
Oomoo`3NOol0059oo`03001oogoo0?mookUoo`0301moogoo0=ioo`00DWoo00<007ooOol0ogoo^7oo
00<07gooOol0ggoo001BOol00`00Oomoo`3oOonhOol00`0OOomoo`3OOol0059oo`03001oogoo0?mo
okMoo`0301moogoo0>1oo`00DWoo00<007ooOol0ogoo]goo00<07gooOol0h7oo001BOol00`00Oomo
o`3oOonfOol00`0OOomoo`3QOol0059oo`03001oogoo0?mookIoo`0301moogoo0>5oo`00DWoo00<0
07ooOol0ogoo]Goo00<07gooOol0hWoo001BOol00`00Oomoo`3oOoneOol00`0OOomoo`3ROol0059o
o`03001oogoo0?mookAoo`0301moogoo0>=oo`00DWoo00<007ooOol0ogoo]7oo00<07gooOol0hgoo
001BOol00`00Oomoo`3oOoncOol00`0OOomoo`3TOol0059oo`03001oogoo0?mook=oo`0301moogoo
00=oo`03O01oogoo0=ioo`00DWoo0P00ogoo/goo00<07gooOol00goo00=l07ooOol0ggoo001BOol0
0`00Oomoo`3oOonbOol00`0OOomoo`03Ool00g`0Oomoo`3OOol0059oo`03001oogoo0?mook9oo`03
01moogoo009oo`03O01oogoo0>1oo`00DWoo00<007ooOol0ogoo/Goo00<07gooOol00goo00=l07oo
Ool0h7oo001BOol00`00Oomoo`3oOonaOol00`0OOomoo`3VOol0059oo`03001oogoo0?mook1oo`03
01moogoo0>Moo`00DWoo00<007ooOol0ogoo/7oo00<07gooOol0igoo001BOol2003oOonaOol00`0O
Oomoo`3WOol0059oo`03001oogoo0?moojmoo`0301moogoo00=oo`03O01oogoo0>9oo`00DWoo00<0
07ooOol0ogoo[goo00<07gooOol00Woo00=l07ooOol0hgoo001BOol00`00Oomoo`3oOon^Ool00`0O
Oomoo`03Ool00g`0Oomoo`3SOol0059oo`03001oogoo0?moojioo`0301moogoo009oo`03O01oogoo
0>Aoo`00DWoo0P00ogoo[Woo00<07gooOol00goo00=l07ooOol0i7oo001BOol00`00Oomoo`3oOon]
Ool00`0OOomoo`3ZOol0059oo`03001oogoo0?moojaoo`0301moogoo0>]oo`00DWoo0P00ogoo[Goo
00<07gooOol0jgoo001BOol00`00Oomoo`3oOon[Ool00`0OOomoo`3/Ool0059oo`03001oogoo0?mo
oj]oo`0301moogoo009oo`03O01oogoo0>Moo`00DWoo0P00ogooZgoo00<07gooOol00goo00=l07oo
Ool0igoo001BOol00`00Oomoo`3oOonZOol00`0OOomoo`02Ool00g`0Oomoo`3XOol0059oo`800?mo
ojYoo`0301moogoo00=oo`03O01oogoo0>Qoo`00DWoo0P00ogooZGoo00<07gooOol00goo00=l07oo
Ool0jGoo000FOol50004Ool20006Ool01@00Oomoogoo00001Goo1@000goo10005Goo00<007ooOol0
ogooYgoo00<07gooOol0l7oo000HOol00`00Oomoo`04Ool20007Ool00`00Ool00008Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`0BOol2003oOonXOol00`0OOomoo`3`Ool001Qoo`03001o
ogoo00ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`03001oogoo019oo`@00?mo
ojEoo`0301moogoo0?5oo`0067oo00<007ooOol03Goo00<007oo000027oo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol04Woo00<007ooOol0ogooYGoo00<07gooOol0lWoo000HOol00`00Oomo
o`0<Ool01@00Oomoogoo00001goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol04Woo00<0
07ooOol0ogooYGoo00<07gooOol017oo00=l07ooOol0jgoo000HOol00`00Oomoo`0HOol00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`3oOonTOol00`0O
Oomoo`04Ool00g`0Oomoo`3/Ool001Ioo`<001Qoo`<000Aoo`03001oogoo009oo`03001oo`0000<0
009oo`03001oo`0000Yoo`03001oogoo0?moojAoo`0301moogoo00Aoo`03O01oogoo0>aoo`0067oo
00<007ooOol067oo00<007ooOol00goo100027oo00<007oo00002Woo00<007ooOol0ogooXgoo00<0
7gooOol017oo00=l07ooOol0kGoo0016Ool00`00Oomoo`09Ool00`00Oomoo`3oOonSOol00`0OOomo
o`04Ool00g`0Oomoo`3]Ool004Eoo`03001oo`0000Yoo`03001oogoo0?mooj9oo`0301moogoo0?Eo
o`00AWoo00<007ooOol02Goo00<007ooOol0ogooXWoo00<07gooOol0E7ooS@0057oo001BOol00`00
Oomoo`3oOonQOol00`0OOomoo`1EOon=000DOol0059oo`03001oogoo0?mooj5oo`0301moogoo05Eo
ohd001Aoo`00DWoo00<007ooOol0ogooX7oo00<07gooOol017oo00=l07ooOol0CgooS@0057oo001B
Ool00`00Oomoo`3oOonOOol00`0OOomoo`04Ool00g`0Oomoo`1:OonC000DOol0059oo`03001oogoo
0?mooimoo`0301moogoo00Aoo`03O01oogoo04Yoo`03001oogoo08Yoo`H001Aoo`00DWoo00<007oo
Ool0ogooWWoo00<07gooOol017oo00=l07ooOol0Bgoo00<007ooOol0RWoo1P0057oo001BOol00`00
Oomoo`3oOonNOol00`0OOomoo`04Ool00g`0Oomoo`1;Ool00`00Oomoo`2:Ool6000DOol0059oo`03
001oogoo0?mooieoo`0301moogoo05=oo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogoo
W7oo00<07gooOol0E7oo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOonLOol00`0OOomo
o`1DOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?mooi]oo`0301moogoo00Aoo`03O01o
ogoo04ioo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogooVWoo00<07gooOol01Goo00=l
07ooOol0CWoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOonJOol00`0OOomoo`04Ool0
0g`0Oomoo`1?Ool00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?mooiUoo`0301moogoo00Eo
o`03O01oogoo04moo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogooVGoo00<07gooOol0
17oo00=l07ooOol0D7oo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOonHOol00`0OOomo
o`05Ool00g`0Oomoo`1@Ool00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?mooiMoo`0301mo
ogoo05Uoo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogooUgoo00<07gooOol0FGoo00<0
07ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOonFOol00`0OOomoo`1JOol00`00Oomoo`2:Ool6
000DOol0059oo`03001oogoo0?mooiEoo`0301moogoo00Eoo`03O01oogoo05=oo`03001oogoo08Yo
o`H001Aoo`00DWoo0P00ogooUWoo00<07gooOol017oo00=l07ooOol0E7oo00<007ooOol0RWoo1P00
57oo001BOol00`00Oomoo`3oOonDOol00`0OOomoo`05Ool00g`0Oomoo`1DOol00`00Oomoo`2:Ool6
000DOol0059oo`03001oogoo0?mooiAoo`0301moogoo00Aoo`03O01oogoo05Eoo`03001oogoo08Yo
o`H001Aoo`00DWoo00<007ooOol0ogooTgoo00<07gooOol01Goo00=l07ooOol0EGoo00<007ooOol0
RWoo1P0057oo001BOol00`00Oomoo`3oOonBOol00`0OOomoo`1NOol00`00Oomoo`2:Ool6000DOol0
059oo`03001oogoo0?mooi5oo`0301moogoo05moo`03001oogoo08Yoo`H001Aoo`00DWoo00<007oo
Ool0ogooTGoo00<07gooOol0Ggoo00<007ooOol0RWoo1P0057oo001BOol2003oOonAOol00`0OOomo
o`05Ool00g`0Oomoo`1HOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?moohmoo`0301mo
ogoo00Eoo`03O01oogoo05Uoo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogooSWoo00<0
7gooOol01Woo00=l07ooOol0FGoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOon>Ool0
0`0OOomoo`05Ool00g`0Oomoo`1JOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?mooheo
o`0301moogoo00Ioo`03O01oogoo05Yoo`03001oogoo03eoo`H0009oo`80009oo`8000=oo`@000=o
o`D000Aoo`D000Aoo`<000Aoo`D000=oo`@000=oo`<00004Ool000000006Ool6000DOol0059oo`80
0?mooheoo`0301moogoo00Ioo`03O01oogoo05]oo`03001oogoo03ioo`05001oogooOol00003Ool0
1000Oomoo`000goo00<007ooOol00Woo00D007ooOomoo`0000Ioo`03001oogoo00Ioo`05001oogoo
Ool00005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol01Goo
1P0057oo001BOol00`00Oomoo`3oOon;Ool00`0OOomoo`1UOol00`00Oomoo`0nOol00`00Oomoo`06
Ool20004Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol01Goo1P0057oo001BOol0
0`00Oomoo`3oOon;Ool00`0OOomoo`1UOol00`00Oomoo`0nOol00`00Ool00006Ool20004Ool00`00
Oomoo`06Ool00`00Oomoo`04Ool60003Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00<007ooOol01Goo1P0057oo001BOol2003oOon;Ool00`0OOomoo`1V
Ool00`00Oomoo`0nOol30005Ool01000Oomoo`000goo00@007ooOomoo`8000=oo`8000Eoo`03001o
ogoo009oo`05001oogooOol00009Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoogoo0P00
0Woo00<007ooOol01Goo1P0057oo001BOol00`00Oomoo`3oOon9Ool00`0OOomoo`06Ool00g`0Oomo
o`1NOol00`00Oomoo`0nOol00`00Ool00004Ool20002Ool20003Ool3000017oo001oogoo0P0000Ao
o`00000000=oo`@000=oo`D000Aoo`<000Eoo`@000=oo`800003Ool0000000Qoo`H001Aoo`00DWoo
00<007ooOol0ogooR7oo00<07gooOol01Woo00=l07ooOol0Ggoo00<007ooOol0?Woo00D007ooOomo
o`0002=oo`03001oogoo025oo`H001Aoo`00DWoo0P00ogooRGoo00<07gooOol01Goo00=l07ooOol0
H7oo00<007ooOol0?Goo1P00;Goo00<007ooOol05goo1P0057oo001BOol00`00Oomoo`3oOon7Ool0
0`0OOomoo`06Ool00g`0Oomoo`1POol00`00Oomoo`2:Ool6000DOol0059oo`800?moohMoo`0301mo
ogoo00Ioo`03O01oogoo065oo`03001oogoo08Yoo`H001Aoo`00DWoo0P00ogooQWoo00<07gooOol0
Jgoo00<007ooOol02Woo1W`017oo1W`017oo1W`017oo1W`0G7oo1P0057oo000FOol50004Ool20006
Ool01@00Oomoogoo00001Goo1@000goo10005Goo00<007ooOol0ogooQ7oo00<07gooOol0K7oo00<0
07ooOol0RWoo1P0057oo000HOol00`00Oomoo`04Ool20007Ool00`00Ool00008Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`0BOol2003oOon4Ool00`0OOomoo`1]Ool00`00Oomoo`2:Ool6
000DOol001Qoo`03001oogoo00ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`03
001oogoo019oo`@00?mooh9oo`0301moogoo00Ioo`03O01oogoo06Aoo`03001oogoo08Yoo`H001Ao
o`0067oo00<007ooOol03Goo00<007oo000027oo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool04Woo00<007ooOol0ogooPWoo00<07gooOol01Woo00=l07ooOol0IGoo00<007ooOol0RWoo1P00
57oo000HOol00`00Oomoo`0<Ool01@00Oomoogoo00001goo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol04Woo00<007ooOol0ogooPGoo00<07gooOol01Woo00=l07ooOol0IWoo00<007ooOol0
RWoo1P0057oo000HOol00`00Oomoo`0HOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05
Ool2000;Ool00`00Oomoo`3oOon0Ool00`0OOomoo`07Ool00g`0Oomoo`1VOol00`00Oomoo`0oOol3
0003Ool50004Ool50002Ool3000017oo000000000Woo1@009goo1P0057oo000FOol3000HOol30004
Ool00`00Oomoo`02Ool00`00Ool000030002Ool00`00Ool0000:Ool00`00Oomoo`3oOomoOol00`0O
Oomoo`07Ool00g`0Oomoo`1WOol00`00Oomoo`0nOol01@00Oomoogoo00000goo00<007ooOol01goo
00<007ooOol00goo00D007ooOomoo`00009oo`03001oogoo02Yoo`H001Aoo`0067oo00<007ooOol0
67oo00<007ooOol00goo100027oo00<007oo00002Woo00<007ooOol0ogooOWoo00<07gooOol0LWoo
00<007ooOol0?Woo00D007ooOomoo`0000=oo`03001oogoo00Moo`03001oogoo00=oo`05001oogoo
Ool00002Ool00`00Oomoo`0ZOol6000DOol004Eoo`8000]oo`03001oogoo0?moogeoo`0301moogoo
07=oo`03001oogoo03ioo`05001oogooOol00003Ool00`00Oomoo`07Ool00`00Oomoo`03Ool01@00
Oomoogoo00000Woo1P009goo1P0057oo0015Ool00`00Oomoo`0:Ool00`00Oomoo`3oOomlOol00`0O
Oomoo`1dOol00`00Oomoo`0nOol01@00Oomoogoo00000goo0P0027oo00<007ooOol00goo0P000Woo
00@007ooOol000Aoo`03001oogoo02Eoo`H001Aoo`00AWoo0P002Woo00<007ooOol0ogooO7oo00<0
7gooOol01goo00=l07ooOol0JWoo00<007ooOol0?Woo00D007ooOomoo`00009oo`800004Ool00000
0003Ool30004Ool200000goo00000004Ool4000XOol6000DOol0059oo`03001oogoo0?moog]oo`03
01moogoo00Moo`03O01oogoo06]oo`03001oogoo03ioo`05001oogooOol00017Ool6000DOol0059o
o`03001oogoo0?moogYoo`0301moogoo00Moo`03O01oogoo06aoo`03001oogoo03eoo`<00004Ool0
0000000<Ool00`00Oomoo`0gOol6000DOol0059oo`03001oogoo0?moogUoo`0301moogoo00Moo`03
O01oogoo06eoo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogooN7oo00<07gooOol0N7oo
00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOomgOol00`0OOomoo`1iOol00`00Oomoo`2:
Ool6000DOol0059oo`03001oogoo0?moogIoo`0301moogoo07Yoo`03001oogoo08Yoo`H001Aoo`00
DWoo00<007ooOol0ogooMGoo00<07gooOol027oo00=l07ooOol0L7oo00<007ooOol0RWoo1P0057oo
001BOol00`00Oomoo`3oOomdOol00`0OOomoo`08Ool00g`0Oomoo`1aOol00`00Oomoo`2:Ool6000D
Ool0059oo`03001oogoo0?moog=oo`0301moogoo00Qoo`03O01oogoo079oo`03001oogoo08Yoo`H0
01Aoo`00DWoo00<007ooOol0ogooLWoo00<07gooOol027oo00=l07ooOol0Lgoo00<007ooOol0RWoo
1P0057oo001BOol00`00Oomoo`3oOomaOol00`0OOomoo`08Ool00g`0Oomoo`1dOol00`00Oomoo`2:
Ool6000DOol0059oo`03001oogoo0?moog1oo`0301moogoo081oo`03001oogoo08Yoo`H001Aoo`00
DWoo00<007ooOol0ogooKgoo00<07gooOol0PGoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomo
o`3oOom^Ool00`0OOomoo`09Ool00g`0Oomoo`1fOol00`00Oomoo`2:Ool6000DOol0059oo`03001o
ogoo0?moofaoo`807`]oo`03O01oogoo07Moo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0
ogooJgoo00<07gooOol0QGoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOomZOol00`0O
Oomoo`26Ool00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?moofUoo`0301moogoo08Moo`03
001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogooJ7oo00<07gooOol02Woo00=l07ooOol0Ngoo
00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOomWOol00`0OOomoo`0:Ool00g`0Oomoo`1l
Ool00`00Oomoo`2:Ool6000DOol0059oo`800?moofMoo`0301moogoo00Yoo`03O01oogoo07eoo`03
001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogooIGoo00<07gooOol02Woo00=l07ooOol0OWoo
00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOomSOol201n>Ool00`00Oomoo`2:Ool6000D
Ool0059oo`03001oogoo0?moof9oo`0301moogoo08ioo`03001oogoo08Yoo`H001Aoo`00DWoo00<0
07ooOol0ogooHGoo00<07gooOol0Sgoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOomP
Ool00`0OOomoo`0;Ool00g`0Oomoo`22Ool00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?mo
oemoo`0301moogoo00]oo`03O01oogoo08=oo`03001oogoo08Yoo`H001Aoo`00DWoo0P00ogooGWoo
0P0O37oo0W`0QWoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOomLOol00`0OOomoo`0;
Ool00g`0Oomoo`26Ool00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?mooeYoo`807iMoo`03
001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogooF7oo0P0OVGoo00<007ooOol0RWoo1P0057oo
001BOol00`00Oomoo`3oOomGOol00`0OOomoo`0<Ool00g`0Oomoo`2:Ool00`00Oomoo`2:Ool6000D
Ool0059oo`800?mooeIoo`807`ioo`03O01oogoo08]oo`03001oogoo08Yoo`H001Aoo`00DWoo00<0
07ooOol0ogooE7oo00<07gooOol037oo0W`0SWoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomo
o`3oOomBOol201l>Ool00g`0Oomoo`2>Ool00`00Oomoo`2:Ool6000DOol0059oo`800?mooe9oo`03
01moogoo09moo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogooCgoo0P0OXWoo00<007oo
Ool0RWoo1P0057oo001BOol2003oOom?Ool00`0OOomoo`2ROol00`00Oomoo`2:Ool6000DOol0059o
o`03001oogoo0?moodaoo`807a1oo`03O01oogoo099oo`03001oogoo08Yoo`H001Aoo`00DWoo00<0
07ooOol0ogooBgoo00<07gooOol03Woo0W`0UGoo00<007ooOol0RWoo1P0057oo001BOol2003oOom:
Ool201l?Ool2O02GOol00`00Oomoo`2:Ool6000DOol0059oo`800?moodQoo`807jYoo`03001oogoo
08Yoo`H001Aoo`007goo10001Goo0P001Goo100017oo100017oo100017oo1@001Woo00<007ooOol0
ogooAGoo0P0O[7oo00<007ooOol0RWoo1P0057oo000NOol00`00Oomoo`02Ool00`00Oomoo`02Ool2
0004Ool00`00Oomoo`02Ool01000Oomoo`0017oo00@007ooOol000Aoo`03001oogoo00=oo`03001o
ogoo00Ioo`800?moodAoo`807a5oo`03O01oogoo09Yoo`03001oogoo08Yoo`H001Aoo`007Woo00<0
07ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00@007ooOol000Aoo`04001oogoo0004Ool0
0`00Oomoo`03Ool00`00Oomoo`06Ool4003oOom0Ool201lBOol00g`0Oomoo`2KOol00`00Oomoo`0m
Ool60002Ool20002Ool20003Ool40003Ool50004Ool50004Ool30004Ool50003Ool40003Ool30000
17oo000000001Woo1P0057oo000NOol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool0
1000Oomoo`0017oo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo0?mo
ocmoo`807a9oo`9l09ioo`03001oogoo03ioo`05001oogooOol00003Ool01000Oomoo`000goo00<0
07ooOol00Woo00D007ooOomoo`0000Ioo`03001oogoo00Ioo`05001oogooOol00005Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol01Goo1P0057oo000NOol00`00
Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool01000Oomoo`0017oo00@007ooOol000Aoo`03
001oogoo00=oo`03001oogoo00Ioo`03001oogoo0?mooceoo`807a=oo`03O01oogoo09ioo`03001o
ogoo03ioo`03001oogoo00Ioo`8000Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Io
o`03001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomo
o`05Ool6000DOol001ioo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`04001oogoo
0004Ool01000Oomoo`0017oo00<007ooOol00goo00<007ooOol01Woo00<007ooOol027oo1@0Oogoo
;Woo0P0O]Woo00<007ooOol0?Woo00<007oo00001Woo0P0017oo00<007ooOol01Woo00<007ooOol0
17oo1P000goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000=o
o`03001oogoo00Eoo`H001Aoo`007Woo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo
00@007ooOol000Aoo`04001oogoo0004Ool01000Oomoogoo0`0027oo00<007ooOol03Goo200Oogoo
8goo0`0O^7oo00<007ooOol0?Woo0`001Goo00@007ooOol000=oo`04001oogooOol20003Ool20005
Ool00`00Oomoo`02Ool01@00Oomoogoo00002Goo00<007ooOol00Woo00<007ooOol00Woo00@007oo
Oomoo`80009oo`03001oogoo00Eoo`H001Aoo`007goo100037oo100017oo100017oo10001Woo00<0
07ooOol01Woo00<007ooOol05Goo200Oogoo67oo0`0O5Woo00=l07ooOol0XWoo00<007ooOol0?Woo
00<007oo000017oo0P000Woo0P000goo0`0000Aoo`00Oomoo`800004Ool000000003Ool40003Ool5
0004Ool30005Ool40003Ool200000goo00000008Ool6000DOol0059oo`03001oogoo01eoo`P07omo
o`ioo`807aMoo`9l0:Eoo`03001oogoo03ioo`05001oogooOol0000SOol00`00Oomoo`0QOol6000D
Ool0059oo`03001oogoo02Eoo`P07omoo`=oo`<07aMoo`9l0:Moo`03001oogoo03eoo`H002eoo`03
001oogoo01Moo`H001Aoo`00DWoo00<007ooOol0;Goo2@0OmWoo0`0O`goo00<007ooOol0RWoo1P00
57oo001BOol00`00Oomoo`0fOol801o/Ool201o6Ool00`00Oomoo`2:Ool6000DOol0059oo`03001o
ogoo03ioo`P07n5oo`<07aYoo`03O01oogoo0:]oo`03001oogoo00YoobH07eYoo`H001Aoo`00DWoo
00<007ooOol0AWoo200OeWoo0`0O6goo0W`0[Woo00<007ooOol0RWoo1P0057oo001BOol00`00Oomo
o`1>Ool801o:Ool401lLOol2O02`Ool00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo05Ioo`P0
7kioo`@07m9oo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0GWoo1`0O]7oo0`0O7goo00=l
07ooOol0]7oo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`1UOol801nXOol401lPOol2O02g
Ool00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo06eoo`L07ieoo`@07b9oo`9l0;Uoo`03001o
ogoo03eoo`<000Ioo`<00003Ool00000009oo`D000=oo`@000Aoo`<00003Ool00000009oo`D001mo
o`H001Aoo`00DWoo00<007ooOol0M7oo1`0OTWoo100OhGoo00<007ooOol0?Woo00<007ooOol017oo
00@007ooOomoo`80009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0003Ool20005Ool0
0`00Oomoo`0OOol6000DOol0059oo`03001oogoo07]oo`P07hIoo`@07bAoo`9l0;moo`03001oogoo
03ioo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0007Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`0OOol6000DOol0059oo`03001oogoo08=oo`L07g]oo`@0
7bIoo`9l0<5oo`03001oogoo03ioo`03001oo`0000Eoo`D0009oo`H0009oo`03001oogoo00Ioo`D0
00Eoo`03001oogoo01moo`H001Aoo`00DWoo00<007ooOol0RWoo200OK7oo1`0O:7oo0W`0`goo00<0
07ooOol0?Woo0`0017oo00<007ooOol00Woo00@007ooOol000Aoo`04001oogoo0003Ool20002Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0OOol6000DOol0059oo`03001oogoo099oo`L0
7eaoo`T07oAoo`03001oogoo03ioo`03001oo`0000Eoo`@000Aoo`@000Aoo`<00003Ool007oo009o
o`@000Ioo`03001oogoo01moo`H001Aoo`00DWoo00<007ooOol0VGoo1`0OCWoo1`0O<Goo17`0b7oo
00<007ooOol0?Woo00D007ooOomoo`0002Eoo`03001oogoo01moo`H001Aoo`00DWoo00<007ooOol0
X7oo500O;Woo300O=Woo0W`0c7oo00<007ooOol0?Goo1P0097oo0P008Goo1P0057oo001BOol00`00
Oomoo`2dOol^01ooOolAOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?mooaioo`=l0=9o
o`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogoo6goo0g`0eGoo00<007ooOol0RWoo1P00
57oo001BOol00`00Oomoo`3oOolFOol2O03KOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo
0?mooaAoo`9l0=eoo`03001oogoo08Yoo`H001Aoo`00DWoo0P00ogoo4goo0W`0ggoo00<007ooOol0
RWoo1P0057oo001BOol00`00Oomoo`3oOol;Ool3O03UOol00`00Oomoo`2:Ool6000DOol0059oo`03
001oogoo0?moo`Qoo`=l0>Qoo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogoo0Goo0g`0
kgoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3fOol3O004Ool3O03bOol00`00Oomoo`2:
Ool6000DOol0059oo`03001oogoo0?=oo`=l0?aoo`03001oogoo08Yoo`H001Aoo`00DWoo00<007oo
Ool0jGoo1W`0ogoo17oo00<007ooOol0RWoo1P0057oo001BOol20026Ool6O004Ool6O004Ool6O00i
Ool3O004Ool6O03oOol>Ool00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo081oo`9l025oo`Il
00Aoo`Il00Aoo`Il00Aoo`Il00Aoo`Il00Aoo`=l0?mooa]oo`03001oogoo08Yoo`H001Aoo`00DWoo
00<007ooOol0OGoo0g`0ogooLgoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`1lOol00g`0
Oomoo`3oOomdOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?mooo=oo`03001oogoo08Yo
o`H001Aoo`00DWoo0P00NGoo00=l07ooOol0ogooN7oo00<007ooOol0RWoo1P0057oo001BOol00`00
Oomoo`1gOol00g`0Oomoo`3oOomiOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo07Eoo`9l
0?moogaoo`03001oogoo08Yoo`03001oogoo01Moo`00DWoo0P00MGoo00=l07ooOol0ogooO7oo00<0
07ooOol0RWoo00<007ooOol05goo001BOol00`00Oomoo`3oOoocOol00`00Oomoo`2:Ool00`00Oomo
o`0GOol0059oo`800?moooAoo`03001oogoo08Yoo`03001oogoo01Moo`00DWoo00<007ooOol0L7oo
00=l07ooOol0ogooP7oo00<007ooOol0RWoo00<007ooOol05goo001BOol2001`Ool00g`0Oomoo`3o
Oon1Oon>000IOol0059oo`03001oogoo06ioo`03O01oogoo0?mooomoobYoo`00DWoo0P00KWoo00=l
07ooOol0ogooogoo:goo000^Ool40005Ool20005Ool40004Ool50007Ool00`00Oomoo`1/Ool00g`0
Oomoo`3oOoooOol/Ool002eoo`03001oogoo009oo`03001oogoo009oo`8000Aoo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo00Moo`800?mooomooiaoo`00;Goo00<007ooOol00Woo00<007oo
Ool027oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01goo1000ogooogooVWoo000]Ool0
0`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`07Ool0
0`00Oomoo`3oOoooOonKOol002eoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo00Moo`03001oogoo06Qoo`9l0?mooomooc5oo`00;Goo00<007ooOol0
0Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol0
Igoo00=l07ooOol0ogooogoo<Goo000]Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool01000Oomoogoo0`002Goo00<007ooOol0IWoo00=l07ooOol0ogooogoo<Woo000^Ool4000<Ool4
0006Ool00`00Oomoo`07Ool00`00Oomoo`1UOol00g`0Oomoo`3oOoooOolcOol0059oo`03001oogoo
0?mooomooi]oo`00DWoo00<007ooOol0ogooogooVgoo001BOol00`00Oomoo`3oOoooOonKOol0059o
o`03001oogoo069oo`03O01oogoo0?mooomoocIoo`00DWoo00<007ooOol0HGoo00=l07ooOol0ogoo
ogoo=goo001BOol00`00Oomoo`1POol00g`0Oomoo`3oOoooOolhOol0059oo`03001oogoo05moo`03
O01oogoo0?mooomoocUoo`00DWoo00<007ooOol0ogooogooVgoo001BOol00`00Oomoo`3oOoooOonK
Ool0059oo`03001oogoo0?mooomooi]oo`00DWoo00<007ooOol0Fgoo00=l07ooOol0ogooogoo?Goo
001BOol00`00Oomoo`1JOol00g`0Oomoo`3oOoooOolnOol0059oo`03001oogoo05Qoo`9l0?mooomo
od5oo`00DWoo00<007ooOol0Egoo00=l07ooOol0ogooogoo@Goo001BOol00`00Oomoo`3oOoooOonK
Ool0059oo`03001oogoo0?mooomooi]oo`00DWoo00<007ooOol0Dgoo00=l07ooOol0ogooogooAGoo
001BOol00`00Oomoo`1AOol2O03oOoooOom8Ool0059oo`03001oogoo04moo`9l0?mooomoodYoo`00
DWoo00<007ooOol0ogooogooVgoo001BOol00`00Oomoo`3oOoooOonKOol0059oo`03001oogoo04]o
o`03O01oogoo0?mooomoodeoo`00DWoo00<007ooOol0BGoo0W`0ogooogooD7oo001BOol20018Ool2
O03oOoooOomBOol0059oo`03001oogoo04Ioo`03O01oogoo0?mooomooe9oo`00DWoo00<007ooOol0
ogooogooVgoo001BOol00`00Oomoo`12Ool00g`0Oomoo`3oOoooOomFOol0059oo`03001oogoo045o
o`03O01oogoo0?mooomooeMoo`00DWoo00<007ooOol0?goo0W`0ogooogooFWoo001BOol00`00Oomo
o`0nOol00g`0Oomoo`3oOoooOomJOol0059oo`800?mooomooiaoo`00DWoo00<007ooOol0ogooogoo
Vgoo001BOol00`00Oomoo`0iOol2O03oOoooOomPOol0059oo`03001oogoo03Moo`9l0?mooomoof9o
o`00DWoo00<007ooOol0=Goo0W`0ogooogooI7oo001BOol2003oOoooOonLOol0059oo`03001oogoo
0?mooomooi]oo`00DWoo00<007ooOol0<Goo00=l07ooOol0ogooogooIgoo001BOol2000aOol00g`0
Oomoo`3oOoooOomXOol0059oo`03001oogoo02ioo`9l0?mooomoof]oo`00DWoo0P00;Woo00=l07oo
Ool0ogooogooJgoo001BOol00`00Oomoo`3oOoooOonKOol0059oo`8002Yoo`03O01oogoo0?mooomo
ofmoo`00DWoo00<007ooOol09goo0W`0ogooogooLWoo001BOol2000VOol2O03oOoooOomdOol004Ao
o`D000Uoo`03001oogoo02Aoo`03O01oogoo0?mooomoogAoo`00AWoo00<007ooOol02Goo0P00ogoo
ogooW7oo0016Ool00`00Oomoo`09Ool4003oOoooOonJOol004Ioo`03001oogoo00Uoo`03001oogoo
021oo`03O01oogoo0?mooomoogQoo`00AWoo00<007ooOol02Goo00<007ooOol07Woo0W`0ogooogoo
Ngoo0016Ool00`00Oomoo`09Ool00`00Oomoo`0LOol2O03oOoooOommOol004Aoo`<000]oo`03001o
ogoo0?mooomooi]oo`00AWoo00<007ooOol02Goo00<007ooOol0ogooogooVgoo001BOol00`00Oomo
o`0HOol00g`0Oomoo`3oOoooOon0Ool0059oo`03001oogoo01Moo`03O01oogoo0?mooomooh5oo`00
DWoo00<007ooOol05Goo0W`0ogooogooQ7oo001BOol00`00Oomoo`0DOol00g`0Oomoo`3oOoooOon4
Ool0059oo`03001oogoo0?mooomooi]oo`00DWoo00<007ooOol03goo00=l07ooOol0ogooogooRGoo
001BOol00`00Oomoo`0>Ool00g`0Oomoo`3oOoooOon:Ool0059oo`03001oogoo00aoo`9l0?mooomo
oheoo`00DWoo00<007ooOol02goo00=l07ooOol0ogooogooSGoo001BOol00`00Oomoo`3oOoooOonK
Ool0059oo`03001oogoo0?mooomooi]oo`00DWoo00<007ooOol0ogooogooVgoo001BOol00`00Oomo
o`3oOoooOonKOol0059oo`03001oogoo0?mooomooi]oo`00DWoo00<007ooOol0ogooogooVgoo001B
Ool00`00Oomoo`3oOoooOonKOol0059oo`03001oogoo0?mooomooi]oo`00DWoo00<007ooOol0ogoo
ogooVgoo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1o
o`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooAgoo0`00ogooYWoo003oOom8Ool0
0`00Oomoo`3oOonUOol00?moo`Yoo`<00004Ool000000003Ool200000goo00000002Ool50004Ool3
0004Ool50008Ool50002Ool3000017oo000000000Woo10001Goo0P0000=oo`0000000goo0`000goo
1@00ogooS7oo003oOol;Ool01@00Oomoogoo00000goo00<007ooOol00P001Goo00<007ooOol00goo
00D007ooOomoo`0000Eoo`03001oogoo00Yoo`03001oogoo00=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00<007ooOol00P000goo00D007ooOomoo`00009oo`03001oogoo009oo`03001o
ogoo0?moohUoo`00ogoo2goo00D007ooOomoo`0000=oo`05001oogooOol00005Ool00`00Oomoo`03
Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool00`00Oomoo`09Ool00`00Oomoo`3oOon9Ool00?moo`]o
o`05001oo`00Ool00003Ool01@00Oomoogoo00001Goo00<007ooOol00goo00<007ooOol01goo00<0
07ooOol02Woo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00<007ooOol01Goo1000ogooS7oo001GOol3002`Ool01@00Ool007oo00000goo00D0
07ooOomoo`0000Eoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00=o
o`80009oo`04001oogooOol20002Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Ioo`03001o
ogoo009oo`03001oogoo0?moohUoo`00F7oo00<007ooOol0[goo0P0000=oo`0000000Woo0P000Woo
0P001Goo00<007ooOol00Woo1@0017oo0`0037oo00<007ooOol00Woo0P0000=oo`0000000goo0P00
00=oo`0000000goo0P000Woo0P000Woo1@0017oo1@00ogooRgoo001;Ool50004Ool300000goo001o
o`2`Ool200000goo0000000=Ool00`00Oomoo`03Ool00`00Oomoo`0DOol00`00Oomoo`0KOol00`00
Oomoo`3oOonEOol004aoo`05001oogooOol00002Ool01000Oomoogoo0P00/7oo0`0000Aoo`000000
00]oo`8000moo`03001oogoo00Qoo`D00?mook=oo`00C7oo00D007ooOomoo`00009oo`03001oogoo
009oo`03001oogoo0?mooomooiEoo`00C7oo00D007ooOomoo`00009oo`03001oogoo009oo`03001o
ogoo0?mooomooiEoo`00C7oo10000goo00@007ooOomoo`800?mooomooiMoo`00C7oo00D007ooOomo
o`0000=oo`<00003Ool000000?mooomooiIoo`00C7oo00D007ooOomoo`000?mooomooimoo`00Bgoo
1@00ogooogooX7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mo
oomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`
Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003o
OoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogoo
l7oo0000\
\>"],
  ImageRangeCache->{{{0, 749}, {366.813, 0}} -> {-1.06507, -0.648943, \
0.00442282, 0.00442282}, {{18.375, 583.625}, {358.063, 8.6875}} -> \
{-0.484085, -11.2764, 0.0065048, 0.0472667}, {{583.625, 724.938}, {268.188, \
126.875}} -> {-14.9683, -2.1938, 0.0318446, 0.0265372}, {{595.375, 634.625}, \
{254, 206.938}} -> {-15.9524, -11.8034, 0.0334398, 0.108214}, {{595.375, \
634.625}, {188.063, 141}} -> {-15.9524, -17.5117, 0.0334398, 0.108214}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[21]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Injection\",ShowReport\[Rule] \"CompartmentContent\"\
\>", "SubsubsectionIcon"],

Cell[TextData[StyleBox["It computed the retention the day 180 (also can be \
used \"t\" in place of a numeric number)", "Theorem"]], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Injection\>", \ "\<Acute\>", "\<CompartmentContent\>", 1, 
      fn1, 180, lambda]\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \({qB[180] \[Rule] 4.366813021347342`*^-11, 
      q\_2[180] \[Rule] 1.5520475694779634`*^-8, 
      q\_3[180] \[Rule] 2.614115017827877`*^-9, 
      q\_4[180] \[Rule] 7.066358176484791`*^-12, 
      qURI[180] \[Rule] 1.4186824593168375`*^-7, 
      qULI[180] \[Rule] 1.683658604224156`*^-11, 
      qLLI[180] \[Rule] 3.0498612198387856`*^-11, 
      qFEC[180] \[Rule] 8.48648771265446`*^-9}\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Injection\>", \ "\<Constant\>", "\<CompartmentContent\>", 
      1, fn1, 180, lambda]\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \({qB[180] \[Rule] 0.35272933316985977`, 
      q\_2[180] \[Rule] 3.0783649266364974`, 
      q\_3[180] \[Rule] 0.18470187749561023`, 
      q\_4[180] \[Rule] 0.056639493470578124`, 
      qURI[180] \[Rule] 7.844495932071804`, 
      qULI[180] \[Rule] 0.0011309820109169635`, 
      qLLI[180] \[Rule] 0.0018734458735077284`, 
      qFEC[180] \[Rule] 0.02162239062135812`, 
      qWB[180] \[Rule] 3.67544005865697`}\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
        element, "\<Injection\>", \ "\<Continuous\>", \
"\<CompartmentContent\>", inputs1, fn1, 180, lambda] // Chop\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \({qB[180] \[Rule] 2.531028712744695`*^-10, 
      q\_2[180] \[Rule] 8.995965721094697`*^-8, 
      q\_3[180] \[Rule] 1.5151560310876445`*^-8, q\_4[180] \[Rule] 0, 
      qURI[180] \[Rule] 7.956182712547726`*^-7, qULI[180] \[Rule] 0, 
      qLLI[180] \[Rule] 1.7677134903184498`*^-10, 
      qFEC[180] \[Rule] 4.6902761818380284`*^-8, 
      qWB[180] \[Rule] 1.0567963448602606`*^-7}\)], "Output",
  CellLabel->"Out[24]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Injection\>", \ "\<MultiInputs\>", \
"\<CompartmentContent\>", inputs2, fn1, 180, lambda]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \("Option not available for MultiInputs intake"\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Injection\",ShowReport\[Rule] \"Disintegrations\"\
\>", "SubsubsectionIcon"],

Cell[TextData[StyleBox["It computed the accumulted disintegration over 180 \
days  (also can be used \"t\" in place of a numeric number)", "Theorem"]], \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Injection\>", \ "\<Acute\>", "\<Disintegrations\>", 1, fn1, 
      180, lambda]\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \({qB[180] \[Rule] 30475.814385875878`, 
      q\_2[180] \[Rule] 265970.7296613934`, 
      q\_3[180] \[Rule] 15958.242215620712`, 
      q\_4[180] \[Rule] 4893.652235857949`, 
      qURI[180] \[Rule] 677764.4485310039`, 
      qULI[180] \[Rule] 97.71684574322566`, 
      qLLI[180] \[Rule] 161.86572347106772`, 
      qFEC[180] \[Rule] 1868.174549685306`, 
      qWB[180] \[Rule] 317558.02106796217`}\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Injection\>", \ "\<Constant\>", "\<Disintegrations\>", 1, 
      fn1, 180, lambda]\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \({qB[180] \[Rule] 5.470366438849681`*^6, 
      q\_2[180] \[Rule] 4.49507278102946`*^7, 
      q\_3[180] \[Rule] 2.586533859469927`*^6, 
      q\_4[180] \[Rule] 877998.9121139472`, 
      qURI[180] \[Rule] 1.1377926966532671`*^8, 
      qULI[180] \[Rule] 15786.286937526786`, 
      qLLI[180] \[Rule] 26000.664824595566`, 
      qFEC[180] \[Rule] 278526.5923513079`, 
      qWB[180] \[Rule] 5.392741397249027`*^7}\)], "Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
        element, "\<Injection\>", \ "\<Continuous\>", "\<Disintegrations\>", 
        inputs1, fn1, 180, lambda] // Chop\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \("Option not available for continuous intake"\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Injection\>", \ "\<MultiInputs\>", "\<Disintegrations\>", 
      inputs2, fn1, 180, lambda]\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \("Option not available for MultiInputs intake"\)], "Output",
  CellLabel->"Out[29]="]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ingestion", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Ingestion\",ShowReport\[Rule] \"Automatic\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Ingestion\>", \ "\<Acute\>", "\<Automatic\>", 1, fn1, t1, 
      lambda]\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \({qDailyUrine[t1] \[Rule] 
        2.421887757139943`*^9\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ \
t1\) - 68464.36979918668`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t1\) \
+ 15.438401935805658`\ \[ExponentialE]\^\(\(-2.8591877362402403`\)\ t1\) - 
          0.0016950214037013689`\ \[ExponentialE]\^\(\(-0.1467904756738283`\)\
\ t1\) + 0.001575532649493866`\ \[ExponentialE]\^\(\(-0.09296730783935535`\)\ \
t1\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\), 
      qDailyFaecal[
          t1] \[Rule] \(-0.6376162230444735`\)\ \
\[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\) + 
          0.00007086761148549597`\ \
\[ExponentialE]\^\(\(-2.8591877362402403`\)\ t1\) - 
          0.00018718875923836174`\ \
\[ExponentialE]\^\(\(-1.8866433975699939`\)\ t1\) + 
          0.00020289664681691154`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) - 
          0.0006486492342218757`\ \[ExponentialE]\^\(\(-0.1467904756738283`\)\
\ t1\) + 0.0005666728326360337`\ \[ExponentialE]\^\(\(-0.09296730783935535`\)\
\ t1\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\), 
      qWholebody[t1] \[Rule] 
        0.0914295213228372`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ \
t1\) - 0.42066221132094905`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t1\) + 1.029280247819995`\ \[ExponentialE]\^\(\(-2.8591877362402403`\)\ t1\) \
- 0.000037069668834817066`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ t1\) \
+ 0.000118081122349335`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) - 
          0.03780557175841985`\ \[ExponentialE]\^\(\(-0.1467904756738283`\)\ \
t1\) + 0.33767700248302257`\ \[ExponentialE]\^\(\(-0.09296730783935535`\)\ t1\
\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\)}\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Ingestion\>", \ "\<Constant\>", "\<Automatic\>", 1, fn1, 
      t1, lambda]\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \({qDailyUrine[
          t1] \[Rule] \(\(0.6487196125913783`\)\(\[InvisibleSpace]\)\) - 
          1.0054899377902852`*^8\ \[ExponentialE]\^\(\(-24.086643397569993`\)\
\ t1\) + 5664.465108067257`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t1\) - 5.39957615938391`\ \[ExponentialE]\^\(\(-2.8591877362402403`\)\ t1\) + 
          0.01154721650652421`\ \[ExponentialE]\^\(\(-0.1467904756738283`\)\ \
t1\) - 0.016947168699521065`\ \[ExponentialE]\^\(\(-0.09296730783935535`\)\ \
t1\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\), 
      qDailyFaecal[
          t1] \[Rule] \(\(0.001788124060231669`\)\(\[InvisibleSpace]\)\) - 
          0.000024785924543270834`\ \[ExponentialE]\^\(\(-2.8591877362402403`\
\)\ t1\) + 
          0.00009921788053824152`\ \
\[ExponentialE]\^\(\(-1.8866433975699939`\)\ t1\) - 
          0.00018671870391946368`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) + 
          0.00441887820885048`\ \[ExponentialE]\^\(\(-0.1467904756738283`\)\ \
t1\) - 0.006095398972025934`\ \[ExponentialE]\^\(\(-0.09296730783935535`\)\ \
t1\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\), 
      qWholebody[
          t1] \[Rule] \(\(3.703735910485367`\)\(\[InvisibleSpace]\)\) - 
          0.003795859797221109`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ \
t1\) + 0.03480389033447638`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t1\) - 0.35999043881374243`\ \[ExponentialE]\^\(\(-2.8591877362402403`\)\ \
t1\) + 0.00001964847669812058`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ \
t1\) - 0.00010866593641795825`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ \
t1\) + 0.2575478523717347`\ \[ExponentialE]\^\(\(-0.1467904756738283`\)\ t1\) \
- 3.6322123371208948`\ \[ExponentialE]\^\(\(-0.09296730783935535`\)\ \
t1\)}\)], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Ingestion\>", \ "\<Continuous\>", "\<Automatic\>", inputs1, 
      fn1, t, lambda]\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \({qDailyUrine[
          t] \[Rule] \(-1.2218055570063458`*^8\)\ \
\[ExponentialE]\^\(\(-24.086643397569993`\)\ t\) + 
          6970.368152137537`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t\) - 7.239047788726849`\ \[ExponentialE]\^\(\(-2.8591877362402403`\)\ t\) + 
          1.0462982782551355`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.013276104689884383`\ \[ExponentialE]\^\(\(-0.1467904756738283`\)\ \
t\) + 0.009132080347608262`\ \[ExponentialE]\^\(\(-0.09296730783935536`\)\ \
t\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999317`\)\ t\), 
      qDailyFaecal[
          t] \[Rule] \(-0.0000332297363645275`\)\ \
\[ExponentialE]\^\(\(-2.8591877362402403`\)\ t\) + 
          0.00014157340674663153`\ \
\[ExponentialE]\^\(\(-1.8866433975699939`\)\ t\) - 
          0.00030951251473337405`\ \
\[ExponentialE]\^\(\(-1.0866433975699932`\)\ t\) + 
          0.001996261212576929`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.005080487551212154`\ \[ExponentialE]\^\(\(-0.1467904756738283`\)\ \
t\) + 0.0032845411614296216`\ \[ExponentialE]\^\(\(-0.09296730783935536`\)\ t\
\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999317`\)\ t\), 
      qWholebody[
          t] \[Rule] \(-0.00461248036360662`\)\ \
\[ExponentialE]\^\(\(-24.086643397569993`\)\ t\) + 
          0.042827685250001746`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t\) - 0.4826282495392698`\ \[ExponentialE]\^\(\(-2.8591877362402403`\)\ t\) + 
          0.00002803629515611942`\ \
\[ExponentialE]\^\(\(-1.8866433975699939`\)\ t\) - 
          0.0001801290740593729`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\
\ t\) - 1.2165648051104907`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.29610878507475497`\ \[ExponentialE]\^\(\(-0.1467904756738283`\)\ \
t\) + 1.9572387276170238`\ \[ExponentialE]\^\(\(-0.09296730783935536`\)\ t\)}\
\)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Ingestion\>", \ "\<MultiInputs\>", "\<Automatic\>", 
      inputs2, fn1, t, lambda]\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \({qDailyUrine[t] \[Rule] 
        1.6953214299979605`*^10\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ \
t\) - 479250.58860082703`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t\) + 
          108.22096155043756`\ \[ExponentialE]\^\(\(-2.8591877362402403`\)\ t\
\) - 0.01635906090619515`\ \[ExponentialE]\^\(\(-0.1467904756738283`\)\ t\) + 
          0.015855291766052493`\ \[ExponentialE]\^\(\(-0.09296730783935535`\)\
\ t\) + 3.3306690738754696`*^-16\ \
\[ExponentialE]\^\(\(-0.08664339756999316`\)\ t\), 
      qDailyFaecal[
          t] \[Rule] \(-4.463313561311315`\)\ \
\[ExponentialE]\^\(\(-24.086643397569993`\)\ t\) + 
          0.0004967716924091714`\ \[ExponentialE]\^\(\(-2.8591877362402403`\)\
\ t\) - 0.0013232263679956629`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ \
t\) + 0.0014898462856023924`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ \
t\) - 0.006260270404975977`\ \[ExponentialE]\^\(\(-0.1467904756738283`\)\ t\) \
+ 0.00570268289916169`\ \[ExponentialE]\^\(\(-0.09296730783935535`\)\ t\) + 
          4.163336342344337`*^-17\ \[ExponentialE]\^\(\(-0.08664339756999316`\
\)\ t\), qWholebody[t] \[Rule] 
        0.6400066492598604`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ t\) \
- 2.944635479286705`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t\) + 
          7.215105461505762`\ \[ExponentialE]\^\(\(-2.8591877362402403`\)\ \
t\) - 0.0002620433163544607`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ \
t\) + 0.0008670558350363782`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ \
t\) - 0.36487070289437024`\ \[ExponentialE]\^\(\(-0.1467904756738283`\)\ t\) \
+ 3.3981951429405797`\ \[ExponentialE]\^\(\(-0.09296730783935535`\)\ t\) + 
          0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t\)}\)], "Output",\

  CellLabel->"Out[33]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Ingestion\",ShowReport\[Rule] \"BioassayTable\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
        element, "\<Ingestion\>", \ "\<Acute\>", "\<BioassayTable\>", 1, fn1, 
        180, lambda] // Chop\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nstart intake"\), \("Urine\n24 hours"\), \("Faecal\n\
24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "0.5829233003607031`", "4.074775878120601`*^-7", 
            "0.33408033536638054`"},
          {"2", "0.05075806371033074`", "5.920721596691865`*^-6", 
            "0.25558903385421605`"},
          {"3", "0.0030076122080772393`", "0.00001830489394328101`", 
            "0.23135026034107117`"},
          {"4", "0.00031057873875233436`", "0.00003263319426308932`", 
            "0.21180591219620015`"},
          {"5", "0.00018573414614359054`", "0.000045519949191670896`", 
            "0.1939956237632339`"},
          {"6", "0.000199940616675983`", "0.00005584825706421515`", 
            "0.17763898248115756`"},
          {"7", "0.0002152685549291185`", "0.00006355744541750786`", 
            "0.16261683916563863`"},
          {"8", "0.0002250965039422015`", "0.00006894190960445717`", 
            "0.14882626059450765`"},
          {"9", "0.00023012268281467094`", "0.00007237318535444615`", 
            "0.1361717868320265`"},
          {"10", "0.00023128946584241212`", "0.0000742060423154543`", 
            "0.12456458358721502`"},
          {"20", "0.0001554428975917912`", "0.00005383783516701451`", 
            "0.050594437190029456`"},
          {"30", "0.0000761328821609501`", "0.00002690572355185513`", 
            "0.020298451898625145`"},
          {"40", "0.00003345427931731454`", "0.000011922608560068805`", 
            "0.0080874140529117`"},
          {"50", "0.000013988582340883647`", "5.005957428834722`*^-6", 
            "0.003209465693621216`"},
          {"60", "5.701865669671337`*^-6", "2.04495860780488`*^-6", 
            "0.0012707535028908521`"},
          {"70", "2.292088782412886`*^-6", "8.230525924252158`*^-7", 
            "0.0005024736493418201`"},
          {"80", "9.142468356458612`*^-7", "3.2851797260838214`*^-7", 
            "0.00019853176152245921`"},
          {"90", "3.630491117032764`*^-7", "1.3050673215490396`*^-7", 
            "0.00007840638472583891`"},
          {"100", "1.4379879991802904`*^-7", "5.170376108587288`*^-8", 
            "0.00003095701097785678`"},
          {"180", "0", "0", "1.823746561927576`*^-8"},
          {"200", "0", "0", "2.840944162836449`*^-9"},
          {"300", "0", "0", "0"},
          {"400", "0", "0", "0"},
          {"500", "0", "0", "0"},
          {"600", "0", "0", "0"},
          {"700", "0", "0", "0"},
          {"800", "0", "0", "0"},
          {"900", "0", "0", "0"},
          {"1000", "0", "0", "0"},
          {"2000", "0", "0", "0"},
          {"3000", "0", "0", "0"},
          {"4000", "0", "0", "0"},
          {"5000", "0", "0", "0"},
          {"6000", "0", "0", "0"},
          {"7000", "0", "0", "0"},
          {"8000", "0", "0", "0"},
          {"9000", "0", "0", "0"},
          {"10000", "0", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nstart intake", 
          "Urine\n24 hours", "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
  CellLabel->"Out[34]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Ingestion\>", \ "\<Constant\>", "\<BioassayTable\>", 1, 
      fn1, 180, lambda]\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\n start intake"\), \("Urine\n24 hours"\), \("Faecal\n\
24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "0.36220367385926994`", "7.470331708780975`*^-8", 
            "0.5956990936960578`"},
          {"2", "0.6255197207115162`", "2.559824491422039`*^-6", 
            "0.8786390391761958`"},
          {"3", "0.6423145623531927`", "0.000014293423644671864`", 
            "1.121289537924762`"},
          {"4", "0.6433963420157323`", "0.00003978587041447392`", 
            "1.3426937542535193`"},
          {"5", "0.6436121780814381`", "0.00007905340089324632`", 
            "1.5454672122133677`"},
          {"6", "0.6438037932972809`", "0.0001299621870871002`", 
            "1.7311687690151012`"},
          {"7", "0.6440118416141347`", "0.00018987346968232023`", 
            "1.9011898878322468`"},
          {"8", "0.6442324654593117`", "0.00025630152745121076`", 
            "2.0568128893148048`"},
          {"9", "0.6444604341624887`", "0.0003271064886343914`", 
            "2.1992210372255956`"},
          {"10", "0.6446914260168026`", "0.0004005155951251776`", 
            "2.329505483684276`"},
          {"20", "0.6466926921964404`", "0.0010732048415541973`", 
            "3.1516026644895048`"},
          {"30", "0.6478189190330994`", "0.0014674208272231568`", 
            "3.4835723883666967`"},
          {"40", "0.648340921633574`", "0.0016526688195297734`", 
            "3.6163236606748397`"},
          {"50", "0.6485648037153853`", "0.001732616377237567`", 
            "3.669116567200562`"},
          {"60", "0.6486572804206228`", "0.0017657447595298206`", 
            "3.690044780383902`"},
          {"70", "0.6486947273484702`", "0.0017791827279621704`", 
            "3.6983259279056075`"},
          {"80", "0.6487097254234948`", "0.001784570046539164`", 
            "3.701599225339886`"},
          {"90", "0.6487156952301234`", "0.0017867155866368237`", 
            "3.7028922617297155`"},
          {"100", "0.6487180630050426`", "0.001787566831556637`", 
            "3.703402859471235`"},
          {"180", "0.6487196116761185`", "0.0017881237310401546`", 
            "3.703735714314127`"},
          {"200", "0.6487196124487999`", "0.0017881240089505264`", 
            "3.703735879926812`"},
          {"300", "0.648719612591365`", "0.0017881240602269644`", 
            "3.703735910482564`"},
          {"400", "0.6487196125913783`", "0.001788124060231669`", 
            "3.7037359104853667`"},
          {"500", "0.6487196125913783`", "0.001788124060231669`", 
            "3.703735910485367`"},
          {"600", "0.6487196125913783`", "0.001788124060231669`", 
            "3.703735910485367`"},
          {"700", "0.6487196125913783`", "0.001788124060231669`", 
            "3.703735910485367`"},
          {"800", "0.6487196125913783`", "0.001788124060231669`", 
            "3.703735910485367`"},
          {"900", "0.6487196125913783`", "0.001788124060231669`", 
            "3.703735910485367`"},
          {"1000", "0.6487196125913783`", "0.001788124060231669`", 
            "3.703735910485367`"},
          {"2000", "0.6487196125913783`", "0.001788124060231669`", 
            "3.703735910485367`"},
          {"3000", "0.6487196125913783`", "0.001788124060231669`", 
            "3.703735910485367`"},
          {"4000", "0.6487196125913783`", "0.001788124060231669`", 
            "3.703735910485367`"},
          {"5000", "0.6487196125913783`", "0.001788124060231669`", 
            "3.703735910485367`"},
          {"6000", "0.6487196125913783`", "0.001788124060231669`", 
            "3.703735910485367`"},
          {"7000", "0.6487196125913783`", "0.001788124060231669`", 
            "3.703735910485367`"},
          {"8000", "0.6487196125913783`", "0.001788124060231669`", 
            "3.703735910485367`"},
          {"9000", "0.6487196125913783`", "0.001788124060231669`", 
            "3.703735910485367`"},
          {"10000", "0.6487196125913783`", "0.001788124060231669`", 
            "3.703735910485367`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\n start intake", 
          "Urine\n24 hours", "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
  CellLabel->"Out[35]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
        element, "\<Ingestion\>", \ "\<Continuous\>", "\<BioassayTable\>", 
        inputs1, fn1, 180, lambda] // Chop\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\n start intake"\), \("Urine\n24 hours"\), \("Faecal\n\
24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "0.39210969591623357`", "8.570704829180542`*^-8", 
            "0.598827384695304`"},
          {"2", "0.548124411532535`", "2.782801885151619`*^-6", 
            "0.7351042469731963`"},
          {"3", "0.4223924847845947`", "0.000014549776496540712`", 
            "0.7955243796045475`"},
          {"4", "0.313976703538664`", "0.00003757964129783633`", 
            "0.8183697759202098`"},
          {"5", "0.23282070558229817`", "0.00006888301797202266`", 
            "0.8160233436192359`"},
          {"6", "0.17267686881975064`", "0.00010407525111765515`", 
            "0.7966237299953118`"},
          {"7", "0.12813825695591752`", "0.00013941154104495996`", 
            "0.7660303247116197`"},
          {"8", "0.09515613548875623`", "0.0001722852846375377`", 
            "0.7284711102151904`"},
          {"9", "0.07072986942226778`", "0.00020112591802019688`", 
            "0.6869757496517704`"},
          {"10", "0.05263748093869469`", "0.000225150069456354`", 
            "0.6436933493614732`"},
          {"20", "0.0033112607032420582`", "0.00024688429232066393`", 
            "0.2861524797302049`"},
          {"30", "0.0005281863458917457`", "0.00014004119541110617`", 
            "0.11656185370093165`"},
          {"40", "0.0001906086740668944`", "0.00006539551473293552`", 
            "0.046651726490213756`"},
          {"50", "0.0000791592613248876`", "0.000028158399606863465`", 
            "0.01855229996171926`"},
          {"60", "0.00003254861268868828`", "0.00001165537675776047`", 
            "0.007353987531365358`"},
          {"70", "0.000013167184588724207`", "4.725035623204547`*^-6", 
            "0.002909776072533331`"},
          {"80", "5.271769922625055`*^-6", "1.8936604743647516`*^-6", 
            "0.0011501155325533167`"},
          {"90", "2.0979856874690957`*^-6", "7.540241210307207`*^-7", 
            "0.00045431710836222906`"},
          {"100", "8.320293304486413`*^-7", "2.99127681007709`*^-7", 
            "0.00017940013445755842`"},
          {"180", "4.931699276572828`*^-10", "1.773777192666761`*^-10", 
            "1.0570748578917719`*^-7"},
          {"200", "0", "0", "1.646662720787355`*^-8"},
          {"300", "0", "0", "0"},
          {"400", "0", "0", "0"},
          {"500", "0", "0", "0"},
          {"600", "0", "0", "0"},
          {"700", "0", "0", "0"},
          {"800", "0", "0", "0"},
          {"900", "0", "0", "0"},
          {"1000", "0", "0", "0"},
          {"2000", "0", "0", "0"},
          {"3000", "0", "0", "0"},
          {"4000", "0", "0", "0"},
          {"5000", "0", "0", "0"},
          {"6000", "0", "0", "0"},
          {"7000", "0", "0", "0"},
          {"8000", "0", "0", "0"},
          {"9000", "0", "0", "0"},
          {"10000", "0", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\n start intake", 
          "Urine\n24 hours", "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
  CellLabel->"Out[36]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Ingestion\>", \ "\<MultiInputs\>", "\<BioassayTable\>", 
      inputs2, fn1, 180, lambda]\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nlast intake"\), \("Urine\n24 hours"\), \("Faecal\n\
24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "4.089701207704083`", "0.00012132447036199841`", 
            "3.1952299677535163`"},
          {"2", "0.3564632786925144`", "0.00020828654357051902`", 
            "2.573367234162621`"},
          {"3", "0.021840610577786447`", "0.0003370672905324548`", 
            "2.337610480509227`"},
          {"4", "0.003005162487136456`", "0.0004701831733496947`", 
            "2.140122916404089`"},
          {"5", "0.0021753489845085724`", "0.000584064214745609`", 
            "1.9597419540982681`"},
          {"6", "0.0023000144058343028`", "0.0006720406690735536`", 
            "1.7941192404710273`"},
          {"7", "0.002416304977105673`", "0.0007350251393816195`", 
            "1.6420632673867386`"},
          {"8", "0.002481159306973506`", "0.0007763281210175297`", 
            "1.5025211679635215`"},
          {"9", "0.0025022669831372612`", "0.0007996391209525973`", 
            "1.3745160799190643`"},
          {"10", "0.00248855546272996`", "0.0008083640696555054`", 
            "1.2571398832032314`"},
          {"20", "0.0016013839867925648`", "0.0005559887636187514`", 
            "0.5099818203277501`"},
          {"30", "0.0007747057152871054`", "0.00027403488270739284`", 
            "0.204463043793704`"},
          {"40", "0.0003386345691971268`", "0.0001207361105298733`", 
            "0.08143119498340336`"},
          {"50", "0.0001412270862297153`", "0.000050550819417010315`", 
            "0.03230841234096076`"},
          {"60", "0.000057484969552306496`", "0.000020619340144590872`", 
            "0.012790494101076237`"},
          {"70", "0.000023090403845382107`", "8.291964745086235`*^-6", 
            "0.005057154938922542`"},
          {"80", "9.206025667342414`*^-6", "3.308147459436086`*^-6", 
            "0.001998037947982063`"},
          {"90", "3.6548047456552`*^-6", "1.3138371119176288`*^-6", 
            "0.0007890671388200973`"},
          {"100", "1.4474064446925233`*^-6", "5.204308844845827`*^-7", 
            "0.00031154085857232843`"},
          {"180", "8.562734282701964`*^-10", "3.0797514927885956`*^-10", 
            "1.8353184924018997`*^-7"},
          {"200", "1.3339114786562198`*^-10", "4.797681228103867`*^-11", 
            "2.8589698203249264`*^-8"},
          {"300", "1.2235382679510518`*^-14", "4.4007078616549695`*^-15", 
            "2.622356140851696`*^-12"},
          {"400", "1.122273533825671`*^-18", "4.0364883748418385`*^-19", 
            "2.4053196431466454`*^-16"},
          {"500", "1.0293897564295924`*^-22", "3.702412700552964`*^-23", 
            "2.2062459159448496`*^-20"},
          {"600", "9.4419340581469`*^-27", "3.3959864430662265`*^-27", 
            "2.0236483143771702`*^-24"},
          {"700", "8.660482407310603`*^-31", "3.1149212295385205`*^-31", 
            "1.8561632094973884`*^-28"},
          {"800", "7.94370677294368`*^-35", "2.857118080092042`*^-35", 
            "1.7025398315576317`*^-32"},
          {"900", "7.286254313192945`*^-39", "2.6206517346835795`*^-39", 
            "1.561630929440318`*^-36"},
          {"1000", "6.683215208482093`*^-43", "2.4037562753741526`*^-43", 
            "1.4323842030488675`*^-40"},
          {"2000", "0", "0", "0"},
          {"3000", "0", "0", "0"},
          {"4000", "0", "0", "0"},
          {"5000", "0", "0", "0"},
          {"6000", "0", "0", "0"},
          {"7000", "0", "0", "0"},
          {"8000", "0", "0", "0"},
          {"9000", "0", "0", "0"},
          {"10000", "0", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nlast intake", 
          "Urine\n24 hours", "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
  CellLabel->"Out[37]//TableForm="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Ingestion\",ShowReport\[Rule] \"GraphicReport\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Ingestion\>", \ "\<Acute\>", "\<GraphicReport\>", 1, fn1, 
      180, lambda]\)], "Input",
  CellLabel->"In[38]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.616739 0.057258 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .10142 -46.5 -6.6875 ]
[-0.0125 .10142 0 6.6875 ]
[-0.0125 .21593 -46.5 -6.625 ]
[-0.0125 .21593 0 6.625 ]
[-0.0125 .33045 -46 -6.28125 ]
[-0.0125 .33045 0 6.28125 ]
[-0.0125 .44497 -34 -6.28125 ]
[-0.0125 .44497 0 6.28125 ]
[-0.0125 .55948 -22 -6.28125 ]
[-0.0125 .55948 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10142 m
.00625 .10142 L
s
gsave
-0.0125 .10142 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .21593 m
.00625 .21593 L
s
gsave
-0.0125 .21593 -107.5 -10.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.500 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.313 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
105.000 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .33045 m
.00625 .33045 L
s
gsave
-0.0125 .33045 -107 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00001) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .44497 m
.00625 .44497 L
s
gsave
-0.0125 .44497 -95 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .55948 m
.00625 .55948 L
s
gsave
-0.0125 .55948 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .04869 m
.00375 .04869 L
s
0 .06487 m
.00375 .06487 L
s
0 .07459 m
.00375 .07459 L
s
0 .08156 m
.00375 .08156 L
s
0 .087 m
.00375 .087 L
s
0 .09146 m
.00375 .09146 L
s
0 .09524 m
.00375 .09524 L
s
0 .09852 m
.00375 .09852 L
s
0 .16321 m
.00375 .16321 L
s
0 .17939 m
.00375 .17939 L
s
0 .18911 m
.00375 .18911 L
s
0 .19608 m
.00375 .19608 L
s
0 .20151 m
.00375 .20151 L
s
0 .20597 m
.00375 .20597 L
s
0 .20975 m
.00375 .20975 L
s
0 .21304 m
.00375 .21304 L
s
0 .27772 m
.00375 .27772 L
s
0 .2939 m
.00375 .2939 L
s
0 .30362 m
.00375 .30362 L
s
0 .31059 m
.00375 .31059 L
s
0 .31603 m
.00375 .31603 L
s
0 .32049 m
.00375 .32049 L
s
0 .32427 m
.00375 .32427 L
s
0 .32755 m
.00375 .32755 L
s
0 .39224 m
.00375 .39224 L
s
0 .40842 m
.00375 .40842 L
s
0 .41814 m
.00375 .41814 L
s
0 .42511 m
.00375 .42511 L
s
0 .43055 m
.00375 .43055 L
s
0 .43501 m
.00375 .43501 L
s
0 .43879 m
.00375 .43879 L
s
0 .44207 m
.00375 .44207 L
s
0 .50676 m
.00375 .50676 L
s
0 .52294 m
.00375 .52294 L
s
0 .53265 m
.00375 .53265 L
s
0 .53963 m
.00375 .53963 L
s
0 .54506 m
.00375 .54506 L
s
0 .54952 m
.00375 .54952 L
s
0 .5533 m
.00375 .5533 L
s
0 .55658 m
.00375 .55658 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Acute) show
99.000 12.813 moveto
(intake) show
141.000 12.813 moveto
(in) show
159.000 12.813 moveto
(t) show
171.000 12.813 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
183.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
189.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .60332 m
.06042 .59656 L
.08838 .58347 L
.13894 .55161 L
.20509 .49404 L
.23444 .46199 L
.26115 .43168 L
.2711 .42176 L
.28123 .41357 L
.29174 .40773 L
.30107 .40476 L
.31076 .40338 L
.31951 .4031 L
.32703 .40329 L
.3349 .40371 L
.3657 .40586 L
.37818 .40663 L
.39062 .40728 L
.40085 .40772 L
.41107 .40807 L
.41665 .40823 L
.42258 .40836 L
.42782 .40845 L
.43257 .40851 L
.43539 .40853 L
.43803 .40855 L
.44036 .40856 L
.44287 .40856 L
.44555 .40856 L
.44836 .40855 L
.45072 .40853 L
.4533 .40851 L
.45784 .40846 L
.46191 .40839 L
.47076 .40818 L
.47823 .40794 L
.48577 .40763 L
.49904 .40693 L
.51058 .40614 L
.53436 .40398 L
.55551 .40139 L
.57346 .39864 L
.60295 .39291 L
.65211 .37946 L
.69305 .36377 L
.72536 .34791 L
.75184 .33223 L
.77637 .31524 L
.79724 .29872 L
.8171 .28103 L
Mistroke
.83439 .26391 L
.84961 .24739 L
.86452 .22977 L
.87782 .2128 L
.89097 .19474 L
.90281 .17733 L
.91352 .16057 L
.92426 .14274 L
.93405 .12556 L
.94299 .10904 L
.95205 .09146 L
.96037 .07453 L
.96882 .05654 L
.97619 .04014 L
Mfstroke
0 0 1 r
[ ] 0 setdash
.02381 .25087 m
.13894 .31202 L
.20509 .33878 L
.2577 .35483 L
.30107 .36481 L
.33772 .37116 L
.3667 .37497 L
.38932 .37723 L
.41107 .37884 L
.42166 .37943 L
.43106 .37984 L
.44084 .38016 L
.44612 .38029 L
.45081 .38037 L
.45313 .38041 L
.45556 .38043 L
.45783 .38045 L
.45987 .38046 L
.46224 .38047 L
.46477 .38047 L
.46713 .38046 L
.46927 .38045 L
.4731 .38041 L
.47524 .38039 L
.47721 .38036 L
.4811 .38028 L
.48524 .38018 L
.4924 .37995 L
.49894 .37968 L
.51059 .37907 L
.52332 .37818 L
.53436 .37722 L
.57035 .37276 L
.58806 .36976 L
.60327 .36671 L
.6526 .35346 L
.69364 .33783 L
.72602 .32196 L
.75256 .30623 L
.77713 .28919 L
.79803 .27259 L
.8179 .25481 L
.83521 .2376 L
.85045 .22099 L
.86538 .20328 L
.87869 .18621 L
.89064 .16978 L
.90256 .15227 L
.91334 .13542 L
.92415 .11749 L
Mistroke
.934 .10022 L
.94299 .08361 L
.9521 .06593 L
.96046 .04891 L
.96895 .03082 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[38]:=",
  ImageSize->{600, 294.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;^0001Ka000`40O003h00Oogooogool7oo003o
OoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogoo
l7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00
ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomo
oo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool0
0?mooomooo1oo`00Fgoo1@00=7oo1@00B7oo1000<Woo1@000goo1000;Goo1@0017oo1000@Goo1000
17oo1000:Woo1@000goo100017oo100097oo1@0017oo100017oo1000cGoo001MOol00`00Oomoo`0d
Ool01@00Oomoogoo0000Agoo00<007ooOol00Woo00<007ooOol0<Goo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol0:Woo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo03eoo`03
001oogoo009oo`04001oogoo0004Ool00`00Oomoo`0YOol00`00Oomoo`02Ool00`00Oomoo`02Ool0
1000Oomoo`0017oo00<007ooOol08Goo00D007ooOomoo`0000=oo`03001oogoo009oo`04001oogoo
0004Ool00`00Oomoo`3:Ool005eoo`03001oogoo03Eoo`03001oogoo04eoo`03001oogoo035oo`03
001oogoo009oo`03001oogoo009oo`03001oogoo02]oo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo049oo`04001oogoo0004Ool00`00Oomoo`0YOol00`00Oomoo`02Ool00`00Oomoo`02Ool0
1000Oomoo`0017oo00<007ooOol08Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol000Ao
o`03001oogoo0<Yoo`00GGoo00<007ooOol0=Woo00<007ooOol0C7oo00<007ooOol0<Goo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol0;7oo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool0@Woo00@007ooOol000Aoo`03001oogoo02Uoo`03001oogoo009oo`03001oogoo009oo`04001o
ogoo0004Ool00`00Oomoo`0SOol00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<0
07ooOol0bWoo001MOol00`00Oomoo`0gOol00`00Oomoo`17Ool4000dOol00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`0]Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0nOol40003
Ool00`00Oomoo`02Ool00`00Oomoo`0YOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`00
17oo00<007ooOol097oo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo
0<Yoo`00GGoo00<007ooOol0>7oo00<007ooOol0AWoo00<007ooOol0=Goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol0;Woo00D007ooOomoo`0000Aoo`03001oogoo03ioo`03001oogoo00Ao
o`03001oogoo009oo`03001oogoo02Uoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004
Ool00`00Oomoo`0UOol01@00Oomoogoo000017oo00@007ooOol000Aoo`03001oogoo0<Yoo`00Fgoo
0`00=Woo00D007ooOomoo`0004Qoo`03001oogoo03=oo`<000Aoo`03001oogoo009oo`03001oogoo
02Yoo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0nOol00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Oomoo`0WOol30004Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol0
8Goo00D007ooOomoo`0000=oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`3:Ool005eo
o`03001oogoo03Eoo`<004Uoo`D003=oo`03001oogoo00=oo`@002ioo`<000Eoo`@0045oo`D000=o
o`@002aoo`03001oogoo00=oo`@000Aoo`@002Eoo`<000Eoo`@000Aoo`@00<eoo`00ogooogool7oo
003oOoooOoo`Ool00?mooomooo1oo`00ogooogoo>goo0`00/Woo003oOoooOolmOol00`00Oomoo`2`
Ool00?mooomoob]oo`<00003Ool00000009oo`<00003Ool0000000Aoo`03001oogoo009oo`D00:Uo
o`00ogooogoo:Woo00@007ooOomoo`80009oo`04001oogooOol20004Ool00`00Ool00003Ool00`00
Oomoo`02Ool00`00Oomoo`2VOol00?mooomoobYoo`03001oogoo009oo`04001oogoo0004Ool00`00
Oomoo`02Ool00`00Ool00008Ool00`00Oomoo`2VOol0059oool00<T000ioo`03001oogoo009oo`04
001oogooOol50003Ool01@00Oomoogoo00000goo1000ZGoo001BOol00`00Oomoo`08Ool00`00Oomo
o`0fOol00`00Oomoo`0OOol00`00Oomoo`0EOol00`00Oomoo`0@Ool00`00Oomoo`0<Ool00`00Oomo
o`0:Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0gOol00`00Oomo
o`0NOol00`00Oomoo`0EOol00`00Oomoo`0@Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomo
o`08Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0gOol00`00Oomoo`0>Ool01000Oomo
ogoo0P000Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`04001oogoo0004Ool00`00Oomoo`2V
Ool0059oo`03001oogoo00Qoo`03001oogoo03Ioo`03001oogoo04Yoo`03001oogoo03Moo`03001o
ogoo03Moo`03001oogoo04Uoo`03001oogoo03Moo`03001oogoo03Moo`03001oogoo00moo`<00003
Ool007oo009oo`@000=oo`<00004Ool000000002Ool5002XOol0059oo`03001oogoo00Qoo`03001o
ogoo03Ioo`03001oogoo04Yoo`03001oogoo03Moo`03001oogoo03Moo`03001oogoo04Uoo`03001o
ogoo03Moo`03001oogoo03Moo`03001oogoo01=oo`03001oogoo0;ioo`00DWoo00<007ooOol0ogoo
f7oo0P00`7oo001BOol00`00Oomoo`3oOoooOonKOol0059oo`03001oogoo0?mookYoo`0301moogoo
0=eoo`00DWoo00<007ooOol0ogoo^Woo00<07gooOol0gGoo001BOol00`00Oomoo`3oOoniOol00`0O
Oomoo`3NOol0059oo`03001oogoo0?mookUoo`0301moogoo0=ioo`00DWoo00<007ooOol0ogoo^7oo
00<07gooOol0ggoo001BOol00`00Oomoo`3oOonhOol00`0OOomoo`3OOol0059oo`03001oogoo0?mo
okQoo`0301moogoo0=moo`00DWoo00<007ooOol0ogoo]goo00<07gooOol0h7oo001BOol00`00Oomo
o`3oOongOol00`0OOomoo`3POol0059oo`03001oogoo0?mookIoo`0301moogoo0>5oo`00DWoo00<0
07ooOol0ogoo]Woo00<07gooOol0hGoo001BOol00`00Oomoo`3oOoneOol00`0OOomoo`3ROol0059o
o`03001oogoo0?mookEoo`0301moogoo009oo`03O01oogoo0=eoo`00DWoo00<007ooOol0ogoo]7oo
00<07gooOol0hgoo001BOol00`00Oomoo`3oOondOol00`0OOomoo`3SOol0059oo`03001oogoo0?mo
ok=oo`0301moogoo0>Aoo`00DWoo0P00ogoo]7oo00<07gooOol0i7oo001BOol00`00Oomoo`3oOonb
Ool00`0OOomoo`03Ool00g`0Oomoo`3OOol0059oo`03001oogoo0?mook9oo`0301moogoo009oo`03
O01oogoo0>1oo`00DWoo00<007ooOol0ogoo/Goo00<07gooOol00goo00=l07ooOol0h7oo001BOol0
0`00Oomoo`3oOonaOol00`0OOomoo`02Ool00g`0Oomoo`3QOol0059oo`03001oogoo0?mook1oo`03
01moogoo00=oo`03O01oogoo0>5oo`00DWoo00<007ooOol0ogoo/7oo00<07gooOol0igoo001BOol2
003oOon`Ool00`0OOomoo`3XOol0059oo`03001oogoo0?moojmoo`0301moogoo0>Qoo`00DWoo00<0
07ooOol0ogoo[Woo00<07gooOol0jGoo001BOol00`00Oomoo`3oOon^Ool00`0OOomoo`03Ool00g`0
Oomoo`3SOol0059oo`03001oogoo0?moojeoo`0301moogoo00=oo`03O01oogoo0>Aoo`00DWoo0P00
ogoo[Woo00<07gooOol00goo00=l07ooOol0i7oo001BOol00`00Oomoo`3oOon/Ool00`0OOomoo`03
Ool00g`0Oomoo`3UOol0059oo`03001oogoo0?moojaoo`0301moogoo009oo`03O01oogoo0>Ioo`00
DWoo0P00ogoo[7oo00<07gooOol0k7oo001BOol00`00Oomoo`3oOon[Ool00`0OOomoo`3/Ool0059o
o`800?mooj]oo`0301moogoo0>eoo`00DWoo00<007ooOol0ogooZWoo00<07gooOol0kGoo001BOol2
003oOonZOol00`0OOomoo`03Ool00g`0Oomoo`3XOol0059oo`03001oogoo0?moojUoo`0301moogoo
009oo`03O01oogoo0>Uoo`005Woo1@0017oo0P001Woo00D007ooOomoo`0000Eoo`D000=oo`@001Eo
o`800?moojUoo`0301moogoo00=oo`03O01oogoo0>Uoo`0067oo00<007ooOol017oo0P001goo00<0
07oo000027oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol04Woo0P00ogooZGoo00<07goo
Ool00Woo00=l07ooOol0jWoo000HOol00`00Oomoo`0>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`3oOonWOol00`0OOomoo`03Ool00g`0Oomoo`3Z
Ool001Qoo`03001oogoo00eoo`03001oo`0000Qoo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo019oo`@00?moojEoo`0301moogoo0?5oo`0067oo00<007ooOol037oo00D007ooOomoo`0000Mo
o`03001oogoo009oo`03001oogoo009oo`03001oogoo019oo`03001oogoo0?moojIoo`0301moogoo
0?5oo`0067oo00<007ooOol067oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Goo0P00
2goo00<007ooOol0ogooYGoo00<07gooOol0lWoo000FOol3000HOol30004Ool00`00Oomoo`02Ool0
0`00Ool000030004Ool00`00Oomoo`08Ool00`00Oomoo`3oOonTOol00`0OOomoo`3cOol001Qoo`03
001oogoo01Qoo`03001oogoo00=oo`@000Uoo`8000Yoo`03001oogoo0?moojAoo`0301moogoo00Ao
o`03O01oogoo0>aoo`00AGoo00<007oo00002Woo00<007ooOol0ogooXgoo00<07gooOol017oo00=l
07ooOol0kGoo0015Ool00`00Ool0000:Ool00`00Oomoo`3oOonSOol00`0OOomoo`03Ool00g`0Oomo
o`3^Ool004Ioo`8000Yoo`03001oogoo0?mooj9oo`0301moogoo00Aoo`03O01oogoo0>ioo`00DWoo
00<007ooOol0ogooXGoo00<07gooOol017oo00=l07ooOol0CWooS@0057oo001BOol00`00Oomoo`3o
OonQOol00`0OOomoo`1EOon=000DOol0059oo`03001oogoo0?mooj1oo`0301moogoo05Ioohd001Ao
o`00DWoo00<007ooOol0ogooWgoo00<07gooOol0EgooS@0057oo001BOol00`00Oomoo`3oOonOOol0
0`0OOomoo`04Ool00g`0Oomoo`1:OonC000DOol0059oo`03001oogoo0?mooiioo`0301moogoo00Ao
o`03O01oogoo04]oo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogooWWoo00<07gooOol0
17oo00=l07ooOol0Bgoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOonMOol00`0OOomo
o`04Ool00g`0Oomoo`1<Ool00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?mooiaoo`0301mo
ogoo00Eoo`03O01oogoo04aoo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogooW7oo00<0
7gooOol017oo00=l07ooOol0CGoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOonKOol0
0`0OOomoo`1EOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?mooiYoo`0301moogoo05Io
o`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogooVWoo00<07gooOol0EWoo00<007ooOol0
RWoo1P0057oo001BOol00`00Oomoo`3oOonIOol00`0OOomoo`05Ool00g`0Oomoo`1?Ool00`00Oomo
o`2:Ool6000DOol0059oo`03001oogoo0?mooiUoo`0301moogoo00Aoo`03O01oogoo051oo`03001o
ogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogooV7oo00<07gooOol017oo00=l07ooOol0DGoo00<0
07ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOonGOol00`0OOomoo`05Ool00g`0Oomoo`1AOol0
0`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?mooiMoo`0301moogoo00Aoo`03O01oogoo059o
o`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogooUWoo00<07gooOol0FWoo00<007ooOol0
RWoo1P0057oo001BOol00`00Oomoo`3oOonEOol00`0OOomoo`1KOol00`00Oomoo`2:Ool6000DOol0
059oo`800?mooiIoo`0301moogoo05]oo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogoo
U7oo00<07gooOol01Goo00=l07ooOol0E7oo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3o
OonDOol00`0OOomoo`04Ool00g`0Oomoo`1EOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo
0?mooi=oo`0301moogoo00Eoo`03O01oogoo05Eoo`03001oogoo08Yoo`H001Aoo`00DWoo00<007oo
Ool0ogooTWoo00<07gooOol01Goo00=l07ooOol0EWoo00<007ooOol0RWoo1P0057oo001BOol00`00
Oomoo`3oOonBOol00`0OOomoo`05Ool00g`0Oomoo`1FOol00`00Oomoo`2:Ool6000DOol0059oo`03
001oogoo0?mooi5oo`0301moogoo00Eoo`03O01oogoo05Moo`03001oogoo08Yoo`H001Aoo`00DWoo
0P00ogooTGoo00<07gooOol0H7oo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOon?Ool0
0`0OOomoo`1QOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?moohmoo`0301moogoo065o
o`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogooSWoo00<07gooOol01Goo00=l07ooOol0
FWoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOon=Ool00`0OOomoo`05Ool00g`0Oomo
o`1KOol00`00Oomoo`2:Ool6000DOol0059oo`800?mooheoo`0301moogoo00Eoo`03O01oogoo05ao
o`03001oogoo03eoo`H0009oo`80009oo`8000=oo`@000=oo`D000Aoo`D000Aoo`<000Aoo`D000=o
o`@000=oo`<00004Ool000000006Ool6000DOol0059oo`03001oogoo0?mooh]oo`0301moogoo00Io
o`03O01oogoo05aoo`03001oogoo03ioo`05001oogooOol00003Ool01000Oomoo`000goo00<007oo
Ool00Woo00D007ooOomoo`0000Ioo`03001oogoo00Ioo`05001oogooOol00005Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol01Goo1P0057oo001BOol00`00Oomo
o`3oOon:Ool00`0OOomoo`06Ool00g`0Oomoo`1MOol00`00Oomoo`0nOol00`00Oomoo`06Ool20004
Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol01Goo1P0057oo001BOol2003oOon;
Ool00`0OOomoo`1VOol00`00Oomoo`0nOol00`00Ool00006Ool20004Ool00`00Oomoo`06Ool00`00
Oomoo`04Ool60003Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00<007ooOol01Goo1P0057oo001BOol00`00Oomoo`3oOon9Ool00`0OOomoo`1WOol00`00
Oomoo`0nOol30005Ool01000Oomoo`000goo00@007ooOomoo`8000=oo`8000Eoo`03001oogoo009o
o`05001oogooOol00009Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoogoo0P000Woo00<0
07ooOol01Goo1P0057oo001BOol2003oOon9Ool00`0OOomoo`1XOol00`00Oomoo`0nOol00`00Ool0
0004Ool20002Ool20003Ool3000017oo001oogoo0P0000Aoo`00000000=oo`@000=oo`D000Aoo`<0
00Eoo`@000=oo`800003Ool0000000Qoo`H001Aoo`00DWoo00<007ooOol0ogooQgoo00<07gooOol0
1Woo00=l07ooOol0H7oo00<007ooOol0?Woo00D007ooOomoo`0002=oo`03001oogoo025oo`H001Ao
o`00DWoo0P00ogooQgoo00<07gooOol01Woo00=l07ooOol0HGoo00<007ooOol0?Goo1P00;Goo00<0
07ooOol05goo1P0057oo001BOol00`00Oomoo`3oOon5Ool00`0OOomoo`06Ool00g`0Oomoo`1ROol0
0`00Oomoo`2:Ool6000DOol001Ioo`D000Aoo`8000Ioo`05001oogooOol00005Ool50003Ool4000E
Ool2003oOon6Ool00`0OOomoo`06Ool00g`0Oomoo`1ROol00`00Oomoo`2:Ool6000DOol001Qoo`03
001oogoo00Aoo`8000Moo`03001oo`0000Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo
019oo`03001oogoo0?moohAoo`0301moogoo00Ioo`03O01oogoo06=oo`03001oogoo00Yoo`Il00Ao
o`Il00Aoo`Il00Aoo`Il05aoo`H001Aoo`0067oo00<007ooOol03Woo00<007ooOol01goo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol04Woo0P00ogooQ7oo00<07gooOol0KGoo00<007ooOol0
RWoo1P0057oo000HOol00`00Oomoo`0=Ool00`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`0BOol4003oOon1Ool00`0OOomoo`1^Ool00`00Oomoo`2:Ool6000DOol001Qoo`03
001oogoo00aoo`05001oogooOol00007Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0B
Ool00`00Oomoo`3oOon2Ool00`0OOomoo`1^Ool00`00Oomoo`2:Ool6000DOol001Qoo`03001oogoo
01Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo019oo`03001oogoo0?mooh5oo`0301mo
ogoo00Ioo`03O01oogoo06Ioo`03001oogoo08Yoo`H001Aoo`005Woo0`0067oo0`0017oo00<007oo
Ool00Woo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol0ogooP7oo00<07gooOol01Woo00=l
07ooOol0Igoo00<007ooOol0RWoo1P0057oo000HOol00`00Oomoo`0HOol00`00Oomoo`03Ool40002
Ool40003Ool00`00Oomoo`09Ool00`00Oomoo`3oOomoOol00`0OOomoo`06Ool00g`0Oomoo`1XOol0
0`00Oomoo`0oOol30003Ool50004Ool50002Ool3000017oo000000000Woo1@009goo1P0057oo0016
Ool00`00Oomoo`09Ool00`00Oomoo`3oOomnOol00`0OOomoo`07Ool00g`0Oomoo`1XOol00`00Oomo
o`0nOol01@00Oomoogoo00000goo00<007ooOol01goo00<007ooOol00goo00D007ooOomoo`00009o
o`03001oogoo02Yoo`H001Aoo`00Agoo00<007ooOol027oo00<007ooOol0ogooOGoo00<07gooOol0
1goo00=l07ooOol0JGoo00<007ooOol0?Woo00D007ooOomoo`0000=oo`03001oogoo00Moo`03001o
ogoo00=oo`05001oogooOol00002Ool00`00Oomoo`0ZOol6000DOol004Eoo`03001oo`0000Yoo`03
001oogoo0?moogeoo`0301moogoo07=oo`03001oogoo03ioo`05001oogooOol00003Ool00`00Oomo
o`07Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo1P009goo1P0057oo0015Ool3000:Ool00`00
Oomoo`3oOomlOol00`0OOomoo`1dOol00`00Oomoo`0nOol01@00Oomoogoo00000goo0P0027oo00<0
07ooOol00goo0P000Woo00@007ooOol000Aoo`03001oogoo02Eoo`H001Aoo`00DWoo00<007ooOol0
ogooNgoo00<07gooOol0MGoo00<007ooOol0?Woo00D007ooOomoo`00009oo`800004Ool000000003
Ool30004Ool200000goo00000004Ool4000XOol6000DOol0059oo`03001oogoo0?moogYoo`0301mo
ogoo00Moo`03O01oogoo06aoo`03001oogoo03ioo`05001oogooOol00017Ool6000DOol0059oo`03
001oogoo0?moogUoo`0301moogoo00Moo`03O01oogoo06eoo`03001oogoo03eoo`<00004Ool00000
000<Ool00`00Oomoo`0gOol6000DOol0059oo`03001oogoo0?moogQoo`0301moogoo00Moo`03O01o
ogoo06ioo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogooMgoo00<07gooOol027oo00=l
07ooOol0KWoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOomfOol00`0OOomoo`08Ool0
0g`0Oomoo`1_Ool00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?moogEoo`0301moogoo07]o
o`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol027oo00<07gooOol0ogooJGoo00<07gooOol0
O7oo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`09Ool201ooOomXOol00`0OOomoo`07Ool0
0g`0Oomoo`1cOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo00]oo`807omoofEoo`0301mo
ogoo00Moo`03O01oogoo07Aoo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol03Goo0P0Oogoo
HWoo00<07gooOol01goo00=l07ooOol0MGoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`0?
Ool201ooOomOOol00`0OOomoo`08Ool00g`0Oomoo`1eOol00`00Oomoo`2:Ool6000DOol0059oo`03
001oogoo015oo`807omooeaoo`0301moogoo00Qoo`03O01oogoo07Ioo`03001oogoo08Yoo`H001Ao
o`00DWoo00<007ooOol04goo0P0OogooF7oo0P0OQ7oo00<007ooOol0RWoo1P0057oo001BOol00`00
Oomoo`0EOol00`0OOomoo`3oOomDOol00`0OOomoo`24Ool00`00Oomoo`2:Ool6000DOol0059oo`03
001oogoo01Ioo`807omooe=oo`0301moogoo08Eoo`03001oogoo08Yoo`H001Aoo`00DWoo00<007oo
Ool067oo0P0OogooD7oo00<07gooOol02Woo00=l07ooOol0NGoo00<007ooOol0RWoo1P0057oo001B
Ool00`00Oomoo`0JOol201ooOom=Ool00`0OOomoo`0:Ool00g`0Oomoo`1jOol00`00Oomoo`2:Ool6
000DOol0059oo`03001oogoo01aoo`807omoodUoo`807`]oo`9l07eoo`03001oogoo08Yoo`H001Ao
o`00DWoo0P007goo0P0OogooAWoo00<07gooOol02Woo00=l07ooOol0OGoo00<007ooOol0RWoo1P00
57oo001BOol00`00Oomoo`0POol201ooOom3Ool00`0OOomoo`2;Ool00`00Oomoo`2:Ool6000DOol0
059oo`03001oogoo029oo`0301moogoo0?moocioo`807`aoo`03O01oogoo07moo`03001oogoo08Yo
o`H001Aoo`00DWoo00<007ooOol08goo0P0Oogoo?Goo00<07gooOol02goo00=l07ooOol0P7oo00<0
07ooOol0RWoo1P0057oo001BOol00`00Oomoo`0UOol201ooOoliOol201l<Ool2O023Ool00`00Oomo
o`2:Ool6000DOol0059oo`03001oogoo02Moo`807omoocIoo`0301moogoo00]oo`03O01oogoo08=o
o`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0:Goo0P0Oogoo<Woo0P0OU7oo00<007ooOol0
RWoo1P0057oo001BOol2000/Ool201ooOol_Ool00`0OOomoo`2DOol00`00Oomoo`2:Ool6000DOol0
059oo`03001oogoo02eoo`807omoobaoo`0301moogoo09Eoo`03001oogoo08Yoo`H001Aoo`00DWoo
00<007ooOol0;goo00<07gooOol0ogoo9goo0P0O3goo00=l07ooOol0QWoo00<007ooOol0RWoo1P00
57oo001BOol00`00Oomoo`0`Ool201ooOolVOol00`0OOomoo`0=Ool2O029Ool00`00Oomoo`2:Ool6
000DOol0059oo`03001oogoo039oo`807omoob=oo`0301moogoo00eoo`03O01oogoo08Uoo`03001o
ogoo08Yoo`H001Aoo`00DWoo0P00=Goo0P0Oogoo7goo0P0O3goo00=l07ooOol0RWoo00<007ooOol0
RWoo1P0057oo001BOol00`00Oomoo`0fOol201ooOolLOol00`0OOomoo`2LOol00`00Oomoo`2:Ool6
000DOol0059oo`03001oogoo03Qoo`807omooaQoo`807imoo`03001oogoo08Yoo`H001Aoo`00DWoo
0P00>goo0P0Oogoo57oo0P0O47oo00=l07ooOol0SWoo00<007ooOol0RWoo1P0057oo001BOol00`00
Oomoo`0lOol201ooOolAOol00`0OOomoo`0>Ool2O02AOol00`00Oomoo`2:Ool6000DOol0059oo`80
03moo`807omoo`eoo`807a1oo`03O01oogoo095oo`03001oogoo08Yoo`H001Aoo`00DWoo00<007oo
Ool0@7oo0`0Oogoo27oo0P0O4Goo00=l07ooOol0TWoo00<007ooOol0RWoo1P0057oo001BOol00`00
Oomoo`13Ool201ooOol4Ool201nXOol00`00Oomoo`2:Ool6000DOol0059oo`8004Ioo`<07oioo`80
7jYoo`03001oogoo08Yoo`H001Aoo`00DWoo0P00BGoo0P0OnWoo0P0O4goo00=l07ooOol0UWoo00<0
07ooOol0RWoo1P0057oo000GOol40005Ool20005Ool40004Ool40004Ool40004Ool40004Ool50006
Ool00`00Oomoo`1:Ool301oeOol201lDOol00g`0Oomoo`2GOol00`00Oomoo`2:Ool6000DOol001Io
o`03001oogoo009oo`03001oogoo009oo`8000Aoo`03001oogoo009oo`04001oogoo0004Ool01000
Oomoo`0017oo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo00Ioo`8004ioo`807o5oo`80
7aAoo`9l09Yoo`03001oogoo08Yoo`H001Aoo`005Woo00<007ooOol00Woo00<007ooOol027oo00<0
07ooOol00Woo00@007ooOol000Aoo`04001oogoo0004Ool01000Oomoo`0017oo00<007ooOol00goo
00<007ooOol01Woo1000CWoo0`0Ok7oo0P0O5Goo00=l07ooOol0VWoo00<007ooOol0RWoo1P0057oo
000FOol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool01000Oomoo`0017oo00@007oo
Ool000Aoo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`1BOol201oX
Ool201ndOol00`00Oomoo`2:Ool6000DOol001Ioo`03001oogoo009oo`03001oogoo00Qoo`03001o
ogoo009oo`04001oogoo0004Ool01000Oomoo`0017oo00@007ooOol000Aoo`03001oogoo00=oo`03
001oogoo00Ioo`03001oogoo05Aoo`<07n=oo`807aAoo`03O01oogoo09moo`03001oogoo03eoo`H0
009oo`80009oo`8000=oo`@000=oo`D000Aoo`D000Aoo`<000Aoo`D000=oo`@000=oo`<00004Ool0
00000006Ool6000DOol001Ioo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`04001o
ogoo0004Ool01000Oomoo`0017oo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo00Ioo`03
001oogoo05Moo`807mioo`<07aEoo`03O01oogoo0:1oo`03001oogoo03ioo`05001oogooOol00003
Ool01000Oomoo`000goo00<007ooOol00Woo00D007ooOomoo`0000Ioo`03001oogoo00Ioo`05001o
ogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol0
1Goo1P0057oo000FOol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool01000Oomoo`00
17oo00@007ooOol000Aoo`04001oogoo0004Ool01000Oomoogoo0`0027oo00<007ooOol0FGoo0`0O
fGoo0P0O5Woo0W`0Xgoo00<007ooOol0?Woo00<007ooOol01Woo0P0017oo00<007ooOol01Woo00<0
07ooOol017oo00<007ooOol01Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol00Woo00D0
07ooOomoo`0000=oo`03001oogoo00Eoo`H001Aoo`005goo100037oo100017oo100017oo100017oo
10001Woo00<007ooOol01Woo00<007ooOol0G7oo100Odgoo0P0O5goo00=l07ooOol0Xgoo00<007oo
Ool0?Woo00<007oo00001Woo0P0017oo00<007ooOol01Woo00<007ooOol017oo1P000goo00<007oo
Ool01goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00Eoo`H0
01Aoo`00DWoo00<007ooOol0H7oo0`0OcWoo0P0O_goo00<007ooOol0?Woo0`001Goo00@007ooOol0
00=oo`04001oogooOol20003Ool20005Ool00`00Oomoo`02Ool01@00Oomoogoo00002Goo00<007oo
Ool00Woo00<007ooOol00Woo00@007ooOomoo`80009oo`03001oogoo00Eoo`H001Aoo`00DWoo00<0
07ooOol0Hgoo0`0Ob7oo0`0O5goo00=l07ooOol0Ygoo00<007ooOol0?Woo00<007oo000017oo0P00
0Woo0P000goo0`0000Aoo`00Oomoo`800004Ool000000003Ool40003Ool50004Ool30005Ool40003
Ool200000goo00000008Ool6000DOol0059oo`03001oogoo06Ioo`@07l9oo`807aUoo`03O01oogoo
0:Qoo`03001oogoo03ioo`05001oogooOol0000SOol00`00Oomoo`0QOol6000DOol0059oo`03001o
ogoo06Yoo`<07keoo`807aUoo`9l0:]oo`03001oogoo03eoo`H002eoo`03001oogoo01Moo`H001Ao
o`00DWoo00<007ooOol0KGoo100O]goo0P0O6Goo0W`0[Goo00<007ooOol0RWoo1P0057oo001BOol0
0`00Oomoo`1aOol301naOol301o:Ool00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo07Aoo`@0
7jUoo`@07aUoo`9l0;9oo`03001oogoo00YoobH07eYoo`H001Aoo`00DWoo00<007ooOol0N7oo100O
XGoo100O6goo0W`0]7oo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`1lOol401nIOol401lM
Ool2O02fOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo081oo`@07i5oo`@07mUoo`03001o
ogoo08Yoo`H001Aoo`00DWoo00<007ooOol0Q7oo1@0OR7oo100O87oo0W`0^goo00<007ooOol0RWoo
1P0057oo001BOol00`00Oomoo`29Ool501mnOol501lROol2O02mOol00`00Oomoo`2:Ool6000DOol0
059oo`03001oogoo08ioo`H07g5oo`L07bEoo`9l0;moo`03001oogoo03eoo`<000Ioo`<00003Ool0
0000009oo`D000=oo`@000Aoo`<00003Ool00000009oo`D001moo`H001Aoo`00DWoo00<007ooOol0
U7oo2@0OH7oo200OkGoo00<007ooOol0?Woo00<007ooOol017oo00@007ooOomoo`80009oo`03001o
ogoo00Eoo`03001oogoo009oo`04001oogoo0003Ool20005Ool00`00Oomoo`0OOol6000DOol0059o
o`03001oogoo09eoo``07daoo`P07bioo`9l0<Eoo`03001oogoo03ioo`03001oogoo00Aoo`03001o
ogoo009oo`04001oogoo0007Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`0OOol6000DOol0059oo`03001oogoo0:Uoo`X07c]oo`L07c=oo`=l0<Moo`03001oogoo03io
o`03001oo`0000Eoo`D0009oo`H0009oo`03001oogoo00Ioo`D000Eoo`03001oogoo01moo`H001Ao
o`00DWoo00<007ooOol0/goo300O87oo3`0Oogoo1Goo00<007ooOol0?Woo0`0017oo00<007ooOol0
0Woo00@007ooOol000Aoo`04001oogoo0003Ool20002Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`0OOol6000DOol0059oo`03001oogoo0;moob007d9oo`=l0<ioo`03001oogoo03ioo`03
001oo`0000Eoo`@000Aoo`@000Aoo`<00003Ool007oo009oo`@000Ioo`03001oogoo01moo`H001Ao
o`00DWoo00<007ooOol0ogoo7goo0g`0dGoo00<007ooOol0?Woo00D007ooOomoo`0002Eoo`03001o
ogoo01moo`H001Aoo`00DWoo00<007ooOol0ogoolgoo00<007ooOol0?Goo1P0097oo0P008Goo1P00
57oo001BOol00`00Oomoo`3oOolIOol2O03HOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo
0?mooaIoo`=l0=Yoo`03001oogoo08Yoo`H001Aoo`00DWoo0P00ogoo47oo0g`0hGoo00<007ooOol0
RWoo1P0057oo001BOol00`00Oomoo`3oOol<Ool3O03TOol00`00Oomoo`2:Ool6000DOol0059oo`03
001oogoo0?moo`Ioo`9l0>]oo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogoo0Woo17`0
kGoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3iOol4O03eOol00`00Oomoo`2:Ool6000D
Ool0059oo`03001oogoo08Uoo`Il00Aoo`Al05Qoo`Al00Aoo`9l0?Uoo`03001oogoo08Yoo`H001Ao
o`00DWoo00<007ooOol0Pgoo0W`04Woo0W`017oo1W`0@Woo17`017oo0W`0ogoo17oo00<007ooOol0
RWoo1P0057oo001BOol00`00Oomoo`21Ool2O00TOol6O004Ool6O004Ool3O00DOol3O004Ool6O004
Ool2O03oOol>Ool00`00Oomoo`2:Ool6000DOol0059oo`80085oo`03O01oogoo03]oo`=l00Aoo`Il
00Aoo`=l0?moob5oo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogoolgoo00<007ooOol0
RWoo1P0057oo001BOol00`00Oomoo`3oOoocOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo
07aoo`03O01oogoo0?moogAoo`03001oogoo08Yoo`H001Aoo`00DWoo0P00O7oo00=l07ooOol0ogoo
MGoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`1iOol2O03oOomhOol00`00Oomoo`2:Ool6
000DOol0059oo`03001oogoo07Qoo`03O01oogoo0?moogQoo`03001oogoo08Yoo`H001Aoo`00DWoo
0P00ogoom7oo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOoocOol00`00Oomoo`2:Ool6
000DOol0059oo`03001oogoo07Aoo`03O01oogoo0?moogaoo`03001oogoo08Yoo`03001oogoo01Mo
o`00DWoo0P00MGoo00=l07ooOol0ogooO7oo00<007ooOol0RWoo00<007ooOol05goo001BOol00`00
Oomoo`1cOol00g`0Oomoo`3oOommOol00`00Oomoo`2:Ool00`00Oomoo`0GOol0059oo`8007=oo`03
O01oogoo0?moogioo`03001oogoo08Yoo`03001oogoo01Moo`00DWoo0P00LWoo00=l07ooOol0ogoo
Ogoo00<007ooOol0RWoo00<007ooOol05goo000VOol40005Ool20005Ool40004Ool40004Ool50007
Ool00`00Oomoo`3oOoocOon>000IOol002Eoo`03001oogoo009oo`03001oogoo009oo`8000Aoo`03
001oogoo009oo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`07Ool2003oOoooOonLOol0
02Eoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`04001oogoo0004Ool00`00Oomo
o`03Ool00`00Oomoo`07Ool4003oOoooOonJOol002Eoo`03001oogoo009oo`03001oogoo00Qoo`03
001oogoo009oo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`1^Ool0
0g`0Oomoo`3oOoooOolZOol002Eoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`04
001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`1]Ool00g`0Oomoo`3oOooo
Ool[Ool002Eoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`04001oogoo0004Ool0
0`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`1/Ool00g`0Oomoo`3oOoooOol/Ool002Eoo`03
001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`04001oogoo0004Ool01000Oomoogoo0`00
2Goo00<007ooOol0Jgoo00=l07ooOol0ogooogoo;Goo000VOol4000<Ool40004Ool40006Ool00`00
Oomoo`07Ool00`00Oomoo`1ZOol00g`0Oomoo`3oOoooOol^Ool0059oo`03001oogoo0?mooomooi]o
o`00DWoo00<007ooOol0ogooogooVgoo001BOol00`00Oomoo`1WOol00g`0Oomoo`3oOoooOolaOol0
059oo`03001oogoo06Ioo`03O01oogoo0?mooomooc9oo`00DWoo00<007ooOol0IGoo00=l07ooOol0
ogooogoo<goo001BOol00`00Oomoo`1UOol00g`0Oomoo`3oOoooOolcOol0059oo`03001oogoo06Ao
o`03O01oogoo0?mooomoocAoo`00DWoo00<007ooOol0ogooogooVgoo001BOol00`00Oomoo`3oOooo
OonKOol0059oo`03001oogoo0?mooomooi]oo`00DWoo00<007ooOol0H7oo00=l07ooOol0ogooogoo
>7oo001BOol00`00Oomoo`1OOol00g`0Oomoo`3oOoooOoliOol0059oo`03001oogoo05ioo`03O01o
ogoo0?mooomoocYoo`00DWoo00<007ooOol0GGoo00=l07ooOol0ogooogoo>goo001BOol00`00Oomo
o`3oOoooOonKOol0059oo`03001oogoo0?mooomooi]oo`00DWoo00<007ooOol0ogooogooVgoo001B
Ool00`00Oomoo`1IOol00g`0Oomoo`3oOoooOoloOol0059oo`03001oogoo05Qoo`03O01oogoo0?mo
oomood1oo`00DWoo00<007ooOol0Egoo00=l07ooOol0ogooogoo@Goo001BOol00`00Oomoo`1FOol0
0g`0Oomoo`3oOoooOom2Ool0059oo`03001oogoo0?mooomooi]oo`00DWoo0P00ogooogooW7oo001B
Ool00`00Oomoo`3oOoooOonKOol0059oo`03001oogoo059oo`03O01oogoo0?mooomoodIoo`00DWoo
00<007ooOol0DGoo00=l07ooOol0ogooogooAgoo001BOol00`00Oomoo`1?Ool2O03oOoooOom:Ool0
059oo`03001oogoo04ioo`03O01oogoo0?mooomoodYoo`00DWoo00<007ooOol0ogooogooVgoo001B
Ool00`00Oomoo`3oOoooOonKOol0059oo`8004]oo`03O01oogoo0?mooomoodioo`00DWoo00<007oo
Ool0BGoo00=l07ooOol0ogooogooCgoo001BOol00`00Oomoo`18Ool00g`0Oomoo`3oOoooOom@Ool0
059oo`03001oogoo04Moo`03O01oogoo0?mooomooe5oo`00DWoo0P00Agoo00=l07ooOol0ogooogoo
DWoo001BOol00`00Oomoo`3oOoooOonKOol0059oo`03001oogoo0?mooomooi]oo`00DWoo0P00A7oo
00=l07ooOol0ogooogooEGoo001BOol00`00Oomoo`12Ool00g`0Oomoo`3oOoooOomFOol0059oo`03
001oogoo041oo`9l0?mooomooeUoo`00DWoo0P00@7oo00=l07ooOol0ogooogooFGoo001BOol00`00
Oomoo`3oOoooOonKOol0059oo`800?mooomooiaoo`00DWoo0P00?7oo00=l07ooOol0ogooogooGGoo
000eOol40005Ool20005Ool50008Ool00`00Oomoo`0jOol00g`0Oomoo`3oOoooOomNOol003Aoo`03
001oogoo009oo`03001oogoo009oo`8000Moo`03001oogoo00Qoo`8003Uoo`9l0?mooomoof5oo`00
=7oo00<007ooOol00Woo00<007ooOol02goo00<007ooOol027oo1000=Woo00=l07ooOol0ogooogoo
HGoo000dOol00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`3oOoooOonK
Ool003Aoo`03001oogoo009oo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo0?mooomooi]o
o`00=7oo00<007ooOol00Woo00<007ooOol02goo00<007ooOol027oo00<007ooOol0<Woo0W`0ogoo
ogooIgoo000dOol00`00Oomoo`02Ool00`00Oomoo`09Ool3000:Ool00`00Oomoo`0`Ool2O03oOooo
OomYOol003Eoo`@000ioo`03001oogoo00Qoo`03001oogoo02ioo`9l0?mooomoof]oo`00DWoo00<0
07ooOol0ogooogooVgoo001BOol00`00Oomoo`3oOoooOonKOol0059oo`03001oogoo02Yoo`03O01o
ogoo0?mooomoofioo`00DWoo00<007ooOol0:Goo00=l07ooOol0ogooogooKgoo001BOol00`00Oomo
o`0WOol2O03oOoooOombOol0059oo`03001oogoo02Ioo`03O01oogoo0?mooomoog9oo`00DWoo00<0
07ooOol0ogooogooVgoo001BOol00`00Oomoo`0QOol00g`0Oomoo`3oOoooOomgOol0059oo`03001o
ogoo01moo`9l0?mooomoogYoo`00DWoo00<007ooOol07Goo0W`0ogooogooO7oo001BOol00`00Oomo
o`3oOoooOonKOol0059oo`03001oogoo01Ioo`=l0?mooomooh9oo`00DWoo00<007ooOol04goo0g`0
ogooogooQGoo001BOol00`00Oomoo`0=Ool3O03oOoooOon;Ool0059oo`03001oogoo00Yoo`=l0?mo
oomoohioo`00DWoo00<007ooOol0ogooogooVgoo001BOol00`00Oomoo`3oOoooOonKOol0059oo`03
001oogoo0?mooomooi]oo`00DWoo00<007ooOol0ogooogooVgoo001BOol00`00Oomoo`3oOoooOonK
Ool0059oo`03001oogoo0?mooomooi]oo`00DWoo00<007ooOol0ogooogooVgoo003oOoooOoo`Ool0
0?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOooo
Ooo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00>Moo`<00004Ool000000002Ool4
0005Ool200000goo00000003Ool30004Ool50008Ool50002Ool3000017oo000000000goo0`0017oo
0`0000Aoo`00001oo`80009oo`<0009oo`D000Qoo`D0009oo`<00004Ool000000009Ool3000JOol4
003oOom]Ool00>Qoo`05001oogooOol00002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo0P00
0goo00D007ooOomoo`00009oo`03001oogoo00eoo`03001oogoo00=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000Woo00@007ooOomoo`8000=oo`04001oogoo0003Ool00`00Oomoo`0=Ool00`00
Oomoo`03Ool01@00Oomoogoo00002Goo00D007ooOomoo`0000Uoo`H000Uoo`03001oogoo009oo`03
001oogoo0?moofYoo`00jGoo0`000goo00<007ooOol01Woo00D007ooOomoo`0000=oo`03001oogoo
00Aoo`03001oogoo00eoo`03001oogoo00=oo`05001oogooOol00003Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo00eoo`03001oogoo00=oo`05001oogoo
Ool00009Ool00`00Oomoo`0JOol00`00Oomoo`02Ool00`00Oomoo`3oOomZOol00>Uoo`03001oo`00
00=oo`03001oogoo00Ioo`05001oogooOol00003Ool00`00Oomoo`04Ool6000:Ool00`00Oomoo`03
Ool01@00Oomoogoo00000goo00<007ooOol01Goo1@000goo0`0017oo1P002Woo00<007ooOol00goo
00D007ooOomoo`0000Uoo`03001oogoo00]oo`H000Uoo`03001oogoo009oo`03001oogoo0?moofYo
o`00Egoo0`00Sgoo00<007oo00000goo00@007ooOomoo`8000=oo`05001oogooOol00003Ool00`00
Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`03Ool20002Ool01@00Oomoogoo
00001Woo00<007ooOol00Woo00D007ooOomoo`00009oo`05001oogooOol00004Ool00`00Oomoo`08
Ool00`00Oomoo`03Ool20002Ool00`00Oomoo`07Ool00`00Oomoo`0JOol00`00Oomoo`02Ool00`00
Oomoo`3oOomZOol005Qoo`03001oogoo08ioo`03001oo`0000Aoo`<00004Ool007ooOol20002Ool2
0002Ool50004Ool40009Ool30004Ool200000goo00000003Ool50004Ool40004Ool00`00Ool00003
0002Ool40009Ool30004Ool200000goo00000009Ool5000IOol00`00Oomoo`02Ool00`00Oomoo`3o
OomZOol004]oo`D000Aoo`<00003Ool007oo091oo`03001oogoo01=oo`03001oogoo029oo`03001o
ogoo00eoo`03001oogoo02Qoo`03001oogoo01Yoo`03001oogoo009oo`03001oogoo0?moofYoo`00
C7oo00D007ooOomoo`00009oo`04001oogooOol2002@Ool2000/Ool00`00Oomoo`0JOol2000FOol0
0`00Oomoo`0_Ool4003oOom]Ool004aoo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomo
o`3oOoooOonEOol004aoo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`3oOoooOonE
Ool004aoo`@000=oo`04001oogooOol2003oOoooOonGOol004aoo`05001oogooOol00003Ool30000
0goo0000003oOoooOonFOol004aoo`05001oogooOol0003oOoooOonOOol004]oo`D00?mooomooj1o
o`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mo
oomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`
Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003o
OoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00\
\>"],
  ImageRangeCache->{{{0, 749}, {366.813, 0}} -> {-1.06507, -0.648943, \
0.00442282, 0.00442282}, {{18.375, 583.625}, {358.063, 8.6875}} -> \
{-0.484085, -12.3054, 0.0065048, 0.0479744}, {{583.625, 724.938}, {268.188, \
126.875}} -> {-14.9683, -2.1938, 0.0318446, 0.0265372}, {{595.375, 634.625}, \
{254, 206.938}} -> {-15.9524, -11.8034, 0.0334398, 0.108214}, {{595.375, \
634.625}, {188.063, 141}} -> {-15.9524, -17.5117, 0.0334398, 0.108214}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[38]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Ingestion\>", \ "\<Constant\>", "\<GraphicReport\>", 1, 
      fn1, 180, lambda]\)], "Input",
  CellLabel->"In[39]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.619262 0.0848291 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .02546 -46.5 -6.625 ]
[-0.0125 .02546 0 6.625 ]
[-0.0125 .19512 -46 -6.28125 ]
[-0.0125 .19512 0 6.28125 ]
[-0.0125 .36477 -34 -6.28125 ]
[-0.0125 .36477 0 6.28125 ]
[-0.0125 .53443 -22 -6.28125 ]
[-0.0125 .53443 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02546 m
.00625 .02546 L
s
gsave
-0.0125 .02546 -107.5 -10.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.500 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.313 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
105.000 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .19512 m
.00625 .19512 L
s
gsave
-0.0125 .19512 -107 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00001) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .36477 m
.00625 .36477 L
s
gsave
-0.0125 .36477 -95 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .53443 m
.00625 .53443 L
s
gsave
-0.0125 .53443 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .117 m
.00375 .117 L
s
0 .14097 m
.00375 .14097 L
s
0 .15537 m
.00375 .15537 L
s
0 .1657 m
.00375 .1657 L
s
0 .17376 m
.00375 .17376 L
s
0 .18036 m
.00375 .18036 L
s
0 .18596 m
.00375 .18596 L
s
0 .19082 m
.00375 .19082 L
s
0 .28666 m
.00375 .28666 L
s
0 .31063 m
.00375 .31063 L
s
0 .32503 m
.00375 .32503 L
s
0 .33536 m
.00375 .33536 L
s
0 .34341 m
.00375 .34341 L
s
0 .35002 m
.00375 .35002 L
s
0 .35562 m
.00375 .35562 L
s
0 .36048 m
.00375 .36048 L
s
0 .45632 m
.00375 .45632 L
s
0 .48029 m
.00375 .48029 L
s
0 .49469 m
.00375 .49469 L
s
0 .50502 m
.00375 .50502 L
s
0 .51307 m
.00375 .51307 L
s
0 .51968 m
.00375 .51968 L
s
0 .52528 m
.00375 .52528 L
s
0 .53014 m
.00375 .53014 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Constant) show
117.000 12.813 moveto
(intake) show
153.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .58185 m
.06042 .59229 L
.08838 .59729 L
.1161 .60017 L
.13894 .60152 L
.15779 .60218 L
.17363 .60253 L
.18958 .60274 L
.20509 .60287 L
.21944 .60293 L
.23372 .60297 L
.24625 .60299 L
.25701 .603 L
.26883 .60301 L
.2752 .60301 L
.28092 .60302 L
.30107 .60302 L
.33501 .60303 L
.36579 .60304 L
.41107 .60307 L
.45102 .60309 L
.48098 .60312 L
.53436 .60317 L
.6058 .60323 L
.65542 .60327 L
.69308 .60329 L
.70978 .6033 L
.72615 .60331 L
.7414 .60331 L
.75476 .60331 L
.76709 .60331 L
.7778 .60332 L
.78805 .60332 L
.79874 .60332 L
.80824 .60332 L
.81796 .60332 L
.82683 .60332 L
.83574 .60332 L
.84369 .60332 L
.8508 .60332 L
.8584 .60332 L
.86504 .60332 L
.87166 .60332 L
.87857 .60332 L
.88494 .60332 L
.89145 .60332 L
.8973 .60332 L
.90262 .60332 L
.90833 .60332 L
.9134 .60332 L
Mistroke
.91846 .60332 L
.92382 .60332 L
.92877 .60332 L
.93391 .60332 L
.93901 .60332 L
.94368 .60332 L
.94822 .60332 L
.9523 .60332 L
.95637 .60332 L
.96073 .60332 L
.96476 .60332 L
.96898 .60332 L
.97272 .60332 L
.97619 .60332 L
Mfstroke
0 0 1 r
[ ] 0 setdash
.02381 .01472 m
.20509 .19224 L
.30107 .26062 L
.41107 .31714 L
.48498 .34448 L
.53436 .35856 L
.60287 .37279 L
.63172 .37701 L
.65536 .37973 L
.67446 .38148 L
.69343 .38286 L
.71037 .38382 L
.72677 .38454 L
.74071 .38501 L
.75461 .38536 L
.76768 .38561 L
.77929 .38578 L
.79007 .3859 L
.79954 .38598 L
.80955 .38604 L
.81819 .38608 L
.82671 .38611 L
.8355 .38613 L
.84355 .38615 L
.85168 .38616 L
.85895 .38617 L
.86548 .38617 L
.87248 .38618 L
.87863 .38618 L
.88474 .38618 L
.89118 .38618 L
.8971 .38618 L
.90319 .38618 L
.90866 .38618 L
.91365 .38618 L
.91901 .38618 L
.92378 .38618 L
.92854 .38618 L
.93361 .38619 L
.93829 .38619 L
.94316 .38619 L
.94799 .38619 L
.95243 .38619 L
.95675 .38619 L
.96063 .38619 L
.9645 .38619 L
.96867 .38619 L
.97233 .38619 L
.97619 .38619 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[39]:=",
  ImageSize->{600, 294.25},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[39]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
        element, "\<Ingestion\>", \ "\<Continuous\>", "\<GraphicReport\>", 
        inputs1, fn1, 180, lambda] // Chop\)], "Input",
  CellLabel->"In[40]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.618409 0.0619103 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .12313 -46.5 -6.6875 ]
[-0.0125 .12313 0 6.6875 ]
[-0.0125 .24695 -46.5 -6.6875 ]
[-0.0125 .24695 0 6.6875 ]
[-0.0125 .37077 -40 -6.28125 ]
[-0.0125 .37077 0 6.28125 ]
[-0.0125 .49459 -28 -6.28125 ]
[-0.0125 .49459 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12313 m
.00625 .12313 L
s
gsave
-0.0125 .12313 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .24695 m
.00625 .24695 L
s
gsave
-0.0125 .24695 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .37077 m
.00625 .37077 L
s
gsave
-0.0125 .37077 -101 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0001) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .49459 m
.00625 .49459 L
s
gsave
-0.0125 .49459 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .06612 m
.00375 .06612 L
s
0 .08361 m
.00375 .08361 L
s
0 .09412 m
.00375 .09412 L
s
0 .10166 m
.00375 .10166 L
s
0 .10754 m
.00375 .10754 L
s
0 .11236 m
.00375 .11236 L
s
0 .11645 m
.00375 .11645 L
s
0 .11999 m
.00375 .11999 L
s
0 .18994 m
.00375 .18994 L
s
0 .20743 m
.00375 .20743 L
s
0 .21794 m
.00375 .21794 L
s
0 .22548 m
.00375 .22548 L
s
0 .23136 m
.00375 .23136 L
s
0 .23618 m
.00375 .23618 L
s
0 .24027 m
.00375 .24027 L
s
0 .24381 m
.00375 .24381 L
s
0 .31376 m
.00375 .31376 L
s
0 .33125 m
.00375 .33125 L
s
0 .34176 m
.00375 .34176 L
s
0 .3493 m
.00375 .3493 L
s
0 .35518 m
.00375 .35518 L
s
0 .36 m
.00375 .36 L
s
0 .36409 m
.00375 .36409 L
s
0 .36763 m
.00375 .36763 L
s
0 .43758 m
.00375 .43758 L
s
0 .45507 m
.00375 .45507 L
s
0 .46558 m
.00375 .46558 L
s
0 .47312 m
.00375 .47312 L
s
0 .479 m
.00375 .479 L
s
0 .48382 m
.00375 .48382 L
s
0 .48791 m
.00375 .48791 L
s
0 .49145 m
.00375 .49145 L
s
0 .5614 m
.00375 .5614 L
s
0 .57889 m
.00375 .57889 L
s
0 .5894 m
.00375 .5894 L
s
0 .59694 m
.00375 .59694 L
s
0 .60282 m
.00375 .60282 L
s
0 .60764 m
.00375 .60764 L
s
0 .61173 m
.00375 .61173 L
s
0 .61528 m
.00375 .61528 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Continuous) show
129.000 12.813 moveto
(intake) show
165.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .59324 m
.06042 .60002 L
.08838 .60264 L
.1161 .60332 L
.13894 .60281 L
.15779 .60183 L
.17363 .60068 L
.20509 .59765 L
.25791 .5906 L
.30107 .58296 L
.3616 .56871 L
.41107 .55308 L
.48481 .52076 L
.53436 .49161 L
.60255 .44399 L
.65487 .41152 L
.69419 .39131 L
.72541 .37425 L
.75367 .35619 L
.77729 .33853 L
.79945 .31952 L
.81854 .30103 L
.83519 .28313 L
.8514 .26402 L
.86575 .24556 L
.87857 .22778 L
.8913 .20884 L
.90277 .19058 L
.91423 .17117 L
.92462 .15247 L
.9341 .13447 L
.94367 .11531 L
.95243 .09687 L
.96048 .07914 L
.96868 .06025 L
.97619 .04221 L
s
0 0 1 r
[ ] 0 setdash
.02381 .18089 m
.13894 .26643 L
.20509 .30782 L
.30107 .35399 L
.36239 .37477 L
.41107 .38661 L
.43247 .39052 L
.45317 .39353 L
.47079 .3955 L
.47862 .39619 L
.48567 .39672 L
.49228 .39713 L
.49812 .39742 L
.5044 .39767 L
.50777 .39777 L
.51092 .39784 L
.51389 .39789 L
.51701 .39792 L
.51991 .39794 L
.5225 .39794 L
.52407 .39793 L
.5255 .39792 L
.52707 .3979 L
.5287 .39788 L
.53142 .39783 L
.53436 .39775 L
.53963 .39758 L
.5452 .39733 L
.5549 .39675 L
.56388 .39602 L
.57182 .39522 L
.58864 .39306 L
.60496 .3903 L
.63121 .38444 L
.65285 .37817 L
.69164 .36336 L
.72549 .3462 L
.75308 .32889 L
.77619 .3118 L
.79796 .29332 L
.81673 .27533 L
.83477 .25609 L
.85062 .23746 L
.86467 .21949 L
.87853 .20034 L
.89095 .18188 L
.90215 .16411 L
.91337 .14518 L
.92355 .12695 L
.93379 .10757 L
Mistroke
.94314 .08889 L
.95171 .07093 L
.96041 .05181 L
.96841 .03341 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[40]:=",
  ImageSize->{600, 294.25},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Ingestion\>", \ "\<MultiInputs\>", "\<GraphicReport\>", 
      inputs2, fn1, 180, lambda]\)], "Input",
  CellLabel->"In[41]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.567753 0.0581442 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .1026 -46.5 -6.6875 ]
[-0.0125 .1026 0 6.6875 ]
[-0.0125 .21889 -46.5 -6.6875 ]
[-0.0125 .21889 0 6.6875 ]
[-0.0125 .33518 -40 -6.28125 ]
[-0.0125 .33518 0 6.28125 ]
[-0.0125 .45146 -28 -6.28125 ]
[-0.0125 .45146 0 6.28125 ]
[-0.0125 .56775 -10 -6.28125 ]
[-0.0125 .56775 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .1026 m
.00625 .1026 L
s
gsave
-0.0125 .1026 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .21889 m
.00625 .21889 L
s
gsave
-0.0125 .21889 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .33518 m
.00625 .33518 L
s
gsave
-0.0125 .33518 -101 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0001) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .45146 m
.00625 .45146 L
s
gsave
-0.0125 .45146 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .56775 m
.00625 .56775 L
s
gsave
-0.0125 .56775 -71 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .04906 m
.00375 .04906 L
s
0 .06549 m
.00375 .06549 L
s
0 .07536 m
.00375 .07536 L
s
0 .08244 m
.00375 .08244 L
s
0 .08796 m
.00375 .08796 L
s
0 .09249 m
.00375 .09249 L
s
0 .09633 m
.00375 .09633 L
s
0 .09966 m
.00375 .09966 L
s
0 .16535 m
.00375 .16535 L
s
0 .18178 m
.00375 .18178 L
s
0 .19165 m
.00375 .19165 L
s
0 .19872 m
.00375 .19872 L
s
0 .20425 m
.00375 .20425 L
s
0 .20877 m
.00375 .20877 L
s
0 .21261 m
.00375 .21261 L
s
0 .21594 m
.00375 .21594 L
s
0 .28164 m
.00375 .28164 L
s
0 .29806 m
.00375 .29806 L
s
0 .30793 m
.00375 .30793 L
s
0 .31501 m
.00375 .31501 L
s
0 .32053 m
.00375 .32053 L
s
0 .32506 m
.00375 .32506 L
s
0 .3289 m
.00375 .3289 L
s
0 .33223 m
.00375 .33223 L
s
0 .39792 m
.00375 .39792 L
s
0 .41435 m
.00375 .41435 L
s
0 .42422 m
.00375 .42422 L
s
0 .4313 m
.00375 .4313 L
s
0 .43682 m
.00375 .43682 L
s
0 .44135 m
.00375 .44135 L
s
0 .44519 m
.00375 .44519 L
s
0 .44852 m
.00375 .44852 L
s
0 .51421 m
.00375 .51421 L
s
0 .53064 m
.00375 .53064 L
s
0 .54051 m
.00375 .54051 L
s
0 .54759 m
.00375 .54759 L
s
0 .55311 m
.00375 .55311 L
s
0 .55764 m
.00375 .55764 L
s
0 .56148 m
.00375 .56148 L
s
0 .56481 m
.00375 .56481 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Multi) show
99.000 12.813 moveto
(Inputs) show
135.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .60332 m
.20509 .49269 L
.23623 .45917 L
.2498 .44459 L
.26149 .43322 L
.2713 .42535 L
.28154 .41931 L
.29128 .41569 L
.30107 .41376 L
.31022 .41304 L
.31516 .41294 L
.31957 .41295 L
.32783 .41317 L
.33536 .41349 L
.36608 .41501 L
.37752 .41548 L
.38897 .41587 L
.39525 .41605 L
.40077 .41618 L
.40617 .41628 L
.41107 .41636 L
.41625 .41642 L
.41893 .41645 L
.42177 .41646 L
.42469 .41648 L
.42742 .41648 L
.42984 .41648 L
.43243 .41647 L
.43704 .41645 L
.43933 .41643 L
.44182 .4164 L
.44613 .41634 L
.4501 .41627 L
.4594 .41605 L
.46754 .41579 L
.48465 .41501 L
.49747 .41422 L
.51055 .41322 L
.53436 .41084 L
.55504 .40813 L
.57199 .40542 L
.60516 .3987 L
.65547 .38422 L
.69357 .3691 L
.72693 .35229 L
.75417 .33567 L
.77703 .31944 L
.7986 .30198 L
.8172 .28507 L
.83511 .26701 L
Mistroke
.85084 .24957 L
.86481 .23276 L
.87858 .21484 L
.89093 .19759 L
.9032 .17924 L
.9143 .16155 L
.92438 .14452 L
.93452 .12641 L
.94378 .10897 L
.95227 .0922 L
.9609 .07434 L
.96883 .05715 L
.97619 .04054 L
Mfstroke
0 0 1 r
[ ] 0 setdash
.02381 .34006 m
.20509 .36246 L
.30107 .37749 L
.33536 .38159 L
.36608 .38446 L
.37932 .38545 L
.39101 .3862 L
.41107 .38718 L
.42093 .38752 L
.42637 .38766 L
.4312 .38777 L
.43616 .38785 L
.43884 .38789 L
.44135 .38792 L
.44572 .38795 L
.44815 .38795 L
.45038 .38796 L
.4546 .38795 L
.45849 .38792 L
.46191 .38788 L
.46554 .38783 L
.46943 .38775 L
.47345 .38766 L
.48043 .38745 L
.48775 .38716 L
.49527 .38681 L
.50812 .38603 L
.52231 .38492 L
.53436 .38376 L
.57108 .37885 L
.58898 .37564 L
.60412 .37245 L
.65389 .35855 L
.69164 .3439 L
.72478 .32751 L
.75186 .31127 L
.77685 .29369 L
.79807 .27657 L
.8164 .25999 L
.83408 .24226 L
.84963 .22513 L
.86483 .2069 L
.87837 .1893 L
.89051 .17236 L
.90261 .15433 L
.91355 .13696 L
.92348 .12025 L
.9335 .10246 L
.94265 .08533 L
.9519 .06712 L
Mistroke
.9604 .04958 L
.96821 .03271 L
.97618 .01475 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[41]:=",
  ImageSize->{600, 294.25},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[41]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Ingestion\",ShowReport\[Rule] \"CompartmentContent\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Ingestion\>", \ "\<Acute\>", "\<CompartmentContent\>", 1, 
      fn1, 180, lambda]\)], "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    \({qST[180] \[Rule] 
        1.187581095080721153518773519628985`15.954589770191005*^-1883, 
      qSI[180] \[Rule] 0, qB[180] \[Rule] 4.367963330083658`*^-11, 
      q\_2[180] \[Rule] 1.5524566462309165`*^-8, 
      q\_3[180] \[Rule] 2.6148036370905773`*^-9, 
      q\_4[180] \[Rule] 7.068219596546917`*^-12, 
      qURI[180] \[Rule] 1.4186471182188892`*^-7, 
      qULI[180] \[Rule] 1.684102112016092`*^-11, 
      qLLI[180] \[Rule] 3.050664585847085`*^-11, 
      qFEC[180] \[Rule] 8.485216602411604`*^-9}\)], "Output",
  CellLabel->"Out[42]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Ingestion\>", \ "\<Constant\>", "\<CompartmentContent\>", 
      1, fn1, 180, lambda]\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \({qST[180] \[Rule] 0.04151678519477255`, qSI[180] \[Rule] 0, 
      qB[180] \[Rule] 0.3514605109687888`, 
      q\_2[180] \[Rule] 3.067291569202363`, 
      q\_3[180] \[Rule] 0.1840374760447921`, 
      q\_4[180] \[Rule] 0.05643575241471569`, 
      qURI[180] \[Rule] 7.816278055864485`, 
      qULI[180] \[Rule] 0.0011269136922541835`, 
      qLLI[180] \[Rule] 0.0018667067964402953`, 
      qFEC[180] \[Rule] 0.02154461117052108`, 
      qWB[180] \[Rule] 3.703735714314127`}\)], "Output",
  CellLabel->"Out[43]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
        element, "\<Ingestion\>", \ "\<Continuous\>", \
"\<CompartmentContent\>", inputs1, fn1, 180, lambda] // Chop\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \({qST[180] \[Rule] 0, qSI[180] \[Rule] 0, 
      qB[180] \[Rule] 2.5316953089900594`*^-10, 
      q\_2[180] \[Rule] 8.99833682934042`*^-8, 
      q\_3[180] \[Rule] 1.5155550830398473`*^-8, q\_4[180] \[Rule] 0, 
      qURI[180] \[Rule] 7.955977873642336`*^-7, qULI[180] \[Rule] 0, 
      qLLI[180] \[Rule] 1.7681790286403813`*^-10, 
      qFEC[180] \[Rule] 4.689539440576801`*^-8, 
      qWB[180] \[Rule] 1.0570748578917719`*^-7}\)], "Output",
  CellLabel->"Out[44]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Ingestion\>", \ "\<MultiInputs\>", \
"\<CompartmentContent\>", inputs2, fn1, 180, lambda]\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \("Option not available for MultiInputs intake"\)], "Output",
  CellLabel->"Out[45]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Ingestion\",ShowReport\[Rule] \"Disintegrations\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Ingestion\>", \ "\<Acute\>", "\<Disintegrations\>", 1, fn1, 
      180, lambda]\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \({qST[180] \[Rule] 3587.0502408283487`, qSI[180] \[Rule] 0, 
      qB[180] \[Rule] 30366.188147703353`, 
      q\_2[180] \[Rule] 265013.99157908413`, 
      q\_3[180] \[Rule] 15900.837930270021`, 
      q\_4[180] \[Rule] 4876.049008631437`, 
      qURI[180] \[Rule] 675326.4240266914`, 
      qULI[180] \[Rule] 97.36534301076144`, 
      qLLI[180] \[Rule] 161.28346721244162`, 
      qFEC[180] \[Rule] 1861.4544052193557`, 
      qWB[180] \[Rule] 320002.7657167405`}\)], "Output",
  CellLabel->"Out[46]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Ingestion\>", \ "\<Constant\>", "\<Disintegrations\>", 1, 
      fn1, 180, lambda]\)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \({qST[180] \[Rule] 645520.1205547714`, qSI[180] \[Rule] 0, 
      qB[180] \[Rule] 5.449427974571451`*^6, 
      q\_2[180] \[Rule] 4.477803053140588`*^7, 
      q\_3[180] \[Rule] 2.57656954375003`*^6, 
      q\_4[180] \[Rule] 874638.1757721993`, 
      qURI[180] \[Rule] 1.1334195057744111`*^8, 
      qULI[180] \[Rule] 15725.458915368692`, 
      qLLI[180] \[Rule] 25900.440423591972`, 
      qFEC[180] \[Rule] 277447.4073338537`, 
      qWB[180] \[Rule] 5.4365812245393306`*^7}\)], "Output",
  CellLabel->"Out[47]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
        element, "\<Ingestion\>", \ "\<Continuous\>", "\<Disintegrations\>", 
        inputs1, fn1, 180, lambda] // Chop\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \("Option not available for continuous intake"\)], "Output",
  CellLabel->"Out[48]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Ingestion\>", \ "\<MultiInputs\>", "\<Disintegrations\>", 
      inputs2, fn1, 180, lambda]\)], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \("Option not available for MultiInputs intake"\)], "Output",
  CellLabel->"Out[49]="]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inhalation", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Inhalation\",ShowReport\[Rule] \"Automatic\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Inhalation\>", \ "\<Acute\>", "\<Automatic\>", 1, \ amad, 
      class, \ fn1, t1, lambda]\)], "Input",
  CellLabel->"In[50]:="],

Cell[BoxData[
    \({qLungs[t1] \[Rule] 
        0.01006337724365423`\ \[ExponentialE]\^\(\(-110.08664339756999`\)\ t1\
\) + 0.00798948637352798`\ \[ExponentialE]\^\(\(-102.08664339756999`\)\ t1\) \
+ 0.010318191574724172`\ \[ExponentialE]\^\(\(-100.11664339756999`\)\ t1\) + 
          0.01615017914617113`\ \[ExponentialE]\^\(\(-100.10664339756998`\)\ \
t1\) + 0.`\ \[ExponentialE]\^\(\(-100.09664339756999`\)\ t1\) + 
          0.03193255793813499`\ \[ExponentialE]\^\(\(-100.08764339756999`\)\ \
t1\) + 0.00443273582045417`\ \[ExponentialE]\^\(\(-100.08676339757`\)\ t1\) + 
          0.0010879819033333337`\ \[ExponentialE]\^\(\(-100.08664339756999`\)\
\ t1\), qDailyUrine[t1] \[Rule] 
        7.788945328648337`*^82\ \[ExponentialE]\^\(\(-200.08664339757`\)\ \
t1\) + 1.296708135679509`*^43\ \[ExponentialE]\^\(\(-110.08664339756999`\)\ \
t1\) + 4.1147125004792286`*^39\ \[ExponentialE]\^\(\(-102.08664339756999`\)\ \
t1\) + 7.774113058302224`*^38\ \[ExponentialE]\^\(\(-100.11664339756999`\)\ \
t1\) + 1.2050063721221946`*^39\ \[ExponentialE]\^\(\(-100.10664339756998`\)\ \
t1\) + 2.3388305815118563`*^39\ \[ExponentialE]\^\(\(-100.08764339756999`\)\ \
t1\) + 3.2438757090174678`*^38\ \[ExponentialE]\^\(\(-100.08676339757`\)\ \
t1\) + 9.420323149399797`*^37\ \[ExponentialE]\^\(\(-100.08664339756999`\)\ \
t1\) + 5.505450609535855`*^8\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\
\) - 24994.990609571512`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t1\) + 
          2.3762620263035346`\ \[ExponentialE]\^\(\(-2.859187736240251`\)\ t1\
\) + 3.50946731933248`\ \[ExponentialE]\^\(\(-2.8591877362402403`\)\ t1\) + 
          1.1504202247807265`\ \[ExponentialE]\^\(\(-2.8591877362402367`\)\ \
t1\) - 0.00013863078773737646`\ \[ExponentialE]\^\(\(-0.14679047567383186`\)\ \
t1\) - 0.0003853133404994862`\ \[ExponentialE]\^\(\(-0.1467904756738283`\)\ \
t1\) - 0.0002902409656083066`\ \[ExponentialE]\^\(\(-0.14679047567381764`\)\ \
t1\) + 0.0002703145046395253`\ \[ExponentialE]\^\(\(-0.092967307839366`\)\ t1\
\) + 0.0003581510811113339`\ \[ExponentialE]\^\(\(-0.09296730783935535`\)\ t1\
\) + 0.00012907924735945653`\ \[ExponentialE]\^\(\(-0.0929673078393518`\)\ t1\
\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\), 
      qDailyFaecal[
          t1] \[Rule] \(-6.016831839532957`*^70\)\ \
\[ExponentialE]\^\(\(-200.08664339757`\)\ t1\) - 
          5.739060477644224`*^31\ \[ExponentialE]\^\(\(-110.08664339756999`\)\
\ t1\) - 2.2611882829956096`*^28\ \[ExponentialE]\^\(\(-102.08664339756999`\)\
\ t1\) - 4.528857329136862`*^27\ \[ExponentialE]\^\(\(-100.11664339756999`\)\ \
t1\) - 7.017078840884671`*^27\ \[ExponentialE]\^\(\(-100.10664339756998`\)\ \
t1\) - 1.3641661235744091`*^28\ \[ExponentialE]\^\(\(-100.08764339756999`\)\ \
t1\) - 1.887340900491311`*^27\ \[ExponentialE]\^\(\(-100.08676339757`\)\ t1\) \
- 5.490118630867796`*^26\ \[ExponentialE]\^\(\(-100.08664339756999`\)\ t1\) - 
          0.1449434295113652`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ \
t1\) + 0.000010907865643609977`\ \[ExponentialE]\^\(\(-2.859187736240251`\)\ \
t1\) + 0.000016109670388272626`\ \[ExponentialE]\^\(\(-2.8591877362402403`\)\ \
t1\) + 5.280827243248147`*^-6\ \[ExponentialE]\^\(\(-2.8591877362402367`\)\ \
t1\) - 0.000029984064536370534`\ \[ExponentialE]\^\(\(-1.8866433975700045`\)\ \
t1\) - 0.00004255186746821436`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ \
t1\) - 0.000014445196762325947`\ \[ExponentialE]\^\(\(-1.8866433975699903`\)\ \
t1\) + 0.000095750794785377`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\
\) - 0.000053051102545999176`\ \[ExponentialE]\^\(\(-0.14679047567383186`\)\ \
t1\) - 0.0001474513553071915`\ \[ExponentialE]\^\(\(-0.1467904756738283`\)\ \
t1\) - 0.00011106914618926804`\ \[ExponentialE]\^\(\(-0.14679047567381764`\)\ \
t1\) + 0.00009722419024187773`\ \[ExponentialE]\^\(\(-0.092967307839366`\)\ \
t1\) + 0.00012881642770793192`\ \[ExponentialE]\^\(\(-0.09296730783935535`\)\ \
t1\) + 0.00004642601520140309`\ \[ExponentialE]\^\(\(-0.0929673078393518`\)\ \
t1\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\), 
      qWholebody[t1] \[Rule] 
        0.00010779094387242116`\ \[ExponentialE]\^\(\(-200.08664339757`\)\ t1\
\) + 0.000021900257755225194`\ \[ExponentialE]\^\(\(-110.08664339756999`\)\ \
t1\) + 0.00002071583016319614`\ \[ExponentialE]\^\(\(-102.08664339756999`\)\ \
t1\) + 0.00002806556744617758`\ \[ExponentialE]\^\(\(-100.11664339756999`\)\ \
t1\) + 0.00004393951546604116`\ \[ExponentialE]\^\(\(-100.10664339756998`\)\ \
t1\) + 2.710505431213761`*^-20\ \[ExponentialE]\^\(\(-100.09664339756999`\)\ \
t1\) + 0.00008691931179619777`\ \[ExponentialE]\^\(\(-100.08764339756999`\)\ \
t1\) + 0.000012066016085432278`\ \[ExponentialE]\^\(\(-100.08676339757`\)\ t1\
\) + 3.504431783423129`*^-6\ \[ExponentialE]\^\(\(-100.08664339756999`\)\ \
t1\) + 0.02078381677319397`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ \
t1\) - 0.15357547367497443`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ \
t1\) + 0.1584256957092418`\ \[ExponentialE]\^\(\(-2.859187736240251`\)\ t1\) \
+ 0.23397663872068392`\ \[ExponentialE]\^\(\(-2.8591877362402403`\)\ t1\) + 
          0.07669866473117262`\ \[ExponentialE]\^\(\(-2.8591877362402367`\)\ \
t1\) - 5.937853037797355`*^-6\ \[ExponentialE]\^\(\(-1.8866433975700045`\)\ \
t1\) - 8.426700629716386`*^-6\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ \
t1\) - 2.8606347005662393`*^-6\ \[ExponentialE]\^\(\(-1.8866433975699903`\)\ \
t1\) + 0.3387553247322293`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ t1\) \
- 0.0030920059075871757`\ \[ExponentialE]\^\(\(-0.14679047567383186`\)\ t1\) \
- 0.008593986549031355`\ \[ExponentialE]\^\(\(-0.1467904756738283`\)\ t1\) - 
          0.006473502711280858`\ \[ExponentialE]\^\(\(-0.14679047567381764`\)\
\ t1\) + 0.057935322180423354`\ \[ExponentialE]\^\(\(-0.092967307839366`\)\ \
t1\) + 0.07676095036467756`\ \[ExponentialE]\^\(\(-0.09296730783935535`\)\ t1\
\) + 0.02766498894525106`\ \[ExponentialE]\^\(\(-0.0929673078393518`\)\ t1\) \
+ 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\)}\)], "Output",
  CellLabel->"Out[50]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Inhalation\>", \ "\<Constant\>", "\<Automatic\>", 1, \ 
      amad, class, \ fn1, t1, lambda]\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \({qLungs[
          t1] \[Rule] \(\(0.0008082717969697772`\)\(\[InvisibleSpace]\)\) - 
          0.00009141324445065574`\ \
\[ExponentialE]\^\(\(-110.08664339756999`\)\ t1\) - 
          0.00007826181866332336`\ \
\[ExponentialE]\^\(\(-102.08664339756999`\)\ t1\) - 
          0.00010306170107751148`\ \
\[ExponentialE]\^\(\(-100.11664339756999`\)\ t1\) - 
          0.00016132974394148116`\ \
\[ExponentialE]\^\(\(-100.10664339756998`\)\ t1\) - 
          0.0003190459566651189`\ \[ExponentialE]\^\(\(-100.08764339756999`\)\
\ t1\) - 0.000044288931622718376`\ \[ExponentialE]\^\(\(-100.08676339757`\)\ \
t1\) - 0.000010870400548968245`\ \[ExponentialE]\^\(\(-100.08664339756999`\)\ \
t1\), qDailyUrine[
          t1] \[Rule] \(\(0.31245257219193556`\)\(\[InvisibleSpace]\)\) - 
          3.892786243193521`*^80\ \[ExponentialE]\^\(\(-200.08664339757`\)\ \
t1\) - 1.1778977863795264`*^41\ \[ExponentialE]\^\(\(-110.08664339756999`\)\ \
t1\) - 4.0306080830326764`*^37\ \[ExponentialE]\^\(\(-102.08664339756999`\)\ \
t1\) - 7.765055633587954`*^36\ \[ExponentialE]\^\(\(-100.11664339756999`\)\ \
t1\) - 1.2037226813574662`*^37\ \[ExponentialE]\^\(\(-100.10664339756998`\)\ \
t1\) - 2.336782545894795`*^37\ \[ExponentialE]\^\(\(-100.08764339756999`\)\ \
t1\) - 3.241063652075499`*^36\ \[ExponentialE]\^\(\(-100.08676339757`\)\ t1\) \
- 9.41216812714937`*^35\ \[ExponentialE]\^\(\(-100.08664339756999`\)\ t1\) - 
          2.2856861035652973`*^7\ \[ExponentialE]\^\(\(-24.086643397569993`\)\
\ t1\) + 2067.9844508854076`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t1\
\) - 0.8310968867781485`\ \[ExponentialE]\^\(\(-2.859187736240251`\)\ t1\) - 
          1.2274350770500084`\ \[ExponentialE]\^\(\(-2.8591877362402403`\)\ \
t1\) - 0.402359107168493`\ \[ExponentialE]\^\(\(-2.8591877362402367`\)\ t1\) \
+ 0.0009444126882279039`\ \[ExponentialE]\^\(\(-0.14679047567383186`\)\ t1\) \
+ 0.002624920579695253`\ \[ExponentialE]\^\(\(-0.1467904756738283`\)\ t1\) + 
          0.001977246577313699`\ \[ExponentialE]\^\(\(-0.14679047567381764`\)\
\ t1\) - 0.0029076296917900923`\ \[ExponentialE]\^\(\(-0.092967307839366`\)\ \
t1\) - 0.0038524411369446065`\ \[ExponentialE]\^\(\(-0.09296730783935535`\)\ \
t1\) - 0.0013884369716557488`\ \[ExponentialE]\^\(\(-0.0929673078393518`\)\ \
t1\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\), 
      qDailyFaecal[
          t1] \[Rule] \(\(0.0008612410526644011`\)\(\[InvisibleSpace]\)\) - 
          3.81502253432071`*^-6\ \[ExponentialE]\^\(\(-2.859187736240251`\)\ \
t1\) - 5.63435208681205`*^-6\ \[ExponentialE]\^\(\(-2.8591877362402403`\)\ t1\
\) - 1.846967646200213`*^-6\ \[ExponentialE]\^\(\(-2.8591877362402367`\)\ \
t1\) + 0.000015892809724927347`\ \[ExponentialE]\^\(\(-1.8866433975700045`\)\ \
t1\) + 0.00002255427152954362`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ \
t1\) + 7.656559146753149`*^-6\ \[ExponentialE]\^\(\(-1.8866433975699903`\)\ \
t1\) - 0.00008811611518507337`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ \
t1\) + 0.00036140698027219836`\ \[ExponentialE]\^\(\(-0.14679047567383186`\)\ \
t1\) + 0.0010045021969601851`\ \[ExponentialE]\^\(\(-0.1467904756738283`\)\ \
t1\) + 0.0007566509044910665`\ \[ExponentialE]\^\(\(-0.14679047567381764`\)\ \
t1\) - 0.0010457890252116298`\ \[ExponentialE]\^\(\(-0.092967307839366`\)\ t1\
\) - 0.0013856099601219363`\ \[ExponentialE]\^\(\(-0.09296730783935535`\)\ t1\
\) - 0.0004993800108918783`\ \[ExponentialE]\^\(\(-0.0929673078393518`\)\ \
t1\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t1\), 
      qWholebody[
          t1] \[Rule] \(\(5.861735589759599`\)\(\[InvisibleSpace]\)\) + 
          9.054172342426448`*^-15\ \[ExponentialE]\^\(\(-200.08664339757`\)\ \
t1\) - 5.487090695818677`*^-11\ \[ExponentialE]\^\(\(-110.08664339756999`\)\ \
t1\) - 5.543536464559188`*^-11\ \[ExponentialE]\^\(\(-102.08664339756999`\)\ \
t1\) - 7.638071819720659`*^-11\ \[ExponentialE]\^\(\(-100.11664339756999`\)\ \
t1\) + 1.3814660136321488`*^-14\ \[ExponentialE]\^\(\(-100.10664339756998`\)\ \
t1\) - 4.235164736271502`*^-22\ \[ExponentialE]\^\(\(-100.09664339756999`\)\ \
t1\) + 2.7337127787158133`*^-14\ \[ExponentialE]\^\(\(-100.08764339756999`\)\ \
t1\) - 4.9629336264808786`*^-11\ \[ExponentialE]\^\(\(-100.08676339757`\)\ t1\
\) - 9.539815762165098`*^-12\ \[ExponentialE]\^\(\(-100.08664339756999`\)\ t1\
\) + 6.444107400471744`*^-11\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ t1\
\) + 0.`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t1\) + 
          2.0816681711721685`*^-17\ \
\[ExponentialE]\^\(\(-2.859187736240251`\)\ t1\) + 
          1.3877787807814457`*^-17\ \[ExponentialE]\^\(\(-2.8591877362402403`\
\)\ t1\) + 
          6.938893903907228`*^-18\ \
\[ExponentialE]\^\(\(-2.8591877362402367`\)\ t1\) - 
          8.470329472543003`*^-22\ \
\[ExponentialE]\^\(\(-1.8866433975700045`\)\ t1\) + 
          0.`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ t1\) + 
          0.`\ \[ExponentialE]\^\(\(-1.8866433975699903`\)\ t1\) - 
          0.31169342284452944`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ \
t1\) + 2.0816681711721685`*^-17\ \[ExponentialE]\^\(\(-0.14679047567383186`\)\
\ t1\) + 5.551115123125783`*^-17\ \[ExponentialE]\^\(\(-0.1467904756738283`\)\
\ t1\) + 3.469446951953614`*^-17\ \
\[ExponentialE]\^\(\(-0.14679047567381764`\)\ t1\) - 
          2.220446049250313`*^-16\ \[ExponentialE]\^\(\(-0.092967307839366`\)\
\ t1\) + 0.`\ \[ExponentialE]\^\(\(-0.09296730783935535`\)\ t1\) + 
          0.`\ \[ExponentialE]\^\(\(-0.0929673078393518`\)\ t1\) - 
          5.550042166935283`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ \
t1\)}\)], "Output",
  CellLabel->"Out[51]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Inhalation\>", \ "\<Continuous\>", "\<Automatic\>", 
      inputs1, \ amad, class, \ fn1, t, lambda]\)], "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    \("Option not available for inhalation"\)], "Output",
  CellLabel->"Out[52]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Inhalation\>", \ "\<MultiInputs\>", "\<Automatic\>", 
      inputs2, \ amad, class, \ fn1, t, lambda]\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    \({qLungs[t] \[Rule] 
        0.07044364070557961`\ \[ExponentialE]\^\(\(-110.08664339756999`\)\ \
t\) + 0.05592640461469586`\ \[ExponentialE]\^\(\(-102.08664339756999`\)\ t\) \
+ 0.0722273410230692`\ \[ExponentialE]\^\(\(-100.11664339756999`\)\ t\) + 
          0.11305125402319792`\ \[ExponentialE]\^\(\(-100.10664339756998`\)\ \
t\) + 0.`\ \[ExponentialE]\^\(\(-100.09664339756999`\)\ t\) + 
          0.2235279055669449`\ \[ExponentialE]\^\(\(-100.08764339756999`\)\ t\
\) + 0.03102915074317919`\ \[ExponentialE]\^\(\(-100.08676339757`\)\ t\) + 
          0.007615873323333336`\ \[ExponentialE]\^\(\(-100.08664339756999`\)\ \
t\), qDailyUrine[t] \[Rule] 
        5.452261730053836`*^83\ \[ExponentialE]\^\(\(-200.08664339757`\)\ t\) \
+ 9.076956949756564`*^43\ \[ExponentialE]\^\(\(-110.08664339756999`\)\ t\) + 
          2.88029875033546`*^40\ \[ExponentialE]\^\(\(-102.08664339756999`\)\ \
t\) + 5.441879140811557`*^39\ \[ExponentialE]\^\(\(-100.11664339756999`\)\ \
t\) + 8.435044604855362`*^39\ \[ExponentialE]\^\(\(-100.10664339756998`\)\ \
t\) + 1.6371814070582993`*^40\ \[ExponentialE]\^\(\(-100.08764339756999`\)\ t\
\) + 2.2707129963122275`*^39\ \[ExponentialE]\^\(\(-100.08676339757`\)\ t\) + 
          6.594226204579858`*^38\ \[ExponentialE]\^\(\(-100.08664339756999`\)\
\ t\) + 3.8538154266750984`*^9\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ \
t\) - 174964.934269381`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t\) + 
          16.657252638690263`\ \[ExponentialE]\^\(\(-2.859187736240251`\)\ \
t\) + 24.600857615136164`\ \[ExponentialE]\^\(\(-2.8591877362402403`\)\ t\) + 
          8.064279154702788`\ \[ExponentialE]\^\(\(-2.8591877362402367`\)\ \
t\) - 0.001337959211085631`\ \[ExponentialE]\^\(\(-0.14679047567383186`\)\ \
t\) - 0.003718752100378274`\ \[ExponentialE]\^\(\(-0.1467904756738283`\)\ t\) \
- 0.0028011856508071147`\ \[ExponentialE]\^\(\(-0.14679047567381764`\)\ t\) + 
          0.0027202961113071654`\ \[ExponentialE]\^\(\(-0.092967307839366`\)\ \
t\) + 0.0036042349799425694`\ \[ExponentialE]\^\(\(-0.09296730783935535`\)\ t\
\) + 0.0012989823654140735`\ \[ExponentialE]\^\(\(-0.0929673078393518`\)\ t\) \
+ 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t\), 
      qDailyFaecal[
          t] \[Rule] \(-4.2117822876730696`*^71\)\ \
\[ExponentialE]\^\(\(-200.08664339757`\)\ t\) - 
          4.017342334350957`*^32\ \[ExponentialE]\^\(\(-110.08664339756999`\)\
\ t\) - 1.5828317980969268`*^29\ \[ExponentialE]\^\(\(-102.08664339756999`\)\ \
t\) - 3.170200130395803`*^28\ \[ExponentialE]\^\(\(-100.11664339756999`\)\ \
t\) - 4.91195518861927`*^28\ \[ExponentialE]\^\(\(-100.10664339756998`\)\ t\) \
- 9.549162865020864`*^28\ \[ExponentialE]\^\(\(-100.08764339756999`\)\ t\) - 
          1.3211386303439178`*^28\ \[ExponentialE]\^\(\(-100.08676339757`\)\ \
t\) - 3.843083041607457`*^27\ \[ExponentialE]\^\(\(-100.08664339756999`\)\ \
t\) - 1.0146040065795565`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ t\) + 
          0.00007646255832196349`\ \[ExponentialE]\^\(\(-2.859187736240251`\)\
\ t\) + 0.0001129264561791249`\ \[ExponentialE]\^\(\(-2.8591877362402403`\)\ \
t\) + 0.000037017834127029236`\ \[ExponentialE]\^\(\(-2.8591877362402367`\)\ \
t\) - 0.00021195559485325197`\ \[ExponentialE]\^\(\(-1.8866433975700045`\)\ t\
\) - 0.0003007966571844182`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ t\) \
- 0.00010211224928552263`\ \[ExponentialE]\^\(\(-1.8866433975699903`\)\ t\) + 
          0.000703086858222935`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ \
t\) - 0.0005120090022436689`\ \[ExponentialE]\^\(\(-0.14679047567383186`\)\ t\
\) - 0.0014230886388242568`\ \[ExponentialE]\^\(\(-0.1467904756738283`\)\ t\) \
- 0.0010719551525081859`\ \[ExponentialE]\^\(\(-0.14679047567381764`\)\ t\) + 
          0.0009784106368715272`\ \[ExponentialE]\^\(\(-0.092967307839366`\)\ \
t\) + 0.0012963374933715392`\ \[ExponentialE]\^\(\(-0.09296730783935535`\)\ t\
\) + 0.00046720581562679917`\ \[ExponentialE]\^\(\(-0.0929673078393518`\)\ \
t\) + 0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t\), 
      qWholebody[t] \[Rule] 
        0.0007545366071065596`\ \[ExponentialE]\^\(\(-200.08664339757`\)\ t\) \
+ 0.00015330180428657636`\ \[ExponentialE]\^\(\(-110.08664339756999`\)\ t\) + 
          0.000145010811142373`\ \[ExponentialE]\^\(\(-102.08664339756999`\)\ \
t\) + 0.00019645897212324306`\ \[ExponentialE]\^\(\(-100.11664339756999`\)\ t\
\) + 0.00030757660826228814`\ \[ExponentialE]\^\(\(-100.10664339756998`\)\ \
t\) + 7.215636508434153`*^-16\ \[ExponentialE]\^\(\(-100.09664339756999`\)\ t\
\) + 0.0006084351825800388`\ \[ExponentialE]\^\(\(-100.08764339756999`\)\ t\) \
+ 0.00008446211309796805`\ \[ExponentialE]\^\(\(-100.08676339757`\)\ t\) + 
          0.00002453102197662923`\ \
\[ExponentialE]\^\(\(-100.08664339756999`\)\ t\) + 
          0.1454867174123578`\ \[ExponentialE]\^\(\(-24.086643397569993`\)\ t\
\) - 1.075028315739447`\ \[ExponentialE]\^\(\(-12.086643397569993`\)\ t\) + 
          1.1105411813503523`\ \[ExponentialE]\^\(\(-2.859187736240251`\)\ \
t\) + 1.6401423494465046`\ \[ExponentialE]\^\(\(-2.8591877362402403`\)\ t\) + 
          0.5376465311212909`\ \[ExponentialE]\^\(\(-2.8591877362402367`\)\ t\
\) - 0.000041974335108934235`\ \[ExponentialE]\^\(\(-1.8866433975700045`\)\ t\
\) - 0.000059567852865821295`\ \[ExponentialE]\^\(\(-1.8866433975699939`\)\ t\
\) - 0.000020221659037616436`\ \[ExponentialE]\^\(\(-1.8866433975699903`\)\ t\
\) + 2.4874406265361575`\ \[ExponentialE]\^\(\(-1.0866433975699932`\)\ t\) - 
          0.02984169571787028`\ \[ExponentialE]\^\(\(-0.14679047567383186`\)\ \
t\) - 0.08294263958887144`\ \[ExponentialE]\^\(\(-0.1467904756738283`\)\ t\) \
- 0.062477337984648426`\ \[ExponentialE]\^\(\(-0.14679047567381764`\)\ t\) + 
          0.5830291343222547`\ \[ExponentialE]\^\(\(-0.092967307839366`\)\ \
t\) + 0.7724798750837789`\ \[ExponentialE]\^\(\(-0.09296730783935535`\)\ t\) \
+ 0.27840519304533884`\ \[ExponentialE]\^\(\(-0.0929673078393518`\)\ t\) + 
          0.`\ \[ExponentialE]\^\(\(-0.08664339756999316`\)\ t\)}\)], "Output",\

  CellLabel->"Out[53]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Inhalation\",ShowReport\[Rule] \"BioassayTable\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Inhalation\>", \ "\<Acute\>", "\<BioassayTable\>", 1, \ 
      amad, class, \ fn1, 180, lambda]\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nintake"\), \("Lung\nretention"\), \("Urine\n24 \
hours"\), \("Faecal\n24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "2.1950568164839258`*^-45", "0.28179457831587557`", 
            "2.1153390345835146`*^-7", "0.27342835202852595`"},
          {"2", "0", "0.023135225186400543`", "2.936634448210609`*^-6", 
            "0.1613655433572524`"},
          {"3", "0", "0.0013737879132246966`", "8.942278232341233`*^-6", 
            "0.12424723346569642`"},
          {"4", "0", "0.00014560797340869703`", "0.000015841589217686902`", 
            "0.10623645973600314`"},
          {"5", "0", "0.00008945487056586466`", "0.000022028349801900604`", 
            "0.09476509276690531`"},
          {"6", "0", "0.00009645797858414554`", "0.000026979045660509648`", 
            "0.08591876848900715`"},
          {"7", "0", "0.00010379490673896911`", "0.000030669910698076284`", 
            "0.07836402796671728`"},
          {"8", "0", "0.00010848142455399667`", "0.00003324426461242397`", 
            "0.0716207882985698`"},
          {"9", "0", "0.00011086388245906581`", "0.00003488117279962411`", 
            "0.06549787676511114`"},
          {"10", "0", "0.00011139531017716715`", "0.00003575118978217238`", 
            "0.05990356226890942`"},
          {"20", "0", "0.00007478289335304065`", "0.000025902711568391602`", 
            "0.02432768987833538`"},
          {"30", "0", "0.00003661601189196304`", "0.000012940563984637193`", 
            "0.009760087442683845`"},
          {"40", "0", "0.00001608771642862966`", "5.7334835133209146`*^-6", 
            "0.0038886272270175705`"},
          {"50", "0", "6.726492871715882`*^-6", "2.4071574393370644`*^-6", 
            "0.0015431814031032936`"},
          {"60", "0", "2.741682513126913`*^-6", "9.832998932992441`*^-7", 
            "0.0006110041707903937`"},
          {"70", "0", "1.102106086618879`*^-6", "3.9574941108368835`*^-7", 
            "0.00024159911934972574`"},
          {"80", "0", "4.395930034831511`*^-7", "1.5795990134516945`*^-7", 
            "0.00009545783571737636`"},
          {"90", "0", "1.745621205919118`*^-7", "6.275058581066383`*^-8", 
            "0.00003769925293406007`"},
          {"100", "0", "6.914142810561606`*^-8", "2.486024237041859`*^-8", 
            "0.000014884703123033057`"},
          {"180", "0", "4.091150079531786`*^-11", "1.4714602835195082`*^-11", 
            "8.76890615304822`*^-9"},
          {"200", "0", "6.373246517170143`*^-12", "2.292266307720908`*^-12", 
            "1.3659777710571156`*^-9"},
          {"300", "0", "5.845903707117204`*^-16", "2.1025998997653079`*^-16", 
            "1.2529270186400376`*^-13"},
          {"400", "0", "5.362074248856476`*^-20", "1.9285806639978774`*^-20", 
            "1.1492298562041741`*^-17"},
          {"500", "0", "4.9182878671933804`*^-24", "1.7689637331973754`*^-24",
             "1.0541150669769832`*^-21"},
          {"600", "0", "4.511230992059216`*^-28", "1.6225573273630223`*^-28", 
            "9.668723522750809`*^-26"},
          {"700", "0", "4.137863747104409`*^-32", "1.4882680923131984`*^-32", 
            "8.868501882576241`*^-30"},
          {"800", "0", "3.795397845926657`*^-36", "1.3650931632725111`*^-36", 
            "8.13450973711179`*^-34"},
          {"900", "0", "3.481275771607134`*^-40", "1.2521126764942774`*^-40", 
            "7.461265672522464`*^-38"},
          {"1000", "0", "3.1931516773191577`*^-44", 
            "1.1484828997972527`*^-44", "6.843741938371358`*^-42"},
          {"2000", "0", "0", "0", "0"},
          {"3000", "0", "0", "0", "0"},
          {"4000", "0", "0", "0", "0"},
          {"5000", "0", "0", "0", "0"},
          {"6000", "0", "0", "0", "0"},
          {"7000", "0", "0", "0", "0"},
          {"8000", "0", "0", "0", "0"},
          {"9000", "0", "0", "0", "0"},
          {"10000", "0", "0", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nintake", 
          "Lung\nretention", "Urine\n24 hours", "Faecal\n24 hours", 
          "Wholebody"}}]]]], "Output",
  CellLabel->"Out[54]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Inhalation\>", \ "\<Constant\>", "\<BioassayTable\>", 1, \ 
      amad, class, \ fn1, 180, lambda]\)], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nintake"\), \("Thoracic\nLung"\), \("Urine\n24 \
hours"\), \("Faecal\n24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "0.0008082717969697772`", "0.17962794777176772`", 
            "3.950454241047363`*^-8", "0.667175661877839`"},
          {"2", "0.0008082717969697772`", "0.3017380392584555`", 
            "1.2850048288147783`*^-6", "1.1592533946491699`"},
          {"3", "0.0008082717969697772`", "0.3093948246093595`", 
            "7.0462418929219084`*^-6", "1.5701017876228374`"},
          {"4", "0.0008082717969697772`", "0.3098914314507195`", 
            "0.000019451913107852798`", "1.9332263610760814`"},
          {"5", "0.0008082717969697772`", "0.30999425260557545`", 
            "0.000038479589611808117`", "2.2616166895244527`"},
          {"6", "0.0008082717969697772`", "0.31008666835244236`", 
            "0.00006309150404568796`", "2.561201375916611`"},
          {"7", "0.0008082717969697772`", "0.3101870103160762`", 
            "0.000092016136802894`", "2.8353986637251576`"},
          {"8", "0.0008082717969697772`", "0.3102933603455731`", 
            "0.00012405885939628024`", "3.086662225544594`"},
          {"9", "0.0008082717969697772`", "0.3104032052556098`", 
            "0.0001581923146864854`", "3.3170123994916834`"},
          {"10", "0.0008082717969697772`", "0.31051447189889836`", 
            "0.0001935658177797456`", "3.5282243587146658`"},
          {"20", "0.0008082717969697772`", "0.3114776981928009`", 
            "0.0005173824584067755`", "4.880617476618225`"},
          {"30", "0.0008082717969697772`", "0.3120194346298826`", 
            "0.0007070151924531542`", "5.449226237666812`"},
          {"40", "0.0008082717969697772`", "0.3122704750805445`", 
            "0.0007961057356540499`", "5.688296772042872`"},
          {"50", "0.0008082717969697772`", "0.31237813366833445`", 
            "0.0008345505715133851`", "5.78881354971768`"},
          {"60", "0.0008082717969697772`", "0.31242260091964447`", 
            "0.0008504803599604094`", "5.83107564872748`"},
          {"70", "0.0008082717969697772`", "0.312440606722558`", 
            "0.0008569418240486817`", "5.848844672506699`"},
          {"80", "0.0008082717969697772`", "0.31244781821734646`", 
            "0.0008595322012451868`", "5.8563156267059515`"},
          {"90", "0.0008082717969697772`", "0.31245068864307246`", 
            "0.0008605638289970689`", "5.8594567760082885`"},
          {"100", "0.0008082717969697772`", "0.3124518271202308`", 
            "0.000860973126061735`", "5.860777466602345`"},
          {"180", "0.0008082717969697772`", "0.3124525717518609`", 
            "0.0008612408943831119`", "5.861734654092453`"},
          {"200", "0.0008082717969697772`", "0.3124525721233815`", 
            "0.0008612410280074874`", "5.861735424355453`"},
          {"300", "0.0008082717969697772`", "0.3124525721919289`", 
            "0.000861241052662139`", "5.861735589731045`"},
          {"400", "0.0008082717969697772`", "0.31245257219193556`", 
            "0.0008612410526644011`", "5.8617355897595935`"},
          {"500", "0.0008082717969697772`", "0.31245257219193556`", 
            "0.0008612410526644011`", "5.861735589759599`"},
          {"600", "0.0008082717969697772`", "0.31245257219193556`", 
            "0.0008612410526644011`", "5.861735589759599`"},
          {"700", "0.0008082717969697772`", "0.31245257219193556`", 
            "0.0008612410526644011`", "5.861735589759599`"},
          {"800", "0.0008082717969697772`", "0.31245257219193556`", 
            "0.0008612410526644011`", "5.861735589759599`"},
          {"900", "0.0008082717969697772`", "0.31245257219193556`", 
            "0.0008612410526644011`", "5.861735589759599`"},
          {"1000", "0.0008082717969697772`", "0.31245257219193556`", 
            "0.0008612410526644011`", "5.861735589759599`"},
          {"2000", "0.0008082717969697772`", "0.31245257219193556`", 
            "0.0008612410526644011`", "5.861735589759599`"},
          {"3000", "0.0008082717969697772`", "0.31245257219193556`", 
            "0.0008612410526644011`", "5.861735589759599`"},
          {"4000", "0.0008082717969697772`", "0.31245257219193556`", 
            "0.0008612410526644011`", "5.861735589759599`"},
          {"5000", "0.0008082717969697772`", "0.31245257219193556`", 
            "0.0008612410526644011`", "5.861735589759599`"},
          {"6000", "0.0008082717969697772`", "0.31245257219193556`", 
            "0.0008612410526644011`", "5.861735589759599`"},
          {"7000", "0.0008082717969697772`", "0.31245257219193556`", 
            "0.0008612410526644011`", "5.861735589759599`"},
          {"8000", "0.0008082717969697772`", "0.31245257219193556`", 
            "0.0008612410526644011`", "5.861735589759599`"},
          {"9000", "0.0008082717969697772`", "0.31245257219193556`", 
            "0.0008612410526644011`", "5.861735589759599`"},
          {"10000", "0.0008082717969697772`", "0.31245257219193556`", 
            "0.0008612410526644011`", "5.861735589759599`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nintake", 
          "Thoracic\nLung", "Urine\n24 hours", "Faecal\n24 hours", 
          "Wholebody"}}]]]], "Output",
  CellLabel->"Out[55]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
        element, "\<Inhalation\>", \ "\<Continuous\>", "\<BioassayTable\>", 
        inputs1, \ amad, class, \ fn1, 180, lambda] // Chop\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \("Option not available for inhalation"\)], "Output",
  CellLabel->"Out[56]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Inhalation\>", \ "\<MultiInputs\>", "\<BioassayTable\>", 
      inputs2, \ amad, class, fn1, 180, lambda]\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nlast intake"\), "\<\"Lung\"\>", \("Urine\n24 hours"\
\), \("Faecal\n24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "1.536539771538759`*^-44", "1.9767872068575432`", 
            "0.00005897748271931931`", "2.3651041925634884`"},
          {"2", "0", "0.16249188164958348`", "0.00010132547340295847`", 
            "1.519888971007346`"},
          {"3", "0", "0.009995743886729443`", "0.00016356216983173208`", 
            "1.2195237893257018`"},
          {"4", "0", "0.0014200250597905858`", "0.0002275794512875265`", 
            "1.0613150858879528`"},
          {"5", "0", "0.0010480321546529406`", "0.00028221223633424113`", 
            "0.9532293270727011`"},
          {"6", "0", "0.0011090413317111241`", "0.0003243533019381047`", 
            "0.8663832646917171`"},
          {"7", "0", "0.001164603081913228`", "0.000354480389134356`", 
            "0.7908330976950739`"},
          {"8", "0", "0.0011954084562743783`", "0.0003741973982231229`", 
            "0.7229107557224443`"},
          {"9", "0", "0.0012052270287987812`", "0.00038528067607543814`", 
            "0.6610797724367415`"},
          {"10", "0", "0.0011983487621275682`", "0.0003893670187665806`", 
            "0.6045435360018709`"},
          {"20", "0", "0.0007703907230639064`", "0.00026748876894334484`", 
            "0.2452178419329703`"},
          {"30", "0", "0.00037258850894401663`", "0.0001317976576346052`", 
            "0.0983116988499669`"},
          {"40", "0", "0.00016284376659485026`", "0.00005806057719320739`", 
            "0.039154096407928086`"},
          {"50", "0", "0.00006790964842529024`", "0.000024307703628940933`", 
            "0.01553458742609584`"},
          {"60", "0", "0.000027640994480758942`", "9.914603567714454`*^-6", 
            "0.006149928997688879`"},
          {"70", "0", "0.000011102557497087052`", "3.987031280029871`*^-6", 
            "0.0024315783555858366`"},
          {"80", "0", "4.426487299429463`*^-6", "1.5906414576447496`*^-6", 
            "0.0009606944749861939`"},
          {"90", "0", "1.7573111236639147`*^-6", "6.317223349054568`*^-7", 
            "0.0003793981916146421`"},
          {"100", "0", "6.959427220066832`*^-7", "2.502339258483457`*^-7", 
            "0.00014979460052998338`"},
          {"180", "0", "4.117119076415449`*^-10", "1.4808007880048468`*^-10", 
            "8.824546103190745`*^-8"},
          {"200", "0", "6.413689813176447`*^-11", "2.3068126899492598`*^-11", 
            "1.3746448358248383`*^-8"},
          {"300", "0", "5.8829951469961214`*^-15", "2.115940602085632`*^-15", 
            "1.2608766601778727`*^-12"},
          {"400", "0", "5.396095835641938`*^-19", "1.9408172298117197`*^-19", 
            "1.1565215536641866`*^-16"},
          {"500", "0", "4.949493693379236`*^-23", "1.7801875525981455`*^-23", 
            "1.0608032748341483`*^-20"},
          {"600", "0", "4.5398541011478976`*^-27", "1.63285221926577`*^-27", 
            "9.730070177076676`*^-25"},
          {"700", "0", "4.164117894974986`*^-31", "1.497710938414298`*^-31", 
            "8.924771246168977`*^-29"},
          {"800", "0", "3.8194790971071346`*^-35", "1.3737544822362636`*^-35",
             "8.186122026549867`*^-33"},
          {"900", "0", "3.5033639635522784`*^-39", "1.2600571505889693`*^-39",
             "7.508606325605431`*^-37"},
          {"1000", "0", "3.2134117635079353`*^-43", 
            "1.1557698579194343`*^-43", "6.887164492548316`*^-41"},
          {"2000", "0", "0", "0", "0"},
          {"3000", "0", "0", "0", "0"},
          {"4000", "0", "0", "0", "0"},
          {"5000", "0", "0", "0", "0"},
          {"6000", "0", "0", "0", "0"},
          {"7000", "0", "0", "0", "0"},
          {"8000", "0", "0", "0", "0"},
          {"9000", "0", "0", "0", "0"},
          {"10000", "0", "0", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nlast intake", 
          "Lung", "Urine\n24 hours", "Faecal\n24 hours", 
          "Wholebody"}}]]]], "Output",
  CellLabel->"Out[57]//TableForm="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Inhalation\",ShowReport\[Rule] \"GraphicReport\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Inhalation\>", \ "\<Acute\>", "\<GraphicReport\>", 1, \ 
      amad, class, \ fn1, 180, lambda]\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    RowBox[{\(ParametricPlot::"pptr"\), \(\(:\)\(\ \)\), \
"\<\"\\!\\({\\(Log[Biokmod`Humorap3`Private`t3$40053]\\)\\/\\(Log[10]\\), \
\\(Log[\\(\\(\\(\\(\[LeftSkeleton] 33 \[RightSkeleton]\\)\\)[\\(\\(\
\[LeftSkeleton] 33 \[RightSkeleton]\\)\\)]\\)\\)]\\)\\/\\(Log[10]\\)}\\) does \
not evaluate to a pair of real numbers at \
\\!\\(Biokmod`Humorap3`Private`t3$40053\\) = \\!\\(8.261491491551926`\\). \\!\
\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"ParametricPlot::pptr\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[58]:="],

Cell[BoxData[
    RowBox[{\(ParametricPlot::"pptr"\), \(\(:\)\(\ \)\), \
"\<\"\\!\\({\\(Log[Biokmod`Humorap3`Private`t3$40053]\\)\\/\\(Log[10]\\), \
\\(Log[\\(\\(\\(\\(\[LeftSkeleton] 33 \[RightSkeleton]\\)\\)[\\(\\(\
\[LeftSkeleton] 33 \[RightSkeleton]\\)\\)]\\)\\)]\\)\\/\\(Log[10]\\)}\\) does \
not evaluate to a pair of real numbers at \
\\!\\(Biokmod`Humorap3`Private`t3$40053\\) = \\!\\(16.18077517482789`\\). \\!\
\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"ParametricPlot::pptr\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[58]:="],

Cell[BoxData[
    RowBox[{\(ParametricPlot::"pptr"\), \(\(:\)\(\ \)\), \
"\<\"\\!\\({\\(Log[Biokmod`Humorap3`Private`t3$40053]\\)\\/\\(Log[10]\\), \
\\(Log[\\(\\(\\(\\(\[LeftSkeleton] 33 \[RightSkeleton]\\)\\)[\\(\\(\
\[LeftSkeleton] 33 \[RightSkeleton]\\)\\)]\\)\\)]\\)\\/\\(Log[10]\\)}\\) does \
not evaluate to a pair of real numbers at \
\\!\\(Biokmod`Humorap3`Private`t3$40053\\) = \\!\\(7.247549022562476`\\). \\!\
\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"ParametricPlot::pptr\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[58]:="],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(ParametricPlot :: \\\"pptr\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[58]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.422291 0.603319 0.0370835 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .00998 -50.6875 -6.6875 ]
[-0.0125 .00998 0 6.6875 ]
[-0.0125 .12123 -50.6875 -6.6875 ]
[-0.0125 .12123 0 6.6875 ]
[-0.0125 .23248 -50.6875 -6.6875 ]
[-0.0125 .23248 0 6.6875 ]
[-0.0125 .34373 -46.5 -6.625 ]
[-0.0125 .34373 0 6.625 ]
[-0.0125 .45498 -40 -6.28125 ]
[-0.0125 .45498 0 6.28125 ]
[-0.0125 .56624 -22 -6.28125 ]
[-0.0125 .56624 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35242 0 m
.35242 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .00998 m
.00625 .00998 L
s
gsave
-0.0125 .00998 -111.688 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
109.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12123 m
.00625 .12123 L
s
gsave
-0.0125 .12123 -111.688 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
109.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .23248 m
.00625 .23248 L
s
gsave
-0.0125 .23248 -111.688 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
109.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .34373 m
.00625 .34373 L
s
gsave
-0.0125 .34373 -107.5 -10.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.500 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.313 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
105.000 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .45498 m
.00625 .45498 L
s
gsave
-0.0125 .45498 -101 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0001) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .56624 m
.00625 .56624 L
s
gsave
-0.0125 .56624 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .08598 m
.00375 .08598 L
s
0 .09707 m
.00375 .09707 L
s
0 .10357 m
.00375 .10357 L
s
0 .10819 m
.00375 .10819 L
s
0 .11178 m
.00375 .11178 L
s
0 .11471 m
.00375 .11471 L
s
0 .11719 m
.00375 .11719 L
s
0 .11934 m
.00375 .11934 L
s
0 .19723 m
.00375 .19723 L
s
0 .20832 m
.00375 .20832 L
s
0 .21482 m
.00375 .21482 L
s
0 .21944 m
.00375 .21944 L
s
0 .22303 m
.00375 .22303 L
s
0 .22596 m
.00375 .22596 L
s
0 .22844 m
.00375 .22844 L
s
0 .23059 m
.00375 .23059 L
s
0 .30848 m
.00375 .30848 L
s
0 .31957 m
.00375 .31957 L
s
0 .32607 m
.00375 .32607 L
s
0 .33069 m
.00375 .33069 L
s
0 .33428 m
.00375 .33428 L
s
0 .33721 m
.00375 .33721 L
s
0 .33969 m
.00375 .33969 L
s
0 .34184 m
.00375 .34184 L
s
0 .41973 m
.00375 .41973 L
s
0 .43082 m
.00375 .43082 L
s
0 .43732 m
.00375 .43732 L
s
0 .44194 m
.00375 .44194 L
s
0 .44553 m
.00375 .44553 L
s
0 .44846 m
.00375 .44846 L
s
0 .45094 m
.00375 .45094 L
s
0 .45309 m
.00375 .45309 L
s
0 .53098 m
.00375 .53098 L
s
0 .54207 m
.00375 .54207 L
s
0 .54857 m
.00375 .54857 L
s
0 .5532 m
.00375 .5532 L
s
0 .55678 m
.00375 .55678 L
s
0 .55971 m
.00375 .55971 L
s
0 .56219 m
.00375 .56219 L
s
0 .56434 m
.00375 .56434 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Acute) show
99.000 12.813 moveto
(intake) show
141.000 12.813 moveto
(in) show
159.000 12.813 moveto
(t) show
171.000 12.813 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
183.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
189.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
0 1 0 r
1.5 Mabswid
[ ] 0 setdash
.02381 .58292 m
.06042 .57778 L
.08838 .56915 L
.13894 .54848 L
.20509 .51121 L
.23444 .49049 L
.26115 .47103 L
.2711 .46473 L
.28124 .45959 L
.29175 .45596 L
.30107 .45415 L
.31076 .45334 L
.31951 .45319 L
.32703 .45333 L
.3349 .45361 L
.3657 .455 L
.37818 .45549 L
.39062 .45591 L
.40085 .45619 L
.41107 .45642 L
.41665 .45652 L
.42258 .4566 L
.42782 .45666 L
.43257 .45669 L
.43539 .45671 L
.43803 .45672 L
.44036 .45672 L
.44287 .45673 L
.44555 .45672 L
.44836 .45672 L
.45072 .45671 L
.4533 .45669 L
.45784 .45665 L
.46191 .45661 L
.47076 .45647 L
.47823 .45631 L
.48577 .45611 L
.49904 .45566 L
.51058 .45515 L
.53436 .45375 L
.55551 .45206 L
.57346 .45028 L
.60295 .44657 L
.65211 .43785 L
.69305 .42769 L
.72536 .41742 L
.75184 .40726 L
.77637 .39626 L
.79724 .38556 L
.8171 .3741 L
Mistroke
.83439 .36301 L
.84961 .35231 L
.86452 .34091 L
.87782 .32991 L
.89097 .31821 L
.90281 .30694 L
.91352 .29608 L
.92426 .28453 L
.93405 .27341 L
.94299 .26271 L
.95205 .25133 L
.96037 .24036 L
.96882 .22871 L
.97619 .21809 L
Mfstroke
0 0 1 r
2 Mabswid
[ 1 8 ] 0 Mabsdash
.02381 .3558 m
.13894 .39473 L
.20509 .41181 L
.2577 .42209 L
.30107 .42848 L
.33772 .43256 L
.36671 .43501 L
.38932 .43646 L
.41107 .43749 L
.42166 .43787 L
.43106 .43813 L
.44084 .43834 L
.44612 .43842 L
.45081 .43847 L
.45313 .43849 L
.45556 .43851 L
.45783 .43852 L
.45987 .43853 L
.46224 .43853 L
.46477 .43853 L
.46713 .43853 L
.46927 .43852 L
.4731 .43849 L
.47524 .43848 L
.47721 .43845 L
.4811 .43841 L
.48524 .43834 L
.4924 .43819 L
.49894 .43802 L
.51059 .43761 L
.52332 .43704 L
.53436 .43641 L
.57035 .43352 L
.58807 .43157 L
.60327 .4296 L
.6526 .42101 L
.69364 .41089 L
.72602 .40061 L
.75256 .39042 L
.77713 .37938 L
.79803 .36863 L
.8179 .35712 L
.83521 .34597 L
.85045 .33522 L
.86538 .32375 L
.87869 .31269 L
.89064 .30205 L
.90256 .29071 L
.91334 .2798 L
.92415 .26819 L
Mistroke
.934 .257 L
.94299 .24624 L
.9521 .23479 L
.96046 .22377 L
.96895 .21205 L
.97619 .20162 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0227273 0.227273 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.0681818 0.361111 0.295455 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .18182 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Lungs) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.386364 0.361111 0.613636 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
1.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .5 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.704545 0.361111 0.931818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
2 Mabswid
[ 1 8 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .81818 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[58]:=",
  ImageSize->{600, 294.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;^0001Ka000`40O003h00Oogooogool7oo003o
OoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogoo
l7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00
ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomo
oo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool0
0?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool0061oo`D003=oo`D004Qoo`@0035oo`D000=o
o`@002aoo`D000Aoo`@0041oo`@000Aoo`@002Uoo`D000=oo`@000Aoo`@002Eoo`D000Aoo`@000Ao
o`@00<aoo`00HWoo00<007ooOol0<goo00D007ooOomoo`0004Moo`03001oogoo009oo`03001oogoo
031oo`03001oogoo009oo`03001oogoo009oo`03001oogoo02Uoo`05001oogooOol00003Ool00`00
Oomoo`02Ool00`00Oomoo`0lOol00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol0:7oo00<0
07ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo029oo`05001oogooOol00003
Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol0bGoo001ROol00`00Oomoo`0dOol00`00
Oomoo`1=Ool00`00Oomoo`0`Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol00`00
Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`11Ool01000Oomoo`0017oo00<007ooOol0:7oo00<0
07ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo02=oo`03001oogoo00Aoo`03
001oogoo009oo`04001oogoo0004Ool00`00Oomoo`39Ool0069oo`03001oogoo03Eoo`03001oogoo
04aoo`03001oogoo031oo`03001oogoo009oo`03001oogoo009oo`03001oogoo02]oo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo045oo`04001oogoo0004Ool00`00Oomoo`0XOol00`00Oomo
o`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol097oo00<007ooOol00goo00<007oo
Ool00Woo00@007ooOol000Aoo`03001oogoo0<Uoo`00HWoo00<007ooOol0=Woo00<007ooOol0Agoo
1000<goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0;7oo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol0?Goo10000goo00<007ooOol00Woo00<007ooOol0:7oo00<007ooOol00Woo
00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo02Eoo`03001oogoo009oo`03001oogoo009o
o`04001oogoo0004Ool00`00Oomoo`39Ool0069oo`03001oogoo03Moo`03001oogoo04Ioo`03001o
ogoo03Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo02eoo`05001oogooOol00004Ool0
0`00Oomoo`0mOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0XOol00`00Oomoo`02Ool0
0`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol09Woo00D007ooOomoo`0000Aoo`04001oogoo
0004Ool00`00Oomoo`39Ool0061oo`<003Eoo`05001oogooOol00018Ool00`00Oomoo`0bOol30004
Ool00`00Oomoo`02Ool00`00Oomoo`0YOol01@00Oomoogoo00000goo00<007ooOol00Woo00<007oo
Ool0?Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol09Woo0`0017oo00<007ooOol00Woo
00@007ooOol000Aoo`03001oogoo029oo`05001oogooOol00003Ool00`00Oomoo`02Ool01000Oomo
o`0017oo00<007ooOol0bGoo001ROol00`00Oomoo`0dOol30019Ool5000bOol00`00Oomoo`03Ool4
000]Ool30005Ool40010Ool50003Ool4000[Ool00`00Oomoo`03Ool40004Ool4000VOol30005Ool4
0004Ool4003<Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooc]oo`<00;9o
o`00ogooogoo?Goo00<007ooOol0/7oo003oOoooOol[Ool300000goo00000002Ool300000goo0000
0004Ool00`00Oomoo`02Ool5002YOol00?mooomoobYoo`04001oogooOol20002Ool01000Oomoogoo
0P0017oo00<007oo00000goo00<007ooOol00Woo00<007ooOol0YWoo001GOooo0034000>Ool00`00
Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00<007oo000027oo00<007ooOol0YWoo001G
Ool00`00Oomoo`08Ool00`00Oomoo`0fOol00`00Oomoo`0NOol00`00Oomoo`0EOol00`00Oomoo`0?
Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`06
Ool00`00Oomoo`0fOol00`00Oomoo`0NOol00`00Oomoo`0EOol00`00Oomoo`0?Ool00`00Oomoo`0<
Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0f
Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool01000Oomoogoo1@000goo00D007ooOomoo`0000=oo`@0
0:Uoo`005Woo1@0017oo0P001Woo00D007ooOomoo`0000Eoo`D000=oo`@001Yoo`03001oogoo00Qo
o`03001oogoo03Ioo`03001oogoo01ioo`03001oogoo01Eoo`03001oogoo00moo`03001oogoo00ao
o`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo03Io
o`03001oogoo01ioo`03001oogoo01Eoo`03001oogoo00moo`03001oogoo00aoo`03001oogoo00Yo
o`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo03Ioo`03001oogoo00io
o`04001oogooOol20002Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00@007ooOol000Aoo`03
001oogoo0:Ioo`0067oo00<007ooOol017oo0P001goo00<007oo000027oo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol05goo00<007ooOol027oo00<007ooOol0=Woo00<007ooOol0B7oo00<0
07ooOol0=goo00<007ooOol0=Woo00<007ooOol0B7oo00<007ooOol0=goo00<007ooOol0=Woo00<0
07ooOol03goo0`0000=oo`00Ool00Woo10000goo0`0000Aoo`000000009oo`D00:Qoo`0067oo00<0
07ooOol03Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol05goo00<0
07ooOol0ogooe7oo00<007ooOol0_Woo000HOol00`00Oomoo`0=Ool00`00Ool00008Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`0GOol4003oOooBOol20030Ool001Qoo`03001oogoo00ao
o`05001oogooOol00007Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0GOol00`00Oomo
o`3oOoooOonFOol001Qoo`03001oogoo01Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo
00Aoo`D00003Ool0000000]oo`03001oogoo0?mooomooiIoo`005Woo0`0067oo0`0017oo00<007oo
Ool00Woo00<007oo00000`000goo00L007ooOomoo`00Ool0000:Ool00`00Oomoo`3oOoooOonFOol0
01Qoo`03001oogoo01Qoo`03001oogoo00=oo`@000Uoo`07001oogooOol007oo00002Woo00<007oo
Ool0ogooogooUWoo0016Ool01000Oomoogoo0P002goo00<007ooOol0ogooogooUWoo0016Ool01@00
Oomoogoo000037oo00<007ooOol0ogooogooUWoo0015Ool20004Ool2000:Ool00`00Oomoo`3oOooo
OonFOol005Moo`03001oogoo0?mooomooiIoo`00Egoo00<007ooOol0ogooogooUWoo001GOol00`00
Oomoo`3oOoooOonFOol005Moo`03001oogoo0?mooomooiIoo`00Egoo00<007ooOol0ogooogooUWoo
001GOol00`00Oomoo`3oOoooOonFOol005Moo`03001oogoo0?mooomooiIoo`00Egoo00<007ooOol0
ogooogooUWoo001GOol00`00Oomoo`3oOoooOonFOol005Moo`03001oogoo0?mooomooiIoo`00Egoo
00<007ooOol0ogooogooUWoo001GOol00`00Oomoo`3oOoooOonFOol005Moo`03001oogoo0?mooomo
oiIoo`00Egoo00<007ooOol0ogooogooUWoo001GOol00`00Oomoo`3oOoooOonFOol005Moo`03001o
ogoo0?mooomooiIoo`00Egoo00<007ooOol0ogooogooUWoo001GOol00`00Oomoo`3oOoooOonFOol0
05Moo`03001oogoo0?mooomooiIoo`00Egoo00<007ooOol0ogooogooUWoo001GOol00`00Oomoo`3o
OoooOonFOol005Moo`03001oogoo0?mooomooiIoo`00Egoo00<007ooOol0ogooogooUWoo001GOol0
0`00Oomoo`3oOoooOonFOol005Moo`03001oogoo0?mooomooiIoo`00Egoo00<007ooOol0ogooogoo
UWoo001GOol3003oOoooOonFOol005Moo`03001oogoo0?mooomooiIoo`00Egoo00<007ooOol0ogoo
ogooUWoo001GOol00`00Oomoo`3oOoooOonFOol005Moo`03001oogoo0?mooomooiIoo`00Egoo0`00
ogooogooUWoo001GOol00`00Oomoo`3oOoooOonFOol005Moo`03001oogoo0?mooomooiIoo`00Egoo
0`00ogooogooUWoo001GOol00`00Oomoo`3oOoooOonFOol005Moo`<00?mooomooiIoo`00Egoo00<0
07ooOol0ogooogooUWoo001GOol3003oOoooOonFOol001Ioo`D000Aoo`8000Ioo`05001oogooOol0
0005Ool50003Ool4000JOol3003oOoooOonFOol001Qoo`03001oogoo00Aoo`8000Moo`03001oo`00
00Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo01Moo`<00?moooAoohd001Aoo`0067oo
00<007ooOol03Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol05goo
0`00ogoom7ooS@0057oo000HOol00`00Oomoo`0=Ool00`00Ool00008Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`0GOol4003oOoocOon=000DOol001Qoo`03001oogoo00aoo`05001oogoo
Ool00007Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0GOol00`00Oomoo`3oOoodOon=
000DOol001Qoo`03001oogoo01Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`D0
0003Ool0000000]oo`03001oogoo0?mooniooi<001Aoo`005Woo0`0067oo0`0017oo00<007ooOol0
0Woo00<007oo00000`000goo00<007ooOol00goo00<007ooOol027oo00<007ooOol0ogookWoo00<0
07ooOol0RWoo1P0057oo000HOol00`00Oomoo`0HOol00`00Oomoo`03Ool40009Ool00`00Oomoo`02
Ool00`00Oomoo`09Ool00`00Oomoo`3oOoo^Ool00`00Oomoo`2:Ool6000DOol004Ioo`03001oogoo
00=oo`03001oogoo00Qoo`03001oogoo0?moonioo`03001oogoo08Yoo`H001Aoo`00AWoo00L007oo
Oomoo`00Ool0000:Ool00`00Oomoo`3oOoo^Ool00`00Oomoo`2:Ool6000DOol004Eoo`8000Aoo`03
001oogoo00Uoo`03001oogoo0?moonioo`03001oogoo08Yoo`H001Aoo`00Egoo00<007ooOol0ogoo
kWoo00<007ooOol0RWoo1P0057oo001GOol00`00Oomoo`3oOoo^Ool00`00Oomoo`2:Ool6000DOol0
05Moo`03001oogoo0?moonioo`03001oogoo08Yoo`H001Aoo`00Egoo00<007ooOol0ogookWoo00<0
07ooOol0RWoo1P0057oo001GOol00`00Oomoo`3oOoo^Ool00`00Oomoo`2:Ool6000DOol005Moo`03
001oogoo0?moonioo`03001oogoo08Yoo`H001Aoo`00Egoo00<007ooOol0ogookWoo00<007ooOol0
RWoo1P0057oo001GOol00`00Oomoo`3oOoo^Ool00`00Oomoo`2:Ool6000DOol005Moo`03001oogoo
0?moonioo`03001oogoo08Yoo`H001Aoo`00Egoo00<007ooOol0ogookWoo00<007ooOol0RWoo1P00
57oo001GOol00`00Oomoo`3oOoo^Ool00`00Oomoo`2:Ool6000DOol005Moo`03001oogoo0?moonio
o`03001oogoo08Yoo`H001Aoo`00Egoo00<007ooOol0ogookWoo00<007ooOol0RWoo1P0057oo001G
Ool00`00Oomoo`3oOoo^Ool00`00Oomoo`2:Ool6000DOol005Moo`03001oogoo0?moonioo`03001o
ogoo08Yoo`H001Aoo`00Egoo00<007ooOol0ogookWoo00<007ooOol0RWoo1P0057oo001GOol00`00
Oomoo`3oOoo^Ool00`00Oomoo`1FOol4000`Ool6000DOol005Moo`03001oogoo0?moonioo`03001o
ogoo05Yoo`03001oogoo02eoo`H001Aoo`00Egoo00<007ooOol0ogookWoo00<007ooOol0?Goo1P00
17oo0P0000Aoo`00001oo`<00004Ool000000002Ool3000017oo001oogoo1@00:7oo1P0057oo001G
Ool00`00Oomoo`3oOoo^Ool00`00Oomoo`0nOol01@00Oomoogoo00000goo00<007ooOol00P000goo
00D007ooOomoo`00009oo`04001oogooOol20002Ool00`00Oomoo`02Ool00`00Oomoo`0UOol6000D
Ool005Moo`03001oogoo0?moonioo`03001oogoo00Yoo`Il00Aoo`Il00Aoo`Il00Aoo`Il011oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`03001oogoo009oo`03
001oogoo00Eoo`03001oogoo02Eoo`H001Aoo`00Egoo00<007ooOol0ogookWoo00<007ooOol0?Woo
00<007ooOol01Goo00D007ooOomoo`0000=oo`05001oogooOol00002Ool00`00Oomoo`02Ool01000
Oomoogoo1000:7oo1P0057oo001GOol00`00Oomoo`3oOoo^Ool00`00Oomoo`0nOol00`00Oomoo`05
Ool01@00Oomoogoo00000goo0P000Woo00@007ooOol000=oo`80009oo`03001oogoo009oo`03001o
ogoo02Eoo`H001Aoo`00Egoo00<007ooOol0ogookWoo00<007ooOol0?Woo00<007ooOol017oo0P00
0Woo0P000Woo0P0000=oo`00000017oo0`0000=oo`0000000Woo1@009goo1P0057oo001GOol00`00
Oomoo`3oOoo^Ool00`00Oomoo`0nOol00`00Oomoo`19Ool6000DOol005Moo`03001oogoo0?moonio
o`03001oogoo03eoo`<004Yoo`H001Aoo`00Egoo0`00ogookWoo00<007ooOol0RWoo1P0057oo001G
Ool00`00Oomoo`3oOoo^Ool00`00Oomoo`2:Ool6000DOol005Moo`03001oogoo0?moonioo`03001o
ogoo08Yoo`H001Aoo`00Egoo00<007ooOol0ogookWoo00<007ooOol0RWoo1P0057oo001GOol00`00
Oomoo`3oOoo^Ool00`00Oomoo`2:Ool6000DOol005Moo`<00?moonioo`03001oogoo08Yoo`H001Ao
o`00Egoo00<007ooOol0ogookWoo00<007ooOol0RWoo1P0057oo001GOol00`00Oomoo`3oOon`Ool2
01llOol00`00Oomoo`2:Ool6000DOol005Moo`<00?mook1oo`807caoo`03001oogoo08Yoo`H001Ao
o`00Egoo00<007ooOol0ogoo/7oo0P0O0goo00<3h7ooOol0=Woo00<007ooOol0RWoo1P0057oo001G
Ool3003oOondOol00`?POomoo`0gOol00`00Oomoo`2:Ool6000DOol005Moo`03001oogoo0?mookAo
o`030n1oogoo03Moo`03001oogoo08Yoo`H001Aoo`00Egoo0`00ogoo/goo00<3h7ooOol0>7oo00<0
07ooOol0RWoo1P0057oo000FOol50004Ool20006Ool01@00Oomoogoo00001Goo1@000goo10006Woo
0`00ogoo/goo00<3h7ooOol0>7oo00<007ooOol0RWoo1P0057oo000HOol00`00Oomoo`04Ool20007
Ool00`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0GOol3003oOonbOol0
0`?POomoo`0iOol00`00Oomoo`2:Ool6000DOol001Qoo`03001oogoo00ioo`03001oogoo00Moo`03
001oogoo009oo`03001oogoo009oo`03001oogoo01Moo`<00?mooj]oo`0301moogoo00=oo`030n1o
ogoo03Yoo`03001oogoo08Yoo`H001Aoo`0067oo00<007ooOol03Goo00<007oo000027oo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol05goo1000ogooZGoo0`0O0goo00<3h7ooOol0>goo00<0
07ooOol0RWoo1P0057oo000HOol00`00Oomoo`0<Ool01@00Oomoogoo00001goo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol05goo00<007ooOol0ogooZ7oo100O17oo00<3h7ooOol0>goo00<0
07ooOol0RWoo1P0057oo000HOol00`00Oomoo`0HOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool50002Ool00`00Oomoo`09Ool00`00Oomoo`3oOonXOol301l4Ool00`?POomoo`0lOol0
0`00Oomoo`2:Ool6000DOol001Ioo`<001Qoo`<000Aoo`03001oogoo009oo`03001oo`0000<000=o
o`07001oogooOol007oo00002Woo00<007ooOol0ogoo[Woo00<3h7ooOol0?Goo00<007ooOol0RWoo
1P0057oo000HOol00`00Oomoo`0HOol00`00Oomoo`03Ool40009Ool01`00Oomoogoo001oo`0000Yo
o`03001oogoo0?moojeoo`030n1oogoo03ioo`03001oogoo08Yoo`H001Aoo`00AWoo00L007ooOomo
o`00Ool0000:Ool00`00Oomoo`3oOon/Ool00`?POomoo`0oOol00`00Oomoo`2:Ool6000DOol004Io
o`07001oogooOol007oo00002Woo00<007ooOol0ogoo[7oo00<3h7ooOol0?goo00<007ooOol0RWoo
1P0057oo0015Ool20004Ool00`00Oomoo`09Ool00`00Oomoo`3oOon[Ool00`?POomoo`10Ool00`00
Oomoo`2:Ool6000DOol005Moo`03001oogoo0?moojAoo`0301moogoo00=oo`030n1oogoo045oo`03
001oogoo08Yoo`H001Aoo`00Egoo00<007ooOol0ogooXgoo0`0O0goo00<3h7ooOol0@Woo00<007oo
Ool0RWoo1P0057oo001GOol00`00Oomoo`3oOonROol301l3Ool00`?POomoo`13Ool00`00Oomoo`2:
Ool6000DOol005Moo`03001oogoo0?mooj=oo`0301moogoo009oo`030n1oogoo04=oo`03001oogoo
08Yoo`H001Aoo`00Egoo00<007ooOol0ogooYgoo00<3h7ooOol0A7oo00<007ooOol0RWoo1P0057oo
001GOol00`00Oomoo`3oOonVOol00`?POomoo`15Ool00`00Oomoo`0mOol60002Ool20002Ool20003
Ool40003Ool50004Ool50004Ool30004Ool50003Ool40003Ool3000017oo000000001Woo1P0057oo
001GOol00`00Oomoo`3oOonUOol00`?POomoo`16Ool00`00Oomoo`0nOol01@00Oomoogoo00000goo
00@007ooOol000=oo`03001oogoo009oo`05001oogooOol00006Ool00`00Oomoo`06Ool01@00Oomo
ogoo00001Goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00Eo
o`H001Aoo`00Egoo00<007ooOol0ogooY7oo00<3h7ooOol0Agoo00<007ooOol0?Woo00<007ooOol0
1Woo0P0017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol01goo00<0
07ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00Eoo`H001Aoo`00Egoo
00<007ooOol0ogooY7oo00<3h7ooOol0Agoo00<007ooOol0?Woo00<007oo00001Woo0P0017oo00<0
07ooOol01Woo00<007ooOol017oo1P000goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0
0Woo00D007ooOomoo`0000=oo`03001oogoo00Eoo`H001Aoo`00Egoo00<007ooOol0ogooXgoo00<3
h7ooOol0B7oo00<007ooOol0?Woo0`001Goo00@007ooOol000=oo`04001oogooOol20003Ool20005
Ool00`00Oomoo`02Ool01@00Oomoogoo00002Goo00<007ooOol00Woo00<007ooOol00Woo00@007oo
Oomoo`80009oo`03001oogoo00Eoo`H001Aoo`00Egoo00<007ooOol0ogooXWoo00<3h7ooOol0BGoo
00<007ooOol0?Woo00<007oo000017oo0P000Woo0P000goo0`0000Aoo`00Oomoo`800004Ool00000
0003Ool40003Ool50004Ool30005Ool40003Ool200000goo00000008Ool6000DOol005Moo`03001o
ogoo0?mooiYoo`0301moogoo00Aoo`030n1oogoo04Yoo`03001oogoo03ioo`05001oogooOol0000S
Ool00`00Oomoo`0QOol6000DOol005Moo`03001oogoo0?mooiUoo`<07`Aoo`030n1oogoo04]oo`03
001oogoo03eoo`H002eoo`03001oogoo01Moo`H001Aoo`00Egoo00<007ooOol0ogooV7oo0`0O1Goo
00<3h7ooOol0Bgoo00<007ooOol0RWoo1P0057oo001GOol00`00Oomoo`3oOonIOol00`0OOomoo`03
Ool00`?POomoo`1<Ool00`00Oomoo`2:Ool6000DOol005Moo`03001oogoo0?mooiioo`030n1oogoo
04eoo`03001oogoo00YoobH3h5Yoo`H001Aoo`00Egoo00<007ooOol0ogooWGoo00<3h7ooOol0CWoo
00<007ooOol0RWoo1P0057oo001GOol00`00Oomoo`3oOonLOol00`?POomoo`1?Ool00`00Oomoo`2:
Ool6000DOol005Moo`03001oogoo0?mooi]oo`030n1oogoo051oo`03001oogoo08Yoo`H001Aoo`00
Egoo00<007ooOol0ogooTWoo00<07gooOol01Goo00<3h7ooOol0DGoo00<007ooOol0RWoo1P0057oo
001GOol00`00Oomoo`3oOonAOol301l5Ool00`?POomoo`1BOol00`00Oomoo`2:Ool6000DOol005Mo
o`03001oogoo0?mooi1oo`<07`Eoo`030n1oogoo05=oo`03001oogoo03moo`<000=oo`D000Aoo`D0
009oo`<00004Ool000000002Ool5000WOol6000DOol005Moo`03001oogoo0?mooi5oo`0301moogoo
00=oo`030n1oogoo05Aoo`03001oogoo03ioo`05001oogooOol00003Ool00`00Oomoo`07Ool00`00
Oomoo`03Ool01@00Oomoogoo00000Woo00<007ooOol0:Woo1P0057oo001GOol00`00Oomoo`3oOonF
Ool00`?POomoo`1EOol00`00Oomoo`0nOol01@00Oomoogoo00000goo00<007ooOol01goo00<007oo
Ool00goo00D007ooOomoo`00009oo`03001oogoo02Yoo`H001Aoo`00Egoo00<007ooOol0ogooUGoo
00<3h7ooOol0EWoo00<007ooOol0?Woo00D007ooOomoo`0000=oo`03001oogoo00Moo`03001oogoo
00=oo`05001oogooOol00002Ool6000WOol6000DOol005Moo`03001oogoo0?mooiAoo`030n1oogoo
05Moo`03001oogoo03ioo`05001oogooOol00003Ool20008Ool00`00Oomoo`03Ool20002Ool01000
Oomoo`0017oo00<007ooOol09Goo1P0057oo001GOol3003oOonCOol00`?POomoo`1HOol00`00Oomo
o`0nOol01@00Oomoogoo00000Woo0P0000Aoo`00000000=oo`<000Aoo`800003Ool0000000Aoo`@0
02Qoo`H001Aoo`00Egoo00<007ooOol0ogooTWoo00<3h7ooOol0FGoo00<007ooOol0?Woo00D007oo
Oomoo`0004Moo`H001Aoo`00Egoo00<007ooOol0ogooQgoo100O1Woo00<3h7ooOol0FWoo00<007oo
Ool0?Goo0`0000Aoo`00000000aoo`03001oogoo03Moo`H001Aoo`00Egoo00<007ooOol0ogooQgoo
100O1Goo00<3h7ooOol0Fgoo00<007ooOol0RWoo1P0057oo001GOol00`00Oomoo`3oOon?Ool00`?P
Oomoo`1LOol00`00Oomoo`2:Ool6000DOol005Moo`<00?moohioo`030n1oogoo05eoo`03001oogoo
08Yoo`H001Aoo`00Egoo00<007ooOol0ogooSGoo00<3h7ooOol0GWoo00<007ooOol0RWoo1P0057oo
001GOol00`00Oomoo`3oOon<Ool00`?POomoo`1OOol00`00Oomoo`2:Ool6000DOol005Moo`<00?mo
oh]oo`030n1oogoo061oo`03001oogoo08Yoo`H001Aoo`00Egoo00<007ooOol0ogooOgoo0`0O27oo
00<3h7ooOol0HGoo00<007ooOol0RWoo1P0057oo001GOol3003oOomoOol301l7Ool00`?POomoo`1R
Ool00`00Oomoo`2:Ool6000DOol005Moo`03001oogoo0?moohQoo`030n1oogoo06=oo`03001oogoo
08Yoo`H001Aoo`00Egoo0`00ogooQgoo00<3h7ooOol0I7oo00<007ooOol0RWoo1P0057oo000LOol5
0004Ool20005Ool01@00Oomoogoo00001Woo1@000goo100057oo0`00ogooQGoo0P?PIgoo00<007oo
Ool0RWoo1P0057oo000NOol00`00Oomoo`04Ool20006Ool00`00Ool00009Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`0AOol3003oOomhOol00`0OOomoo`09Ool00`?POomoo`1WOol00`00
Oomoo`2:Ool6000DOol001ioo`03001oogoo00eoo`03001oogoo00Qoo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo015oo`<00?moogMoo`<07`Uoo`030n1oogoo06Qoo`03001oogoo08Yoo`H0
01Aoo`007Woo00<007ooOol037oo00<007oo00002Goo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol04Goo1000ogooMGoo0`0O27oo0P?PJgoo00<007ooOol0RWoo1P0057oo000NOol00`00Oomo
o`0;Ool01@00Oomoogoo000027oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol04Goo00<0
07ooOol0ogooMgoo00<07gooOol01Woo00<3h7ooOol0Jgoo00<007ooOol0RWoo1P0057oo000NOol0
0`00Oomoo`0HOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`3oOomo
Ool00`?POomoo`1/Ool00`00Oomoo`2:Ool6000DOol001aoo`<001Qoo`<000Aoo`03001oogoo009o
o`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo0?moogeoo`83h6moo`03001oogoo08Yoo`H0
01Aoo`007Woo00<007ooOol067oo00<007ooOol00goo10000Woo10000Woo00<007ooOol02Goo00<0
07ooOol0ogooO7oo00<3h7ooOol0Kgoo00<007ooOol0RWoo1P0057oo001;Ool00`00Oomoo`09Ool0
0`00Oomoo`3oOomjOol20n1bOol00`00Oomoo`2:Ool6000DOol004aoo`03001oogoo00Qoo`03001o
ogoo0?moofaoo`@07`Uoo`030n1oogoo079oo`03001oogoo08Yoo`H001Aoo`00BWoo00<007oo0000
2Woo00<007ooOol0ogooK7oo100O27oo00<3h7ooOol0Lgoo00<007ooOol0RWoo1P0057oo001:Ool3
000:Ool00`00Oomoo`0>Ool301ooOomUOol20n1fOol00`00Oomoo`0mOol60002Ool20002Ool20003
Ool40003Ool50004Ool50004Ool30004Ool50003Ool40003Ool3000017oo000000001Woo1P0057oo
001GOol00`00Oomoo`0>Ool301ooOomTOol00`?POomoo`1fOol00`00Oomoo`0nOol01@00Oomoogoo
00000goo00@007ooOol000=oo`03001oogoo009oo`05001oogooOol00006Ool00`00Oomoo`06Ool0
1@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001o
ogoo00Eoo`H001Aoo`00Egoo00<007ooOol0ogooIGoo00<07gooOol02goo0P?PNGoo00<007ooOol0
?Woo00<007ooOol01Woo0P0017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00Eo
o`H001Aoo`00Egoo00<007ooOol0ogooI7oo0`0O2goo00<3h7ooOol0NGoo00<007ooOol0?Woo00<0
07oo00001Woo0P0017oo00<007ooOol01Woo00<007ooOol017oo1P000goo00<007ooOol01goo00<0
07ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00Eoo`H001Aoo`00Egoo
00<007ooOol06Goo0`0OogooAgoo0`0O2goo00<3h7ooOol0NWoo00<007ooOol0?Woo0`001Goo00@0
07ooOol000=oo`04001oogooOol20003Ool20005Ool00`00Oomoo`02Ool01@00Oomoogoo00002Goo
00<007ooOol00Woo00<007ooOol00Woo00@007ooOomoo`80009oo`03001oogoo00Eoo`H001Aoo`00
Egoo00<007ooOol06Goo0`0OogooB7oo00<07gooOol027oo0P?POGoo00<007ooOol0?Woo00<007oo
000017oo0P000Woo0P000goo0`0000Aoo`00Oomoo`800004Ool000000003Ool40003Ool50004Ool3
0005Ool40003Ool200000goo00000008Ool6000DOol005Moo`03001oogoo02Aoo`0301moogoo0?mo
odMoo`030n1oogoo07eoo`03001oogoo03ioo`05001oogooOol0000SOol00`00Oomoo`0QOol6000D
Ool005Moo`03001oogoo02=oo`@07omoocAoo`0301moogoo00ioo`83h81oo`03001oogoo03eoo`H0
02eoo`03001oogoo01Moo`H001Aoo`00Egoo00<007ooOol097oo100Oogoo<Woo0`0O3Goo0P?PPWoo
00<007ooOol0RWoo1P0057oo001GOol00`00Oomoo`0VOol00`0OOomoo`3oOol`Ool301l<Ool20n24
Ool00`00Oomoo`2:Ool6000DOol005Moo`03001oogoo0?mooeYoo`0301moogoo00Uoo`83h8Ioo`03
001oogoo00Uoo`<07`Qoo`<07`Qoo`@07`Qoo`<07eaoo`H001Aoo`00Egoo00<007ooOol0;Woo0`0O
ogoo=7oo00<3h7ooOol0QWoo00<007ooOol02Goo0`0O27oo0`0O27oo100O27oo0`0OG7oo1P0057oo
001GOol00`00Oomoo`0^Ool301ooOolbOol20n29Ool00`00Oomoo`2:Ool6000DOol005Moo`03001o
ogoo03Yoo`0301moogoo0?mooa5oo`@07`moo`83h8]oo`03001oogoo08Yoo`H001Aoo`00Egoo00<0
07ooOol0>Goo0`0Oogoo4Woo100O3Goo0P?PSGoo00<007ooOol0RWoo1P0057oo001GOol00`00Oomo
o`0jOol301ooOolPOol20n2?Ool00`00Oomoo`2:Ool6000DOol005Moo`03001oogoo03]oo`0301mo
ogoo00Moo`0301moogoo0?mooa9oo`<3h95oo`03001oogoo03eoo`<000Ioo`<00003Ool00000009o
o`D000=oo`@000Aoo`<00003Ool00000009oo`D001moo`H001Aoo`00Egoo00<007ooOol0A7oo0`0O
o7oo0`0O4Goo0P?PU7oo00<007ooOol0?Woo00<007ooOol017oo00@007ooOomoo`80009oo`03001o
ogoo00Eoo`03001oogoo009oo`04001oogoo0003Ool20005Ool00`00Oomoo`0OOol6000DOol005Mo
o`03001oogoo04Eoo`<07o]oo`<07`moo`83h9Ioo`03001oogoo03ioo`03001oogoo00Aoo`03001o
ogoo009oo`04001oogoo0007Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`0OOol6000DOol005Moo`03001oogoo04Ioo`0301moogoo0?5oo`0301moogoo01Ioo`83h9Qo
o`03001oogoo03ioo`03001oo`0000Eoo`D0009oo`H0009oo`03001oogoo00Ioo`D000Eoo`03001o
ogoo01moo`H001Aoo`00Egoo00<007ooOol0CWoo100Oigoo0`0O5Goo0P?PVWoo00<007ooOol0?Woo
0`0017oo00<007ooOol00Woo00@007ooOol000Aoo`04001oogoo0003Ool20002Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`0OOol6000DOol005Moo`03001oogoo04ioo`@07nIoo`<07a=o
o`<3h9aoo`03001oogoo03ioo`03001oo`0000Eoo`@000Aoo`@000Aoo`<00003Ool007oo009oo`@0
00Ioo`03001oogoo01moo`H001Aoo`00Egoo00<007ooOol0ogoo>Woo00<07gooOol03goo0`?PWgoo
00<007ooOol0?Woo00D007ooOomoo`0002Eoo`03001oogoo01moo`H001Aoo`00Egoo00<007ooOol0
FGoo100Ojgoo0`?PXWoo00<007ooOol0?Goo1P0097oo0P008Goo1P0057oo001GOol00`00Oomoo`1I
Ool401o@Ool401lDOol30n2UOol00`00Oomoo`2:Ool6000DOol005Moo`03001oogoo06Aoo`@07keo
o`0301moogoo00Eoo`@07a5oo`<3h:Qoo`03001oogoo08Yoo`H001Aoo`00Egoo0`00I7oo100O^goo
100O67oo0`?PZgoo00<007ooOol0RWoo1P0057oo001GOol00`00Oomoo`1_Ool401nWOol00`0OOomo
o`05Ool401lGOol20n2^Ool00`00Oomoo`2:Ool6000DOol005Moo`03001oogoo06moo`@07jEoo`@0
7`Moo`0301moogoo01Aoo`<3h;1oo`03001oogoo08Yoo`H001Aoo`00Egoo00<007ooOol0Ngoo0`0O
2Goo00<07gooOol0SGoo100O77oo0`?P/goo00<007ooOol0RWoo1P0057oo001GOol00`00Oomoo`1k
Ool301l8Ool301n3Ool401l8Ool00`0OOomoo`0HOol40n2fOol00`00Oomoo`2:Ool6000DOol005Mo
o`<008Moo`<07h9oo`@07aioo`D3h;Yoo`03001oogoo08Yoo`03001oogoo01Moo`00Egoo00<007oo
Ool0R7oo00<07gooOol01Woo0`0O57oo00<07gooOol0EWoo0`0O9Woo10?P_goo00<007ooOol0RWoo
00<007ooOol05goo001GOol00`00Oomoo`2AOol301l8Ool301l8Ool401m;Ool301l8Ool301lQOol5
0n33Ool00`00Oomoo`2:Ool00`00Oomoo`0GOol005Moo`<009aoo`<07`Uoo`@07`Moo`<07`Moo`@0
7aioo`@07`Qoo`<07`Qoo`<07bMoo`D3h<Qoo`03001oogoo08Yoo`03001oogoo01Moo`00Egoo00<0
07ooOol0ZWoo00<07gooOol01Woo0`0O1goo100O27oo0`0O1goo1@0O1goo100O27oo0`0O;7oo1P?P
cGoo00<007ooOol0RWoo00<007ooOol05goo001GOol30039Ool301l7Ool501lmOol50n3COon>000I
Ool005Moo`03001oogoo0?mooa1oo`H3h?mooh1oo`00Egoo0`00ogoo2Woo1P?PogooQWoo001GOol3
003oOol4Ool60n3oOon<Ool002Aoo`@000Eoo`8000Eoo`@000Aoo`@000Aoo`@000Aoo`D000Ioo`<0
0?aoo`L3h?mooi9oo`008goo00<007ooOol00Woo00<007ooOol00Woo0P0017oo00<007ooOol00Woo
00@007ooOol000Aoo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`06Ool30027OolD0n1>
OolC0n3oOonIOol002=oo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`04001oogoo
0004Ool01000Oomoo`0017oo00<007ooOol00goo00<007ooOol01Woo1000OWoo20?P57oo50?P;7oo
3P?Pogoo[7oo000SOol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool01000Oomoo`00
17oo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo07eoo`83h31oob`3
h?mookYoo`008goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00@007ooOol000Ao
o`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`1kOol20n3oOoooOolI
Ool002=oo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`04001oogoo0004Ool01000
Oomoo`0017oo00<007ooOol00goo00<007ooOol01Woo00<007ooOol0NGoo0P?Pogooogoo6goo000S
Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool01000Oomoo`0017oo00@007ooOol0
00Aoo`04001oogooOol30008Ool00`00Oomoo`1gOol20n3oOoooOolMOol002Aoo`@000aoo`@000Ao
o`@000Aoo`@000Ioo`03001oogoo00Ioo`03001oogoo07Eoo`83h?mooomooamoo`00Egoo00<007oo
Ool0Lgoo0P?Pogooogoo8Goo001GOol00`00Oomoo`1bOol00`?POomoo`3oOoooOolQOol005Moo`03
001oogoo075oo`030n1oogoo0?mooomoob9oo`00Egoo00<007ooOol0Kgoo0P?Pogooogoo9Goo001G
Ool00`00Oomoo`1^Ool00`?POomoo`3oOoooOolUOol005Moo`03001oogoo06eoo`030n1oogoo0?mo
oomoobIoo`00Egoo00<007ooOol0Jgoo0P?Pogooogoo:Goo001GOol00`00Oomoo`1ZOol00`?POomo
o`3oOoooOolYOol005Moo`03001oogoo06Uoo`030n1oogoo0?mooomoobYoo`00Egoo00<007ooOol0
Igoo0P?Pogooogoo;Goo001GOol00`00Oomoo`1VOol00`?POomoo`3oOoooOol]Ool005Moo`03001o
ogoo06Aoo`83h?mooomooc1oo`00Egoo00<007ooOol0Hgoo00<3h7ooOol0ogooogoo<7oo001GOol0
0`00Oomoo`1QOol20n3oOoooOolcOol005Moo`03001oogoo061oo`030n1oogoo0?mooomooc=oo`00
Egoo00<007ooOol0Ggoo00<3h7ooOol0ogooogoo=7oo001GOol00`00Oomoo`1MOol20n3oOoooOolg
Ool005Moo`03001oogoo05aoo`030n1oogoo0?mooomoocMoo`00Egoo00<007ooOol0FWoo0P?Pogoo
ogoo>Woo001GOol00`00Oomoo`1IOol00`?POomoo`3oOoooOoljOol005Moo`03001oogoo05Moo`83
h?mooomooceoo`00Egoo00<007ooOol0EGoo0P?Pogooogoo?goo001GOol00`00Oomoo`1COol20n3o
OoooOom1Ool005Moo`03001oogoo059oo`030n1oogoo0?mooomood5oo`00Egoo00<007ooOol0D7oo
0P?PogooogooA7oo001GOol00`00Oomoo`1>Ool20n3oOoooOom6Ool005Moo`03001oogoo04aoo`83
h?mooomoodQoo`00Egoo00<007ooOol0Bgoo00<3h7ooOol0ogooogooB7oo001GOol30019Ool20n3o
OoooOom;Ool005Moo`03001oogoo04Moo`83h?mooomoodeoo`00Egoo00<007ooOol0AGoo0P?Pogoo
ogooCgoo001GOol00`00Oomoo`13Ool20n3oOoooOomAOol005Moo`03001oogoo049oo`030n1oogoo
0?mooomooe5oo`00Egoo0`00@7oo0P?PogooogooE7oo001GOol00`00Oomoo`0nOol20n3oOoooOomF
Ool005Moo`03001oogoo03aoo`83h?mooomooeQoo`00Egoo0`00>Woo0P?PogooogooFWoo001GOol0
0`00Oomoo`0hOol20n3oOoooOomLOol005Moo`<003Eoo`<3h?mooomooeioo`00Egoo00<007ooOol0
<goo0P?PogooogooHGoo001GOol3000aOol20n3oOoooOomSOol005Moo`<002ioo`<3h?mooomoofEo
o`00>Woo10001Goo0P001Goo1@0027oo0`00;7oo0P?PogooogooJ7oo000iOol00`00Oomoo`02Ool0
0`00Oomoo`02Ool20007Ool00`00Oomoo`08Ool3000YOol30n3oOoooOomZOol003Uoo`03001oogoo
009oo`03001oogoo00]oo`03001oogoo00Qoo`@002Ioo`83h?mooomoofeoo`00>Goo00<007ooOol0
0Woo00<007ooOol02goo00<007ooOol027oo00<007ooOol097oo0`?PogooogooKgoo000iOol00`00
Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`0QOol30n3oOoooOombOol003Uo
o`03001oogoo009oo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo01eoo`@3h?mooomoogEo
o`00>Goo00<007ooOol00Woo00<007ooOol02Goo0`002Woo00<007ooOol06Woo0`?PogooogooNGoo
000jOol4000>Ool00`00Oomoo`08Ool00`00Oomoo`0FOol40n3oOoooOomlOol005Moo`03001oogoo
015oo`D3h?mooomooh1oo`00Egoo00<007ooOol02goo1P?PogooogooQGoo001GOol00`00Oomoo`08
Ool30n3oOoooOon;Ool005Moo`03001oogoo0?mooomooiIoo`00Egoo00<007ooOol0ogooogooUWoo
001GOol00`00Oomoo`3oOoooOonFOol005Moo`03001oogoo0?mooomooiIoo`00Egoo00<007ooOol0
ogooogooUWoo001GOol00`00Oomoo`3oOoooOonFOol005Moo`03001oogoo0?mooomooiIoo`00Egoo
00<007ooOol0ogooogooUWoo001GOol00`00Oomoo`3oOoooOonFOol005Moo`03001oogoo0?mooomo
oiIoo`00Egoo00<007ooOol0ogooogooUWoo001GOol00`00Oomoo`3oOoooOonFOol005Moo`03001o
ogoo0?mooomooiIoo`00Egoo00<007ooOol0ogooogooUWoo001GOol00`00Oomoo`3oOoooOonFOol0
0?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOooo
Ooo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo
003ZOol3000017oo000000000Woo10001Goo0P0000=oo`0000000goo0`0017oo1@0027oo1@000Woo
0`0000Aoo`00000000=oo`<000Aoo`<00004Ool00000Ool20002Ool30002Ool50008Ool50002Ool3
000017oo000000002Goo0`006Woo1000ogooJWoo003[Ool01@00Oomoogoo00000Woo00<007ooOol0
0Woo00D007ooOomoo`00009oo`8000=oo`05001oogooOol00002Ool00`00Oomoo`0=Ool00`00Oomo
o`03Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`04001oogooOol20003Ool01000Oomo
o`000goo00<007ooOol03Goo00<007ooOol00goo00D007ooOomoo`0000Uoo`05001oogooOol00009
Ool60009Ool00`00Oomoo`02Ool00`00Oomoo`3oOomWOol00>aoo`<000=oo`03001oogoo00Ioo`05
001oogooOol00003Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool01@00Oomoogoo
00000goo00<007ooOol017oo00<007ooOol00Woo00L007ooOomoo`00Ool00004Ool00`00Oomoo`0=
Ool00`00Oomoo`03Ool01@00Oomoogoo00002Goo00<007ooOol06Woo00<007ooOol00Woo00<007oo
Ool0ogooIgoo001LOol3002=Ool00`00Ool00003Ool00`00Oomoo`06Ool01@00Oomoogoo00000goo
00<007ooOol017oo1P002Woo00<007ooOol00goo00D007ooOomoo`0000=oo`03001oogoo00Eoo`D0
00=oo`<000Aoo`H000Yoo`03001oogoo00=oo`05001oogooOol00009Ool00`00Oomoo`0;Ool60009
Ool00`00Oomoo`02Ool00`00Oomoo`3oOomWOol005eoo`03001oogoo08aoo`03001oo`0000=oo`04
001oogooOol20003Ool01@00Oomoogoo00000goo00<007ooOol017oo00<007ooOol00Woo00<007oo
Ool027oo00<007ooOol00goo0P000Woo00D007ooOomoo`0000Ioo`03001oogoo009oo`05001oogoo
Ool00002Ool01@00Oomoogoo000017oo00<007ooOol027oo00<007ooOol00goo0P000Woo00<007oo
Ool01goo00<007ooOol06Woo00<007ooOol00Woo00<007ooOol0ogooIgoo001@Ool50004Ool30000
0goo001oo`2=Ool00`00Ool00004Ool3000017oo001oogoo0P000Woo0P000Woo1@0017oo10002Goo
0`0017oo0P0000=oo`0000000goo1@0017oo100017oo00<007oo00000`000Woo10002Goo0`0017oo
0P0000=oo`0000002Goo1@006Goo00<007ooOol00Woo00<007ooOol0ogooIgoo001AOol01@00Oomo
ogoo00000Woo00@007ooOomoo`8008moo`03001oogoo01=oo`03001oogoo029oo`03001oogoo00eo
o`03001oogoo02Qoo`03001oogoo01Yoo`03001oogoo009oo`03001oogoo0?moofMoo`00DGoo00D0
07ooOomoo`00009oo`03001oogoo009oo`03001oogoo08aoo`8002aoo`03001oogoo01Yoo`8001Io
o`03001oogoo02moo`@00?moofYoo`00DGoo00D007ooOomoo`00009oo`03001oogoo009oo`03001o
ogoo0?mooomooi1oo`00DGoo10000goo00@007ooOomoo`800?mooomooi9oo`00DGoo00D007ooOomo
o`0000=oo`<00003Ool000000?mooomooi5oo`00DGoo00D007ooOomoo`000?mooomooiYoo`00D7oo
1@00ogooogooVgoo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mo
oomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`
Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003o
OoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogoo
l7oo003oOoooOoo`Ool00?mooomooo1oo`00\
\>"],
  ImageRangeCache->{{{0, 749}, {366.813, 0}} -> {-1.06507, -0.648943, \
0.00442282, 0.00442282}, {{18.375, 583.625}, {358.063, 8.6875}} -> \
{-0.516095, -18.7599, 0.00657772, 0.0749043}, {{583.625, 724.938}, {268.188, \
126.875}} -> {-14.9683, -3.1709, 0.0318446, 0.0389212}, {{595.375, 634.625}, \
{258.5, 226.438}} -> {-15.9524, -10.7645, 0.0334398, 0.108214}, {{595.375, \
634.625}, {213.563, 181.438}} -> {-15.9524, -14.6575, 0.0334398, 0.108214}, \
{{595.375, 634.625}, {168.625, 136.5}} -> {-15.9524, -18.5478, 0.0334398, \
0.108214}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[58]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Inhalation\>", \ "\<Constant\>", "\<GraphicReport\>", 1, \ 
      amad, class, \ fn1, 180, lambda]\)], "Input",
  CellLabel->"In[59]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.422291 0.603319 0.0795052 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .12629 -46.5 -6.6875 ]
[-0.0125 .12629 0 6.6875 ]
[-0.0125 .2853 -40 -6.28125 ]
[-0.0125 .2853 0 6.28125 ]
[-0.0125 .44431 -28 -6.28125 ]
[-0.0125 .44431 0 6.28125 ]
[-0.0125 .60332 -10 -6.28125 ]
[-0.0125 .60332 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35242 0 m
.35242 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12629 m
.00625 .12629 L
s
gsave
-0.0125 .12629 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .2853 m
.00625 .2853 L
s
gsave
-0.0125 .2853 -101 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0001) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .44431 m
.00625 .44431 L
s
gsave
-0.0125 .44431 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -71 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .05308 m
.00375 .05308 L
s
0 .07554 m
.00375 .07554 L
s
0 .08904 m
.00375 .08904 L
s
0 .09872 m
.00375 .09872 L
s
0 .10627 m
.00375 .10627 L
s
0 .11246 m
.00375 .11246 L
s
0 .11771 m
.00375 .11771 L
s
0 .12226 m
.00375 .12226 L
s
0 .21209 m
.00375 .21209 L
s
0 .23455 m
.00375 .23455 L
s
0 .24805 m
.00375 .24805 L
s
0 .25773 m
.00375 .25773 L
s
0 .26528 m
.00375 .26528 L
s
0 .27147 m
.00375 .27147 L
s
0 .27672 m
.00375 .27672 L
s
0 .28127 m
.00375 .28127 L
s
0 .3711 m
.00375 .3711 L
s
0 .39356 m
.00375 .39356 L
s
0 .40706 m
.00375 .40706 L
s
0 .41674 m
.00375 .41674 L
s
0 .42429 m
.00375 .42429 L
s
0 .43048 m
.00375 .43048 L
s
0 .43573 m
.00375 .43573 L
s
0 .44028 m
.00375 .44028 L
s
0 .53011 m
.00375 .53011 L
s
0 .55257 m
.00375 .55257 L
s
0 .56607 m
.00375 .56607 L
s
0 .57575 m
.00375 .57575 L
s
0 .5833 m
.00375 .5833 L
s
0 .58949 m
.00375 .58949 L
s
0 .59474 m
.00375 .59474 L
s
0 .5993 m
.00375 .5993 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Constant) show
117.000 12.813 moveto
(intake) show
153.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .35745 m
.41107 .35745 L
.53436 .35745 L
.60372 .35745 L
.65224 .35745 L
.69278 .35745 L
.72483 .35745 L
.75369 .35745 L
.77776 .35745 L
.79827 .35745 L
.81784 .35745 L
.83489 .35745 L
.84991 .35745 L
.86466 .35745 L
.87782 .35745 L
.89084 .35745 L
.90257 .35745 L
.91318 .35745 L
.92384 .35745 L
.93355 .35745 L
.94333 .35745 L
.95229 .35745 L
.96051 .35745 L
.96887 .35745 L
.97619 .35745 L
s
0 1 0 r
1.5 Mabswid
[ ] 0 setdash
.02381 .54404 m
.06042 .55341 L
.08838 .55781 L
.1161 .56035 L
.13894 .56154 L
.1578 .56213 L
.17363 .56243 L
.18958 .56262 L
.20509 .56274 L
.21944 .5628 L
.23372 .56283 L
.24625 .56285 L
.25701 .56286 L
.26883 .56286 L
.2752 .56287 L
.28092 .56287 L
.30107 .56287 L
.33501 .56288 L
.36579 .56289 L
.41107 .56292 L
.45102 .56294 L
.48098 .56296 L
.53436 .56301 L
.6058 .56307 L
.65542 .56311 L
.69308 .56313 L
.70978 .56313 L
.72615 .56314 L
.7414 .56314 L
.75476 .56315 L
.76709 .56315 L
.7778 .56315 L
.78805 .56315 L
.79874 .56315 L
.80824 .56315 L
.81796 .56315 L
.82683 .56315 L
.83574 .56315 L
.84369 .56315 L
.8508 .56315 L
.8584 .56315 L
.86504 .56315 L
.87166 .56315 L
.87857 .56315 L
.88494 .56315 L
.89145 .56315 L
.8973 .56315 L
.90262 .56315 L
.90833 .56315 L
.9134 .56315 L
Mistroke
.91846 .56315 L
.92382 .56315 L
.92877 .56315 L
.93391 .56315 L
.93901 .56315 L
.94368 .56315 L
.94822 .56315 L
.9523 .56315 L
.95637 .56315 L
.96073 .56315 L
.96476 .56315 L
.96898 .56315 L
.97272 .56315 L
.97619 .56315 L
Mfstroke
0 0 1 r
2 Mabswid
[ 1 8 ] 0 Mabsdash
.02381 .01472 m
.20509 .17881 L
.30107 .24239 L
.41107 .2951 L
.48498 .32064 L
.53436 .3338 L
.60287 .34711 L
.63172 .35106 L
.65536 .3536 L
.67446 .35524 L
.69343 .35654 L
.71037 .35743 L
.72677 .35811 L
.74071 .35854 L
.75461 .35888 L
.76768 .35911 L
.7793 .35927 L
.79007 .35938 L
.79954 .35945 L
.80955 .35951 L
.81819 .35955 L
.82671 .35957 L
.8355 .3596 L
.84355 .35961 L
.85168 .35962 L
.85895 .35963 L
.86548 .35963 L
.87248 .35964 L
.87863 .35964 L
.88474 .35964 L
.89118 .35964 L
.8971 .35964 L
.90319 .35964 L
.90866 .35964 L
.91365 .35964 L
.91901 .35964 L
.92378 .35964 L
.92854 .35965 L
.93361 .35965 L
.93829 .35965 L
.94316 .35965 L
.94799 .35965 L
.95243 .35965 L
.95675 .35965 L
.96063 .35965 L
.9645 .35965 L
.96867 .35965 L
.97233 .35965 L
.97619 .35965 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0227273 0.227273 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.0681818 0.361111 0.295455 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .18182 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Lungs) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.386364 0.361111 0.613636 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
1.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .5 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.704545 0.361111 0.931818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
2 Mabswid
[ 1 8 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .81818 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[59]:=",
  ImageSize->{600, 294.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;^0001Ka000`40O003h00Oogooogool7oo003o
OoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogoo
l7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00
ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomo
oo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool0
0?mooomooo1oo`00Fgoo1@00=7oo1@00B7oo1000<Woo1@000goo1000;Goo1@0017oo1000@Goo1000
17oo1000:Woo1@000goo100017oo100097oo1@0017oo100017oo1000cGoo001MOol00`00Oomoo`0d
Ool01@00Oomoogoo0000Agoo00<007ooOol00Woo00<007ooOol0<Goo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol0:Woo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo03eoo`03
001oogoo009oo`04001oogoo0004Ool00`00Oomoo`0YOol00`00Oomoo`02Ool00`00Oomoo`02Ool0
1000Oomoo`0017oo00<007ooOol08Goo00D007ooOomoo`0000=oo`03001oogoo009oo`04001oogoo
0004Ool00`00Oomoo`3:Ool005eoo`03001oogoo03Eoo`03001oogoo04eoo`03001oogoo035oo`03
001oogoo009oo`03001oogoo009oo`03001oogoo02]oo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo049oo`04001oogoo0004Ool00`00Oomoo`0YOol00`00Oomoo`02Ool00`00Oomoo`02Ool0
1000Oomoo`0017oo00<007ooOol08Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol000Ao
o`03001oogoo0<Yoo`00GGoo00<007ooOol0=Woo00<007ooOol0C7oo00<007ooOol0<Goo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol0;7oo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool0@Woo00@007ooOol000Aoo`03001oogoo02Uoo`03001oogoo009oo`03001oogoo009oo`04001o
ogoo0004Ool00`00Oomoo`0SOol00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<0
07ooOol0bWoo001MOol00`00Oomoo`0gOol00`00Oomoo`17Ool4000dOol00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`0]Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0nOol40003
Ool00`00Oomoo`02Ool00`00Oomoo`0YOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`00
17oo00<007ooOol097oo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo
0<Yoo`00GGoo00<007ooOol0>7oo00<007ooOol0AWoo00<007ooOol0=Goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol0;Woo00D007ooOomoo`0000Aoo`03001oogoo03ioo`03001oogoo00Ao
o`03001oogoo009oo`03001oogoo02Uoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004
Ool00`00Oomoo`0UOol01@00Oomoogoo000017oo00@007ooOol000Aoo`03001oogoo0<Yoo`00Fgoo
0`00=Woo00D007ooOomoo`0004Qoo`03001oogoo03=oo`<000Aoo`03001oogoo009oo`03001oogoo
02Yoo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`0nOol00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Oomoo`0WOol30004Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol0
8Goo00D007ooOomoo`0000=oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`3:Ool005eo
o`03001oogoo03Eoo`<004Uoo`D003=oo`03001oogoo00=oo`@002ioo`<000Eoo`@0045oo`D000=o
o`@002aoo`03001oogoo00=oo`@000Aoo`@002Eoo`<000Eoo`@000Aoo`@00<eoo`00ogooogool7oo
003oOoooOoo`Ool00?mooomooo1oo`00ogooogoo>goo0`00/Woo003oOoooOolmOol00`00Oomoo`2`
Ool00?mooomoob]oo`<00003Ool00000009oo`<00003Ool0000000Aoo`03001oogoo009oo`D00:Uo
o`00ogooogoo:Woo00@007ooOomoo`80009oo`04001oogooOol20004Ool00`00Ool00003Ool00`00
Oomoo`02Ool00`00Oomoo`2VOol00?mooomoobYoo`03001oogoo009oo`04001oogoo0004Ool00`00
Oomoo`02Ool00`00Ool00008Ool00`00Oomoo`2VOol0059oool00<T000ioo`03001oogoo009oo`04
001oogooOol50003Ool01@00Oomoogoo00000goo1000ZGoo001BOol00`00Oomoo`08Ool00`00Oomo
o`0fOol00`00Oomoo`0OOol00`00Oomoo`0EOol00`00Oomoo`0@Ool00`00Oomoo`0<Ool00`00Oomo
o`0:Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0gOol00`00Oomo
o`0NOol00`00Oomoo`0EOol00`00Oomoo`0@Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomo
o`08Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0gOol00`00Oomoo`0>Ool01000Oomo
ogoo0P000Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`04001oogoo0004Ool00`00Oomoo`2V
Ool0059oo`03001oogoo00Qoo`03001oogoo03Ioo`03001oogoo04Yoo`03001oogoo03Moo`03001o
ogoo03Moo`03001oogoo04Uoo`03001oogoo03Moo`03001oogoo03Moo`03001oogoo00moo`<00003
Ool007oo009oo`@000=oo`<00004Ool000000002Ool5002XOol0059oo`03001oogoo00Qoo`03001o
ogoo03Ioo`03001oogoo04Yoo`03001oogoo03Moo`03001oogoo03Moo`03001oogoo04Uoo`03001o
ogoo03Moo`03001oogoo03Moo`03001oogoo01=oo`03001oogoo0;ioo`00DWoo00<007ooOol0ogoo
f7oo0P00`7oo001BOol00`00Oomoo`3oOoooOonKOol0059oo`03001oogoo00Moo`807omooomooi9o
o`00DWoo00<007ooOol01goo0P0OogooogooTWoo001BOol00`00Oomoo`07Ool201ooOoooOonBOol0
059oo`03001oogoo0?mooomooi]oo`00DWoo00<007ooOol0ogooogooVgoo001BOol00`00Oomoo`3o
OoooOonKOol0059oo`03001oogoo0?mooomooi]oo`00DWoo00<007ooOol047oo00<07gooOol0ogoo
ogooR7oo001BOol00`00Oomoo`0?Ool301ooOoooOon9Ool0059oo`03001oogoo011oo`<07omooomo
ohQoo`00DWoo00<007ooOol04Goo00<07gooOol0ogooogooQgoo001BOol00`00Oomoo`3oOoooOonK
Ool0059oo`03001oogoo0?mooomooi]oo`00DWoo00<007ooOol0ogooogooVgoo001BOol00`00Oomo
o`0HOol00`0OOomoo`3oOoooOon0Ool0059oo`03001oogoo01Moo`<07omooomooh5oo`00DWoo00<0
07ooOol067oo0`0OogooogooP7oo001BOol00`00Oomoo`0IOol00`0OOomoo`3oOoooOomoOol0059o
o`800?mooomooiaoo`00DWoo00<007ooOol0ogooogooVgoo001BOol00`00Oomoo`3oOoooOonKOol0
059oo`03001oogoo0?mooomooi]oo`00DWoo00<007ooOol0ogooogooVgoo001BOol00`00Oomoo`0P
Ool201ooOoooOomiOol0059oo`03001oogoo021oo`807omooomoogUoo`00DWoo00<007ooOol087oo
0P0OogooogooNGoo001BOol00`00Oomoo`3oOoooOonKOol0059oo`03001oogoo0?mooomooi]oo`00
DWoo0P00ogooogooW7oo001BOol00`00Oomoo`3oOoooOonKOol0059oo`03001oogoo0?mooomooi]o
o`00DWoo00<007ooOol0:7oo0`0OogooogooL7oo001BOol00`00Oomoo`0XOol301ooOoooOom`Ool0
059oo`03001oogoo0?mooomooi]oo`00DWoo0P00ogooogooW7oo001BOol00`00Oomoo`3oOoooOonK
Ool0059oo`03001oogoo0?mooomooi]oo`00DWoo00<007ooOol0<Goo00<07gooOol0ogooogooIgoo
001BOol00`00Oomoo`0`Ool301ooOoooOomXOol0059oo`80039oo`<07omooomoofMoo`00DWoo00<0
07ooOol0<Woo00<07gooOol0ogooogooIWoo001BOol00`00Oomoo`3oOoooOonKOol0059oo`800?mo
oomooiaoo`00DWoo00<007ooOol0ogooogooVgoo001BOol00`00Oomoo`3oOoooOonKOol0059oo`80
0?mooomooiaoo`00DWoo00<007ooOol0>Goo0P0OogooogooH7oo001BOol2000jOol201ooOoooOomP
Ool001Ioo`D000Aoo`8000Ioo`05001oogooOol00005Ool50003Ool4000EOol00`00Oomoo`0iOol2
01ooOonnOon=000DOol001Qoo`03001oogoo00Aoo`8000Moo`03001oo`0000Qoo`03001oogoo009o
o`03001oogoo009oo`03001oogoo019oo`800?moooYoohd001Aoo`0067oo00<007ooOol03Woo00<0
07ooOol01goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol04Woo00<007ooOol0ogoonGoo
S@0057oo000HOol00`00Oomoo`0=Ool00`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`0BOol4003oOoohOon=000DOol001Qoo`03001oogoo00aoo`05001oogooOol00007Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`12Ool00`0OOomoo`3oOon^
OonC000DOol001Qoo`03001oogoo01Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo019o
o`03001oogoo045oo`<07omoojmoo`03001oogoo08Yoo`H001Aoo`005Woo0`0067oo0`0017oo00<0
07ooOol00Woo00<007ooOol01Goo0P002goo00<007ooOol0@Woo0`0Oogoo[Woo00<007ooOol0RWoo
1P0057oo000HOol00`00Oomoo`0HOol00`00Oomoo`03Ool40002Ool40002Ool00`00Ool0000:Ool0
0`00Oomoo`13Ool00`0OOomoo`3oOon]Ool00`00Oomoo`2:Ool6000DOol004Eoo`03001oo`0000Yo
o`03001oogoo0?mooo=oo`03001oogoo08Yoo`H001Aoo`00AGoo0P002goo00<007ooOol0ogoolgoo
00<007ooOol0RWoo1P0057oo0015Ool00`00Oomoo`0:Ool00`00Oomoo`3oOoocOol00`00Oomoo`2:
Ool6000DOol004Ioo`8000Yoo`03001oogoo0?mooo=oo`03001oogoo08Yoo`H001Aoo`00DWoo00<0
07ooOol0BWoo00<07gooOol0ogooYWoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`19Ool3
01ooOonWOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo04Yoo`<07omoojIoo`03001oogoo
08Yoo`H001Aoo`00DWoo00<007ooOol0Bgoo00<07gooOol0ogooYGoo00<007ooOol0RWoo1P0057oo
001BOol00`00Oomoo`3oOoocOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?mooo=oo`03
001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogoolgoo00<007ooOol0RWoo1P0057oo001BOol0
0`00Oomoo`3oOoocOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo059oo`807omooimoo`03
001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0DWoo0P0OogooWgoo00<007ooOol0RWoo1P0057oo
001BOol00`00Oomoo`1BOol201ooOonOOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?mo
oo=oo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogoolgoo00<007ooOol0RWoo1P0057oo
001BOol00`00Oomoo`3oOoocOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?mooo=oo`03
001oogoo05Ioo`@0031oo`H001Aoo`00DWoo00<007ooOol0ogoolgoo00<007ooOol0FWoo00<007oo
Ool0;Goo1P0057oo001BOol00`00Oomoo`1JOol301ooOonFOol00`00Oomoo`0mOol60004Ool20000
17oo000007oo0`0000Aoo`000000009oo`<00004Ool007ooOol5000XOol6000DOol0059oo`03001o
ogoo05Yoo`<07omooiIoo`03001oogoo03ioo`05001oogooOol00003Ool00`00Oomoo`020003Ool0
1@00Oomoogoo00000Woo00@007ooOomoo`80009oo`03001oogoo009oo`03001oogoo02Eoo`H001Ao
o`00DWoo00<007ooOol0ogoolgoo00<007ooOol02Woo1W`017oo1W`017oo1W`017oo1W`047oo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00<0
07ooOol01Goo00<007ooOol09Goo1P0057oo001BOol00`00Oomoo`3oOoocOol00`00Oomoo`0nOol0
0`00Oomoo`05Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`03001oogoo009oo`04001o
ogooOol4000XOol6000DOol0059oo`03001oogoo0?mooo=oo`03001oogoo03ioo`03001oogoo00Eo
o`05001oogooOol00003Ool20002Ool01000Oomoo`000goo0P000Woo00<007ooOol00Woo00<007oo
Ool09Goo1P0057oo001BOol00`00Oomoo`1TOol00`0OOomoo`3oOon<Ool00`00Oomoo`0nOol00`00
Oomoo`04Ool20002Ool20002Ool200000goo00000004Ool300000goo00000002Ool5000WOol6000D
Ool0059oo`03001oogoo06=oo`<07omooheoo`03001oogoo03ioo`03001oogoo04Uoo`H001Aoo`00
DWoo00<007ooOol0I7oo0`0OogooS7oo00<007ooOol0?Goo0`00BWoo1P0057oo001BOol00`00Oomo
o`1UOol00`0OOomoo`3oOon;Ool00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?mooo=oo`03
001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogoolgoo00<007ooOol0RWoo1P0057oo001BOol0
0`00Oomoo`1^Ool00`0OOomoo`3oOon2Ool00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo06eo
o`<07omooh=oo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0KWoo0`0OogooPWoo00<007oo
Ool0RWoo1P0057oo001BOol2001`Ool00`0OOomoo`3oOon1Ool00`00Oomoo`2:Ool6000DOol0059o
o`03001oogoo0?mooo=oo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogoolgoo00<007oo
Ool0RWoo1P0057oo001BOol00`00Oomoo`1gOol00`0OOomoo`3oOomiOol00`00Oomoo`2:Ool6000D
Ool0059oo`03001oogoo07Ioo`<07omoogYoo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0
Mgoo0`0OogooNGoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`1hOol00`0OOomoo`3oOomh
Ool00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?mooo=oo`03001oogoo08Yoo`H001Aoo`00
DWoo00<007ooOol0ogoolgoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOoocOol00`00
Oomoo`2:Ool6000DOol0059oo`800?moooAoo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0
P7oo0`0OogooL7oo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`20Ool301ooOom`Ool00`00
Oomoo`2:Ool6000DOol0059oo`03001oogoo0?mooo=oo`03001oogoo08Yoo`H001Aoo`00DWoo00<0
07ooOol0ogoolgoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`2:Ool00`0OOomoo`3oOomV
Ool00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo08Uoo`<07omoofMoo`03001oogoo08Yoo`H0
01Aoo`00DWoo0P00Rgoo0`0OogooIWoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`2;Ool0
0`0OOomoo`3oOomUOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?mooo=oo`03001oogoo
08Yoo`H001Aoo`00DWoo00<007ooOol0U7oo00<07gooOol0ogooG7oo00<007ooOol0RWoo1P0057oo
001BOol2002DOol401ooOomLOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo09Aoo`@07omo
oe]oo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0UWoo00<07gooOol0ogooFWoo00<007oo
Ool0?Goo1P000Woo0P000Woo0P000goo10000goo1@0017oo1@0017oo0`0017oo1@000goo10000goo
0`0000Aoo`00000000Ioo`H001Aoo`00DWoo0P00ogoom7oo00<007ooOol0?Woo00D007ooOomoo`00
00=oo`04001oogoo0003Ool00`00Oomoo`02Ool01@00Oomoogoo00001Woo00<007ooOol01Woo00D0
07ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomo
o`05Ool6000DOol0059oo`03001oogoo0?mooo=oo`03001oogoo03ioo`03001oogoo00Ioo`8000Ao
o`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo009o
o`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`05Ool6000DOol0059oo`03001oogoo
09ioo`<07omooe9oo`03001oogoo03ioo`03001oo`0000Ioo`8000Aoo`03001oogoo00Ioo`03001o
ogoo00Aoo`H000=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`05001oogooOol0
0003Ool00`00Oomoo`05Ool6000DOol0059oo`8009moo`<07omooe9oo`03001oogoo03ioo`<000Eo
o`04001oogoo0003Ool01000Oomoogoo0P000goo0P001Goo00<007ooOol00Woo00D007ooOomoo`00
00Uoo`03001oogoo009oo`03001oogoo009oo`04001oogooOol20002Ool00`00Oomoo`05Ool6000D
Ool0059oo`03001oogoo0?mooo=oo`03001oogoo03ioo`03001oo`0000Aoo`80009oo`8000=oo`<0
0004Ool007ooOol2000017oo000000000goo10000goo1@0017oo0`001Goo10000goo0P0000=oo`00
000027oo1P0057oo001BOol00`00Oomoo`3oOoocOol00`00Oomoo`0nOol01@00Oomoogoo00008goo
00<007ooOol08Goo1P0057oo001BOol2003oOoodOol00`00Oomoo`0mOol6000]Ool00`00Oomoo`0G
Ool6000DOol001moo`@000Eoo`8000Eoo`@000Aoo`@000Aoo`@000Aoo`D000Ioo`03001oogoo0:Qo
o`<07omoodQoo`03001oogoo08Yoo`H001Aoo`007Woo00<007ooOol00Woo00<007ooOol00Woo0P00
17oo00<007ooOol00Woo00@007ooOol000Aoo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomo
o`06Ool2002YOol301ooOom8Ool00`00Oomoo`2:Ool6000DOol001ioo`03001oogoo009oo`03001o
ogoo00Qoo`03001oogoo009oo`04001oogoo0004Ool01000Oomoo`0017oo00<007ooOol00goo00<0
07ooOol01Woo1000ogoolWoo00<007ooOol02Woo9P?PFWoo1P0057oo000NOol00`00Oomoo`02Ool0
0`00Oomoo`08Ool00`00Oomoo`02Ool01000Oomoo`0017oo00@007ooOol000Aoo`03001oogoo00=o
o`03001oogoo00Ioo`03001oogoo0?mooo=oo`03001oogoo08Yoo`H001Aoo`007Woo00<007ooOol0
0Woo00<007ooOol027oo00<007ooOol00Woo00@007ooOol000Aoo`04001oogoo0004Ool00`00Oomo
o`03Ool00`00Oomoo`06Ool00`00Oomoo`3oOoocOol00`00Oomoo`2:Ool6000DOol001ioo`03001o
ogoo009oo`03001oogoo00Qoo`03001oogoo009oo`04001oogoo0004Ool01000Oomoo`0017oo00<0
07ooOol00goo00<007ooOol01Woo00<007ooOol0/Woo0`0Oogoo?Woo00<007ooOol0RWoo1P0057oo
000NOol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool01000Oomoo`0017oo00@007oo
Ool000Aoo`04001oogooOol30008Ool00`00Oomoo`2bOol301ooOolnOol00`00Oomoo`2:Ool6000D
Ool001moo`@000aoo`@000Aoo`@000Aoo`@000Ioo`03001oogoo00Ioo`03001oogoo0?mooo=oo`03
001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogoolgoo00<007ooOol0?goo0`000goo1@0017oo
1@000Woo0`0000Aoo`000000009oo`D002Moo`H001Aoo`00DWoo00<007ooOol0_7oo0`0Oogoo=7oo
00<007ooOol0?Woo00D007ooOomoo`0000=oo`03001oogoo00Moo`03001oogoo00=oo`05001oogoo
Ool00002Ool00`00Oomoo`0ZOol6000DOol0059oo`03001oogoo0;aoo`<07omoocAoo`03001oogoo
03ioo`05001oogooOol00003Ool00`00Oomoo`07Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo
00<007ooOol0:Woo1P0057oo001BOol00`00Oomoo`3oOoocOol00`00Oomoo`0nOol01@00Oomoogoo
00000goo00<007ooOol01goo00<007ooOol00goo00D007ooOomoo`00009oo`H002Moo`H001Aoo`00
DWoo00<007ooOol0ogoolgoo00<007ooOol0?Woo00D007ooOomoo`0000=oo`8000Qoo`03001oogoo
00=oo`80009oo`04001oogoo0004Ool00`00Oomoo`0UOol6000DOol0059oo`03001oogoo0<Moo`<0
7omoobUoo`03001oogoo03ioo`05001oogooOol00002Ool2000017oo000000000goo0`0017oo0P00
00=oo`00000017oo1000:7oo1P0057oo001BOol00`00Oomoo`37Ool301ooOolYOol00`00Oomoo`0n
Ool01@00Oomoogoo0000Agoo1P0057oo001BOol00`00Oomoo`3BOol00`0OOomoo`3oOolNOol00`00
Oomoo`0mOol3000017oo0000000037oo00<007ooOol0=goo1P0057oo001BOol00`00Oomoo`3AOol4
01ooOolNOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0=9oo`@07omooaeoo`03001oogoo
08Yoo`H001Aoo`00DWoo00<007ooOol0e7oo00<07gooOol0ogoo77oo00<007ooOol0RWoo1P0057oo
001BOol00`00Oomoo`3oOoocOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0=aoo`<07omo
oaAoo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0g7oo0`0Oogoo57oo00<007ooOol0RWoo
1P0057oo001BOol00`00Oomoo`3oOoocOol00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0>Mo
o`<07omoo`Uoo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0igoo0`0Oogoo2Goo00<007oo
Ool0RWoo1P0057oo001BOol00`00Oomoo`3bOol301omOol00`00Oomoo`2:Ool6000DOol0059oo`03
001oogoo0?9oo`<07`Uoo`0301moogoo0?5oo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0
oGoo0`0OlWoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3nOol301l8Ool00`0OOomoo`3V
Ool00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo0?moo`0301moogoo00Ioo`<07nMoo`03001o
ogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogoo2Woo0`0O27oo00<07gooOol0fgoo00<007ooOol0
RWoo1P0057oo001BOol00`00Oomoo`3oOol;Ool00`0OOomoo`06Ool301oLOol00`00Oomoo`2:Ool6
000DOol0059oo`03001oogoo0?mooaEoo`<07m]oo`03001oogoo08Yoo`H001Aoo`00DWoo00<007oo
Ool0ogoo5Woo00<07gooOol01Woo100Od7oo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3o
OolOOol401l8Ool301o5Ool00`00Oomoo`2:Ool6000DOol0059oo`03001oogoo00Qoo`Il00Aoo`Il
00Aoo`Il00Aoo`Il00Aoo`Il00Aoo`Il00Aoo`Il00Aoo`Il00Aoo`Il00Aoo`Il00Aoo`Il00Aoo`Il
00Aoo`Il00Aoo`Il00Aoo`Il00Aoo`Il00Aoo`Il00Aoo`Il00Aoo`Il00Aoo`Il00Aoo`Il00Aoo`Il
00Aoo`Il00Aoo`Il00Aoo`Il00Aoo`Il00Aoo`Il00Aoo`Il00Aoo`Il00Aoo`<07`=l00Aoo`04O000
7`0O01l2O004Ool2O00301l00g`0Oomoo`02Ool6O004Ool6O004Ool6O004Ool6O004Ool6O004Ool6
O004Ool6O004Ool6O004Ool6O004Ool6O004Ool6O004Ool4O00hOol00`00Oomoo`2:Ool6000DOol0
059oo`03001oogoo0?moocIoo`<07`Qoo`<07`Qoo`<07`Qoo`@07`Qoo`<07`Qoo`<07`Qoo`<07`Qo
o`@07`Qoo`<07`Qoo`<07`Qoo`<07`Qoo`@07cioo`03001oogoo08Yoo`H001Aoo`00DWoo00<007oo
Ool0ogooC7oo0`0O27oo100O27oo0`0O27oo0`0O27oo0`0O27oo100O27oo0`0O27oo0`0O27oo0`0O
27oo100O?Woo00<007ooOol0?Goo1P000Woo0P000Woo0P000goo10000goo1@0017oo1@0017oo0`00
17oo1@000goo10000goo0`0000Aoo`00000000Ioo`H001Aoo`00DWoo00<007ooOol0ogoolgoo00<0
07ooOol0?Woo00D007ooOomoo`0000=oo`04001oogoo0003Ool00`00Oomoo`02Ool01@00Oomoogoo
00001Woo00<007ooOol01Woo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo009oo`05
001oogooOol00003Ool00`00Oomoo`05Ool6000DOol0059oo`03001oogoo0?mooo=oo`03001oogoo
03ioo`03001oogoo00Ioo`8000Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03
001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`05
Ool6000DOol0059oo`03001oogoo0?mooo=oo`03001oogoo03ioo`03001oo`0000Ioo`8000Aoo`03
001oogoo00Ioo`03001oogoo00Aoo`H000=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo
009oo`05001oogooOol00003Ool00`00Oomoo`05Ool6000DOol0059oo`03001oogoo0?mooo=oo`03
001oogoo03ioo`<000Eoo`04001oogoo0003Ool01000Oomoogoo0P000goo0P001Goo00<007ooOol0
0Woo00D007ooOomoo`0000Uoo`03001oogoo009oo`03001oogoo009oo`04001oogooOol20002Ool0
0`00Oomoo`05Ool6000DOol0059oo`800?moooAoo`03001oogoo03ioo`03001oo`0000Aoo`80009o
o`8000=oo`<00004Ool007ooOol2000017oo000000000goo10000goo1@0017oo0`001Goo10000goo
0P0000=oo`00000027oo1P0057oo001BOol00`00Oomoo`3oOoocOol00`00Oomoo`0nOol01@00Oomo
ogoo00008goo00<007ooOol08Goo1P0057oo001BOol00`00Oomoo`3oOoocOol00`00Oomoo`0mOol6
000]Ool00`00Oomoo`0GOol6000DOol0059oo`03001oogoo0?mooo=oo`03001oogoo08Yoo`H001Ao
o`00DWoo00<007ooOol0ogoolgoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOoocOol0
0`00Oomoo`09Ool301l8Ool301l8Ool401l8Ool301mLOol6000DOol0059oo`03001oogoo0?mooo=o
o`03001oogoo00Uoo`<07`Qoo`<07`Qoo`@07`Qoo`<07eaoo`H001Aoo`00DWoo00<007ooOol0ogoo
lgoo00<007ooOol0RWoo1P0057oo001BOol00`00Oomoo`3oOoocOol00`00Oomoo`2:Ool6000DOol0
059oo`03001oogoo0?mooo=oo`03001oogoo08Yoo`H001Aoo`00DWoo0P00ogoom7oo00<007ooOol0
RWoo1P0057oo001BOol00`00Oomoo`3oOoocOol00`00Oomoo`0mOol30006Ool300000goo00000002
Ool50003Ool40004Ool300000goo00000002Ool5000OOol6000DOol0059oo`03001oogoo0?mooo=o
o`03001oogoo03ioo`03001oogoo00Aoo`04001oogooOol20002Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool01000Oomoo`000goo0P001Goo00<007ooOol07goo1P0057oo001BOol00`00Oomoo`3oOooc
Ool00`00Oomoo`0nOol00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`001goo00<007ooOol0
1Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol07goo1P0057oo001BOol00`00Oomoo`3o
OoocOol00`00Oomoo`0nOol00`00Ool00005Ool50002Ool60002Ool00`00Oomoo`06Ool50005Ool0
0`00Oomoo`0OOol6000DOol0059oo`03001oogoo0?mooo=oo`03001oogoo03ioo`<000Aoo`03001o
ogoo009oo`04001oogoo0004Ool01000Oomoo`000goo0P000Woo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol07goo1P0057oo001BOol2003oOoodOol00`00Oomoo`0nOol00`00Ool00005Ool4
0004Ool40004Ool300000goo001oo`02Ool40006Ool00`00Oomoo`0OOol6000DOol0059oo`03001o
ogoo0?mooo=oo`03001oogoo03ioo`05001oogooOol0000UOol00`00Oomoo`0OOol6000DOol0059o
o`03001oogoo0?mooo=oo`03001oogoo03eoo`H002Aoo`80025oo`H001Aoo`00DWoo00<007ooOol0
ogoolgoo00<007ooOol0RWoo1P0057oo001BOol2003oOoodOol00`00Oomoo`2:Ool6000DOol0059o
o`03001oogoo0?mooo=oo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogoolgoo00<007oo
Ool0RWoo1P0057oo001BOol00`00Oomoo`3oOoocOol00`00Oomoo`2:Ool6000DOol0059oo`800?mo
ooAoo`03001oogoo08Yoo`H001Aoo`00DWoo00<007ooOol0ogoolgoo00<007ooOol0RWoo1P0057oo
001BOol00`00Oomoo`3oOoocOol00`00Oomoo`2:Ool00`00Oomoo`0GOol0059oo`800?moooAoo`03
001oogoo08Yoo`03001oogoo01Moo`00DWoo00<007ooOol0ogoolgoo00<007ooOol0RWoo00<007oo
Ool05goo001BOol2003oOoodOol00`00Oomoo`2:Ool00`00Oomoo`0GOol0059oo`03001oogoo0?mo
oo=oo`03001oogoo08Yoo`03001oogoo01Moo`00;Woo10001Goo0P001Goo100017oo1@001goo0P00
ogoom7ooSP006Goo000]Ool00`00Oomoo`02Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`3oOoooOonKOol002eoo`03001oogoo009oo`03
001oogoo00Qoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Moo`@00?mooomooiYoo`00
;Goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
1goo00<007ooOol0ogooogooVgoo000]Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`3oOoooOonKOol002eoo`03001oogoo009o
o`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo0?mo
oomooi]oo`00;Goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00@007ooOomoo`<0
00Uoo`03001oogoo0?mooomooi]oo`00;Woo100037oo10001Woo00<007ooOol01goo00<007ooOol0
ogooogooVgoo001BOol00`00Oomoo`3oOoooOonKOol0059oo`03001oogoo0?mooomooi]oo`00DWoo
00<007ooOol0ogooogooVgoo001BOol00`00Oomoo`3oOoooOonKOol0059oo`03001oogoo0?mooomo
oi]oo`00DWoo00<007ooOol0ogooogooVgoo001BOol00`00Oomoo`3oOoooOonKOol0059oo`03001o
ogoo0?mooomooi]oo`00DWoo00<007ooOol0ogooogooVgoo001BOol00`00Oomoo`3oOoooOonKOol0
059oo`03001oogoo0?mooomooi]oo`00DWoo00<007ooOol0ogooogooVgoo001BOol00`00Oomoo`3o
OoooOonKOol0059oo`03001oogoo0?mooomooi]oo`00DWoo00<007ooOol0ogooogooVgoo001BOol0
0`00Oomoo`3oOoooOonKOol0059oo`03001oogoo0?mooomooi]oo`00DWoo00<007ooOol0ogooogoo
Vgoo001BOol00`00Oomoo`3oOoooOonKOol0059oo`03001oogoo0?mooomooi]oo`00DWoo00<007oo
Ool0ogooogooVgoo001BOol00`00Oomoo`3oOoooOonKOol0059oo`03001oogoo0?mooomooi]oo`00
DWoo00<007ooOol0ogooogooVgoo001BOol00`00Oomoo`3oOoooOonKOol0059oo`03001oogoo0?mo
oomooi]oo`00DWoo00<007ooOol0ogooogooVgoo001BOol00`00Oomoo`3oOoooOonKOol0059oo`03
001oogoo0?mooomooi]oo`00DWoo00<007ooOol0ogooogooVgoo001BOol00`00Oomoo`3oOoooOonK
Ool0059oo`03001oogoo0?mooomooi]oo`00DWoo00<007ooOol0ogooogooVgoo001BOol2003oOooo
OonLOol0059oo`03001oogoo0?mooomooi]oo`00DWoo00<007ooOol0ogooogooVgoo001BOol00`00
Oomoo`3oOoooOonKOol0059oo`03001oogoo0?mooomooi]oo`00DWoo00<007ooOol0ogooogooVgoo
001BOol00`00Oomoo`08Ool20n3oOoooOonAOol0059oo`03001oogoo00Yoo`@3h?mooomooheoo`00
DWoo00<007ooOol03Woo10?PogooogooRGoo001BOol00`00Oomoo`0BOol40n3oOoooOon5Ool0059o
o`8001Moo`H3h?mooomoogmoo`00DWoo00<007ooOol077oo1P?PogooogooNGoo001BOol00`00Oomo
o`0ROol70n3oOoooOombOol0059oo`03001oogoo02Uoo`H3h?mooomoofaoo`00DWoo00<007ooOol0
;goo6P?PogooogooDWoo001BOol00`00Oomoo`19Oooo0n1b0n3OOol0059oo`800?mooomooiaoo`00
DWoo00<007ooOol0ogooogooVgoo001BOol00`00Oomoo`3oOoooOonKOol0059oo`03001oogoo0?mo
oomooi]oo`00DWoo00<007ooOol0ogooogooVgoo001BOol2003oOoooOonLOol0059oo`03001oogoo
0?mooomooi]oo`00DWoo00<007ooOol0ogooogooVgoo001BOol2003oOoooOonLOol0059oo`03001o
ogoo0?mooomooi]oo`00DWoo00<007ooOol0ogooogooVgoo001BOol2003oOoooOonLOol0059oo`03
001oogoo0?mooomooi]oo`00DWoo0P00ogooogooW7oo001BOol00`00Oomoo`3oOoooOonKOol004Ao
o`D000Uoo`800?mooomooiaoo`00AWoo00<007ooOol02Goo00<007ooOol0ogooogooVgoo0016Ool0
0`00Oomoo`09Ool4003oOoooOonJOol004Ioo`03001oogoo00Uoo`03001oogoo0?mooomooi]oo`00
AWoo00<007ooOol02Goo00<007ooOol0ogooogooVgoo0016Ool00`00Oomoo`09Ool00`00Oomoo`3o
OoooOonKOol004Aoo`<000]oo`03001oogoo0?mooomooi]oo`00AWoo00<007ooOol02Goo00<007oo
Ool0ogooogooVgoo001BOol00`00Oomoo`3oOoooOonKOol0059oo`03001oogoo0?mooomooi]oo`00
ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomo
oo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOol1Ool30004
Ool40003Ool300001Goo00000000Ool01@001Goo0`0017oo0`0000Aoo`00001oo`<00004Ool00000
0003Ool30007Ool50002Ool3000017oo000000000goo0`0017oo0`0000Aoo`00001oo`80009oo`<0
009oo`D00?mooh1oo`00ogoo00D007ooOomoo`00009oo`03001oogoo009oo`05001oogooOol00003
Ool01000Oomoo`0017oo00D007ooOomoo`0000=oo`04001oogoo0003Ool20003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000Qoo`03001oogoo00=oo`05001oogooOol00003Ool01@00Oomoogoo
00000Woo00@007ooOomoo`8000=oo`04001oogoo0003Ool00`00Oomoo`3oOon3Ool00?ioo`03001o
ogoo00Eoo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`05Ool01@00Oomoogoo0000
1Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol0000<Ool00`00Oomoo`03Ool0
1@00Oomoogoo00000goo00<007ooOol017oo00<007ooOol00Woo00L007ooOomoo`00Ool00004Ool0
0`00Oomoo`3oOon3Ool00?ioo`03001oogoo00Eoo`03001oogoo009oo`05001oogooOol00003Ool0
1000Oomoogoo100017oo00<007ooOol01Goo1@000goo00D007ooOomoo`0000=oo`03001oogoo00Yo
o`03001oogoo00=oo`05001oogooOol00003Ool00`00Oomoo`05Ool50003Ool30004Ool6003oOon0
Ool005Moo`<00:Aoo`03001oogoo00Eoo`03001oogoo009oo`04001oogooOol20002Ool01000Oomo
o`0017oo00D007ooOomoo`0000Ioo`03001oogoo009oo`04001oogooOol20002Ool01@00Oomoogoo
000037oo00<007ooOol00goo0P000Woo00D007ooOomoo`0000Ioo`03001oogoo009oo`05001oogoo
Ool00002Ool01@00Oomoogoo000017oo00<007ooOol0ogooOWoo001HOol00`00Oomoo`2SOol00`00
Oomoo`06Ool40003Ool200000goo00000004Ool50002Ool50004Ool40003Ool200000goo00000003
Ool50007Ool30004Ool200000goo00000003Ool50004Ool40004Ool00`00Ool000030002Ool4003o
Oon1Ool004]oo`D000Aoo`<00003Ool007oo0:Eoo`05001oogooOol0000KOol00`00Oomoo`0EOol0
0`00Oomoo`0HOol00`00Oomoo`0=Ool00`00Oomoo`3oOon:Ool004aoo`05001oogooOol00002Ool0
1000Oomoogoo0P00Ygoo1000@7oo00<007ooOol06Woo0P00ogooS7oo001<Ool01@00Oomoogoo0000
0Woo00<007ooOol00Woo00<007ooOol0ogooogooUGoo001<Ool01@00Oomoogoo00000Woo00<007oo
Ool00Woo00<007ooOol0ogooogooUGoo001<Ool40003Ool01000Oomoogoo0P00ogooogooUgoo001<
Ool01@00Oomoogoo00000goo0`0000=oo`000000ogooogooUWoo001<Ool01@00Oomoogoo0000ogoo
ogooWgoo001;Ool5003oOoooOonPOol00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mo
oomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`
Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003o
OoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogoo
l7oo003oOoooOoo`Ool00001\
\>"],
  ImageRangeCache->{{{0, 749}, {366.813, 0}} -> {-1.06507, -0.648943, \
0.00442282, 0.00442282}, {{18.375, 583.625}, {358.063, 8.6875}} -> \
{-0.484088, -8.69332, 0.0065048, 0.0345501}, {{583.625, 724.938}, {268.188, \
126.875}} -> {-14.9683, -3.1709, 0.0318446, 0.0389212}, {{595.375, 634.625}, \
{258.5, 226.438}} -> {-15.9524, -10.7645, 0.0334398, 0.108214}, {{595.375, \
634.625}, {213.563, 181.438}} -> {-15.9524, -14.6575, 0.0334398, 0.108214}, \
{{595.375, 634.625}, {168.625, 136.5}} -> {-15.9524, -18.5478, 0.0334398, \
0.108214}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[59]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Inhalation\>", \ "\<Continuous\>", "\<GraphicReport\>", 
      inputs1, \ amad, class, fn1, 180, lambda]\)], "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    \("Option not available for inhalation"\)], "Output",
  CellLabel->"Out[60]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Inhalation\>", \ "\<MultiInputs\>", "\<GraphicReport\>", 
      inputs2, \ amad, class, \ fn1, 180, lambda]\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    RowBox[{\(ParametricPlot::"pptr"\), \(\(:\)\(\ \)\), \
"\<\"\\!\\({\\(Log[Biokmod`Humorap3`Private`t3$46740]\\)\\/\\(Log[10]\\), \
\\(Log[\\(\\(\\(\\(\[LeftSkeleton] 33 \[RightSkeleton]\\)\\)[\\(\\(\
\[LeftSkeleton] 33 \[RightSkeleton]\\)\\)]\\)\\)]\\)\\/\\(Log[10]\\)}\\) does \
not evaluate to a pair of real numbers at \
\\!\\(Biokmod`Humorap3`Private`t3$46740\\) = \\!\\(8.261491491551926`\\). \\!\
\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"ParametricPlot::pptr\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[61]:="],

Cell[BoxData[
    RowBox[{\(ParametricPlot::"pptr"\), \(\(:\)\(\ \)\), \
"\<\"\\!\\({\\(Log[Biokmod`Humorap3`Private`t3$46740]\\)\\/\\(Log[10]\\), \
\\(Log[\\(\\(\\(\\(\[LeftSkeleton] 33 \[RightSkeleton]\\)\\)[\\(\\(\
\[LeftSkeleton] 33 \[RightSkeleton]\\)\\)]\\)\\)]\\)\\/\\(Log[10]\\)}\\) does \
not evaluate to a pair of real numbers at \
\\!\\(Biokmod`Humorap3`Private`t3$46740\\) = \\!\\(16.18077517482789`\\). \\!\
\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"ParametricPlot::pptr\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[61]:="],

Cell[BoxData[
    RowBox[{\(ParametricPlot::"pptr"\), \(\(:\)\(\ \)\), \
"\<\"\\!\\({\\(Log[Biokmod`Humorap3`Private`t3$46740]\\)\\/\\(Log[10]\\), \
\\(Log[\\(\\(\\(\\(\[LeftSkeleton] 33 \[RightSkeleton]\\)\\)[\\(\\(\
\[LeftSkeleton] 33 \[RightSkeleton]\\)\\)]\\)\\)]\\)\\/\\(Log[10]\\)}\\) does \
not evaluate to a pair of real numbers at \
\\!\\(Biokmod`Humorap3`Private`t3$46740\\) = \\!\\(7.247549022562476`\\). \\!\
\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"ParametricPlot::pptr\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[61]:="],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(ParametricPlot :: \\\"pptr\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[61]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.422291 0.592207 0.0375439 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .10414 -50.6875 -6.6875 ]
[-0.0125 .10414 0 6.6875 ]
[-0.0125 .21677 -50.6875 -6.6875 ]
[-0.0125 .21677 0 6.6875 ]
[-0.0125 .3294 -46.5 -6.625 ]
[-0.0125 .3294 0 6.625 ]
[-0.0125 .44203 -40 -6.28125 ]
[-0.0125 .44203 0 6.28125 ]
[-0.0125 .55466 -22 -6.28125 ]
[-0.0125 .55466 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35242 0 m
.35242 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10414 m
.00625 .10414 L
s
gsave
-0.0125 .10414 -111.688 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
109.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .21677 m
.00625 .21677 L
s
gsave
-0.0125 .21677 -111.688 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
109.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .3294 m
.00625 .3294 L
s
gsave
-0.0125 .3294 -107.5 -10.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.500 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.313 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
105.000 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .44203 m
.00625 .44203 L
s
gsave
-0.0125 .44203 -101 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0001) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .55466 m
.00625 .55466 L
s
gsave
-0.0125 .55466 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .06844 m
.00375 .06844 L
s
0 .07967 m
.00375 .07967 L
s
0 .08626 m
.00375 .08626 L
s
0 .09094 m
.00375 .09094 L
s
0 .09457 m
.00375 .09457 L
s
0 .09753 m
.00375 .09753 L
s
0 .10004 m
.00375 .10004 L
s
0 .10222 m
.00375 .10222 L
s
0 .18107 m
.00375 .18107 L
s
0 .1923 m
.00375 .1923 L
s
0 .19889 m
.00375 .19889 L
s
0 .20357 m
.00375 .20357 L
s
0 .2072 m
.00375 .2072 L
s
0 .21017 m
.00375 .21017 L
s
0 .21268 m
.00375 .21268 L
s
0 .21485 m
.00375 .21485 L
s
0 .2937 m
.00375 .2937 L
s
0 .30493 m
.00375 .30493 L
s
0 .31152 m
.00375 .31152 L
s
0 .3162 m
.00375 .3162 L
s
0 .31983 m
.00375 .31983 L
s
0 .3228 m
.00375 .3228 L
s
0 .32531 m
.00375 .32531 L
s
0 .32748 m
.00375 .32748 L
s
0 .40634 m
.00375 .40634 L
s
0 .41756 m
.00375 .41756 L
s
0 .42415 m
.00375 .42415 L
s
0 .42883 m
.00375 .42883 L
s
0 .43246 m
.00375 .43246 L
s
0 .43543 m
.00375 .43543 L
s
0 .43794 m
.00375 .43794 L
s
0 .44011 m
.00375 .44011 L
s
0 .51897 m
.00375 .51897 L
s
0 .5302 m
.00375 .5302 L
s
0 .53678 m
.00375 .53678 L
s
0 .54146 m
.00375 .54146 L
s
0 .54509 m
.00375 .54509 L
s
0 .54806 m
.00375 .54806 L
s
0 .55057 m
.00375 .55057 L
s
0 .55275 m
.00375 .55275 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Multiple) show
117.000 12.813 moveto
(intake) show
153.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
0 1 0 r
1.5 Mabswid
[ ] 0 setdash
.02381 .60332 m
.20509 .53096 L
.23624 .5094 L
.2498 .50008 L
.26149 .49288 L
.2715 .48785 L
.28154 .48419 L
.29109 .48199 L
.30107 .4808 L
.31022 .48038 L
.31516 .48033 L
.31957 .48035 L
.32783 .4805 L
.33536 .48071 L
.36608 .48168 L
.37752 .48199 L
.38897 .48224 L
.39525 .48235 L
.40077 .48243 L
.40617 .4825 L
.41107 .48255 L
.41625 .48258 L
.41894 .4826 L
.42177 .48261 L
.42469 .48262 L
.42742 .48262 L
.42984 .48262 L
.43243 .48261 L
.43704 .4826 L
.43933 .48258 L
.44182 .48257 L
.44614 .48253 L
.4501 .48248 L
.4594 .48234 L
.46754 .48216 L
.48465 .48166 L
.49748 .48115 L
.51055 .4805 L
.53436 .47896 L
.55504 .47721 L
.572 .47546 L
.60516 .47111 L
.65547 .46176 L
.69357 .452 L
.72693 .44115 L
.75417 .43041 L
.77703 .41993 L
.7986 .40866 L
.8172 .39774 L
.83511 .38608 L
Mistroke
.85084 .37482 L
.86481 .36396 L
.87858 .35239 L
.89093 .34125 L
.9032 .3294 L
.9143 .31798 L
.92438 .30699 L
.93452 .29529 L
.94378 .28403 L
.95227 .2732 L
.9609 .26167 L
.96883 .25057 L
.97619 .23984 L
Mfstroke
0 0 1 r
2 Mabswid
[ 1 8 ] 0 Mabsdash
.02381 .43342 m
.20509 .44787 L
.30107 .4575 L
.33536 .46013 L
.36608 .46197 L
.37932 .46261 L
.39101 .46308 L
.41107 .46371 L
.42093 .46392 L
.42637 .46402 L
.43121 .46409 L
.43616 .46414 L
.43884 .46416 L
.44135 .46418 L
.44572 .4642 L
.44815 .4642 L
.45038 .4642 L
.4546 .46419 L
.45849 .46417 L
.46191 .46415 L
.46554 .46411 L
.46943 .46406 L
.47345 .464 L
.48044 .46387 L
.48775 .46368 L
.49527 .46345 L
.50812 .46295 L
.52231 .46223 L
.53436 .46148 L
.57108 .4583 L
.58898 .45623 L
.60412 .45417 L
.65389 .44519 L
.69164 .43573 L
.72478 .42514 L
.75186 .41466 L
.77685 .40331 L
.79807 .39225 L
.8164 .38154 L
.83408 .37009 L
.84963 .35904 L
.86483 .34726 L
.87837 .3359 L
.89051 .32496 L
.90261 .31332 L
.91355 .3021 L
.92348 .29131 L
.9335 .27983 L
.94265 .26877 L
.9519 .25701 L
Mistroke
.9604 .24568 L
.96821 .23479 L
.97618 .22319 L
.97619 .22317 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0227273 0.227273 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.0681818 0.361111 0.295455 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .18182 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Lungs) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.386364 0.361111 0.613636 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
1.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .5 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.704545 0.361111 0.931818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
2 Mabswid
[ 1 8 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .81818 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[61]:=",
  ImageSize->{600, 294.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;^0001Ka000`40O003h00Oogooogool7oo003o
OoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogoo
l7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00
ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomo
oo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool0
0?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool0061oo`D003=oo`D004Qoo`@0035oo`D000=o
o`@002aoo`D000Aoo`@0041oo`@000Aoo`@002Uoo`D000=oo`@000Aoo`@002Eoo`D000Aoo`@000Ao
o`@00<aoo`00HWoo00<007ooOol0<goo00D007ooOomoo`0004Moo`03001oogoo009oo`03001oogoo
031oo`03001oogoo009oo`03001oogoo009oo`03001oogoo02Uoo`05001oogooOol00003Ool00`00
Oomoo`02Ool00`00Oomoo`0lOol00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol0:7oo00<0
07ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo029oo`05001oogooOol00003
Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol0bGoo001ROol00`00Oomoo`0dOol00`00
Oomoo`1=Ool00`00Oomoo`0`Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol00`00
Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`11Ool01000Oomoo`0017oo00<007ooOol0:7oo00<0
07ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo02=oo`03001oogoo00Aoo`03
001oogoo009oo`04001oogoo0004Ool00`00Oomoo`39Ool0069oo`03001oogoo03Eoo`03001oogoo
04aoo`03001oogoo031oo`03001oogoo009oo`03001oogoo009oo`03001oogoo02]oo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo045oo`04001oogoo0004Ool00`00Oomoo`0XOol00`00Oomo
o`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol097oo00<007ooOol00goo00<007oo
Ool00Woo00@007ooOol000Aoo`03001oogoo0<Uoo`00HWoo00<007ooOol0=Woo00<007ooOol0Agoo
1000<goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0;7oo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol0?Goo10000goo00<007ooOol00Woo00<007ooOol0:7oo00<007ooOol00Woo
00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo02Eoo`03001oogoo009oo`03001oogoo009o
o`04001oogoo0004Ool00`00Oomoo`39Ool0069oo`03001oogoo03Moo`03001oogoo04Ioo`03001o
ogoo03Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo02eoo`05001oogooOol00004Ool0
0`00Oomoo`0mOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0XOol00`00Oomoo`02Ool0
0`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol09Woo00D007ooOomoo`0000Aoo`04001oogoo
0004Ool00`00Oomoo`39Ool0061oo`<003Eoo`05001oogooOol00018Ool00`00Oomoo`0bOol30004
Ool00`00Oomoo`02Ool00`00Oomoo`0YOol01@00Oomoogoo00000goo00<007ooOol00Woo00<007oo
Ool0?Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol09Woo0`0017oo00<007ooOol00Woo
00@007ooOol000Aoo`03001oogoo029oo`05001oogooOol00003Ool00`00Oomoo`02Ool01000Oomo
o`0017oo00<007ooOol0bGoo001ROol00`00Oomoo`0dOol30019Ool5000bOol00`00Oomoo`03Ool4
000]Ool30005Ool40010Ool50003Ool4000[Ool00`00Oomoo`03Ool40004Ool4000VOol30005Ool4
0004Ool4003<Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooc]oo`<00;9o
o`00ogooogoo?Goo00<007ooOol0/7oo003oOoooOol[Ool300000goo00000002Ool300000goo0000
0004Ool00`00Oomoo`02Ool5002YOol00?mooomoobYoo`04001oogooOol20002Ool01000Oomoogoo
0P0017oo00<007oo00000goo00<007ooOol00Woo00<007ooOol0YWoo001GOooo0034000>Ool00`00
Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00<007oo000027oo00<007ooOol0YWoo001G
Ool00`00Oomoo`08Ool00`00Oomoo`0fOol00`00Oomoo`0NOol00`00Oomoo`0EOol00`00Oomoo`0?
Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`06
Ool00`00Oomoo`0fOol00`00Oomoo`0NOol00`00Oomoo`0EOol00`00Oomoo`0?Ool00`00Oomoo`0<
Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0f
Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool01000Oomoogoo1@000goo00D007ooOomoo`0000=oo`@0
0:Uoo`00Egoo00<007ooOol027oo00<007ooOol0=Woo00<007ooOol07Woo00<007ooOol05Goo00<0
07ooOol03goo00<007ooOol037oo00<007ooOol02Woo00<007ooOol027oo00<007ooOol01goo00<0
07ooOol01Woo00<007ooOol0=Woo00<007ooOol07Woo00<007ooOol05Goo00<007ooOol03goo00<0
07ooOol037oo00<007ooOol02Woo00<007ooOol027oo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol0=Woo00<007ooOol03Woo00@007ooOomoo`80009oo`03001oogoo009oo`05001oogooOol0
0003Ool01000Oomoo`0017oo00<007ooOol0YWoo001GOol00`00Oomoo`08Ool00`00Oomoo`0fOol0
0`00Oomoo`18Ool00`00Oomoo`0gOol00`00Oomoo`0fOol00`00Oomoo`18Ool00`00Oomoo`0gOol0
0`00Oomoo`0fOol00`00Oomoo`0?Ool300000goo001oo`02Ool40003Ool3000017oo000000000Woo
1@00Z7oo001GOol00`00Oomoo`3oOooDOol00`00Oomoo`2nOol005Moo`03001oogoo0?moom=oo`80
0<1oo`00Egoo00<007ooOol0ogooogooUWoo001GOol00`00Oomoo`3oOoooOonFOol005Moo`03001o
ogoo0?mooomooiIoo`00Egoo00<007ooOol0ogooogooUWoo001GOol00`00Oomoo`3oOoooOonFOol0
05Moo`03001oogoo0?mooomooiIoo`00Egoo00<007ooOol0ogooogooUWoo001GOol00`00Oomoo`3o
OoooOonFOol005Moo`03001oogoo0?mooomooiIoo`00Egoo00<007ooOol0ogooogooUWoo001GOol0
0`00Oomoo`3oOoooOonFOol005Moo`03001oogoo0?mooomooiIoo`00Egoo00<007ooOol0ogooogoo
UWoo001GOol00`00Oomoo`3oOoooOonFOol005Moo`03001oogoo0?mooomooiIoo`00Egoo00<007oo
Ool0ogooogooUWoo001GOol00`00Oomoo`3oOoooOonFOol005Moo`03001oogoo0?mooomooiIoo`00
Egoo00<007ooOol0ogooogooUWoo001GOol00`00Oomoo`3oOoooOonFOol005Moo`03001oogoo0?mo
oomooiIoo`00Egoo00<007ooOol0ogooogooUWoo001GOol00`00Oomoo`3oOoooOonFOol005Moo`03
001oogoo0?mooomooiIoo`00Egoo00<007ooOol0ogooogooUWoo001GOol3003oOoooOonFOol005Mo
o`03001oogoo0?mooomooiIoo`00Egoo00<007ooOol0ogooogooUWoo001GOol00`00Oomoo`3oOooo
OonFOol005Moo`03001oogoo0?mooomooiIoo`00Egoo0`00ogooogooUWoo001GOol00`00Oomoo`3o
OoooOonFOol005Moo`03001oogoo0?mooomooiIoo`00Egoo0`00ogooogooUWoo001GOol00`00Oomo
o`3oOoooOonFOol005Moo`<00?mooomooiIoo`00Egoo00<007ooOol0ogooogooUWoo001GOol3003o
OoooOonFOol001Ioo`D000Aoo`8000Ioo`05001oogooOol00005Ool50003Ool4000JOol3003oOooo
OonFOol001Qoo`03001oogoo00Aoo`8000Moo`03001oo`0000Qoo`03001oogoo009oo`03001oogoo
009oo`03001oogoo01Moo`<00?mooomooiIoo`0067oo00<007ooOol03Woo00<007ooOol01goo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol05goo0`00ogooogooUWoo000HOol00`00Oomoo`0=
Ool00`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0GOol4003oOoooOonE
Ool001Qoo`03001oogoo00aoo`05001oogooOol00007Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`0GOol00`00Oomoo`3oOoooOonFOol001Qoo`03001oogoo01Qoo`03001oogoo009oo`03
001oogoo009oo`03001oogoo01Moo`03001oogoo0?mooomooiIoo`005Woo0`0067oo0`0017oo00<0
07ooOol00Woo00<007ooOol017oo1@0000=oo`0000002goo00<007ooOol0ogooogooUWoo000HOol0
0`00Oomoo`0HOol00`00Oomoo`03Ool40002Ool40003Ool00`00Oomoo`03Ool00`00Oomoo`08Ool0
0`00Oomoo`3oOoooOonFOol004Ioo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo0?mooomo
oiIoo`00AWoo00<007ooOol00goo00<007ooOol027oo00<007ooOol0ogoom7ooS@0057oo0016Ool0
1`00Oomoogoo001oo`0000Yoo`03001oogoo0?moooAoohd001Aoo`00AGoo0P0017oo00<007ooOol0
2Goo00<007ooOol0ogoom7ooS@0057oo001GOol00`00Oomoo`3oOoodOon=000DOol005Moo`03001o
ogoo0?mooniooi<001Aoo`00Egoo00<007ooOol0ogookWoo00<007ooOol0RWoo1P0057oo001GOol0
0`00Oomoo`3oOoo^Ool00`00Oomoo`2:Ool6000DOol005Moo`03001oogoo0?moonioo`03001oogoo
08Yoo`H001Aoo`00Egoo00<007ooOol0ogookWoo00<007ooOol0RWoo1P0057oo001GOol00`00Oomo
o`3oOoo^Ool00`00Oomoo`2:Ool6000DOol005Moo`03001oogoo0?moonioo`03001oogoo08Yoo`H0
01Aoo`00Egoo00<007ooOol0ogookWoo00<007ooOol0RWoo1P0057oo001GOol00`00Oomoo`3oOoo^
Ool00`00Oomoo`2:Ool6000DOol005Moo`03001oogoo0?moonioo`03001oogoo08Yoo`H001Aoo`00
Egoo00<007ooOol0ogookWoo00<007ooOol0RWoo1P0057oo001GOol00`00Oomoo`3oOoo^Ool00`00
Oomoo`2:Ool6000DOol005Moo`03001oogoo0?moonioo`03001oogoo08Yoo`H001Aoo`00Egoo00<0
07ooOol0ogookWoo00<007ooOol0RWoo1P0057oo001GOol00`00Oomoo`3oOoo^Ool00`00Oomoo`2:
Ool6000DOol005Moo`03001oogoo0?moonioo`03001oogoo08Yoo`H001Aoo`00Egoo00<007ooOol0
ogookWoo00<007ooOol0RWoo1P0057oo001GOol00`00Oomoo`3oOoo^Ool00`00Oomoo`2:Ool6000D
Ool005Moo`03001oogoo0?moonioo`03001oogoo08Yoo`H001Aoo`00Egoo00<007ooOol0ogookWoo
00<007ooOol0RWoo1P0057oo001GOol00`00Oomoo`3oOoo^Ool00`00Oomoo`2:Ool6000DOol005Mo
o`03001oogoo0?moonioo`03001oogoo08Yoo`H001Aoo`00Egoo00<007ooOol0ogookWoo00<007oo
Ool0EWoo1000<7oo1P0057oo001GOol00`00Oomoo`3oOoo^Ool00`00Oomoo`1JOol00`00Oomoo`0]
Ool6000DOol005Moo`03001oogoo0?moonioo`03001oogoo03eoo`H000Aoo`800004Ool00000Ool3
000017oo000000000Woo0`0000Aoo`00Oomoo`D002Qoo`H001Aoo`00Egoo0`00ogookWoo00<007oo
Ool0?Woo00D007ooOomoo`0000=oo`03001oogoo008000=oo`05001oogooOol00002Ool01000Oomo
ogoo0P000Woo00<007ooOol00Woo00<007ooOol09Goo1P0057oo001GOol00`00Oomoo`3oOoo^Ool0
0`00Oomoo`0:Ool6O004Ool6O004Ool6O004Ool6O00@Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`0UOol6
000DOol005Moo`03001oogoo0?moonioo`03001oogoo03ioo`03001oogoo00Eoo`05001oogooOol0
0003Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00@007ooOomoo`@002Qoo`H001Aoo`00Egoo
00<007ooOol0ogookWoo00<007ooOol0?Woo00<007ooOol01Goo00D007ooOomoo`0000=oo`80009o
o`04001oogoo0003Ool20002Ool00`00Oomoo`02Ool00`00Oomoo`0UOol6000DOol005Moo`03001o
ogoo0?moonioo`03001oogoo03ioo`03001oogoo00Aoo`80009oo`80009oo`800003Ool0000000Ao
o`<00003Ool00000009oo`D002Moo`H001Aoo`00Egoo0`00ogookWoo00<007ooOol0?Woo00<007oo
Ool0BGoo1P0057oo001GOol00`00Oomoo`3oOoo^Ool00`00Oomoo`0mOol3001:Ool6000DOol005Mo
o`03001oogoo0?moonioo`03001oogoo08Yoo`H001Aoo`00Egoo0`00ogookWoo00<007ooOol0RWoo
1P0057oo001GOol00`00Oomoo`3oOoo^Ool00`00Oomoo`2:Ool6000DOol005Moo`<00?moonioo`03
001oogoo08Yoo`H001Aoo`00Egoo0`00ogookWoo00<007ooOol0RWoo1P0057oo001GOol00`00Oomo
o`3oOoo^Ool00`00Oomoo`2:Ool6000DOol001Ioo`D000Aoo`8000Ioo`05001oogooOol00005Ool5
0003Ool4000JOol3003oOoo^Ool00`00Oomoo`2:Ool6000DOol001Qoo`03001oogoo00Aoo`8000Mo
o`03001oo`0000Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo01Moo`<00?moonioo`03
001oogoo08Yoo`H001Aoo`0067oo00<007ooOol03Woo00<007ooOol01goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol05goo0`00ogookWoo00<007ooOol0RWoo1P0057oo000HOol00`00Oomo
o`0=Ool00`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0GOol4003oOoo]
Ool00`00Oomoo`2:Ool6000DOol001Qoo`03001oogoo00aoo`05001oogooOol00007Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`0GOol00`00Oomoo`3oOoo^Ool00`00Oomoo`2:Ool6000D
Ool001Qoo`03001oogoo01Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`D0009o
o`03001oogoo00Uoo`03001oogoo0?moonioo`03001oogoo08Yoo`H001Aoo`005Woo0`0067oo0`00
17oo00<007ooOol00Woo00<007oo00000`000goo00L007ooOomoo`00Ool0000:Ool00`00Oomoo`3o
Ooo^Ool00`00Oomoo`2:Ool6000DOol001Qoo`03001oogoo01Qoo`03001oogoo00=oo`@000Uoo`07
001oogooOol007oo00002Woo00<007ooOol0ogookWoo00<007ooOol0RWoo1P0057oo0016Ool01`00
Oomoogoo001oo`0000Yoo`03001oogoo0?mook9oo`807cYoo`03001oogoo08Yoo`H001Aoo`00AWoo
00L007ooOomoo`00Ool0000:Ool00`00Oomoo`3oOonbOol201ljOol00`00Oomoo`2:Ool6000DOol0
04Eoo`8000Aoo`03001oogoo00Uoo`03001oogoo0?mook9oo`807cYoo`03001oogoo08Yoo`H001Ao
o`00Egoo00<007ooOol0ogookWoo00<007ooOol0RWoo1P0057oo001GOol00`00Oomoo`3oOoo^Ool0
0`00Oomoo`2:Ool6000DOol005Moo`03001oogoo0?mookEoo`030n1oogoo03Ioo`03001oogoo08Yo
o`H001Aoo`00Egoo00<007ooOol0ogoo]7oo00<3h7ooOol0=goo00<007ooOol0RWoo1P0057oo001G
Ool00`00Oomoo`3oOondOol00`?POomoo`0gOol00`00Oomoo`2:Ool6000DOol005Moo`03001oogoo
0?moojeoo`0301moogoo00=oo`030n1oogoo03Qoo`03001oogoo08Yoo`H001Aoo`00Egoo00<007oo
Ool0ogoo[7oo0`0O17oo00<3h7ooOol0>7oo00<007ooOol0RWoo1P0057oo001GOol00`00Oomoo`3o
Oon[Ool301l4Ool00`?POomoo`0iOol00`00Oomoo`2:Ool6000DOol005Moo`03001oogoo0?moojao
o`0301moogoo009oo`030n1oogoo03Yoo`03001oogoo08Yoo`H001Aoo`00Egoo00<007ooOol0ogoo
/7oo00<3h7ooOol0>goo00<007ooOol0RWoo1P0057oo001GOol00`00Oomoo`3oOon`Ool00`?POomo
o`0kOol00`00Oomoo`2:Ool6000DOol005Moo`03001oogoo0?moojmoo`030n1oogoo03aoo`03001o
ogoo08Yoo`H001Aoo`00Egoo00<007ooOol0ogooZ7oo00<07gooOol00goo00<3h7ooOol0?Goo00<0
07ooOol0?Goo1P000Woo0P000Woo0P000goo10000goo1@0017oo1@0017oo0`0017oo1@000goo1000
0goo0`0000Aoo`00000000Ioo`H001Aoo`00Egoo00<007ooOol0ogooYgoo0`0O0goo00<3h7ooOol0
?Woo00<007ooOol0?Woo00D007ooOomoo`0000=oo`04001oogoo0003Ool00`00Oomoo`02Ool01@00
Oomoogoo00001Woo00<007ooOol01Woo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo
009oo`05001oogooOol00003Ool00`00Oomoo`05Ool6000DOol005Moo`03001oogoo0?moojIoo`<0
7`=oo`030n1oogoo03moo`03001oogoo03ioo`03001oogoo00Ioo`8000Aoo`03001oogoo00Ioo`03
001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`05
001oogooOol00003Ool00`00Oomoo`05Ool6000DOol005Moo`03001oogoo0?moojMoo`0301moogoo
009oo`030n1oogoo03moo`03001oogoo03ioo`03001oo`0000Ioo`8000Aoo`03001oogoo00Ioo`03
001oogoo00Aoo`H000=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`05001oogoo
Ool00003Ool00`00Oomoo`05Ool6000DOol005Moo`03001oogoo0?mooj]oo`030n1oogoo041oo`03
001oogoo03ioo`<000Eoo`04001oogoo0003Ool01000Oomoogoo0P000goo0P001Goo00<007ooOol0
0Woo00D007ooOomoo`0000Uoo`03001oogoo009oo`03001oogoo009oo`04001oogooOol20002Ool0
0`00Oomoo`05Ool6000DOol005Moo`03001oogoo0?moojYoo`030n1oogoo045oo`03001oogoo03io
o`03001oo`0000Aoo`80009oo`8000=oo`<00004Ool007ooOol2000017oo000000000goo10000goo
1@0017oo0`001Goo10000goo0P0000=oo`00000027oo1P0057oo001GOol00`00Oomoo`3oOonYOol0
0`?POomoo`12Ool00`00Oomoo`0nOol01@00Oomoogoo00008goo00<007ooOol08Goo1P0057oo001G
Ool00`00Oomoo`3oOonYOol00`?POomoo`12Ool00`00Oomoo`0mOol6000]Ool00`00Oomoo`0GOol6
000DOol005Moo`03001oogoo0?moojQoo`030n1oogoo04=oo`03001oogoo08Yoo`H001Aoo`00Egoo
00<007ooOol0ogooZ7oo00<3h7ooOol0@goo00<007ooOol0RWoo1P0057oo001GOol00`00Oomoo`3o
OonOOol301l5Ool00`?POomoo`14Ool00`00Oomoo`0:OolV0n1JOol6000DOol005Moo`03001oogoo
0?mooimoo`<07`Aoo`030n1oogoo04Eoo`03001oogoo08Yoo`H001Aoo`00Egoo00<007ooOol0ogoo
YGoo00<3h7ooOol0AWoo00<007ooOol0RWoo1P0057oo001GOol00`00Oomoo`3oOonTOol00`?POomo
o`17Ool00`00Oomoo`2:Ool6000DOol005Moo`<00?mooj=oo`030n1oogoo04Qoo`03001oogoo08Yo
o`H001Aoo`00Egoo00<007ooOol0ogooXWoo00<3h7ooOol0BGoo00<007ooOol0RWoo1P0057oo001G
Ool00`00Oomoo`3oOonQOol00`?POomoo`1:Ool00`00Oomoo`0oOol30003Ool50004Ool50002Ool3
000017oo000000000Woo1@009goo1P0057oo001GOol00`00Oomoo`3oOonIOol00`0OOomoo`04Ool0
0`?POomoo`1;Ool00`00Oomoo`0nOol01@00Oomoogoo00000goo00<007ooOol01goo00<007ooOol0
0goo00D007ooOomoo`00009oo`03001oogoo02Yoo`H001Aoo`00Egoo00<007ooOol0ogooUgoo100O
1Goo00<3h7ooOol0Bgoo00<007ooOol0?Woo00D007ooOomoo`0000=oo`03001oogoo00Moo`03001o
ogoo00=oo`05001oogooOol00002Ool00`00Oomoo`0ZOol6000DOol005Moo`<00?mooiMoo`<07`Eo
o`030n1oogoo04aoo`03001oogoo03ioo`05001oogooOol00003Ool00`00Oomoo`07Ool00`00Oomo
o`03Ool01@00Oomoogoo00000Woo1P009goo1P0057oo001GOol00`00Oomoo`3oOonHOol00`0OOomo
o`03Ool00`?POomoo`1=Ool00`00Oomoo`0nOol01@00Oomoogoo00000goo0P0027oo00<007ooOol0
0goo0P000Woo00@007ooOol000Aoo`03001oogoo02Eoo`H001Aoo`00Egoo00<007ooOol0ogooWGoo
00<3h7ooOol0CWoo00<007ooOol0?Woo00D007ooOomoo`00009oo`800004Ool000000003Ool30004
Ool200000goo00000004Ool4000XOol6000DOol005Moo`<00?mooiaoo`030n1oogoo04moo`03001o
ogoo03ioo`05001oogooOol00017Ool6000DOol005Moo`03001oogoo0?mooi]oo`030n1oogoo051o
o`03001oogoo03eoo`<00004Ool00000000<Ool00`00Oomoo`0gOol6000DOol005Moo`03001oogoo
0?mooiYoo`030n1oogoo055oo`03001oogoo08Yoo`H001Aoo`00Egoo0`00ogooTGoo00<07gooOol0
1Goo00<3h7ooOol0DWoo00<007ooOol0RWoo1P0057oo001GOol3003oOon@Ool301l5Ool00`?POomo
o`1COol00`00Oomoo`2:Ool6000DOol005Moo`03001oogoo0?moohmoo`<07`Eoo`030n1oogoo05Ao
o`03001oogoo08Yoo`H001Aoo`0077oo1@0017oo0P001Goo00D007ooOomoo`0000Ioo`D000=oo`@0
01Aoo`<00?mooi1oo`0301moogoo00=oo`030n1oogoo05Eoo`03001oogoo08Yoo`H001Aoo`007Woo
00<007ooOol017oo0P001Woo00<007oo00002Goo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool04Goo0`00ogooUGoo00<3h7ooOol0EWoo00<007ooOol0RWoo1P0057oo000NOol00`00Oomoo`0=
Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0AOol4003oOonCOol0
0`?POomoo`1GOol00`00Oomoo`2:Ool6000DOol001ioo`03001oogoo00aoo`03001oo`0000Uoo`03
001oogoo009oo`03001oogoo009oo`03001oogoo015oo`03001oogoo0?mooi=oo`030n1oogoo05Qo
o`03001oogoo08Yoo`H001Aoo`007Woo00<007ooOol02goo00D007ooOomoo`0000Qoo`03001oogoo
009oo`03001oogoo009oo`03001oogoo015oo`03001oogoo0?mooi9oo`030n1oogoo05Uoo`03001o
ogoo08Yoo`H001Aoo`007Woo00<007ooOol067oo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool01Goo00<007ooOol02Goo00<007ooOol0ogooTGoo00<3h7ooOol0FWoo00<007ooOol0RWoo1P00
57oo000LOol3000HOol30004Ool00`00Oomoo`02Ool00`00Ool000030002Ool00`00Oomoo`09Ool0
0`00Oomoo`3oOon7Ool301l7Ool00`?POomoo`1JOol00`00Oomoo`2:Ool6000DOol001ioo`03001o
ogoo01Qoo`03001oogoo00=oo`@000Qoo`03001oogoo00Uoo`03001oogoo0?moohMoo`<07`Ioo`03
0n1oogoo05]oo`03001oogoo08Yoo`H001Aoo`00C7oo00<007ooOol027oo00<007ooOol0ogooSgoo
00<3h7ooOol0G7oo00<007ooOol0RWoo1P0057oo001:Ool00`00Ool0000:Ool00`00Oomoo`3oOon>
Ool00`?POomoo`1MOol00`00Oomoo`2:Ool6000DOol004Yoo`<000Yoo`03001oogoo0?mooheoo`03
0n1oogoo05ioo`03001oogoo08Yoo`H001Aoo`00Egoo00<007ooOol0ogooRgoo0P?PHGoo00<007oo
Ool0RWoo1P0057oo001GOol00`00Oomoo`3oOon:Ool00`?POomoo`1QOol00`00Oomoo`2:Ool6000D
Ool005Moo`03001oogoo0?moogioo`<07`Qoo`030n1oogoo069oo`03001oogoo08Yoo`H001Aoo`00
Egoo00<007ooOol0ogooOWoo0`0O1goo00<3h7ooOol0Hgoo00<007ooOol0RWoo1P0057oo001GOol0
0`00Oomoo`3oOon7Ool00`?POomoo`1TOol00`00Oomoo`2:Ool6000DOol005Moo`03001oogoo0?mo
ohEoo`83h6Moo`03001oogoo08Yoo`H001Aoo`00Egoo00<007ooOol0ogooQ7oo00<3h7ooOol0Igoo
00<007ooOol0?Goo1P000Woo0P000Woo0P000goo10000goo1@0017oo1@0017oo0`0017oo1@000goo
10000goo0`0000Aoo`00000000Ioo`H001Aoo`00Egoo00<007ooOol0ogooMgoo00<07gooOol02Goo
00<3h7ooOol0J7oo00<007ooOol0?Woo00D007ooOomoo`0000=oo`04001oogoo0003Ool00`00Oomo
o`02Ool01@00Oomoogoo00001Woo00<007ooOol01Woo00D007ooOomoo`0000Eoo`03001oogoo009o
o`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`05Ool6000DOol005Moo`03001oogoo
0?moogIoo`<07`Uoo`030n1oogoo06Uoo`03001oogoo03ioo`03001oogoo00Ioo`8000Aoo`03001o
ogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo009oo`03001o
ogoo009oo`05001oogooOol00003Ool00`00Oomoo`05Ool6000DOol005Moo`03001oogoo0?moogEo
o`<07`Uoo`030n1oogoo06Yoo`03001oogoo03ioo`03001oo`0000Ioo`8000Aoo`03001oogoo00Io
o`03001oogoo00Aoo`H000=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`05001o
ogooOol00003Ool00`00Oomoo`05Ool6000DOol005Moo`03001oogoo0?moogIoo`0301moogoo00Io
o`83h6eoo`03001oogoo03ioo`<000Eoo`04001oogoo0003Ool01000Oomoogoo0P000goo0P001Goo
00<007ooOol00Woo00D007ooOomoo`0000Uoo`03001oogoo009oo`03001oogoo009oo`04001oogoo
Ool20002Ool00`00Oomoo`05Ool6000DOol005Moo`03001oogoo0?moogioo`030n1oogoo06eoo`03
001oogoo03ioo`03001oo`0000Aoo`80009oo`8000=oo`<00004Ool007ooOol2000017oo00000000
0goo10000goo1@0017oo0`001Goo10000goo0P0000=oo`00000027oo1P0057oo001GOol00`00Oomo
o`3oOommOol00`?POomoo`1^Ool00`00Oomoo`0nOol01@00Oomoogoo00008goo00<007ooOol08Goo
1P0057oo001GOol00`00Oomoo`3oOomkOol20n1aOol00`00Oomoo`0mOol6000]Ool00`00Oomoo`0G
Ool6000DOol005Moo`03001oogoo0?moogYoo`030n1oogoo075oo`03001oogoo08Yoo`H001Aoo`00
Egoo00<007ooOol0ogooJgoo100O2Woo00<3h7ooOol0LWoo00<007ooOol0RWoo1P0057oo001GOol0
0`00Oomoo`3oOom[Ool401l8Ool20n1eOol00`00Oomoo`09Ool301l8Ool301l8Ool401l8Ool301mL
Ool6000DOol005Moo`03001oogoo0?moogIoo`030n1oogoo07Eoo`03001oogoo00Uoo`<07`Qoo`<0
7`Qoo`@07`Qoo`<07eaoo`H001Aoo`00Egoo00<007ooOol0ogooM7oo0P?PN7oo00<007ooOol0RWoo
1P0057oo001GOol00`00Oomoo`3oOomTOol00`0OOomoo`0<Ool00`?POomoo`1hOol00`00Oomoo`2:
Ool6000DOol005Moo`03001oogoo0?moof=oo`<07`]oo`83h7]oo`03001oogoo08Yoo`H001Aoo`00
Egoo00<007ooOol0ogooHWoo0`0O2Woo0P?POGoo00<007ooOol0RWoo1P0057oo001GOol00`00Oomo
o`3oOomSOol00`0OOomoo`08Ool00`?POomoo`1mOol00`00Oomoo`0mOol30006Ool300000goo0000
0002Ool50003Ool40004Ool300000goo00000002Ool5000OOol6000DOol005Moo`03001oogoo0?mo
ofaoo`83h81oo`03001oogoo03ioo`03001oogoo00Aoo`04001oogooOol20002Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool01000Oomoo`000goo0P001Goo00<007ooOol07goo1P0057oo001GOol00`00
Oomoo`3oOomJOol00`0OOomoo`0=Ool20n22Ool00`00Oomoo`0nOol00`00Oomoo`04Ool00`00Oomo
o`02Ool01000Oomoo`001goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool07goo1P0057oo001GOol00`00Oomoo`3oOomIOol301l<Ool20n24Ool00`00Oomoo`0nOol00`00
Ool00005Ool50002Ool60002Ool00`00Oomoo`06Ool50005Ool00`00Oomoo`0OOol6000DOol005Mo
o`<00?mooeQoo`<07`]oo`83h8Ioo`03001oogoo03ioo`<000Aoo`03001oogoo009oo`04001oogoo
0004Ool01000Oomoo`000goo0P000Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol07goo
1P0057oo001GOol00`00Oomoo`3oOomIOol00`0OOomoo`09Ool00`?POomoo`26Ool00`00Oomoo`0n
Ool00`00Ool00005Ool40004Ool40004Ool300000goo001oo`02Ool40006Ool00`00Oomoo`0OOol6
000DOol005Moo`03001oogoo0?moof=oo`83h8Uoo`03001oogoo03ioo`05001oogooOol0000UOol0
0`00Oomoo`0OOol6000DOol005Moo`03001oogoo0?moof5oo`83h8]oo`03001oogoo03eoo`H002Ao
o`80025oo`H001Aoo`00Egoo00<007ooOol0ogooCWoo0`0O3Woo0P?PSGoo00<007ooOol0RWoo1P00
57oo001GOol3003oOom>Ool301l<Ool20n2?Ool00`00Oomoo`2:Ool6000DOol005Moo`03001oogoo
0?mooe]oo`83h95oo`03001oogoo08Yoo`H001Aoo`00Egoo00<007ooOol0ogooAGoo00<07gooOol0
4Goo0P?PTgoo00<007ooOol0RWoo1P0057oo001GOol3003oOom4Ool301l@Ool20n2EOol00`00Oomo
o`2:Ool6000DOol005Moo`03001oogoo0?mood=oo`<07`moo`83h9Moo`03001oogoo08Yoo`H001Ao
o`00Egoo0`00ogooA7oo00<07gooOol037oo0P?PVGoo00<007ooOol0RWoo1P0057oo001GOol00`00
Oomoo`3oOom@Ool30n2KOol00`00Oomoo`2:Ool00`00Oomoo`0GOol005Moo`<001Ioo`0301moogoo
0?moob1oo`<07a9oo`83h9ioo`03001oogoo08Yoo`03001oogoo01Moo`00Egoo0`002Woo0`0O27oo
0`0Oogoo8Goo0`0O47oo0P?PX7oo00<007ooOol0RWoo00<007ooOol05goo000TOol40005Ool20005
Ool40004Ool40004Ool40004Ool50006Ool3000:Ool301l9Ool301l7Ool301ooOolVOol30n2ROol0
0`00Oomoo`2:Ool00`00Oomoo`0GOol002=oo`03001oogoo009oo`03001oogoo009oo`8000Aoo`03
001oogoo009oo`04001oogoo0004Ool01000Oomoo`0017oo00<007ooOol00goo00<007ooOol01Woo
0`005goo00<07gooOol01Woo0`0O27oo100OoWoo0`0O5Woo0P?PYGoo00<007ooOol0RWoo00<007oo
Ool05goo000SOol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool01000Oomoo`0017oo
00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo00Ioo`@002Yoo`@07`Qoo`<07nYoo`0301mo
ogoo00Ioo`<07a=oo`<3h:Moohh001Uoo`008goo00<007ooOol00Woo00<007ooOol027oo00<007oo
Ool00Woo00@007ooOol000Aoo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00
Oomoo`0gOol301l8Ool301oNOol301lJOol30n3oOomBOol002=oo`03001oogoo009oo`03001oogoo
00Qoo`03001oogoo009oo`04001oogoo0004Ool01000Oomoo`0017oo00<007ooOol00goo00<007oo
Ool01Woo00<007ooOol0@Woo0`0O27oo0`0ObGoo00<07gooOol01Goo100O67oo0`?PogooEGoo000S
Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool01000Oomoo`0017oo00@007ooOol0
00Aoo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo04eoo`<07`Qoo`<07keoo`<07`Ioo`<0
7aIoo`<3h?mooeQoo`008goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00@007oo
Ool000Aoo`04001oogoo0004Ool01000Oomoogoo0`0027oo00<007ooOol0F7oo0`0O27oo100OYgoo
00<07gooOol01Woo0`0O7Goo0`?PogooFgoo000TOol4000<Ool40004Ool40004Ool40006Ool00`00
Oomoo`06Ool00`00Oomoo`1SOol401l8Ool301nJOol401l8Ool00`0OOomoo`0HOol40n3oOomNOol0
05Moo`03001oogoo06moo`<07`Qoo`<07hmoo`<07b1oo`@3h?moof9oo`00Egoo00<007ooOol0NWoo
0`0O27oo0`0ONGoo0`0O2Goo00<07gooOol06goo10?PogooIWoo001GOol00`00Oomoo`25Ool301l8
Ool301lEOol00`0OOomoo`1:Ool401l8Ool301lSOol40n3oOomZOol005Moo`03001oogoo091oo`<0
7`Qoo`@07`Qoo`<07d1oo`<07`Qoo`@07bUoo`D3h?moofioo`00Egoo00<007ooOol0Vgoo100O2Goo
0`0O1goo0`0O27oo0`0O1goo1@0O1goo100O27oo0`0O27oo0`0O;goo1P?PogooLgoo001GOol00`00
Oomoo`2YOol00`0OOomoo`06Ool301l8Ool301l7Ool501l7Ool401l8Ool301ldOol60n3oOomiOol0
05Moo`03001oogoo0?mooa5oo`H3h?moogmoo`00Egoo00<007ooOol0ogoo2goo1P?PogooQGoo001G
Ool00`00Oomoo`3oOol3Ool80n3oOon;Ool005Moo`03001oogoo0?]oo`L3h?mooi=oo`00Egoo00<0
07ooOol0lgoo20?PogooVWoo001GOol00`00Oomoo`27Ool;0n1?OolB0n3oOonROol005Moo`03001o
ogoo07moo`P3h0]oodl3h?mookAoo`00Egoo00<007ooOol0Ngoo10?Pogooogoo5goo001GOol00`00
Oomoo`1iOol20n3oOoooOolKOol005Moo`03001oogoo07Moo`83h?mooomooaeoo`00Egoo00<007oo
Ool0MGoo0P?Pogooogoo7goo001GOol00`00Oomoo`1cOol20n3oOoooOolQOol005Moo`03001oogoo
075oo`83h?mooomoob=oo`00Egoo00<007ooOol0Kgoo0P?Pogooogoo9Goo001GOol00`00Oomoo`1]
Ool20n3oOoooOolWOol005Moo`03001oogoo06]oo`83h?mooomoobUoo`00Egoo00<007ooOol0JWoo
00<3h7ooOol0ogooogoo:Goo001GOol00`00Oomoo`1XOol20n3oOoooOol/Ool005Moo`03001oogoo
06Moo`030n1oogoo0?mooomoobaoo`00Egoo00<007ooOol0IGoo0P?Pogooogoo;goo001GOol00`00
Oomoo`1TOol00`?POomoo`3oOoooOol_Ool005Moo`03001oogoo06=oo`030n1oogoo0?mooomooc1o
o`00Egoo00<007ooOol0HGoo0P?Pogooogoo<goo001GOol3001POol00`?POomoo`3oOoooOolcOol0
05Moo`03001oogoo05ioo`83h?mooomoocIoo`00Egoo00<007ooOol0GGoo00<3h7ooOol0ogooogoo
=Woo001GOol00`00Oomoo`1LOol00`?POomoo`3oOoooOolgOol005Moo`03001oogoo05Yoo`83h?mo
oomoocYoo`00Egoo0`00F7oo0P?Pogooogoo?7oo001GOol00`00Oomoo`1FOol20n3oOoooOolnOol0
05Moo`03001oogoo05=oo`<3h?mooomood1oo`00Egoo0`00DGoo0P?Pogooogoo@goo001GOol00`00
Oomoo`1>Ool30n3oOoooOom5Ool005Moo`<004aoo`83h?mooomoodQoo`00Egoo00<007ooOol0BWoo
0P?PogooogooBWoo001GOol30017Ool30n3oOoooOom<Ool005Moo`<004Eoo`83h?mooomoodmoo`00
>Woo10001Goo0P001Goo1@0027oo0`00@Woo0`?PogooogooDGoo000iOol00`00Oomoo`02Ool00`00
Oomoo`02Ool20007Ool00`00Oomoo`08Ool30010Ool20n3oOoooOomDOol003Uoo`03001oogoo009o
o`03001oogoo00]oo`03001oogoo00Qoo`@003aoo`<3h?mooomooeIoo`00>Goo00<007ooOol00Woo
00<007ooOol02goo00<007ooOol027oo00<007ooOol0>goo0P?PogooogooFGoo000iOol00`00Oomo
o`02Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`0hOol30n3oOoooOomKOol003Uoo`03
001oogoo009oo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo03Ioo`83h?mooomooeioo`00
>Goo00<007ooOol00Woo00<007ooOol02Goo0`002Woo00<007ooOol0<goo0`?PogooogooH7oo000j
Ool4000>Ool00`00Oomoo`08Ool00`00Oomoo`0aOol20n3oOoooOomSOol005Moo`03001oogoo02mo
o`83h?mooomoofEoo`00Egoo00<007ooOol0;7oo0`?PogooogooIgoo001GOol00`00Oomoo`0ZOol2
0n3oOoooOomZOol005Moo`03001oogoo02Moo`<3h?mooomoofaoo`00Egoo00<007ooOol09Goo0P?P
ogooogooKgoo001GOol00`00Oomoo`0ROol30n3oOoooOomaOol005Moo`03001oogoo021oo`83h?mo
oomoogAoo`00Egoo00<007ooOol07Goo0`?PogooogooMWoo001GOol00`00Oomoo`0KOol20n3oOooo
OomiOol005Moo`03001oogoo01Qoo`<3h?mooomoog]oo`00Egoo00<007ooOol05Woo0P?Pogooogoo
OWoo001GOol00`00Oomoo`0DOol20n3oOoooOon0Ool005Moo`03001oogoo015oo`<3h?mooomooh9o
o`00Egoo00<007ooOol03goo0P?PogooogooQGoo001GOol00`00Oomoo`0<Ool30n3oOoooOon7Ool0
05Moo`03001oogoo00Yoo`83h?mooomoohYoo`00Egoo00<007ooOol027oo0P?PogooogooS7oo001G
Ool00`00Oomoo`3oOoooOonFOol005Moo`03001oogoo0?mooomooiIoo`00Egoo00<007ooOol0ogoo
ogooUWoo001GOol00`00Oomoo`3oOoooOonFOol005Moo`03001oogoo0?mooomooiIoo`00Egoo00<0
07ooOol0ogooogooUWoo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool0
0?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOolZ
Ool3003oOoo3Ool00?moob]oo`03001oogoo0?mool9oo`00ogoo0Woo0`0000Aoo`00000000=oo`80
0003Ool00000009oo`D000Aoo`<000Aoo`D000=oo`@000Aoo`D000=oo`D000Ioo`D0009oo`<00004
Ool000000003Ool30004Ool3000017oo000007oo0P000Woo0`000Woo1@00ogooOGoo003oOol3Ool0
1@00Oomoogoo00000goo00<007ooOol00P001Goo00<007ooOol00goo00D007ooOomoo`0000Eoo`03
001oogoo00=oo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`03
Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`04001oogooOol20003Ool01000Oomoo`00
0goo00<007ooOol0ogooP7oo003oOol3Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Eoo`03
001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`05001oogooOol00005Ool00`00Oomoo`02
Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00<007ooOol017oo00<007oo
Ool00Woo00L007ooOomoo`00Ool00004Ool00`00Oomoo`3oOon0Ool005aoo`<00:=oo`05001oo`00
Ool00003Ool01@00Oomoogoo00001Goo00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo
00D007ooOomoo`0000Eoo`03001oogoo009oo`H000Qoo`03001oogoo00=oo`05001oogooOol00003
Ool00`00Oomoo`05Ool50003Ool30004Ool6003oOommOol005eoo`03001oogoo0:9oo`05001oo`00
Ool00003Ool01@00Oomoogoo00001Goo00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo
0P000Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Woo00<007oo
Ool00goo0P000Woo00D007ooOomoo`0000Ioo`03001oogoo009oo`05001oogooOol00002Ool01@00
Oomoogoo000017oo00<007ooOol0ogooNgoo001@Ool50004Ool300000goo001oo`2SOol200000goo
00000002Ool20002Ool20005Ool00`00Oomoo`02Ool50004Ool30004Ool200000goo00000006Ool0
0`00Oomoo`03Ool40007Ool30004Ool200000goo00000003Ool50004Ool40004Ool00`00Ool00003
0002Ool4003oOomnOol0055oo`05001oogooOol00002Ool01000Oomoogoo0P00Y7oo0P0000=oo`00
00003Goo00<007ooOol00goo00<007ooOol05goo00<007ooOol07Woo00<007ooOol03Goo00<007oo
Ool0ogooQgoo001AOol01@00Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol0XGoo0`0000Ao
o`00000000]oo`8000moo`03001oogoo00aoo`80019oo`03001oogoo01Yoo`800?moohUoo`00DGoo
00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo0?mooomooi1oo`00DGoo10000goo00@0
07ooOomoo`800?mooomooi9oo`00DGoo00D007ooOomoo`0000=oo`<00003Ool000000?mooomooi5o
o`00DGoo00D007ooOomoo`000?mooomooiYoo`00D7oo1@00ogooogooVgoo003oOoooOoo`Ool00?mo
oomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`
Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003o
OoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogoo
l7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00
\
\>"],
  ImageRangeCache->{{{0, 749}, {366.813, 0}} -> {-1.06507, -0.648943, \
0.00442282, 0.00442282}, {{18.375, 583.625}, {358.063, 8.6875}} -> \
{-0.516095, -18.2339, 0.00657772, 0.0739857}, {{583.625, 724.938}, {268.188, \
126.875}} -> {-14.9683, -3.1709, 0.0318446, 0.0389212}, {{595.375, 634.625}, \
{258.5, 226.438}} -> {-15.9524, -10.7645, 0.0334398, 0.108214}, {{595.375, \
634.625}, {213.563, 181.438}} -> {-15.9524, -14.6575, 0.0334398, 0.108214}, \
{{595.375, 634.625}, {168.625, 136.5}} -> {-15.9524, -18.5478, 0.0334398, \
0.108214}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[61]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Inhalation\",ShowReport\[Rule] \"CompartmentContent\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Inhalation\>", \ "\<Acute\>", "\<CompartmentContent\>", 
      1, \ amad, class, \ fn1, 180, lambda]\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \({q\_ET1[180] \[Rule] 3.833831653217919`*^-86, 
      q\_AI[180] \[Rule] 
        2.7247110407050328158213844709603027`15.954589770191241*^-7826, 
      q\_bb1[180] \[Rule] 
        1.5184544554933862481359260219023`15.95458977019007*^-7829, 
      q\_bb2[180] \[Rule] 
        1.6704411587312679656836509634037`15.954589770191005*^-7829, 
      q\_bbseq[180] \[Rule] 
        1.07671953486003472333605256234`15.954589770191005*^-7829, 
      q\_BB1[180] \[Rule] 
        3.088887594177123999944537460205`15.95458977019067*^-7830, 
      q\_BB2[180] \[Rule] 
        2.2560862456313499051225915425943`15.954589770191005*^-7829, 
      q\_BBseq[180] \[Rule] 
        1.7331926008027386939899292996532`15.954589770191005*^-7829, 
      q\_LNth[180] \[Rule] 
        1.57871262291168613412437362813023`14.92814434937435*^-7828, 
      q\_ET2[180] \[Rule] 
        3.1567770717968215369428821233`15.954589770191586*^-7831, 
      q\_ETseq[180] \[Rule] 
        1.40543858635208290802750001070537`15.954589770191005*^-7828, 
      q\_LNet[180] \[Rule] 
        2.7717689203049202983048576794091`14.907661895699661*^-7829, 
      qLungs[180] \[Rule] 0.`, 
      qST[180] \[Rule] 
        2.69961687716894230223760545130714`15.954589770190966*^-1884, 
      qSI[180] \[Rule] 0, qB[180] \[Rule] 2.1001965691640315`*^-11, 
      q\_2[180] \[Rule] 7.46449467684897`*^-9, 
      q\_3[180] \[Rule] 1.2572453580251381`*^-9, 
      q\_4[180] \[Rule] 3.3985291151225175`*^-12, 
      qURI[180] \[Rule] 6.821987851891581`*^-8, 
      qULI[180] \[Rule] 8.097470635562062`*^-12, 
      qLLI[180] \[Rule] 1.4668152731785196`*^-11, 
      qFEC[180] \[Rule] 4.080595830917626`*^-9}\)], "Output",
  CellLabel->"Out[62]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Inhalation\>", \ "\<Constant\>", "\<CompartmentContent\>", 
      1, \ amad, class, \ fn1, 180, lambda]\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \({q\_ET1[180] \[Rule] 0.31169342284452944`, 
      q\_AI[180] \[Rule] 0.0005313944500743153`, 
      q\_bb1[180] \[Rule] 0.00006438169010523872`, 
      q\_bb2[180] \[Rule] 0.00004378892311232248`, 
      q\_bbseq[180] \[Rule] 7.713692225754938`*^-7, 
      q\_BB1[180] \[Rule] 0.00010755246578955283`, 
      q\_BB2[180] \[Rule] 0.00005914101590968554`, 
      q\_BBseq[180] \[Rule] 1.24167100695224`*^-6, 
      q\_LNth[180] \[Rule] 2.1174913459582982`*^-10, 
      q\_ET2[180] \[Rule] 0.0019980236666473465`, 
      q\_ETseq[180] \[Rule] 1.9927534831419603`*^-6, 
      q\_LNet[180] \[Rule] \
\(-2.76950974375598465431156274364`14.907685871806317*^-7831\), 
      qLungs[180] \[Rule] 0.0008082717969697772`, 
      qST[180] \[Rule] 0.00829515193822697`, qSI[180] \[Rule] 0, 
      qB[180] \[Rule] 0.16927920559958712`, 
      q\_2[180] \[Rule] 1.4773457160036756`, 
      q\_3[180] \[Rule] 0.08864073425386684`, 
      q\_4[180] \[Rule] 0.02718199922331132`, 
      qURI[180] \[Rule] 3.7646714188044452`, 
      qULI[180] \[Rule] 0.0005427723703675046`, 
      qLLI[180] \[Rule] 0.0008990900366381772`, 
      qFEC[180] \[Rule] 0.010376854800704624`}\)], "Output",
  CellLabel->"Out[63]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
        element, "\<Inhalation\>", \ "\<Continuous\>", \
"\<CompartmentContent\>", inputs1, AMADAdultW[5], amad, \ fn1, 180, lambda] // 
      Chop\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \("Option not available for inhalation"\)], "Output",
  CellLabel->"Out[64]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Inhalation\>", \ "\<MultiInputs\>", \
"\<CompartmentContent\>", inputs2, amad, class, fn1, 180, lambda]\)], "Input",\

  CellLabel->"In[65]:="],

Cell[BoxData[
    \("Option not available for MultiInputs intake"\)], "Output",
  CellLabel->"Out[65]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntakeWay\[Rule] \"Inhalation\",ShowReport\[Rule] \"Disintegrations\"\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Inhalation\>", \ "\<Acute\>", "\<Disintegrations\>", \ 1, \ 
      amad, class, \ fn1, 180, lambda]\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \({q\_ET1[180] \[Rule] 26930.311733767343`, 
      q\_AI[180] \[Rule] 45.91248048642084`, 
      q\_bb1[180] \[Rule] 5.562578025092626`, 
      q\_bb2[180] \[Rule] 3.783362956904662`, 
      q\_bbseq[180] \[Rule] 0.06664630083052266`, 
      q\_BB1[180] \[Rule] 9.292533044217365`, 
      q\_BB2[180] \[Rule] 5.10978377459683`, 
      q\_BBseq[180] \[Rule] 0.10728037500067353`, 
      q\_LNth[180] \[Rule] 0.000018295125228995346`, 
      q\_ET2[180] \[Rule] 172.62924479833075`, 
      q\_ETseq[180] \[Rule] 0.17217390094346538`, 
      q\_LNet[180] \[Rule] 1.7202485276812673`*^-6, 
      qLungs[180] \[Rule] 69.83468325818875`, 
      qST[180] \[Rule] 716.7011274628103`, qSI[180] \[Rule] 0, 
      qB[180] \[Rule] 14625.723363804324`, 
      q\_2[180] \[Rule] 127642.66986271758`, 
      q\_3[180] \[Rule] 7658.559439534094`, 
      q\_4[180] \[Rule] 2348.5247328940977`, 
      qURI[180] \[Rule] 325267.61058470403`, 
      qULI[180] \[Rule] 46.895532806428086`, 
      qLLI[180] \[Rule] 77.68137916542545`, 
      qFEC[180] \[Rule] 896.5602548005126`}\)], "Output",
  CellLabel->"Out[66]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Inhalation\>", \ "\<Constant\>", "\<Disintegrations\>", 
      1, \ amad, class, \ fn1, 180, lambda]\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \({q\_ET1[180] \[Rule] 4.822673085931743`*^6, 
      q\_AI[180] \[Rule] 8263.7877905036`, 
      q\_bb1[180] \[Rule] 1001.2095260299964`, 
      q\_bb2[180] \[Rule] 680.9675426922857`, 
      q\_bbseq[180] \[Rule] 11.995668329956397`, 
      q\_BB1[180] \[Rule] 1672.5705361106588`, 
      q\_BB2[180] \[Rule] 919.7100411224964`, 
      q\_BBseq[180] \[Rule] 19.309395732164194`, 
      q\_LNth[180] \[Rule] 0.003292756972827292`, 
      q\_ET2[180] \[Rule] 31072.397014847666`, 
      q\_ETseq[180] \[Rule] 30.989581938483525`, 
      q\_LNet[180] \[Rule] 0.0003096103599676296`, 
      qLungs[180] \[Rule] 12569.553793278132`, 
      qST[180] \[Rule] 128972.84810845448`, qSI[180] \[Rule] 0, 
      qB[180] \[Rule] 2.6249597512802235`*^6, 
      q\_2[180] \[Rule] 2.1569470943413507`*^7, 
      q\_3[180] \[Rule] 1.2411332211305744`*^6, 
      q\_4[180] \[Rule] 421308.46171931474`, 
      qURI[180] \[Rule] 5.4596588577055514`*^7, 
      qULI[180] \[Rule] 7574.954387794199`, 
      qLLI[180] \[Rule] 12476.251684021889`, 
      qFEC[180] \[Rule] 133647.70720006735`}\)], "Output",
  CellLabel->"Out[67]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
        element, "\<Inhalation\>", \ "\<Continuous\>", "\<Disintegrations\>", 
        inputs1, \ amad, class, \ fn1, 180, lambda] // Chop\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \("Option not available for inhalation"\)], "Output",
  CellLabel->"Out[68]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Inhalation\>", \ "\<MultiInputs\>", "\<Disintegrations\>", 
      inputs2, amad, class, fn1, \ 180, lambda]\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \("Option not available for MultiInputs intake"\)], "Output",
  CellLabel->"Out[69]="]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cobalt", "Section"],

Cell[CellGroupData[{

Cell["The model", "SubsubsectionIcon"],

Cell[TextData[StyleBox["All these elements have the same pattern, that it is \
shown in fig. 1. All elements have compartments B, LLI, ULI, BL and URI \
however the number of systemic compartments changed depending on the elements \
(the maximum is three: a, b and c). The same happen of the flow. Fig 1 \
represents a diagram flow where are included all ICRP 30 elements.",
  FormatType->StandardForm]], "Text"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0002El0@0006`000000000000005/1001K0@00
00000000001P=P0003L00215CDH00040O2D00;/100050000000000000000000080<005P200100@00
l0000000000000000000003R1020Z@<0600000`0000000006@0000`0003oool0500000`0000=0000
4P0000`0000200008@0000P0000:0000400005P1000<00002@000100001L0@00H04001@0000<0000
3@000300000<00003`00P4H0000X0000700004M4BD<20000F04000`0002d0P00K0400000000W0000
6000004000000000oooo0000000U000030000040000V000070000080000000000@00000000000002
9@0000`000020000:P0001P0002K0@00]`000=P1003`00009@0000`000000020:00000`000010000
9@0000`000070020:00000`0000200008@0000P0000N000060000:L100310000c@400>L0001B0000
L0400080003eoooo0000000000000000T04000000000000P@@1b06T0H@1/00000000000000000000
000000000000000000000000000000000000000000000000000000004P0>00002`0000<000030000
000000D0000N0000T040000000000000;ASdMbB^4P010000F0@:ZER]4P2DcjP02`0005R]4P0dD@4`
7<nX08R]4P0<0000h1>X042g4P080000mOooo`0000000000000009010000000000008440LP1Y0640
K0000000000000000000000000000000000000000000000000000000000000000000000000170000
A:dB06l<0C3/F>5gm;3QM`02001l[180FEKdMeP42ZUL0000R:`B01c?Z01/[180LR@1<5P42ZUTMP08
000002D0000<00000P0002D0000<00000P0002D0000<00000P000180000<00000@0005@000240000
C`000;D0001d0000`P00004000000212000P@ZL1003100002@0004`00000000000000000003ooooo
ooooof0000120200K`1b0200E01b02h0800000L0000300001P0000@0000300001P0000@000030000
0`0005@0001/0000C`000<@0001/0000d@00004000000212000P@ZL1003@00001@0004`000000000
00000000003ooooooooooeP0001306l0K@1`02h0000700001P0000P0000600000`000280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000000209`0001P000010000
00000?ooo`0000009@0000`0000100009P0001`000030000000000400000000000000RD0000<0000
0`0002X0000H0000F04001<1001g0@00<04002D0000<00000000P2P0000<00000@0002D0000<0000
1`00P2P0000<00000`000240000800007P0001P0001P0@006@400701000[0@00DP00070100030000
loooo`0000000000000009010000000000000440LP1Y0640K0000000000000000000000000000000
0000000000000000000000000000000000000000000000001>dB06Af00P0000040800040001h0P@0
000006d<0C1B0@H0?>hB029@0C1/kQ80b0000000002l0P00B:Z600d0000lkQ80=541<=2YQP1/kQ80
300005S_4P0dl18000000??oool0000000000000002l0P000000000000110780J@1Q06`000000000
00000000000000000000000000000000000000000000000000000000000000001P0002<000000000
400000d0000300000`0005UFm7Od0@X4G00006c]4P1HZHH0D>dB078T0C3d0@X4I7H02000000U0000
300000<0000U0000300000<0000D0000300000d0000B000030000040001D0000E00000P0000=0@00
3P0001`100010000000P@P00849P0@006@400040001<00000000000000000000oooooooooom@0000
H@0000L0000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H0000
6P000140000=0`00S0400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000
0000P2L0000H00000@000000003oool0000002D0000<00000@0002H0000L00001000000000010000
00000000008U0000300000@0000Z000060000:/1000C0@00bP400301000U000030000000080X0000
30000040000U0000300000L0080X0000300000@0000Q0000200001h0000H0000/`4001T100330@00
:`4002D0000<00000`0002D0000<00000`0001@0000<00003@000180000<00000@0005@0001D0000
F`0000d1001Q00007040004000000212000P@[<1000I0@000@0004`00000000000000000003ooooo
oooooe00001R00001`000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000000209`0001P00004000000000?ooo`0000009@0000`0000400009P0001`000010000
000000400000000000000RD0000<00000@0002X0000H0000n`4001<1000J0P00<04002D0000<0000
0000P2P0000<0000100002D0000<00001`00P2P0000<00000@000240000800007P0001P000030P00
6@4001<2000[0@009@0000`0000300009@0000`000030000500000`0000=00004P0000`000010000
E00005@0002[00003@400;40000L0@000@000000848002120`8001T100010000C000000000000000
00000?ooooooooooD00006<0000700008P0000`0003ooooo8@0000P0000I000030000?ooo`0H0000
30000000000N0000600001X0000A00003@<008`1000R000030000?oooolH000030000000000I0000
30000?ooo`0U000030000000080W00006000004000000000oooo0000000U000030000040000V0000
700000@0000000000@000000000000029@0000`000040000:P0001P0000l0P00A0400602001V0@00
9@0000`000000020:00000`0000100009@0000`000070020:00000`0000400008@0000P0000N0000
600004D2001:0@00F0800641000U0000300000<0000U0000300000<0000D0000300000d0000B0000
30000040001D0000F0000>d0000n0@00o00004d100010000000P@P0084950P00BP400080001<0000
0000000000000000oooooooooom@0000@P1<00T0000700008P0000`0003ooooo8@0000P0000I0000
30000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R000030000?oooolH0000
30000000000I000030000?ooo`0U000030000000080W0000600000@000000000oooo0000000U0000
300000@0000V000070000040000000000@000000000000029@0000`000010000:P0001P0002X0@00
Q`000<P1002V00009@0000`000000020:00000`0000400009@0000`000070020:00000`000010000
8@0000P0000N000060000;01002=0000`@400:40000U000030000080000U000030000080000D0000
300000d0000B000030000040001D0000H00005P000210000IP0008h000010000000P@P0084:`0@00
S@0000<0001<00000000000000000000oooooooooomD0000E@1<04T0000700001P000080000R0000
30000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H00006P000140000=0`00
S0400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<00000000P2L0000H0000
0@000000003oool0000002D0000<00000@0002H0000L0000100000000001000000000000008U0000
300000@0000Z000060000:P1001D0000b04007<0000U000030000000080X000030000040000U0000
300000L0080X0000300000@0000Q0000200001h0000H0000/04005X000310@00KP0002D0000<0000
0`0002D0000<00000`0001@0000<00003@000180000<00000@0005@0001P0000F00004h0001X0000
G@00004000000212000P@[01001J00000`0004`00000000000000000003ooooooooooe@0001<04`0
B@0000L0000700000`000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000000209`0001P00004000000000?ooo`0000009@0000`0000400009P0001`000010000
000000400000000000000RD0000<00000@0002X0000H0000Y04000`0003<0@00;`0002D0000<0000
0000P2P0000<0000100002D0000<00001`00P2P0000<00000@000240000800007P0001P0002]0@00
4P000<@1000Z00009@0000`0000200009@0000`000020000500000`0000=00004P0000`000010000
E0000600001E00001P0006L0000C00000@00000084800212[@40018000030000C000000000000000
00000?ooooooooooE00004H0A@1300001P0000H0000700008P0000`0003ooooo8@0000P0000I0000
30000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R000030000?oooolH0000
30000000000I000030000?ooo`0U00003000000008160000:00001`00017A4U30P000681003C0000
W@4001D100000000G`0003P000010000>0000000000h0000000000000@0100000000000000000000
00000000000U000030000040000U0000300000D0081G0000:00000h000360000A@00004100030000
V`7D06P1e01X0@/19@0000`000080020:00000`0000100009`0001P0000100000000000000000000
9@0000`000010000EP0002P0000;0000o@0001H000080@000`0006<12@5X0A@1KP490BD0000<0000
1`00P2D0000<00000000P2P0000<00000@0004H0000D0000200004M4BD<30000AP0002P0000L0000
AdA9@`80002e0@00k`000<81000E0@00000005l0000h00000@0003P000000000>000000000000040
0@0000000000000000000000000000009@0000`0000100009@0000`000050020E`0002@0001P0000
hP0006D000010@000P000;X1l02k0@/19@0000`000080020:00000`0000100009`0001P000010000
00000000000000009@0000`000010000EP0002P0001N0000o@0006T000080@000`000;H12@6l0A@1
`@490BD0000<00001`00P2D0000<00000000P2P0000<00000@0004H0000D0000200004M4BD<30000
AP0002P0000L0000AdA9@`80003F0@00e0000142000F0@00000005l0000h00000@0003P000000000
>0000000000000400@0000000000000000000000000000009@0000`0000100009@0000`000050020
E`0002P0001m0000a`000;@000020@000`000=L1e@0:0]D02P8<0BD0000<00002000P2P0000<0000
0@0002L0000H00000@00000000000000000002D0000<00000@0005H0000X0000[@000?h0002h0000
204000<000050PX12P8D0A022P4U0000300000L0080U000030000000080X00003000004000160000
500000P00017A4U30`0004H0000X0000700004M4BD<20000G0400940002Z0@006@400000001O0000
>0000040000h0000000003P00000000000010040000000000000000000000000000002D0000<0000
0@0002D0000<00001@00P5L0000X00000`0008T0001:00003@4000<0001M0AL1G@6G0:01U`0U0000
300000P0080X000030000040000W0000600000400000000000000000000U000030000040001F0000
:00004H000260000D000094000030000WP6M0:P1V02N0I809@0000`0000700209@0000`000000020
:00000`000010000AP0001@000080000AdA9@`<000160000:00001`00017A4U30P0007l1002M0000
[`4002@100000000G`0003P000010000>0000000000h0000000000000@0100000000000000000000
00000000000U000030000040000U0000300000D0081G0000<00002H0002E0000E@0001P100050000
Z`4R0H018P600J<0Y@6S0:D1X`0U0000300000P0080X000030000040000W00006000004000000000
00000000000U000030000040001F0000:00004X0002B0000EP0009d000030000Y06Y0:h1XP2R0Ih0
9@0000`0000700209@0000`000000020:00000`000010000AP0001@000080000AdA9@`<000160000
:00001`00017A4U30P000<L1002A00005`8001T100000000G`0003P000010000>0000000000h0000
000000000@010000000000000000000000000000000U000030000040000U0000300000D0081G0000
:00007H000290000_`0000d1000300005@8G0AD2U`3@0IL09@0000`000080020:00000`000010000
9`0001P00001000000000000000000009@0000`000010000EP0002P0001`0000QP0007/0002A0000
0`000=<1TP380IP0d`6M02D0000<00001`00P2D0000<00000000P2P0000<00000@0004H0000D0000
200004M4BD<30000AP0002P0000L0000AdA9@`80002b0@00LP000;l100290000000005l0000h0000
0@0003P000000000>0000000000000400@0000000000000000000000000000009@0000`000010000
9@0000`000050020E`0002@0001N0000K@000680001m00000P000;P1Q`2h0G/09@0000`000080020
:00000`0000100009`0001P00001000000000000000000009@0000`000010000EP0002P0001K0000
J00006H0001b00000`000;h1OP2h0G@0/`5n02D0000<00001`00P2D0000<00000000P2P0000<0000
0@0004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80002b0@00;P000;l1001F0000
000005l0000h00000@0003P000000000>0000000000000400@000000000000000000000000000000
9@0000`0000100009@0000`000050020E`0002@0001N0000:@000680001:00000P000;P1E02h0CL0
9@0000`000080020:00000`0000100009`0001P00001000000000000000000009@0000`000010000
EP0002P0001K0000900006H0000^00000`000;h1>P2h0C00/`4j02D0000<00001`00P2D0000<0000
0000P2P0000<00000@0004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80001W0@00
;`4004<2001X0@00000005l0000h00000@0003P000000000>0000000000000400@00000000000000
00000000000000009@0000`0000100009@0000`000050020E`0002`0000>00008P400><0001G0@00
100006P1<05X0F41>@9Q0CT2H@4U0000300000P0080X000030000040000W00006000004000000000
00000000000U000030000040001F0000:0000=l0001@0@00jP0005/100030000=`9W0D82HP4g0U`1
9@0000`0000700209@0000`000000020:00000`000010000AP0001@000080000AdA9@`<000160000
:00001`00017A4U30P000;X1000_0@00?P8005`100000000G`0003P000010000>0000000000h0000
000000000@010000000000000000000000000000000U000030000040000U0000300000D0081G0000
:0000640000R0@00gP0004/100030000^`4`0K/1E@4d0UD19@0000`000080020:00000`000010000
9`0001P00001000000000000000000009@0000`000010000EP0002P0003J0000A0400>@0001?0@00
0`000382F`4l0UH1<P9@0BD0000<00001`00P2D0000<00000000P2P0000<00000@0004H0000D0000
200004M4BD<30000AP0002P0000L0000AdA9@`80000:0P00;`4004<2001@0@00000005l0000h0000
0@0003P000000000>0000000000000400@0000000000000000000000000000009@0000`000010000
9@0000`000050020E`0002`0002a00008P400><0000o0@00100000/2<04;0TT1>@990CT2B@4U0000
300000P0080X000030000040000W0000600000400000000000000000000U000030000040001F0000
:0000=l0000h0@00jP0004<100030000=`9?0D82BP4g0T@19@0000`0000700209@0000`000000020
:00000`000010000AP0001@000080000AdA9@`<000160000:00001`00017A4U30P000<h1002N0000
E@8004H100000000G`0003P000010000>0000000000h0000000000000@0100000000000000000000
00000000000U000030000040000U0000300000D0081G0000;00007D0002A0000n000038100040000
c`6o0<l1W`1>0Yl0CP8l0BD0000<00002000P2P0000<00000@0002L0000H00000@00000000000000
000002D0000<00000@0005H0000X0000l@0002h1003l0000>04000<000190SX1CP940E@2>P4U0000
300000L0080U000030000000080X00003000004000160000500000P00017A4U30`0002L0000H0000
0@000000003oool0000002D0000<00000@0002H0000L0000100000000001000000000000008U0000
300000@0000Z00006000090200150@00/`8006L1000U000030000000080X000030000040000U0000
300000L0080X0000300000@0000Q0000200001h0000H0000V08004/1002/0P00HP4002D0000<0000
0P0002D0000<00000P0001@0000<00003@000180000<00000@0005@0001P0000@04003l1001?0@00
C040004000000212000P@YP2001;0@000`0004`00000000000000000003ooooooooooe@0001E0580
B@0000L0000700000P000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`000000020AP0002P0000L0000AdA9@`80001O0P00CP400982001K0@00000005l0000h0000
100003P000000000>0000000000000400@0000000000000000000000000000009@0000`000040000
9@0000`000050020E`0002@000060@00AP400381001;0@000P000602E@680U@19@0000`000080020
:00000`0000400009`0001P00004000000000000000000009@0000`000040000EP0002P0000^0@00
@`4003P1001>0@000`0008H2FP6@0U@1QP9?0BD0000<00001`00P2D0000<00000000P2P0000<0000
100004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80002d0@00Y@000;d1002i0000
00000180000<00000@0005l0000h0000100003P000000000>0000000000200400@00000000000000
00000000000000009@0000`0000400009@0000`000050020E`0002@0001N0000W0000680002]0000
0P000;P1]`2h0JX09@0000`000080020:00000`0000400009`0001P0000400000000000000000000
9@0000`000040000EP0002P0001M0000VP0006@0002Q00000`000;`1[@2h0JH0]@6]02D0000<0000
1`00P2D0000<00000000P2P0000<0000100004H0000D0000200004M4BD<30000AP0001@000080000
AdA9@`<0000<00004000000000000000600000`0000000006@0000`0003oool09@0000`000000020
8P0000`0003ooooo3P0001@000000000400001@0
\>"], "Text",
  ImageSize->{347, 347},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 1 ICRP 30 models (Cobalts, Caesium and others", "Commentary"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CompartNumbers[cobalt]\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "\<\"Blood\"\>"},
          {"2", "\<\"Systemic A\"\>"},
          {"3", "\<\"Systemic B\"\>"},
          {"4", "\<\"Systemic C\"\>"},
          {"5", "\<\"Bladder\"\>"},
          {"6", "\<\"Urine\"\>"},
          {"7", "\<\"ULI\"\>"},
          {"8", "\<\"LLI\"\>"},
          {"9", "\<\"FEC\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[70]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
TableForm[TransferRates[cobalt], TableHeadings -> 
   {None, {\"From\", \"to\", \"Tranfer Rates(\\!\\(days\\^\\(-1\\)\\))\"}}]\
\>", "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"From\"\>", "\<\"to\"\>", "\<\"Tranfer \
Rates(\\!\\(days\\^\\(-1\\)\\))\"\>"},
          {"1", "2", "0.4158883083359672`"},
          {"1", "3", "0.13862943611198905`"},
          {"1", "4", "0.13862943611198905`"},
          {"1", "5", "0.5941261547656673`"},
          {"1", "7", "0.09902102579427789`"},
          {"2", "5", \(Log[2]\/7\)},
          {"3", "5", \(Log[2]\/70\)},
          {"4", "5", \(\(3\ Log[2]\)\/2800\)},
          {"2", "7", \(Log[2]\/42\)},
          {"3", "7", \(Log[2]\/420\)},
          {"4", "7", \(Log[2]\/5600\)},
          {"5", "6", "12"},
          {"7", "8", \(k\_ULI\)},
          {"8", "9", \(k\_LLI\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"From", "to", 
          "Tranfer Rates(\!\(days\^\(-1\)\))"}}]]]], "Output",
  CellLabel->"Out[71]//TableForm="]
}, Open  ]],

Cell[BoxData[
    \(Clear[element, \ lambda, \ fn1, \ amad, \ class]\)], "Input",
  CellLabel->"In[72]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Injection", "SubsubsectionIcon"],

Cell["\<\
Here are shown whole body and daily urine an faecal excretion as function of \
the time for a single intake of 1 Bq and for a chronic intake 1 Bq/day of \
Co-57 (decay constant: \[Lambda]  = 271 days) into compartment 1 (Blood) in t \
=0 .\
\>", "MathCaption"],

Cell["\<\
Whole body and daily urine values from day 1 to 10 are the same that Table \
A.3.9 of ICRP 78 (Faecal and values higher that 10 days are not included in \
ICRP ).\
\>", "Commentary"],

Cell[BoxData[
    \(element = \ cobalt; lambda\  = \ Log[2]/271;\)], "Input",
  CellLabel->"In[73]:="],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Injection\>", \ "\<Acute\>", "\<BioassayTable\>", 1, fn1, 
      180, lambda]\)], "Input",
  CellLabel->"In[74]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nstart intake"\), \("Urine\n24 hours"\), \("Faecal\n\
24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "0.31844900957063005`", "0.011132231338382776`", 
            "0.6678642886438787`"},
          {"2", "0.1137371357126923`", "0.025987746287051975`", 
            "0.5264333670561148`"},
          {"3", "0.04664655696239576`", "0.02120153536030939`", 
            "0.45724051625489276`"},
          {"4", "0.027956215232089472`", "0.013262896099553254`", 
            "0.41485339753725625`"},
          {"5", "0.021552455823926214`", "0.00804366820060074`", 
            "0.3841975427688378`"},
          {"6", "0.018405649377108393`", "0.0052796581001590724`", 
            "0.35953081402271564`"},
          {"7", "0.01624265576578326`", "0.0038772604747134326`", 
            "0.338492486942973`"},
          {"8", "0.014477536694899843`", "0.0031199574684619515`", 
            "0.3200303237251471`"},
          {"9", "0.012947204513597349`", "0.0026536075555612408`", 
            "0.30361200365185403`"},
          {"10", "0.011595904885240284`", "0.0023219960835031564`", 
            "0.2889185347923945`"},
          {"20", "0.0040972996828299146`", "0.0007921752871493892`", 
            "0.2017943461250369`"},
          {"30", "0.0017293357965421207`", "0.00032301031874788045`", 
            "0.166413971421501`"},
          {"40", "0.0009447619320778563`", "0.00016921251423273774`", 
            "0.14783971790575381`"},
          {"50", "0.0006537523132394523`", "0.00011349833231461483`", 
            "0.13523706452190415`"},
          {"60", "0.0005207303550055803`", "0.00008899187786801006`", 
            "0.12517955301183378`"},
          {"70", "0.00044182132231767506`", "0.00007501742453924895`", 
            "0.1165281199219256`"},
          {"80", "0.00038439988560537436`", "0.000065102703431529`", 
            "0.10885722504604967`"},
          {"90", "0.0003378124517755723`", "0.00005715260586949982`", 
            "0.10197016103494011`"},
          {"100", "0.00029823496688636197`", "0.0000504301062302652`", 
            "0.09574896330225638`"},
          {"180", "0.00011943894259480115`", "0.000020142908849518594`", 
            "0.062020123423749234`"},
          {"200", "0.00009728439775546267`", "0.000016393888754231505`", 
            "0.05648075511103742`"},
          {"300", "0.00004120113744310281`", "6.914432669923474`*^-6", 
            "0.037298458346161655`"},
          {"400", "0.000022456180591143646`", "3.7569408826843656`*^-6", 
            "0.02579951869263614`"},
          {"500", "0.00001428687117657194`", "2.3864941397609947`*^-6", 
            "0.018152094092146822`"},
          {"600", "9.739997958959524`*^-6", "1.625968833967862`*^-6", 
            "0.012848221681167296`"},
          {"700", "6.817267473743379`*^-6", "1.1377993782778232`*^-6", 
            "0.009112975635854456`"},
          {"800", "4.81655663016917`*^-6", "8.038179627414512`*^-7", 
            "0.006468263917472747`"},
          {"900", "3.4141376758619903`*^-6", "5.697576922230626`*^-7", 
            "0.004592212276731455`"},
          {"1000", "2.4227838069347168`*^-6", "4.043148967993762`*^-7", 
            "0.003260564846415284`"},
          {"2000", "7.890075314230796`*^-8", "1.3166916745994325`*^-8", 
            "0.00010621442873563723`"},
          {"3000", "2.5702884164650104`*^-9", "4.289283972731761`*^-10", 
            "3.4600647871309115`*^-6"},
          {"4000", "8.373028554731683`*^-11", "1.3972866606318248`*^-11", 
            "1.1271583795142521`*^-7"},
          {"5000", "2.7276163534527698`*^-12", "4.551832017635054`*^-13", 
            "3.671856137591855`*^-9"},
          {"6000", "8.885543531803427`*^-14", "1.482814894072714`*^-14", 
            "1.1961519995957679`*^-10"},
          {"7000", "2.8945743691478023`*^-15", "4.830450687919841`*^-16", 
            "3.896611284654825`*^-12"},
          {"8000", "9.429429666885257`*^-17", "1.5735783300846016`*^-17", 
            "1.2693687348121824`*^-13"},
          {"9000", "3.0717519228546116`*^-18", "5.126123670211205`*^-19", 
            "4.135123745250375`*^-15"},
          {"10000", "1.0006607195660013`*^-19", "1.6698974166018472`*^-20", 
            "1.3470670829988206`*^-16"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nstart intake", 
          "Urine\n24 hours", "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
  CellLabel->"Out[74]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Injection\>", \ "\<Constant\>", "\<GraphicReport\>", 1, 
      fn1, 180, lambda]\)], "Input",
  CellLabel->"In[75]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.634391 0.251133 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .05653 -34 -6.28125 ]
[-0.0125 .05653 0 6.28125 ]
[-0.0125 .13212 -28 -6.28125 ]
[-0.0125 .13212 0 6.28125 ]
[-0.0125 .30766 -28 -6.28125 ]
[-0.0125 .30766 0 6.28125 ]
[-0.0125 .38326 -22 -6.28125 ]
[-0.0125 .38326 0 6.28125 ]
[-0.0125 .55879 -22 -6.28125 ]
[-0.0125 .55879 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .05653 m
.00625 .05653 L
s
gsave
-0.0125 .05653 -95 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.005) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .13212 m
.00625 .13212 L
s
gsave
-0.0125 .13212 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .30766 m
.00625 .30766 L
s
gsave
-0.0125 .30766 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .38326 m
.00625 .38326 L
s
gsave
-0.0125 .38326 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .55879 m
.00625 .55879 L
s
gsave
-0.0125 .55879 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .00081 m
.00375 .00081 L
s
0 .03219 m
.00375 .03219 L
s
0 .07641 m
.00375 .07641 L
s
0 .09322 m
.00375 .09322 L
s
0 .10779 m
.00375 .10779 L
s
0 .12063 m
.00375 .12063 L
s
0 .20772 m
.00375 .20772 L
s
0 .25195 m
.00375 .25195 L
s
0 .28332 m
.00375 .28332 L
s
0 .32754 m
.00375 .32754 L
s
0 .34436 m
.00375 .34436 L
s
0 .35892 m
.00375 .35892 L
s
0 .37177 m
.00375 .37177 L
s
0 .45886 m
.00375 .45886 L
s
0 .50308 m
.00375 .50308 L
s
0 .53445 m
.00375 .53445 L
s
0 .57868 m
.00375 .57868 L
s
0 .59549 m
.00375 .59549 L
s
0 .61005 m
.00375 .61005 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Constant) show
117.000 12.813 moveto
(intake) show
153.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .4442 m
.06042 .47992 L
.08838 .50036 L
.1161 .51587 L
.13894 .52589 L
.17363 .53753 L
.20509 .54529 L
.26115 .55505 L
.30107 .56041 L
.41107 .57388 L
.47999 .58182 L
.53436 .58719 L
.6034 .59236 L
.62978 .59382 L
.65448 .59496 L
.69522 .59647 L
.72741 .59744 L
.75381 .59816 L
.77827 .5988 L
.79909 .59933 L
.8189 .59983 L
.83615 .60026 L
.85134 .60064 L
.86623 .601 L
.87951 .60132 L
.89144 .6016 L
.90333 .60187 L
.91409 .60211 L
.92488 .60234 L
.93471 .60254 L
.94369 .60272 L
.95278 .6029 L
.96113 .60305 L
.96882 .60319 L
.97619 .60332 L
s
0 0 1 r
[ ] 0 setdash
.02381 .01472 m
.08838 .13364 L
.13894 .21156 L
.20509 .28708 L
.23623 .31235 L
.26149 .32847 L
.30107 .34701 L
.31846 .35305 L
.33525 .35794 L
.362 .36428 L
.41107 .3732 L
.48481 .38381 L
.53436 .38966 L
.60117 .39559 L
.62892 .39738 L
.65109 .39856 L
.69114 .40025 L
.72284 .4013 L
.75147 .40213 L
.77536 .40278 L
.79774 .40336 L
.817 .40386 L
.83379 .40429 L
.85011 .4047 L
.86456 .40506 L
.87746 .40538 L
.89027 .40569 L
.9018 .40595 L
.91331 .40621 L
.92376 .40644 L
.93328 .40664 L
.94289 .40684 L
.95169 .40701 L
.95977 .40717 L
.96801 .40732 L
.97559 .40745 L
.97619 .40746 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[75]:=",
  ImageSize->{600, 294.25},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[75]="]
}, Open  ]],

Cell["\<\
Even, it can applied input variable in the time. In this example is evaluted \
the retention the 5 days after the start a continuous  intake I = 6 +4.3 \
Cos[-0.5 t] Bq/day of Co-57  into compartment 1 (Blood).\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      cobalt, "\<Injection\>", "\<Continuous\>", "\<CompartmentContent\>", {6 \
+ 4.3\ Cos[\(-0.5\)\ t], \ t}, 1, 5, Log[2]/271]\)], "Input",
  CellLabel->"In[76]:="],

Cell[BoxData[
    \({qB[5] \[Rule] 2.7080243035475062`, q\_2[5] \[Rule] 7.271002039504258`, 
      q\_3[5] \[Rule] 3.1241010171397465`, 
      q\_4[5] \[Rule] 3.2098227523961222`, 
      q\_5[5] \[Rule] 0.20166494316472386`, 
      qURI[5] \[Rule] 15.710406698570706`, 
      qULI[5] \[Rule] 0.25469031554988597`, 
      qLLI[5] \[Rule] 0.5333559349896121`, 
      qFEC[5] \[Rule] 1.863965689749722`, 
      qWB[5] \[Rule] 17.30266130629187`}\)], "Output",
  CellLabel->"Out[76]="]
}, Open  ]],

Cell["\<\
Here is represented the predicted values (Bq per Bq/day intake) for a chronic \
intake of 1 Bq/day.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      cobalt, "\<Injection\>", "\<Constant\>", "\<GraphicReport\>", 1, 1, 
      180, Log[2]/271]\)], "Input",
  CellLabel->"In[77]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.634391 0.251133 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .05653 -34 -6.28125 ]
[-0.0125 .05653 0 6.28125 ]
[-0.0125 .13212 -28 -6.28125 ]
[-0.0125 .13212 0 6.28125 ]
[-0.0125 .30766 -28 -6.28125 ]
[-0.0125 .30766 0 6.28125 ]
[-0.0125 .38326 -22 -6.28125 ]
[-0.0125 .38326 0 6.28125 ]
[-0.0125 .55879 -22 -6.28125 ]
[-0.0125 .55879 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .05653 m
.00625 .05653 L
s
gsave
-0.0125 .05653 -95 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.005) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .13212 m
.00625 .13212 L
s
gsave
-0.0125 .13212 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .30766 m
.00625 .30766 L
s
gsave
-0.0125 .30766 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .38326 m
.00625 .38326 L
s
gsave
-0.0125 .38326 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .55879 m
.00625 .55879 L
s
gsave
-0.0125 .55879 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .00081 m
.00375 .00081 L
s
0 .03219 m
.00375 .03219 L
s
0 .07641 m
.00375 .07641 L
s
0 .09322 m
.00375 .09322 L
s
0 .10779 m
.00375 .10779 L
s
0 .12063 m
.00375 .12063 L
s
0 .20772 m
.00375 .20772 L
s
0 .25195 m
.00375 .25195 L
s
0 .28332 m
.00375 .28332 L
s
0 .32754 m
.00375 .32754 L
s
0 .34436 m
.00375 .34436 L
s
0 .35892 m
.00375 .35892 L
s
0 .37177 m
.00375 .37177 L
s
0 .45886 m
.00375 .45886 L
s
0 .50308 m
.00375 .50308 L
s
0 .53445 m
.00375 .53445 L
s
0 .57868 m
.00375 .57868 L
s
0 .59549 m
.00375 .59549 L
s
0 .61005 m
.00375 .61005 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Constant) show
117.000 12.813 moveto
(intake) show
153.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .4442 m
.06042 .47992 L
.08838 .50036 L
.1161 .51587 L
.13894 .52589 L
.17363 .53753 L
.20509 .54529 L
.26115 .55505 L
.30107 .56041 L
.41107 .57388 L
.47999 .58182 L
.53436 .58719 L
.6034 .59236 L
.62978 .59382 L
.65448 .59496 L
.69522 .59647 L
.72741 .59744 L
.75381 .59816 L
.77827 .5988 L
.79909 .59933 L
.8189 .59983 L
.83615 .60026 L
.85134 .60064 L
.86623 .601 L
.87951 .60132 L
.89144 .6016 L
.90333 .60187 L
.91409 .60211 L
.92488 .60234 L
.93471 .60254 L
.94369 .60272 L
.95278 .6029 L
.96113 .60305 L
.96882 .60319 L
.97619 .60332 L
s
0 0 1 r
[ ] 0 setdash
.02381 .01472 m
.08838 .13364 L
.13894 .21156 L
.20509 .28708 L
.23623 .31235 L
.26149 .32847 L
.30107 .34701 L
.31846 .35305 L
.33525 .35794 L
.362 .36428 L
.41107 .3732 L
.48481 .38381 L
.53436 .38966 L
.60117 .39559 L
.62892 .39738 L
.65109 .39856 L
.69114 .40025 L
.72284 .4013 L
.75147 .40213 L
.77536 .40278 L
.79774 .40336 L
.817 .40386 L
.83379 .40429 L
.85011 .4047 L
.86456 .40506 L
.87746 .40538 L
.89027 .40569 L
.9018 .40595 L
.91331 .40621 L
.92376 .40644 L
.93328 .40664 L
.94289 .40684 L
.95169 .40701 L
.95977 .40717 L
.96801 .40732 L
.97559 .40745 L
.97619 .40746 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[77]:=",
  ImageSize->{600, 294.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;^0001Ka000`40O003h00Oogooogool7oo003o
OoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogoo
l7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00
ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomo
oo1oo`00ogooogool7oo001<Ool5000eOol5001;Ool4000dOol50003Ool4000_Ool50004Ool40013
Ool40004Ool4000/Ool50003Ool40004Ool4000WOol50004Ool40004Ool4003=Ool004ioo`03001o
ogoo03Eoo`05001oogooOol0001:Ool00`00Oomoo`02Ool00`00Oomoo`0cOol00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`0/Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol0
?goo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo02]oo`03001oogoo009oo`03001oogoo
009oo`04001oogoo0004Ool00`00Oomoo`0TOol01@00Oomoogoo00000goo00<007ooOol00Woo00@0
07ooOol000Aoo`03001oogoo0<Yoo`00CWoo00<007ooOol0=Woo00<007ooOol0D7oo00<007ooOol0
<goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0;Goo00<007ooOol017oo00<007ooOol0
0Woo00<007ooOol0A7oo00@007ooOol000Aoo`03001oogoo02]oo`03001oogoo009oo`03001oogoo
009oo`04001oogoo0004Ool00`00Oomoo`0UOol00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomo
o`0017oo00<007ooOol0bWoo001>Ool00`00Oomoo`0gOol00`00Oomoo`1?Ool00`00Oomoo`0cOol0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0^Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Oomoo`14Ool01000Oomoo`0017oo00<007ooOol0:goo00<007ooOol00Woo00<007ooOol00Woo
00@007ooOol000Aoo`03001oogoo02Ioo`03001oogoo00=oo`03001oogoo009oo`04001oogoo0004
Ool00`00Oomoo`3:Ool004ioo`03001oogoo03Qoo`03001oogoo04Yoo`@003Ioo`03001oogoo009o
o`03001oogoo009oo`03001oogoo02moo`03001oogoo009oo`03001oogoo009oo`03001oogoo041o
o`@000=oo`03001oogoo009oo`03001oogoo02]oo`03001oogoo009oo`03001oogoo009oo`04001o
ogoo0004Ool00`00Oomoo`0WOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<0
07ooOol0bWoo001>Ool00`00Oomoo`0iOol00`00Oomoo`19Ool00`00Oomoo`0gOol00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`0`Ool01@00Oomoogoo000017oo00<007ooOol0@7oo00<007oo
Ool017oo00<007ooOol00Woo00<007ooOol0:goo00<007ooOol00Woo00<007ooOol00Woo00@007oo
Ool000Aoo`03001oogoo02Qoo`05001oogooOol00004Ool01000Oomoo`0017oo00<007ooOol0bWoo
001<Ool3000gOol01@00Oomoogoo0000Bgoo00<007ooOol0=Goo0`0017oo00<007ooOol00Woo00<0
07ooOol0;7oo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo041oo`03001oogoo00Ao
o`03001oogoo009oo`03001oogoo02Uoo`<000Aoo`03001oogoo009oo`04001oogoo0004Ool00`00
Oomoo`0TOol01@00Oomoogoo00000goo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo0<Yo
o`00CWoo00<007ooOol0=Woo0`00C7oo1@00=Goo00<007ooOol00goo1000<7oo0`001Goo1000@goo
1@000goo1000;Woo00<007ooOol00goo100017oo1000:7oo0`001Goo100017oo1000cGoo003oOooo
Ooo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooc]oo`<00;9oo`00ogoo
ogoo?Goo00<007ooOol0/7oo003oOoooOol[Ool300000goo00000002Ool300000goo00000004Ool0
0`00Oomoo`02Ool5002YOol00?mooomoobYoo`04001oogooOol20002Ool01000Oomoogoo0P0017oo
00<007oo00000goo00<007ooOol00Woo00<007ooOol0YWoo0012Oooo003H000?Ool00`00Oomoo`02
Ool01000Oomoo`0017oo00<007ooOol00Woo00<007oo000027oo00<007ooOol0YWoo0012Ool00`00
Oomoo`08Ool00`00Oomoo`0iOol00`00Oomoo`0POol00`00Oomoo`0FOol00`00Oomoo`0@Ool00`00
Oomoo`0=Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00
Oomoo`0iOol00`00Oomoo`0POol00`00Oomoo`0EOol00`00Oomoo`0AOol00`00Oomoo`0<Ool00`00
Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0iOol00`00
Oomoo`0?Ool00`00Oomoo`02Ool01000Oomoogoo1@000goo00D007ooOomoo`0000=oo`@00:Uoo`00
@Woo00<007ooOol027oo00<007ooOol0>Goo00<007ooOol087oo00<007ooOol05Woo00<007ooOol0
47oo00<007ooOol03Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol01goo00<007ooOol0
1Woo00<007ooOol0>Goo00<007ooOol087oo00<007ooOol05Goo00<007ooOol04Goo00<007ooOol0
37oo00<007ooOol02goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01Woo00<007ooOol0
>Goo00<007ooOol03goo00@007ooOomoo`80009oo`03001oogoo009oo`05001oogooOol00003Ool0
1000Oomoo`0017oo00<007ooOol0YWoo0012Ool00`00Oomoo`08Ool00`00Oomoo`0iOol00`00Oomo
o`1<Ool00`00Oomoo`0iOol00`00Oomoo`0iOol00`00Oomoo`1<Ool00`00Oomoo`0hOol00`00Oomo
o`0iOol00`00Oomoo`0@Ool300000goo001oo`02Ool40003Ool3000017oo000000000Woo1@00Z7oo
0012Ool00`00Oomoo`3oOooYOol00`00Oomoo`2nOol0049oo`03001oogoo0?moonQoo`800<1oo`00
@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomoo`08Ool00`0OOomoo`3oOoooOonPOol0049o
o`03001oogoo00Uoo`0301moogoo0?mooomooimoo`00@Woo00<007ooOol02Goo00<07gooOol0ogoo
ogooWgoo0012Ool00`00Oomoo`0:Ool00`0OOomoo`3oOoooOonNOol0049oo`03001oogoo00Yoo`03
01moogoo0?mooomooiioo`00@Woo00<007ooOol02goo00<07gooOol0ogooogooWGoo0012Ool00`00
Oomoo`0;Ool00`0OOomoo`3oOoooOonMOol0049oo`03001oogoo00aoo`0301moogoo0?mooomooiao
o`00@Woo0`0037oo00<07gooOol0ogooogooW7oo0012Ool00`00Oomoo`0=Ool00`0OOomoo`3oOooo
OonKOol0049oo`03001oogoo00ioo`0301moogoo0?mooomooiYoo`00@Woo00<007ooOol03Woo00<0
7gooOol0ogooogooVWoo0012Ool00`00Oomoo`0?Ool00`0OOomoo`3oOoooOonIOol0049oo`03001o
ogoo00moo`0301moogoo0?mooomooiUoo`00@Woo00<007ooOol047oo00<07gooOol0ogooogooV7oo
0012Ool00`00Oomoo`0@Ool00`0OOomoo`3oOoooOonHOol0049oo`03001oogoo015oo`0301moogoo
0?mooomooiMoo`005Woo10001Goo0P001Goo100017oo100017oo100027oo00<007ooOol04Goo00<0
7gooOol0ogooogooUgoo000EOol00`00Oomoo`02Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`02
Ool01000Oomoo`0017oo00@007ooOol000Aoo`03001oogoo00Eoo`03001oogoo019oo`0301moogoo
0?mooomooiIoo`005Goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00@007ooOol0
00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`@0019oo`0301moogoo0?mooomooiEoo`005Goo00<0
07ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo01=oo`0301moogoo0?mooomooiEoo`005Goo00<007ooOol00Woo00<0
07ooOol027oo00<007ooOol00Woo00@007ooOol000Aoo`04001oogooOol40008Ool00`00Oomoo`0D
Ool00`0OOomoo`3oOoooOonDOol001Eoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009o
o`04001oogoo0004Ool01@00Oomoogoo00002goo00<007ooOol057oo00<07gooOol0ogooogooU7oo
000EOol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool01000Oomoo`0017oo00D007oo
Oomoo`0000]oo`03001oogoo01Eoo`0301moogoo0?mooomooi=oo`005Woo100037oo100017oo1000
17oo1@001goo00<007ooOol05Goo00<07gooOol0ogooogooTgoo0012Ool00`00Oomoo`0FOol00`0O
Oomoo`3oOoooOonBOol0049oo`03001oogoo01Ioo`0301moogoo0?mooomooi9oo`00@Woo00<007oo
Ool05goo00<07gooOol0ogooogooTGoo0012Ool00`00Oomoo`0GOol00`0OOomoo`3oOoooOonAOol0
049oo`<001Qoo`0301moogoo0?mooomooi1oo`00@Woo00<007ooOol06Goo00<07gooOol0ogooogoo
Sgoo0012Ool00`00Oomoo`0IOol00`0OOomoo`3oOoooOon?Ool0049oo`03001oogoo01Yoo`0301mo
ogoo0?mooomoohioo`00@Woo00<007ooOol06Woo00<07gooOol0ogooogooSWoo0012Ool00`00Oomo
o`0KOol00`0OOomoo`3oOoooOon=Ool0049oo`03001oogoo01]oo`0301moogoo0?mooomooheoo`00
@Woo00<007ooOol077oo00<07gooOol0ogooogooS7oo0012Ool3000LOol00`0OOomoo`3oOoooOon<
Ool0049oo`03001oogoo01eoo`0301moogoo0?mooomooh]oo`00@Woo00<007ooOol07Woo00<07goo
Ool0ogooogooRWoo0012Ool00`00Oomoo`0NOol00`0OOomoo`3oOoooOon:Ool0049oo`03001oogoo
01moo`0301moogoo0?mooomoohUoo`00@Woo00<007ooOol07goo00<07gooOol0ogooogooRGoo0012
Ool00`00Oomoo`0POol00`0OOomoo`3oOoooOon8Ool0049oo`<0021oo`0301moogoo0?mooomoohQo
o`00@Woo00<007ooOol08Goo00<07gooOol0ogooogooQgoo0012Ool00`00Oomoo`0QOol00`0OOomo
o`3oOoooOon7Ool0049oo`03001oogoo029oo`0301moogoo0?mooomoohIoo`00@Woo00<007ooOol0
8goo00<07gooOol0ogooogooQGoo0012Ool00`00Oomoo`0SOol00`0OOomoo`3oOoooOon5Ool0049o
o`<002Aoo`0301moogoo0?mooomoohAoo`00@Woo00<007ooOol097oo00<07gooOol0ogooogooQ7oo
0012Ool00`00Oomoo`0UOol00`0OOomoo`3oOooQOon=000DOol001ioo`@000Eoo`8000Eoo`@000Ao
o`D000Moo`03001oogoo02Eoo`0301moogoo0?moon5oohd001Aoo`007Goo00<007ooOol00Woo00<0
07ooOol00Woo0P0017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol0
9Woo00<07gooOol0ogooh7ooS@0057oo000MOol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`07Ool4000UOol00`0OOomoo`3oOooPOon=000DOol001eo
o`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Mo
o`03001oogoo02Moo`0301moogoo0?moomUooi<001Aoo`007Goo00<007ooOol00Woo00<007ooOol0
27oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol0:7oo00<07gooOol0
ogoof7oo00<007ooOol0RWoo1P0057oo000MOol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`0XOol00`0OOomoo`3oOooHOol00`00
Oomoo`2:Ool6000DOol001eoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`04001o
ogooOol30009Ool00`00Oomoo`0YOol00`0OOomoo`3oOooGOol00`00Oomoo`2:Ool6000DOol001io
o`@000aoo`@000Ioo`03001oogoo00Moo`03001oogoo02Yoo`0301moogoo0?moomIoo`03001oogoo
08Yoo`H001Aoo`00@Woo00<007ooOol0:Woo00<07gooOol0ogooeWoo00<007ooOol0RWoo1P0057oo
0012Ool00`00Oomoo`0[Ool00`0OOomoo`3oOooEOol00`00Oomoo`2:Ool6000DOol0049oo`03001o
ogoo02aoo`0301moogoo0?moomAoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0;7oo00<0
7gooOol0ogooe7oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`0]Ool00`0OOomoo`3oOooC
Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo02ioo`0301moogoo0?moom9oo`03001oogoo
08Yoo`H001Aoo`00@Woo00<007ooOol0;Woo00<07gooOol0ogoodWoo00<007ooOol0RWoo1P0057oo
0012Ool00`00Oomoo`0_Ool00`0OOomoo`3oOooAOol00`00Oomoo`2:Ool6000DOol0049oo`03001o
ogoo031oo`0301moogoo0?moom1oo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0<7oo00<0
7gooOol0ogood7oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`0aOol00`0OOomoo`3oOoo?
Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo039oo`0301moogoo0?moolioo`03001oogoo
08Yoo`H001Aoo`00@Woo00<007ooOol0<Woo00<07gooOol0ogoocWoo00<007ooOol0RWoo1P0057oo
0012Ool00`00Oomoo`0cOol00`0OOomoo`3oOoo=Ool00`00Oomoo`2:Ool6000DOol0049oo`03001o
ogoo03Aoo`0301moogoo0?moolaoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0=7oo00<0
7gooOol0ogooc7oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`0eOol00`0OOomoo`3oOoo;
Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo03Ioo`0301moogoo0?moolYoo`03001oogoo
08Yoo`H001Aoo`00@Woo00<007ooOol0=Woo00<07gooOol0ogoobWoo00<007ooOol0RWoo1P0057oo
0012Ool00`00Oomoo`0gOol00`0OOomoo`3oOoo9Ool00`00Oomoo`2:Ool6000DOol0049oo`03001o
ogoo03Qoo`0301moogoo0?moolQoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0>7oo00<0
7gooOol0ogoob7oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`0iOol00`0OOomoo`3oOoo7
Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo03Yoo`0301moogoo0?moolIoo`03001oogoo
03eoo`H0009oo`80009oo`8000=oo`@000=oo`D000Aoo`D000Aoo`<000Aoo`D000=oo`@000=oo`<0
0004Ool000000006Ool6000DOol0049oo`03001oogoo03Yoo`0301moogoo0?moolIoo`03001oogoo
03ioo`05001oogooOol00003Ool01000Oomoo`000goo00<007ooOol00Woo00D007ooOomoo`0000Io
o`03001oogoo00Ioo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000goo00<007ooOol01Goo1P0057oo0012Ool00`00Oomoo`0kOol00`0OOomoo`3oOoo5Ool0
0`00Oomoo`0nOol00`00Oomoo`06Ool20004Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomo
o`06Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<0
07ooOol01Goo1P0057oo0012Ool00`00Oomoo`0lOol00`0OOomoo`3oOoo4Ool00`00Oomoo`0nOol0
0`00Ool00006Ool20004Ool00`00Oomoo`06Ool00`00Oomoo`04Ool60003Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol01Goo1P0057oo0012
Ool00`00Oomoo`0lOol00`0OOomoo`3oOoo4Ool00`00Oomoo`0nOol30005Ool01000Oomoo`000goo
00@007ooOomoo`8000=oo`8000Eoo`03001oogoo009oo`05001oogooOol00009Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool01000Oomoogoo0P000Woo00<007ooOol01Goo1P0057oo0012Ool00`00Oomo
o`0mOol00`0OOomoo`3oOoo3Ool00`00Oomoo`0nOol00`00Ool00004Ool20002Ool20003Ool30000
17oo001oogoo0P0000Aoo`00000000=oo`@000=oo`D000Aoo`<000Eoo`@000=oo`800003Ool00000
00Qoo`H001Aoo`00@Woo00<007ooOol0?Woo00<07gooOol0ogoo`Woo00<007ooOol0?Woo00D007oo
Oomoo`0002=oo`03001oogoo025oo`H001Aoo`00@Woo0`00?Woo00<07gooOol0ogoo`Woo00<007oo
Ool0?Goo1P00;Goo00<007ooOol05goo1P0057oo0012Ool00`00Oomoo`0oOol00`0OOomoo`3oOoo1
Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo041oo`0301moogoo0?mool1oo`03001oogoo
08Yoo`H001Aoo`00@Woo00<007ooOol0@Goo00<07gooOol0ogoo_goo00<007ooOol02Woo1W`017oo
1W`017oo1W`017oo1W`0G7oo1P0057oo0012Ool00`00Oomoo`12Ool00`0OOomoo`3oOonnOol00`00
Oomoo`2:Ool6000DOol0049oo`03001oogoo049oo`0301moogoo0?mookioo`03001oogoo08Yoo`H0
01Aoo`00@Woo00<007ooOol0@goo00<07gooOol0ogoo_Goo00<007ooOol0RWoo1P0057oo0012Ool0
0`00Oomoo`14Ool00`0OOomoo`3oOonlOol00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo04Eo
o`0301moogoo0?mook]oo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0AWoo00<07gooOol0
ogoo^Woo00<007ooOol0?goo0`000goo1@0017oo1@000Woo0`0000Aoo`000000009oo`D002Moo`H0
01Aoo`00@Woo00<007ooOol0Agoo00<07gooOol0ogoo^Goo00<007ooOol0?Woo00D007ooOomoo`00
00=oo`03001oogoo00Moo`03001oogoo00=oo`05001oogooOol00002Ool00`00Oomoo`0ZOol6000D
Ool0049oo`03001oogoo04Qoo`0301moogoo0?mookQoo`03001oogoo03ioo`05001oogooOol00003
Ool00`00Oomoo`07Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00<007ooOol0:Woo1P0057oo
0012Ool00`00Oomoo`18Ool00`0OOomoo`3oOonhOol00`00Oomoo`0nOol01@00Oomoogoo00000goo
00<007ooOol01goo00<007ooOol00goo00D007ooOomoo`00009oo`H002Moo`H001Aoo`00@Woo00<0
07ooOol0BGoo00<07gooOol0ogoo]goo00<007ooOol0?Woo00D007ooOomoo`0000=oo`8000Qoo`03
001oogoo00=oo`80009oo`04001oogoo0004Ool00`00Oomoo`0UOol6000DOol0049oo`03001oogoo
04Yoo`0301moogoo0?mookIoo`03001oogoo03ioo`05001oogooOol00002Ool2000017oo00000000
0goo0`0017oo0P0000=oo`00000017oo1000:7oo1P0057oo0012Ool00`00Oomoo`1;Ool00`0OOomo
o`3oOoneOol00`00Oomoo`0nOol01@00Oomoogoo0000Agoo1P0057oo0012Ool00`00Oomoo`1<Ool0
0`0OOomoo`3oOondOol00`00Oomoo`0mOol3000017oo0000000037oo00<007ooOol0=goo1P0057oo
0012Ool00`00Oomoo`1=Ool00`0OOomoo`3oOoncOol00`00Oomoo`2:Ool6000DOol0049oo`03001o
ogoo04ioo`0301moogoo0?mook9oo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0CWoo00<0
7gooOol0ogoo/Woo00<007ooOol0RWoo1P0057oo0012Ool3001?Ool00`0OOomoo`3oOonaOol00`00
Oomoo`2:Ool6000DOol0049oo`03001oogoo051oo`0301moogoo0?mook1oo`03001oogoo08Yoo`H0
01Aoo`00@Woo00<007ooOol0DGoo00<07gooOol0ogoo[goo00<007ooOol0RWoo1P0057oo0012Ool0
0`00Oomoo`1BOol00`0OOomoo`3oOon^Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo05=o
o`0301moogoo0?moojeoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0E7oo00<07gooOol0
ogoo[7oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`1EOol00`0OOomoo`3oOon[Ool00`00
Oomoo`2:Ool6000DOol0049oo`03001oogoo05Eoo`0301moogoo0?mooj]oo`03001oogoo08Yoo`H0
01Aoo`00@Woo00<007ooOol0EWoo00<07gooOol0ogooZWoo00<007ooOol0RWoo1P0057oo0012Ool0
0`00Oomoo`1GOol00`0OOomoo`3oOonYOol00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo05Qo
o`0301moogoo0?moojQoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0FGoo00<07gooOol0
ogooYgoo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`1JOol00`0OOomoo`3oOonVOol00`00
Oomoo`2:Ool6000DOol0049oo`03001oogoo05]oo`0301moogoo0?moojEoo`03001oogoo08Yoo`H0
01Aoo`00@Woo00<007ooOol0Fgoo00<07gooOol0ogooYGoo00<007ooOol0RWoo1P0057oo0012Ool3
001LOol00`0OOomoo`3oOonTOol00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo05eoo`0301mo
ogoo0?mooj=oo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0GWoo00<07gooOol0ogooXWoo
00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`1OOol00`0OOomoo`3oOonQOol00`00Oomoo`2:
Ool6000DOol0049oo`03001oogoo061oo`0301moogoo0?mooj1oo`03001oogoo08Yoo`H001Aoo`00
@Woo00<007ooOol0HGoo0P0OogooX7oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`1SOol0
0`0OOomoo`3oOonMOol00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo06Aoo`0301moogoo0?mo
oiaoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0IGoo00<07gooOol0ogooVgoo00<007oo
Ool0RWoo1P0057oo000NOol40005Ool20005Ool40004Ool40008Ool00`00Oomoo`1VOol00`0OOomo
o`3oOonJOol00`00Oomoo`2:Ool6000DOol001eoo`03001oogoo009oo`03001oogoo009oo`8000Ao
o`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`05Ool00`00Oomoo`1WOol00`0OOomoo`3o
OonIOol00`00Oomoo`2:Ool6000DOol001eoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo
009oo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo06Qoo`807omooiUoo`03001oogoo08Yo
o`H001Aoo`007Goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol01Goo
00<007ooOol01Goo1000JGoo00<07gooOol0ogooUWoo00<007ooOol0RWoo1P0057oo000MOol00`00
Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool01000Oomoogoo100027oo00<007ooOol0Jgoo
00<07gooOol0ogooUGoo00<007ooOol0RWoo1P0057oo000MOol00`00Oomoo`02Ool00`00Oomoo`08
Ool00`00Oomoo`02Ool01@00Oomoogoo00002goo00<007ooOol0K7oo00<07gooOol0ogooU7oo00<0
07ooOol0RWoo1P0057oo000MOol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool01@00
Oomoogoo00002goo00<007ooOol0KGoo0P0OogooU7oo00<007ooOol0RWoo1P0057oo000NOol4000<
Ool40004Ool50007Ool00`00Oomoo`1_Ool201ooOonBOol00`00Oomoo`2:Ool6000DOol0049oo`03
001oogoo075oo`0301moogoo0?moohmoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0LWoo
0P0OogooSgoo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`1dOol201ooOon=Ool00`00Oomo
o`2:Ool6000DOol0049oo`03001oogoo07Ioo`807omooh]oo`03001oogoo08Yoo`H001Aoo`00@Woo
0`00N7oo0P0OogooRGoo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`1jOol201ooOon7Ool0
0`00Oomoo`2:Ool6000DOol0049oo`03001oogoo07aoo`807omoohEoo`03001oogoo08Yoo`H001Ao
o`00@Woo00<007ooOol0OWoo0P0OogooPgoo00<007ooOol0?Goo1P000Woo0P000Woo0P000goo1000
0goo1@0017oo1@0017oo0`0017oo1@000goo10000goo0`0000Aoo`00000000Ioo`H001Aoo`00@Woo
00<007ooOol0P7oo0P0OogooPGoo00<007ooOol0?Woo00D007ooOomoo`0000=oo`04001oogoo0003
Ool00`00Oomoo`02Ool01@00Oomoogoo00001Woo00<007ooOol01Woo00D007ooOomoo`0000Eoo`03
001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`05Ool6000DOol0049o
o`03001oogoo089oo`807omoogmoo`03001oogoo03ioo`03001oogoo00Ioo`8000Aoo`03001oogoo
00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo
009oo`05001oogooOol00003Ool00`00Oomoo`05Ool6000DOol0049oo`03001oogoo08Aoo`807omo
ogeoo`03001oogoo03ioo`03001oo`0000Ioo`8000Aoo`03001oogoo00Ioo`03001oogoo00Aoo`H0
00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00
Oomoo`05Ool6000DOol0049oo`03001oogoo08Ioo`807omoog]oo`03001oogoo03ioo`<000Eoo`04
001oogoo0003Ool01000Oomoogoo0P000goo0P001Goo00<007ooOol00Woo00D007ooOomoo`0000Uo
o`03001oogoo009oo`03001oogoo009oo`04001oogooOol20002Ool00`00Oomoo`05Ool6000DOol0
049oo`<008Qoo`807omoogUoo`03001oogoo03ioo`03001oo`0000Aoo`80009oo`8000=oo`<00004
Ool007ooOol2000017oo000000000goo10000goo1@0017oo0`001Goo10000goo0P0000=oo`000000
27oo1P0057oo0012Ool00`00Oomoo`2:Ool301ooOomfOol00`00Oomoo`0nOol01@00Oomoogoo0000
8goo00<007ooOol08Goo1P0057oo0012Ool00`00Oomoo`2=Ool201ooOomdOol00`00Oomoo`0mOol6
000]Ool00`00Oomoo`0GOol6000DOol0049oo`03001oogoo08moo`<07omoog5oo`03001oogoo08Yo
o`H001Aoo`00@Woo00<007ooOol0TWoo0`0OogooKWoo00<007ooOol0RWoo1P0057oo0012Ool00`00
Oomoo`2EOol401ooOomZOol00`00Oomoo`0:OolV01mJOol6000DOol0049oo`03001oogoo09Uoo`@0
7omoofIoo`03001oogoo08Yoo`H001Aoo`00@Woo0`00WGoo100OogooHWoo00<007ooOol0RWoo1P00
57oo0012Ool00`00Oomoo`2QOol401ooOomNOol00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo
0:Eoo`D07omooeUoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0ZWoo1P0OogooDgoo00<0
07ooOol0RWoo1P0057oo0012Ool00`00Oomoo`2`Ool601ooOom=Ool00`00Oomoo`0mOol30006Ool3
00000goo00000002Ool50003Ool40004Ool300000goo00000002Ool5000OOol6000DOol0049oo`03
001oogoo0;Ioo`H07omoodMoo`03001oogoo03ioo`03001oogoo00Aoo`04001oogooOol20002Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000goo0P001Goo00<007ooOol07goo1P0057oo
0012Ool3002lOol701ooOom0Ool00`00Oomoo`0nOol00`00Oomoo`04Ool00`00Oomoo`02Ool01000
Oomoo`001goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol07goo1P00
57oo0012Ool00`00Oomoo`33Ool701ooOoliOol00`00Oomoo`0nOol00`00Ool00005Ool50002Ool6
0002Ool00`00Oomoo`06Ool50005Ool00`00Oomoo`0OOol6000DOol0049oo`03001oogoo0<Yoo`H0
7omooc=oo`03001oogoo03ioo`<000Aoo`03001oogoo009oo`04001oogoo0004Ool01000Oomoo`00
0goo0P000Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol07goo1P0057oo000UOol40005
Ool20005Ool50008Ool00`00Oomoo`3@Ool701ooOol/Ool00`00Oomoo`0nOol00`00Ool00005Ool4
0004Ool40004Ool300000goo001oo`02Ool40006Ool00`00Oomoo`0OOol6000DOol002Aoo`03001o
ogoo009oo`03001oogoo009oo`8000Moo`03001oogoo00Qoo`03001oogoo0=Moo`L07omoobEoo`03
001oogoo03ioo`05001oogooOol0000UOol00`00Oomoo`0OOol6000DOol002Aoo`03001oogoo009o
o`03001oogoo00]oo`03001oogoo00Qoo`@00=eoo`L07omooaioo`03001oogoo03eoo`H002Aoo`80
025oo`H001Aoo`0097oo00<007ooOol00Woo00<007ooOol02goo00<007ooOol027oo00<007ooOol0
iGoo200Oogoo5Woo00<007ooOol0RWoo1P0057oo000TOol00`00Oomoo`02Ool00`00Oomoo`0;Ool0
0`00Oomoo`08Ool00`00Oomoo`3]Ool801ooOol>Ool00`00Oomoo`2:Ool6000DOol002Aoo`03001o
ogoo009oo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo0?Eoo`T07omoo`Eoo`03001oogoo
08Yoo`H001Aoo`0097oo00<007ooOol00Woo00<007ooOol02Goo0`002Woo00<007ooOol0oWoo2P0O
nWoo00<007ooOol0RWoo1P0057oo000UOol4000>Ool00`00Oomoo`08Ool00`00Oomoo`3oOol9Ool;
01o_Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooaAoo``07n=oo`03001oogoo08Yo
o`H001Aoo`00@Woo00<007ooOol0ogoo87oo6P0ObGoo00<007ooOol0RWoo1P0057oo0012Ool00`00
Oomoo`3oOoljOolA01nhOol00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mood]oobD07i=o
o`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0ogooL7oo;P0OIGoo00<007ooOol0RWoo1P00
57oo0012Ool00`00Oomoo`3oOonNOol/01liOol00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo
0?mooomoo`Aoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0
RWoo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001o
ogoo0?mooomoo`Aoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007oo
Ool0RWoo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03
001oogoo0?mooomoo`Aoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<0
07ooOol0RWoo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool00`00Oomoo`0G
Ool0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo08Yoo`03001oogoo01Moo`00@Woo00<007oo
Ool0ogooogoo17oo00<007ooOol0RWoo00<007ooOol05goo0012Ool00`00Oomoo`3oOoooOol4Ool0
0`00Oomoo`2:Ool00`00Oomoo`0GOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo08Yoo`03
001oogoo01Moo`00@Woo00<007ooOol0ogooogoo17ooSP006Goo0012Ool00`00Oomoo`3oOoooOon[
Ool0049oo`03001oogoo0?mooomooj]oo`00@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomo
o`08Ool00g`0Oomoo`3oOoooOonPOol0049oo`03001oogoo00Uoo`03O01oogoo0?mooomooimoo`00
@Woo00<007ooOol02Woo0W`0ogooogooWgoo0012Ool00`00Oomoo`0<Ool00g`0Oomoo`3oOoooOonL
Ool0049oo`03001oogoo0?mooomooj]oo`00@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomo
o`3oOoooOon[Ool0049oo`<0011oo`03O01oogoo0?mooomooiQoo`00@Woo00<007ooOol04Goo00=l
07ooOol0ogooogooUgoo0012Ool00`00Oomoo`0BOol00g`0Oomoo`3oOoooOonFOol0049oo`03001o
ogoo01=oo`03O01oogoo0?mooomooiEoo`00@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomo
o`3oOoooOon[Ool0049oo`03001oogoo0?mooomooj]oo`00@Woo00<007ooOol05goo00=l07ooOol0
ogooogooTGoo0012Ool00`00Oomoo`0HOol00g`0Oomoo`3oOoooOon@Ool0049oo`03001oogoo01Uo
o`03O01oogoo0?mooomoohmoo`00@Woo00<007ooOol06Woo00=l07ooOol0ogooogooSWoo0012Ool0
0`00Oomoo`3oOoooOon[Ool0049oo`03001oogoo0?mooomooj]oo`00@Woo00<007ooOol07Woo00=l
07ooOol0ogooogooRWoo0012Ool00`00Oomoo`0OOol00g`0Oomoo`3oOoooOon9Ool0049oo`03001o
ogoo021oo`9l0?mooomoohUoo`00@Woo00<007ooOol08Woo00=l07ooOol0ogooogooQWoo0012Ool0
0`00Oomoo`3oOoooOon[Ool0049oo`03001oogoo0?mooomooj]oo`00@Woo00<007ooOol09Woo0W`0
ogooogooPgoo0012Ool3000XOol2O03oOoooOon1Ool0049oo`03001oogoo02Yoo`9l0?mooomoogmo
o`00@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomoo`3oOoooOon[Ool0049oo`03001oogoo
02moo`9l0?mooomoogYoo`00@Woo00<007ooOol0<Goo0W`0ogooogooN7oo0012Ool00`00Oomoo`0c
Ool2O03oOoooOomfOol0049oo`03001oogoo0?mooomooj]oo`00@Woo00<007ooOol0>7oo0W`0ogoo
ogooLGoo0012Ool00`00Oomoo`0jOol2O03oOoooOom_Ool0049oo`03001oogoo03aoo`9l0?mooomo
ofeoo`00@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomoo`11Ool2O03oOoooOomXOol0049o
o`03001oogoo04=oo`9l0?mooomoofIoo`00@Woo00<007ooOol0AGoo0W`0ogooogooI7oo0012Ool3
001;Ool00g`0Oomoo`3oOoooOomMOol0049oo`03001oogoo04aoo`9l0?mooomooeeoo`00@Woo00<0
07ooOol0CWoo0g`0ogooogooFWoo0012Ool00`00Oomoo`1DOol3O03oOoooOomDOol0049oo`03001o
ogoo05Moo`=l0?mooomooe5oo`00@Woo00<007ooOol0GWoo0g`0ogooogooBWoo0012Ool00`00Oomo
o`1QOol3O03oOoooOom7Ool0049oo`03001oogoo06Qoo`=l0?mooomood1oo`00@Woo00<007ooOol0
Jgoo0g`0ogooogoo?Goo000UOol40005Ool20005Ool40009Ool00`00Oomoo`1bOol3O03oOoooOolf
Ool002Aoo`03001oogoo009oo`03001oogoo009oo`8000Aoo`03001oogoo009oo`03001oogoo00Io
o`03001oogoo07Eoo`=l00Aoo`=l0?mooomoobaoo`0097oo00<007ooOol00Woo00<007ooOol03Goo
00<007ooOol01Woo00<007ooOol0Ogoo0g`0ogooogoo:Goo000TOol00`00Oomoo`02Ool00`00Oomo
o`0=Ool00`00Oomoo`06Ool40025Ool6O03oOoooOolOOol002Aoo`03001oogoo009oo`03001oogoo
00Uoo`@000Uoo`03001oogoo091oo`=l0?mooomooaQoo`0097oo00<007ooOol00Woo00<007ooOol0
2Goo00<007ooOol02Woo00<007ooOol0Tgoo0g`017oo0g`0ogooogoo3Woo000TOol00`00Oomoo`02
Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`2MOol3O003Ool3O03oOoooOol5Ool002Eo
o`@000aoo`D000Qoo`03001oogoo0:Ioo`=l0?mooomoo`9oo`00@Woo00<007ooOol0[Goo1W`0ogoo
mgoo0012Ool00`00Oomoo`2gOol6O03oOoo]Ool0049oo`03001oogoo0<5oo`=l0?moonIoo`00@Woo
00<007ooOol0a7oo0g`017oo0g`0ogoog7oo0012Ool3003>Ool3O004Ool3O03oOooBOol0049oo`03
001oogoo0=Qoo`=l00Aoo`=l0?moolQoo`00@Woo00<007ooOol0hWoo0g`017oo0g`0ogoo_Woo0012
Ool00`00Oomoo`3/Ool3O004Ool3O03oOondOol0049oo`03001oogoo0?Ioo`=l00Aoo`=l0?moojYo
o`00@Woo00<007ooOol0ogoo0Goo0g`017oo1W`0ogooWGoo0012Ool00`00Oomoo`3oOolBOol6O03o
OonCOol0049oo`03001oogoo0?mooaaoo`Il00Aoo`Il0?moogmoo`00@Woo0`00ogoo<7oo1W`017oo
1W`017oo1W`0ogooHGoo0012Ool00`00Oomoo`3oOom>Ool6O004Ool6O004Ool6O004Ool3O03oOoll
Ool0049oo`03001oogoo0?moofmoo`=l00Aoo`Il00Aoo`Il00Aoo`Il00Aoo`=l0?mooaAoo`00@Woo
00<007ooOol0ogooUgoo0g`017oo1W`017oo1W`017oo1W`017oo1W`017oo0W`0hWoo0012Ool00`00
Oomoo`3oOoo8Ool2O03POol0049oo`03001oogoo0?mooomooj]oo`00@Woo00<007ooOol0ogooogoo
Zgoo0012Ool3003oOoooOon[Ool0049oo`03001oogoo0?mooomooj]oo`00@Woo00<007ooOol0ogoo
ogooZgoo0012Ool00`00Oomoo`3oOoooOon[Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`
Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003o
OoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003hOol30004Ool40003Ool300001Goo00000000
Ool01@001Goo0`0017oo0`0000Aoo`00001oo`<00004Ool000000003Ool30008Ool50002Ool30000
17oo000000000goo0`0017oo0`0000Aoo`00001oo`80009oo`<0009oo`D00?moohMoo`00mgoo00D0
07ooOomoo`00009oo`03001oogoo009oo`05001oogooOol00003Ool01000Oomoo`0017oo00D007oo
Oomoo`0000=oo`04001oogoo0003Ool20003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Uo
o`03001oogoo00=oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo00@007ooOomoo`8000=o
o`04001oogoo0003Ool00`00Oomoo`3oOon:Ool00?Ioo`03001oogoo00Eoo`03001oogoo009oo`05
001oogooOol00003Ool00`00Oomoo`05Ool01@00Oomoogoo00001Woo00<007ooOol00Woo00D007oo
Oomoo`0000=oo`05001oogooOol0000=Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00<007oo
Ool017oo00<007ooOol00Woo00L007ooOomoo`00Ool00004Ool00`00Oomoo`3oOon:Ool00?Ioo`03
001oogoo00Eoo`03001oogoo009oo`05001oogooOol00003Ool01000Oomoogoo100017oo00<007oo
Ool01Goo1@000goo00D007ooOomoo`0000=oo`03001oogoo00]oo`03001oogoo00=oo`05001oogoo
Ool00003Ool00`00Oomoo`05Ool50003Ool30004Ool6003oOon7Ool004Qoo`<00:]oo`03001oogoo
00Eoo`03001oogoo009oo`04001oogooOol20002Ool01000Oomoo`0017oo00D007ooOomoo`0000Io
o`03001oogoo009oo`04001oogooOol20002Ool01@00Oomoogoo00003Goo00<007ooOol00goo0P00
0Woo00D007ooOomoo`0000Ioo`03001oogoo009oo`05001oogooOol00002Ool01@00Oomoogoo0000
17oo00<007ooOol0ogooQGoo0019Ool00`00Oomoo`2ZOol00`00Oomoo`06Ool40003Ool200000goo
00000004Ool50002Ool50004Ool40003Ool200000goo00000003Ool50008Ool30004Ool200000goo
00000003Ool50004Ool40004Ool00`00Ool000030002Ool4003oOon8Ool003aoo`D000Aoo`<00003
Ool007oo0:aoo`05001oogooOol0000KOol00`00Oomoo`0EOol00`00Oomoo`0IOol00`00Oomoo`0=
Ool00`00Oomoo`3oOonAOol003eoo`05001oogooOol00002Ool01000Oomoogoo0P00[Woo1000@Goo
00<007ooOol06Woo0P00ogooTgoo000mOol01@00Oomoogoo00000Woo00<007ooOol00Woo00<007oo
Ool0ogooogooY7oo000mOol01@00Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol0ogooogoo
Y7oo000mOol40003Ool01000Oomoogoo0P00ogooogooYWoo000mOol01@00Oomoogoo00000goo0`00
00=oo`000000ogooogooYGoo000mOol01@00Oomoogoo0000ogooogoo[Woo000lOol5003oOoooOon_
Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003o
OoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogoo
l7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00
\
\>"],
  ImageRangeCache->{{{0, 749}, {366.813, 0}} -> {-1.06507, -0.648943, \
0.00442282, 0.00442282}, {{18.375, 583.625}, {358.063, 8.6875}} -> \
{-0.392627, -2.82449, 0.00629642, 0.0105877}, {{583.625, 724.938}, {268.188, \
126.875}} -> {-14.9683, -2.1938, 0.0318446, 0.0265372}, {{595.375, 634.625}, \
{254, 206.938}} -> {-15.9524, -11.8034, 0.0334398, 0.108214}, {{595.375, \
634.625}, {188.063, 141}} -> {-15.9524, -17.5117, 0.0334398, 0.108214}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[77]="]
}, Open  ]],

Cell["\<\
 Here is assumed a variable intake I = {2.3 Exp[-0.05 t] Bq/day of Co-57  \
into compartment 1 (Blood).\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      cobalt, "\<Injection\>", "\<Continuous\>", "\<GraphicReport\>", {2.3\ \
Exp[\(-0.05\)\ t], \ t}, 1, 180, Log[2]/271]\)], "Input",
  CellLabel->"In[78]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.602818 0.202276 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .13738 -34 -6.28125 ]
[-0.0125 .13738 0 6.28125 ]
[-0.0125 .19827 -28 -6.28125 ]
[-0.0125 .19827 0 6.28125 ]
[-0.0125 .33965 -28 -6.28125 ]
[-0.0125 .33965 0 6.28125 ]
[-0.0125 .40054 -22 -6.28125 ]
[-0.0125 .40054 0 6.28125 ]
[-0.0125 .54193 -22 -6.28125 ]
[-0.0125 .54193 0 6.28125 ]
[-0.0125 .60282 -10 -6.28125 ]
[-0.0125 .60282 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .13738 m
.00625 .13738 L
s
gsave
-0.0125 .13738 -95 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.005) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .19827 m
.00625 .19827 L
s
gsave
-0.0125 .19827 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .33965 m
.00625 .33965 L
s
gsave
-0.0125 .33965 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .40054 m
.00625 .40054 L
s
gsave
-0.0125 .40054 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .54193 m
.00625 .54193 L
s
gsave
-0.0125 .54193 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .60282 m
.00625 .60282 L
s
gsave
-0.0125 .60282 -71 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .05688 m
.00375 .05688 L
s
0 .0925 m
.00375 .0925 L
s
0 .11777 m
.00375 .11777 L
s
0 .15339 m
.00375 .15339 L
s
0 .16693 m
.00375 .16693 L
s
0 .17866 m
.00375 .17866 L
s
0 .18901 m
.00375 .18901 L
s
0 .25916 m
.00375 .25916 L
s
0 .29478 m
.00375 .29478 L
s
0 .32005 m
.00375 .32005 L
s
0 .35567 m
.00375 .35567 L
s
0 .36921 m
.00375 .36921 L
s
0 .38094 m
.00375 .38094 L
s
0 .39129 m
.00375 .39129 L
s
0 .46143 m
.00375 .46143 L
s
0 .49705 m
.00375 .49705 L
s
0 .52232 m
.00375 .52232 L
s
0 .55794 m
.00375 .55794 L
s
0 .57148 m
.00375 .57148 L
s
0 .58322 m
.00375 .58322 L
s
0 .59356 m
.00375 .59356 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Continuous) show
129.000 12.813 moveto
(intake) show
165.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .52132 m
.06042 .54967 L
.08838 .56565 L
.1161 .57751 L
.13894 .58493 L
.17363 .59305 L
.19066 .59591 L
.20509 .59785 L
.21861 .59933 L
.23213 .60051 L
.24589 .60145 L
.25791 .60209 L
.2705 .60259 L
.28171 .60292 L
.29122 .60312 L
.30107 .60325 L
.30591 .60329 L
.31101 .60331 L
.31991 .60332 L
.32817 .60328 L
.33546 .60321 L
.34305 .6031 L
.35104 .60295 L
.36617 .60256 L
.37845 .60212 L
.39076 .60158 L
.41107 .60041 L
.4324 .59877 L
.45309 .59671 L
.48561 .59232 L
.51254 .5874 L
.53436 .58239 L
.57035 .57177 L
.60327 .55897 L
.65429 .53206 L
.6928 .50497 L
.72646 .47583 L
.75391 .44805 L
.77693 .42199 L
.79861 .39528 L
.81732 .37084 L
.8353 .34642 L
.85111 .32458 L
.86513 .3052 L
.87895 .28634 L
.89134 .26984 L
.90252 .2554 L
.91372 .24141 L
.92388 .22913 L
.9341 .21718 L
Mistroke
.94344 .20657 L
.95199 .19706 L
.96068 .18756 L
.96867 .17891 L
.97619 .17082 L
Mfstroke
0 0 1 r
[ ] 0 setdash
.02381 .17587 m
.08838 .27115 L
.13894 .33323 L
.17363 .3675 L
.20509 .39248 L
.23623 .41167 L
.26149 .42343 L
.28313 .43103 L
.30107 .43579 L
.31822 .43918 L
.33295 .4413 L
.34088 .44218 L
.34785 .44282 L
.35567 .44339 L
.36263 .44378 L
.3691 .44405 L
.37574 .44424 L
.37944 .44431 L
.38285 .44436 L
.38906 .44439 L
.39482 .44436 L
.39996 .44429 L
.40545 .44418 L
.41107 .44402 L
.4217 .4436 L
.43088 .44311 L
.44998 .44173 L
.46606 .44017 L
.4801 .43849 L
.50809 .43415 L
.53436 .4287 L
.57228 .41798 L
.60548 .40529 L
.65325 .38042 L
.69332 .35245 L
.72505 .32506 L
.75368 .29612 L
.77758 .26886 L
.79796 .24355 L
.81742 .21785 L
.83438 .19453 L
.85084 .17145 L
.86541 .15096 L
.87841 .13288 L
.8913 .11537 L
.90291 .10007 L
.91343 .08668 L
.92399 .07369 L
.93362 .06223 L
.94333 .05101 L
Mistroke
.95222 .04099 L
.96038 .03195 L
.96868 .02287 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[78]:=",
  ImageSize->{600, 294.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;^0001Ka000`40O003h00Oogooogool7oo003o
OoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogoo
l7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00
ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomo
oo1oo`00ogooogool7oo001<Ool5000eOol5001;Ool4000dOol50003Ool4000_Ool50004Ool40013
Ool40004Ool4000/Ool50003Ool40004Ool4000WOol50004Ool40004Ool4003=Ool004ioo`03001o
ogoo03Eoo`05001oogooOol0001:Ool00`00Oomoo`02Ool00`00Oomoo`0cOol00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`0/Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol0
?goo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo02]oo`03001oogoo009oo`03001oogoo
009oo`04001oogoo0004Ool00`00Oomoo`0TOol01@00Oomoogoo00000goo00<007ooOol00Woo00@0
07ooOol000Aoo`03001oogoo0<Yoo`00CWoo00<007ooOol0=Woo00<007ooOol0D7oo00<007ooOol0
<goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0;Goo00<007ooOol017oo00<007ooOol0
0Woo00<007ooOol0A7oo00@007ooOol000Aoo`03001oogoo02]oo`03001oogoo009oo`03001oogoo
009oo`04001oogoo0004Ool00`00Oomoo`0UOol00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomo
o`0017oo00<007ooOol0bWoo001>Ool00`00Oomoo`0gOol00`00Oomoo`1?Ool00`00Oomoo`0cOol0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0^Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Oomoo`14Ool01000Oomoo`0017oo00<007ooOol0:goo00<007ooOol00Woo00<007ooOol00Woo
00@007ooOol000Aoo`03001oogoo02Ioo`03001oogoo00=oo`03001oogoo009oo`04001oogoo0004
Ool00`00Oomoo`3:Ool004ioo`03001oogoo03Qoo`03001oogoo04Yoo`@003Ioo`03001oogoo009o
o`03001oogoo009oo`03001oogoo02moo`03001oogoo009oo`03001oogoo009oo`03001oogoo041o
o`@000=oo`03001oogoo009oo`03001oogoo02]oo`03001oogoo009oo`03001oogoo009oo`04001o
ogoo0004Ool00`00Oomoo`0WOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<0
07ooOol0bWoo001>Ool00`00Oomoo`0iOol00`00Oomoo`19Ool00`00Oomoo`0gOol00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`0`Ool01@00Oomoogoo000017oo00<007ooOol0@7oo00<007oo
Ool017oo00<007ooOol00Woo00<007ooOol0:goo00<007ooOol00Woo00<007ooOol00Woo00@007oo
Ool000Aoo`03001oogoo02Qoo`05001oogooOol00004Ool01000Oomoo`0017oo00<007ooOol0bWoo
001<Ool3000gOol01@00Oomoogoo0000Bgoo00<007ooOol0=Goo0`0017oo00<007ooOol00Woo00<0
07ooOol0;7oo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo041oo`03001oogoo00Ao
o`03001oogoo009oo`03001oogoo02Uoo`<000Aoo`03001oogoo009oo`04001oogoo0004Ool00`00
Oomoo`0TOol01@00Oomoogoo00000goo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo0<Yo
o`00CWoo00<007ooOol0=Woo0`00C7oo1@00=Goo00<007ooOol00goo1000<7oo0`001Goo1000@goo
1@000goo1000;Woo00<007ooOol00goo100017oo1000:7oo0`001Goo100017oo1000cGoo003oOooo
Ooo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooc]oo`<00;9oo`00ogoo
ogoo?Goo00<007ooOol0/7oo003oOoooOol[Ool300000goo00000002Ool300000goo00000004Ool0
0`00Oomoo`02Ool5002YOol00?mooomoobYoo`04001oogooOol20002Ool01000Oomoogoo0P0017oo
00<007oo00000goo00<007ooOol00Woo00<007ooOol0YWoo0012Oooo003H000?Ool00`00Oomoo`02
Ool01000Oomoo`0017oo00<007ooOol00Woo00<007oo000027oo00<007ooOol0YWoo0012Ool00`00
Oomoo`08Ool00`00Oomoo`0iOol00`00Oomoo`0POol00`00Oomoo`0FOol00`00Oomoo`0@Ool00`00
Oomoo`0=Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00
Oomoo`0iOol00`00Oomoo`0POol00`00Oomoo`0EOol00`00Oomoo`0AOol00`00Oomoo`0<Ool00`00
Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0iOol00`00
Oomoo`0?Ool00`00Oomoo`02Ool01000Oomoogoo1@000goo00D007ooOomoo`0000=oo`@00:Uoo`00
@Woo00<007ooOol027oo00<007ooOol0>Goo00<007ooOol087oo00<007ooOol05Woo00<007ooOol0
47oo00<007ooOol03Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol01goo00<007ooOol0
1Woo00<007ooOol0>Goo00<007ooOol087oo00<007ooOol05Goo00<007ooOol04Goo00<007ooOol0
37oo00<007ooOol02goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01Woo00<007ooOol0
>Goo00<007ooOol03goo00@007ooOomoo`80009oo`03001oogoo009oo`05001oogooOol00003Ool0
1000Oomoo`0017oo00<007ooOol0YWoo0012Ool00`00Oomoo`08Ool00`00Oomoo`0iOol00`00Oomo
o`1<Ool00`00Oomoo`0iOol00`00Oomoo`0iOol00`00Oomoo`1<Ool00`00Oomoo`0hOol00`00Oomo
o`0iOol00`00Oomoo`0@Ool300000goo001oo`02Ool40003Ool3000017oo000000000Woo1@00Z7oo
0012Ool00`00Oomoo`3oOooYOol00`00Oomoo`2nOol0049oo`03001oogoo0?moonQoo`800<1oo`00
@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomoo`3oOoo9Ool00`0OOomoo`3NOol0049oo`03
001oogoo0?moolQoo`0301moogoo0=moo`00@Woo00<007ooOol0ogooagoo00<07gooOol0h7oo0012
Ool00`00Oomoo`3oOoo7Ool00`0OOomoo`3POol0049oo`03001oogoo0?moolIoo`0301moogoo0>5o
o`00@Woo00<007ooOol0ogooaGoo00<07gooOol0hWoo0012Ool00`00Oomoo`3oOoo4Ool00`0OOomo
o`3SOol0049oo`03001oogoo0?mool=oo`0301moogoo0>Aoo`00@Woo00<007ooOol0ogoo`Woo00<0
7gooOol0iGoo0012Ool00`00Oomoo`3oOoo1Ool00`0OOomoo`3VOol0049oo`03001oogoo0?mool1o
o`0301moogoo0>Moo`00@Woo00<007ooOol0ogoo_goo00<07gooOol0j7oo0012Ool00`00Oomoo`3o
OonnOol00`0OOomoo`3YOol0049oo`03001oogoo0?mookeoo`0301moogoo0>Yoo`00@Woo00<007oo
Ool0ogoo_7oo00<07gooOol0jgoo0012Ool00`00Oomoo`3oOonlOol00`0OOomoo`3[Ool0049oo`03
001oogoo0?mook]oo`0301moogoo0>aoo`00@Woo00<007ooOol0ogoo^Woo00<07gooOol0kGoo0012
Ool00`00Oomoo`3oOoniOol00`0OOomoo`3^Ool0049oo`03001oogoo0?mookQoo`0301moogoo0>mo
o`00@Woo0`00ogoo]goo00<07gooOol0l7oo0012Ool00`00Oomoo`3oOonfOol00`0OOomoo`3aOol0
049oo`03001oogoo0?mookEoo`0301moogoo0?9oo`00@Woo00<007ooOol0ogoo]7oo00<07gooOol0
lgoo0012Ool00`00Oomoo`3oOondOol00`0OOomoo`3cOol0049oo`03001oogoo0?mook=oo`0301mo
ogoo0?Aoo`00@Woo00<007ooOol0ogoo/Woo00<07gooOol0mGoo0012Ool00`00Oomoo`3oOonbOol0
0`0OOomoo`3eOol0049oo`03001oogoo0?mook5oo`0301moogoo0?Ioo`00@Woo00<007ooOol0ogoo
/7oo00<07gooOol0mgoo0012Ool00`00Oomoo`3oOon_Ool00`0OOomoo`3hOol0049oo`03001oogoo
0?moojioo`0301moogoo0?Uoo`00@Woo00<007ooOol0ogoo[Woo00<07gooOol0nGoo0012Ool00`00
Oomoo`3oOon]Ool00`0OOomoo`3jOol0049oo`03001oogoo0?moojaoo`0301moogoo0?]oo`00@Woo
00<007ooOol0ogooZgoo00<07gooOol0o7oo0012Ool3003oOonZOol00`0OOomoo`3mOol0049oo`03
001oogoo0?moojUoo`0301moogoo0?ioo`00@Woo00<007ooOol0ogooZGoo00<07gooOol0oWoo0012
Ool00`00Oomoo`3oOonXOol00`0OOomoo`3oOol0049oo`03001oogoo0?moojMoo`0301moogoo0?mo
o`5oo`00@Woo00<007ooOol0ogooYWoo00<07gooOol0ogoo0Woo0012Ool00`00Oomoo`3oOonUOol0
0`0OOomoo`3oOol3Ool0049oo`03001oogoo0?moojAoo`0301moogoo0?moo`Aoo`00@Woo00<007oo
Ool0ogooY7oo00<07gooOol0ogoo17oo0012Ool00`00Oomoo`3oOonSOol00`0OOomoo`3oOol5Ool0
049oo`03001oogoo0?mooj9oo`0301moogoo0?moo`Ioo`00@Woo00<007ooOol0ogooXGoo00<07goo
Ool0ogoo1goo0012Ool3003oOonPOol00`0OOomoo`3oOol8Ool0049oo`03001oogoo0?mooimoo`03
01moogoo0?moo`Uoo`00@Woo00<007ooOol0ogooWgoo00<07gooOol0ogoo2Goo0012Ool00`00Oomo
o`3oOonNOol00`0OOomoo`3oOol:Ool0049oo`03001oogoo0?mooieoo`0301moogoo06Uoohd001Ao
o`00@Woo00<007ooOol0ogooW7oo00<07gooOol0JWooS@0057oo0012Ool00`00Oomoo`3oOonLOol0
0`0OOomoo`1ZOon=000DOol001Ioo`@000Eoo`8000Eoo`@000Aoo`@000Aoo`@000Qoo`03001oogoo
0?mooi]oo`0301moogoo06]oohd001Aoo`005Goo00<007ooOol00Woo00<007ooOol00Woo0P0017oo
00<007ooOol00Woo00@007ooOol000Aoo`04001oogoo0004Ool00`00Oomoo`05Ool00`00Oomoo`3o
OonJOol00`0OOomoo`1VOonC000DOol001Eoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo
009oo`04001oogoo0004Ool00`00Oomoo`05Ool00`00Oomoo`05Ool4003oOonIOol00`0OOomoo`1V
Ool00`00Oomoo`2:Ool6000DOol001Eoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009o
o`04001oogoo0004Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`3oOonIOol00`0OOomo
o`1WOol00`00Oomoo`2:Ool6000DOol001Eoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo
009oo`04001oogoo0004Ool01000Oomoogoo100027oo00<007ooOol0ogooV7oo00<07gooOol0J7oo
00<007ooOol0RWoo1P0057oo000EOol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool0
1000Oomoo`0017oo00D007ooOomoo`0000]oo`03001oogoo0?mooiQoo`0301moogoo06Qoo`03001o
ogoo08Yoo`H001Aoo`005Goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00@007oo
Ool000Aoo`05001oogooOol0000;Ool00`00Oomoo`3oOonGOol00`0OOomoo`1YOol00`00Oomoo`2:
Ool6000DOol001Ioo`@000aoo`@000Aoo`@000Aoo`D000Moo`03001oogoo0?mooiIoo`0301moogoo
06Yoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0ogooUWoo00<07gooOol0JWoo00<007oo
Ool0RWoo1P0057oo0012Ool00`00Oomoo`3oOonEOol00`0OOomoo`1[Ool00`00Oomoo`2:Ool6000D
Ool0049oo`<00?mooiAoo`0301moogoo06aoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0
ogooU7oo00<07gooOol0K7oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`3oOonCOol00`0O
Oomoo`1]Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooi9oo`0301moogoo06ioo`03
001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0ogooTGoo00<07gooOol0Kgoo00<007ooOol0RWoo
1P0057oo0012Ool00`00Oomoo`3oOonAOol00`0OOomoo`1_Ool00`00Oomoo`2:Ool6000DOol0049o
o`<00?mooi1oo`0301moogoo071oo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0ogooSgoo
00<07gooOol0LGoo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`3oOon?Ool00`0OOomoo`1a
Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?moohioo`0301moogoo079oo`03001oogoo
08Yoo`H001Aoo`00@Woo00<007ooOol0ogooSGoo00<07gooOol0Lgoo00<007ooOol0RWoo1P0057oo
0012Ool00`00Oomoo`08Ool00`0OOomoo`3oOon2Ool00`0OOomoo`1cOol00`00Oomoo`2:Ool6000D
Ool0049oo`<000Uoo`0301moogoo0?mooh1oo`0301moogoo03Moo`03O01oogoo03Yoo`03001oogoo
08Yoo`H001Aoo`00@Woo00<007ooOol02Goo00<07gooOol0ogooOgoo00<07gooOol0=goo00=l07oo
Ool0>goo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`0:Ool00`0OOomoo`3oOommOol00`0O
Oomoo`0gOol00g`0Oomoo`0lOol00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo00]oo`0301mo
ogoo0?moogaoo`0301moogoo03Ioo`03O01oogoo03eoo`03001oogoo08Yoo`H001Aoo`00@Woo00<0
07ooOol037oo00<07gooOol0ogooNWoo00<07gooOol0Mgoo00<007ooOol0RWoo1P0057oo0012Ool3
000<Ool00`0OOomoo`3oOomiOol00`0OOomoo`1hOol00`00Oomoo`2:Ool6000DOol0049oo`03001o
ogoo00eoo`0301moogoo0?moogQoo`0301moogoo07Qoo`03001oogoo08Yoo`H001Aoo`007Woo1000
1Goo0P001Goo100017oo1@001goo00<007ooOol03Woo00<07gooOol0ogooMWoo00<07gooOol0=Goo
00=l07ooOol0@Goo00<007ooOol0?Goo1P000Woo0P000Woo0P000goo10000goo1@0017oo1@0017oo
0`0017oo1@000goo10000goo0`0000Aoo`00000000Ioo`H001Aoo`007Goo00<007ooOol00Woo00<0
07ooOol00Woo0P0017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol0
3Woo00<07gooOol0ogooMGoo00<07gooOol0=Goo00=l07ooOol0@Woo00<007ooOol0?Woo00D007oo
Oomoo`0000=oo`04001oogoo0003Ool00`00Oomoo`02Ool01@00Oomoogoo00001Woo00<007ooOol0
1Woo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool0
0`00Oomoo`05Ool6000DOol001eoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo00Moo`@000ioo`0301moogoo0?moogAoo`0301moogoo03Eoo`03O01o
ogoo049oo`03001oogoo03ioo`03001oogoo00Ioo`8000Aoo`03001oogoo00Ioo`03001oogoo00Ao
o`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`05001oogooOol0
0003Ool00`00Oomoo`05Ool6000DOol001eoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo011oo`0301moogoo0?moog9oo`0301mo
ogoo03Eoo`03O01oogoo04=oo`03001oogoo03ioo`03001oo`0000Ioo`8000Aoo`03001oogoo00Io
o`03001oogoo00Aoo`H000=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`05001o
ogooOol00003Ool00`00Oomoo`05Ool6000DOol001eoo`03001oogoo009oo`03001oogoo00Qoo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo011oo`0301moogoo0?moog5o
o`0301moogoo03Eoo`03O01oogoo04Aoo`03001oogoo03ioo`<000Eoo`04001oogoo0003Ool01000
Oomoogoo0P000goo0P001Goo00<007ooOol00Woo00D007ooOomoo`0000Uoo`03001oogoo009oo`03
001oogoo009oo`04001oogooOol20002Ool00`00Oomoo`05Ool6000DOol001eoo`03001oogoo009o
o`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo015o
o`0301moogoo0?moofmoo`0301moogoo07eoo`03001oogoo03ioo`03001oo`0000Aoo`80009oo`80
00=oo`<00004Ool007ooOol2000017oo000000000goo10000goo1@0017oo0`001Goo10000goo0P00
00=oo`00000027oo1P0057oo000MOol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool0
1000Oomoogoo0`002Goo00<007ooOol04Woo00<07gooOol0ogooKWoo00<07gooOol0OGoo00<007oo
Ool0?Woo00D007ooOomoo`0002=oo`03001oogoo025oo`H001Aoo`007Woo100037oo10001Woo00<0
07ooOol01goo00<007ooOol04goo00<07gooOol0ogooK7oo00<07gooOol0=7oo00=l07ooOol0Agoo
00<007ooOol0?Goo1P00;Goo00<007ooOol05goo1P0057oo0012Ool00`00Oomoo`0COol00`0OOomo
o`3oOom[Ool00`0OOomoo`0dOol00g`0Oomoo`18Ool00`00Oomoo`2:Ool6000DOol0049oo`03001o
ogoo01Aoo`0301moogoo0?moofUoo`0301moogoo03Aoo`03O01oogoo04Uoo`03001oogoo08Yoo`H0
01Aoo`00@Woo00<007ooOol05Goo00<07gooOol0ogooJ7oo00<07gooOol0<goo00=l07ooOol0BWoo
00<007ooOol02Woo1W`017oo1W`017oo1W`017oo1W`0G7oo1P0057oo0012Ool00`00Oomoo`0EOol0
0`0OOomoo`3oOomWOol00`0OOomoo`0cOol00g`0Oomoo`1;Ool00`00Oomoo`2:Ool6000DOol0049o
o`03001oogoo01Ioo`0301moogoo0?moofEoo`0301moogoo089oo`03001oogoo08Yoo`H001Aoo`00
@Woo00<007ooOol05goo00<07gooOol0ogooHgoo00<07gooOol0Pgoo00<007ooOol0RWoo1P0057oo
0012Ool00`00Oomoo`0GOol00`0OOomoo`3oOomROol00`0OOomoo`24Ool00`00Oomoo`2:Ool6000D
Ool0049oo`03001oogoo01Qoo`0301moogoo0?moof5oo`0301moogoo03=oo`03O01oogoo04ioo`03
001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol06Goo00<07gooOol0ogooGgoo00<07gooOol0<goo
00=l07ooOol0Cgoo00<007ooOol0?goo0`000goo1@0017oo1@000Woo0`0000Aoo`000000009oo`D0
02Moo`H001Aoo`00@Woo00<007ooOol06Woo00<07gooOol0ogooGGoo00<07gooOol0=7oo00=l07oo
Ool0Cgoo00<007ooOol0?Woo00D007ooOomoo`0000=oo`03001oogoo00Moo`03001oogoo00=oo`05
001oogooOol00002Ool00`00Oomoo`0ZOol6000DOol0049oo`03001oogoo01Yoo`0301moogoo0?mo
oeaoo`0301moogoo03Aoo`03O01oogoo051oo`03001oogoo03ioo`05001oogooOol00003Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00<007ooOol0:Woo1P0057oo0012Ool0
0`00Oomoo`0KOol00`0OOomoo`3oOomJOol00`0OOomoo`0dOol00g`0Oomoo`1AOol00`00Oomoo`0n
Ool01@00Oomoogoo00000goo00<007ooOol01goo00<007ooOol00goo00D007ooOomoo`00009oo`H0
02Moo`H001Aoo`00@Woo00<007ooOol077oo00<07gooOol0ogooF7oo00<07gooOol0RGoo00<007oo
Ool0?Woo00D007ooOomoo`0000=oo`8000Qoo`03001oogoo00=oo`80009oo`04001oogoo0004Ool0
0`00Oomoo`0UOol6000DOol0049oo`03001oogoo01aoo`0301moogoo0?mooeQoo`0301moogoo08Uo
o`03001oogoo03ioo`05001oogooOol00002Ool2000017oo000000000goo0`0017oo0P0000=oo`00
000017oo1000:7oo1P0057oo0012Ool00`00Oomoo`0MOol00`0OOomoo`3oOomFOol00`0OOomoo`2:
Ool00`00Oomoo`0nOol01@00Oomoogoo0000Agoo1P0057oo0012Ool00`00Oomoo`0NOol00`0OOomo
o`3oOomDOol00`0OOomoo`0cOol00g`0Oomoo`1EOol00`00Oomoo`0mOol3000017oo0000000037oo
00<007ooOol0=goo1P0057oo0012Ool00`00Oomoo`0OOol00`0OOomoo`3oOomBOol00`0OOomoo`0c
Ool00g`0Oomoo`1FOol00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo01moo`0301moogoo0?mo
oe5oo`0301moogoo03=oo`03O01oogoo05Moo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0
87oo00<07gooOol0ogooD7oo00<07gooOol0<goo00=l07ooOol0Egoo00<007ooOol0RWoo1P0057oo
0012Ool00`00Oomoo`0QOol00`0OOomoo`3oOom>Ool00`0OOomoo`0cOol00g`0Oomoo`1HOol00`00
Oomoo`2:Ool6000DOol0049oo`03001oogoo025oo`0301moogoo0?moodeoo`0301moogoo08moo`03
001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol08Woo00<07gooOol0ogooBgoo00<07gooOol0T7oo
00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`0SOol00`0OOomoo`3oOom:Ool00`0OOomoo`2@
Ool00`00Oomoo`2:Ool6000DOol0049oo`<002=oo`0301moogoo0?moodUoo`0301moogoo03=oo`03
O01oogoo05]oo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol097oo00<07gooOol0ogooAgoo
00<07gooOol0<goo00=l07ooOol0G7oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`0UOol0
0`0OOomoo`3oOom5Ool00`0OOomoo`0cOol00g`0Oomoo`1MOol00`00Oomoo`2:Ool6000DOol0049o
o`03001oogoo02Ioo`0301moogoo0?moodAoo`0301moogoo03=oo`03O01oogoo05eoo`03001oogoo
08Yoo`H001Aoo`00@Woo00<007ooOol09Woo00<07gooOol0ogoo@goo00<07gooOol0<goo00=l07oo
Ool0GWoo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`0WOol00`0OOomoo`3oOom1Ool00`0O
Oomoo`2EOol00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo02Qoo`0301moogoo0?moocmoo`03
01moogoo09Ioo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0:Goo00<07gooOol0ogoo?Goo
00<07gooOol0Ugoo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`0YOol00`0OOomoo`3oOolm
Ool00`0OOomoo`0cOol00g`0Oomoo`1QOol00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo02Yo
o`0301moogoo0?mooc]oo`0301moogoo03=oo`03O01oogoo069oo`03001oogoo08Yoo`H001Aoo`00
@Woo00<007ooOol0:goo00<07gooOol0ogoo>Goo00<07gooOol0<goo00=l07ooOol0Hgoo00<007oo
Ool0RWoo1P0057oo0012Ool00`00Oomoo`0/Ool00`0OOomoo`3oOolgOol00`0OOomoo`0dOol00g`0
Oomoo`1SOol00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo02eoo`0301moogoo0?moocEoo`03
01moogoo03Aoo`03O01oogoo06Aoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0;Goo00<0
7gooOol0ogoo=7oo00<07gooOol0W7oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`0^Ool0
0`0OOomoo`3oOolcOol00`0OOomoo`2LOol00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo02mo
o`0301moogoo0?mooc5oo`0301moogoo09eoo`03001oogoo08Yoo`H001Aoo`00@Woo0`00<7oo00<0
7gooOol0ogoo;goo00<07gooOol0=7oo00=l07ooOol0Igoo00<007ooOol0RWoo1P0057oo0012Ool0
0`00Oomoo`0aOol00`0OOomoo`3oOol]Ool00`0OOomoo`0dOol00g`0Oomoo`1XOol00`00Oomoo`2:
Ool6000DOol0049oo`03001oogoo035oo`0301moogoo0?moobaoo`0301moogoo03Aoo`03O01oogoo
06Uoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0<Woo00<07gooOol0ogoo:Woo00<07goo
Ool0=Goo00=l07ooOol0JGoo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`0cOol00`0OOomo
o`3oOolXOol00`0OOomoo`0eOol00g`0Oomoo`1ZOol00`00Oomoo`2:Ool6000DOol0049oo`03001o
ogoo03Aoo`0301moogoo0?moobIoo`0301moogoo0:=oo`03001oogoo08Yoo`H001Aoo`00@Woo00<0
07ooOol0=Goo00<07gooOol0ogoo97oo00<07gooOol0Y7oo00<007ooOol0RWoo1P0057oo0012Ool0
0`00Oomoo`0eOol00`0OOomoo`3oOolSOol00`0OOomoo`2UOol00`00Oomoo`2:Ool6000DOol0049o
o`03001oogoo03Ioo`0301moogoo0?moob5oo`0301moogoo03Ioo`03O01oogoo06eoo`03001oogoo
08Yoo`H001Aoo`00@Woo00<007ooOol0=goo00<07gooOol0ogoo7goo00<07gooOol0=Woo00=l07oo
Ool0KWoo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`0hOol00`0OOomoo`3oOolMOol00`0O
Oomoo`0fOol00g`0Oomoo`1_Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo03Uoo`0301mo
ogoo0?mooa]oo`0301moogoo03Moo`03O01oogoo06moo`03001oogoo08Yoo`H001Aoo`00@Woo0`00
>Goo00<07gooOol0ogoo6Woo00<07gooOol0=goo00=l07ooOol0L7oo00<007ooOol0RWoo1P0057oo
0012Ool00`00Oomoo`0jOol00`0OOomoo`3oOolHOol00`0OOomoo`2[Ool00`00Oomoo`2:Ool6000D
Ool0049oo`03001oogoo03]oo`0301moogoo0?mooaIoo`0301moogoo0:aoo`03001oogoo08Yoo`H0
01Aoo`00@Woo00<007ooOol0?7oo00<07gooOol0ogoo57oo00<07gooOol0[Goo00<007ooOol0RWoo
1P0057oo0012Ool00`00Oomoo`0mOol00`0OOomoo`3oOolBOol00`0OOomoo`0hOol00g`0Oomoo`1c
Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo03eoo`0301moogoo0?mooa5oo`0301moogoo
03Qoo`03O01oogoo07Aoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0?Woo00<07gooOol0
ogoo3Woo0P0O>Woo00=l07ooOol0MGoo00<007ooOol0RWoo1P0057oo000NOol40005Ool20005Ool4
0004Ool40008Ool00`00Oomoo`0oOol00`0OOomoo`3oOol<Ool00`0OOomoo`0jOol00g`0Oomoo`1e
Ool00`00Oomoo`0mOol60002Ool20002Ool20003Ool40003Ool50004Ool50004Ool30004Ool50003
Ool40003Ool3000017oo000000001Woo1P0057oo000MOol00`00Oomoo`02Ool00`00Oomoo`02Ool2
0004Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol01Goo00<007ooOol0@7oo00<07goo
Ool0ogoo2Woo00<07gooOol0>Woo00=l07ooOol0MWoo00<007ooOol0?Woo00D007ooOomoo`0000=o
o`04001oogoo0003Ool00`00Oomoo`02Ool01@00Oomoogoo00001Woo00<007ooOol01Woo00D007oo
Oomoo`0000Eoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`05
Ool6000DOol001eoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo045oo`0301moogoo0?moo`Qoo`0301moogoo0;Aoo`03001oogoo
03ioo`03001oogoo00Ioo`8000Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03
001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`05
Ool6000DOol001eoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00Eo
o`03001oogoo00Eoo`@0045oo`0301moogoo0?moo`Ioo`0301moogoo0;Eoo`03001oogoo03ioo`03
001oo`0000Ioo`8000Aoo`03001oogoo00Ioo`03001oogoo00Aoo`H000=oo`03001oogoo00Moo`03
001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`05Ool6000DOol001eo
o`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`04001oogooOol40008Ool00`00Oomo
o`13Ool00`0OOomoo`3oOol4Ool00`0OOomoo`2fOol00`00Oomoo`0nOol30005Ool01000Oomoo`00
0goo00@007ooOomoo`8000=oo`8000Eoo`03001oogoo009oo`05001oogooOol00009Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool01000Oomoogoo0P000Woo00<007ooOol01Goo1P0057oo000MOol00`00
Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool01@00Oomoogoo00002goo00<007ooOol0A7oo
00<07gooOol0ogoo0Woo00<07gooOol0?7oo00=l07ooOol0N7oo00<007ooOol0?Woo00<007oo0000
17oo0P000Woo0P000goo0`0000Aoo`00Oomoo`800004Ool000000003Ool40003Ool50004Ool30005
Ool40003Ool200000goo00000008Ool6000DOol001eoo`03001oogoo009oo`03001oogoo00Qoo`03
001oogoo009oo`05001oogooOol0000;Ool00`00Oomoo`15Ool00`0OOomoo`3nOol201lnOol00g`0
Oomoo`1iOol00`00Oomoo`0nOol01@00Oomoogoo00008goo00<007ooOol08Goo1P0057oo000NOol4
000<Ool40004Ool50007Ool00`00Oomoo`16Ool00`0OOomoo`3lOol00`0OOomoo`0mOol00g`0Oomo
o`1jOol00`00Oomoo`0mOol6000]Ool00`00Oomoo`0GOol6000DOol0049oo`03001oogoo04Moo`03
01moogoo0?Yoo`0301moogoo03ioo`03O01oogoo07Yoo`03001oogoo08Yoo`H001Aoo`00@Woo00<0
07ooOol0B7oo00<07gooOol0n7oo00<07gooOol0?Woo00=l07ooOol0Ngoo00<007ooOol0RWoo1P00
57oo0012Ool30019Ool00`0OOomoo`3eOol201noOol00`00Oomoo`0:OolV01mJOol6000DOol0049o
o`03001oogoo04Yoo`0301moogoo0?=oo`0301moogoo0;moo`03001oogoo08Yoo`H001Aoo`00@Woo
00<007ooOol0Bgoo00<07gooOol0l7oo0P0O`Woo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomo
o`1<Ool00`0OOomoo`3^Ool00`0OOomoo`11Ool00g`0Oomoo`1nOol00`00Oomoo`2:Ool6000DOol0
049oo`03001oogoo04eoo`0301moogoo0>]oo`807d=oo`03O01oogoo07moo`03001oogoo08Yoo`H0
01Aoo`00@Woo00<007ooOol0CWoo00<07gooOol0jGoo00<07gooOol0@Woo00=l07ooOol0P7oo00<0
07ooOol0RWoo1P0057oo0012Ool3001?Ool00`0OOomoo`3WOol00`0OOomoo`13Ool00g`0Oomoo`20
Ool00`00Oomoo`0mOol30006Ool300000goo00000002Ool50003Ool40004Ool300000goo00000002
Ool5000OOol6000DOol0049oo`03001oogoo051oo`807nEoo`807dEoo`03O01oogoo085oo`03001o
ogoo03ioo`03001oogoo00Aoo`04001oogooOol20002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1000Oomoo`000goo0P001Goo00<007ooOol07goo1P0057oo0012Ool00`00Oomoo`1BOol00`0OOomo
o`3QOol00`0OOomoo`39Ool00`00Oomoo`0nOol00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomo
o`001goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol07goo1P0057oo
0012Ool00`00Oomoo`1COol00`0OOomoo`3NOol201o<Ool00`00Oomoo`0nOol00`00Ool00005Ool5
0002Ool60002Ool00`00Oomoo`06Ool50005Ool00`00Oomoo`0OOol6000DOol0049oo`03001oogoo
05Aoo`807meoo`0301moogoo0<aoo`03001oogoo03ioo`<000Aoo`03001oogoo009oo`04001oogoo
0004Ool01000Oomoo`000goo0P000Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol07goo
1P0057oo0012Ool00`00Oomoo`1FOol00`0OOomoo`3HOol201m8Ool00g`0Oomoo`24Ool00`00Oomo
o`0nOol00`00Ool00005Ool40004Ool40004Ool300000goo001oo`02Ool40006Ool00`00Oomoo`0O
Ool6000DOol0049oo`<005Moo`0301moogoo0=Ioo`0301moogoo04Moo`03O01oogoo08Eoo`03001o
ogoo03ioo`05001oogooOol0000UOol00`00Oomoo`0OOol6000DOol0049oo`03001oogoo05Qoo`80
7mAoo`807dUoo`03O01oogoo08Ioo`03001oogoo03eoo`H002Aoo`80025oo`H001Aoo`00@Woo00<0
07ooOol0FWoo00<07gooOol0cgoo0P0OBgoo00=l07ooOol0QWoo00<007ooOol0RWoo1P0057oo0012
Ool00`00Oomoo`1KOol00`0OOomoo`3<Ool201m<Ool00g`0Oomoo`27Ool00`00Oomoo`2:Ool6000D
Ool0049oo`03001oogoo05aoo`807lYoo`807mQoo`03001oogoo08Yoo`H001Aoo`00@Woo0`00GWoo
00<07gooOol0aGoo0P0OfWoo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`1OOol201o3Ool2
01oLOol00`00Oomoo`2:Ool6000DOol002Eoo`@000Eoo`8000Eoo`D000Qoo`03001oogoo065oo`03
01moogoo0;ioo`807e5oo`03O01oogoo08Yoo`03001oogoo08Yoo`H001Aoo`0097oo00<007ooOol0
0Woo00<007ooOol00Woo0P001goo00<007ooOol027oo00<007ooOol0HWoo0P0O_7oo0P0ODWoo00=l
07ooOol0Rgoo00<007ooOol0RWoo1P0057oo000TOol00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00
Oomoo`08Ool4001SOol00`0OOomoo`2gOol201mCOol00g`0Oomoo`2<Ool00`00Oomoo`2:Ool6000D
Ool002Aoo`03001oogoo009oo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo06Eoo`807kEo
o`807eAoo`03O01oogoo08eoo`03001oogoo08Yoo`H001Aoo`0097oo00<007ooOol00Woo00<007oo
Ool02goo00<007ooOol027oo00<007ooOol0Igoo0P0O/7oo0`0OEGoo00=l07ooOol0SWoo00<007oo
Ool0RWoo1P0057oo000TOol00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomo
o`1YOol00`0OOomoo`2[Ool201oYOol00`00Oomoo`2:Ool6000DOol002Aoo`03001oogoo009oo`03
001oogoo00Uoo`<000Yoo`03001oogoo06Yoo`807jQoo`<07n]oo`03001oogoo08Yoo`H001Aoo`00
9Goo10003Woo00<007ooOol027oo00<007ooOol0K7oo00<07gooOol0XWoo0`0OkWoo00<007ooOol0
RWoo1P0057oo0012Ool00`00Oomoo`1]Ool201nPOol201mMOol00g`0Oomoo`2AOol00`00Oomoo`2:
Ool6000DOol0049oo`03001oogoo06moo`807i]oo`<07eioo`03O01oogoo099oo`03001oogoo08Yo
o`H001Aoo`00@Woo00<007ooOol0LGoo0P0OUWoo0`0OH7oo00=l07ooOol0Tgoo00<007ooOol0RWoo
1P0057oo0012Ool00`00Oomoo`1cOol201n@Ool401mSOol00g`0Oomoo`2COol00`00Oomoo`2:Ool6
000DOol0049oo`03001oogoo07Eoo`807h]oo`<07fIoo`03O01oogoo09Aoo`03001oogoo08Yoo`H0
01Aoo`00@Woo00<007ooOol0Mgoo0`0OQ7oo100Oogoo0Goo00<007ooOol0RWoo1P0057oo0012Ool0
0`00Oomoo`1jOol201mnOol401ooOol5Ool00`00Oomoo`2:Ool00`00Oomoo`0GOol0049oo`03001o
ogoo07aoo`<07gQoo`<07fioo`03O01oogoo09Moo`03001oogoo08Yoo`03001oogoo01Moo`00@Woo
00<007ooOol0Ogoo0P0OLWoo100OL7oo00=l07ooOol0V7oo00<007ooOol0RWoo00<007ooOol05goo
0012Ool00`00Oomoo`21Ool401mZOol401mcOol00g`0Oomoo`2IOol00`00Oomoo`2:Ool00`00Oomo
o`0GOol0049oo`03001oogoo08Eoo`@07f1oo`H07gIoo`03O01oogoo09Yoo`03001oogoo08Yoo`03
001oogoo01Moo`00@Woo00<007ooOol0RGoo1P0OE7oo1P0ONgoo00=l07ooOol0VgooSP006Goo0012
Ool00`00Oomoo`2?Ool801m5Ool701ooOoo7Ool0049oo`03001oogoo09Moo`D07cUoo`L07omoolio
o`00@Woo00<007ooOol0W7oo2P0O77oo4`0OogooeGoo0012Ool00`00Oomoo`2VOolL01nOOol00g`0
Oomoo`3oOom6Ool0049oo`03001oogoo0?moof5oo`03O01oogoo0?moodMoo`00@Woo00<007ooOol0
ogooHGoo00=l07ooOol0ogooAgoo0012Ool00`00Oomoo`3oOomOOol2O03oOom:Ool0049oo`03001o
ogoo0?mooomooj]oo`00@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomoo`3oOoooOon[Ool0
049oo`03001oogoo0?mooe]oo`03O01oogoo0?moodeoo`00@Woo0`00ogooFWoo00=l07ooOol0ogoo
CWoo0012Ool00`00Oomoo`3oOomIOol00g`0Oomoo`3oOom?Ool0049oo`03001oogoo0?mooeUoo`03
O01oogoo0?moodmoo`00@Woo00<007ooOol0ogooF7oo00=l07ooOol0ogooD7oo0012Ool00`00Oomo
o`3oOoooOon[Ool0049oo`03001oogoo0?mooomooj]oo`00@Woo00<007ooOol0ogooE7oo00=l07oo
Ool0ogooE7oo0012Ool00`00Oomoo`3oOomDOol00g`0Oomoo`3oOomDOol0049oo`03001oogoo0?mo
oe9oo`9l0?mooeMoo`00@Woo00<007ooOol0ogooD7oo0W`0ogooFGoo0012Ool00`00Oomoo`3oOooo
Oon[Ool0049oo`03001oogoo0?mooomooj]oo`00@Woo00<007ooOol0ogooogooZgoo0012Ool00`00
Oomoo`3oOom=Ool00g`0Oomoo`3oOomKOol0049oo`03001oogoo0?moodaoo`03O01oogoo0?mooeao
o`00@Woo00<007ooOol0ogooBWoo0W`0ogooGgoo0012Ool00`00Oomoo`3oOom9Ool00g`0Oomoo`3o
OomOOol0049oo`<00?mooomooj]oo`00@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomoo`3o
Oom5Ool00g`0Oomoo`3oOomSOol0049oo`03001oogoo0?moodAoo`03O01oogoo0?moofAoo`00@Woo
00<007ooOol0ogoo@Woo0W`0ogooIgoo0012Ool00`00Oomoo`3oOom1Ool00g`0Oomoo`3oOomWOol0
049oo`03001oogoo0?mooomooj]oo`00@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomoo`3o
OolmOol00g`0Oomoo`3oOom[Ool0049oo`03001oogoo0?moocaoo`03O01oogoo0?moofaoo`00@Woo
00<007ooOol0ogoo>Woo0W`0ogooKgoo0012Ool30008Ool00g`0Oomoo`3oOol^Ool00g`0Oomoo`3o
Oom_Ool0049oo`03001oogoo00Uoo`03O01oogoo0?mooomooimoo`00@Woo00<007ooOol02Woo0W`0
ogooogooWgoo0012Ool00`00Oomoo`0<Ool00g`0Oomoo`3oOolVOol00g`0Oomoo`3oOomcOol0049o
o`03001oogoo0?mooc=oo`9l0?moogIoo`00@Woo00<007ooOol0ogoo<Woo00=l07ooOol0ogooMWoo
0012Ool00`00Oomoo`0@Ool00g`0Oomoo`3oOolNOol00g`0Oomoo`3oOomgOol0049oo`03001oogoo
015oo`03O01oogoo0?mooomooiMoo`009Goo10001Goo0P001Goo10002Goo00<007ooOol04Woo0W`0
ogoo67oo00=l07ooOol0ogooO7oo000TOol00`00Oomoo`02Ool00`00Oomoo`02Ool20004Ool00`00
Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0DOol00g`0Oomoo`3oOolCOol2O03oOomoOol002Ao
o`03001oogoo009oo`03001oogoo00eoo`03001oogoo00Ioo`@00?moobMoo`9l0?mooh5oo`0097oo
00<007ooOol00Woo00<007ooOol03Goo00<007ooOol01Woo00<007ooOol0ogooogooZgoo000TOol0
0`00Oomoo`02Ool00`00Oomoo`09Ool40009Ool00`00Oomoo`0HOol00g`0Oomoo`3oOoooOon@Ool0
02Aoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo01Uoo`9l0?moo`Qo
o`03O01oogoo0?moohEoo`0097oo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol02Woo00<0
07ooOol06goo00=l07ooOol0ogoo0goo0W`0ogooR7oo000UOol4000<Ool50008Ool00`00Oomoo`0L
Ool00g`0Oomoo`3oOol2O03oOon:Ool0049oo`03001oogoo0?mooomooj]oo`00@Woo0`008Goo00=l
07ooOol0mWoo00=l07ooOol0ogooSGoo0012Ool00`00Oomoo`0ROol00g`0Oomoo`3cOol2O03oOon@
Ool0049oo`03001oogoo02=oo`9l0?1oo`=l0?mooi9oo`00@Woo00<007ooOol09Goo00=l07ooOol0
ogooogooPgoo0012Ool00`00Oomoo`3oOolAOol00g`0Oomoo`3oOonGOol0049oo`03001oogoo02Uo
o`9l0>=oo`9l0?mooiYoo`00@Woo00<007ooOol0:goo0W`0ggoo0W`0ogooW7oo0012Ool3000]Ool2
O03GOol2O03oOonROol0049oo`03001oogoo0?moo`Eoo`9l0?moojAoo`00@Woo00<007ooOol0<goo
0W`0cGoo0W`0ogooYWoo0012Ool00`00Oomoo`0eOol2O036Ool00g`0Oomoo`3oOonZOol0049oo`03
001oogoo03Moo`03O01oogoo0<5oo`9l0?moojeoo`00@Woo0`00?7oo0W`0^goo0W`0ogoo[goo0012
Ool00`00Oomoo`0nOol4O02`Ool3O03oOoneOol0049oo`03001oogoo0>moo`=l0?mookQoo`00@Woo
00<007ooOol0AWoo0g`0Wgoo0g`0ogoo_goo0012Ool00`00Oomoo`19Ool3O02IOol3O03oOoo2Ool0
049oo`<004moo`=l08Uoo`Il0?moolUoo`00@Woo00<007ooOol0DWoo0g`017oo0g`0MWoo1G`0ogoo
dgoo000dOol50009Ool00`00Oomoo`1LOol3O01ZOol4O004Ool00g`0Oomoo`3oOooFOol003Ioo`03
001oogoo00Uoo`03001oogoo06=oo`Il00Aoo`9l04ioo`Il00Aoo`9l0?moon5oo`00=Woo00<007oo
Ool02Goo1000KWoo17`017oo1W`017oo1W`067oo1W`017oo1W`017oo1W`0ogoolGoo000fOol00`00
Oomoo`09Ool00`00Oomoo`2;Ool6O004Ool6O03oOoooOol@Ool003Ioo`03001oogoo00Uoo`03001o
ogoo0?mooomooj]oo`00=Woo00<007ooOol02Goo00<007ooOol0ogooogooZgoo000dOol3000;Ool0
0`00Oomoo`3oOoooOon[Ool003Ioo`03001oogoo00Uoo`03001oogoo0?mooomooj]oo`00@Woo00<0
07ooOol0ogooogooZgoo0012Ool00`00Oomoo`3oOoooOon[Ool00?mooomooo1oo`00ogooogool7oo
003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogoo
ogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003aOol30004Ool40003Ool30000
17oo000000000goo0`0017oo1@000Woo0`0000Aoo`00000000=oo`800003Ool00000009oo`@000Eo
o`800004Ool00000Ool50006Ool50002Ool3000017oo000000000goo0`0017oo0`0000Aoo`00001o
o`80009oo`<0009oo`D00?mooh1oo`00l7oo00D007ooOomoo`00009oo`03001oogoo009oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00<007ooOol00goo00<007ooOol00goo00D007ooOomo
o`0000=oo`03001oogoo0080009oo`03001oogoo009oo`05001oogooOol00002Ool20002Ool00`00
Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00D007ooOomoo`00
009oo`04001oogooOol20003Ool01000Oomoo`000goo00<007ooOol0ogooPgoo003_Ool00`00Oomo
o`05Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Uoo`03001oogoo00=o
o`05001oogooOol00003Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00D007ooOomoo`0000=o
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00=oo`05001oogooOol00003Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo0?mooh=oo`00kgoo00<0
07ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol00009Ool00`00Oomo
o`03Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`03001oogoo009oo`05001oogooOol0
0003Ool01000Oomoogoo100027oo00<007ooOol00goo00D007ooOomoo`0000=oo`03001oogoo00Eo
o`D000=oo`<000Aoo`H00?mooh1oo`00B7oo0`00Y7oo00<007ooOol01Goo00<007ooOol00Woo00@0
07ooOomoo`80009oo`05001oogooOol00009Ool00`00Oomoo`03Ool20002Ool01@00Oomoogoo0000
0goo00@007ooOol000Aoo`05001oogooOol00003Ool01000Oomoo`0017oo00<007ooOol01Goo00<0
07ooOol00goo0P000Woo00D007ooOomoo`0000Ioo`03001oogoo009oo`05001oogooOol00002Ool0
1@00Oomoogoo000017oo00<007ooOol0ogooOWoo0019Ool00`00Oomoo`2SOol00`00Oomoo`06Ool4
0003Ool200000goo00000003Ool50004Ool30004Ool200000goo00000003Ool20002Ool20003Ool4
0003Ool20002Ool20003Ool50005Ool30004Ool200000goo00000003Ool50004Ool40004Ool00`00
Ool000030002Ool4003oOon1Ool003aoo`D000Aoo`<00003Ool007oo0:Eoo`05001oogooOol0000C
Ool00`00Oomoo`17Ool00`00Oomoo`0=Ool00`00Oomoo`3oOon:Ool003eoo`05001oogooOol00002
Ool01000Oomoogoo0P00Ygoo10007Goo00<007ooOol0;goo00<007ooOol06Woo0P00ogooS7oo000m
Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol0ogooogooY7oo000mOol01@00Oomo
ogoo00000Woo00<007ooOol00Woo00<007ooOol0ogooogooY7oo000mOol40003Ool01000Oomoogoo
0P00ogooogooYWoo000mOol01@00Oomoogoo00000goo0`0000=oo`000000ogooogooYGoo000mOol0
1@00Oomoogoo0000ogooogoo[Woo000lOol5003oOoooOon_Ool00?mooomooo1oo`00ogooogool7oo
003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogoo
ogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1o
o`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00\
\>"],
  ImageRangeCache->{{{0, 749}, {366.813, 0}} -> {-1.06507, -0.648943, \
0.00442282, 0.00442282}, {{18.375, 583.625}, {358.063, 8.6875}} -> \
{-0.392627, -3.35062, 0.00629642, 0.013145}, {{583.625, 724.938}, {268.188, \
126.875}} -> {-14.9683, -2.1938, 0.0318446, 0.0265372}, {{595.375, 634.625}, \
{254, 206.938}} -> {-15.9524, -11.8034, 0.0334398, 0.108214}, {{595.375, \
634.625}, {188.063, 141}} -> {-15.9524, -17.5117, 0.0334398, 0.108214}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[78]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ingestion", "SubsubsectionIcon"],

Cell[TextData[{
  StyleBox["Here is computed the retention all compartment  ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  "for a single intake by ingestion ",
  Cell[BoxData[
      \(I\_0\)]],
  "= 1 of Co-60 (\[Lambda] = 5.27 y) ",
  StyleBox["f1 = 0.05 ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  "in t =0",
  StyleBox[".",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["\:f35f",
    FormatType->StandardForm]
}], "MathCaption"],

Cell[BoxData[
    \(lambda\  = \ Log[2]/\((5.27*365.24)\); fn1\  = \ 0.05;\)], "Input",
  CellLabel->"In[79]:="],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
        element, "\<Ingestion\>", \ "\<Acute\>", "\<BioassayTable\>", 1, fn1, 
        180, lambda] // Chop\)], "Input",
  CellLabel->"In[80]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nstart intake"\), \("Urine\n24 hours"\), \("Faecal\n\
24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "0.013624951907567113`", "0.27199432883869606`", 
            "0.7140206729830303`"},
          {"2", "0.007254805597013346`", "0.36966197431914977`", 
            "0.33684681258635185`"},
          {"3", "0.0027618078500181924`", "0.1866976804736687`", 
            "0.14726604382399358`"},
          {"4", "0.0015322156830239243`", "0.07726230016902748`", 
            "0.06841850538206166`"},
          {"5", "0.001136583438852855`", "0.029958321848542465`", 
            "0.03729896626695612`"},
          {"6", "0.0009590033866396843`", "0.011367394927771312`", 
            "0.02495913859883956`"},
          {"7", "0.0008444877783174634`", "0.004319360518802417`", 
            "0.01978630385694713`"},
          {"8", "0.0007533662323098534`", "0.0016831473847287541`", 
            "0.017342666254993713`"},
          {"9", "0.000674889916757487`", "0.0006987045920522929`", 
            "0.015962827583874673`"},
          {"10", "0.0006056291246357982`", "0.000327557194231672`", 
            "0.015023893908465622`"},
          {"20", "0.00021818715757100722`", "0.000042216094151492636`", 
            "0.010592576004313308`"},
          {"30", "0.00009370472153105133`", "0.000017516985259201007`", 
            "0.008909160132648536`"},
          {"40", "0.00005204784822717604`", "9.32943569518924`*^-6", 
            "0.008083176027764953`"},
          {"50", "0.00003667330643387536`", "6.369820910672123`*^-6", 
            "0.007555703374708201`"},
          {"60", "0.00002980284226628062`", "5.094286006529317`*^-6", 
            "0.007148073988986088`"},
          {"70", "0.000025828137215555515`", "4.385742166907765`*^-6", 
            "0.0068013241680392545`"},
          {"80", "0.00002296359985052643`", "3.889281577912315`*^-6", 
            "0.006494383085242021`"},
          {"90", "0.000020626249725634007`", "3.4896895741480926`*^-6", 
            "0.006218360015534419`"},
          {"100", "0.0000186130784295909`", "3.147408487650526`*^-6", 
            "0.005968442152083475`"},
          {"180", "8.883893275727961`*^-6", "1.4982450095269274`*^-6", 
            "0.004607790312002115`"},
          {"200", "7.560372823669832`*^-6", "1.2740470736315825`*^-6", 
            "0.004384583613393251`"},
          {"300", "3.986656285957359`*^-6", "6.690514396502216`*^-7", 
            "0.0036066002244158494`"},
          {"400", "2.7057984912325263`*^-6", "4.5268477716251764`*^-7", 
            "0.00310768353179668`"},
          {"500", "2.1441127795547293`*^-6", "3.581555732884084`*^-7", 
            "0.0027238628563417307`"},
          {"600", "1.8208528502335635`*^-6", "3.0396845525596377`*^-7", 
            "0.0024018193829603756`"},
          {"700", "1.5876505152021713`*^-6", "2.6497834206557263`*^-7", 
            "0.0021222584649381216`"},
          {"800", "1.3973924386546062`*^-6", "2.3320586254917228`*^-7", 
            "0.001876580511334852`"},
          {"900", "1.233965185889309`*^-6", "2.0592642853775875`*^-7", 
            "0.00165975145705199`"},
          {"1000", "1.0908819180520335`*^-6", "1.8204670730841342`*^-7", 
            "0.0014681000615082308`"},
          {"2000", "3.1986113167967303`*^-7", "5.337825964266924`*^-8", 
            "0.0004305898996216268`"},
          {"3000", "9.381660372933985`*^-8", "1.565606614524076`*^-8", 
            "0.000126293813929323`"},
          {"4000", "2.751680128113906`*^-8", "4.591989511984022`*^-9", 
            "0.00003704250252798874`"},
          {"5000", "8.070792616640915`*^-9", "1.3468496839326954`*^-9", 
            "0.000010864720534166101`"},
          {"6000", "2.367197146515681`*^-9", "3.950366463317131`*^-10", 
            "3.1866678606916386`*^-6"},
          {"7000", "6.943087991277531`*^-10", "1.1586589346579255`*^-10", 
            "9.346629784384457`*^-7"},
          {"8000", "2.036436675784662`*^-10", "0", 
            "2.7414055102492556`*^-7"},
          {"9000", "0", "0", "8.040656734025028`*^-8"},
          {"10000", "0", "0", "2.3583581660103877`*^-8"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nstart intake", 
          "Urine\n24 hours", "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
  CellLabel->"Out[80]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Ingestion\>", \ "\<Constant\>", "\<GraphicReport\>", 1, 
      fn1, 180, lambda]\)], "Input",
  CellLabel->"In[81]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.608578 0.266848 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .07488 -28 -6.28125 ]
[-0.0125 .07488 0 6.28125 ]
[-0.0125 .15521 -28 -6.28125 ]
[-0.0125 .15521 0 6.28125 ]
[-0.0125 .2614 -28 -6.28125 ]
[-0.0125 .2614 0 6.28125 ]
[-0.0125 .34173 -22 -6.28125 ]
[-0.0125 .34173 0 6.28125 ]
[-0.0125 .42206 -22 -6.28125 ]
[-0.0125 .42206 0 6.28125 ]
[-0.0125 .52825 -22 -6.28125 ]
[-0.0125 .52825 0 6.28125 ]
[-0.0125 .60858 -10 -6.28125 ]
[-0.0125 .60858 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07488 m
.00625 .07488 L
s
gsave
-0.0125 .07488 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .15521 m
.00625 .15521 L
s
gsave
-0.0125 .15521 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .2614 m
.00625 .2614 L
s
gsave
-0.0125 .2614 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .34173 m
.00625 .34173 L
s
gsave
-0.0125 .34173 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .42206 m
.00625 .42206 L
s
gsave
-0.0125 .42206 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .52825 m
.00625 .52825 L
s
gsave
-0.0125 .52825 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .60858 m
.00625 .60858 L
s
gsave
-0.0125 .60858 -71 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .2022 m
.00375 .2022 L
s
0 .23554 m
.00375 .23554 L
s
0 .28253 m
.00375 .28253 L
s
0 .30039 m
.00375 .30039 L
s
0 .31587 m
.00375 .31587 L
s
0 .32952 m
.00375 .32952 L
s
0 .46905 m
.00375 .46905 L
s
0 .50239 m
.00375 .50239 L
s
0 .54938 m
.00375 .54938 L
s
0 .56724 m
.00375 .56724 L
s
0 .58272 m
.00375 .58272 L
s
0 .59637 m
.00375 .59637 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Constant) show
117.000 12.813 moveto
(intake) show
153.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .01472 m
.06042 .06488 L
.08838 .09652 L
.1161 .12067 L
.13894 .13584 L
.17363 .15269 L
.19066 .15888 L
.20509 .16332 L
.25791 .17516 L
.30107 .18201 L
.41107 .19703 L
.53436 .21183 L
.60117 .21747 L
.62785 .21917 L
.65279 .2205 L
.69387 .22227 L
.72628 .22341 L
.75283 .22427 L
.77742 .22503 L
.79833 .22568 L
.81821 .2263 L
.83552 .22684 L
.85077 .22732 L
.8657 .22779 L
.87902 .22821 L
.89097 .22858 L
.9029 .22895 L
.91369 .22928 L
.9245 .2296 L
.93434 .22989 L
.94334 .23015 L
.95245 .23041 L
.96082 .23064 L
.96851 .23085 L
.97619 .23105 L
s
0 0 1 r
[ ] 0 setdash
.02381 .33247 m
.08838 .44332 L
.13894 .50913 L
.17652 .54435 L
.20509 .56412 L
.23381 .57872 L
.2473 .58399 L
.2606 .58832 L
.28275 .59383 L
.30107 .59706 L
.3181 .5992 L
.32701 .60004 L
.3348 .60065 L
.34903 .60151 L
.3616 .60205 L
.36829 .60226 L
.37517 .60244 L
.38692 .60268 L
.39376 .60278 L
.39998 .60285 L
.4058 .60291 L
.41107 .60295 L
.421 .60301 L
.42604 .60304 L
.4313 .60306 L
.44159 .60309 L
.4505 .60311 L
.45836 .60312 L
.46654 .60313 L
.48054 .60315 L
.53436 .60319 L
.5716 .60321 L
.60548 .60323 L
.65493 .60325 L
.69467 .60326 L
.72619 .60327 L
.75465 .60327 L
.77844 .60328 L
.79872 .60328 L
.81811 .60329 L
.83501 .60329 L
.85141 .60329 L
.86594 .6033 L
.87891 .6033 L
.89176 .6033 L
.90335 .6033 L
.91383 .60331 L
.92438 .60331 L
.93398 .60331 L
.94367 .60331 L
Mistroke
.95255 .60331 L
.9607 .60332 L
.96899 .60332 L
.97619 .60332 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[81]:=",
  ImageSize->{600, 294.25},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[81]="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.619262 0.0848291 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .02546 -46.5 -6.625 ]
[-0.0125 .02546 0 6.625 ]
[-0.0125 .19512 -46 -6.28125 ]
[-0.0125 .19512 0 6.28125 ]
[-0.0125 .36477 -34 -6.28125 ]
[-0.0125 .36477 0 6.28125 ]
[-0.0125 .53443 -22 -6.28125 ]
[-0.0125 .53443 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02546 m
.00625 .02546 L
s
gsave
-0.0125 .02546 -107.5 -10.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.500 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.313 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
105.000 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .19512 m
.00625 .19512 L
s
gsave
-0.0125 .19512 -107 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00001) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .36477 m
.00625 .36477 L
s
gsave
-0.0125 .36477 -95 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .53443 m
.00625 .53443 L
s
gsave
-0.0125 .53443 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .117 m
.00375 .117 L
s
0 .14097 m
.00375 .14097 L
s
0 .15537 m
.00375 .15537 L
s
0 .1657 m
.00375 .1657 L
s
0 .17376 m
.00375 .17376 L
s
0 .18036 m
.00375 .18036 L
s
0 .18596 m
.00375 .18596 L
s
0 .19082 m
.00375 .19082 L
s
0 .28666 m
.00375 .28666 L
s
0 .31063 m
.00375 .31063 L
s
0 .32503 m
.00375 .32503 L
s
0 .33536 m
.00375 .33536 L
s
0 .34341 m
.00375 .34341 L
s
0 .35002 m
.00375 .35002 L
s
0 .35562 m
.00375 .35562 L
s
0 .36048 m
.00375 .36048 L
s
0 .45632 m
.00375 .45632 L
s
0 .48029 m
.00375 .48029 L
s
0 .49469 m
.00375 .49469 L
s
0 .50502 m
.00375 .50502 L
s
0 .51307 m
.00375 .51307 L
s
0 .51968 m
.00375 .51968 L
s
0 .52528 m
.00375 .52528 L
s
0 .53014 m
.00375 .53014 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Constant) show
117.000 12.813 moveto
(intake) show
153.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .58185 m
.06042 .59229 L
.08838 .59729 L
.1161 .60017 L
.13894 .60152 L
.15779 .60218 L
.17363 .60253 L
.18958 .60274 L
.20509 .60287 L
.21944 .60293 L
.23372 .60297 L
.24625 .60299 L
.25701 .603 L
.26883 .60301 L
.2752 .60301 L
.28092 .60302 L
.30107 .60302 L
.33501 .60303 L
.36579 .60304 L
.41107 .60307 L
.45102 .60309 L
.48098 .60312 L
.53436 .60317 L
.6058 .60323 L
.65542 .60327 L
.69308 .60329 L
.70978 .6033 L
.72615 .60331 L
.7414 .60331 L
.75476 .60331 L
.76709 .60331 L
.7778 .60332 L
.78805 .60332 L
.79874 .60332 L
.80824 .60332 L
.81796 .60332 L
.82683 .60332 L
.83574 .60332 L
.84369 .60332 L
.8508 .60332 L
.8584 .60332 L
.86504 .60332 L
.87166 .60332 L
.87857 .60332 L
.88494 .60332 L
.89145 .60332 L
.8973 .60332 L
.90262 .60332 L
.90833 .60332 L
.9134 .60332 L
Mistroke
.91846 .60332 L
.92382 .60332 L
.92877 .60332 L
.93391 .60332 L
.93901 .60332 L
.94368 .60332 L
.94822 .60332 L
.9523 .60332 L
.95637 .60332 L
.96073 .60332 L
.96476 .60332 L
.96898 .60332 L
.97272 .60332 L
.97619 .60332 L
Mfstroke
0 0 1 r
[ ] 0 setdash
.02381 .01472 m
.20509 .19224 L
.30107 .26062 L
.41107 .31714 L
.48498 .34448 L
.53436 .35856 L
.60287 .37279 L
.63172 .37701 L
.65536 .37973 L
.67446 .38148 L
.69343 .38286 L
.71037 .38382 L
.72677 .38454 L
.74071 .38501 L
.75461 .38536 L
.76768 .38561 L
.77929 .38578 L
.79007 .3859 L
.79954 .38598 L
.80955 .38604 L
.81819 .38608 L
.82671 .38611 L
.8355 .38613 L
.84355 .38615 L
.85168 .38616 L
.85895 .38617 L
.86548 .38617 L
.87248 .38618 L
.87863 .38618 L
.88474 .38618 L
.89118 .38618 L
.8971 .38618 L
.90319 .38618 L
.90866 .38618 L
.91365 .38618 L
.91901 .38618 L
.92378 .38618 L
.92854 .38618 L
.93361 .38619 L
.93829 .38619 L
.94316 .38619 L
.94799 .38619 L
.95243 .38619 L
.95675 .38619 L
.96063 .38619 L
.9645 .38619 L
.96867 .38619 L
.97233 .38619 L
.97619 .38619 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{600, 294.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H00019R000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo
003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0
ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool0
0?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3o
oomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00
o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool004P0oooo1@00000Y0?ooo`@00000>P3oool2
000002T0oooo1@0000020?ooo`8000009@3oool4000000<0oooo0P00000e0?ooo`800000103oool2
00000280oooo1@0000020?ooo`800000103oool2000001l0oooo100000030?ooo`800000103oool2
00000:H0oooo001:0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0>P3oool01000
0000oooo0?ooo`00000Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000<`3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000002<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000Y@3oool004X0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02P0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`00000f0?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool08@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`00002U0?ooo`00BP3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo03T0oooo0P00000[0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0T0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0b
0?ooo`8000000`3oool010000000oooo0?ooo`00000S0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0X`3oool0
04X0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`00000j0?ooo`030000003oool0
oooo02X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0280oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000d0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000008`3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0L0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00002U0?ooo`00B@3oool2000002`0
oooo0P00000k0?ooo`<00000:@3oool2000000@0oooo0P00000V0?ooo`800000103oool2000003D0
oooo0`0000030?ooo`8000008`3oool2000000@0oooo0P0000040?ooo`800000803oool2000000@0
oooo0P0000040?ooo`800000YP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o
0?ooool0ooooFP3oool00?l0ooooaP3oool200000940oooo003o0?ooolL0oooo00<000000?ooo`3o
ool0S`3oool00?l0oooo^`3oool4000000030?ooo`000000000000<000000`3oool010000000oooo
0?ooo`3oool3000008X0oooo00110?ooool00000KP00000;0?ooo`040000003oool0oooo00000080
oooo100000030?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0Q`3oool00440oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00/0oooo
00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00<00000RP3oool00440oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo00`0oooo0`0000030?ooo`<0000000D0oooo00000000000000000?ooo`020000
00030?ooo`000000000000800000R@3oool00440oooo00<000000?ooo`3oool0o`3ooomi0?ooo`03
0000003oool0oooo09T0oooo00110?ooo`030000003oool0oooo0?l0ooooN03oool2000009/0oooo
00110?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`00@@3oool00`000000oooo0?ooo`06
0?ooo`030000o`3oool0oooo0?l0ooooo`3oool=0?ooo`00@@3oool00`000000oooo0?ooo`070?oo
o`030000o`3oool0oooo0?l0ooooo`3oool<0?ooo`004@3oool500000080oooo0P0000050?ooo`05
0000003oool0oooo0?ooo`0000000`3oool500000080oooo0P00000A0?ooo`030000003oool0oooo
00P0oooo00<0003o0?ooo`3oool0o`3ooooo0?ooo`/0oooo000C0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool03P3oool4000000P0oooo00<0003o0?ooo`3oool0o`3ooooo0?ooo`X0oooo000C0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
0?l0ooooo`3oool90?ooo`004`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000H0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`3o0?ooool0oooo203oool001<0oooo00<000000?ooo`3o
ool02@3oool01@000000oooo0?ooo`3oool0000000D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo0?l0ooooo`3oool70?ooo`004P3oool2000001@0oooo0P0000040?oo
o`8000000`3oool300000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo0?l0ooooo`3oool60?ooo`00>03oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00h0oooo00<0003o0?ooo`3oool0o`3ooooo0?ooo`D0oooo000g0?ooo`800000
203oool00`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0?l0ooooo`3oool40?ooo`00@@3o
ool00`000000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0?l0ooooo`3oool30?ooo`00@@3oool0
0`000000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0?l0ooooo`3oool20?ooo`00@@3oool00`00
0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo0?l0ooooo`3oool10?ooo`00@@3oool00`000000
oooo0?ooo`0C0?ooo`030000o`3oool0oooo0?l0ooooo`3oool00440oooo00<000000?ooo`3oool0
503oool00`000?l0oooo0?ooo`3o0?ooooh0oooo00110?ooo`030000003oool0oooo01D0oooo00<0
003o0?ooo`3oool0o`3oooom0?ooo`00@@3oool00`000000oooo0?ooo`0F0?ooo`80003oo`3oooom
0?ooo`00@@3oool00`000000oooo0?ooo`0H0?ooo`030000o`3oool0oooo0?l0oooonP3oool00440
oooo00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`3o0?ooooT0oooo00110?ooo`030000
003oool0oooo01X0oooo00<0003o0?ooo`3oool0o`3ooooh0?ooo`00@@3oool00`000000oooo0?oo
o`0K0?ooo`030000o`3oool0oooo0?l0oooom`3oool00440oooo00<000000?ooo`3oool0703oool0
0`000?l0oooo0?ooo`3o0?ooooH0oooo00110?ooo`030000003oool0oooo01d0oooo00<0003o0?oo
o`3oool0o`3ooooe0?ooo`00@@3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo0?l0
oooom03oool00440oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?ooo`3o0?oooo<0oooo
00110?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0o`3oooob0?ooo`00@@3oool0
0`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0?l0ooool@3oool00440oooo00<000000?oo
o`3oool08P3oool00`000?l0oooo0?ooo`3o0?oooo00oooo00110?ooo`030000003oool0oooo02<0
oooo00<0003o0?ooo`3oool0o`3oooo_0?ooo`00@@3oool00`000000oooo0?ooo`0T0?ooo`030000
o`3oool0oooo0?l0ooookP3oool00440oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0?oo
o`3o0?ooond0oooo00110?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`3oool0o`3oooo/
0?ooo`00@@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0?l0ooooj`3oool00440
oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`3o0?ooonX0oooo00110?ooo`030000
003oool0oooo02T0oooo00<0003o0?ooo`3oool0o`3ooooY0?ooo`00@@3oool00`000000oooo0?oo
o`0Z0?ooo`030000o`3oool0oooo0?l0ooooj03oool00440oooo00<000000?ooo`3oool0:`3oool0
0`000?l0oooo0?ooo`3o0?ooonL0oooo00110?ooo`<00000;03oool00`000?l0oooo0?ooo`3o0?oo
onH0oooo00110?ooo`030000003oool0oooo02d0oooo00<0003o0?ooo`3oool0o`3ooomT0?ooog40
0000403oool00440oooo00<000000?ooo`3oool0;P3oool00`000?l0oooo0?ooo`3o0?ooof<0oooo
L@00000@0?ooo`00@@3oool00`000000oooo0?ooo`0_0?ooo`030000o`3oool0oooo0?l0ooooHP3o
ooma00000100oooo00110?ooo`030000003oool0oooo0300oooo00<0003o0?ooo`3oool0o`3ooomL
0?ooogH00000403oool00440oooo00<000000?ooo`3oool0<@3oool00`000?l0oooo0?ooo`3o0?oo
oe/0oooo00<000000?ooo`3oool0KP3oool500000100oooo00110?ooo`030000003oool0oooo0380
oooo00<0003o0?ooo`3oool0o`3ooomJ0?ooo`030000003oool0oooo06h0oooo1@00000@0?ooo`00
@@3oool00`000000oooo0?ooo`0c0?ooo`030000o`3oool0oooo0?l0ooooF@3oool00`000000oooo
0?ooo`1^0?ooo`D00000403oool00440oooo0`00000d0?ooo`030000o`3oool0oooo0?l0ooooF03o
ool00`000000oooo0?ooo`1^0?ooo`D00000403oool00440oooo00<000000?ooo`3oool0=@3oool0
0`000?l0oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0KP3oool500000100oooo00110?oo
o`030000003oool0oooo03H0oooo00<0003o0?ooo`3oool0o`3ooomF0?ooo`030000003oool0oooo
06h0oooo1@00000@0?ooo`00@@3oool00`000000oooo0?ooo`0g0?ooo`80003oo`3ooomF0?ooo`03
0000003oool0oooo06h0oooo1@00000@0?ooo`00@@3oool00`000000oooo0?ooo`0i0?ooo`030000
o`3oool0oooo0?l0ooooD`3oool00`000000oooo0?ooo`1^0?ooo`D00000403oool00440oooo00<0
00000?ooo`3oool0>P3oool00`000?l0oooo0?ooo`3o0?oooe80oooo00<000000?ooo`3oool0KP3o
ool500000100oooo00110?ooo`<00000>`3oool00`000?l0oooo0?ooo`3o0?oooe40oooo00<00000
0?ooo`3oool0KP3oool500000100oooo00110?ooo`030000003oool0oooo03`0oooo00<0003o0?oo
o`3oool0o`3ooom@0?ooo`030000003oool0oooo06h0oooo1@00000@0?ooo`00@@3oool00`000000
oooo0?ooo`0m0?ooo`030000o`3oool0oooo0?l0ooooC`3oool00`000000oooo0?ooo`1^0?ooo`D0
0000403oool00440oooo0`00000n0?ooo`030000o`3oool0oooo0?l0ooooCP3oool00`000000oooo
0?ooo`1^0?ooo`D00000403oool00440oooo00<000000?ooo`3oool0?`3oool00`000?l0oooo0?oo
o`3o0?ooodd0oooo00<000000?ooo`3oool0KP3oool500000100oooo00110?ooo`030000003oool0
oooo0400oooo00<0003o0?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo06h0oooo1@00000@
0?ooo`00@@3oool300000440oooo00<0003o0?ooo`3oool0o`3ooom;0?ooo`030000003oool0oooo
06h0oooo1@00000@0?ooo`00@@3oool00`000000oooo0?ooo`120?ooo`030000o`3oool0oooo0?l0
ooooBP3oool00`000000oooo0?ooo`1^0?ooo`D00000403oool00440oooo00<000000?ooo`3oool0
@`3oool00`000?l0oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool0KP3oool500000100oooo
00110?ooo`<00000A03oool00`000?l0oooo0?ooo`3o0?ooodP0oooo00<000000?ooo`3oool0KP3o
ool500000100oooo00110?ooo`030000003oool0oooo04D0oooo00<0003o0?ooo`3oool0o`3ooom7
0?ooo`030000003oool0oooo06h0oooo1@00000@0?ooo`00@@3oool3000004H0oooo00<0003o0?oo
o`3oool0o`3ooom60?ooo`030000003oool0oooo06h0oooo1@00000@0?ooo`00@@3oool00`000000
oooo0?ooo`170?ooo`030000o`3oool0oooo0?l0ooooA@3oool00`000000oooo0?ooo`0`0?ooo`D0
000000@0oooo000000000000oooo0P0000030?ooo`<000000P3oool4000000<0oooo0`0000030?oo
o`800000103oool3000000<0oooo0P0000020?ooo`8000000P3oool2000000P0oooo1@00000@0?oo
o`004`3oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`80
00000`3oool5000000H0oooo0`0000180?ooo`030000o`3oool0oooo0?l0ooooA03oool00`000000
oooo0?ooo`0a0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00L0oooo1@00000@0?ooo`004P3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01P3o
ool4000004P0oooo0P000?oo0?oood@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`@000000P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo1@00000@0?ooo`00
4P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1;0?ooo`030000o`3oool0oooo0?l0oooo
@@3oool00`000000oooo0?ooo`0a0?ooo`8000000`3oool2000000030?ooo`000000000000<0oooo
0`0000020?ooo`@000000`3oool200000080oooo1@0000030?ooo`800000103oool200000080oooo
1000000:0?ooo`D00000403oool00180oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0C03o
ool00`000?l0oooo0?ooo`3o0?oood00oooo00<000000?ooo`3oool0<@3oool010000000oooo0?oo
o`00000J0?ooo`030000003oool0oooo01`0oooo1@00000@0?ooo`004P3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`1=0?ooo`80003oo`3ooom00?ooo`030000003oool0oooo0300oooo1@00
000R0?ooo`030000003oool0oooo01@0oooo1@00000@0?ooo`004`3oool2000000X0oooo0P000004
0?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000203oool00`000000oooo0?ooo`1?
0?ooo`030000o`3oool0oooo0?l0oooo?@3oool00`000000oooo0?ooo`1^0?ooo`D00000403oool0
0440oooo00<000000?ooo`3oool0D03oool20000ool0oooo?@3oool00`000000oooo0?ooo`1^0?oo
o`D00000403oool00440oooo00<000000?ooo`3oool0DP3oool00`000?l0oooo0?ooo`3o0?ooocX0
oooo00<000000?ooo`3oool01`3oool50?l000<0oooo1@3o00030?ooo`D0o`000`3oool50?l004X0
oooo1@00000@0?ooo`00@@3oool00`000000oooo0?ooo`1C0?ooo`030000o`3oool0oooo0?l0oooo
>@3oool00`000000oooo0?ooo`1^0?ooo`D00000403oool00440oooo00<000000?ooo`3oool0E03o
ool20000ool0oooo>@3oool00`000000oooo0?ooo`1^0?ooo`D00000403oool00440oooo00<00000
0?ooo`3oool0EP3oool00`000?l0oooo0?ooo`3o0?ooocH0oooo00<000000?ooo`3oool0KP3oool5
00000100oooo00110?ooo`030000003oool0oooo05L0oooo0P000?oo0?ooocH0oooo00<000000?oo
o`3oool0KP3oool500000100oooo00110?ooo`030000003oool0oooo05T0oooo00<0003o0?ooo`3o
ool0o`3ooolc0?ooo`030000003oool0oooo0380oooo0P0000030?ooo`@000000`3oool300000003
0?ooo`00000000000080oooo0P0000020?ooo`<000008@3oool500000100oooo00110?ooo`030000
003oool0oooo05X0oooo00<0003o0?ooo`3oool0o`3ooolb0?ooo`030000003oool0oooo0340oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`00000T0?ooo`D00000403oool00440oooo00<000000?oo
o`3oool0F`3oool20000ool0oooo<P3oool00`000000oooo0?ooo`0a0?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool01000000Q0?ooo`D00000403oool00440oooo00<000000?ooo`3oool0G@3oool0
0`000?l0oooo0?ooo`3o0?ooobl0oooo00<000000?ooo`3oool0<@3oool010000000oooo0?ooo`00
00020?ooo`@000000`3oool200000080oooo100000040?ooo`8000008P3oool500000100oooo0011
0?ooo`030000003oool0oooo05h0oooo0P000?oo0?ooobl0oooo00<000000?ooo`3oool0<@3oool0
10000000oooo0?ooo`00000i0?ooo`D00000403oool00440oooo00<000000?ooo`3oool0H03oool0
0`000?l0oooo0?ooo`3o0?ooob`0oooo00<000000?ooo`3oool0<03oool2000000040?ooo`000000
0000000000T0oooo00<000000?ooo`3oool0;03oool500000100oooo00110?ooo`030000003oool0
oooo0640oooo00<0003o0?ooo`3oool0o`3oool[0?ooo`030000003oool0oooo06h0oooo1@00000@
0?ooo`00@@3oool00`000000oooo0?ooo`1R0?ooo`80003oo`3oool[0?ooo`030000003oool0oooo
06h0oooo1@00000@0?ooo`00@@3oool00`000000oooo0?ooo`1T0?ooo`030000o`3oool0oooo0?l0
oooo:03oool00`000000oooo0?ooo`1^0?ooo`D00000403oool00440oooo00<000000?ooo`3oool0
I@3oool20000ool0oooo:03oool00`000000oooo0?ooo`1^0?ooo`D00000403oool00440oooo00<0
00000?ooo`3oool0I`3oool00`000?l0oooo0?ooo`3o0?ooobD0oooo00<000000?ooo`3oool0KP3o
ool500000100oooo00110?ooo`030000003oool0oooo06P0oooo00<0003o0?ooo`3oool0o`3ooolT
0?ooo`030000003oool0oooo06h0oooo1@00000@0?ooo`00@@3oool00`000000oooo0?ooo`1Y0?oo
o`80003oo`3ooolT0?ooo`030000003oool0oooo06h0oooo1@00000@0?ooo`00@@3oool00`000000
oooo0?ooo`1[0?ooo`030000o`3oool0oooo0?l0oooo8@3oool00`000000oooo0?ooo`1^0?ooo`D0
0000403oool00440oooo00<000000?ooo`3oool0K03oool20000ool0oooo8@3oool00`000000oooo
0?ooo`1^0?ooo`D00000403oool00440oooo00<000000?ooo`3oool0KP3oool20000ool0oooo7`3o
ool00`000000oooo0?ooo`1^0?ooo`D00000403oool00440oooo00<000000?ooo`3oool0L03oool2
0000ool0oooo7@3oool00`000000oooo0?ooo`1^0?ooo`D00000403oool00440oooo00<000000?oo
o`3oool0LP3oool20000ool0oooo6`3oool00`000000oooo0?ooo`1^0?ooo`D00000403oool00440
oooo00<000000?ooo`3oool0M03oool20000ool0oooo6@3oool00`000000oooo0?ooo`1^0?ooo`D0
0000403oool00440oooo00<000000?ooo`3oool0MP3oool20000ool0oooo5`3oool00`000000oooo
0?ooo`1^0?ooo`D00000403oool00440oooo00<000000?ooo`3oool0N03oool20000ool0oooo5@3o
ool00`000000oooo0?ooo`1^0?ooo`D00000403oool00440oooo00<000000?ooo`3oool0NP3oool2
0000ool0oooo4`3oool00`000000oooo0?ooo`1^0?ooo`D00000403oool00440oooo0`00001l0?oo
o`80003oo`3ooolA0?ooo`030000003oool0oooo06h0oooo1@00000@0?ooo`00@@3oool00`000000
oooo0?ooo`1n0?ooo`80003oo`3oool?0?ooo`030000003oool0oooo06h0oooo1@00000@0?ooo`00
@@3oool00`000000oooo0?ooo`200?ooo`030000o`3oool0oooo0?l0oooo303oool00`000000oooo
0?ooo`1^0?ooo`D00000403oool00440oooo00<000000?ooo`3oool0P@3oool20000ool0oooo303o
ool00`000000oooo0?ooo`1^0?ooo`D00000403oool00440oooo00<000000?ooo`3oool0P`3oool2
0000ool0oooo2P3oool00`000000oooo0?ooo`1^0?ooo`D00000403oool00440oooo00<000000?oo
o`3oool0Q@3oool20000ool0oooo203oool00`000000oooo0?ooo`1^0?ooo`D00000403oool00440
oooo00<000000?ooo`3oool0Q`3oool20000ool0oooo1P3oool00`000000oooo0?ooo`1^0?ooo`D0
0000403oool00440oooo00<000000?ooo`3oool0R@3oool20000ool0oooo103oool00`000000oooo
0?ooo`1^0?ooo`D00000403oool00440oooo00<000000?ooo`3oool0R`3oool20000ool0oooo0P3o
ool00`000000oooo0?ooo`1^0?ooo`D00000403oool00440oooo0`00002=0?ooo`80003oo`3oool0
0`000000oooo0?ooo`1^0?ooo`D00000403oool00440oooo00<000000?ooo`3oool0S`3oool20000
ood0oooo00<000000?ooo`3oool0KP3oool500000100oooo00110?ooo`030000003oool0oooo0940
oooo0P000?ok0?ooo`030000003oool0oooo06h0oooo1@00000@0?ooo`00@@3oool00`000000oooo
0?ooo`2C0?ooo`80003on@3oool00`000000oooo0?ooo`1^0?ooo`D00000403oool00440oooo00<0
00000?ooo`3oool0U@3oool30000ooH0oooo00<000000?ooo`3oool0KP3oool500000100oooo0011
0?ooo`<00000V03oool20000oo@0oooo00<000000?ooo`3oool0KP3oool500000100oooo00110?oo
o`030000003oool0oooo09X0oooo0`000?oa0?ooo`030000003oool0oooo06h0oooo1@00000@0?oo
o`00@@3oool00`000000oooo0?ooo`2M0?ooo`<0003okP3oool00`000000oooo0?ooo`1^0?ooo`D0
0000403oool00440oooo00<000000?ooo`3oool0X03oool20000on`0oooo00<000000?ooo`3oool0
KP3oool500000100oooo00110?ooo`<00000XP3oool30000onT0oooo00<000000?ooo`3oool0<03o
ool5000000040?ooo`00000000000?ooo`8000000`3oool300000080oooo100000030?ooo`<00000
0`3oool2000000@0oooo0`0000030?ooo`8000000P3oool200000080oooo0P0000080?ooo`D00000
403oool00440oooo00<000000?ooo`3oool0Y@3oool30000onH0oooo00<000000?ooo`3oool0<@3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
0000103oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`070?ooo`D00000403oool00440oooo00<000000?ooo`3oool0Z03oool20000
on@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`@000000P3oool00`00
0000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00L0oooo1@00000@0?ooo`00@@3oool300000:X0oooo0`000?oQ
0?ooo`030000003oool0oooo0340oooo0P0000030?ooo`80000000<0oooo0000000000000`3oool3
00000080oooo100000030?ooo`8000000P3oool5000000<0oooo0P0000040?ooo`8000000P3oool4
000000X0oooo1@00000@0?ooo`00@@3oool00`000000oooo0?ooo`2]0?ooo`<0003ogP3oool00`00
0000oooo0?ooo`0a0?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3oool0703oool5
00000100oooo00110?ooo`030000003oool0oooo0;00oooo10000?oJ0?ooo`030000003oool0oooo
0300oooo1@00000R0?ooo`030000003oool0oooo01@0oooo1@00000@0?ooo`00@@3oool300000;@0
oooo10000?oF0?ooo`030000003oool0oooo06h0oooo1@00000@0?ooo`00@@3oool00`000000oooo
0?ooo`2h0?ooo`<0003od`3oool00`000000oooo0?ooo`1^0?ooo`D00000403oool00440oooo0`00
002k0?ooo`@0003oc`3oool00`000000oooo0?ooo`070?oooal0003oB03oool500000100oooo000O
0?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000000`3oool5000000H0oooo0`00002o
0?ooo`@0003ob`3oool00`000000oooo0?ooo`1^0?ooo`D00000403oool001h0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`330?ooo`D0003oaP3oool00`000000oooo
0?ooo`1^0?ooo`D00000403oool001h0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01P3oool40000
0<L0oooo1@000?o10?ooo`030000003oool0oooo06h0oooo1@00000@0?ooo`007P3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0<d0oooo1@000?nl0?ooo`030000003o
ool0oooo06h0oooo1@00000@0?ooo`007P3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0=80oooo1@000?ng0?ooo`030000003oool0oooo0340oooo0`0000030?ooo`D0
00000P3oool3000000<0oooo0`0000020?ooo`D0000000@0oooo0000000000000000703oool50000
0100oooo000O0?ooo`8000002P3oool2000000@0oooo0P0000040?ooo`800000203oool00`000000
oooo0?ooo`3G0?ooo`P0003o[`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0080
oooo100000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool4000000<0
oooo00<000000?ooo`3oool06`3oool500000100oooo00110?ooo`030000003oool0oooo0=l0oooo
2@000?nV0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0400000080oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000001d0
oooo1@00000@0?ooo`00@@3oool00`000000oooo0?ooo`3X0?ooo`P0003oWP3oool00`000000oooo
0?ooo`0b0?ooo`800000103oool3000000<0oooo0P0000040?ooo`<000000`3oool3000000<0oooo
00<000000?ooo`3oool06`3oool500000100oooo00110?ooo`030000003oool0oooo0?00oooo3P00
0?n@0?ooo`030000003oool0oooo0380oooo00@000000?ooo`3oool000006P3oool00`000000oooo
0?ooo`0K0?ooo`D00000403oool00440oooo00<000000?ooo`3oool0oP3ooolJ0000ogH0oooo00<0
00000?ooo`3oool0<@3oool5000001T0oooo0P00000M0?ooo`D00000403oool00440oooo00<00000
0?ooo`3oool0o`3ooolI0?ooodT0003o;@3oool00`000000oooo0?ooo`1^0?ooo`D00000403oool0
0440oooo00<000000?ooo`3oool0o`3ooon?0?ooo`030000003oool0oooo06h0oooo1@00000@0?oo
o`00@@3oool00`000000oooo0?ooo`3o0?ooohl0oooo00<000000?ooo`3oool0KP3oool500000100
oooo00110?ooo`030000003oool0oooo0?l0ooooS`3oool00`000000oooo0?ooo`1^0?ooo`D00000
403oool00440oooo00<000000?ooo`3oool0o`3ooon?0?ooo`030000003oool0oooo06h0oooo1@00
000@0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooohl0oooo00<000000?ooo`3oool0KP3oool5
00000100oooo00110?ooo`030000003oool0oooo0?l0ooooS`3oool00`000000oooo0?ooo`1^0?oo
o`D00000403oool00440oooo00<000000?ooo`3oool0o`3ooon?0?ooo`030000003oool0oooo06h0
oooo1@00000@0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooohl0oooo00<000000?ooo`3oool0
KP3oool500000100oooo00110?ooo`030000003oool0oooo0?l0ooooS`3oool00`000000oooo0?oo
o`1^0?ooo`D00000403oool00440oooo00<000000?ooo`3oool0o`3ooon?0?ooo`030000003oool0
oooo06h0oooo1@00000@0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooohl0oooo00<000000?oo
o`3oool0KP3oool500000100oooo00110?ooo`030000003oool0oooo0?l0ooooS`3oool00`000000
oooo0?ooo`1^0?ooo`D00000403oool00440oooo00<000000?ooo`3oool0o`3ooon?0?ooo`030000
003oool0oooo06h0oooo1@00000@0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooohl0oooo00<0
00000?ooo`3oool0KP3oool500000100oooo00110?ooo`030000003oool0oooo0?l0ooooS`3oool0
0`000000oooo0?ooo`1^0?ooo`D00000403oool00440oooo00<000000?ooo`3oool0o`3ooon?0?oo
o`030000003oool0oooo06h0oooo00<000000?ooo`3oool04P3oool00440oooo00<000000?ooo`3o
ool0o`3ooon?0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool04P3oool00440oooo
00<000000?ooo`3oool0o`3ooon?0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0
4P3oool00440oooo00<000000?ooo`3oool0o`3ooon?0?ooog800000503oool00440oooo00<00000
0?ooo`3oool0o`3ooooo0?oooaH0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?oo
o`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00440oooo00<000000?ooo`3oool0
o`3ooooo0?oooaH0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`00@@3oool3
00000?l0ooooo`3ooolF0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00440
oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00110?ooo`030000003oool0oooo0?l0oooo
o`3ooolF0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00440oooo00<00000
0?ooo`3oool0o`3ooooo0?oooaH0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?oo
o`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00440oooo00<000000?ooo`3oool0
o`3ooooo0?oooaH0oooo00110?ooo`<00000o`3ooooo0?oooaH0oooo00110?ooo`030000003oool0
oooo0?l0ooooo`3ooolF0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00440
oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00110?ooo`030000003oool0oooo0?l0oooo
o`3ooolF0?ooo`00@@3oool300000?l0ooooo`3ooolF0?ooo`00@@3oool00`000000oooo0?ooo`3o
0?ooool0oooo5P3oool00440oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00110?ooo`03
0000003oool0oooo0?l0ooooo`3ooolF0?ooo`00@@3oool300000?l0ooooo`3ooolF0?ooo`00@@3o
ool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00440oooo00<000000?ooo`3oool0o`3ooooo
0?oooaH0oooo00110?ooo`<00000o`3ooooo0?oooaH0oooo00110?ooo`030000003oool0oooo0?l0
ooooo`3ooolF0?ooo`00@@3oool300000?l0ooooo`3ooolF0?ooo`00@@3oool00`000000oooo0?oo
o`3o0?ooool0oooo5P3oool00440oooo0`00003o0?ooool0oooo5P3oool00440oooo00<000000?oo
o`3oool0o`3ooooo0?oooaH0oooo000[0?ooo`800000103oool2000000<0oooo1@0000060?ooo`<0
0000o`3ooooo0?oooaH0oooo000Z0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool002X0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`060?ooo`@00000o`3ooooo0?oooaD0oooo000Z0?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooool0
oooo5P3oool002X0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0?l0ooooo`3ooolF0?ooo`00:`3oool2000000X0oooo0P0000080?ooo`030000
003oool0oooo0?l0ooooo`3ooolF0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo5P3o
ool00440oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00110?ooo`030000003oool0oooo
0?l0ooooo`3ooolF0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00440oooo
00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3o
oolF0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00440oooo00<000000?oo
o`3oool0o`3ooooo0?oooaH0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`00
@@3oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00440oooo00<000000?ooo`3oool0o`3o
oooo0?oooaH0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`00@@3oool00`00
0000oooo0?ooo`3o0?ooool0oooo5P3oool00440oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0
oooo00110?ooo`030000003oool0oooo00T0oooo0`3o003o0?ooool0oooo2P3oool00440oooo00<0
00000?ooo`3oool0303oool20?l00?l0ooooo`3oool80?ooo`00@@3oool00`000000oooo0?ooo`0A
0?ooo`80o`00o`3ooooo0?ooo`<0oooo00110?ooo`030000003oool0oooo01<0oooo0`3o003o0?oo
ool0oooo00110?ooo`030000003oool0oooo01T0oooo1@3o003o0?ooooL0oooo00110?ooo`030000
003oool0oooo0240oooo1@3o003o0?ooonl0oooo00110?ooo`030000003oool0oooo02T0oooo1@3o
00030?ooo`D0o`000`3oool50?l000<0oooo0`3o003o0?ooom40oooo00110?ooo`030000003oool0
oooo04@0oooo0P3o00030?ooo`D0o`000`3oool50?l000<0oooo1@3o00030?ooo`D0o`000`3oool5
0?l000<0oooo1@3o00030?ooo`D0o`000`3oool50?l000<0oooo1@3o00030?ooo`D0o`000`3oool5
0?l000<0oooo1@3o00030?ooo`D0o`000`3oool50?l000<0oooo1@3o00030?ooo`D0o`000`3oool5
0?l000<0oooo1@3o00030?ooo`D0o`000`3oool50?l000<0oooo1@3o00030?ooo`D0o`000`3oool5
0?l000<0oooo1@3o00030?ooo`D0o`000`3oool50?l000<0oooo1@3o00030?ooo`D0o`000`3oool5
0?l000<0oooo1@3o00030?ooo`D0o`000`3oool50?l000<0oooo0P3o00020?ooo`D0o`000`3oool5
0?l000<0oooo103o002c0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00440
oooo00<000000?ooo`3oool0o`3ooooo0?oooaH0oooo00110?ooo`030000003oool0oooo0?l0oooo
o`3ooolF0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool00440oooo00<00000
0?ooo`3oool0o`3ooooo0?oooaH0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00
o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oo
oeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00c03oool3000000<0oooo0P00
00020?ooo`8000000P3oool2000000040?ooo`0000000000000000@0oooo0P0000030?ooo`L00000
0P3oool200000080oooo0P00000:0?ooo`<0000000<0oooo0000000000000P3oool200000080oooo
0P0000030?ooo`L0000000<0oooo0000000000000`3oool300000?l0oooo=P3oool00</0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0400000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@000000P3oool00`000000
oooo000000030?ooo`030000003oool0oooo0?l0oooo=`3oool00</0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo0`0000030?oo
o`030000003oool0oooo00H0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
000=0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000080?ooo`03
0000003oool0oooo00<000000`3oool400000?l0oooo=P3oool004@0oooo0`0000240?ooo`030000
003oool0oooo00@0oooo0P0000020?ooo`@000000`3oool4000000030?ooo`000000000000<00000
0`3oool3000000030?ooo`0000000000008000000P3oool5000000T0oooo0P0000020?ooo`@00000
0P3oool5000000<0oooo0`0000020?ooo`040000003oool00000000000<0oooo0P00003o0?ooocL0
oooo00150?ooo`030000003oool0oooo08<0oooo00@000000?ooo`3oool00000503oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`3o0?ooocd0oooo000k0?ooo`@00000103oool3000008H0oooo0`00000d0?ooo`030000
003oool0oooo0180oooo0P00003o0?ooocl0oooo000l0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000o`3ooooo0?oooa@0oooo000l0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000o`3ooooo0?oooa@0oooo000l0?ooo`<00000103oool400000?l0
ooooo`3ooolC0?ooo`00?03oool010000000oooo0?ooo`00003o0?ooool0oooo6P3oool003/0oooo
1000003o0?ooool0oooo6`3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?oo
ool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3o
ool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0oooo
o`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?oo
o`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo
0?oooeX0oooo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {293.25, 0}} -> {-1.06554, -0.648943, \
0.00442583, 0.00442583}, {{14.75, 466.688}, {286.25, 6.9375}} -> {-0.484687, \
-8.33593, 0.00650932, 0.0324043}, {{466.688, 579.625}, {214.375, 101.375}} -> \
{-14.9763, -2.19605, 0.0318763, 0.0265637}, {{476.063, 507.438}, {203, \
165.375}} -> {-15.9571, -11.8114, 0.0334665, 0.1083}, {{476.063, 507.438}, \
{150.313, 112.688}} -> {-15.9571, -17.5175, 0.0334665, 0.1083}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[34]=",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[TextData[{
  StyleBox["Here is computed the whole body retention and the urine and \
faecal excretion for f1 = 0.1 using the function ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["BioassayReport ", "Input"],
  "for a single intake ",
  Cell[BoxData[
      \(I\_0\)]],
  "= 1 of Co-60 (\[Lambda] = 5.27 y) in t =0 ",
  StyleBox[".",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  " ",
  StyleBox[" ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["\:f35f",
    FormatType->StandardForm]
}], "MathCaption"],

Cell[BoxData[
    \(lambda\  = \ Log[2]/\((5.27*365.24)\); fn1\  = \ 0.1;\)], "Input",
  CellLabel->"In[82]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
        element, "\<Ingestion\>", \ "\<Acute\>", "\<BioassayTable\>", 1, fn1, 
        180, lambda] // Chop\)], "Input",
  CellLabel->"In[83]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nstart intake"\), \("Urine\n24 hours"\), \("Faecal\n\
24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "0.027485139147156768`", "0.2614094898383679`", 
            "0.7107453247437685`"},
          {"2", "0.014354447482729134`", "0.3505589551065794`", 
            "0.3455760209508635`"},
          {"3", "0.005478742339908314`", "0.17676272228078718`", 
            "0.16321013297257908`"},
          {"4", "0.003051622416906469`", "0.07332823231221236`", 
            "0.08677151504374173`"},
          {"5", "0.002268557087468656`", "0.02858780152508442`", 
            "0.055883914670793525`"},
          {"6", "0.0019155995350097408`", "0.010970603526486945`", 
            "0.042977590814227154`"},
          {"7", "0.0016872554414738724`", "0.004272115333819956`", 
            "0.03700274611763661`"},
          {"8", "0.0015053058033398963`", "0.0017536763402772459`", 
            "0.03373044127327393`"},
          {"9", "0.0013485349314794365`", "0.0008031275467794318`", 
            "0.0315666342754254`"},
          {"10", "0.0012101553367287465`", "0.00043625766171842225`", 
            "0.02990885582802858`"},
          {"20", "0.0004360239938439245`", "0.00008435266029207603`", 
            "0.02118094937101283`"},
          {"30", "0.00018729506602908978`", "0.00003501136574586033`", 
            "0.017816513264412`"},
          {"40", "0.00010405586396314654`", "0.000018651109936708508`", 
            "0.016165345362289595`"},
          {"50", "0.00007333061451107846`", "0.00001273661311224722`", 
            "0.015110695895126368`"},
          {"60", "0.000059597555749246805`", "0.000010187094663570777`", 
            "0.01429556967758154`"},
          {"70", "0.000051650961099953876`", "8.77055246787914`*^-6", 
            "0.013602146940440858`"},
          {"80", "0.000045923076825192645`", "7.77785450807778`*^-6", 
            "0.012988320305490937`"},
          {"90", "0.000041249022611423805`", "6.978786740896501`*^-6", 
            "0.01243631951804847`"},
          {"100", "0.000037223124637888165`", "6.294302053887368`*^-6", 
            "0.011936522867184277`"},
          {"180", "0.000017766605072928894`", "2.996289825282827`*^-6", 
            "0.009215408070665962`"},
          {"200", "0.000015119806553646018`", "2.5479350447961515`*^-6", 
            "0.008769020369809902`"},
          {"300", "7.973002837684275`*^-6", "1.3380504658180404`*^-6", 
            "0.007213122980144547`"},
          {"400", "5.411481288860037`*^-6", "9.053500273422074`*^-7", 
            "0.006215314469436714`"},
          {"500", "4.288171314159566`*^-6", "7.163020273808225`*^-7", 
            "0.005447684030357498`"},
          {"600", "3.6416723299131774`*^-6", "6.079313210462243`*^-7", 
            "0.004803603365857328`"},
          {"700", "3.1752759517949616`*^-6", "5.299524928474909`*^-7", 
            "0.004244486062968408`"},
          {"800", "2.7947640425845448`*^-6", "4.6640824613126194`*^-7", 
            "0.0037531338545384384`"},
          {"900", "2.4679123519033125`*^-6", "4.1184984937384123`*^-7", 
            "0.0033194789232681753`"},
          {"1000", "2.1817480208288526`*^-6", "3.6409077530889145`*^-7", 
            "0.002936178913996973`"},
          {"2000", "6.397176437801377`*^-7", "1.0675574851690542`*^-7", 
            "0.000861173580472929`"},
          {"3000", "1.8763185251797593`*^-7", "3.1311906149805776`*^-8", 
            "0.00025258580386736546`"},
          {"4000", "5.5033205149962256`*^-8", "9.183912740379009`*^-9", 
            "0.00007408447007172152`"},
          {"5000", "1.6141468671960927`*^-8", "2.693679925693847`*^-9", 
            "0.000021729284155216892`"},
          {"6000", "4.734360102849504`*^-9", "7.900675604460066`*^-10", 
            "6.373289698111598`*^-6"},
          {"7000", "1.388607570044755`*^-9", "2.3173010886872684`*^-10", 
            "1.869312458059206`*^-6"},
          {"8000", "4.072843938319225`*^-10", "0", "5.482771427902797`*^-7"},
          {"9000", "1.194582117419448`*^-10", "0", "1.608119734131422`*^-7"},
          {"10000", "0", "0", "4.716682271564439`*^-8"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nstart intake", 
          "Urine\n24 hours", "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
  CellLabel->"Out[83]//TableForm="]
}, Open  ]],

Cell["\<\
Whole body and daily urine values from day 1 to 10 are the same that Table \
A.3.26 of ICRP 78 (Faecal and values higher that 10 days are not included in \
ICRP ).\
\>", "Commentary"]
}, Closed]],

Cell[CellGroupData[{

Cell["Inhalation", "SubsubsectionIcon"],

Cell[TextData[{
  "Here is shown the Report for an inhalation  acute intake\"1\" of Co-60 (\
\[Lambda] = 5.27 y) with ",
  Cell[BoxData[
      \(f\_1\)]],
  "=0.05 (Type S), AMAD 5."
}], "MathCaption",
  CellTags->"ICRP 78"],

Cell[BoxData[
    \(\(\(\(lambda\  = \ Log[2]/\((5.27*365.24)\)\) \)\(;\)\(\(fn1\  = \ 
        0.05\) \)\(;\)\(\ \ \)\(\(amad = \ 
        AMADAdultW[5]\) \)\(;\)\(\(class\  = \ S\) \)\(;\)\(\ \)\)\)], "Input",\

  CellLabel->"In[84]:="],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Inhalation\>", \ "\<Acute\>", "\<BioassayTable\>", 1, \ 
      amad, class, \ fn1, 180, lambda]\)], "Input",
  CellLabel->"In[85]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nintake"\), \("Lung\nretention"\), \("Urine\n24 \
hours"\), \("Faecal\n24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "0.06425238283930051`", "0.005654157731848609`", 
            "0.1098842932178019`", "0.4897186792181675`"},
          {"2", "0.06264865081239229`", "0.0031340743268978666`", 
            "0.15498702461867106`", "0.25271535143396456`"},
          {"3", "0.061868263427907036`", "0.0012083109164636283`", 
            "0.079651952884157`", "0.14282023783264605`"},
          {"4", "0.0612122377374881`", "0.0006736507775097911`", 
            "0.0335347499168257`", "0.0979163974972665`"},
          {"5", "0.0605857455508689`", "0.0005018324323583173`", 
            "0.013405829305244421`", "0.08005917565535355`"},
          {"6", "0.05997563184726288`", "0.00042568456521690525`", 
            "0.005449566169940923`", "0.07271562558689512`"},
          {"7", "0.05937979853862927`", "0.0003771433497867419`", 
            "0.002417748987819671`", "0.06936518970723332`"},
          {"8", "0.05879765175896909`", "0.00033869472903802836`", 
            "0.0012742501032661049`", "0.06753259850946637`"},
          {"9", "0.05822880940571218`", "0.0003055997643312775`", 
            "0.0008390548216668453`", "0.06629203893448574`"},
          {"10", "0.05767292607702852`", "0.0002763635108601695`", 
            "0.0006672528758903097`", "0.06529822709169425`"},
          {"20", "0.052757951780823216`", "0.00011125934252084858`", 
            "0.0004353587938424822`", "0.058360322375178`"},
          {"30", "0.04882400678617337`", "0.000056169682442927036`", 
            "0.00033971052801221567`", "0.053596011326339385`"},
          {"40", "0.045650083877093114`", "0.00003617506078680623`", 
            "0.0002701422517108449`", "0.049975039417926456`"},
          {"50", "0.043066724885656216`", "0.000027657743516702104`", 
            "0.00021749655640927734`", "0.04708989202730986`"},
          {"60", "0.04094368035059834`", "0.00002311436320482539`", 
            "0.00017689588716744684`", "0.044731429960230024`"},
          {"70", "0.039180588395192825`", "0.00002011876374014747`", 
            "0.0001452778690855385`", "0.04277116780726429`"},
          {"80", "0.037699920936259866`", "0.000017853425101700284`", 
            "0.00012050859571138535`", "0.04112002207325953`"},
          {"90", "0.03644163520995515`", "0.000016017383850457773`", 
            "0.00010101812728883401`", "0.03971209389772523`"},
          {"100", "0.03535911000499482`", "0.000014480846980639797`", 
            "0.00008562104317630072`", "0.03849708992198988`"},
          {"180", "0.02996620703529719`", "7.826845641808058`*^-6", 
            "0.000034510144571818194`", "0.03242768355909544`"},
          {"200", "0.029049288172294428`", "7.002084355913846`*^-6", 
            "0.000030385152375412477`", "0.03140581828261472`"},
          {"300", "0.025289330212555944`", "4.749125877630559`*^-6", 
            "0.000021550761314448236`", "0.027288322711885225`"},
          {"400", "0.02220905084965916`", "3.792673904433758`*^-6", 
            "0.00001806689072962632`", "0.023980558624462738`"},
          {"500", "0.019549847285393145`", "3.235619368909477`*^-6", 
            "0.000015569876271551742`", "0.021143456388198274`"},
          {"600", "0.017235397422902265`", "2.828875486488197`*^-6", 
            "0.000013481528911970272`", "0.018676166665913343`"},
          {"700", "0.015217370728911016`", "2.495873865418144`*^-6", 
            "0.000011685811481656642`", "0.01652212259246576`"},
          {"800", "0.01345616677261069`", "2.210224498278014`*^-6", 
            "0.000010133780723543699`", "0.014638419878652258`"},
          {"900", "0.011917794749566314`", "1.9608899425055794`*^-6", 
            "8.79080297433188`*^-6", "0.01298931453947933`"},
          {"1000", "0.010572866837372649`", "1.7418381047724633`*^-6", 
            "7.6282676015289195`*^-6", "0.011544194325529973`"},
          {"2000", "0.0035410982390983543`", "5.653282731536556`*^-7", 
            "1.8908293046905707`*^-6", "0.003911670903877166`"},
          {"3000", "0.0014497830977757123`", "2.0837572270661702`*^-7", 
            "5.037898798388699`*^-7", "0.0016007684232885375`"},
          {"4000", "0.0007002869318362228`", "8.842501915591525`*^-8", 
            "1.5269575579135159`*^-7", "0.0007682541562206018`"},
          {"5000", "0.00037397327495628793`", "4.2459903426220755`*^-8", 
            "5.536797295603854`*^-8", "0.0004080021508355185`"},
          {"6000", "0.00021008103857197123`", "2.2262479557110227`*^-8", 
            "2.402477660262045`*^-8", "0.00022867275297225057`"},
          {"7000", "0.0001208792663472174`", "1.2321363784134453`*^-8", 
            "1.186560478540285`*^-8", "0.00013165278945650674`"},
          {"8000", "0.00007038938236121361`", "7.033877258944834`*^-9", 
            "6.303043885293376`*^-9", "0.00007685381408118603`"},
          {"9000", "0.00004127322040572003`", "4.086985948730146`*^-9", 
            "3.469379675626707`*^-9", "0.0000452273883030919`"},
          {"10000", "0.000024319780787619006`", "2.4001361178234583`*^-9", 
            "1.941426539834014`*^-9", "0.000026763707859817925`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nintake", 
          "Lung\nretention", "Urine\n24 hours", "Faecal\n24 hours", 
          "Wholebody"}}]]]], "Output",
  CellLabel->"Out[85]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Inhalation\>", \ "\<Constant\>", "\<GraphicReport\>", 1, \ 
      amad, class, \ fn1, 180, lambda]\)], "Input",
  CellLabel->"In[86]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.422291 0.458692 0.169838 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .11901 -28 -6.28125 ]
[-0.0125 .11901 0 6.28125 ]
[-0.0125 .28885 -22 -6.28125 ]
[-0.0125 .28885 0 6.28125 ]
[-0.0125 .45869 -10 -6.28125 ]
[-0.0125 .45869 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35242 0 m
.35242 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11901 m
.00625 .11901 L
s
gsave
-0.0125 .11901 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .28885 m
.00625 .28885 L
s
gsave
-0.0125 .28885 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .45869 m
.00625 .45869 L
s
gsave
-0.0125 .45869 -71 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .0003 m
.00375 .0003 L
s
0 .03021 m
.00375 .03021 L
s
0 .05143 m
.00375 .05143 L
s
0 .06789 m
.00375 .06789 L
s
0 .08134 m
.00375 .08134 L
s
0 .09271 m
.00375 .09271 L
s
0 .10256 m
.00375 .10256 L
s
0 .11124 m
.00375 .11124 L
s
0 .17014 m
.00375 .17014 L
s
0 .20005 m
.00375 .20005 L
s
0 .22127 m
.00375 .22127 L
s
0 .23773 m
.00375 .23773 L
s
0 .25117 m
.00375 .25117 L
s
0 .26254 m
.00375 .26254 L
s
0 .27239 m
.00375 .27239 L
s
0 .28108 m
.00375 .28108 L
s
0 .33998 m
.00375 .33998 L
s
0 .36989 m
.00375 .36989 L
s
0 .39111 m
.00375 .39111 L
s
0 .40757 m
.00375 .40757 L
s
0 .42101 m
.00375 .42101 L
s
0 .43238 m
.00375 .43238 L
s
0 .44223 m
.00375 .44223 L
s
0 .45092 m
.00375 .45092 L
s
0 .50982 m
.00375 .50982 L
s
0 .53973 m
.00375 .53973 L
s
0 .56094 m
.00375 .56094 L
s
0 .5774 m
.00375 .5774 L
s
0 .59085 m
.00375 .59085 L
s
0 .60222 m
.00375 .60222 L
s
0 .61207 m
.00375 .61207 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Constant) show
117.000 12.813 moveto
(intake) show
153.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .26037 m
.41107 .40908 L
.53436 .45552 L
.60372 .48087 L
.65224 .49815 L
.69278 .51227 L
.72483 .52321 L
.75369 .53288 L
.77776 .54084 L
.79827 .54754 L
.81784 .55386 L
.83489 .55932 L
.84991 .5641 L
.86466 .56876 L
.87782 .5729 L
.89084 .57697 L
.90257 .58063 L
.91318 .58393 L
.92384 .58723 L
.93355 .59023 L
.94333 .59324 L
.95229 .596 L
.96051 .59852 L
.96887 .60108 L
.97619 .60332 L
s
0 1 0 r
1.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.06042 .04717 L
.08838 .06776 L
.1161 .08354 L
.13894 .09349 L
.17363 .10455 L
.19066 .10863 L
.20509 .11155 L
.25792 .11936 L
.30107 .12389 L
.41107 .13389 L
.53436 .14407 L
.60117 .14828 L
.65279 .15078 L
.69167 .15235 L
.72557 .15358 L
.75321 .15453 L
.77635 .15533 L
.79815 .15607 L
.81693 .15671 L
.83499 .15733 L
.85085 .15788 L
.86492 .15836 L
.87879 .15883 L
.89122 .15925 L
.90243 .15963 L
.91365 .16 L
.92384 .16034 L
.93408 .16068 L
.94344 .16098 L
.95201 .16126 L
.96071 .16154 L
.96872 .1618 L
.9761 .16203 L
.97619 .16203 L
s
0 0 1 r
2 Mabswid
[ 1 8 ] 0 Mabsdash
.02381 .21484 m
.08838 .28666 L
.13894 .32943 L
.17652 .35237 L
.20509 .36527 L
.23381 .37482 L
.2473 .37829 L
.2606 .38113 L
.28276 .38478 L
.30107 .38693 L
.3181 .38837 L
.3348 .38937 L
.34928 .38999 L
.3616 .39037 L
.37502 .39068 L
.38862 .39091 L
.40061 .39106 L
.41107 .39117 L
.53436 .39205 L
.60307 .39263 L
.65566 .39314 L
.69514 .39355 L
.72648 .39388 L
.75482 .39418 L
.7785 .39442 L
.79871 .39462 L
.81803 .39481 L
.83489 .39496 L
.85125 .39511 L
.86574 .39523 L
.87868 .39533 L
.89151 .39543 L
.90307 .39552 L
.91354 .39559 L
.92406 .39566 L
.93365 .39573 L
.94333 .39579 L
.95219 .39584 L
.96032 .39589 L
.9686 .39594 L
.97619 .39599 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0227273 0.227273 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.0681818 0.361111 0.295455 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .18182 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Lungs) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.386364 0.361111 0.613636 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
1.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .5 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.704545 0.361111 0.931818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
2 Mabswid
[ 1 8 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .81818 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[86]:=",
  ImageSize->{600, 294.25},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[86]="]
}, Open  ]],

Cell["\<\
Whole body and daily urine values from day 1 to 10 are the same that Table \
A.3.25 of ICRP 78 (Values higher that 10 days are not included in ICRP ).\
\>", "Commentary"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Uranium", "Section"],

Cell[CellGroupData[{

Cell["The model", "SubsubsectionIcon"],

Cell["The compartments has been numbered as follow: ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CompartNumbers[uranium]\)], "Input",
  CellLabel->"In[87]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "\<\"Plasma\"\>"},
          {"2", "\<\"RBC\"\>"},
          {"3", "\<\"ST0\"\>"},
          {"4", "\<\"ST1\"\>"},
          {"5", "\<\"ST2\"\>"},
          {"6", "\<\"Liver1\"\>"},
          {"7", "\<\"Liver2\"\>"},
          {"8", "\<\"UrinaryPath\"\>"},
          {"9", "\<\"OtherKidney\"\>"},
          {"10", "\<\"TrabecularSurface\"\>"},
          {"11", "\<\"ExchTrabVol\"\>"},
          {"12", "\<\"NonExchTrabVol\"\>"},
          {"13", "\<\"CorticalSurf\"\>"},
          {"14", "\<\"CorticalVolExch\"\>"},
          {"15", "\<\"CorticalVolNonExch\"\>"},
          {"16", "\<\"Bladder\"\>"},
          {"17", "\<\"Urine\"\>"},
          {"18", "\<\"ULI\"\>"},
          {"19", "\<\"LLI\"\>"},
          {"20", "\<\"FEC\"\>"},
          {"21", "\<\"SI\"\>"},
          {"22", "\<\"ST\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[87]//TableForm="]
}, Open  ]],

Cell["\<\
 Transfer rates are taken from Table A.13.1. (ICRP 78) (For GI compartments \
are applied the transfer rate included in Options[qGI]).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[TransferRatesE[uranium], 
      TableHeadings \[Rule] {None, {"\<From\>", \ "\<to\>", "\<Tranfer Rates(\
\!\(days\^\(-1\)\))\>"}}]\)], "Input",
  CellLabel->"In[88]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"From\"\>", "\<\"to\"\>", "\<\"Tranfer \
Rates(\\!\\(days\\^\\(-1\\)\\))\"\>"},
          {"1", "3", "10.5`"},
          {"1", "2", "0.245`"},
          {"1", "16", "15.43`"},
          {"1", "8", "2.94`"},
          {"1", "9", "0.0122`"},
          {"1", "18", "0.122`"},
          {"1", "6", "0.367`"},
          {"1", "4", "1.63`"},
          {"1", "5", "0.0735`"},
          {"1", "10", "2.04`"},
          {"1", "13", "1.63`"},
          {"3", "1", "8.32`"},
          {"2", "1", "0.347`"},
          {"8", "16", "0.099`"},
          {"9", "1", "0.00038`"},
          {"6", "1", "0.092`"},
          {"6", "7", "0.00693`"},
          {"4", "1", "0.0347`"},
          {"5", "1", "0.000019`"},
          {"13", "1", "0.0693`"},
          {"13", "14", "0.0693`"},
          {"7", "1", "0.00019`"},
          {"11", "12", "0.00578`"},
          {"12", "1", "0.000493`"},
          {"15", "1", "0.0000821`"},
          {"14", "13", "0.0173`"},
          {"14", "15", "0.00578`"},
          {"10", "1", "0.0693`"},
          {"11", "10", "0.0173`"},
          {"10", "11", "0.0693`"},
          {"16", "17", "12"},
          {"18", "19", \(k\_ULI\)},
          {"19", "20", \(k\_LLI\)},
          {"21", "1", \(f\_B\ k\_SI\)},
          {"21", "18", \(k\_SI\)},
          {"22", "21", \(k\_ST\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"From", "to", 
          "Tranfer Rates(\!\(days\^\(-1\)\))"}}]]]], "Output",
  CellLabel->"Out[88]//TableForm="]
}, Open  ]],

Cell["\<\
 Because the decay constant is to small for major uranium nuclides (i.e: \
U-238, U-235,U-234)  we can assume \[Lambda]=0.  \
\>", "Commentary"],

Cell[BoxData[
    \(Clear[element, \ lambda, \ fn1, \ amad, \ class]\)], "Input",
  CellLabel->"In[89]:="],

Cell[BoxData[
    \(\(\(\(element = \ uranium\) \)\(;\)\(\(lambda\  = \ 
        0\) \)\(;\)\(\ \)\)\)], "Input",
  CellLabel->"In[90]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Injection", "SubsubsectionIcon"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Injection\>", \ "\<Acute\>", "\<BioassayTable\>", 1, fn1, 
      180, lambda]\)], "Input",
  CellLabel->"In[91]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nstart intake"\), \("Urine\n24 hours"\), \("Faecal\n\
24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "0.6449932072755635`", "0.0016844948036295042`", 
            "0.35332229792080494`"},
          {"2", "0.022107830794587946`", "0.0018721934697592938`", 
            "0.3293422736564576`"},
          {"3", "0.017996533842386097`", "0.0009470271556020259`", 
            "0.3103987126584694`"},
          {"4", "0.016268086997306783`", "0.0004240733478193589`", 
            "0.29370655231334314`"},
          {"5", "0.014761998386549478`", "0.00019775277818297063`", 
            "0.2787468011486108`"},
          {"6", "0.01343372554781235`", "0.00010579415738307915`", 
            "0.26520728144341527`"},
          {"7", "0.012255871179689595`", "0.00006791400322389661`", 
            "0.2528834962605018`"},
          {"8", "0.011206628512378022`", "0.00005108136993917563`", 
            "0.24162578637818452`"},
          {"9", "0.010268370221809847`", "0.00004249542890461965`", 
            "0.23131492072747006`"},
          {"10", "0.009426653244020734`", "0.00003728411486565694`", 
            "0.2218509833685836`"},
          {"20", "0.004388986642765327`", "0.000017644834662502422`", 
            "0.15904401685112626`"},
          {"30", "0.0023882219461080515`", "0.000011118757120538899`", 
            "0.127431659971103`"},
          {"40", "0.001500297786784656`", "8.03579509488116`*^-6", 
            "0.1088831515448547`"},
          {"50", "0.0010530171118237437`", "6.201380050512095`*^-6", 
            "0.09649539433790447`"},
          {"60", "0.0007950382368926544`", "4.942693027932504`*^-6", 
            "0.08743174853378056`"},
          {"70", "0.0006275219146554692`", "4.013623380382742`*^-6", 
            "0.0804110931032605`"},
          {"80", "0.00050892883693795`", "3.3022177867656045`*^-6", 
            "0.07478251109970258`"},
          {"90", "0.00042013167051884424`", "2.7459652040762796`*^-6", 
            "0.07017139401429967`"},
          {"100", "0.0003512740431893674`", "2.3046972525293853`*^-6", 
            "0.06633752447612262`"},
          {"180", "0.00010938711089866163`", "7.226341860277935`*^-7", 
            "0.0502751915932889`"},
          {"200", "0.00008577229634464372`", "5.669484165672536`*^-7", 
            "0.04833456716077967`"},
          {"300", "0.00003109183059881587`", "2.058710898844545`*^-7", 
            "0.043082284355448974`"},
          {"400", "0.000016077889604111488`", "1.0660483937363242`*^-7", 
            "0.04086756446229493`"},
          {"500", "0.000011549421935243276`", "7.665103043092724`*^-8", 
            "0.039521795879591114`"},
          {"600", "9.981574563073387`*^-6", "6.627280699573925`*^-8", 
            "0.03845103774778146`"},
          {"700", "9.266453644707698`*^-6", "6.153335249318073`*^-8", 
            "0.03748616158796023`"},
          {"800", "8.805804765902973`*^-6", "5.847698092858219`*^-8", 
            "0.03657789048834186`"},
          {"900", "8.429134147149887`*^-6", "5.597635612494177`*^-8", 
            "0.03571102162337206`"},
          {"1000", "8.087460264092836`*^-6", "5.370758741493148`*^-8", 
            "0.034880087700227116`"},
          {"2000", "5.469636236831582`*^-6", "3.632322639317845`*^-8", 
            "0.028159672966997427`"},
          {"3000", "3.8125327588181372`*^-6", "2.531871803668407`*^-8", 
            "0.023551142098997606`"},
          {"4000", "2.7516900475183133`*^-6", "1.827385108591414`*^-8", 
            "0.02028676045600979`"},
          {"5000", "2.063133851935243`*^-6", "1.3701261268395722`*^-8", 
            "0.01788810080285192`"},
          {"6000", "1.6079478908524389`*^-6", "1.0678435632266448`*^-8", 
            "0.016055932167292106`"},
          {"7000", "1.2998643146946466`*^-6", "8.632487935805402`*^-9", 
            "0.014602227389040292`"},
          {"8000", "1.0852194445615422`*^-6", "7.2070491171753205`*^-9", 
            "0.013408068481095284`"},
          {"9000", "9.305537812683527`*^-7", "6.179921676362953`*^-9", 
            "0.012397570831212713`"},
          {"10000", "8.149385301381776`*^-7", "5.412121808292424`*^-9", 
            "0.011521718557092796`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nstart intake", 
          "Urine\n24 hours", "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
  CellLabel->"Out[91]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Injection\>", \ "\<Constant\>", "\<GraphicReport\>", 1, 
      fn1, 180, lambda]\)], "Input",
  CellLabel->"In[92]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.608025 0.185993 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .05005 -34 -6.28125 ]
[-0.0125 .05005 0 6.28125 ]
[-0.0125 .18005 -34 -6.28125 ]
[-0.0125 .18005 0 6.28125 ]
[-0.0125 .23604 -28 -6.28125 ]
[-0.0125 .23604 0 6.28125 ]
[-0.0125 .36604 -28 -6.28125 ]
[-0.0125 .36604 0 6.28125 ]
[-0.0125 .42203 -22 -6.28125 ]
[-0.0125 .42203 0 6.28125 ]
[-0.0125 .55204 -22 -6.28125 ]
[-0.0125 .55204 0 6.28125 ]
[-0.0125 .60802 -10 -6.28125 ]
[-0.0125 .60802 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .05005 m
.00625 .05005 L
s
gsave
-0.0125 .05005 -95 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .18005 m
.00625 .18005 L
s
gsave
-0.0125 .18005 -95 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.005) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .23604 m
.00625 .23604 L
s
gsave
-0.0125 .23604 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .36604 m
.00625 .36604 L
s
gsave
-0.0125 .36604 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .42203 m
.00625 .42203 L
s
gsave
-0.0125 .42203 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .55204 m
.00625 .55204 L
s
gsave
-0.0125 .55204 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .60802 m
.00625 .60802 L
s
gsave
-0.0125 .60802 -71 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .10604 m
.00375 .10604 L
s
0 .13879 m
.00375 .13879 L
s
0 .16202 m
.00375 .16202 L
s
0 .19478 m
.00375 .19478 L
s
0 .20723 m
.00375 .20723 L
s
0 .21801 m
.00375 .21801 L
s
0 .22753 m
.00375 .22753 L
s
0 .29203 m
.00375 .29203 L
s
0 .32478 m
.00375 .32478 L
s
0 .34802 m
.00375 .34802 L
s
0 .38077 m
.00375 .38077 L
s
0 .39322 m
.00375 .39322 L
s
0 .40401 m
.00375 .40401 L
s
0 .41352 m
.00375 .41352 L
s
0 .47802 m
.00375 .47802 L
s
0 .51077 m
.00375 .51077 L
s
0 .53401 m
.00375 .53401 L
s
0 .56676 m
.00375 .56676 L
s
0 .57921 m
.00375 .57921 L
s
0 .59 m
.00375 .59 L
s
0 .59951 m
.00375 .59951 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Constant) show
117.000 12.813 moveto
(intake) show
153.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .55628 m
.41107 .58483 L
.53436 .59139 L
.60372 .59463 L
.65224 .59653 L
.69278 .59788 L
.72483 .59881 L
.75369 .59956 L
.77776 .60013 L
.79827 .60059 L
.81784 .601 L
.83489 .60133 L
.84991 .60161 L
.86466 .60187 L
.87782 .60208 L
.89084 .60229 L
.90257 .60246 L
.91318 .60261 L
.92384 .60275 L
.93355 .60287 L
.94333 .60298 L
.95229 .60308 L
.96051 .60317 L
.96887 .60325 L
.97619 .60332 L
s
0 0 1 r
[ ] 0 setdash
.02381 .01472 m
.08838 .08272 L
.13894 .12275 L
.17652 .14452 L
.20509 .15696 L
.23381 .16634 L
.2606 .1727 L
.28275 .17652 L
.30107 .17889 L
.31822 .1806 L
.33295 .18175 L
.36263 .18347 L
.38757 .18452 L
.41107 .18534 L
.53436 .18904 L
.60612 .19101 L
.6559 .19229 L
.69367 .19322 L
.72681 .19401 L
.7539 .19463 L
.77888 .19518 L
.8001 .19563 L
.81844 .196 L
.83611 .19633 L
.85167 .19661 L
.86547 .19685 L
.87911 .19707 L
.89134 .19726 L
.90351 .19744 L
.91451 .19759 L
.92451 .19772 L
.93458 .19784 L
.94378 .19795 L
.95221 .19804 L
.96078 .19813 L
.96867 .19821 L
.97619 .19828 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[92]:=",
  ImageSize->{600, 294.25},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[92]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ingestion", "SubsubsectionIcon"],

Cell[TextData[{
  "We are going to evaluate the daily urine and faecal excretion for a single \
intake ",
  Cell[BoxData[
      \(I\_0\)]],
  "= 1 by ingestion in t = 0 for f1= 0.05 and f = 0.002"
}], "Text",
  CellTags->"ICRP 78"],

Cell["Here is calculated the  for f1 = 0.05", "MathCaption"],

Cell[BoxData[
    \(\(fn1\  = \ 0.05;\)\)], "Input",
  CellLabel->"In[93]:="],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
        element, "\<Ingestion\>", \ "\<Acute\>", "\<BioassayTable\>", 1, fn1, 
        180, lambda] // Chop\)], "Input",
  CellLabel->"In[94]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nstart intake"\), \("Urine\n24 hours"\), \("Faecal\n\
24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "0.03147712596649703`", "0.27179267676434227`", 
            "0.6967301972691612`"},
          {"2", "0.0016819494056936196`", "0.36878792761727486`", 
            "0.32626032024619256`"},
          {"3", "0.0009219725242209445`", "0.18581016304749487`", 
            "0.1395281846744765`"},
          {"4", "0.0008298434175361066`", "0.07665608565402782`", 
            "0.06204225560291223`"},
          {"5", "0.000752524918290684`", "0.029573751451708263`", 
            "0.03171597923291326`"},
          {"6", "0.0006844336598675962`", "0.01110795844626522`", 
            "0.019923587126780523`"},
          {"7", "0.0006241161834207171`", "0.004125342387845232`", 
            "0.015174128555514383`"},
          {"8", "0.00057043178872139`", "0.0015251538819045507`", 
            "0.013078542884888465`"},
          {"9", "0.0005224610762058976`", "0.0005633043792233616`", 
            "0.011992777429459112`"},
          {"10", "0.00047945279687303805`", "0.00020849942492129347`", 
            "0.011304825207664534`"},
          {"20", "0.00022250641382120379`", "9.017961815072084`*^-7", 
            "0.007995274347155372`"},
          {"30", "0.00012070092551194622`", "5.60185303033478`*^-7", 
            "0.006395154098741869`"},
          {"40", "0.0000756262223059953`", "4.0409020718445987`*^-7", 
            "0.0054590400155388056`"},
          {"50", "0.00005298213369406973`", "3.115641964424043`*^-7", 
            "0.004835252582213647`"},
          {"60", "0.00003995616703893201`", "2.48208601671962`*^-7", 
            "0.004379519584163629`"},
          {"70", "0.000031515543829852`", "2.0149185553375304`*^-7", 
            "0.0040268237002981395`"},
          {"80", "0.000025548461942859202`", "1.657392256770862`*^-7", 
            "0.003744213927367176`"},
          {"90", "0.00002108454430690271`", "1.3779346585973684`*^-7", 
            "0.003512772515613041`"},
          {"100", "0.000017624942059035753`", "1.1563013724291693`*^-7", 
            "0.003320391604628054`"},
          {"180", "5.483102213071911`*^-6", "3.6222290056286965`*^-8", 
            "0.0025148560873284142`"},
          {"200", "4.298761161210252`*^-6", "2.841434620926009`*^-8", 
            "0.0024175883619969637`"},
          {"300", "1.5572255689169645`*^-6", "1.0310965747883927`*^-8", 
            "0.0021544263146662584`"},
          {"400", "8.046619387538922`*^-7", "5.335317521115712`*^-9", 
            "0.002043539811574915`"},
          {"500", "5.777176171339882`*^-7", "3.834182749073989`*^-9", 
            "0.0019762059722933426`"},
          {"600", "4.991763572007035`*^-7", "3.314286955991008`*^-9", 
            "0.0019226523332000502`"},
          {"700", "4.633767717032722`*^-7", "3.077026522468884`*^-9", 
            "0.0018744013411555699`"},
          {"800", "4.4033076196381415`*^-7", "2.9241181698225205`*^-9", 
            "0.001828983153656763`"},
          {"900", "4.2149223623833`*^-7", "2.799053766544546`*^-9", 
            "0.0017856359203664105`"},
          {"1000", "4.044060354924106`*^-7", "2.685598632368169`*^-9", 
            "0.0017440857856217211`"},
          {"2000", "2.735024205655079`*^-7", "1.8162983339564676`*^-9", 
            "0.0014080387010360698`"},
          {"3000", "1.9063976256644688`*^-7", "1.266023064161459`*^-9", 
            "0.0011775954790643598`"},
          {"4000", "1.3759296102477947`*^-7", "9.137485212917795`*^-10", 
            "0.0010143657196028885`"},
          {"5000", "1.0316223235384836`*^-7", "6.850997547047655`*^-10", 
            "0.0008944258066353206`"},
          {"6000", "8.040109966689357`*^-8", "5.339466646603341`*^-10", 
            "0.0008028127933842489`"},
          {"7000", "6.499576011426145`*^-8", "4.316415003202678`*^-10", 
            "0.0007301244535653442`"},
          {"8000", "5.426277552289527`*^-8", "3.60364516005518`*^-10", 
            "0.0006704143477132688`"},
          {"9000", "4.652901335749915`*^-8", "3.09004821730241`*^-10", 
            "0.0006198879084516602`"},
          {"10000", "4.074793607394822`*^-8", "2.7061286544949326`*^-10", 
            "0.0005760941310205232`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nstart intake", 
          "Urine\n24 hours", "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
  CellLabel->"Out[94]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Ingestion\>", \ "\<Constant\>", "\<GraphicReport\>", 1, 
      fn1, 180, lambda]\)], "Input",
  CellLabel->"In[95]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.611091 0.351129 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .01453 -28 -6.28125 ]
[-0.0125 .01453 0 6.28125 ]
[-0.0125 .15426 -28 -6.28125 ]
[-0.0125 .15426 0 6.28125 ]
[-0.0125 .25996 -22 -6.28125 ]
[-0.0125 .25996 0 6.28125 ]
[-0.0125 .36566 -22 -6.28125 ]
[-0.0125 .36566 0 6.28125 ]
[-0.0125 .50539 -22 -6.28125 ]
[-0.0125 .50539 0 6.28125 ]
[-0.0125 .61109 -10 -6.28125 ]
[-0.0125 .61109 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01453 m
.00625 .01453 L
s
gsave
-0.0125 .01453 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .15426 m
.00625 .15426 L
s
gsave
-0.0125 .15426 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .25996 m
.00625 .25996 L
s
gsave
-0.0125 .25996 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .36566 m
.00625 .36566 L
s
gsave
-0.0125 .36566 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .50539 m
.00625 .50539 L
s
gsave
-0.0125 .50539 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61109 m
.00625 .61109 L
s
gsave
-0.0125 .61109 -71 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .07636 m
.00375 .07636 L
s
0 .12023 m
.00375 .12023 L
s
0 .18206 m
.00375 .18206 L
s
0 .20557 m
.00375 .20557 L
s
0 .22593 m
.00375 .22593 L
s
0 .24389 m
.00375 .24389 L
s
0 .42749 m
.00375 .42749 L
s
0 .47136 m
.00375 .47136 L
s
0 .53319 m
.00375 .53319 L
s
0 .5567 m
.00375 .5567 L
s
0 .57706 m
.00375 .57706 L
s
0 .59502 m
.00375 .59502 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Constant) show
117.000 12.813 moveto
(intake) show
153.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .01472 m
.06042 .05711 L
.08838 .07552 L
.1161 .08414 L
.13894 .08756 L
.15779 .08928 L
.17363 .0904 L
.20509 .09243 L
.30107 .09959 L
.41107 .11002 L
.53436 .12264 L
.6034 .12883 L
.65174 .13245 L
.69219 .13502 L
.72416 .13678 L
.75297 .13821 L
.77701 .13931 L
.79749 .14017 L
.81703 .14095 L
.83406 .14158 L
.85058 .14216 L
.8652 .14264 L
.87825 .14305 L
.89118 .14343 L
.90282 .14375 L
.91336 .14403 L
.92395 .14429 L
.9336 .14452 L
.94333 .14473 L
.95224 .14492 L
.96042 .14508 L
.96873 .14524 L
.97619 .14537 L
s
0 0 1 r
[ ] 0 setdash
.02381 .2477 m
.08838 .39352 L
.13894 .48006 L
.17652 .52634 L
.20509 .55231 L
.23381 .57147 L
.24823 .57882 L
.2606 .58406 L
.28136 .5909 L
.29192 .59357 L
.30107 .5955 L
.3181 .59829 L
.32685 .59937 L
.3348 .60018 L
.3481 .60123 L
.35523 .60166 L
.3616 .60198 L
.36888 .60228 L
.37548 .6025 L
.38721 .60279 L
.39348 .60291 L
.39906 .60299 L
.40544 .60307 L
.41107 .60312 L
.42097 .60319 L
.4262 .60322 L
.43103 .60324 L
.43929 .60326 L
.4438 .60327 L
.44788 .60328 L
.45612 .60329 L
.46066 .6033 L
.46482 .6033 L
.47291 .60331 L
.47731 .60331 L
.48125 .60331 L
.4848 .60331 L
.48852 .60331 L
.49505 .60331 L
.49892 .60331 L
.50251 .60331 L
.50904 .60331 L
.51569 .60331 L
.52162 .60331 L
.53436 .60331 L
.55393 .60331 L
.57052 .60331 L
.60347 .60331 L
.65291 .60332 L
.69401 .60332 L
Mistroke
.72643 .60332 L
.753 .60332 L
.77759 .60332 L
.79851 .60332 L
.8184 .60332 L
.83572 .60332 L
.85097 .60332 L
.8659 .60332 L
.87922 .60332 L
.89118 .60332 L
.90311 .60332 L
.9139 .60332 L
.92471 .60332 L
.93456 .60332 L
.94356 .60332 L
.95267 .60332 L
.96103 .60332 L
.96873 .60332 L
.97619 .60332 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[95]:=",
  ImageSize->{600, 294.25},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[95]="]
}, Open  ]],

Cell["Here is calculated the  for f1 = 0.002", "MathCaption"],

Cell[BoxData[
    \(\(fn1\  = \ 0.002;\)\)], "Input",
  CellLabel->"In[96]:="],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
        element, "\<Ingestion\>", \ "\<Acute\>", "\<BioassayTable\>", 1, fn1, 
        180, lambda] // Chop\)], "Input",
  CellLabel->"In[97]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nstart intake"\), \("Urine\n24 hours"\), \("Faecal\n\
24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "0.0012556418195924126`", "0.2819493959191489`", 
            "0.7167949622142158`"},
          {"2", "0.00007037261284842996`", "0.38827660082994786`", 
            "0.3284479887712703`"},
          {"3", "0.000036943425899794166`", "0.19654394616105397`", 
            "0.13186709918432044`"},
          {"4", "0.00003322095439477332`", "0.08119842403428335`", 
            "0.05063545419564694`"},
          {"5", "0.000030124677882795332`", "0.031341490749493994`", 
            "0.01926383876827469`"},
          {"6", "0.000027398248152640456`", "0.011772976030758109`", 
            "0.0074634644893684056`"},
          {"7", "0.000024983194766353342`", "0.004371265771471511`", 
            "0.003067215523134944`"},
          {"8", "0.000022833803229175328`", "0.0016147922612762544`", 
            "0.0014295894586339724`"},
          {"9", "0.00002091323318922011`", "0.0005951948332687529`", 
            "0.000813481392180533`"},
          {"10", "0.000019191385567005406`", "0.00021918549194577253`", 
            "0.0005751045146722913`"},
          {"20", "8.905238671029578`*^-6", "4.56672922810597`*^-8", 
            "0.0003198863593499817`"},
          {"30", "4.830134561365461`*^-6", "2.241474372777219`*^-8", 
            "0.0002558442327258176`"},
          {"40", "3.026040509712929`*^-6", "1.6167326810645477`*^-8", 
            "0.00021838555685511159`"},
          {"50", "2.119821229755285`*^-6", "1.2464978049742115`*^-8", 
            "0.0001934269331363514`"},
          {"60", "1.5985763038130554`*^-6", "9.930072875086182`*^-9", 
            "0.0001751934924548452`"},
          {"70", "1.2608464054612335`*^-6", "8.060978218260573`*^-9", 
            "0.00016108297582508114`"},
          {"80", "1.0221026517666897`*^-6", "6.630579196809094`*^-9", 
            "0.00014977668407300124`"},
          {"90", "8.435071430137192`*^-7", "5.512534761997756`*^-9", 
            "0.0001405176031396549`"},
          {"100", "7.050961198344641`*^-7", "4.625840599459252`*^-9", 
            "0.00013282126154379236`"},
          {"180", "2.1934615208494754`*^-7", "1.4490368904773732`*^-9", 
            "0.00010059595588413203`"},
          {"200", "1.7196672846180386`*^-7", "1.136681082591906`*^-9", 
            "0.00009670486740176493`"},
          {"300", "6.22932479258341`*^-8", "4.124667274396643`*^-10", 
            "0.00008617750688004203`"},
          {"400", "3.218770841485405`*^-8", "2.1342072553665048`*^-10", 
            "0.00008174180575851903`"},
          {"500", "2.3109099949597534`*^-8", "1.5336998338000285`*^-10", 
            "0.00007904837976719807`"},
          {"600", "1.996721073508831`*^-8", "1.325727305712121`*^-10", 
            "0.00007690620937732281`"},
          {"700", "1.8535157483064862`*^-8", "1.2308143393369164`*^-10", 
            "0.00007497615857163714`"},
          {"800", "1.761329534088682`*^-8", "1.1696532631333412`*^-10", 
            "0.0000731594240311365`"},
          {"900", "1.6859746306083917`*^-8", "1.119625503420707`*^-10", 
            "0.00007142552900126581`"},
          {"1000", "1.6176294261559254`*^-8", "1.0742418066200798`*^-10", 
            "0.00006976351846819613`"},
          {"2000", "1.0940129799904413`*^-8", "0", 
            "0.00005632159612011475`"},
          {"3000", "7.625611503792734`*^-9", "0", "0.00004710384316428291`"},
          {"4000", "5.503731975806808`*^-9", "0", 
            "0.000040574637876933465`"},
          {"5000", "4.1264981587990635`*^-9", "0", 
            "0.000035777032117167046`"},
          {"6000", "3.216049915526903`*^-9", "0", 
            "0.000032112505853404026`"},
          {"7000", "2.599834475740942`*^-9", "0", 
            "0.000029204968700570344`"},
          {"8000", "2.170513906628313`*^-9", "0", 
            "0.000026816562256545805`"},
          {"9000", "1.8611626536810255`*^-9", "0", 
            "0.000024795503317590302`"},
          {"10000", "1.6299190577946654`*^-9", "0", 
            "0.00002304375137887847`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nstart intake", 
          "Urine\n24 hours", "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
  CellLabel->"Out[97]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Ingestion\>", \ "\<Constant\>", "\<GraphicReport\>", 1, 
      fn1, 180, lambda]\)], "Input",
  CellLabel->"In[98]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238082 0.422291 0.603483 0.189829 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .034 -34 -6.28125 ]
[-0.0125 .034 0 6.28125 ]
[-0.0125 .16668 -34 -6.28125 ]
[-0.0125 .16668 0 6.28125 ]
[-0.0125 .22383 -28 -6.28125 ]
[-0.0125 .22383 0 6.28125 ]
[-0.0125 .35651 -28 -6.28125 ]
[-0.0125 .35651 0 6.28125 ]
[-0.0125 .41365 -22 -6.28125 ]
[-0.0125 .41365 0 6.28125 ]
[-0.0125 .54634 -22 -6.28125 ]
[-0.0125 .54634 0 6.28125 ]
[-0.0125 .60348 -10 -6.28125 ]
[-0.0125 .60348 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35241 0 m
.35241 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .034 m
.00625 .034 L
s
gsave
-0.0125 .034 -95 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .16668 m
.00625 .16668 L
s
gsave
-0.0125 .16668 -95 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.005) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .22383 m
.00625 .22383 L
s
gsave
-0.0125 .22383 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .35651 m
.00625 .35651 L
s
gsave
-0.0125 .35651 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .41365 m
.00625 .41365 L
s
gsave
-0.0125 .41365 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .54634 m
.00625 .54634 L
s
gsave
-0.0125 .54634 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .60348 m
.00625 .60348 L
s
gsave
-0.0125 .60348 -71 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .09114 m
.00375 .09114 L
s
0 .12457 m
.00375 .12457 L
s
0 .14828 m
.00375 .14828 L
s
0 .18171 m
.00375 .18171 L
s
0 .19442 m
.00375 .19442 L
s
0 .20543 m
.00375 .20543 L
s
0 .21514 m
.00375 .21514 L
s
0 .28097 m
.00375 .28097 L
s
0 .3144 m
.00375 .3144 L
s
0 .33811 m
.00375 .33811 L
s
0 .37154 m
.00375 .37154 L
s
0 .38425 m
.00375 .38425 L
s
0 .39526 m
.00375 .39526 L
s
0 .40497 m
.00375 .40497 L
s
0 .4708 m
.00375 .4708 L
s
0 .50423 m
.00375 .50423 L
s
0 .52794 m
.00375 .52794 L
s
0 .56137 m
.00375 .56137 L
s
0 .57408 m
.00375 .57408 L
s
0 .58509 m
.00375 .58509 L
s
0 .5948 m
.00375 .5948 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Constant) show
117.000 12.813 moveto
(intake) show
153.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .01472 m
.06042 .0379 L
.08838 .04814 L
.1161 .05302 L
.13894 .05498 L
.15779 .05595 L
.17363 .05658 L
.20509 .05769 L
.30107 .06157 L
.41107 .06721 L
.53436 .07404 L
.6034 .07739 L
.65174 .07935 L
.69219 .08074 L
.72416 .08169 L
.75297 .08246 L
.77701 .08305 L
.79749 .08352 L
.81703 .08394 L
.83406 .08428 L
.85058 .0846 L
.8652 .08486 L
.87825 .08508 L
.89118 .08528 L
.90282 .08546 L
.91336 .08561 L
.92395 .08575 L
.9336 .08587 L
.94333 .08599 L
.95224 .08609 L
.96042 .08618 L
.96873 .08626 L
.97619 .08634 L
s
0 0 1 r
[ ] 0 setdash
.02381 .40961 m
.08838 .48891 L
.13894 .53607 L
.17652 .56132 L
.20509 .57549 L
.23381 .58595 L
.24823 .58995 L
.2606 .59281 L
.28136 .59655 L
.29192 .598 L
.30107 .59906 L
.3181 .60058 L
.32685 .60117 L
.3348 .60161 L
.3481 .60219 L
.35523 .60242 L
.3616 .60259 L
.36888 .60276 L
.37548 .60288 L
.38721 .60304 L
.39348 .6031 L
.39906 .60314 L
.40544 .60319 L
.41107 .60322 L
.42097 .60325 L
.4262 .60327 L
.43103 .60328 L
.43929 .60329 L
.4438 .6033 L
.44788 .6033 L
.45612 .60331 L
.46066 .60331 L
.46482 .60331 L
.4688 .60331 L
.47291 .60332 L
.47731 .60332 L
.48125 .60332 L
.485 .60332 L
.48847 .60332 L
.49239 .60332 L
.49589 .60332 L
.50206 .60332 L
.50546 .60332 L
.50853 .60332 L
.5116 .60332 L
.51484 .60332 L
.51833 .60332 L
.52153 .60332 L
.52506 .60332 L
.52835 .60332 L
Mistroke
.53126 .60332 L
.53436 .60332 L
.53722 .60332 L
.53981 .60332 L
.5448 .60332 L
.54922 .60332 L
.55377 .60332 L
.55855 .60332 L
.56289 .60332 L
.5724 .60332 L
.60177 .60332 L
.65176 .60332 L
.69322 .60332 L
.72587 .60332 L
.7526 .60332 L
.77732 .60332 L
.79834 .60332 L
.8165 .60332 L
.83405 .60332 L
.84948 .60332 L
.86459 .60332 L
.87804 .60332 L
.89012 .60332 L
.90215 .60332 L
.91303 .60332 L
.92393 .60332 L
.93385 .60332 L
.94291 .60332 L
.95209 .60332 L
.96051 .60332 L
.96826 .60332 L
.97616 .60332 L
.97619 .60332 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0333333 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.1 0.361111 0.433333 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .26667 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.566667 0.361111 0.9 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .73333 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{600, 294.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;^0001Ka000`40O003h00Oogooogool7oo003o
OoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogoo
l7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00
ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomo
oo1oo`00ogooogool7oo001<Ool5000eOol5001;Ool4000dOol50003Ool4000_Ool50004Ool40013
Ool40004Ool4000/Ool50003Ool40004Ool4000WOol50004Ool40004Ool4003=Ool004ioo`03001o
ogoo03Eoo`05001oogooOol0001:Ool00`00Oomoo`02Ool00`00Oomoo`0cOol00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`0/Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol0
?goo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo02]oo`03001oogoo009oo`03001oogoo
009oo`04001oogoo0004Ool00`00Oomoo`0TOol01@00Oomoogoo00000goo00<007ooOol00Woo00@0
07ooOol000Aoo`03001oogoo0<Yoo`00CWoo00<007ooOol0=Woo00<007ooOol0D7oo00<007ooOol0
<goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0;Goo00<007ooOol017oo00<007ooOol0
0Woo00<007ooOol0A7oo00@007ooOol000Aoo`03001oogoo02]oo`03001oogoo009oo`03001oogoo
009oo`04001oogoo0004Ool00`00Oomoo`0UOol00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomo
o`0017oo00<007ooOol0bWoo001>Ool00`00Oomoo`0gOol00`00Oomoo`1?Ool00`00Oomoo`0cOol0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0^Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Oomoo`14Ool01000Oomoo`0017oo00<007ooOol0:goo00<007ooOol00Woo00<007ooOol00Woo
00@007ooOol000Aoo`03001oogoo02Ioo`03001oogoo00=oo`03001oogoo009oo`04001oogoo0004
Ool00`00Oomoo`3:Ool004ioo`03001oogoo03Qoo`03001oogoo04Yoo`@003Ioo`03001oogoo009o
o`03001oogoo009oo`03001oogoo02moo`03001oogoo009oo`03001oogoo009oo`03001oogoo041o
o`@000=oo`03001oogoo009oo`03001oogoo02]oo`03001oogoo009oo`03001oogoo009oo`04001o
ogoo0004Ool00`00Oomoo`0WOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<0
07ooOol0bWoo001>Ool00`00Oomoo`0iOol00`00Oomoo`19Ool00`00Oomoo`0gOol00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`0`Ool01@00Oomoogoo000017oo00<007ooOol0@7oo00<007oo
Ool017oo00<007ooOol00Woo00<007ooOol0:goo00<007ooOol00Woo00<007ooOol00Woo00@007oo
Ool000Aoo`03001oogoo02Qoo`05001oogooOol00004Ool01000Oomoo`0017oo00<007ooOol0bWoo
001<Ool3000gOol01@00Oomoogoo0000Bgoo00<007ooOol0=Goo0`0017oo00<007ooOol00Woo00<0
07ooOol0;7oo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo041oo`03001oogoo00Ao
o`03001oogoo009oo`03001oogoo02Uoo`<000Aoo`03001oogoo009oo`04001oogoo0004Ool00`00
Oomoo`0TOol01@00Oomoogoo00000goo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo0<Yo
o`00CWoo00<007ooOol0=Woo0`00C7oo1@00=Goo00<007ooOol00goo1000<7oo0`001Goo1000@goo
1@000goo1000;Woo00<007ooOol00goo100017oo1000:7oo0`001Goo100017oo1000cGoo003oOooo
Ooo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooc]oo`<00;9oo`00ogoo
ogoo?Goo00<007ooOol0/7oo003oOoooOol[Ool300000goo00000002Ool300000goo00000004Ool0
0`00Oomoo`02Ool5002YOol00?mooomoobYoo`04001oogooOol20002Ool01000Oomoogoo0P0017oo
00<007oo00000goo00<007ooOol00Woo00<007ooOol0YWoo0012Oooo003H000?Ool00`00Oomoo`02
Ool01000Oomoo`0017oo00<007ooOol00Woo00<007oo000027oo00<007ooOol0YWoo0012Ool00`00
Oomoo`08Ool00`00Oomoo`0iOol00`00Oomoo`0POol00`00Oomoo`0FOol00`00Oomoo`0@Ool00`00
Oomoo`0=Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00
Oomoo`0iOol00`00Oomoo`0POol00`00Oomoo`0EOol00`00Oomoo`0AOol00`00Oomoo`0<Ool00`00
Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0iOol00`00
Oomoo`0?Ool00`00Oomoo`02Ool01000Oomoogoo1@000goo00D007ooOomoo`0000=oo`@00:Uoo`00
@Woo00<007ooOol027oo00<007ooOol0>Goo00<007ooOol087oo00<007ooOol05Woo00<007ooOol0
47oo00<007ooOol03Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol01goo00<007ooOol0
1Woo00<007ooOol0>Goo00<007ooOol087oo00<007ooOol05Goo00<007ooOol04Goo00<007ooOol0
37oo00<007ooOol02goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01Woo00<007ooOol0
>Goo00<007ooOol03goo00@007ooOomoo`80009oo`03001oogoo009oo`05001oogooOol00003Ool0
1000Oomoo`0017oo00<007ooOol0YWoo0012Ool00`00Oomoo`08Ool00`00Oomoo`0iOol00`00Oomo
o`1<Ool00`00Oomoo`0iOol00`00Oomoo`0iOol00`00Oomoo`1<Ool00`00Oomoo`0hOol00`00Oomo
o`0iOol00`00Oomoo`0@Ool300000goo001oo`02Ool40003Ool3000017oo000000000Woo1@00Z7oo
0012Ool00`00Oomoo`3oOooYOol00`00Oomoo`2nOol0049oo`03001oogoo0?moonQoo`800<1oo`00
@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomoo`08Ool00g`0Oomoo`3oOoooOonPOol0049o
o`03001oogoo00Uoo`9l0?mooomooj1oo`00@Woo00<007ooOol02goo0W`0ogooogooWWoo0012Ool0
0`00Oomoo`0=Ool00g`0Oomoo`3oOoooOonKOol0049oo`03001oogoo0?mooomooj]oo`00@Woo00<0
07ooOol04Goo00=l07ooOol0ogooogooUgoo0012Ool00`00Oomoo`0BOol00g`0Oomoo`3oOoooOonF
Ool001Ioo`@000Eoo`8000Eoo`@000Aoo`@000Aoo`D000Moo`03001oogoo01=oo`9l0?mooomooiIo
o`005Goo00<007ooOol00Woo00<007ooOol00Woo0P0017oo00<007ooOol00Woo00@007ooOol000Ao
o`03001oogoo00=oo`03001oogoo00Moo`03001oogoo01Eoo`03O01oogoo0?mooomooi=oo`005Goo
00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00=o
o`03001oogoo00Moo`@00?mooomoojYoo`005Goo00<007ooOol00Woo00<007ooOol027oo00<007oo
Ool00Woo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo0?mooomooj]o
o`005Goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00@007ooOol000Aoo`03001o
ogoo00=oo`03001oogoo00Moo`03001oogoo01Uoo`=l0?mooomoohmoo`005Goo00<007ooOol00Woo
00<007ooOol027oo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo00Mo
o`03001oogoo01aoo`=l0?mooomoohaoo`005Goo00<007ooOol00Woo00<007ooOol027oo00<007oo
Ool00Woo00@007ooOol000Aoo`04001oogooOol30009Ool00`00Oomoo`3oOoooOon[Ool001Ioo`@0
00aoo`@000Aoo`@000Ioo`03001oogoo00Moo`03001oogoo02=oo`03O01oogoo0?mooomoohEoo`00
@Woo00<007ooOol097oo0W`0ogooogooQGoo0012Ool00`00Oomoo`0VOol2O03oOoooOon3Ool0049o
o`03001oogoo02aoo`Il0?mooomoogUoo`00@Woo00<007ooOol0=Woo0g`0ogooogooLWoo0012Ool0
0`00Oomoo`0iOol3O004Ool6O004Ool3O03oOoooOomNOol0049oo`03001oogoo04eoo`=l00Aoo`Il
00Aoo`Il00Aoo`=l0?mooomood1oo`00@Woo00<007ooOol0Jgoo0g`017oo1W`017oo1W`0ogooogoo
:Goo0012Ool00`00Oomoo`26Ool6O004Ool6O03oOoooOolEOol0049oo`03001oogoo09Yoo`Il00Ao
o`Il0?mooomoo`5oo`00@Woo00<007ooOol0[Woo1W`017oo1W`0ogook7oo0012Ool00`00Oomoo`32
Ool6O004Ool3O03oOooKOol0049oo`03001oogoo0<moo`=l00Aoo`Il00Aoo`=l0?moolMoo`00@Woo
00<007ooOol0hgoo0g`017oo1W`0ogoo^Woo0012Ool00`00Oomoo`3dOol6O004Ool6O004Ool3O03o
OonOOol0049oo`03001oogoo0?moo`aoo`=l00Aoo`Il00Aoo`=l0?mooh]oo`00@Woo00<007ooOol0
ogoo87oo0g`017oo1W`017oo1W`0ogooM7oo0012Ool00`00Oomoo`3oOolkOol6O004Ool6O004Ool6
O03oOomFOol0049oo`03001oogoo0?mooeUoo`Il00Aoo`Il00Aoo`Il00Aoo`Il00Aoo`=l0?moobMo
o`00@Woo00<007ooOol0ogooQ7oo0g`017oo1W`017oo1W`017oo1W`017oo1W`017oo1W`017oo1W`0
igoo0012Ool00`00Oomoo`3oOoo7Ool3O03POol0049oo`03001oogoo0?mooomooj]oo`00@Woo0`00
ogooogooZgoo0012Ool00`00Oomoo`3oOoooOon[Ool0049oo`03001oogoo0?mooomooj]oo`00@Woo
00<007ooOol0ogooogooZgoo0012Ool00`00Oomoo`3oOoooOon[Ool0049oo`03001oogoo0?mooomo
oj]oo`00@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomoo`3oOoooOon[Ool0049oo`03001o
ogoo0?mooomooj]oo`00@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomoo`3oOoooOon[Ool0
049oo`03001oogoo0?mooomooj]oo`00@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomoo`3o
OoooOon[Ool0049oo`03001oogoo0?mooomooj]oo`00@Woo0`00ogooogooZgoo0012Ool00`00Oomo
o`3oOoooOol:Oon=000DOol0049oo`03001oogoo0?mooomoo`Yoohd001Aoo`00@Woo00<007ooOol0
ogooogoo2WooS@0057oo0012Ool00`00Oomoo`3oOoooOol:Oon=000DOol0049oo`03001oogoo0?mo
oomoo`Aooi<001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool0
0`00Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03
001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012
Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Ao
o`03001oogoo08Yoo`H001Aoo`00@Woo0`00ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool0
0`00Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03
001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012
Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Ao
o`03001oogoo08Yoo`H001Aoo`005Woo10001Goo0P001Goo100017oo100017oo100027oo00<007oo
Ool0ogooogoo17oo00<007ooOol0RWoo1P0057oo000EOol00`00Oomoo`02Ool00`00Oomoo`02Ool2
0004Ool00`00Oomoo`02Ool01000Oomoo`0017oo00@007ooOol000Aoo`03001oogoo00Eoo`03001o
ogoo0?mooomoo`Aoo`03001oogoo08Yoo`H001Aoo`005Goo00<007ooOol00Woo00<007ooOol027oo
00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Eoo`03001oogoo00Eoo`@00?mooomoo`=o
o`03001oogoo08Yoo`H001Aoo`005Goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo
00@007ooOol000Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo0?mooomoo`Aoo`03001o
ogoo08Yoo`H001Aoo`005Goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00@007oo
Ool000Aoo`04001oogooOol40008Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0
01Eoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`04001oogoo0004Ool01@00Oomo
ogoo00002goo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo000EOol00`00Oomoo`02
Ool00`00Oomoo`08Ool00`00Oomoo`02Ool01000Oomoo`0017oo00D007ooOomoo`0000]oo`03001o
ogoo0?mooomoo`Aoo`03001oogoo08Yoo`H001Aoo`005Woo100037oo100017oo100017oo1@001goo
00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool0
0`00Oomoo`2:Ool6000DOol0049oo`<00?mooomoo`Aoo`03001oogoo08Yoo`H001Aoo`00@Woo00<0
07ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool00`00
Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo08Yoo`H001Aoo`00@Woo
00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool0
0`00Oomoo`2:Ool6000DOol0049oo`<00?mooomoo`Aoo`03001oogoo03eoo`H0009oo`80009oo`80
00=oo`@000=oo`D000Aoo`D000Aoo`<000Aoo`D000=oo`@000=oo`<00004Ool000000006Ool6000D
Ool0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo03ioo`05001oogooOol00003Ool01000Oomo
o`000goo00<007ooOol00Woo00D007ooOomoo`0000Ioo`03001oogoo00Ioo`05001oogooOol00005
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol01Goo1P0057oo
0012Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`0nOol00`00Oomoo`06Ool20004Ool00`00Oomo
o`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00<007ooOol01Goo1P0057oo0012Ool00`00Oomoo`3oOoooOol4
Ool00`00Oomoo`0nOol00`00Ool00006Ool20004Ool00`00Oomoo`06Ool00`00Oomoo`04Ool60003
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007oo
Ool01Goo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`0nOol30005Ool01000Oomo
o`000goo00@007ooOomoo`8000=oo`8000Eoo`03001oogoo009oo`05001oogooOol00009Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool01000Oomoogoo0P000Woo00<007ooOol01Goo1P0057oo0012Ool3
003oOoooOol4Ool00`00Oomoo`0nOol00`00Ool00004Ool20002Ool20003Ool3000017oo001oogoo
0P0000Aoo`00000000=oo`@000=oo`D000Aoo`<000Eoo`@000=oo`800003Ool0000000Qoo`H001Ao
o`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0?Woo00D007ooOomoo`0002=oo`03001oogoo
025oo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0?Goo1P00;Goo00<007ooOol0
5goo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001o
ogoo0?mooomoo`Aoo`03001oogoo08Yoo`H001Aoo`00@Woo0`00ogooogoo17oo00<007ooOol02Woo
1W`017oo1W`017oo1W`017oo1W`0G7oo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool00`00Oomo
o`2:Ool6000DOol001ioo`@000Eoo`8000Eoo`@000Aoo`D000Moo`03001oogoo0?mooomoo`Aoo`03
001oogoo08Yoo`H001Aoo`007Goo00<007ooOol00Woo00<007ooOol00Woo0P0017oo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P00
57oo000MOol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`07Ool4003oOoooOol3Ool00`00Oomoo`2:Ool6000DOol001eoo`03001oogoo009oo`03001o
ogoo00Qoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo0?mooomoo`Ao
o`03001oogoo08Yoo`H001Aoo`007Goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol01goo00<007ooOol0ogooogoo17oo00<007ooOol0?goo0`000goo
1@0017oo1@000Woo0`0000Aoo`000000009oo`D002Moo`H001Aoo`007Goo00<007ooOol00Woo00<0
07ooOol027oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol0ogooogoo
17oo00<007ooOol0?Woo00D007ooOomoo`0000=oo`03001oogoo00Moo`03001oogoo00=oo`05001o
ogooOol00002Ool00`00Oomoo`0ZOol6000DOol001eoo`03001oogoo009oo`03001oogoo00Qoo`03
001oogoo009oo`04001oogooOol30009Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`0nOol01@00
Oomoogoo00000goo00<007ooOol01goo00<007ooOol00goo00D007ooOomoo`00009oo`03001oogoo
02Yoo`H001Aoo`007Woo100037oo10001Woo00<007ooOol01goo00<007ooOol0ogooogoo17oo00<0
07ooOol0?Woo00D007ooOomoo`0000=oo`03001oogoo00Moo`03001oogoo00=oo`05001oogooOol0
0002Ool6000WOol6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo03ioo`05001oogoo
Ool00003Ool20008Ool00`00Oomoo`03Ool20002Ool01000Oomoo`0017oo00<007ooOol09Goo1P00
57oo0012Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`0nOol01@00Oomoogoo00000Woo0P0000Ao
o`00000000=oo`<000Aoo`800003Ool0000000Aoo`@002Qoo`H001Aoo`00@Woo00<007ooOol0ogoo
ogoo17oo00<007ooOol0?Woo00D007ooOomoo`0004Moo`H001Aoo`00@Woo00<007ooOol0ogooogoo
17oo00<007ooOol0?Goo0`0000Aoo`00000000aoo`03001oogoo03Moo`H001Aoo`00@Woo00<007oo
Ool0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool00`00Oomo
o`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo08Yoo`H001Aoo`00@Woo00<0
07ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool00`00
Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo08Yoo`H001Aoo`00@Woo
00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool0
0`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo08Yoo`H001Aoo`00
@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`3oOoooOol4
Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo08Yoo`H001Ao
o`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`3oOooo
Ool4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo08Yoo`H0
01Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`3o
OoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`<00?mooomoo`Aoo`03001oogoo08Yoo`H001Ao
o`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`3oOooo
Ool4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo08Yoo`H0
01Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`3o
OoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo08Yo
o`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomo
o`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo
08Yoo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00
Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001o
ogoo08Yoo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool0
0`00Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03
001oogoo08Yoo`H001Aoo`00@Woo0`00ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00
Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001o
ogoo08Yoo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool0
0`00Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03
001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012
Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Ao
o`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0?Goo1P000Woo
0P000Woo0P000goo10000goo1@0017oo1@0017oo0`0017oo1@000goo10000goo0`0000Aoo`000000
00Ioo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0?Woo00D007ooOomoo`0000=o
o`04001oogoo0003Ool00`00Oomoo`02Ool01@00Oomoogoo00001Woo00<007ooOol01Woo00D007oo
Oomoo`0000Eoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`05
Ool6000DOol0049oo`<00?mooomoo`Aoo`03001oogoo03ioo`03001oogoo00Ioo`8000Aoo`03001o
ogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo009oo`03001o
ogoo009oo`05001oogooOol00003Ool00`00Oomoo`05Ool6000DOol0049oo`03001oogoo0?mooomo
o`Aoo`03001oogoo03ioo`03001oo`0000Ioo`8000Aoo`03001oogoo00Ioo`03001oogoo00Aoo`H0
00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00
Oomoo`05Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo03ioo`<000Eoo`04001o
ogoo0003Ool01000Oomoogoo0P000goo0P001Goo00<007ooOol00Woo00D007ooOomoo`0000Uoo`03
001oogoo009oo`03001oogoo009oo`04001oogooOol20002Ool00`00Oomoo`05Ool6000DOol0049o
o`03001oogoo0?mooomoo`Aoo`03001oogoo03ioo`03001oo`0000Aoo`80009oo`8000=oo`<00004
Ool007ooOol2000017oo000000000goo10000goo1@0017oo0`001Goo10000goo0P0000=oo`000000
27oo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`0nOol01@00Oomoogoo00008goo
00<007ooOol08Goo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`0mOol6000]Ool0
0`00Oomoo`0GOol6000DOol001ioo`@000Eoo`8000Eoo`@000Aoo`@000Qoo`03001oogoo0?mooomo
o`Aoo`03001oogoo08Yoo`H001Aoo`007Goo00<007ooOol00Woo00<007ooOol00Woo0P0017oo00<0
07ooOol00Woo00@007ooOol000Aoo`03001oogoo00Eoo`03001oogoo0?mooomoo`Aoo`03001oogoo
08Yoo`H001Aoo`007Goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol0ogooogoo17oo00<007ooOol02Woo9P0OFWoo1P0057oo000M
Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool4003oOoooOol3Ool00`00Oomoo`2:Ool6000DOol001eoo`03001oogoo009oo`03001oogoo00Qo
o`03001oogoo009oo`04001oogooOol40008Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool6
000DOol001eoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`05001oogooOol0000;
Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol001eoo`03001oogoo009oo`03001o
ogoo00Qoo`03001oogoo009oo`05001oogooOol0000;Ool00`00Oomoo`3oOoooOol4Ool00`00Oomo
o`2:Ool6000DOol001ioo`@000aoo`@000Aoo`D000Moo`03001oogoo0?mooomoo`Aoo`03001oogoo
08Yoo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0?Goo0`001Woo0`0000=oo`00
00000Woo1@000goo100017oo0`0000=oo`0000000Woo1@007goo1P0057oo0012Ool00`00Oomoo`3o
OoooOol4Ool00`00Oomoo`0nOol00`00Oomoo`04Ool01000Oomoogoo0P000Woo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol000=oo`8000Eoo`03001oogoo01moo`H001Aoo`00@Woo0`00ogoo
ogoo17oo00<007ooOol0?Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol000Moo`03001o
ogoo00Eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo01moo`H001Aoo`00@Woo00<007oo
Ool0ogooogoo17oo00<007ooOol0?Woo00<007oo00001Goo1@000Woo1P000Woo00<007ooOol01Woo
1@001Goo00<007ooOol07goo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`0nOol3
0004Ool00`00Oomoo`02Ool01000Oomoo`0017oo00@007ooOol000=oo`80009oo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo01moo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007oo
Ool0?Woo00<007oo00001Goo100017oo100017oo0`0000=oo`00Ool00Woo10001Woo00<007ooOol0
7goo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`0nOol01@00Oomoogoo00009Goo
00<007ooOol07goo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`0mOol6000TOol2
000QOol6000DOol0049oo`<00?mooomoo`Aoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0
ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`2:
Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007oo
Ool0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool3003oOoooOol4Ool00`00Oomoo`2:Ool6
000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0
ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`2:
Ool6000DOol0049oo`<00?mooomoo`Aoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0ogoo
ogoo17oo00<007ooOol0RWoo1P0057oo000UOol40005Ool20005Ool50008Ool00`00Oomoo`08Ool0
0`0OOomoo`3oOoohOol00`00Oomoo`2:Ool6000DOol002Aoo`03001oogoo009oo`03001oogoo009o
o`8000Moo`03001oogoo00Qoo`03001oogoo00Uoo`0301moogoo0?moooMoo`03001oogoo08Yoo`H0
01Aoo`0097oo00<007ooOol00Woo00<007ooOol02goo00<007ooOol027oo10002Goo00<07gooOol0
ogoomWoo00<007ooOol0RWoo1P0057oo000TOol00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomo
o`08Ool00`00Oomoo`0:Ool00`0OOomoo`3oOoofOol00`00Oomoo`2:Ool6000DOol002Aoo`03001o
ogoo009oo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00]oo`0301moogoo0?moooEoo`03
001oogoo08Yoo`H001Aoo`0097oo00<007ooOol00Woo00<007ooOol02goo00<007ooOol027oo00<0
07ooOol037oo00<07gooOol0ogoom7oo00<007ooOol0RWoo1P0057oo000TOol00`00Oomoo`02Ool0
0`00Oomoo`09Ool3000:Ool00`00Oomoo`0=Ool00`0OOomoo`3oOoocOol00`00Oomoo`2:Ool6000D
Ool002Eoo`@000ioo`03001oogoo00Qoo`03001oogoo00ioo`0301moogoo0?mooo9oo`03001oogoo
08Yoo`H001Aoo`00@Woo00<007ooOol03goo00<07gooOol0ogoolGoo00<007ooOol0RWoo00<007oo
Ool05goo0012Ool00`00Oomoo`0?Ool00`0OOomoo`3oOooaOol00`00Oomoo`2:Ool00`00Oomoo`0G
Ool0049oo`03001oogoo011oo`0301moogoo0?mooo1oo`03001oogoo08Yoo`03001oogoo01Moo`00
@Woo00<007ooOol04Goo00<07gooOol0ogookgoo00<007ooOol0RWoo00<007ooOol05goo0012Ool0
0`00Oomoo`0BOol00`0OOomoo`3oOoo^Ool00`00Oomoo`2:Ool00`00Oomoo`0GOol0049oo`03001o
ogoo01=oo`0301moogoo0?mooneoohh001Uoo`00@Woo00<007ooOol04goo00<07gooOol0ogooogoo
UGoo0012Ool00`00Oomoo`0DOol00`0OOomoo`3oOoooOonDOol0049oo`03001oogoo01Eoo`0301mo
ogoo0?mooomooi=oo`00@Woo00<007ooOol05Woo00<07gooOol0ogooogooTWoo0012Ool00`00Oomo
o`0GOol00`0OOomoo`3oOoooOonAOol0049oo`03001oogoo01Moo`0301moogoo0?mooomooi5oo`00
@Woo00<007ooOol067oo00<07gooOol0ogooogooT7oo0012Ool00`00Oomoo`0IOol00`0OOomoo`3o
OoooOon?Ool0049oo`03001oogoo01Yoo`0301moogoo0?mooomoohioo`00@Woo00<007ooOol06goo
00<07gooOol0ogooogooSGoo0012Ool00`00Oomoo`0LOol00`0OOomoo`3oOoooOon<Ool0049oo`03
001oogoo01aoo`0301moogoo0?mooomoohaoo`00@Woo00<007ooOol07Goo00<07gooOol0ogooogoo
Rgoo0012Ool00`00Oomoo`0NOol00`0OOomoo`3oOoooOon:Ool0049oo`03001oogoo01moo`0301mo
ogoo0?mooomoohUoo`00@Woo0`0087oo00<07gooOol0ogooogooR7oo0012Ool00`00Oomoo`0POol0
0`0OOomoo`3oOoooOon8Ool0049oo`03001oogoo025oo`0301moogoo0?mooomoohMoo`00@Woo00<0
07ooOol08Woo00<07gooOol0ogooogooQWoo0012Ool00`00Oomoo`0SOol00`0OOomoo`3oOoooOon5
Ool0049oo`03001oogoo02Aoo`0301moogoo0?mooomoohAoo`00@Woo00<007ooOol09Goo00<07goo
Ool0ogooogooPgoo0012Ool00`00Oomoo`0UOol00`0OOomoo`3oOoooOon3Ool0049oo`03001oogoo
02Ioo`0301moogoo0?mooomooh9oo`00@Woo00<007ooOol09goo00<07gooOol0ogooogooPGoo0012
Ool00`00Oomoo`0XOol00`0OOomoo`3oOoooOon0Ool0049oo`03001oogoo02Uoo`0301moogoo0?mo
oomoogmoo`00@Woo00<007ooOol0:Woo00<07gooOol0ogooogooOWoo0012Ool00`00Oomoo`0[Ool0
0`0OOomoo`3oOoooOommOol0049oo`03001oogoo02aoo`0301moogoo0?mooomoogaoo`00@Woo00<0
07ooOol0;Goo0P0OogooogooO7oo0012Ool3000_Ool00`0OOomoo`3oOoooOomiOol0049oo`03001o
ogoo031oo`0301moogoo0?mooomoogQoo`00@Woo00<007ooOol0<Goo00<07gooOol0ogooogooMgoo
0012Ool00`00Oomoo`0bOol00`0OOomoo`3oOoooOomfOol0049oo`03001oogoo03=oo`0301moogoo
0?mooomoogEoo`00@Woo00<007ooOol0=7oo00<07gooOol0ogooogooM7oo0012Ool00`00Oomoo`0e
Ool00`0OOomoo`3oOoooOomcOol0049oo`03001oogoo03Ioo`0301moogoo0?mooomoog9oo`00@Woo
00<007ooOol0=goo00<07gooOol0ogooogooLGoo0012Ool00`00Oomoo`0hOol00`0OOomoo`3oOooo
Oom`Ool0049oo`03001oogoo03Uoo`807omooomoog1oo`00@Woo0`00>goo00<07gooOol0ogooogoo
KGoo0012Ool00`00Oomoo`0lOol00`0OOomoo`3oOoooOom/Ool0049oo`03001oogoo03eoo`0301mo
ogoo0?mooomoof]oo`00@Woo00<007ooOol0?Woo00<07gooOol0ogooogooJWoo0012Ool00`00Oomo
o`0oOol00`0OOomoo`3oOoooOomYOol0049oo`03001oogoo041oo`807omooomoofUoo`00@Woo00<0
07ooOol0@Woo00<07gooOol0ogooogooIWoo000UOol40005Ool20005Ool40009Ool00`00Oomoo`13
Ool00`0OOomoo`3oOoooOomUOol002Aoo`03001oogoo009oo`03001oogoo009oo`8000Aoo`03001o
ogoo009oo`03001oogoo00Ioo`03001oogoo04Aoo`807omooomoofEoo`0097oo00<007ooOol00Woo
00<007ooOol03Goo00<007ooOol01Woo1000AGoo00<07gooOol0ogooogooHWoo000TOol00`00Oomo
o`02Ool00`00Oomoo`0=Ool00`00Oomoo`06Ool00`00Oomoo`17Ool201ooOoooOomROol002Aoo`03
001oogoo009oo`03001oogoo00Uoo`@000Uoo`03001oogoo04Uoo`0301moogoo0?mooomooemoo`00
97oo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0BWoo0P0Oogooogoo
Ggoo000TOol00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`1<Ool00`0O
Oomoo`3oOoooOomLOol002Eoo`@000aoo`D000Qoo`03001oogoo04eoo`0301moogoo0?mooomooe]o
o`00@Woo00<007ooOol0CWoo0P0OogooogooFgoo0012Ool3001@Ool201ooOoooOomIOol0049oo`03
001oogoo059oo`807omooomooeMoo`00@Woo00<007ooOol0E7oo0P0OogooogooEGoo0012Ool00`00
Oomoo`1FOol301ooOoooOomBOol0049oo`03001oogoo05Uoo`807omooomooe1oo`00@Woo00<007oo
Ool0Fgoo0P0OogooogooCWoo0012Ool3001MOol301ooOoooOom;Ool0049oo`03001oogoo061oo`80
7omooomoodUoo`00@Woo00<007ooOol0HWoo0`0OogooogooAWoo0012Ool00`00Oomoo`1UOol301oo
OoooOom3Ool0049oo`03001oogoo06Qoo`807omooomood5oo`00@Woo0`00JWoo0`0Oogooogoo?Woo
0012Ool00`00Oomoo`1]Ool401ooOoooOoljOol0049oo`03001oogoo075oo`<07omooomoocMoo`00
@Woo00<007ooOol0M7oo0`0Oogooogoo=7oo0012Ool00`00Oomoo`1gOol601ooOoooOol^Ool0049o
o`<007eoo`L07omooomoobMoo`00=7oo1@002Goo00<007ooOol0Q7oo1@0Oogooogoo8Woo000fOol0
0`00Oomoo`09Ool00`00Oomoo`29Ool<01ooOoooOolFOol003Ioo`03001oogoo00Uoo`03001oogoo
09Eoob`07omoo`Qoo`0301moogoo0=ioo`00=Woo00<007ooOol02Goo1000`7ooo`0O2@0Oh7oo000f
Ool00`00Oomoo`09Ool00`00Oomoo`3oOoooOon[Ool003Ioo`03001oogoo00Uoo`03001oogoo0?mo
oomooj]oo`00=7oo0`002goo00<007ooOol0ogooogooZgoo000fOol00`00Oomoo`09Ool00`00Oomo
o`3oOoooOon[Ool0049oo`03001oogoo0?mooomooj]oo`00@Woo00<007ooOol0ogooogooZgoo003o
OoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogoo
l7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00
n7oo0`0017oo10000goo0`0000Eoo`00000007oo00D000Eoo`<000Aoo`<00004Ool00000Ool30000
17oo000000000goo0`0027oo1@000Woo0`0000Aoo`00000000=oo`<000Aoo`<00004Ool00000Ool2
0002Ool30002Ool5003oOon7Ool00?Moo`05001oogooOol00002Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000goo00@007ooOol000Aoo`05001oogooOol00003Ool01000Oomoo`000goo0P000goo00D0
07ooOomoo`0000=oo`05001oogooOol00009Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00D0
07ooOomoo`00009oo`04001oogooOol20003Ool01000Oomoo`000goo00<007ooOol0ogooRWoo003f
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol01Goo00D007oo
Oomoo`0000Ioo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00003Goo00<007oo
Ool00goo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo009oo`07001oogooOol007oo
000017oo00<007ooOol0ogooRWoo003fOol00`00Oomoo`05Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00@007ooOomoo`@000Aoo`03001oogoo00Eoo`D000=oo`05001oogooOol00003Ool00`00
Oomoo`0;Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00<007ooOol01Goo1@000goo0`0017oo
1P00ogooQgoo0018Ool3002[Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoogoo0P000Woo
00@007ooOol000Aoo`05001oogooOol00006Ool00`00Oomoo`02Ool01000Oomoogoo0P000Woo00D0
07ooOomoo`0000eoo`03001oogoo00=oo`80009oo`05001oogooOol00006Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000Woo00D007ooOomoo`0000Aoo`03001oogoo0?moohEoo`00BGoo00<007ooOol0
ZWoo00<007ooOol01Woo10000goo0P0000=oo`00000017oo1@000Woo1@0017oo10000goo0P0000=o
o`0000000goo1@0027oo0`0017oo0P0000=oo`0000000goo1@0017oo100017oo00<007oo00000`00
0Woo1000ogooR7oo000lOol50004Ool300000goo001oo`2/Ool01@00Oomoogoo00006goo00<007oo
Ool05Goo00<007ooOol06Goo00<007ooOol03Goo00<007ooOol0ogooTGoo000mOol01@00Oomoogoo
00000Woo00@007ooOomoo`800:ioo`@0045oo`03001oogoo01Yoo`800?mooi=oo`00?Goo00D007oo
Oomoo`00009oo`03001oogoo009oo`03001oogoo0?mooomoojAoo`00?Goo00D007ooOomoo`00009o
o`03001oogoo009oo`03001oogoo0?mooomoojAoo`00?Goo10000goo00@007ooOomoo`800?mooomo
ojIoo`00?Goo00D007ooOomoo`0000=oo`<00003Ool000000?mooomoojEoo`00?Goo00D007ooOomo
o`000?mooomoojioo`00?7oo1@00ogooogoo[goo003oOoooOoo`Ool00?mooomooo1oo`00ogooogoo
l7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00
ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomo
oo1oo`00ogooogool7oo003oOoooOoo`Ool00001\
\>"],
  ImageRangeCache->{{{0, 749}, {366.813, 0}} -> {-1.06507, -0.648943, \
0.00442282, 0.00442282}, {{18.375, 583.625}, {358.063, 8.6875}} -> \
{-0.392627, -3.57382, 0.00629642, 0.0140069}, {{583.625, 724.938}, {268.188, \
126.875}} -> {-14.9683, -2.1938, 0.0318446, 0.0265372}, {{595.375, 634.625}, \
{254, 206.938}} -> {-15.9524, -11.8034, 0.0334398, 0.108214}, {{595.375, \
634.625}, {188.063, 141}} -> {-15.9524, -17.5117, 0.0334398, 0.108214}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[98]="]
}, Open  ]],

Cell["These  values are the same that Table A.12.? of ICRP 78 ", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Inhalation", "SubsubsectionIcon"],

Cell[TextData[{
  "Now it evaluates  lung retention and the daily urine and faecal excretion \
for a single intake ",
  Cell[BoxData[
      \(I\_0\)]],
  "= 1 by inhalation in t = 0 for AMAD 5, and type S "
}], "MathCaption"],

Cell[BoxData[
    \(fn1\  = \ 0.002; \ amad = \ AMADAdultW[5]; \ class\  = \ S;\)], "Input",\

  CellLabel->"In[99]:="],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Inhalation\>", \ "\<Acute\>", "\<BioassayTable\>", 1, \ 
      amad, class, \ fn1, 180, lambda]\)], "Input",
  CellLabel->"In[100]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Days after\nintake"\), \("Lung\nretention"\), \("Urine\n24 \
hours"\), \("Faecal\n24 hours"\), "\<\"Wholebody\"\>"},
          {"1", "0.06427552500237536`", "0.0007039962593648622`", 
            "0.11387953857289934`", "0.4908915921343731`"},
          {"2", "0.06269378801433073`", "0.0000440788558102069`", 
            "0.16275643453258837`", "0.24932846358368366`"},
          {"3", "0.061935137890495325`", "0.000025985430110287734`", 
            "0.08384098905595638`", "0.13648634121865505`"},
          {"4", "0.06130047409779483`", "0.000023659237179731243`", 
            "0.03523951490155747`", "0.0905638048916471`"},
          {"5", "0.060694931817597914`", "0.000021950980916284578`", 
            "0.014025752262741498`", "0.07259474051649371`"},
          {"6", "0.06010535929127244`", "0.00002047753480059495`", 
            "0.0056515486401707005`", "0.06548012532152771`"},
          {"7", "0.059529670629585585`", "0.000019172678246561804`", 
            "0.002467744823814566`", "0.062462508142352345`"},
          {"8", "0.058967285487397984`", "0.000018007524523843202`", 
            "0.0012720970495148087`", "0.060977169272881285`"},
          {"9", "0.058417835123414426`", "0.000016962059021894717`", 
            "0.0008212249995177556`", "0.060067158772486175`"},
          {"10", "0.057880987087771014`", "0.000016020413773461077`", 
            "0.0006467528392169464`", "0.05937796242697347`"},
          {"20", "0.05313929788613847`", "0.000010229702182824527`", 
            "0.0004385116762847252`", "0.054308889026037574`"},
          {"30", "0.04935432825601152`", "7.716778906503158`*^-6", 
            "0.00035000191825945715`", "0.050342139234907636`"},
          {"40", "0.04631240670334732`", "6.441465805825594`*^-6", 
            "0.0002812202727976443`", "0.04716509384556211`"},
          {"50", "0.0438491883809243`", "5.686767756836811`*^-6", 
            "0.00022761750597560804`", "0.044598669144702514`"},
          {"60", "0.041837963228833416`", "5.178782980340933`*^-6", 
            "0.0001857250006135902`", "0.04250742897135463`"},
          {"70", "0.04018079749916242`", "4.8050322252156386`*^-6", 
            "0.00015288926665474323`", "0.040787676587776954`"},
          {"80", "0.03880180963056221`", "4.514583156414384`*^-6", 
            "0.00012707566420561145`", "0.03935944603652789`"},
          {"90", "0.037642056328222546`", "4.281321633887135`*^-6", 
            "0.00010672041037257385`", "0.03816077770725369`"},
          {"100", "0.03665563536597257`", "4.0899820649628604`*^-6", 
            "0.00009061873965326983`", "0.0371434899739066`"},
          {"180", "0.031972952567723444`", "3.290408279173901`*^-6", 
            "0.000037231456705588695`", "0.03235803631732401`"},
          {"200", "0.031218666464948697`", "3.1840211258205367`*^-6", 
            "0.00003299989533650516`", "0.031595855728084585`"},
          {"300", "0.028174460369493545`", "2.81521354699929`*^-6", 
            "0.00002431196207813846`", "0.028537996444950822`"},
          {"400", "0.025650019783283295`", "2.551819078215785`*^-6", 
            "0.000021169153764766246`", "0.02601182199964132`"},
          {"500", "0.023406716857724684`", "2.328994832151779`*^-6", 
            "0.000018919934337779942`", "0.023768302284850454`"},
          {"600", "0.02139231874660401`", "2.131871035726887`*^-6", 
            "0.000016977426228803605`", "0.021753613107576276`"},
          {"700", "0.019580131605462667`", "1.9552656389939735`*^-6", 
            "0.000015246093279408512`", "0.019940801999192077`"},
          {"800", "0.0179488559839372`", "1.7964062138716569`*^-6", 
            "0.000013695558800486118`", "0.018308553056643938`"},
          {"900", "0.016479754588993967`", "1.6532862719617625`*^-6", 
            "0.000012305888432095902`", "0.016838160610433455`"},
          {"1000", "0.01515608482609662`", "1.524236589627373`*^-6", 
            "0.000011060193638168236`", "0.015512921376151886`"},
          {"2000", "0.007276566540623154`", "7.520061746143364`*^-7", 
            "3.883249866110106`*^-6", "0.00760903373469607`"},
          {"3000", "0.0042705698227413135`", "4.527148655553842`*^-7", 
            "1.4544678170191894`*^-6", "0.004574395631806314`"},
          {"4000", "0.0029570119626817575`", "3.190765649795438`*^-7", 
            "6.140691871658888`*^-7", "0.0032342274049519787`"},
          {"5000", "0.002263663623664677`", "2.4702374868453697`*^-7", 
            "3.0870187756049106`*^-7", "0.002517401135531679`"},
          {"6000", "0.0018228563480254336`", "2.005640751968213`*^-7", 
            "1.8648950211863635`*^-7", "0.002055979008040727`"},
          {"7000", "0.0015035285167753596`", "1.6667928916941355`*^-7", 
            "1.2930316961590194`*^-7", "0.0017183969793671285`"},
          {"8000", "0.0012550507091918426`", "1.4023086148881592`*^-7", 
            "9.701941283690729`*^-8", "0.0014535841106086446`"},
          {"9000", "0.0010549132337941709`", "1.1887771544146636`*^-7", 
            "7.563901316398614`*^-8", "0.0012386957740330208`"},
          {"10000", "0.0008910504723014032`", "1.0134279082411879`*^-7", 
            "5.998588448186126`*^-8", "0.00106142107869287`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Days after\nintake", 
          "Lung\nretention", "Urine\n24 hours", "Faecal\n24 hours", 
          "Wholebody"}}]]]], "Output",
  CellLabel->"Out[100]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BiokdataReport[
      element, "\<Inhalation\>", \ "\<Constant\>", "\<GraphicReport\>", 1, \ 
      amad, class, \ fn1, 180, lambda]\)], "Input",
  CellLabel->"In[101]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4905 
%%ImageSize: 600 294.302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.401738 0.377929 0.245252 0.377929 [
[ 0 0 0 0 ]
[ 1 .4905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0116786 0.779667 0.478825 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.422291 0.482039 0.140366 [
[.02381 -0.0125 -5 -12.5625 ]
[.02381 -0.0125 5 0 ]
[.15093 -0.0125 -5 -12.5625 ]
[.15093 -0.0125 5 0 ]
[.31898 -0.0125 -5 -12.5625 ]
[.31898 -0.0125 5 0 ]
[.4461 -0.0125 -8 -12.5625 ]
[.4461 -0.0125 8 0 ]
[.57322 -0.0125 -8 -12.5625 ]
[.57322 -0.0125 8 0 ]
[.74127 -0.0125 -8 -12.5625 ]
[.74127 -0.0125 8 0 ]
[.86839 -0.0125 -11 -12.5625 ]
[.86839 -0.0125 11 0 ]
[.99551 -0.0125 -11 -12.5625 ]
[.99551 -0.0125 11 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 28 6.28125 ]
[-0.0125 .06094 -34 -6.28125 ]
[-0.0125 .06094 0 6.28125 ]
[-0.0125 .20131 -28 -6.28125 ]
[-0.0125 .20131 0 6.28125 ]
[-0.0125 .34167 -22 -6.28125 ]
[-0.0125 .34167 0 6.28125 ]
[-0.0125 .48204 -10 -6.28125 ]
[-0.0125 .48204 0 6.28125 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5625 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12.5625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15093 0 m
.15093 .00625 L
s
gsave
.15093 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31898 0 m
.31898 .00625 L
s
gsave
.31898 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4461 0 m
.4461 .00625 L
s
gsave
.4461 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57322 0 m
.57322 .00625 L
s
gsave
.57322 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74127 0 m
.74127 .00625 L
s
gsave
.74127 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86839 0 m
.86839 .00625 L
s
gsave
.86839 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99551 0 m
.99551 .00625 L
s
gsave
.99551 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22529 0 m
.22529 .00375 L
s
.27805 0 m
.27805 .00375 L
s
.35242 0 m
.35242 .00375 L
s
.38069 0 m
.38069 .00375 L
s
.40518 0 m
.40518 .00375 L
s
.42678 0 m
.42678 .00375 L
s
.64758 0 m
.64758 .00375 L
s
.70034 0 m
.70034 .00375 L
s
.77471 0 m
.77471 .00375 L
s
.80298 0 m
.80298 .00375 L
s
.82747 0 m
.82747 .00375 L
s
.84907 0 m
.84907 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .06094 m
.00625 .06094 L
s
gsave
-0.0125 .06094 -95 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .20131 m
.00625 .20131 L
s
gsave
-0.0125 .20131 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .34167 m
.00625 .34167 L
s
gsave
-0.0125 .34167 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .48204 m
.00625 .48204 L
s
gsave
-0.0125 .48204 -71 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .1032 m
.00375 .1032 L
s
0 .12791 m
.00375 .12791 L
s
0 .14545 m
.00375 .14545 L
s
0 .15905 m
.00375 .15905 L
s
0 .17017 m
.00375 .17017 L
s
0 .17956 m
.00375 .17956 L
s
0 .1877 m
.00375 .1877 L
s
0 .19488 m
.00375 .19488 L
s
0 .24356 m
.00375 .24356 L
s
0 .26828 m
.00375 .26828 L
s
0 .28582 m
.00375 .28582 L
s
0 .29942 m
.00375 .29942 L
s
0 .31053 m
.00375 .31053 L
s
0 .31993 m
.00375 .31993 L
s
0 .32807 m
.00375 .32807 L
s
0 .33525 m
.00375 .33525 L
s
0 .38393 m
.00375 .38393 L
s
0 .40864 m
.00375 .40864 L
s
0 .42618 m
.00375 .42618 L
s
0 .43978 m
.00375 .43978 L
s
0 .4509 m
.00375 .4509 L
s
0 .4603 m
.00375 .4603 L
s
0 .46844 m
.00375 .46844 L
s
0 .47562 m
.00375 .47562 L
s
0 .52429 m
.00375 .52429 L
s
0 .54901 m
.00375 .54901 L
s
0 .56655 m
.00375 .56655 L
s
0 .58015 m
.00375 .58015 L
s
0 .59126 m
.00375 .59126 L
s
0 .60066 m
.00375 .60066 L
s
0 .6088 m
.00375 .6088 L
s
0 .61598 m
.00375 .61598 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Constant) show
117.000 12.813 moveto
(intake) show
153.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .31815 m
.41107 .44112 L
.53436 .47959 L
.60372 .50062 L
.65224 .51497 L
.69278 .52672 L
.72483 .53583 L
.75369 .5439 L
.77776 .55055 L
.79827 .55616 L
.81784 .56146 L
.83489 .56604 L
.84991 .57006 L
.86466 .57398 L
.87782 .57747 L
.89084 .58091 L
.90257 .584 L
.91318 .5868 L
.92384 .5896 L
.93355 .59215 L
.94333 .59471 L
.95229 .59706 L
.96051 .59921 L
.96887 .6014 L
.97619 .60332 L
s
0 1 0 r
1.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.06042 .03004 L
.08838 .03658 L
.1161 .03986 L
.13894 .0413 L
.1578 .04209 L
.17363 .04264 L
.20509 .04365 L
.30107 .04722 L
.41107 .05267 L
.53436 .06016 L
.6034 .06471 L
.65174 .068 L
.69219 .07084 L
.72416 .07317 L
.75297 .07534 L
.77701 .07722 L
.79749 .07888 L
.81703 .0805 L
.83407 .08196 L
.85058 .08341 L
.8652 .08473 L
.87825 .08593 L
.89118 .08714 L
.90282 .08826 L
.91336 .0893 L
.92395 .09035 L
.9336 .09133 L
.94333 .09234 L
.95224 .09328 L
.96042 .09415 L
.96874 .09505 L
.97619 .09588 L
s
0 0 1 r
2 Mabswid
[ 1 8 ] 0 Mabsdash
.02381 .28237 m
.08838 .34205 L
.13894 .37766 L
.17652 .39676 L
.20509 .40751 L
.23381 .41546 L
.2473 .41834 L
.2606 .4207 L
.28276 .42373 L
.30107 .42551 L
.3181 .42671 L
.3348 .42753 L
.34928 .42804 L
.3616 .42835 L
.37502 .4286 L
.38862 .42879 L
.40061 .42891 L
.41107 .42899 L
.45102 .42922 L
.48098 .42937 L
.53436 .42967 L
.60444 .43015 L
.65334 .43053 L
.69411 .43087 L
.72632 .43115 L
.75272 .43138 L
.77719 .43159 L
.79802 .43177 L
.81783 .43192 L
.83509 .43206 L
.85029 .43217 L
.86518 .43227 L
.87846 .43236 L
.89038 .43244 L
.90228 .43251 L
.91304 .43258 L
.92384 .43264 L
.93366 .4327 L
.94264 .43274 L
.95174 .43279 L
.96009 .43283 L
.96857 .43288 L
.97619 .43292 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.78723 .12431 m
.78723 .31328 L
.97619 .31328 L
.97619 .12431 L
F
1 g
.77967 .13187 m
.77967 .32084 L
.96863 .32084 L
.96863 .13187 L
F
0 g
.001 w
[ ] 0 setdash
.77967 .13187 m
.96863 .13187 L
.96863 .32084 L
.77967 .32084 L
.77967 .13187 L
s
% Start of sub-graphic
p
0.779667 0.131873 0.968632 0.320837 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0277778 0.277778 0.0227273 0.227273 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0833333 0.0681818 0.361111 0.295455 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .18182 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Lungs) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.386364 0.361111 0.613636 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
1.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .5 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Urine) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0833333 0.704545 0.361111 0.931818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
2 Mabswid
[ 1 8 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.43056 .81818 -61 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Faecal) show
63.000 26.000 moveto
(Excretion) show
117.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .4905 L
0 .4905 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[101]:=",
  ImageSize->{600, 294.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;^0001Ka000`40O003h00Oogooogool7oo003o
OoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogoo
l7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00
ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomo
oo1oo`00ogooogool7oo001<Ool5000eOol5001;Ool4000dOol50003Ool4000_Ool50004Ool40013
Ool40004Ool4000/Ool50003Ool40004Ool4000WOol50004Ool40004Ool4003=Ool004ioo`03001o
ogoo03Eoo`05001oogooOol0001:Ool00`00Oomoo`02Ool00`00Oomoo`0cOol00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`0/Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol0
?goo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo02]oo`03001oogoo009oo`03001oogoo
009oo`04001oogoo0004Ool00`00Oomoo`0TOol01@00Oomoogoo00000goo00<007ooOol00Woo00@0
07ooOol000Aoo`03001oogoo0<Yoo`00CWoo00<007ooOol0=Woo00<007ooOol0D7oo00<007ooOol0
<goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0;Goo00<007ooOol017oo00<007ooOol0
0Woo00<007ooOol0A7oo00@007ooOol000Aoo`03001oogoo02]oo`03001oogoo009oo`03001oogoo
009oo`04001oogoo0004Ool00`00Oomoo`0UOol00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomo
o`0017oo00<007ooOol0bWoo001>Ool00`00Oomoo`0gOol00`00Oomoo`1?Ool00`00Oomoo`0cOol0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0^Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Oomoo`14Ool01000Oomoo`0017oo00<007ooOol0:goo00<007ooOol00Woo00<007ooOol00Woo
00@007ooOol000Aoo`03001oogoo02Ioo`03001oogoo00=oo`03001oogoo009oo`04001oogoo0004
Ool00`00Oomoo`3:Ool004ioo`03001oogoo03Qoo`03001oogoo04Yoo`@003Ioo`03001oogoo009o
o`03001oogoo009oo`03001oogoo02moo`03001oogoo009oo`03001oogoo009oo`03001oogoo041o
o`@000=oo`03001oogoo009oo`03001oogoo02]oo`03001oogoo009oo`03001oogoo009oo`04001o
ogoo0004Ool00`00Oomoo`0WOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<0
07ooOol0bWoo001>Ool00`00Oomoo`0iOol00`00Oomoo`19Ool00`00Oomoo`0gOol00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`0`Ool01@00Oomoogoo000017oo00<007ooOol0@7oo00<007oo
Ool017oo00<007ooOol00Woo00<007ooOol0:goo00<007ooOol00Woo00<007ooOol00Woo00@007oo
Ool000Aoo`03001oogoo02Qoo`05001oogooOol00004Ool01000Oomoo`0017oo00<007ooOol0bWoo
001<Ool3000gOol01@00Oomoogoo0000Bgoo00<007ooOol0=Goo0`0017oo00<007ooOol00Woo00<0
07ooOol0;7oo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo041oo`03001oogoo00Ao
o`03001oogoo009oo`03001oogoo02Uoo`<000Aoo`03001oogoo009oo`04001oogoo0004Ool00`00
Oomoo`0TOol01@00Oomoogoo00000goo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo0<Yo
o`00CWoo00<007ooOol0=Woo0`00C7oo1@00=Goo00<007ooOol00goo1000<7oo0`001Goo1000@goo
1@000goo1000;Woo00<007ooOol00goo100017oo1000:7oo0`001Goo100017oo1000cGoo003oOooo
Ooo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooc]oo`<00;9oo`00ogoo
ogoo?Goo00<007ooOol0/7oo003oOoooOol[Ool300000goo00000002Ool300000goo00000004Ool0
0`00Oomoo`02Ool5002YOol00?mooomoobYoo`04001oogooOol20002Ool01000Oomoogoo0P0017oo
00<007oo00000goo00<007ooOol00Woo00<007ooOol0YWoo0012Oooo003H000?Ool00`00Oomoo`02
Ool01000Oomoo`0017oo00<007ooOol00Woo00<007oo000027oo00<007ooOol0YWoo0012Ool00`00
Oomoo`08Ool00`00Oomoo`0iOol00`00Oomoo`0POol00`00Oomoo`0FOol00`00Oomoo`0@Ool00`00
Oomoo`0=Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00
Oomoo`0iOol00`00Oomoo`0POol00`00Oomoo`0EOol00`00Oomoo`0AOol00`00Oomoo`0<Ool00`00
Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0iOol00`00
Oomoo`0?Ool00`00Oomoo`02Ool01000Oomoogoo1@000goo00D007ooOomoo`0000=oo`@00:Uoo`00
@Woo00<007ooOol027oo00<007ooOol0>Goo00<007ooOol087oo00<007ooOol05Woo00<007ooOol0
47oo00<007ooOol03Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol01goo00<007ooOol0
1Woo00<007ooOol0>Goo00<007ooOol087oo00<007ooOol05Goo00<007ooOol04Goo00<007ooOol0
37oo00<007ooOol02goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01Woo00<007ooOol0
>Goo00<007ooOol03goo00@007ooOomoo`80009oo`03001oogoo009oo`05001oogooOol00003Ool0
1000Oomoo`0017oo00<007ooOol0YWoo0012Ool00`00Oomoo`08Ool00`00Oomoo`0iOol00`00Oomo
o`1<Ool00`00Oomoo`0iOol00`00Oomoo`0iOol00`00Oomoo`1<Ool00`00Oomoo`0hOol00`00Oomo
o`0iOol00`00Oomoo`0@Ool300000goo001oo`02Ool40003Ool3000017oo000000000Woo1@00Z7oo
0012Ool00`00Oomoo`3oOooYOol00`00Oomoo`2nOol0049oo`03001oogoo0?moonQoo`800<1oo`00
@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomoo`08Ool20n3oOoooOonQOol0049oo`03001o
ogoo00Yoo`83h?mooomooimoo`00@Woo00<007ooOol037oo0`?PogooogooW7oo0012Ool00`00Oomo
o`0?Ool20n3oOoooOonJOol0049oo`03001oogoo015oo`<3h?mooomooiMoo`00@Woo00<007ooOol0
57oo0`?PogooogooU7oo0012Ool00`00Oomoo`0GOol20n3oOoooOonBOol0049oo`03001oogoo01Uo
o`@3h?mooomoohioo`00@Woo00<007ooOol07Goo10?PogooogooRWoo0012Ool00`00Oomoo`0QOol4
0n3oOoooOon6Ool0049oo`03001oogoo02Eoo`H3h?mooomooh1oo`00@Woo00<007ooOol0:goo1P?P
ogooogooNWoo0012Ool00`00Oomoo`0aOolB0n3oOoooOomXOol0049oo`03001oogoo04=oobL3h?mo
oomood5oo`00@Woo00<007ooOol0JWoo5P?Pogooogoo:goo0012Ool00`00Oomoo`20OolD0n3oOooo
OolGOol0049oo`03001oogoo09Aooa43h?mooomoo`Ioo`00@Woo00<007ooOol0YGoo4P?Pogoolgoo
0012Ool00`00Oomoo`2gOolB0n3oOooQOol001Ioo`@000Eoo`8000Eoo`@000Aoo`@000Aoo`D000Mo
o`03001oogoo0<Uooa<3h?moolioo`005Goo00<007ooOol00Woo00<007ooOol00Woo0P0017oo00<0
07ooOol00Woo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo0=aooa<3
h?mook]oo`005Goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00@007ooOol000Ao
o`03001oogoo00=oo`03001oogoo00Moo`03001oogoo0>mooa83h?moojUoo`005Goo00<007ooOol0
0Woo00<007ooOol027oo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo
00Moo`@00?moo`5ooa03h?mooiUoo`005Goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol0
0Woo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo0?mooa9oo`h3h?mo
oh]oo`005Goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00@007ooOol000Aoo`03
001oogoo00=oo`03001oogoo00Moo`03001oogoo0?moob1oo``3h?moogmoo`005Goo00<007ooOol0
0Woo00<007ooOol027oo00<007ooOol00Woo00@007ooOol000Aoo`04001oogooOol30009Ool00`00
Oomoo`3oOol/Ool?0n3oOom`Ool001Ioo`@000aoo`@000Aoo`@000Ioo`03001oogoo00Moo`03001o
ogoo0?mooc]ooa43h?mooemoo`00@Woo00<007ooOol0ogooC7oo3P?PogooDGoo0012Ool00`00Oomo
o`3oOomJOol<0n3oOom5Ool0049oo`03001oogoo0?moofIoo`/3h?moocYoo`00@Woo00<007ooOol0
ogooLGoo2@?Pogoo<Goo0012Ool00`00Oomoo`3oOomjOol@0n3oOolQOol0049oo`03001oogoo0?mo
ohYoo`P3h?mooaUoo`00@Woo00<007ooOol0ogooTWoo30?Pogoo3Goo0012Ool00`00Oomoo`3oOonN
Ool<0n3oOol1Ool0049oo`03001oogoo0?moojYoo`T3h?Moo`00@Woo00<007ooOol0ogoo/goo2@?P
kWoo0012Ool00`00Oomoo`3oOonlOol80n3VOol0049oo`03001oogoo0?moolAoo`H3h>1oo`00@Woo
00<007ooOol0ogooogooZgoo0012Ool00`00Oomoo`3oOoooOon[Ool0049oo`<00?mooomooj]oo`00
@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomoo`3oOoooOon[Ool0049oo`03001oogoo0?mo
oomooj]oo`00@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomoo`3oOoooOon[Ool0049oo`03
001oogoo0?mooomooj]oo`00@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomoo`3oOoooOon[
Ool0049oo`03001oogoo0?mooomooj]oo`00@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomo
o`3oOoooOol:Oon=000DOol0049oo`<00?mooomoo`Yoohd001Aoo`00@Woo00<007ooOol0ogooogoo
2WooS@0057oo0012Ool00`00Oomoo`3oOoooOol:Oon=000DOol0049oo`03001oogoo0?mooomoo`Ao
oi<001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomo
o`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo
08Yoo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool3003o
OoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo08Yo
o`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomo
o`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo
08Yoo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00
Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`<00?mooomoo`Aoo`03001oogoo08Yo
o`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomo
o`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo
08Yoo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool3003o
OoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo08Yo
o`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomo
o`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`<00?mooomoo`Aoo`03001oogoo08Yoo`H0
01Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0EWoo1000<7oo1P0057oo0012Ool00`00
Oomoo`3oOoooOol4Ool00`00Oomoo`1JOol00`00Oomoo`0]Ool6000DOol0049oo`03001oogoo0?mo
oomoo`Aoo`03001oogoo03eoo`H000Aoo`800004Ool00000Ool3000017oo000000000Woo0`0000Ao
o`00Oomoo`D002Qoo`H001Aoo`00@Woo0`00ogooogoo17oo00<007ooOol0?Woo00D007ooOomoo`00
00=oo`03001oogoo008000=oo`05001oogooOol00002Ool01000Oomoogoo0P000Woo00<007ooOol0
0Woo00<007ooOol09Goo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`0:Ool6O004
Ool6O004Ool6O004Ool6O00@Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00002Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`0UOol6000DOol0049oo`03001o
ogoo0?mooomoo`Aoo`03001oogoo03ioo`03001oogoo00Eoo`05001oogooOol00003Ool01@00Oomo
ogoo00000Woo00<007ooOol00Woo00@007ooOomoo`@002Qoo`H001Aoo`00@Woo00<007ooOol0ogoo
ogoo17oo00<007ooOol0?Woo00<007ooOol01Goo00D007ooOomoo`0000=oo`80009oo`04001oogoo
0003Ool20002Ool00`00Oomoo`02Ool00`00Oomoo`0UOol6000DOol001ioo`@000Eoo`8000Eoo`@0
00Aoo`D000Moo`<00?mooomoo`Aoo`03001oogoo03ioo`03001oogoo00Aoo`80009oo`80009oo`80
0003Ool0000000Aoo`<00003Ool00000009oo`D002Moo`H001Aoo`007Goo00<007ooOol00Woo00<0
07ooOol00Woo0P0017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol0
ogooogoo17oo00<007ooOol0?Woo00<007ooOol0BGoo1P0057oo000MOol00`00Oomoo`02Ool00`00
Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`3oOoooOol4
Ool00`00Oomoo`0mOol3001:Ool6000DOol001eoo`03001oogoo009oo`03001oogoo00Qoo`03001o
ogoo009oo`03001oogoo00=oo`03001oogoo00Moo`@00?mooomoo`=oo`03001oogoo08Yoo`H001Ao
o`007Goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool01goo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo000MOol00`00Oomoo`02Ool0
0`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`3oOooo
Ool4Ool00`00Oomoo`2:Ool6000DOol001eoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo
009oo`04001oogooOol30009Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol001io
o`@000aoo`@000Ioo`03001oogoo00Moo`03001oogoo0?mooomoo`Aoo`03001oogoo08Yoo`H001Ao
o`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`3oOooo
Ool4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo08Yoo`H0
01Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`3o
OoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo08Yo
o`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomo
o`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo
08Yoo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00
Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001o
ogoo08Yoo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool0
0`00Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`<00?mooomoo`Aoo`03001oogoo
08Yoo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00
Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001o
ogoo08Yoo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool0
0`00Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03
001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012
Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo0?mooomoo`Ao
o`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0?Goo1P000Woo
0P000Woo0P000goo10000goo1@0017oo1@0017oo0`0017oo1@000goo10000goo0`0000Aoo`000000
00Ioo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0?Woo00D007ooOomoo`0000=o
o`04001oogoo0003Ool00`00Oomoo`02Ool01@00Oomoogoo00001Woo00<007ooOol01Woo00D007oo
Oomoo`0000Eoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`05
Ool6000DOol0049oo`<00?mooomoo`Aoo`03001oogoo03ioo`03001oogoo00Ioo`8000Aoo`03001o
ogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo009oo`03001o
ogoo009oo`05001oogooOol00003Ool00`00Oomoo`05Ool6000DOol0049oo`03001oogoo0?mooomo
o`Aoo`03001oogoo03ioo`03001oo`0000Ioo`8000Aoo`03001oogoo00Ioo`03001oogoo00Aoo`H0
00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00
Oomoo`05Ool6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo03ioo`<000Eoo`04001o
ogoo0003Ool01000Oomoogoo0P000goo0P001Goo00<007ooOol00Woo00D007ooOomoo`0000Uoo`03
001oogoo009oo`03001oogoo009oo`04001oogooOol20002Ool00`00Oomoo`05Ool6000DOol0049o
o`03001oogoo0?mooomoo`Aoo`03001oogoo03ioo`03001oo`0000Aoo`80009oo`8000=oo`<00004
Ool007ooOol2000017oo000000000goo10000goo1@0017oo0`001Goo10000goo0P0000=oo`000000
27oo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`0nOol01@00Oomoogoo00008goo
00<007ooOol08Goo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`0mOol6000]Ool0
0`00Oomoo`0GOol6000DOol0049oo`03001oogoo00Qoo`0301moogoo0?moooQoo`03001oogoo08Yo
o`H001Aoo`00@Woo00<007ooOol01goo0`0OogoonGoo00<007ooOol0RWoo1P0057oo0012Ool30008
Ool301ooOoohOol00`00Oomoo`0:OolV0n1JOol6000DOol0049oo`03001oogoo00Uoo`0301moogoo
0?moooMoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo
1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo
0?mooomoo`Aoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol04Goo00<07gooOol0ogookgoo
00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`0@Ool301ooOoo`Ool00`00Oomoo`0oOol30003
Ool50004Ool50002Ool3000017oo000000000Woo1@009goo1P0057oo0012Ool3000AOol301ooOoo_
Ool00`00Oomoo`0nOol01@00Oomoogoo00000goo00<007ooOol01goo00<007ooOol00goo00D007oo
Oomoo`00009oo`03001oogoo02Yoo`H001Aoo`00@Woo00<007ooOol04Woo00<07gooOol0ogookWoo
00<007ooOol0?Woo00D007ooOomoo`0000=oo`03001oogoo00Moo`03001oogoo00=oo`05001oogoo
Ool00002Ool00`00Oomoo`0ZOol6000DOol0049oo`03001oogoo0?mooomoo`Aoo`03001oogoo03io
o`05001oogooOol00003Ool00`00Oomoo`07Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo1P00
9goo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`0nOol01@00Oomoogoo00000goo
0P0027oo00<007ooOol00goo0P000Woo00@007ooOol000Aoo`03001oogoo02Eoo`H001Aoo`00@Woo
00<007ooOol0ogooogoo17oo00<007ooOol0?Woo00D007ooOomoo`00009oo`800004Ool000000003
Ool30004Ool200000goo00000004Ool4000XOol6000DOol0049oo`<00?mooomoo`Aoo`03001oogoo
03ioo`05001oogooOol00017Ool6000DOol0049oo`03001oogoo01Uoo`0301moogoo0?moonMoo`03
001oogoo03eoo`<00004Ool00000000<Ool00`00Oomoo`0gOol6000DOol0049oo`03001oogoo01Qo
o`<07omoonQoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol027oo0W`03goo0`0Oogooigoo
00<007ooOol0RWoo1P0057oo0012Ool3000:Ool2O00>Ool00`0OOomoo`3oOooVOol00`00Oomoo`2:
Ool6000DOol0049oo`03001oogoo00aoo`9l0?moooEoo`03001oogoo08Yoo`H001Aoo`00@Woo00<0
07ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`0BOol3O03oOoo^Ool0
0`00Oomoo`2:Ool6000DOol0049oo`<001Eoo`=l0?moon]oo`03001oogoo08Yoo`H001Aoo`00@Woo
00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`0LOol2O002Ool3
01ooOooPOol00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo01ioo`9l00<07omoon1oo`03001o
ogoo08Yoo`H001Aoo`009Goo10001Goo0P001Goo1@0027oo0`00ogooogoo17oo00<007ooOol0RWoo
1P0057oo000TOol00`00Oomoo`02Ool00`00Oomoo`02Ool20007Ool00`00Oomoo`08Ool00`00Oomo
o`0UOol3O03oOooKOol00`00Oomoo`2:Ool6000DOol002Aoo`03001oogoo009oo`03001oogoo00]o
o`03001oogoo00Qoo`03001oogoo02Qoo`=l0?moomQoo`03001oogoo08Yoo`H001Aoo`0097oo00<0
07ooOol00Woo00<007ooOol02goo00<007ooOol027oo1000ogooogoo0goo00<007ooOol0RWoo1P00
57oo000TOol00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`0ZOol00`0O
Oomoo`02Ool2O03oOooBOol00`00Oomoo`2:Ool6000DOol002Aoo`03001oogoo009oo`03001oogoo
00]oo`03001oogoo00Qoo`03001oogoo02Uoo`<07`Eoo`=l0?moolmoo`03001oogoo08Yoo`H001Ao
o`0097oo00<007ooOol00Woo00<007ooOol02Goo0`002Woo00<007ooOol0:Woo0`0OogooeWoo00<0
07ooOol0RWoo1P0057oo000UOol4000>Ool00`00Oomoo`08Ool00`00Oomoo`0[Ool00`0OOomoo`0:
Ool3O03oOoo8Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo03]oo`=l0?moolEoo`03001o
ogoo08Yoo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007ooOol0RWoo1P0057oo0012Ool0
0`00Oomoo`0cOol00`0OOomoo`0<Ool2O03oOonoOol00`00Oomoo`2:Ool6000DOol0049oo`03001o
ogoo039oo`<07`moo`=l0?mookaoo`03001oogoo03eoo`H0009oo`80009oo`8000=oo`@000=oo`D0
00Aoo`D000Aoo`<000Aoo`D000=oo`@000=oo`<00004Ool000000006Ool6000DOol0049oo`03001o
ogoo03=oo`<07omooleoo`03001oogoo03ioo`05001oogooOol00003Ool01000Oomoo`000goo00<0
07ooOol00Woo00D007ooOomoo`0000Ioo`03001oogoo00Ioo`05001oogooOol00005Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol01Goo1P0057oo0012Ool00`00
Oomoo`0dOol00`0OOomoo`0DOol3O03oOoneOol00`00Oomoo`0nOol00`00Oomoo`06Ool20004Ool0
0`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol01Goo1P0057oo0012Ool00`00Oomoo`1>
Ool3O03oOonbOol00`00Oomoo`0nOol00`00Ool00006Ool20004Ool00`00Oomoo`06Ool00`00Oomo
o`04Ool60003Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00<007ooOol01Goo1P0057oo0012Ool00`00Oomoo`3oOoooOol4Ool00`00Oomoo`0nOol30005
Ool01000Oomoo`000goo00@007ooOomoo`8000=oo`8000Eoo`03001oogoo009oo`05001oogooOol0
0009Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoogoo0P000Woo00<007ooOol01Goo1P00
57oo0012Ool00`00Oomoo`1EOol2O03oOon/Ool00`00Oomoo`0nOol00`00Ool00004Ool20002Ool2
0003Ool3000017oo001oogoo0P0000Aoo`00000000=oo`@000=oo`D000Aoo`<000Eoo`@000=oo`80
0003Ool0000000Qoo`H001Aoo`00@Woo00<007ooOol0?7oo00<07gooOol067oo0g`0ogooZGoo00<0
07ooOol0?Woo00D007ooOomoo`0002=oo`03001oogoo025oo`H001Aoo`00@Woo00<007ooOol0>goo
0`0OogooaGoo00<007ooOol0?Goo1P00;Goo00<007ooOol05goo1P0057oo0012Ool00`00Oomoo`0l
Ool301lOOol3O03oOonROol00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo03eoo`0301moogoo
025oo`=l0?mooimoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0ogooogoo17oo00<007oo
Ool02Goo0`0O27oo0`0O27oo100O27oo0`0OG7oo1P0057oo0012Ool30016Ool00`0OOomoo`0OOol3
O03oOonHOol00`00Oomoo`09Ool301l8Ool301l8Ool401l8Ool301mLOol6000DOol0049oo`03001o
ogoo04Eoo`<07b=oo`=l0?mooiEoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0AWoo0`0O
ogoo^Woo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`17Ool00`0OOomoo`0WOol3O03oOon?
Ool00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo07Aoo`=l0?moohaoo`03001oogoo08Yoo`H0
01Aoo`00@Woo00<007ooOol0D7oo00<07gooOol0ogoo/7oo00<007ooOol0?Goo0`001Woo0`0000=o
o`0000000Woo1@000goo100017oo0`0000=oo`0000000Woo1@007goo1P0057oo0012Ool00`00Oomo
o`1>Ool401lYOol3O03oOon5Ool00`00Oomoo`0nOol00`00Oomoo`04Ool01000Oomoogoo0P000Woo
00<007ooOol01Goo00<007ooOol00Woo00@007ooOol000=oo`8000Eoo`03001oogoo01moo`H001Ao
o`00@Woo00<007ooOol0CWoo1@0O:goo0g`0ogooPWoo00<007ooOol0?Woo00<007ooOol017oo00<0
07ooOol00Woo00@007ooOol000Moo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo01moo`H001Aoo`00@Woo00<007ooOol0DGoo00<07gooOol0ogoo[goo00<007ooOol0?Woo
00<007oo00001Goo1@000Woo1P000Woo00<007ooOol01Woo1@001Goo00<007ooOol07goo1P0057oo
0012Ool00`00Oomoo`1KOol00`0OOomoo`0VOol3O03oOomlOol00`00Oomoo`0nOol30004Ool00`00
Oomoo`02Ool01000Oomoo`0017oo00@007ooOol000=oo`80009oo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo01moo`H001Aoo`00@Woo00<007ooOol0FWoo0`0O:Woo0g`0ogooNGoo00<007oo
Ool0?Woo00<007oo00001Goo100017oo100017oo0`0000=oo`00Ool00Woo10001Woo00<007ooOol0
7goo1P0057oo0012Ool00`00Oomoo`1KOol301ooOonUOol00`00Oomoo`0nOol01@00Oomoogoo0000
9Goo00<007ooOol07goo1P0057oo0012Ool3001LOol00`0OOomoo`0_Ool3O03oOombOol00`00Oomo
o`0mOol6000TOol2000QOol6000DOol0049oo`03001oogoo095oo`=l0?moofmoo`03001oogoo08Yo
o`H001Aoo`00@Woo00<007ooOol0I7oo0`0OogooW7oo00<007ooOol0RWoo1P0057oo0012Ool00`00
Oomoo`1TOol301l9Ool00`0OOomoo`0TOol3O03oOomYOol00`00Oomoo`2:Ool6000DOol0049oo`03
001oogoo06moo`<07bQoo`=l0?moofIoo`03001oogoo08Yoo`H001Aoo`00@Woo00<007ooOol0L7oo
0`0OogooT7oo00<007ooOol0RWoo1P0057oo0012Ool00`00Oomoo`1aOol00`0OOomoo`06Ool401lS
Ool3O03oOomOOol00`00Oomoo`2:Ool6000DOol0049oo`03001oogoo07Yoo`@07aAoo`0301moogoo
00moo`=l0?mooeaoo`03001oogoo08Yoo`H001Aoo`00@Woo0`00QGoo100O27oo0`0O87oo00<07goo
Ool0ogooC7oo00<007ooOol0RWoo00<007ooOol05goo0012Ool00`00Oomoo`25Ool401l8Ool401l7
Ool301l8Ool301l3O005Ool401ooOom=Ool00`00Oomoo`2:Ool00`00Oomoo`0GOol0049oo`03001o
ogoo095oo`<07`Qoo`<07`Qoo`<07`=oo`=l009oo`D07`Moo`<07`Qoo`<07`Qoo`<07`Qoo`@07`Qo
o`<07`Qoo`<07`Qoo`<07`Qoo`@07`Moo`@07`Qoo`<07`Qoo`<07`Qoo`@07lEoo`03001oogoo08Yo
o`03001oogoo01Moo`00@Woo00<007ooOol0]Goo00<07gooOol01Woo0`0O27oo0`0O27oo0`0O27oo
100O27oo0`0O27oo0`0O27oo0`0O27oo100O1goo100O27oo0`0O27oo0`0O27oo100O27oo0`0O27oo
0`0O27oo0`0O27oo100O27oo0`0O27oo0`0O27oo0`0O27oo100O1goo100O27oo0`0O27oo0`0O27oo
100O?Woo00<007ooOol0RWoo00<007ooOol05goo0012Ool00`00Oomoo`2dOol3O02>Ool301l8Ool3
01l8Ool301l8Ool401l8Ool301l8Ool301l8Ool301l8Ool401l7Ool401l8Ool301l8Ool301l8Ool4
01lnOol00`00Oomoo`2:Ool00`00Oomoo`0GOol0049oo`03001oogoo0;Moo`=l0?moodUoohh001Uo
o`00@Woo00<007ooOol0ogooogooZgoo0012Ool3002nOol3O03oOooYOol0049oo`03001oogoo0<5o
o`9l0?moonMoo`00@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomoo`37Ool3O03oOooPOol0
049oo`03001oogoo0<Yoo`=l0?moomeoo`00@Woo0`00ogooogooZgoo0012Ool00`00Oomoo`3AOol2
O03oOooGOol0049oo`03001oogoo0==oo`=l0?moomAoo`00@Woo00<007ooOol0ogooogooZgoo0012
Ool3003JOol3O03oOoo=Ool0049oo`03001oogoo0=eoo`=l0?moolYoo`00@Woo00<007ooOol0ogoo
ogooZgoo0012Ool00`00Oomoo`3TOol2O03oOoo4Ool0049oo`<00>Ioo`=l0?mool5oo`00@Woo00<0
07ooOol0ogooogooZgoo0012Ool00`00Oomoo`3]Ool3O03oOonjOol0049oo`03001oogoo0?1oo`=l
0?mookMoo`00=7oo1@002Goo0`00ogooogooZgoo000fOol00`00Oomoo`09Ool00`00Oomoo`3gOol3
O03oOon`Ool003Ioo`03001oogoo00Uoo`03001oogoo0?Yoo`=l0?moojeoo`00=Woo00<007ooOol0
2Goo1000ogooogooZWoo000fOol00`00Oomoo`09Ool00`00Oomoo`3oOol1Ool3O03oOonWOol003Io
o`03001oogoo00Uoo`03001oogoo0?moo`Aoo`=l0?moojAoo`00=7oo0`002goo00<007ooOol0ogoo
ogooZgoo000fOol00`00Oomoo`09Ool00`00Oomoo`3oOol;Ool3O03oOonMOol0049oo`03001oogoo
0?moo`ioo`=l0?mooiYoo`00@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomoo`3oOolEOol2
O03oOonDOol0049oo`03001oogoo0?mooaMoo`=l0?mooi5oo`00@Woo00<007ooOol0ogoo7Woo0W`0
ogooRgoo0012Ool00`00Oomoo`3oOolPOol2O03oOon9Ool0049oo`03001oogoo0?moob9oo`9l0?mo
ohMoo`00@Woo00<007ooOol0ogoo:7oo00=l07ooOol0ogooP7oo0012Ool00`00Oomoo`3oOolYOol2
O03oOon0Ool0049oo`03001oogoo0?moob]oo`9l0?moogioo`00@Woo00<007ooOol0ogoo<Goo0W`0
ogooN7oo0012Ool00`00Oomoo`3oOolcOol2O03oOomfOol0049oo`03001oogoo0?moocEoo`9l0?mo
ogAoo`00@Woo00<007ooOol0ogoo>goo0g`0ogooKGoo0012Ool3003oOolnOol3O03oOomZOol0049o
o`03001oogoo0?mooomooj]oo`00@Woo00<007ooOol0ogooA7oo0g`0ogooI7oo0012Ool00`00Oomo
o`3oOom7Ool3O03oOomQOol0049oo`03001oogoo0?moodioo`9l0?mooe]oo`00@Woo00<007ooOol0
ogooD7oo0W`0ogooFGoo0012Ool00`00Oomoo`3oOomBOol2O03oOomGOol0049oo`03001oogoo0?mo
oeQoo`9l0?mooe5oo`00@Woo00<007ooOol0ogooFWoo0W`0ogooCgoo0012Ool00`00Oomoo`3oOomL
Ool2O03oOom=Ool0049oo`03001oogoo0?moof5oo`=l0?moodMoo`00@Woo00<007ooOol0ogooI7oo
0g`0ogooA7oo0012Ool3003oOoooOon[Ool0049oo`03001oogoo0?moof]oo`=l0?mooceoo`00@Woo
00<007ooOol0ogooKWoo0g`0ogoo>Woo0012Ool00`00Oomoo`3oOomeOol3O03oOolcOol0049oo`03
001oogoo0?moogQoo`9l0?mooc5oo`00@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomoo`3o
OomnOol3O03oOolZOol0049oo`03001oogoo0?mooh5oo`=l0?moobMoo`00@Woo0`00ogooR7oo0W`0
ogoo8Goo0012Ool00`00Oomoo`3oOon:Ool2O03oOolOOol0049oo`03001oogoo0?moohaoo`9l0?mo
oaeoo`00@Woo00<007ooOol0ogooTWoo0W`0ogoo5goo0012Ool00`00Oomoo`3oOonDOol3O03oOolD
Ool0049oo`03001oogoo0?mooomooj]oo`00@Woo00<007ooOol0ogooVgoo0g`0ogoo3Goo0012Ool3
003oOonNOol3O03oOol:Ool0049oo`03001oogoo0?moojEoo`Al0?moo`9oo`00@Woo00<007ooOol0
ogooZGoo0W`0ogoo0012Ool00`00Oomoo`3oOoooOon[Ool0049oo`03001oogoo0?moojmoo`=l0?Qo
o`00@Woo0`00ogoo/Woo0W`0mWoo0012Ool00`00Oomoo`3oOonhOol4O03^Ool0049oo`03001oogoo
0?mookaoo`9l0>aoo`00@Woo00<007ooOol0ogooogooZgoo0012Ool3003oOoo2Ool2O03VOol0049o
o`03001oogoo0?moolAoo`Al0>9oo`00@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomoo`3o
OoooOon[Ool0049oo`<00?mooomooj]oo`00@Woo00<007ooOol0ogooogooZgoo0012Ool00`00Oomo
o`3oOoooOon[Ool0049oo`<00?mooomooj]oo`00@Woo00<007ooOol0ogooogooZgoo003oOoooOoo`
Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003o
OoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00n7oo0`00
17oo10000goo0`0000Eoo`00000007oo00D000Eoo`<000Aoo`<00004Ool00000Ool3000017oo0000
00000goo0`0027oo1@000Woo0`0000Aoo`00000000=oo`<000Aoo`<00004Ool00000Ool20002Ool3
0002Ool5003oOon7Ool00?Moo`05001oogooOol00002Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00@007ooOol000Aoo`05001oogooOol00003Ool01000Oomoo`000goo0P000goo00D007ooOomo
o`0000=oo`05001oogooOol00009Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00D007ooOomo
o`00009oo`04001oogooOol20003Ool01000Oomoo`000goo00<007ooOol0ogooRWoo003fOol00`00
Oomoo`05Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol01Goo00D007ooOomoo`00
00Ioo`03001oogoo009oo`05001oogooOol00003Ool01@00Oomoogoo00003Goo00<007ooOol00goo
00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo009oo`07001oogooOol007oo000017oo
00<007ooOol0ogooRWoo003fOol00`00Oomoo`05Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo
00@007ooOomoo`@000Aoo`03001oogoo00Eoo`D000=oo`05001oogooOol00003Ool00`00Oomoo`0;
Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00<007ooOol01Goo1@000goo0`0017oo1P00ogoo
Qgoo0018Ool3002[Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoogoo0P000Woo00@007oo
Ool000Aoo`05001oogooOol00006Ool00`00Oomoo`02Ool01000Oomoogoo0P000Woo00D007ooOomo
o`0000eoo`03001oogoo00=oo`80009oo`05001oogooOol00006Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000Woo00D007ooOomoo`0000Aoo`03001oogoo0?moohEoo`00BGoo00<007ooOol0ZWoo00<0
07ooOol01Woo10000goo0P0000=oo`00000017oo1@000Woo1@0017oo10000goo0P0000=oo`000000
0goo1@0027oo0`0017oo0P0000=oo`0000000goo1@0017oo100017oo00<007oo00000`000Woo1000
ogooR7oo000lOol50004Ool300000goo001oo`2/Ool01@00Oomoogoo00006goo00<007ooOol05Goo
00<007ooOol06Goo00<007ooOol03Goo00<007ooOol0ogooTGoo000mOol01@00Oomoogoo00000Woo
00@007ooOomoo`800:ioo`@0045oo`03001oogoo01Yoo`800?mooi=oo`00?Goo00D007ooOomoo`00
009oo`03001oogoo009oo`03001oogoo0?mooomoojAoo`00?Goo00D007ooOomoo`00009oo`03001o
ogoo009oo`03001oogoo0?mooomoojAoo`00?Goo10000goo00@007ooOomoo`800?mooomoojIoo`00
?Goo00D007ooOomoo`0000=oo`<00003Ool000000?mooomoojEoo`00?Goo00D007ooOomoo`000?mo
oomoojioo`00?7oo1@00ogooogoo[goo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003o
OoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogoo
l7oo003oOoooOoo`Ool00?mooomooo1oo`00ogooogool7oo003oOoooOoo`Ool00?mooomooo1oo`00
ogooogool7oo003oOoooOoo`Ool00001\
\>"],
  ImageRangeCache->{{{0, 749}, {366.813, 0}} -> {-1.06507, -0.648943, \
0.00442282, 0.00442282}, {{18.375, 583.625}, {358.063, 8.6875}} -> {-0.39263, \
-3.96799, 0.00629642, 0.0189428}, {{583.625, 724.938}, {268.188, 126.875}} -> \
{-14.9683, -3.1709, 0.0318446, 0.0389212}, {{595.375, 634.625}, {258.5, \
226.438}} -> {-15.9524, -10.7645, 0.0334398, 0.108214}, {{595.375, 634.625}, \
{213.563, 181.438}} -> {-15.9524, -14.6575, 0.0334398, 0.108214}, {{595.375, \
634.625}, {168.625, 136.5}} -> {-15.9524, -18.5478, 0.0334398, 0.108214}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[101]="]
}, Open  ]],

Cell["These  values are the same that Table A.12.? of ICRP 78 ", "Text"],

Cell["\<\
Sometime it can be useful to obtain an approximated expressions for \
estimating the lung retention and the urine and faecal excretion. \
\>", "MathCaption"],

Cell["\<\
The first step is to obtain the full expression (It is not shown because is \
too long)\
\>", "Text"],

Cell[BoxData[
    \(\({uraniumLungRet[t_], \ uraniumUriExcretion[t_], \ 
          uraniumFecExcretion[t_], \ uraniumWholebody[t_]} = 
        Map[Last, 
          BiokdataReport[
            element, "\<Inhalation\>", \ "\<Acute\>", "\<Automatic\>", 1, \ 
            amad, class, \ fn1, t, lambda]];\)\)], "Input",
  CellLabel->"In[102]:="],

Cell["\<\
Here is build a new expression eliminating the negligible terms\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(uraniumLungRetShort[t_] = Drop[uraniumLungRet[t] // Chop, 7]\)], "Input",\

  CellLabel->"In[103]:="],

Cell[BoxData[
    \(0.010053333963025171`\ \[ExponentialE]\^\(\(-10.0001`\)\ t\) + 
      0.007981512842198623`\ \[ExponentialE]\^\(\(-2.0001`\)\ t\) + 
      0.010307893988629533`\ \[ExponentialE]\^\(\(-0.0301`\)\ t\) + 
      0.016134061219013337`\ \[ExponentialE]\^\(\(-0.0201`\)\ t\) + 
      0.03190068914967446`\ \[ExponentialE]\^\(\(-0.0011`\)\ t\) + 
      0.004428311936829278`\ \[ExponentialE]\^\(\(-0.00022`\)\ t\) + 
      0.0010868960941352924`\ \[ExponentialE]\^\(\(-0.0001`\)\ t\)\)], \
"Output",
  CellLabel->"Out[103]="]
}, Open  ]],

Cell["\<\
Both expression are compared. It can be observer that the short expression \
give the same solution that the full expression\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[\((uraniumLungRet[t] - uraniumLungRetShort[t])\)/
        uraniumLungRet[t], \ {t, \ 1, 100}]\)], "Input",
  CellLabel->"In[104]:="],

Cell[BoxData[
    \({0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 
      0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 
      0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 
      0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 
      0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 
      0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 
      0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 
      0.`, 0.`}\)], "Output",
  CellLabel->"Out[104]="]
}, Open  ]],

Cell["\<\
We procedure in the same way for urine and faecal excretion.  We build a new \
expression eliminating the negligible terms\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(uraniumUriExcretionShort[t_] = 
      Chop[Drop[
          uraniumUriExcretion[t] /. \ \ x_?NumberQ\  :> \ 
              SetPrecision[x, \ 3], \ 8], 10^\(-7\)]\)], "Input",
  CellLabel->"In[105]:="],

Cell[BoxData[
    \(\(-1.5226989551476599605`3.000000000000001\)\ \
\[ExponentialE]\^\(\(-10.0000999999999997669`3.000000000000001\)\ t\) - 
      1.6996055790256019896`2.9999999999999996\ \
\[ExponentialE]\^\(\(-6.0120240480961939511`2.9999999999999996\)\ t\) + 
      1.1079326151403123719`2.9740985808133735\ \
\[ExponentialE]\^\(\(-5.3780035102389831536`3.000000000000001\)\ t\) + 
      0.0001632283188521304`2.9999999999999996\ \
\[ExponentialE]\^\(\(-2.000100000000000211`2.9999999999999996\)\ t\) + 
      2.7016129957515`2.768950072960469*^-6\ \
\[ExponentialE]\^\(\(-0.3436368331818790978`3.0000000000000013\)\ t\) + 
      3.4746427349227`2.9742687169627144*^-6\ \
\[ExponentialE]\^\(\(-0.1388439316660918799`3. \)\ t\) + 
      6.39782405522`2.9295939492678342*^-7\ \
\[ExponentialE]\^\(\(-0.0990000000000037517`2.9999999999999996\)\ t\) + 
      0.0000162951280267747`2.92806364623655\ \
\[ExponentialE]\^\(\(-0.0972756442480573469`3.000000000000001\)\ t\) + 
      3.1658013364066`3.000000000000001*^-6\ \
\[ExponentialE]\^\(\(-0.0300999999999999983`3.0000000000000013\)\ t\) + 
      2.1086466495564`3.000000000000001*^-6\ \
\[ExponentialE]\^\(\(-0.0200999999999999998`2.999999999999999\)\ t\) + 
      1.0397155728131`2.7749815238848163*^-6\ \
\[ExponentialE]\^\(\(-0.0125838165507303756`2.9999999999999996\)\ t\) + 
      3.0644983144636`2.9999999999999996*^-6\ \
\[ExponentialE]\^\(\(-0.0011000000000000001`3.0000000000000013\)\ t\) + 
      4.318868178244`3.000000000000001*^-7\ \
\[ExponentialE]\^\(\(-0.00022`2.999999999999999\)\ t\) + 
      1.166022623412185654779`3.000000000000001*^-7\ \
\[ExponentialE]\^\(\(-0.0001`3.0000000000000013\)\ t\)\)], "Output",
  CellLabel->"Out[105]="]
}, Open  ]],

Cell["\<\
Both expression are compared. It can be observed that the short expression \
gives the same solution that the full expression for t>1\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Chop[
      Table[\((uraniumUriExcretion[t] - uraniumUriExcretionShort[t])\)/
          uraniumUriExcretion[t], \ {t, \ 1, 100}], 0.05]\)], "Input",
  CellLabel->"In[106]:="],

Cell[BoxData[
    \({\(-0.329339170252274`\), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[106]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(uraniumFecExcretionShort[t_] = 
      Chop[Drop[
          uraniumFecExcretion[t] /. \ \ x_?NumberQ\  :> \ 
              SetPrecision[x, \ 3], 8], 10^\(-7\)]\)], "Input",
  CellLabel->"In[107]:="],

Cell[BoxData[
    \(20.6451296364007711066`3.0000000000000018\ \
\[ExponentialE]\^\(\(-6.0120240480961939511`2.9999999999999996\)\ t\) + 
      0.0005574759782449651`2.9740986353810386\ \
\[ExponentialE]\^\(\(-5.3780035102389831536`3.000000000000001\)\ t\) + 
      0.7636616532730766682`2.999999999999999\ \
\[ExponentialE]\^\(\(-2.000100000000000211`2.9999999999999996\)\ t\) - 
      4.8520273604725963153`2.9999999999999996\ \
\[ExponentialE]\^\(\(-1.8000000000000113687`3.000000000000001\)\ t\) + 
      2.073044868389142259`3.000000000000001\ \
\[ExponentialE]\^\(\(-1.`2.9999999999999996\)\ t\) + 
      0.000330714552184681`2.9999999999999996\ \
\[ExponentialE]\^\(\(-0.0300999999999999983`3.0000000000000013\)\ t\) + 
      0.0003372053660185732`3.0000000000000013\ \
\[ExponentialE]\^\(\(-0.0200999999999999998`2.999999999999999\)\ t\) + 
      0.0000319370992109096`3. \ \
\[ExponentialE]\^\(\(-0.0011000000000000001`3.0000000000000013\)\ t\) + 
      5.335343800437`3.000000000000001*^-7\ \
\[ExponentialE]\^\(\(-0.00022`2.999999999999999\)\ t\)\)], "Output",
  CellLabel->"Out[107]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Chop[
      Table[\((uraniumFecExcretion[t] - uraniumFecExcretionShort[t])\)/
          uraniumFecExcretion[t], \ {t, \ 1, 100}], 0.05]\)], "Input",
  CellLabel->"In[108]:="],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[108]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[uraniumLungRet, uraniumLungRetShort, uraniumUriExcretion, 
      uraniumFecExcretion, uraniumUriExcretionShort, 
      uraniumFecExcretionShort]\)], "Input",
  CellLabel->"In[109]:="]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
PrintingStyleEnvironment->"Printout",
WindowToolbars->"EditBar",
WindowSize->{889, 634},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageFooters->{{Inherited, Cell[ 
        TextData[ {
          "\[Copyright]2004 Guillermo Sanchez & ENUSA. All rights \
reserved."}], "PageFooter"], Inherited}, {Inherited, Cell[ 
        TextData[ {
          "\[Copyright]2004 Guillermo Sanchez & ENUSA . All rights \
reserved."}], "PageFooter"], Inherited}},
ShowSelection->True,
Magnification->1.25,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Introduction"->{
    Cell[11265, 314, 47963, 1185, 373, "Text",
      CellTags->"Introduction"]},
  "Info3263734794-7542638"->{
    Cell[77533, 2037, 229, 4, 48, "Print",
      CellTags->"Info3263734794-7542638"]},
  "ICRP 78"->{
    Cell[1065064, 33462, 224, 7, 49, "MathCaption",
      CellTags->"ICRP 78"],
    Cell[1143559, 36624, 231, 7, 48, "Text",
      CellTags->"ICRP 78"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Introduction", 1319764, 42153},
  {"Info3263734794-7542638", 1319875, 42156},
  {"ICRP 78", 1319977, 42159}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 74, 0, 157, "Chapter"],
Cell[1853, 55, 58, 0, 38, "Commentary"],

Cell[CellGroupData[{
Cell[1936, 59, 40, 0, 48, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[2001, 63, 87, 2, 33, "Input"],
Cell[2091, 67, 91, 2, 70, "Print"],
Cell[2185, 71, 118, 2, 70, "Print"],
Cell[2306, 75, 89, 2, 70, "Print"],
Cell[2398, 79, 148, 3, 70, "Print"]
}, Open  ]],
Cell[2561, 85, 99, 2, 33, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2697, 92, 44, 0, 34, "SubsectionIcon"],
Cell[2744, 94, 233, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[3002, 103, 86, 2, 33, "Input"],
Cell[3091, 107, 8039, 199, 124, "Print"]
}, Open  ]],
Cell[11145, 309, 117, 3, 29, "Text"],
Cell[11265, 314, 47963, 1185, 373, "Text",
  CellTags->"Introduction"],
Cell[59231, 1501, 6511, 212, 185, "DefinitionBox"],
Cell[65745, 1715, 8397, 231, 1394, "Text"],
Cell[74145, 1948, 3385, 87, 69, "DefinitionBox"],
Cell[77533, 2037, 229, 4, 48, "Print",
  CellTags->"Info3263734794-7542638"]
}, Closed]],

Cell[CellGroupData[{
Cell[77799, 2046, 26, 0, 47, "Section"],
Cell[77828, 2048, 248, 8, 52, "Text"],

Cell[CellGroupData[{
Cell[78101, 2060, 35, 0, 48, "SubsectionIcon"],
Cell[78139, 2062, 1039, 29, 86, "Text"],
Cell[79181, 2093, 70, 0, 49, "MathCaption"],
Cell[79254, 2095, 80, 2, 33, "Input"],
Cell[79337, 2099, 229, 4, 54, "Input"],
Cell[79569, 2105, 428, 10, 67, "Text"],
Cell[80000, 2117, 37538, 953, 335, 15699, 678, "GraphicsData", "PostScript", \
"Graphics"],
Cell[117541, 3072, 75, 0, 29, "Text"],
Cell[117619, 3074, 130, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[117774, 3081, 79, 2, 33, "Input"],
Cell[117856, 3085, 543, 17, 173, "Output"]
}, Open  ]],
Cell[118414, 3105, 577, 12, 86, "Text"],

Cell[CellGroupData[{
Cell[119016, 3121, 201, 4, 55, "Input"],
Cell[119220, 3127, 785, 21, 201, "Output"]
}, Open  ]],
Cell[120020, 3151, 64, 0, 49, "MathCaption"],

Cell[CellGroupData[{
Cell[120109, 3155, 94, 2, 33, "Input"],
Cell[120206, 3159, 979, 21, 191, "Output"]
}, Open  ]],
Cell[121200, 3183, 101, 2, 49, "MathCaption"],

Cell[CellGroupData[{
Cell[121326, 3189, 69, 2, 33, "Input"],
Cell[121398, 3193, 168, 3, 46, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[121615, 3202, 35, 0, 34, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[121675, 3206, 99, 2, 30, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[121799, 3212, 176, 4, 54, "Input"],
Cell[121978, 3218, 1352, 22, 137, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[123367, 3245, 167, 4, 33, "Input"],
Cell[123537, 3251, 1703, 28, 158, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[125277, 3284, 186, 4, 54, "Input"],
Cell[125466, 3290, 1585, 28, 137, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[127088, 3323, 187, 4, 54, "Input"],
Cell[127278, 3329, 1330, 22, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[128657, 3357, 103, 2, 24, "SubsubsectionIcon"],
Cell[128763, 3361, 132, 1, 51, "MathCaption"],

Cell[CellGroupData[{
Cell[128920, 3366, 169, 4, 36, "Input"],
Cell[129092, 3372, 4028, 80, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[133157, 3457, 172, 4, 36, "Input"],
Cell[133332, 3463, 4442, 89, 70, "Output"]
}, Open  ]],
Cell[137789, 3555, 68, 0, 41, "Commentary"],

Cell[CellGroupData[{
Cell[137882, 3559, 180, 4, 36, "Input"],
Cell[138065, 3565, 5053, 96, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[143155, 3666, 181, 4, 36, "Input"],
Cell[143339, 3672, 3993, 80, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[147381, 3758, 103, 2, 24, "SubsubsectionIcon"],
Cell[147487, 3762, 114, 1, 51, "MathCaption"],

Cell[CellGroupData[{
Cell[147626, 3767, 169, 4, 36, "Input"],
Cell[147798, 3773, 35110, 1564, 70, 35026, 1561, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[182911, 5339, 155, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[183103, 5348, 172, 4, 36, "Input"],
Cell[183278, 5354, 30961, 1373, 70, 30877, 1370, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[214242, 6729, 155, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[214434, 6738, 192, 4, 61, "Input"],
Cell[214629, 6744, 62393, 1830, 70, 32733, 1460, "GraphicsData", \
"PostScript", "Graphics"],
Cell[277025, 8576, 155, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[277217, 8585, 181, 4, 36, "Input"],
Cell[277401, 8591, 63020, 1894, 70, 34513, 1538, "GraphicsData", \
"PostScript", "Graphics"],
Cell[340424, 10487, 155, 4, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[340628, 10497, 108, 2, 24, "SubsubsectionIcon"],
Cell[340739, 10501, 147, 1, 51, "MathCaption"],

Cell[CellGroupData[{
Cell[340911, 10506, 174, 4, 36, "Input"],
Cell[341088, 10512, 448, 9, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[341573, 10526, 177, 4, 36, "Input"],
Cell[341753, 10532, 471, 10, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[342261, 10547, 190, 4, 61, "Input"],
Cell[342454, 10553, 440, 8, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[342931, 10566, 181, 4, 61, "Input"],
Cell[343115, 10572, 104, 2, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[343268, 10580, 105, 2, 24, "SubsubsectionIcon"],
Cell[343376, 10584, 168, 2, 51, "MathCaption"],

Cell[CellGroupData[{
Cell[343569, 10590, 171, 4, 36, "Input"],
Cell[343743, 10596, 458, 10, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[344238, 10611, 174, 4, 36, "Input"],
Cell[344415, 10617, 471, 10, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[344923, 10632, 194, 4, 61, "Input"],
Cell[345120, 10638, 103, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[345260, 10645, 183, 4, 36, "Input"],
Cell[345446, 10651, 104, 2, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[345611, 10660, 35, 0, 34, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[345671, 10664, 99, 2, 30, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[345795, 10670, 164, 4, 36, "Input"],
Cell[345962, 10676, 1798, 29, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[347797, 10710, 167, 4, 36, "Input"],
Cell[347967, 10716, 1829, 30, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[349833, 10751, 174, 4, 36, "Input"],
Cell[350010, 10757, 1884, 33, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[351931, 10795, 175, 4, 36, "Input"],
Cell[352109, 10801, 1798, 28, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[353956, 10835, 103, 2, 24, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[354084, 10841, 181, 4, 36, "Input"],
Cell[354268, 10847, 3268, 70, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[357573, 10922, 172, 4, 36, "Input"],
Cell[357748, 10928, 4416, 89, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[362201, 11022, 192, 4, 61, "Input"],
Cell[362396, 11028, 3290, 71, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[365723, 11104, 181, 4, 36, "Input"],
Cell[365907, 11110, 3988, 80, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[369944, 11196, 103, 2, 24, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[370072, 11202, 169, 4, 36, "Input"],
Cell[370244, 11208, 64837, 1932, 70, 35051, 1561, "GraphicsData", \
"PostScript", "Graphics"],
Cell[435084, 13142, 155, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[435276, 13151, 172, 4, 36, "Input"],
Cell[435451, 13157, 30966, 1373, 70, 30882, 1370, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[466420, 14532, 155, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[466612, 14541, 192, 4, 61, "Input"],
Cell[466807, 14547, 32804, 1463, 70, 32720, 1460, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[499614, 16012, 155, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[499806, 16021, 181, 4, 36, "Input"],
Cell[499990, 16027, 34622, 1543, 70, 34538, 1540, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[534615, 17572, 155, 4, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[534819, 17582, 108, 2, 24, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[534952, 17588, 174, 4, 36, "Input"],
Cell[535129, 17594, 565, 11, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[535731, 17610, 177, 4, 36, "Input"],
Cell[535911, 17616, 534, 11, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[536482, 17632, 190, 4, 61, "Input"],
Cell[536675, 17638, 486, 9, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[537198, 17652, 181, 4, 61, "Input"],
Cell[537382, 17658, 104, 2, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[537535, 17666, 105, 2, 24, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[537665, 17672, 171, 4, 36, "Input"],
Cell[537839, 17678, 524, 11, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[538400, 17694, 174, 4, 36, "Input"],
Cell[538577, 17700, 536, 11, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[539150, 17716, 194, 4, 61, "Input"],
Cell[539347, 17722, 103, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[539487, 17729, 183, 4, 36, "Input"],
Cell[539673, 17735, 104, 2, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[539838, 17744, 36, 0, 34, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[539899, 17748, 100, 2, 30, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[540024, 17754, 182, 4, 54, "Input"],
Cell[540209, 17760, 6100, 82, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[546346, 17847, 185, 4, 36, "Input"],
Cell[546534, 17853, 5647, 85, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[552218, 17943, 192, 4, 61, "Input"],
Cell[552413, 17949, 96, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[552546, 17956, 193, 4, 61, "Input"],
Cell[552742, 17962, 6101, 84, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[558892, 18052, 104, 2, 24, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[559021, 18058, 187, 4, 36, "Input"],
Cell[559211, 18064, 4298, 81, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[563546, 18150, 190, 4, 61, "Input"],
Cell[563739, 18156, 5477, 90, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[569253, 18251, 210, 4, 61, "Input"],
Cell[569466, 18257, 96, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[569599, 18264, 197, 4, 61, "Input"],
Cell[569799, 18270, 4254, 81, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[574102, 18357, 104, 2, 24, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[574231, 18363, 187, 4, 36, "Input"],
Cell[574421, 18369, 618, 10, 70, "Message"],
Cell[575042, 18381, 618, 10, 70, "Message"],
Cell[575663, 18393, 618, 10, 70, "Message"],
Cell[576284, 18405, 368, 6, 70, "Message"],
Cell[576655, 18413, 71158, 2194, 70, 41798, 1827, "GraphicsData", \
"PostScript", "Graphics"],
Cell[647816, 20609, 155, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[648008, 20618, 190, 4, 61, "Input"],
Cell[648201, 20624, 59161, 1828, 70, 33378, 1505, "GraphicsData", \
"PostScript", "Graphics"],
Cell[707365, 22454, 155, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[707557, 22463, 196, 4, 61, "Input"],
Cell[707756, 22469, 96, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[707889, 22476, 199, 4, 61, "Input"],
Cell[708091, 22482, 618, 10, 70, "Message"],
Cell[708712, 22494, 618, 10, 70, "Message"],
Cell[709333, 22506, 618, 10, 70, "Message"],
Cell[709954, 22518, 368, 6, 70, "Message"],
Cell[710325, 22526, 66568, 2045, 70, 38135, 1689, "GraphicsData", \
"PostScript", "Graphics"],
Cell[776896, 24573, 155, 4, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[777100, 24583, 109, 2, 24, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[777234, 24589, 192, 4, 54, "Input"],
Cell[777429, 24595, 1718, 35, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[779184, 24635, 195, 4, 54, "Input"],
Cell[779382, 24641, 1211, 24, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[780630, 24670, 221, 5, 54, "Input"],
Cell[780854, 24677, 96, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[780987, 24684, 197, 5, 54, "Input"],
Cell[781187, 24691, 104, 2, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[781340, 24699, 106, 2, 24, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[781471, 24705, 191, 4, 54, "Input"],
Cell[781665, 24711, 1115, 23, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[782817, 24739, 192, 4, 54, "Input"],
Cell[783012, 24745, 1127, 23, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[784176, 24773, 212, 4, 54, "Input"],
Cell[784391, 24779, 96, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[784524, 24786, 199, 4, 54, "Input"],
Cell[784726, 24792, 104, 2, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[784903, 24802, 25, 0, 80, "Section"],

Cell[CellGroupData[{
Cell[784953, 24806, 38, 0, 30, "SubsubsectionIcon"],
Cell[784994, 24808, 412, 5, 67, "Text"],
Cell[785409, 24815, 13141, 165, 444, 13049, 162, "GraphicsData", "Metafile", \
"Text"],
Cell[798553, 24982, 72, 0, 38, "Commentary"],

Cell[CellGroupData[{
Cell[798650, 24986, 80, 2, 33, "Input"],
Cell[798733, 24990, 592, 18, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[799362, 25013, 176, 4, 59, "Input"],
Cell[799541, 25019, 1031, 27, 70, "Output"]
}, Open  ]],
Cell[800587, 25049, 106, 2, 33, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[800730, 25056, 38, 0, 24, "SubsubsectionIcon"],
Cell[800771, 25058, 270, 5, 68, "MathCaption"],
Cell[801044, 25065, 192, 4, 59, "Commentary"],
Cell[801239, 25071, 102, 2, 33, "Input"],
Cell[801344, 25075, 27, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[801396, 25079, 169, 4, 33, "Input"],
Cell[801568, 25085, 4654, 89, 70, "Output"]
}, Open  ]],
Cell[806237, 25177, 30, 0, 31, "Text"],

Cell[CellGroupData[{
Cell[806292, 25181, 172, 4, 61, "Input"],
Cell[806467, 25187, 29815, 1305, 70, 29731, 1302, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[836285, 26494, 155, 4, 70, "Output"]
}, Open  ]],
Cell[836455, 26501, 241, 4, 60, "MathCaption"],

Cell[CellGroupData[{
Cell[836721, 26509, 202, 4, 61, "Input"],
Cell[836926, 26515, 481, 10, 70, "Output"]
}, Open  ]],
Cell[837422, 26528, 130, 3, 49, "MathCaption"],

Cell[CellGroupData[{
Cell[837577, 26535, 171, 4, 61, "Input"],
Cell[837751, 26541, 57340, 1647, 70, 29731, 1302, "GraphicsData", \
"PostScript", "Graphics"],
Cell[895094, 28190, 155, 4, 70, "Output"]
}, Open  ]],
Cell[895264, 28197, 134, 3, 49, "MathCaption"],

Cell[CellGroupData[{
Cell[895423, 28204, 196, 4, 54, "Input"],
Cell[895622, 28210, 63105, 1790, 70, 31804, 1400, "GraphicsData", \
"PostScript", "Graphics"],
Cell[958730, 30002, 155, 4, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[958934, 30012, 38, 0, 24, "SubsubsectionIcon"],
Cell[958975, 30014, 513, 17, 49, "MathCaption"],
Cell[959491, 30033, 112, 2, 33, "Input"],
Cell[959606, 30037, 27, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[959658, 30041, 181, 4, 54, "Input"],
Cell[959842, 30047, 4539, 87, 833, "Output"]
}, Open  ]],
Cell[964396, 30137, 30, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[964451, 30141, 172, 4, 54, "Input"],
Cell[964626, 30147, 32671, 1408, 375, 32587, 1405, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[997300, 31557, 155, 4, 32, "Output"],
Cell[997458, 31563, 61635, 1755, 375, 30882, 1370, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1059096, 33320, 207, 6, 28, "Output"]
}, Open  ]],
Cell[1059318, 33329, 596, 19, 72, "MathCaption"],
Cell[1059917, 33350, 111, 2, 33, "Input"],

Cell[CellGroupData[{
Cell[1060053, 33356, 181, 4, 54, "Input"],
Cell[1060237, 33362, 4540, 86, 70, "Output"]
}, Open  ]],
Cell[1064792, 33451, 193, 4, 65, "Commentary"]
}, Closed]],

Cell[CellGroupData[{
Cell[1065022, 33460, 39, 0, 24, "SubsubsectionIcon"],
Cell[1065064, 33462, 224, 7, 49, "MathCaption",
  CellTags->"ICRP 78"],
Cell[1065291, 33471, 238, 5, 33, "Input"],
Cell[1065532, 33478, 27, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[1065584, 33482, 187, 4, 54, "Input"],
Cell[1065774, 33488, 5649, 90, 70, "Output"]
}, Open  ]],
Cell[1071438, 33581, 30, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[1071493, 33585, 190, 4, 54, "Input"],
Cell[1071686, 33591, 29703, 1350, 70, 29619, 1347, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1101392, 34943, 155, 4, 70, "Output"]
}, Open  ]],
Cell[1101562, 34950, 180, 3, 59, "Commentary"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1101791, 34959, 26, 0, 80, "Section"],

Cell[CellGroupData[{
Cell[1101842, 34963, 38, 0, 30, "SubsubsectionIcon"],
Cell[1101883, 34965, 62, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[1101970, 34969, 81, 2, 33, "Input"],
Cell[1102054, 34973, 1090, 31, 70, "Output"]
}, Open  ]],
Cell[1103159, 35007, 158, 3, 48, "Text"],

Cell[CellGroupData[{
Cell[1103342, 35014, 198, 4, 54, "Input"],
Cell[1103543, 35020, 1684, 49, 70, "Output"]
}, Open  ]],
Cell[1105242, 35072, 154, 3, 38, "Commentary"],
Cell[1105399, 35077, 106, 2, 33, "Input"],
Cell[1105508, 35081, 138, 3, 33, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1105683, 35089, 38, 0, 24, "SubsubsectionIcon"],
Cell[1105724, 35091, 27, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[1105776, 35095, 169, 4, 33, "Input"],
Cell[1105948, 35101, 4616, 89, 70, "Output"]
}, Open  ]],
Cell[1110579, 35193, 30, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[1110634, 35197, 172, 4, 54, "Input"],
Cell[1110809, 35203, 32502, 1407, 70, 32418, 1404, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1143314, 36612, 155, 4, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1143518, 36622, 38, 0, 24, "SubsubsectionIcon"],
Cell[1143559, 36624, 231, 7, 48, "Text",
  CellTags->"ICRP 78"],
Cell[1143793, 36633, 60, 0, 49, "MathCaption"],
Cell[1143856, 36635, 77, 2, 33, "Input"],
Cell[1143936, 36639, 27, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[1143988, 36643, 181, 4, 54, "Input"],
Cell[1144172, 36649, 4662, 89, 70, "Output"]
}, Open  ]],
Cell[1148849, 36741, 30, 0, 31, "Text"],

Cell[CellGroupData[{
Cell[1148904, 36745, 172, 4, 36, "Input"],
Cell[1149079, 36751, 31489, 1368, 70, 31405, 1365, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1180571, 38121, 155, 4, 70, "Output"]
}, Open  ]],
Cell[1180741, 38128, 61, 0, 38, "MathCaption"],
Cell[1180805, 38130, 78, 2, 36, "Input"],
Cell[1180886, 38134, 27, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[1180938, 38138, 181, 4, 61, "Input"],
Cell[1181122, 38144, 4523, 88, 70, "Output"]
}, Open  ]],
Cell[1185660, 38235, 30, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[1185715, 38239, 172, 4, 54, "Input"],
Cell[1185890, 38245, 60516, 1799, 70, 33272, 1459, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1246409, 40046, 155, 4, 70, "Output"]
}, Open  ]],
Cell[1246579, 40053, 72, 0, 29, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1246688, 40058, 39, 0, 24, "SubsubsectionIcon"],
Cell[1246730, 40060, 225, 6, 68, "MathCaption"],
Cell[1246958, 40068, 119, 3, 33, "Input"],
Cell[1247080, 40073, 27, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[1247132, 40077, 188, 4, 54, "Input"],
Cell[1247323, 40083, 5655, 90, 835, "Output"]
}, Open  ]],
Cell[1252993, 40176, 30, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[1253048, 40180, 191, 4, 54, "Input"],
Cell[1253242, 40186, 57550, 1734, 375, 31031, 1403, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1310795, 41922, 156, 4, 32, "Output"]
}, Open  ]],
Cell[1310966, 41929, 72, 0, 29, "Text"],
Cell[1311041, 41931, 167, 3, 68, "MathCaption"],
Cell[1311211, 41936, 111, 3, 29, "Text"],
Cell[1311325, 41941, 342, 7, 75, "Input"],
Cell[1311670, 41950, 94, 2, 49, "MathCaption"],

Cell[CellGroupData[{
Cell[1311789, 41956, 121, 3, 33, "Input"],
Cell[1311913, 41961, 537, 9, 53, "Output"]
}, Open  ]],
Cell[1312465, 41973, 155, 3, 49, "MathCaption"],

Cell[CellGroupData[{
Cell[1312645, 41980, 158, 3, 33, "Input"],
Cell[1312806, 41985, 609, 9, 116, "Output"]
}, Open  ]],
Cell[1313430, 41997, 153, 3, 49, "MathCaption"],

Cell[CellGroupData[{
Cell[1313608, 42004, 219, 5, 54, "Input"],
Cell[1313830, 42011, 1707, 29, 95, "Output"]
}, Open  ]],
Cell[1315552, 42043, 157, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[1315734, 42050, 194, 4, 54, "Input"],
Cell[1315931, 42056, 410, 6, 95, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1316378, 42067, 217, 5, 54, "Input"],
Cell[1316598, 42074, 1097, 19, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1317732, 42098, 194, 4, 54, "Input"],
Cell[1317929, 42104, 388, 6, 95, "Output"]
}, Open  ]],
Cell[1318332, 42113, 209, 4, 54, "Input"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

