(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    155157,       4659]*)
(*NotebookOutlinePosition[    156681,       4709]*)
(*  CellTagsIndexPosition[    156542,       4701]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Random Intakes", "Chapter"],

Cell["Last update of this help. 2005-08-22", "Commentary"],

Cell[CellGroupData[{

Cell[BoxData[
    \($Version\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("5.2 for Microsoft Windows (June 20, 2005)"\)], "Output",
  CellLabel->"Out[1]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Initialization", "SubsectionIcon"],

Cell["We will need the following packages ", "MathCaption",
  CellTags->"ICRP 78"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Needs["\<Biokmod`Biokdata`\>"]\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \("Resptract 1.2 b1 2005-05-16"\)], "Print",
  CellLabel->"From In[2]:="],

Cell[BoxData[
    \("SysModel, guillermo@usal.es, version 1.3.   2005-08-24"\)], "Print",
  CellLabel->"From In[2]:="],

Cell[BoxData[
    \("Humorap 3.3 b1 2005-06-17"\)], "Print",
  CellLabel->"From In[2]:="],

Cell[BoxData[
    \("Biokdata 1.2.2 2004-09-3 (Lite version. The full version includes all \
ICRP models)"\)], "Print",
  CellLabel->"From In[2]:="]
}, Open  ]],

Cell[BoxData[
    \(Needs["\<Graphics`Graphics`\>"]\)], "Input",
  CellLabel->"In[3]:=",
  CellTags->"Introduction"],

Cell[BoxData[
    \(Needs["\<Graphics`MultipleListPlot`\>"]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(Needs["\<Graphics`FilledPlot`\>"]\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(Needs["\<Statistics`ContinuousDistributions`\>"]\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(Needs["\<Statistics`LinearRegression`\>"]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(Needs["\<Statistics`NonlinearFit`\>"]\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(SeedRandom[]\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(Off[General::spell1]; Off[General::spell];\)], "Input",
  CellLabel->"In[10]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Irregular and random  intakes", "Section",
  CellTags->"Examples"],

Cell["\<\
Irregular and random intakes can be easily solved assuming a multiple single \
inputs. Here is shown by examples.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Example 1", "SubsubsectionIcon"],

Cell[TextData[{
  "Here are supposed 100  random single intakes from day 1 to 200  {",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(intake\_d\)\)\)]],
  "}.  It has been simulated using a lognormal distribution (mean 3 Bq, sigma \
= 1 Bq). "
}], "MathCaption"],

Cell[BoxData[
    \(\(dailyintakes1\  = \ 
        Table[{i, Random[LogNormalDistribution[3, 1]]}, {i, 0, 200, \ 
            2}];\)\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(\({days, \ intakes} = Transpose[dailyintakes1\ ];\)\)], "Input",
  CellLabel->"In[12]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2", "SubsubsectionIcon"],

Cell["\<\
We wish to estimate the retention in the Lungs in workers for inhalation of \
uranium type S and AMAD 5.\
\>", "Text"],

Cell["\<\
It is evaluated the lung retention for an acute intake of 1 Bq in t= 0 AMAD \
5, class S, with a negligible radioactive decay  (i.e: U-238, U-235 or \
U-234). \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(qLungs5S[t_] = LungsRetention[1, AMAD5, S, \ t, 0]\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(0.000010043280629059431`\ \[ExponentialE]\^\(\(-110.1`\)\ t\) + 
      7.97353132935344`*^-6\ \[ExponentialE]\^\(\(-102.1`\)\ t\) + 
      0.000010297586094639224`\ \[ExponentialE]\^\(\(-100.13`\)\ t\) + 
      0.000016117927157791034`\ \[ExponentialE]\^\(\(-100.11999999999999`\)\ \
t\) - 8.131516293641283`*^-20\ \[ExponentialE]\^\(\(-100.11`\)\ t\) + 
      0.000031868788460523434`\ \[ExponentialE]\^\(\(-100.101`\)\ t\) + 
      4.423883624891933`*^-6\ \[ExponentialE]\^\(\(-100.10012`\)\ t\) + 
      1.0858091980412094`*^-6\ \[ExponentialE]\^\(\(-100.1`\)\ t\) + 
      0.010053333963025171`\ \[ExponentialE]\^\(\(-10.0001`\)\ t\) + 
      0.007981512842198623`\ \[ExponentialE]\^\(\(-2.0001`\)\ t\) + 
      0.010307893988629533`\ \[ExponentialE]\^\(\(-0.0301`\)\ t\) + 
      0.016134061219013337`\ \[ExponentialE]\^\(\(-0.0201`\)\ t\) + 
      2.710505431213761`*^-20\ \[ExponentialE]\^\(\(-0.0101`\)\ t\) + 
      0.03190068914967446`\ \[ExponentialE]\^\(\(-0.0011`\)\ t\) + 
      0.004428311936829278`\ \[ExponentialE]\^\(\(-0.00022`\)\ t\) + 
      0.0010868960941352924`\ \[ExponentialE]\^\(\(-0.0001`\)\ t\)\)], \
"Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell["Now we obtained the retention in lungs for \"days\"", "MathCaption"],

Cell[BoxData[
    \(\(\(\ \)\(dailyretencion1\  = \ qLungs5S[days];\)\)\)], "Input",
  CellLabel->"In[14]:="],

Cell[TextData[{
  StyleBox["ListConvolve", "Input"],
  " can be applied to compute the retention.. i.e.:If  {",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  ", ..., ",
  Cell[BoxData[
      \(TraditionalForm\`b\_i\)]],
  ", .., ",
  Cell[BoxData[
      \(TraditionalForm\`b\_n\)]],
  "} the intake days ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(t\)\(=\)\({0,  ... , \ i, \  .. , \ 
          n}\)\(\ \)\)\)]],
  " and f[",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  "] retention or excretion function, Then, the retentions days: {1, 2, ..., \
n}will be evaluated as it follows "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListConvolve[\ {b0, \ b1, \ b2}, {f[1], \ f[2], \ f[3]}, {\(-3\), \ 
          1}, \ 0] // TableForm\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(b0\ f[1]\)},
          {\(b1\ f[1] + b0\ f[2]\)},
          {\(b2\ f[1] + b1\ f[2] + b0\ f[3]\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Times[ b0, 
          f[ 1]], 
        Plus[ 
          Times[ b1, 
            f[ 1]], 
          Times[ b0, 
            f[ 2]]], 
        Plus[ 
          Times[ b2, 
            f[ 1]], 
          Times[ b1, 
            f[ 2]], 
          Times[ b0, 
            f[ 3]]]}]]], "Output",
  CellLabel->"Out[15]//TableForm="]
}, Open  ]],

Cell[BoxData[
    \(\(randomInput1\  = 
        Transpose[{days, 
            ListConvolve[intakes, \ 
              dailyretencion1, \ {\(-Length[dailyintakes1]\), 1}, \ 
              0]}];\)\)], "Input",
  CellLabel->"In[16]:="],

Cell["\<\
Now it is computed the lung retention supposing that each day is intaken the \
daily mean of the period. Obviously, the mean  is obtained  dividing the \
total intake by the number of the days of intakes.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(qLungsChronic1[t_] = 
      LungsRetention[Plus @@ intakes\/Max[days], AMADAdultW[5], S, \ t, 0, \ 
        IntakeType \[Rule] \ "\<Constant\>"]\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \(\(\(821.9400976165584`\)\(\[InvisibleSpace]\)\) - 
      1.2261488963597505`*^-6\ \[ExponentialE]\^\(\(-110.1`\)\ t\) - 
      1.0497355268104394`*^-6\ \[ExponentialE]\^\(\(-102.1`\)\ t\) - 
      1.3823758818095729`*^-6\ \[ExponentialE]\^\(\(-100.13`\)\ t\) - 
      2.1639303615195345`*^-6\ \[ExponentialE]\^\(\(-100.11999999999999`\)\ t\
\) - 4.279391995527318`*^-6\ \[ExponentialE]\^\(\(-100.101`\)\ t\) - 
      5.940514063724319`*^-7\ \[ExponentialE]\^\(\(-100.10012`\)\ t\) - 
      1.4580565609312982`*^-7\ \[ExponentialE]\^\(\(-100.1`\)\ t\) - 
      0.013513277628909899`\ \[ExponentialE]\^\(\(-10.0001`\)\ t\) - 
      0.05363995928701361`\ \[ExponentialE]\^\(\(-2.0001`\)\ t\) - 
      4.603184481678193`\ \[ExponentialE]\^\(\(-0.0301`\)\ t\) - 
      10.789531212574763`\ \[ExponentialE]\^\(\(-0.0201`\)\ t\) - 
      389.81838032969176`\ \[ExponentialE]\^\(\(-0.0011`\)\ t\) - 
      270.56427820573356`\ \[ExponentialE]\^\(\(-0.00022`\)\ t\) - 
      146.09755930852444`\ \[ExponentialE]\^\(\(-0.0001`\)\ t\)\)], "Output",
  CellLabel->"Out[17]="]
}, Open  ]],

Cell["\<\
Here are compared the irregular intakes with the constant intakes. \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[qLungsChronic1[t], {t, 0, 210}, \ 
      Epilog \[Rule] \ {Hue[0], \ PointSize[0.012], 
          Map[Point, randomInput1]}]\)], "Input",
  CellLabel->"In[18]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00453515 0.0147151 0.00530517 [
[.25057 .00222 -6 -9 ]
[.25057 .00222 6 0 ]
[.47732 .00222 -9 -9 ]
[.47732 .00222 9 0 ]
[.70408 .00222 -9 -9 ]
[.70408 .00222 9 0 ]
[.93084 .00222 -9 -9 ]
[.93084 .00222 9 0 ]
[.01131 .12082 -12 -4.5 ]
[.01131 .12082 0 4.5 ]
[.01131 .22692 -12 -4.5 ]
[.01131 .22692 0 4.5 ]
[.01131 .33303 -12 -4.5 ]
[.01131 .33303 0 4.5 ]
[.01131 .43913 -12 -4.5 ]
[.01131 .43913 0 4.5 ]
[.01131 .54523 -18 -4.5 ]
[.01131 .54523 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25057 .01472 m
.25057 .02097 L
s
[(50)] .25057 .00222 0 1 Mshowa
.47732 .01472 m
.47732 .02097 L
s
[(100)] .47732 .00222 0 1 Mshowa
.70408 .01472 m
.70408 .02097 L
s
[(150)] .70408 .00222 0 1 Mshowa
.93084 .01472 m
.93084 .02097 L
s
[(200)] .93084 .00222 0 1 Mshowa
.125 Mabswid
.06916 .01472 m
.06916 .01847 L
s
.11451 .01472 m
.11451 .01847 L
s
.15986 .01472 m
.15986 .01847 L
s
.20522 .01472 m
.20522 .01847 L
s
.29592 .01472 m
.29592 .01847 L
s
.34127 .01472 m
.34127 .01847 L
s
.38662 .01472 m
.38662 .01847 L
s
.43197 .01472 m
.43197 .01847 L
s
.52268 .01472 m
.52268 .01847 L
s
.56803 .01472 m
.56803 .01847 L
s
.61338 .01472 m
.61338 .01847 L
s
.65873 .01472 m
.65873 .01847 L
s
.74943 .01472 m
.74943 .01847 L
s
.79478 .01472 m
.79478 .01847 L
s
.84014 .01472 m
.84014 .01847 L
s
.88549 .01472 m
.88549 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .12082 m
.03006 .12082 L
s
[(20)] .01131 .12082 1 0 Mshowa
.02381 .22692 m
.03006 .22692 L
s
[(40)] .01131 .22692 1 0 Mshowa
.02381 .33303 m
.03006 .33303 L
s
[(60)] .01131 .33303 1 0 Mshowa
.02381 .43913 m
.03006 .43913 L
s
[(80)] .01131 .43913 1 0 Mshowa
.02381 .54523 m
.03006 .54523 L
s
[(100)] .01131 .54523 1 0 Mshowa
.125 Mabswid
.02381 .04124 m
.02756 .04124 L
s
.02381 .06777 m
.02756 .06777 L
s
.02381 .09429 m
.02756 .09429 L
s
.02381 .14734 m
.02756 .14734 L
s
.02381 .17387 m
.02756 .17387 L
s
.02381 .2004 m
.02756 .2004 L
s
.02381 .25345 m
.02756 .25345 L
s
.02381 .27997 m
.02756 .27997 L
s
.02381 .3065 m
.02756 .3065 L
s
.02381 .35955 m
.02756 .35955 L
s
.02381 .38608 m
.02756 .38608 L
s
.02381 .4126 m
.02756 .4126 L
s
.02381 .46565 m
.02756 .46565 L
s
.02381 .49218 m
.02756 .49218 L
s
.02381 .51871 m
.02756 .51871 L
s
.02381 .57176 m
.02756 .57176 L
s
.02381 .59828 m
.02756 .59828 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .05224 L
.10458 .08954 L
.14415 .12207 L
.18221 .15147 L
.22272 .18108 L
.26171 .20823 L
.30316 .23587 L
.34309 .2615 L
.3815 .28537 L
.42237 .31004 L
.46172 .33319 L
.49955 .35496 L
.53984 .37768 L
.57861 .39914 L
.61984 .42158 L
.65954 .44285 L
.69774 .46303 L
.73838 .48422 L
.77751 .50437 L
.81909 .52552 L
.85916 .54567 L
.89771 .56485 L
.93871 .58504 L
.97619 .60332 L
s
1 0 0 r
.012 w
.02381 .01672 Mdot
.03288 .04437 Mdot
.04195 .04067 Mdot
.05102 .04498 Mdot
.06009 .04541 Mdot
.06916 .04648 Mdot
.07823 .0464 Mdot
.0873 .0502 Mdot
.09637 .05064 Mdot
.10544 .06035 Mdot
.11451 .06736 Mdot
.12358 .07385 Mdot
.13265 .07811 Mdot
.14172 .08498 Mdot
.15079 .10551 Mdot
.15986 .09993 Mdot
.16893 .10178 Mdot
.178 .14242 Mdot
.18707 .17542 Mdot
.19615 .16515 Mdot
.20522 .16818 Mdot
.21429 .16665 Mdot
.22336 .16966 Mdot
.23243 .16993 Mdot
.2415 .18442 Mdot
.25057 .22175 Mdot
.25964 .23857 Mdot
.26871 .23548 Mdot
.27778 .24168 Mdot
.28685 .24327 Mdot
.29592 .28067 Mdot
.30499 .27394 Mdot
.31406 .27156 Mdot
.32313 .27336 Mdot
.3322 .27618 Mdot
.34127 .27612 Mdot
.35034 .27952 Mdot
.35941 .28301 Mdot
.36848 .28996 Mdot
.37755 .28919 Mdot
.38662 .28708 Mdot
.39569 .29905 Mdot
.40476 .2935 Mdot
.41383 .29321 Mdot
.4229 .30513 Mdot
.43197 .30912 Mdot
.44104 .30483 Mdot
.45011 .30288 Mdot
.45918 .30122 Mdot
.46825 .30245 Mdot
.47732 .31445 Mdot
.48639 .31415 Mdot
.49546 .31876 Mdot
.50454 .31771 Mdot
.51361 .32229 Mdot
.52268 .33392 Mdot
.53175 .32906 Mdot
.54082 .33965 Mdot
.54989 .336 Mdot
.55896 .33541 Mdot
.56803 .33864 Mdot
.5771 .35418 Mdot
.58617 .36176 Mdot
.59524 .3566 Mdot
.60431 .35576 Mdot
.61338 .3663 Mdot
.62245 .37364 Mdot
.63152 .37579 Mdot
.64059 .38424 Mdot
.64966 .38256 Mdot
.65873 .39539 Mdot
.6678 .4468 Mdot
.67687 .44014 Mdot
.68594 .44526 Mdot
.69501 .44042 Mdot
.70408 .43966 Mdot
.71315 .44581 Mdot
.72222 .44245 Mdot
.73129 .51242 Mdot
.74036 .50194 Mdot
.74943 .50667 Mdot
.7585 .50997 Mdot
.76757 .51645 Mdot
.77664 .54018 Mdot
.78571 .53343 Mdot
.79478 .54471 Mdot
.80385 .53714 Mdot
.81293 .54053 Mdot
.822 .53525 Mdot
.83107 .55726 Mdot
.84014 .54764 Mdot
.84921 .54985 Mdot
.85828 .5525 Mdot
.86735 .55545 Mdot
.87642 .5605 Mdot
.88549 .57107 Mdot
.89456 .57943 Mdot
.90363 .58033 Mdot
.9127 .58482 Mdot
.92177 .59535 Mdot
.93084 .59345 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[18]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo001eOol4
0005Ool4001:Ool70003Ool40005Ool40016Ool70003Ool40005Ool40016Ool60004Ool40005Ool4
000COol007Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`1:Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0AWoo00<007ooOol00goo00<007oo
Ool00Woo00D007ooOomoo`0000Aoo`03001oogoo04=oo`03001oogoo009oo`05001oogooOol00004
Ool01@00Oomoogoo000017oo00<007ooOol047oo001iOol01@00Oomoogoo000017oo00<007ooOol0
BWoo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo04Ioo`03001o
ogoo00Qoo`05001oogooOol00004Ool00`00Oomoo`14Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00<007ooOol047oo001iOol01@00Oomoogoo000017oo00<007ooOol0BWoo
00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo04Ioo`03001oogoo
00Qoo`05001oogooOol00004Ool00`00Oomoo`15Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00
Oomoogoo000017oo00<007ooOol047oo001iOol01@00Oomoogoo000017oo00<007ooOol0BWoo00<0
07ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo04Ioo`03001oogoo00Qo
o`05001oogooOol00004Ool00`00Oomoo`16Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00<007ooOol047oo001eOol40004Ool00`00Oomoo`02Ool00`00Oomoo`1:Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0AWoo00<007ooOol017oo
100017oo00<007ooOol00Woo00<007ooOol0Agoo00<007ooOol00Woo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`03001oogoo011oo`00MGoo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0
BWoo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo04Ioo`03001o
ogoo00Aoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo04=oo`03001oogoo009oo`05001o
ogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol047oo001eOol00`00Oomoo`05Ool00`00
Oomoo`02Ool00`00Oomoo`18Ool30005Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool0A7oo0`001Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0@goo00<007ooOol00Woo
00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`0@Ool007Eoo`D000Aoo`@004eo
o`03001oogoo00Aoo`@000Eoo`@004Uoo`03001oogoo00Aoo`D000Aoo`@004Moo`@000Eoo`@000Eo
o`@001=oo`00ogoo/Goo003oOonaOol00?mook5oo`0087oo00<007ooOol0ogooSWoo000POol00`00
Oomoo`3oOon>Ool0021oo`03001oogoo0?moohioo`0087oo00<007ooOol0ogooSWoo000POol00`00
Oomoo`3oOon>Ool001moo`9l0?mooi1oo`005Woo200017`0o`00SP000Goo000NOol4O00@Ool00`00
Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00
Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00
Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00
Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00
Oomoo`08Ool001moo`9l0003Ool007oo05Qoo`03001oogoo05Yoo`03001oogoo05Yoo`03001oogoo
05Uoo`03001oogoo01]oo`0087oo00@007ooOol00?mooheoo`0087oo00D007ooOomoo`000?moohao
o`0087oo00<007ooOol00Woo00<007ooOol0ogooRGoo000POol00`00Oomoo`03Ool00`00Oomoo`3o
Oon8Ool0021oo`03001oogoo00Aoo`03001oogoo0?moohMoo`0087oo00<007ooOol01Goo00<007oo
Ool0ogooQWoo000POol00`00Oomoo`03Ool2O0000goo001oo`3oOon6Ool0021oo`8000=oo`Al0003
Ool007oo0?moohEoo`0087oo00D007ooO01l07oo00Al0004Ooml07`0Ool2O006Ool2O03oOomjOol0
021oo`03001l07`0009l0004Ooml07`0Ool7O00017ooO01l07oo17`0ogooNGoo000POol00`00O01l
0002O004Ool?O00017ooO01l07oo0W`0ogooLgoo000POol01000Ooml07`01Woo0W`000Aoog`0O01o
o`Al0004Ooml07`0Ool7O03oOombOol0021oo`03001oogoo00aoo`04001oog`0O005Ool7O03oOomb
Ool0021oo`03001oogoo00eoo`03001oogoo00Ioo`9l0003Ooml07`00?moog=oo`0087oo00<007oo
Ool03Woo00<007ooOol037oo0W`0ogooKgoo000POol00`00Oomoo`0?Ool2000;Ool4O03oOom^Ool0
021oo`03001oogoo015oo`03001oogoo00Qoo`Al0?moofioo`0087oo00<007ooOol04Woo00<007oo
Ool027oo0W`00Woo0W`0ogooJgoo000POol2000DOol00`00Oomoo`0:Ool4O03oOomZOol0021oo`03
001oogoo01Aoo`03001oogoo00Uoo`Al0?moofYoo`0087oo00<007ooOol05Goo0P002Woo0W`000=o
og`0O000ogooJ7oo000POol00`00Oomoo`0GOol00`00Oomoo`09Ool4O0000gooO01l003oOomTOol0
021oo`03001oogoo01Qoo`03001oogoo00Qoo`Ql0?moof=oo`0087oo00<007ooOol06Goo00<007oo
Ool027oo0W`000=oog`0O0000W`0ogooHgoo000POol00`00Oomoo`0JOol00`00Oomoo`0;Ool2O002
Ool2O03oOomPOol0021oo`03001oogoo01]oo`8000ioo`Al0?mooemoo`0087oo00<007ooOol07Goo
00<007ooOol02goo17`0ogooGgoo000POol00`00Oomoo`0NOol00`00Oomoo`0;Ool2O03oOomPOol0
021oo`03001oogoo01moo`03001oogoo0?moofaoo`0087oo0P008Goo0P00ogooK7oo000POol00`00
Oomoo`0ROol00`00Oomoo`0>Ool2O03oOomIOol0021oo`03001oogoo02=oo`03001oogoo00aoo`Al
0003Ooml07`00?mooeEoo`0087oo00<007ooOol097oo00<007ooOol02goo27`0ogooE7oo000POol0
0`00Oomoo`0UOol00`00Oomoo`08Ool2O00017ooO01l07oo17`0ogooE7oo000POol00`00Oomoo`0V
Ool20007Ool4O004Ool2O03oOomEOol0021oo`03001oogoo02Qoo`03001oogoo00Aoo`Al0?mooe]o
o`002Woo1P0017oo100027oo00<007ooOol0:Goo00<007ooOol017oo0W`0ogooG7oo000:Ool00`00
Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol01Goo00<007ooOol0:Woo00<007ooOol0ogoo
HGoo000;Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`0[Ool2003o
OomQOol000aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo02eoo`03
001oogoo0?mooeioo`003Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol01Goo0`00;Woo
00<007ooOol0ogooGGoo000>Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00
Oomoo`0_Ool00`00Oomoo`3oOomLOol000Yoo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`05Ool00`00Oomoo`0`Ool2003oOomLOol000Yoo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`05Ool00`00Oomoo`0bOol00`00Oomoo`3oOomIOol000]oo`@000Eoo`@000Qoo`03
001oogoo03=oo`03001oogoo0?mooeQoo`0087oo00<007ooOol0=7oo00<007ooOol0ogooEgoo000P
Ool00`00Oomoo`0eOol2003oOomGOol0021oo`03001oogoo03Moo`03001oogoo0?mooeAoo`0087oo
00<007ooOol0>7oo00<007ooOol00W`0ogooDGoo000POol00`00Oomoo`0iOol00`00O01l0002O03o
Oom@Ool0021oo`03001oogoo03Yoo`Al0?mooe1oo`0087oo0P00?7oo0W`0ogooDGoo000POol00`00
Oomoo`0mOol00`00Oomoo`3oOom>Ool0021oo`03001oogoo03ioo`03001oogoo0?moodeoo`0087oo
00<007ooOol0?goo0P00ogooCGoo000POol00`00Oomoo`11Ool00`00Oomoo`3oOom:Ool0021oo`03
001oogoo049oo`03001oogoo0?moodUoo`0087oo00<007ooOol0@Woo0W`000<007ooOol0ogooAgoo
000POol00`00Oomoo`11Ool4O0000`00O01l0002Ool2O03oOom2Ool0021oo`03001oogoo045oo`il
009oo`9l0?mooc]oo`0087oo00<007ooOol0@Woo0W`000=oog`0O0003G`0ogoo>Woo000POol00`00
Oomoo`0nOol2O006Ool2O0000goo001l0009O03oOoljOol0021oo`8003ioo`Al00Uoo`03001oogoo
009l009oo`9l0?mooc]oo`0087oo00<007ooOol0?Goo17`02Woo0P00ogoo@Goo000POol00`00Oomo
o`0nOol2O00=Ool00`00Oomoo`3oOolnOol0021oo`03001oogoo04ioo`03001oogoo00Aoo`9l0?mo
ocMoo`0087oo00<007ooOol0Cgoo0P000goo17`0ogoo=Woo000POol00`00Oomoo`1AOol00`00Oomo
o`04O03oOolfOol0021oo`03001oogoo059oo`800003Ooml07`00?moocMoo`0087oo00<007ooOol0
E7oo00<007ooOol0ogoo=goo000POol00`00Oomoo`1EOol00`00Oomoo`3oOolfOol0021oo`03001o
ogoo05Ioo`800?moocIoo`0087oo0P00FGoo00<007ooOol0ogoo<goo000POol00`00Oomoo`1IOol2
003oOolcOol0021oo`03001oogoo05]oo`03001oogoo0?mooc1oo`0087oo00<007ooOol0G7oo0P00
ogoo<7oo000POol00`00Oomoo`1NOol00`00Oomoo`3oOol]Ool0021oo`03001oogoo05moo`800?mo
obeoo`0087oo00<007ooOol0HGoo00<007ooOol0ogoo:Woo000POol00`00Oomoo`1ROol2003oOolZ
Ool000aoo`@000Aoo`@000Qoo`03001oogoo05Qoo`9l00Yoo`03001oogoo0?moobMoo`003Woo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0Egoo17`02Woo0P00ogoo9goo
000>Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`1GOol4O00<Ool2
003oOolUOol000Yoo`H000=oo`03001oogoo009oo`03001oogoo00Eoo`<005Qoo`9l00moo`03001o
ogoo0?moob9oo`002goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo
06Yoo`800?moob9oo`002goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo00Eoo`03001o
ogoo06aoo`03001oogoo0?mooamoo`0037oo00<007oo000017oo00<007ooOol00Woo00<007ooOol0
1Goo00<007ooOol0H7oo0W`02goo0P00ogoo7goo000<Ool00`00Ool00004Ool00`00Oomoo`02Ool0
0`00Oomoo`05Ool00`00Oomoo`1LOol2O0000gooO01l0002O00<Ool00`00Oomoo`3oOolLOol000eo
o`8000Eoo`@000Qoo`03001oogoo05]oo`Yl00]oo`800?mooaaoo`0087oo00<007ooOol0Fgoo17`0
00=oog`0O00017`000=oog`0O0002Goo00<007ooOol0ogoo6Goo000POol00`00Oomoo`1LOol2O004
Ool8O009Ool2003oOolIOol0021oo`03001oogoo06=oo`9l0003Ooml07`0009l00]oo`800?mooaMo
o`0087oo00<007ooOol0Igoo0W`03Woo00<007ooOol0ogoo57oo000POol00`00Oomoo`1hOol2003o
OolDOol0021oo`8007]oo`03001oogoo0?mooa5oo`0087oo00<007ooOol0Ngoo0P00ogoo4Goo000P
Ool00`00Oomoo`1mOol2003oOol?Ool0021oo`03001oogoo07moo`03001oogoo0?moo`aoo`0087oo
00<007ooOol0P7oo0P00ogoo37oo000POol00`00Oomoo`22Ool00`00Oomoo`3oOol9Ool0021oo`03
001oogoo079oo`9l00moo`800?moo`Uoo`0087oo00<007ooOol0Kgoo1W`000=oog`0O0003Goo0P00
ogoo1goo000POol00`00Oomoo`1^Ool;O00017ooO01l07oo0W`027oo00<007ooOol0ogoo17oo000P
Ool00`00Oomoo`1^Ool6O0000gooO01l0009O008Ool2003oOol4Ool0021oo`03001oogoo06]oo`9l
009oo`9l00Eoo`9l0003Ooml07`000El0003Ooml07`000Moo`03001oogoo0?moo`5oo`0087oo0P00
Jgoo17`037oo0W`000Aoog`0O01oo`Al0003Ooml07`000Aoo`800?moo`5oo`0087oo00<007ooOol0
JWoo17`04Woo27`01Goo0P00oWoo000POol00`00Oomoo`1[Ool2O00DOol2O0000gooO01l0002O007
Ool00`00O01l003kOol0021oo`03001oogoo08Eoo`9l009oo`9l0004Ooml07`0Ool4O03jOol0021o
o`03001oogoo08Qoo`]l00Aoo`9l009oo`9l0?1oo`0087oo00<007ooOol0R7oo1g`000Aoog`0O01o
o`800003Ooml07`000Il0>moo`0087oo00<007ooOol0RGoo0W`000=oog`0O0001goo00<007`0O000
1W`0kgoo000POol00`00Oomoo`2DOol2O0000gooO01l0002Ool2O03`Ool0021oo`03001oogoo09=o
o`Al0003Ool00000011oo`9l009oo`9l0003Ooml07`00=Yoo`0087oo00<007ooOol0Tgoo17`00goo
00<007ooOol00Woo0W`01Goo0W`000=oog`0O0002G`0fGoo000POol00`00Oomoo`2DOol2O005Ool2
00000gooO01l0002O003Ool?O03IOol0021oo`8009ioo`03001l07`000Al0003Ooml07`0009l0003
Ooml07`0009oo`9l0003Ooml07`00=Yoo`0087oo00<007ooOol0Wgoo1W`000=oog`0O000iGoo000P
Ool00`00Oomoo`2POol00`00O01l0002O00@Ool2O002Ool2O03BOol0021oo`03001oogoo0:9oo`9l
011oo`Ql00Aoo`9l0<]oo`0087oo00<007ooOol0Y7oo00<007ooOol03Goo2W`000=oog`0O0000W`0
bWoo000POol00`00Oomoo`2UOol2000>Ool2O002Ool:O0000gooO01l0037Ool0021oo`03001oogoo
0:Moo`80019oo`Al0004Ooml07`0Ool4O036Ool000aoo`@000Aoo`@000Qoo`03001oogoo0:Uoo`80
015oo`9l00Eoo`Al0<Ioo`002goo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Eoo`03
001oogoo0:]oo`03001oogoo01Ioo`9l00Eoo`9l0<1oo`002goo00<007ooOol00Woo00@007ooOol0
00Aoo`03001oogoo00Eoo`03001oogoo0:aoo`8001aoo`Al0;moo`002goo0P000goo00@007ooOol0
00Aoo`03001oogoo00Eoo`03001oogoo0:ioo`8001Qoo`Il0;moo`002goo00<007oo00000P000goo
00<007ooOol00Woo00<007ooOol01Goo0`00/7oo00<007ooOol057oo1W`01Woo0W`000=oog`0O000
]Goo000;Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`2aOol2000D
Ool4O004Ool2O0000gooO01l0005O0000gooO01l002aOol000aoo`03001oogoo00Aoo`03001oogoo
009oo`03001oogoo00Eoo`03001oogoo0;=oo`8001=oo`9l00Aoo`ml0;1oo`003Goo00<007ooOol0
0goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0]Goo00<007ooOol05Woo17`000Aoog`0
O01oo`9l0003Ooml07`0009l0;1oo`003Woo0`000goo100027oo00<007ooOol0]Woo0P005goo0W`0
2Goo0W`0/Goo000POol00`00Oomoo`2hOol2003COol0021oo`03001oogoo0;Yoo`03001oogoo0=1o
o`0087oo00<007ooOol0^goo0P008Goo0W`0[Goo000POol00`00Oomoo`2mOol2000NOol4O004Ool2
O002Ool2O02ROol0021oo`03001oogoo0;moo`03001oogoo01]oo`Al00=oo`Ql0:5oo`0087oo00<0
07ooOol0`7oo0P0077oo0W`000Aoog`0O01oo`Ql0:5oo`0087oo0P00`goo0P0077oo17`000=oog`0
O0000Woo0W`0XWoo000POol00`00Oomoo`34Ool2000JOol4O009Ool2O02NOol0021oo`03001oogoo
0<Ioo`03001oogoo01Qoo`9l00Uoo`Al09eoo`0087oo00<007ooOol0agoo0P008goo17`0WGoo000P
Ool00`00Oomoo`39Ool2000ROol2O0000gooO01l002KOol0021oo`03001oogoo0<]oo`80029oo`Al
0003Ooml07`009Moo`0087oo00<007ooOol0cGoo0P0087oo27`0UWoo000POol00`00Oomoo`3?Ool0
0`00Oomoo`0NOol2O0000gooO01l0002O02FOol0021oo`03001oogoo0=1oo`80029oo`9l00Eoo`9l
091oo`0087oo00<007ooOol0dWoo0P0097oo1W`0Sgoo000POol2003EOol2000QOol7O02?Ool0021o
o`03001oogoo0=Ioo`03001oogoo01ioo`Il091oo`0087oo00<007ooOol0egoo0P007goo0W`0Tgoo
000POol00`00Oomoo`3IOol2000TOol2O02<Ool0021oo`03001oogoo0=]oo`80025oo`Al08]oo`00
87oo00<007ooOol0gGoo0P007goo17`0Rgoo000POol00`00Oomoo`3OOol00`00Oomoo`0MOol2O02<
Ool0021oo`03001oogoo0>1oo`800:]oo`0087oo00<007ooOol0hWoo0P00ZGoo000POol00`00Oomo
o`3TOol2002WOol0021oo`03001oogoo0>Ioo`800:Eoo`0087oo0P00jGoo0P00Xgoo000POol00`00
Oomoo`3ZOol2002QOol0021oo`03001oogoo0>aoo`8009moo`0087oo00<007ooOol0kWoo0P00WGoo
000POol00`00Oomoo`3`Ool00`00Oomoo`2JOol0021oo`03001oogoo0?5oo`8009Yoo`0087oo00<0
07ooOol0lgoo0P00V7oo000POol00`00Oomoo`3eOol2002FOol000]oo`@000Eoo`@000Qoo`03001o
ogoo0?Moo`03001oogoo09=oo`002Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo
00Eoo`03001oogoo0?Qoo`8009=oo`002Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001o
ogoo00Eoo`03001oogoo0?Yoo`8000]oo`9l00Eoo`9l009oo`9l07Uoo`002Woo00<007ooOol00Woo
00D007ooOomoo`0000Aoo`03001oogoo00Eoo`<00?aoo`8000Qoo`Al00=oo`Ql00Aoo`9l079oo`00
2goo100017oo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0oWoo0P001Woo1W`000=oog`0
O0001W`00goo17`0LGoo000:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol01Goo
00<007ooOol0ogoo0Goo00<007ooOol00W`00Woo1W`000=oog`0O0000Woo0W`000Aoog`0O01oo`Al
075oo`002Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Eoo`03001oogoo0?mo
o`9oo`03001l07`0009l00=oo`Al00Moo`Al0003Ooml07`0079oo`002Woo00<007ooOol00Woo00D0
07ooOomoo`0000Aoo`03001oogoo00Eoo`03001oogoo0?moo`=oo`Al00Aoo`9l00Qoo`Al07Eoo`00
2goo10001Goo100027oo00<007ooOol0ogoo17oo0W`00P003Woo0W`0MWoo000POol00`00Oomoo`3o
Ool8Ool20024Ool0021oo`03001oogoo0?moo`Yoo`80089oo`0087oo00<007ooOol0ogoo37oo0P00
P7oo000POol00`00Oomoo`3oOol>Ool2001nOol0021oo`03001oogoo0?mooa1oo`<007]oo`0087oo
0P00ogoo57oo0P00NGoo000POol00`00Oomoo`3oOolEOol2001gOol0021oo`03001oogoo0?mooaMo
o`8007Eoo`0087oo00<007ooOol0ogoo6Goo0P00Lgoo000POol00`00Oomoo`3oOolKOol2001aOol0
021oo`03001oogoo0?mooaeoo`8006moo`0087oo00<007ooOol0ogoo7goo0P00KGoo000POol00`00
Oomoo`3oOolQOol2001[Ool0021oo`03001oogoo0?moob=oo`8006Uoo`0087oo00<007ooOol0ogoo
9Goo0P00Igoo000POol00`00Oomoo`3oOolWOol2001UOol0021oo`800?moobYoo`03001oogoo069o
o`0087oo00<007ooOol0ogoo:Woo0P00HWoo000POol00`00Oomoo`3oOol/Ool2001POol0021oo`03
001oogoo0?moob5oo`9l00]oo`8005ioo`0087oo00<007ooOol0ogoo87oo17`037oo0P00G7oo000P
Ool00`00Oomoo`3oOolPOol4O0000gooO01l000;Ool2001JOol0021oo`03001oogoo0?moob5oo`9l
0003Ooml07`0009l0003Ooml07`000Uoo`8005Qoo`0087oo00<007ooOol0ogoo7Woo0W`017oo27`0
2Woo0P00EWoo000POol00`00Oomoo`3oOolMOol4O004Ool2O0000gooO01l0002O00<Ool2001DOol0
021oo`03001oogoo0?mooaeoo`Al00Qoo`9l009oo`9l00]oo`80059oo`0087oo00<007ooOol0ogoo
7Woo0W`037oo17`037oo0P00D7oo000POol2003oOol]Ool4O00>Ool2001>Ool0021oo`03001oogoo
0?moobeoo`9l015oo`8004aoo`0087oo00<007ooOol0ogoo@Woo0P00BWoo000POol00`00Oomoo`3o
Oom4Ool20018Ool0021oo`03001oogoo0?moocAoo`9l011oo`8004Ioo`0087oo00<007ooOol0ogoo
<goo17`037oo0W`00goo0P00A7oo000POol00`00Oomoo`3oOolcOol4O004Ool2O005Ool4O004Ool0
0`00Oomoo`11Ool00003Ool0000000D000=oo`@000Eoo`@000Qoo`03001oogoo0?mooc1oo`9l009o
o`9l00Aoo`Al0004Ooml07`0Ool4O005Ool20011Ool000Aoo`03001oogoo00=oo`03001oogoo009o
o`05001oogooOol00004Ool00`00Oomoo`05Ool00`00Oomoo`3oOol_Ool4O007Ool8O0000gooO01l
0008Ool2000oOol000Aoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`05Ool00`00Oomoo`3oOol_Ool4O005Ool2O00017ooO01l07oo17`03Goo0P00?Goo0004Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol01Goo0`00ogoo<7oo
0W`01Goo17`017oo0W`02Goo0W`01Goo0P00>goo0004Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00<007ooOol01Goo00<007ooOol0ogoo=goo17`03Woo17`000=oog`0O000
0goo0P00>Goo0004Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool01Goo00<007ooOol0ogoo>7oo0W`03goo27`000Aoog`0O01oo`8003Moo`0017oo00<007ooOol0
0goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Eoo`03001oogoo0?moodYoo`9l
0003Ooml07`000Ql008003Eoo`000Woo0`001Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03
001oogoo00Eoo`03001oogoo0?moodMoo`9l00Eoo`9l0003Ooml07`000El0003Ool0000003=oo`00
17oo00<007ooOol017oo10001Goo100027oo00<007ooOol0ogooAWoo17`027oo1W`00goo0`00<7oo
000POol00`00Oomoo`3oOom6Ool4O00;Ool2O002Ool2O003Ool2000^Ool0021oo`03001oogoo0?mo
odMoo`9l00moo`Al00Aoo`8002aoo`0087oo00<007ooOol0ogooF7oo17`01Woo0P00:Woo000POol0
0`00Oomoo`3oOomIOol2O009Ool2000XOol0021oo`03001oogoo0?mooeeoo`9l00Moo`8002Ioo`00
87oo0P00ogooGGoo17`027oo0P0097oo000POol00`00Oomoo`3oOomLOol4O00:Ool00`00Oomoo`0Q
Ool0021oo`03001oogoo0?mooeeoo`9l0003Ooml07`000Uoo`80025oo`0087oo00<007ooOol0ogoo
Ggoo17`000=oog`0O0001goo0P007goo000POol00`00Oomoo`3oOomOOol8O0000gooO01l0005Ool2
000MOol0021oo`03001oogoo0?moof1oo`9l0003Ooml07`000Il00Ioo`8001]oo`0087oo00<007oo
Ool0ogooI7oo0W`000=oog`0O0000W`027oo0P006Goo000POol00`00Oomoo`3oOomXOol2O00;Ool2
000GOol0021oo`03001oogoo0?moofmoo`9l00Ioo`8001Eoo`0087oo00<007ooOol0ogooK7oo1W`0
1goo0P004goo000POol00`00Oomoo`3oOom[Ool7O009Ool3000@Ool0021oo`800?moofaoo`Il00eo
o`8000ioo`0087oo00<007ooOol0ogooK7oo0W`04Woo0P0037oo000POol00`00Oomoo`3oOon2Ool2
000:Ool0021oo`03001oogoo0?moohioo`0087oo00<007ooOol0ogooSWoo000POol00`00Oomoo`3o
Oon>Ool0021oo`03001oogoo0?moohioo`0087oo00<007ooOol0ogooSWoo000POol00`00Oomoo`3o
Oon>Ool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-17.3271, -8.7545, 0.809436, \
0.691951}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[dailyintakes1, qLungs5S, dailyretencion1, randomInput1, 
      qLungsChronic1]\)], "Input",
  CellLabel->"In[19]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 3", "SubsubsectionIcon"],

Cell["\<\
Now it is simulated that the AMAD changes each day following a normal random \
distribution with mean 6 and sigma = 1.5.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(randomAMAD\  = \ 
      Table[Random[NormalDistribution[6, 1.5]], {i, 0, 200, 2}]\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({7.179238991199491`, 5.452099073743883`, 4.081973934185835`, 
      7.70074578173131`, 3.7742886784539222`, 6.946346655951315`, 
      4.8874793842581195`, 9.714490336682053`, 8.181700850921835`, 
      6.605605517142314`, 7.43360731068487`, 9.307894935164729`, 
      6.974439041770869`, 6.209674031232044`, 4.82078649003408`, 
      5.977406948825825`, 6.8446098808922`, 6.920165686509253`, 
      6.507374846314573`, 6.990112976667087`, 5.578482894074141`, 
      8.391763850469836`, 3.879464910869312`, 8.86265778333382`, 
      4.326794269289782`, 6.6022334444421436`, 6.482467158483776`, 
      5.5607727981135096`, 5.932531606200776`, 3.9706601427358206`, 
      6.669682464821362`, 5.729718955795178`, 6.578687802293505`, 
      4.859107222092096`, 5.628268143476196`, 4.600448036841845`, 
      7.634322277629027`, 5.680466403530272`, 6.958878450354913`, 
      10.195187359760567`, 5.215994069959783`, 5.0773809812779325`, 
      5.582723159244103`, 4.495760195361273`, 5.71269673277113`, 
      7.398003151408563`, 5.40863765007807`, 4.456395764284373`, 
      4.065710994453594`, 7.907138548071028`, 5.563103990740522`, 
      8.037360065906512`, 9.20947968321044`, 4.642821664925026`, 
      3.052935965571185`, 7.220209972307469`, 6.990663765900843`, 
      6.409762328927824`, 4.418607654826667`, 4.36967041740645`, 
      8.876095622607023`, 3.247178770397631`, 3.932549224456192`, 
      5.154644850147884`, 4.061729768122785`, 8.746816192398178`, 
      7.975716827898433`, 6.842500985883965`, 7.452874121153971`, 
      5.6557687343219785`, 2.511760083925404`, 7.174927398733873`, 
      5.336419130644611`, 5.255880051902444`, 7.022901537515988`, 
      4.994047437464138`, 5.966860885793619`, 3.8715066316481157`, 
      7.513184588818824`, 3.997722138049344`, 6.627228508051659`, 
      6.338517105677594`, 5.252632086969052`, 4.654569953258378`, 
      6.460203859700078`, 7.37271440765456`, 6.586536583143352`, 
      3.8559224745686547`, 7.183583641213442`, 6.299877926288892`, 
      8.013714937639968`, 5.917863614148939`, 6.899447721452189`, 
      8.797006869023171`, 6.363380176424341`, 5.286285430092784`, 
      7.257302790260888`, 3.2379126841312593`, 7.985891663501548`, 
      6.529662201929202`, 7.5228101636658495`}\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["\<\
Now we wish to evaluate the lung retention. The first step it is to build a \
function to obtain the lung retention as function of intake \"int\" and AMAD \
\"p\" for type S\
\>", "MathCaption"],

Cell[BoxData[
    \(\(lung[{ai_, bbf_, \ bbs_, \ BBf_, \ BBs_, \ et2_, \ et1_}, \ t_\ ] = 
        LungsRetention[1, {ai, bbf, \ bbs, \ BBf, \ BBs, \ et2, \ et1}\ , 
          S, \ t, 0];\)\)], "Input",
  CellLabel->"In[21]:="],

Cell["modelAMAD[inp_, p_, t1_]:= inp lung[AMADfit[p] ,t1]  ", "Input",
  CellLabel->"In[22]:="],

Cell[TextData[{
  "Now it is obtained the thoracic lung retention for \"days\" and \
\"randomAMAD\" ",
  StyleBox[". ListConvolve", "Input"],
  " can be applied again to compute the accumulated lung retention.. \
(Previously it is shown how works this function)"
}], "MathCaption"],

Cell["\<\
tt = {t1, t2, t3}; 
ret = {f[I0, amad0, t], f[I1, amad1, t], f[I2, amad2, t]}; \
\>", "Input",
  CellLabel->"In[23]:="],

Cell[CellGroupData[{

Cell["\<\
ListConvolve[tt, ret, {1, 1}, 0, #2 /. t -> #1 & ]//TableForm\
\>", "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(f[I0, amad0, t1]\)},
          {\(f[I0, amad0, t2] + f[I1, amad1, t1]\)},
          {\(f[I0, amad0, t3] + f[I1, amad1, t2] + f[I2, amad2, t1]\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        f[ I0, amad0, t1], 
        Plus[ 
          f[ I0, amad0, t2], 
          f[ I1, amad1, t1]], 
        Plus[ 
          f[ I0, amad0, t3], 
          f[ I1, amad1, t2], 
          f[ I2, amad2, t1]]}]]], "Output",
  CellLabel->"Out[25]//TableForm="]
}, Open  ]],

Cell[BoxData[
    \(Clear[tt, \ ret]\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \(\(retlung\  = \ modelAMAD[intakes, randomAMAD, t];\)\)], "Input",
  CellLabel->"In[27]:="],

Cell["\<\
randomInput2= Transpose[{days, ListConvolve[days, retlung, {1, 1}, 0, #2 /. t \
-> #1 & ]}];\
\>", "Input",
  CellLabel->"In[28]:="],

Cell["Now it is compute the average of the intakes and AMADs", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({meanintake, 
        meanamad} = {Plus @@ intakes\/Max[days]\ , \(\(Plus @@ randomAMAD\)\(\
\ \)\)\/Length[randomAMAD\ ]}\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \({13.44172272739245`, 6.1574439986563005`}\)], "Output",
  CellLabel->"Out[29]="]
}, Open  ]],

Cell["\<\
Now it is computed the lung retention supposing that each day is intaken the \
daily mean (intakes and AMAD) of the period. \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(qLungsChronic2[t1_] = 
      qContinuous[meanintake, \ {modelAMAD[1, meanamad\ , \ t]}, \ t, \ 
        t1]\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \({\(\(696.8487345413566`\)\(\[InvisibleSpace]\)\) - 
        1.2109705921521298`*^-6\ \[ExponentialE]\^\(\(-110.1`\)\ t1\) - 
        9.273287049115297`*^-7\ \[ExponentialE]\^\(\(-102.1`\)\ t1\) - 
        1.192085166278261`*^-6\ \[ExponentialE]\^\(\(-100.13`\)\ t1\) - 
        1.8296357551813667`*^-6\ \[ExponentialE]\^\(\(-100.11999999999999`\)\ \
t1\) - 3.6182904702865687`*^-6\ \[ExponentialE]\^\(\(-100.101`\)\ t1\) - 
        5.022794230546768`*^-7\ \[ExponentialE]\^\(\(-100.10012`\)\ t1\) - 
        1.2508183752232062`*^-7\ \[ExponentialE]\^\(\(-100.1`\)\ t1\) - 
        0.013345998891959707`\ \[ExponentialE]\^\(\(-10.0001`\)\ t1\) - 
        0.04738514864620436`\ \[ExponentialE]\^\(\(-2.0001`\)\ t1\) - 
        3.9695339093066213`\ \[ExponentialE]\^\(\(-0.0301`\)\ t1\) - 
        9.122711358561174`\ \[ExponentialE]\^\(\(-0.0201`\)\ t1\) - 
        329.59731947065416`\ \[ExponentialE]\^\(\(-0.0011`\)\ t1\) - 
        228.76617763816`\ \[ExponentialE]\^\(\(-0.00022`\)\ t1\) - 
        125.33225161146454`\ \[ExponentialE]\^\(\(-0.0001`\)\ t1\)}\)], \
"Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell["\<\
Here are compared the lung retention for random intakes and for chronic \
intakes. \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[qLungsChronic2[t], {t, 0, 210}, \ 
      Epilog \[Rule] \ {Hue[0], \ PointSize[0.012], 
          Map[Point, randomInput2]}]\)], "Input",
  CellLabel->"In[31]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00453515 0.0147151 0.00626655 [
[.25057 .00222 -6 -9 ]
[.25057 .00222 6 0 ]
[.47732 .00222 -9 -9 ]
[.47732 .00222 9 0 ]
[.70408 .00222 -9 -9 ]
[.70408 .00222 9 0 ]
[.93084 .00222 -9 -9 ]
[.93084 .00222 9 0 ]
[.01131 .14005 -12 -4.5 ]
[.01131 .14005 0 4.5 ]
[.01131 .26538 -12 -4.5 ]
[.01131 .26538 0 4.5 ]
[.01131 .39071 -12 -4.5 ]
[.01131 .39071 0 4.5 ]
[.01131 .51604 -12 -4.5 ]
[.01131 .51604 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25057 .01472 m
.25057 .02097 L
s
[(50)] .25057 .00222 0 1 Mshowa
.47732 .01472 m
.47732 .02097 L
s
[(100)] .47732 .00222 0 1 Mshowa
.70408 .01472 m
.70408 .02097 L
s
[(150)] .70408 .00222 0 1 Mshowa
.93084 .01472 m
.93084 .02097 L
s
[(200)] .93084 .00222 0 1 Mshowa
.125 Mabswid
.06916 .01472 m
.06916 .01847 L
s
.11451 .01472 m
.11451 .01847 L
s
.15986 .01472 m
.15986 .01847 L
s
.20522 .01472 m
.20522 .01847 L
s
.29592 .01472 m
.29592 .01847 L
s
.34127 .01472 m
.34127 .01847 L
s
.38662 .01472 m
.38662 .01847 L
s
.43197 .01472 m
.43197 .01847 L
s
.52268 .01472 m
.52268 .01847 L
s
.56803 .01472 m
.56803 .01847 L
s
.61338 .01472 m
.61338 .01847 L
s
.65873 .01472 m
.65873 .01847 L
s
.74943 .01472 m
.74943 .01847 L
s
.79478 .01472 m
.79478 .01847 L
s
.84014 .01472 m
.84014 .01847 L
s
.88549 .01472 m
.88549 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .14005 m
.03006 .14005 L
s
[(20)] .01131 .14005 1 0 Mshowa
.02381 .26538 m
.03006 .26538 L
s
[(40)] .01131 .26538 1 0 Mshowa
.02381 .39071 m
.03006 .39071 L
s
[(60)] .01131 .39071 1 0 Mshowa
.02381 .51604 m
.03006 .51604 L
s
[(80)] .01131 .51604 1 0 Mshowa
.125 Mabswid
.02381 .04605 m
.02756 .04605 L
s
.02381 .07738 m
.02756 .07738 L
s
.02381 .10871 m
.02756 .10871 L
s
.02381 .17138 m
.02756 .17138 L
s
.02381 .20271 m
.02756 .20271 L
s
.02381 .23404 m
.02756 .23404 L
s
.02381 .29671 m
.02756 .29671 L
s
.02381 .32804 m
.02756 .32804 L
s
.02381 .35938 m
.02756 .35938 L
s
.02381 .42204 m
.02756 .42204 L
s
.02381 .45337 m
.02756 .45337 L
s
.02381 .48471 m
.02756 .48471 L
s
.02381 .54737 m
.02756 .54737 L
s
.02381 .5787 m
.02756 .5787 L
s
.02381 .61004 m
.02756 .61004 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .05234 L
.10458 .08969 L
.14415 .12225 L
.18221 .15167 L
.22272 .1813 L
.26171 .20846 L
.30316 .23609 L
.34309 .26172 L
.3815 .28558 L
.42237 .31024 L
.46172 .33338 L
.49955 .35514 L
.53984 .37784 L
.57861 .39929 L
.61984 .42171 L
.65954 .44297 L
.69774 .46313 L
.73838 .48431 L
.77751 .50444 L
.81909 .52558 L
.85916 .54571 L
.89771 .56488 L
.93871 .58506 L
.97619 .60332 L
s
1 0 0 r
.012 w
.02381 .01651 Mdot
.03288 .04781 Mdot
.04195 .0442 Mdot
.05102 .04737 Mdot
.06009 .04867 Mdot
.06916 .0494 Mdot
.07823 .04946 Mdot
.0873 .05149 Mdot
.09637 .05156 Mdot
.10544 .06089 Mdot
.11451 .06629 Mdot
.12358 .06956 Mdot
.13265 .07345 Mdot
.14172 .0805 Mdot
.15079 .10642 Mdot
.15986 .09996 Mdot
.16893 .10153 Mdot
.178 .13888 Mdot
.18707 .17037 Mdot
.19615 .15911 Mdot
.20522 .1629 Mdot
.21429 .16067 Mdot
.22336 .1662 Mdot
.23243 .16506 Mdot
.2415 .18534 Mdot
.25057 .22037 Mdot
.25964 .23582 Mdot
.26871 .23295 Mdot
.27778 .23961 Mdot
.28685 .24382 Mdot
.29592 .279 Mdot
.30499 .2721 Mdot
.31406 .26943 Mdot
.32313 .2726 Mdot
.3322 .27597 Mdot
.34127 .27711 Mdot
.35034 .27891 Mdot
.35941 .28318 Mdot
.36848 .28883 Mdot
.37755 .28559 Mdot
.38662 .28413 Mdot
.39569 .29908 Mdot
.40476 .29308 Mdot
.41383 .29373 Mdot
.4229 .30692 Mdot
.43197 .30891 Mdot
.44104 .30472 Mdot
.45011 .30323 Mdot
.45918 .3022 Mdot
.46825 .30237 Mdot
.47732 .31617 Mdot
.48639 .31396 Mdot
.49546 .31556 Mdot
.50454 .3158 Mdot
.51361 .32513 Mdot
.52268 .33441 Mdot
.53175 .32915 Mdot
.54082 .33956 Mdot
.54989 .33645 Mdot
.55896 .33674 Mdot
.56803 .33771 Mdot
.5771 .36392 Mdot
.58617 .37638 Mdot
.59524 .37053 Mdot
.60431 .37041 Mdot
.61338 .37654 Mdot
.62245 .38106 Mdot
.63152 .38252 Mdot
.64059 .38879 Mdot
.64966 .38742 Mdot
.65873 .41178 Mdot
.6678 .45591 Mdot
.67687 .45002 Mdot
.68594 .45656 Mdot
.69501 .45092 Mdot
.70408 .45079 Mdot
.71315 .45722 Mdot
.72222 .45471 Mdot
.73129 .51338 Mdot
.74036 .50658 Mdot
.74943 .51032 Mdot
.7585 .51339 Mdot
.76757 .52187 Mdot
.77664 .55336 Mdot
.78571 .54502 Mdot
.79478 .55369 Mdot
.80385 .54579 Mdot
.81293 .55264 Mdot
.822 .5466 Mdot
.83107 .56861 Mdot
.84014 .55792 Mdot
.84921 .56045 Mdot
.85828 .5621 Mdot
.86735 .56203 Mdot
.87642 .5671 Mdot
.88549 .58017 Mdot
.89456 .58581 Mdot
.90363 .59157 Mdot
.9127 .59317 Mdot
.92177 .60316 Mdot
.93084 .59979 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[31]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo001`Ool4
0005Ool4001;Ool70003Ool40005Ool40016Ool70003Ool40005Ool40016Ool60004Ool40005Ool4
000GOol006moo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`1;Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0AWoo00<007ooOol00goo00<007oo
Ool00Woo00D007ooOomoo`0000Aoo`03001oogoo04=oo`03001oogoo009oo`05001oogooOol00004
Ool01@00Oomoogoo000017oo00<007ooOol057oo001dOol01@00Oomoogoo000017oo00<007ooOol0
Bgoo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo04Ioo`03001o
ogoo00Qoo`05001oogooOol00004Ool00`00Oomoo`14Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00<007ooOol057oo001dOol01@00Oomoogoo000017oo00<007ooOol0Bgoo
00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo04Ioo`03001oogoo
00Qoo`05001oogooOol00004Ool00`00Oomoo`15Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00
Oomoogoo000017oo00<007ooOol057oo001dOol01@00Oomoogoo000017oo00<007ooOol0Bgoo00<0
07ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo04Ioo`03001oogoo00Qo
o`05001oogooOol00004Ool00`00Oomoo`16Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00<007ooOol057oo001`Ool40004Ool00`00Oomoo`02Ool00`00Oomoo`1;Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0AWoo00<007ooOol017oo
100017oo00<007ooOol00Woo00<007ooOol0Agoo00<007ooOol00Woo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`03001oogoo01Aoo`00L7oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0
Bgoo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo04Ioo`03001o
ogoo00Aoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo04=oo`03001oogoo009oo`05001o
ogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol057oo001`Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool00`00Oomoo`19Ool30005Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool0A7oo0`001Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0@goo00<007ooOol00Woo
00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`0DOol0071oo`D000Aoo`@004io
o`03001oogoo00Aoo`@000Eoo`@004Uoo`03001oogoo00Aoo`D000Aoo`@004Moo`@000Eoo`@000Eo
o`@001Moo`00ogoo/Goo003oOonaOol001]oo`03001oogoo0?mooi=oo`006goo00<007ooOol0ogoo
Tgoo000KOol00`00Oomoo`3oOonCOol001]oo`03001oogoo0?mooi=oo`006goo00<007ooOol0ogoo
Tgoo000KOol00`00Oomoo`3oOonCOol0015oo`T0009l0?l0094000Aoo`006Goo17`047oo00<007oo
Ool047oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol047oo00<007oo
Ool047oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol047oo00<007oo
Ool047oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol047oo00<007oo
Ool03goo00<007ooOol047oo00<007ooOol047oo00<007ooOol03goo00<007ooOol047oo00<007oo
Ool037oo000IOol4O0000`00Oomoo`0=Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0@
Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0@
Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0@
Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0@
Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0<Ool001Yoo`9l009oo`03001oogoo05Io
o`03001oogoo05Yoo`03001oogoo05Yoo`03001oogoo05Yoo`03001oogoo01moo`006goo00D007oo
Oomoo`000?mooi5oo`006goo00<007ooOol00Woo00<007ooOol0ogooSWoo000KOol00`00Oomoo`03
Ool00`00Oomoo`3oOon=Ool001]oo`03001oogoo00Aoo`03001oogoo0?moohaoo`006goo00<007oo
Ool017oo00<007ooOol0ogooS7oo000KOol00`00Oomoo`05Ool00`00Oomoo`3oOon;Ool001]oo`03
001oogoo00Ioo`03001oogoo0?moohYoo`006goo00<007ooOol00goo0W`00Woo00<007ooOol0ogoo
RGoo000KOol00`00Oomoo`02Ool4O002Ool00`00Oomoo`3oOon8Ool001]oo`80009l0003Ooml07`0
009l0004Ooml07`00002O002Ool2O002Ool2O03oOomoOol001]oo`03001l07`0009l0004Ooml07`0
Ool?O00017ooO01l07oo0W`0ogooN7oo000KOol00`00O01l0002O004OolFO03oOomgOol001]oo`04
001oog`0O006Ool2O0001GooO01l0000Ool00W`00Woo0W`000=oog`0O0001G`0ogooMgoo000KOol0
0`00Oomoo`0=Ool00`00Oomoo`06Ool2O0000gooO01l003oOomhOol001]oo`03001oogoo00ioo`03
001oogoo00aoo`9l0?moogAoo`006goo00<007ooOol03goo0P002goo17`0ogooLgoo000KOol00`00
Oomoo`0AOol00`00Oomoo`08Ool4O0000gooO01l003oOom`Ool001]oo`03001oogoo019oo`03001o
ogoo00Qoo`9l0003Ooml07`0009l0?moofmoo`006goo00<007ooOol04goo00<007ooOol02Woo1W`0
ogooKGoo000KOol00`00Oomoo`0DOol00`00Oomoo`0:Ool6O0000gooO01l003oOomYOol001]oo`03
001oogoo01Eoo`8000aoo`Ql0?moofQoo`006goo00<007ooOol05goo00<007ooOol02Woo0W`000=o
og`0O0000W`0ogooJ7oo000KOol2000IOol00`00Oomoo`0=Ool2O002Ool2O03oOomUOol001]oo`03
001oogoo01Uoo`03001oogoo00moo`Al0?moofAoo`006goo00<007ooOol06Woo00<007ooOol03Woo
17`0ogooI7oo000KOol00`00Oomoo`0KOol2000?Ool2O03oOomUOol001]oo`03001oogoo01eoo`03
001oogoo0?moog=oo`006goo00<007ooOol07Woo00<007ooOol0ogooLWoo000KOol00`00Oomoo`0O
Ool00`00Oomoo`3oOomaOol001]oo`03001oogoo021oo`800?moog5oo`006goo00<007ooOol08Woo
00<007ooOol03Woo0W`0ogooGWoo000KOol00`00Oomoo`0SOol00`00Oomoo`0<Ool4O0000gooO01l
003oOomJOol001]oo`03001oogoo02Aoo`03001oogoo00]oo`Ql0?mooeUoo`006goo00<007ooOol0
9Goo00<007ooOol027oo0W`000Aoog`0O01oo`Al0?mooeUoo`006goo00<007ooOol09Woo0P001goo
17`017oo0W`0ogooFWoo000KOol2000YOol00`00Oomoo`04Ool4O03oOomPOol001]oo`03001oogoo
02Uoo`03001oogoo00Aoo`9l0?moof5oo`006goo00<007ooOol0:Woo00<007ooOol0ogooIWoo000K
Ool00`00Oomoo`0[Ool2003oOomVOol001]oo`03001oogoo02eoo`03001oogoo0?moof=oo`006goo
00<007ooOol0;Woo00<007ooOol0ogooHWoo000KOol00`00Oomoo`0_Ool00`00Oomoo`3oOomQOol0
01]oo`03001oogoo031oo`800?moof5oo`006goo00<007ooOol0<Woo00<007ooOol0ogooGWoo0004
Ool60004Ool40009Ool00`00Oomoo`0cOol00`00Oomoo`3oOomMOol000Aoo`03001oogoo009oo`05
001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`0dOol00`00Oomoo`3oOomLOol000Eoo`03
001oogoo00Eoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo03Eoo`8000Aoo`9l0?mooeIo
o`001Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0=goo00<007oo
Ool017`0ogooEGoo0007Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`06Ool3000hOol0
0`00Ooml0003O03oOomEOol000Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Ioo`03
001oogoo03Uoo`04001oog`0O03oOomFOol000Aoo`03001oogoo009oo`05001oogooOol00004Ool0
0`00Oomoo`06Ool00`00Oomoo`0jOol2003oOomGOol000Aoo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`06Ool00`00Oomoo`0lOol00`00Oomoo`3oOomDOol000Eoo`@000Eoo`@000Uo
o`03001oogoo03eoo`03001oogoo0?mooe=oo`006goo00<007ooOol0?Woo00<007ooOol0ogooDWoo
000KOol00`00Oomoo`0oOol200000gooO01l003oOom?Ool001]oo`03001oogoo045oo`Al00Eoo`9l
0?moodMoo`006goo00<007ooOol0@Goo17`000Aoog`0O01oo`Al0?moodIoo`006goo00<007ooOol0
@Woo0W`000<007`0O00027`00Woo0W`0ogoo@7oo000KOol00`00Oomoo`15Ool4O0000gooO01l0008
O03oOoloOol001]oo`03001oogoo03moo`9l00Eoo`9l00Aoo`Ql0?moocmoo`006goo0P00?goo17`0
1Goo0P0017oo0W`00Woo0W`0ogoo@7oo000KOol00`00Oomoo`0nOol4O007Ool00`00Oomoo`3oOom7
Ool001]oo`03001oogoo03moo`9l00Uoo`03001oogoo0?moodIoo`006goo00<007ooOol0Bgoo0P00
ogooAWoo000KOol00`00Oomoo`1=Ool00`00Oomoo`3oOom3Ool001]oo`03001oogoo04ioo`03001o
ogoo00Aoo`9l0?moocaoo`006goo00<007ooOol0Cgoo0P000goo17`0ogoo>goo000KOol00`00Oomo
o`1AOol00`00Oomoo`04O03oOolkOol001]oo`03001oogoo059oo`800003Ooml07`00?moocaoo`00
6goo00<007ooOol0E7oo00<007ooOol0ogoo?7oo000KOol00`00Oomoo`1EOol00`00Oomoo`3oOolk
Ool001]oo`03001oogoo05Ioo`800?mooc]oo`006goo00<007ooOol0F7oo00<007ooOol0ogoo>7oo
000KOol2001JOol2003oOolhOol001]oo`03001oogoo05]oo`03001oogoo0?moocEoo`006goo00<0
07ooOol0G7oo0P00ogoo=Goo000KOol00`00Oomoo`1NOol00`00Oomoo`3oOolbOol001]oo`03001o
ogoo05moo`800?mooc9oo`006goo00<007ooOol0HGoo00<007ooOol0ogoo;goo000KOol00`00Oomo
o`1IOol2O007Ool2003oOol_Ool001]oo`03001oogoo05Qoo`Al00Qoo`03001oogoo0?moobaoo`00
6goo00<007ooOol0F7oo17`02Goo0P00ogoo;7oo000KOol00`00Oomoo`1IOol2O00<Ool2003oOolZ
Ool001]oo`03001oogoo06Uoo`03001oogoo0?moobMoo`006goo00<007ooOol0JWoo0P00ogoo9goo
000KOol00`00Oomoo`1POol2O00:Ool00`00Oomoo`3oOolTOol001]oo`8005eoo`9l0003Ooml07`0
009l00Yoo`800?moobAoo`006goo00<007ooOol0Fgoo27`000=oog`0O0002Goo00<007ooOol0ogoo
8Goo000KOol00`00Oomoo`1KOol4O00017ooO01l07oo17`02Goo0P00ogoo8Goo000KOol00`00Oomo
o`1LOol2O005Ool6O009Ool00`00Oomoo`3oOolNOol001]oo`03001oogoo06Aoo`Il00Uoo`800?mo
oaioo`006goo00<007ooOol0IWoo17`02goo0P00ogoo77oo000KOol00`00Oomoo`1WOol2O00>Ool0
0`00Oomoo`3oOolIOol001]oo`03001oogoo07Qoo`800?mooaUoo`006goo00<007ooOol0NWoo00<0
07ooOol0ogoo5Woo0006Ool40004Ool40009Ool00`00Oomoo`1kOol2003oOolFOol000Qoo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo07eoo`800?mooaAoo`0027oo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0Ogoo00<007ooOol0ogoo4Goo
0004Ool60003Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`20Ool2003oOolAOol000Eo
o`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`06Ool30022Ool00`00Oomoo`3oOol>Ool0
00Eoo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`1cOol2O00>Ool2
003oOol>Ool000Ioo`03001oo`0000Aoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo06mo
o`9l0003Ooml07`000Al00eoo`800?moo`aoo`001Woo00<007oo000017oo00<007ooOol00Woo00<0
07ooOol01Woo00<007ooOol0KWoo2g`000=oog`0O0002goo00<007ooOol0ogoo2Goo0007Ool20005
Ool40009Ool00`00Oomoo`1[Ool2O0000gooO01l0002O0000gooO01l0008O00017ooO01l07oo0W`0
1Goo0P00ogoo2Goo000KOol00`00Oomoo`1ZOol4O0000gooO01l0005Ool2O0000gooO01l0009O006
Ool00`00Oomoo`3oOol6Ool001]oo`03001oogoo06Yoo`Al00aoo`9l0003Ooml07`000El0003Ooml
07`000Aoo`800?moo`Ioo`006goo00<007ooOol0Jgoo0W`04Goo0W`000Aoog`0O01oo`Al00Eoo`9l
0003Ooml07`00?moo`5oo`006goo00<007ooOol0Q7oo17`017oo1g`0ogoo000KOol00`00Oomoo`25
Ool2O002Ool2O0000gooO01l0005O03oOol001]oo`03001oogoo08Qoo`Al0004Ooml07`0Ool2O002
0004Ool2O03hOol001]oo`03001oogoo08Qoo`Al00Qoo`03001oogoo00Il0?Eoo`006goo00<007oo
Ool0RGoo0W`02Woo0P001g`0m7oo000KOol2002EOol2O0000goo001l0005O03dOol001]oo`03001o
ogoo09=oo`Al009oo`80009l00eoo`9l009oo`9l009oo`9l0=ioo`006goo00<007ooOol0Tgoo17`0
17oo00<007ooOol02Goo3W`0gGoo000KOol00`00Oomoo`2DOol2O006Ool200000gooO01l0005Ool?
O03MOol001]oo`03001oogoo09ioo`Al0004Ooml07`0Ool6O002Ool2O002Ool2O03NOol001]oo`03
001oogoo09ioo`Ql0003Ooml07`00>Uoo`006goo00<007ooOol0Wgoo0W`000<007`0O0000W`04goo
0W`00Woo0W`0dgoo000KOol00`00Oomoo`2SOol2O00@Ool2O0000gooO01l0006O0000gooO01l003?
Ool001]oo`03001oogoo0:Aoo`8000iooa1l0<ioo`006goo00<007ooOol0YWoo0P0037oo17`000=o
og`0O0000Woo0W`000=oog`0O0000W`0cWoo000KOol00`00Oomoo`2XOol00`00Oomoo`0:Ool2O00:
Ool2O0000gooO01l003<Ool001]oo`03001oogoo0:Uoo`8001Qoo`Al0<]oo`006goo00<007ooOol0
Zgoo00<007ooOol05Goo17`01Goo0W`0a7oo000KOol2002]Ool2000FOol2O005Ool4O033Ool001]o
o`03001oogoo0:ioo`8001Qoo`9l0003Ooml07`0009l0<=oo`006goo00<007ooOol0/7oo00<007oo
Ool057oo17`000=oog`0O0001Goo0W`00Woo0W`0^Goo000KOol00`00Oomoo`2aOol2000DOol4O004
Ool2O0000gooO01l0006O0000gooO01l002eOol001]oo`03001oogoo0;=oo`8001=oo`9l00Aooa1l
0;Aoo`006goo00<007ooOol0]Goo00<007ooOol05Woo17`000=oog`0O0000Woo0W`000=oog`0O000
0W`0]7oo000KOol00`00Oomoo`2fOol2000GOol2O00:Ool2O02eOol001]oo`03001oogoo0;Qoo`80
0=Qoo`006goo00<007ooOol0^Woo00<007ooOol0eGoo000KOol00`00Oomoo`2kOol2003EOol001]o
o`03001oogoo0;eoo`800==oo`006goo00<007ooOol0_goo00<007ooOol0d7oo000KOol20031Ool2
003@Ool001]oo`03001oogoo0<9oo`8001Yoo`9l0;9oo`006goo00<007ooOol0a7oo0P005goo17`0
/Goo000KOol00`00Oomoo`36Ool2000EOol4O02aOol001]oo`03001oogoo0<Qoo`8001Aoo`9l00Io
o`9l0003Ooml07`00:Moo`006goo00<007ooOol0bWoo0P006Goo1g`0YWoo000KOol00`00Oomoo`3<
Ool2000DOol2O0000gooO01l0005O0000gooO01l002SOol001]oo`03001oogoo0<ioo`80015oo`Al
0004Ooml07`0Ool2O0000gooO01l0002O02ROol001]oo`03001oogoo0=1oo`03001oogoo00ioo`Al
00Moo`Al0003Ooml07`009moo`006goo00<007ooOol0dGoo0P003goo0W`02Goo0W`000=oog`0O000
0W`000=oog`0O000Vgoo0006Ool40004Ool40009Ool00`00Oomoo`3COol2000KOol8O02JOol000Eo
o`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`06Ool00`00Oomoo`3EOol2000JOol2O000
0gooO01l0004O002Ool2O02DOol000Eoo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`06
Ool00`00Oomoo`3GOol00`00Oomoo`0KOol:O02COol000Eoo`8000=oo`04001oogoo0004Ool00`00
Oomoo`06Ool3003HOol2000MOol8O02COol000Eoo`03001oo`00008000=oo`03001oogoo009oo`03
001oogoo00Ioo`03001oogoo0=Yoo`8001aoo`9l009oo`9l09Aoo`001Goo00<007ooOol01Goo00<0
07ooOol00Woo00<007ooOol01Woo00<007ooOol0g7oo0P00]7oo0006Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3NOol2002bOol000Moo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo00Ioo`03001oogoo0>1oo`03001oogoo0:moo`0027oo0`000goo10002Goo
00<007ooOol0hGoo0P00[goo000KOol00`00Oomoo`3SOol2002]Ool001]oo`03001oogoo0>Eoo`80
0:]oo`006goo00<007ooOol0igoo0P005goo0W`0T7oo000KOol00`00Oomoo`3YOol2000DOol4O02?
Ool001]oo`03001oogoo0>]oo`80019oo`Al08moo`006goo00<007ooOol0kGoo0P004Goo0W`0T7oo
000KOol00`00Oomoo`3_Ool2002QOol001]oo`800?9oo`03001oogoo09ioo`006goo00<007ooOol0
lWoo0P00WWoo000KOol00`00Oomoo`3dOol2002LOol001]oo`03001oogoo0?Ioo`8009Yoo`006goo
00<007ooOol0n7oo00<007ooOol0Ugoo000KOol00`00Oomoo`3iOol2002GOol001]oo`03001oogoo
0?]oo`8009Eoo`006goo00<007ooOol0oGoo0P00Tgoo000KOol00`00Oomoo`3oOol2002AOol001]o
o`03001oogoo0?moo`9oo`03001oogoo08ioo`006goo00<007ooOol0ogoo0goo0P00SWoo000KOol0
0`00Oomoo`3oOol5Ool200000gooO01l0006Ool2O0000gooO01l001nOol001]oo`03001oogoo0?mo
o`Moo`Al00Aoo`Ml07eoo`006goo0P00ogoo1Woo1W`000Aoog`0O01oo`Ml00Eoo`9l07Ioo`006goo
00<007ooOol0ogoo17oo1W`000=oog`0O0000W`000Aoog`0O01oo`9l009oo`9l0003Ooml07`0009l
07Eoo`006goo00<007ooOol0ogoo17oo17`00goo17`01goo27`0MGoo000KOol00`00Oomoo`3oOol5
Ool2O005Ool2O0000goo00000005Ool4O0000gooO01l001fOol001]oo`03001oogoo0?mooa5oo`80
00Aoo`9l07Yoo`006goo00<007ooOol0ogoo4goo0P00OWoo000KOol00`00Oomoo`3oOolEOol2001l
Ool001]oo`03001oogoo0?mooaMoo`8007Yoo`006goo00<007ooOol0ogoo6Goo00<007ooOol0Mgoo
000KOol00`00Oomoo`3oOolJOol2001gOol001]oo`03001oogoo0?mooaaoo`8007Eoo`006goo00<0
07ooOol0ogoo7Woo0P00Lgoo000KOol00`00Oomoo`3oOolPOol2001aOol001]oo`800?moob=oo`03
001oogoo06ioo`006goo00<007ooOol0ogoo8goo0P00KWoo000KOol00`00Oomoo`3oOolUOol2001/
Ool001]oo`03001oogoo0?moobMoo`8006Yoo`006goo00<007ooOol0ogoo:Goo0P00J7oo000KOol0
0`00Oomoo`3oOol[Ool2001VOol001]oo`03001oogoo0?moobeoo`8006Aoo`006goo00<007ooOol0
ogoo;goo0P00HWoo000KOol00`00Oomoo`3oOolROol2O00=Ool2001POol000Eoo`@000Eoo`@000Uo
o`03001oogoo0?moob5oo`Al0003Ooml07`000]oo`8005ioo`0017oo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`03001oogoo00Ioo`03001oogoo0?moob5oo`Ql00aoo`8005aoo`0017oo00<007oo
Ool00Woo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`03001oogoo0?mooamoo`9l0004Ooml07`0
Ool4O0000gooO01l000;Ool2001JOol000Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`06Ool00`00Oomoo`3oOolNOol4O004Ool2O0000gooO01l0002O00<Ool2001HOol000Eoo`@0
00Aoo`03001oogoo009oo`03001oogoo00Ioo`<00?mooaioo`Al00Moo`Al00ioo`8005Ioo`0017oo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`03001oogoo0?mooamoo`9l00Uo
o`9l0003Ooml07`000ioo`8005Aoo`0017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001o
ogoo00Ioo`03001oogoo0?moobaoo`Al00moo`80059oo`0017oo00<007ooOol00Woo00D007ooOomo
o`0000Aoo`03001oogoo00Ioo`03001oogoo0?moobaoo`Al015oo`80051oo`001Goo10001Goo1000
2Goo00<007ooOol0ogoo;Goo0W`057oo0P00CWoo000KOol00`00Oomoo`3oOom5Ool2001<Ool001]o
o`03001oogoo0?moodMoo`8004Yoo`006goo00<007ooOol0ogooBGoo0P00B7oo000KOol00`00Oomo
o`3oOom;Ool20016Ool001]oo`03001oogoo0?moodeoo`8004Aoo`006goo00<007ooOol0ogooCgoo
0P00@Woo000KOol00`00Oomoo`3oOoleOol2O005Ool2O006Ool2O00;Ool20010Ool001]oo`03001o
ogoo0?moocAoo`Al00=oo`Al00Aoo`Al00aoo`8003ioo`006goo0P00ogoo=Goo17`00goo17`017oo
17`03Woo0P00?7oo000KOol00`00Oomoo`3oOolaOol2O002Ool2O002Ool2O0000gooO01l0002Ool2
O002Ool2O00AOol2000jOol001]oo`03001oogoo0?mooc1oo`Al00Aoo`Al00=oo`Al01Ioo`8003Qo
o`006goo00<007ooOol0ogoo<7oo17`017oo17`00goo17`027oo0W`03Woo0P00=Woo000KOol00`00
Oomoo`3oOolaOol2O006Ool2O005Ool2O008Ool4O0000gooO01l0005Ool2O005Ool2000dOol001]o
o`03001oogoo0?moodYoo`Ql0003Ooml07`000Al00Ioo`80039oo`006goo00<007ooOol0ogooBgoo
0W`000=oog`0O0002G`027oo0P00<7oo000KOol00`00Oomoo`3oOom7Ool2O006Ool2O0000gooO01l
0004O002Ool2O007Ool2000^Ool001]oo`03001oogoo0?moodIoo`Al00Uoo`9l00Aoo`Al00Qoo`80
02aoo`006goo00<007ooOol0ogooAWoo17`03goo17`02Woo0P00:Woo000KOol00`00Oomoo`3oOom7
Ool2O00AOol2O00=Ool2000XOol001]oo`03001oogoo0?moof]oo`8002Ioo`006goo0P00ogooGgoo
0W`03Goo0P0097oo000KOol00`00Oomoo`3oOomMOol4O00>Ool2000ROol001]oo`03001oogoo0?mo
oeeoo`Il00ioo`80021oo`006goo00<007ooOol0ogooGWoo1W`03goo0`007Goo000KOol00`00Oomo
o`3oOomPOol4O00BOol2000KOol001]oo`03001oogoo0?moof5oo`9l009oo`9l009oo`9l00eoo`80
01Uoo`006goo00<007ooOol0ogooI7oo27`03Woo0P005goo000KOol00`00Oomoo`3oOomTOol8O00@
Ool3000DOol001]oo`03001oogoo0?moofEoo`9l009oo`9l00Eoo`9l00eoo`80019oo`006goo00<0
07ooOol0ogooKGoo1W`03Woo0P0047oo000KOol00`00Oomoo`3oOom/Ool7O00@Ool2000>Ool001]o
o`03001oogoo0?moofaoo`Il025oo`006goo00<007ooOol0ogooKGoo0W`097oo000KOol2003oOonD
Ool001]oo`03001oogoo0?mooi=oo`006goo00<007ooOol0ogooTgoo000KOol00`00Oomoo`3oOonC
Ool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-14.5427, -7.25109, \
0.807057, 0.584073}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[days, \ intakes, lung, \ modelAMAD, \ retlung, randomInput2, 
      meanintake, \ meanamad, \ qLungsChronic2]\)], "Input",
  CellLabel->"In[32]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 4", "SubsubsectionIcon"],

Cell["\<\
A  worker has been exposed during the last 300 days of an intake by \
inhalation of radioactive aerosols (type S, AMAD 5) 5 days per week. It know \
that the daily average intake was 3.3 Bq/day with and standard deviation of \
5.5 Bq/day.  According to the dosimetry historial of this worker, before of \
this period he intaken 3500 Bq  during 1200 days. We wish estimate the daily \
urine excretion. \
\>", "Text"],

Cell["The first step is obteined the IRF for a simgle input 1 ", "MathCaption"],

Cell[BoxData[
    \(\({urineExc, faecalExc, 
          wholebodyRet} = {qDailyUrine[t], qDailyFaecal[t], 
            qWholebody[t]} /. \[InvisibleSpace]BiokdataReport[
            uranium, "\<Inhalation\>", \ "\<Acute\>", "\<Automatic\>", 1, \ 
            AMADAdultW[5], \ S, 0.002, t, 0];\)\)], "Input",
  CellLabel->"In[33]:="],

Cell["\<\
Now it is applied the function qRandom (See in Help: Advance function)\
\>", "MathCaption"],

Cell[BoxData[
    \(\(sol = 
        qRandom[3500, \ 1200, urineExc, 3.3, 5.1, 1.96, 300, \ 5, \ 
          t];\)\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \(\({days, \ me, \ int, \ ul, \ ll} = Transpose[sol];\)\)], "Input",
  CellLabel->"In[35]:="],

Cell["\<\
The blue color represents the confidence interval for the daily  urine \
excretion, it can be observed the effect of the weekeng where there are not \
intakes.  \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FilledListPlot[Transpose[{days, ll}], Transpose[{days, ul}], 
      AxesLabel \[Rule] {"\<days\>", "\<Bq/day\>"}]\)], "Input",
  CellLabel->"In[36]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0031746 -0.15408 44.0605 [
[.18254 .27402 -6 -9 ]
[.18254 .27402 6 0 ]
[.34127 .27402 -9 -9 ]
[.34127 .27402 9 0 ]
[.5 .27402 -9 -9 ]
[.5 .27402 9 0 ]
[.65873 .27402 -9 -9 ]
[.65873 .27402 9 0 ]
[.81746 .27402 -9 -9 ]
[.81746 .27402 9 0 ]
[.97619 .27402 -9 -9 ]
[.97619 .27402 9 0 ]
[1.025 .28652 0 -6.28125 ]
[1.025 .28652 28 6.28125 ]
[.01131 .02216 -30 -4.5 ]
[.01131 .02216 0 4.5 ]
[.01131 .11028 -30 -4.5 ]
[.01131 .11028 0 4.5 ]
[.01131 .1984 -30 -4.5 ]
[.01131 .1984 0 4.5 ]
[.01131 .37465 -30 -4.5 ]
[.01131 .37465 0 4.5 ]
[.01131 .46277 -30 -4.5 ]
[.01131 .46277 0 4.5 ]
[.01131 .55089 -30 -4.5 ]
[.01131 .55089 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .28652 m
.18254 .29277 L
s
[(50)] .18254 .27402 0 1 Mshowa
.34127 .28652 m
.34127 .29277 L
s
[(100)] .34127 .27402 0 1 Mshowa
.5 .28652 m
.5 .29277 L
s
[(150)] .5 .27402 0 1 Mshowa
.65873 .28652 m
.65873 .29277 L
s
[(200)] .65873 .27402 0 1 Mshowa
.81746 .28652 m
.81746 .29277 L
s
[(250)] .81746 .27402 0 1 Mshowa
.97619 .28652 m
.97619 .29277 L
s
[(300)] .97619 .27402 0 1 Mshowa
.125 Mabswid
.05556 .28652 m
.05556 .29027 L
s
.0873 .28652 m
.0873 .29027 L
s
.11905 .28652 m
.11905 .29027 L
s
.15079 .28652 m
.15079 .29027 L
s
.21429 .28652 m
.21429 .29027 L
s
.24603 .28652 m
.24603 .29027 L
s
.27778 .28652 m
.27778 .29027 L
s
.30952 .28652 m
.30952 .29027 L
s
.37302 .28652 m
.37302 .29027 L
s
.40476 .28652 m
.40476 .29027 L
s
.43651 .28652 m
.43651 .29027 L
s
.46825 .28652 m
.46825 .29027 L
s
.53175 .28652 m
.53175 .29027 L
s
.56349 .28652 m
.56349 .29027 L
s
.59524 .28652 m
.59524 .29027 L
s
.62698 .28652 m
.62698 .29027 L
s
.69048 .28652 m
.69048 .29027 L
s
.72222 .28652 m
.72222 .29027 L
s
.75397 .28652 m
.75397 .29027 L
s
.78571 .28652 m
.78571 .29027 L
s
.84921 .28652 m
.84921 .29027 L
s
.88095 .28652 m
.88095 .29027 L
s
.9127 .28652 m
.9127 .29027 L
s
.94444 .28652 m
.94444 .29027 L
s
.25 Mabswid
0 .28652 m
1 .28652 L
s
gsave
1.025 .28652 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .02216 m
.03006 .02216 L
s
[(0.004)] .01131 .02216 1 0 Mshowa
.02381 .11028 m
.03006 .11028 L
s
[(0.006)] .01131 .11028 1 0 Mshowa
.02381 .1984 m
.03006 .1984 L
s
[(0.008)] .01131 .1984 1 0 Mshowa
.02381 .37465 m
.03006 .37465 L
s
[(0.012)] .01131 .37465 1 0 Mshowa
.02381 .46277 m
.03006 .46277 L
s
[(0.014)] .01131 .46277 1 0 Mshowa
.02381 .55089 m
.03006 .55089 L
s
[(0.016)] .01131 .55089 1 0 Mshowa
.125 Mabswid
.02381 .04419 m
.02756 .04419 L
s
.02381 .06622 m
.02756 .06622 L
s
.02381 .08825 m
.02756 .08825 L
s
.02381 .13231 m
.02756 .13231 L
s
.02381 .15434 m
.02756 .15434 L
s
.02381 .17637 m
.02756 .17637 L
s
.02381 .22043 m
.02756 .22043 L
s
.02381 .24246 m
.02756 .24246 L
s
.02381 .26449 m
.02756 .26449 L
s
.02381 .30855 m
.02756 .30855 L
s
.02381 .33058 m
.02756 .33058 L
s
.02381 .35262 m
.02756 .35262 L
s
.02381 .39668 m
.02756 .39668 L
s
.02381 .41871 m
.02756 .41871 L
s
.02381 .44074 m
.02756 .44074 L
s
.02381 .4848 m
.02756 .4848 L
s
.02381 .50683 m
.02756 .50683 L
s
.02381 .52886 m
.02756 .52886 L
s
.02381 .00013 m
.02756 .00013 L
s
.02381 .57292 m
.02756 .57292 L
s
.02381 .59495 m
.02756 .59495 L
s
.02381 .61698 m
.02756 .61698 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 12.813 moveto
(\\220) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(day) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.18254 .11422 m
.18571 .118 L
.18889 .11936 L
.19206 .12055 L
.19524 .12164 L
.19841 .02024 L
.20159 .01472 L
.20476 .11418 L
.20794 .11798 L
.21111 .11934 L
.21429 .12054 L
.21746 .12164 L
.22063 .02026 L
.22381 .01475 L
.22698 .11422 L
.23016 .11803 L
.23333 .1194 L
.23651 .12061 L
.23968 .12172 L
.24286 .02035 L
.24603 .01485 L
.24921 .11433 L
.25238 .11815 L
.25556 .11953 L
.25873 .12074 L
.2619 .12185 L
.26508 .02049 L
.26825 .01501 L
.27143 .11449 L
.2746 .11831 L
.27778 .1197 L
.28095 .12091 L
.28413 .12203 L
.2873 .02068 L
.29048 .0152 L
.29365 .11469 L
.29683 .11852 L
.3 .11991 L
.30317 .12113 L
.30635 .12225 L
.30952 .0209 L
.3127 .01543 L
.31587 .11493 L
.31905 .11875 L
.32222 .12015 L
.3254 .12137 L
.32857 .1225 L
.33175 .02116 L
.33492 .01569 L
.3381 .11519 L
Mistroke
.34127 .11902 L
.34444 .12042 L
.34762 .12164 L
.35079 .12277 L
.35397 .02144 L
.35714 .01598 L
.36032 .11548 L
.36349 .11931 L
.36667 .12071 L
.36984 .12194 L
.37302 .12307 L
.37619 .02174 L
.37937 .01628 L
.38254 .11578 L
.38571 .11962 L
.38889 .12102 L
.39206 .12225 L
.39524 .12339 L
.39841 .02206 L
.40159 .0166 L
.40476 .11611 L
.40794 .11994 L
.41111 .12135 L
.41429 .12258 L
.41746 .12372 L
.42063 .02239 L
.42381 .01694 L
.42698 .11645 L
.43016 .12028 L
.43333 .12169 L
.43651 .12292 L
.43968 .12406 L
.44286 .02274 L
.44603 .01729 L
.44921 .1168 L
.45238 .12063 L
.45556 .12204 L
.45873 .12328 L
.4619 .12442 L
.46508 .02309 L
.46825 .01765 L
.47143 .11716 L
.4746 .121 L
.47778 .1224 L
.48095 .12364 L
.48413 .12478 L
.4873 .02346 L
.49048 .01802 L
.49365 .11753 L
.49683 .12137 L
Mistroke
.5 .12277 L
.50317 .12401 L
.50635 .12515 L
.50952 .02384 L
.5127 .01839 L
.51587 .1179 L
.51905 .12174 L
.52222 .12315 L
.5254 .12439 L
.52857 .12553 L
.53175 .02422 L
.53492 .01878 L
.5381 .11829 L
.54127 .12213 L
.54444 .12354 L
.54762 .12478 L
.55079 .12592 L
.55397 .0246 L
.55714 .01917 L
.56032 .11868 L
.56349 .12252 L
.56667 .12393 L
.56984 .12517 L
.57302 .12631 L
.57619 .025 L
.57937 .01956 L
.58254 .11907 L
.58571 .12291 L
.58889 .12432 L
.59206 .12557 L
.59524 .12671 L
.59841 .02539 L
.60159 .01996 L
.60476 .11947 L
.60794 .12331 L
.61111 .12472 L
.61429 .12596 L
.61746 .12711 L
.62063 .02579 L
.62381 .02036 L
.62698 .11987 L
.63016 .12371 L
.63333 .12512 L
.63651 .12637 L
.63968 .12751 L
.64286 .0262 L
.64603 .02076 L
.64921 .12028 L
.65238 .12412 L
.65556 .12553 L
Mistroke
.65873 .12677 L
.6619 .12792 L
.66508 .0266 L
.66825 .02117 L
.67143 .12068 L
.6746 .12453 L
.67778 .12594 L
.68095 .12718 L
.68413 .12832 L
.6873 .02701 L
.69048 .02158 L
.69365 .12109 L
.69683 .12493 L
.7 .12635 L
.70317 .12759 L
.70635 .12873 L
.70952 .02742 L
.7127 .02199 L
.71587 .1215 L
.71905 .12534 L
.72222 .12676 L
.7254 .128 L
.72857 .12914 L
.73175 .02783 L
.73492 .0224 L
.7381 .12191 L
.74127 .12576 L
.74444 .12717 L
.74762 .12841 L
.75079 .12956 L
.75397 .02824 L
.75714 .02281 L
.76032 .12233 L
.76349 .12617 L
.76667 .12758 L
.76984 .12882 L
.77302 .12997 L
.77619 .02866 L
.77937 .02323 L
.78254 .12274 L
.78571 .12658 L
.78889 .12799 L
.79206 .12924 L
.79524 .13038 L
.79841 .02907 L
.80159 .02364 L
.80476 .12315 L
.80794 .127 L
.81111 .12841 L
.81429 .12965 L
Mistroke
.81746 .1308 L
.82063 .02949 L
.82381 .02405 L
.82698 .12357 L
.83016 .12741 L
.83333 .12882 L
.83651 .13007 L
.83968 .13121 L
.84286 .0299 L
.84603 .02447 L
.84921 .12398 L
.85238 .12783 L
.85556 .12924 L
.85873 .13048 L
.8619 .13163 L
.86508 .03032 L
.86825 .02488 L
.87143 .1244 L
.8746 .12824 L
.87778 .12965 L
.88095 .1309 L
.88413 .13204 L
.8873 .03073 L
.89048 .0253 L
.89365 .12481 L
.89683 .12866 L
.9 .13007 L
.90317 .13131 L
.90635 .13245 L
.90952 .03115 L
.9127 .02572 L
.91587 .12523 L
.91905 .12907 L
.92222 .13048 L
.9254 .13173 L
.92857 .13287 L
.93175 .03156 L
.93492 .02613 L
.9381 .12564 L
.94127 .12949 L
.94444 .1309 L
.94762 .13214 L
.95079 .13328 L
.95397 .03197 L
.95714 .02654 L
.96032 .12606 L
.96349 .1299 L
.96667 .13131 L
.96984 .13255 L
.97302 .1337 L
Mistroke
.97619 .03239 L
Mfstroke
.18254 .57931 m
.18571 .58311 L
.18889 .58448 L
.19206 .58569 L
.19524 .58679 L
.19841 .48551 L
.20159 .48011 L
.20476 .57959 L
.20794 .5834 L
.21111 .58478 L
.21429 .58599 L
.21746 .5871 L
.22063 .48582 L
.22381 .48043 L
.22698 .57991 L
.23016 .58373 L
.23333 .58511 L
.23651 .58633 L
.23968 .58745 L
.24286 .48617 L
.24603 .48077 L
.24921 .58026 L
.25238 .58409 L
.25556 .58548 L
.25873 .5867 L
.2619 .58782 L
.26508 .48654 L
.26825 .48115 L
.27143 .58064 L
.2746 .58447 L
.27778 .58587 L
.28095 .58709 L
.28413 .58822 L
.2873 .48694 L
.29048 .48155 L
.29365 .58105 L
.29683 .58488 L
.3 .58628 L
.30317 .58751 L
.30635 .58864 L
.30952 .48736 L
.3127 .48197 L
.31587 .58147 L
.31905 .5853 L
.32222 .5867 L
.3254 .58794 L
.32857 .58907 L
.33175 .48779 L
.33492 .4824 L
.3381 .5819 L
Mistroke
.34127 .58574 L
.34444 .58714 L
.34762 .58838 L
.35079 .58952 L
.35397 .48824 L
.35714 .48285 L
.36032 .58235 L
.36349 .58619 L
.36667 .5876 L
.36984 .58884 L
.37302 .58997 L
.37619 .4887 L
.37937 .4833 L
.38254 .58281 L
.38571 .58665 L
.38889 .58806 L
.39206 .5893 L
.39524 .59044 L
.39841 .48916 L
.40159 .48377 L
.40476 .58328 L
.40794 .58712 L
.41111 .58853 L
.41429 .58977 L
.41746 .59092 L
.42063 .48964 L
.42381 .48425 L
.42698 .58376 L
.43016 .5876 L
.43333 .58901 L
.43651 .59025 L
.43968 .5914 L
.44286 .49012 L
.44603 .48473 L
.44921 .58424 L
.45238 .58808 L
.45556 .58949 L
.45873 .59074 L
.4619 .59188 L
.46508 .4906 L
.46825 .48521 L
.47143 .58473 L
.4746 .58857 L
.47778 .58998 L
.48095 .59123 L
.48413 .59237 L
.4873 .4911 L
.49048 .4857 L
.49365 .58522 L
.49683 .58906 L
Mistroke
.5 .59047 L
.50317 .59172 L
.50635 .59287 L
.50952 .49159 L
.5127 .4862 L
.51587 .58571 L
.51905 .58956 L
.52222 .59097 L
.5254 .59222 L
.52857 .59336 L
.53175 .49209 L
.53492 .48669 L
.5381 .58621 L
.54127 .59005 L
.54444 .59147 L
.54762 .59271 L
.55079 .59386 L
.55397 .49258 L
.55714 .48719 L
.56032 .58671 L
.56349 .59055 L
.56667 .59197 L
.56984 .59321 L
.57302 .59436 L
.57619 .49308 L
.57937 .48769 L
.58254 .58721 L
.58571 .59105 L
.58889 .59247 L
.59206 .59372 L
.59524 .59486 L
.59841 .49359 L
.60159 .48819 L
.60476 .58771 L
.60794 .59155 L
.61111 .59297 L
.61429 .59422 L
.61746 .59537 L
.62063 .49409 L
.62381 .48869 L
.62698 .58821 L
.63016 .59206 L
.63333 .59347 L
.63651 .59472 L
.63968 .59587 L
.64286 .49459 L
.64603 .48919 L
.64921 .58871 L
.65238 .59256 L
.65556 .59397 L
Mistroke
.65873 .59522 L
.6619 .59637 L
.66508 .49509 L
.66825 .4897 L
.67143 .58921 L
.6746 .59306 L
.67778 .59448 L
.68095 .59572 L
.68413 .59687 L
.6873 .49559 L
.69048 .4902 L
.69365 .58972 L
.69683 .59356 L
.7 .59498 L
.70317 .59623 L
.70635 .59737 L
.70952 .4961 L
.7127 .4907 L
.71587 .59022 L
.71905 .59406 L
.72222 .59548 L
.7254 .59673 L
.72857 .59788 L
.73175 .4966 L
.73492 .4912 L
.7381 .59072 L
.74127 .59457 L
.74444 .59598 L
.74762 .59723 L
.75079 .59838 L
.75397 .4971 L
.75714 .4917 L
.76032 .59122 L
.76349 .59507 L
.76667 .59648 L
.76984 .59773 L
.77302 .59888 L
.77619 .4976 L
.77937 .4922 L
.78254 .59172 L
.78571 .59556 L
.78889 .59698 L
.79206 .59823 L
.79524 .59938 L
.79841 .4981 L
.80159 .4927 L
.80476 .59221 L
.80794 .59606 L
.81111 .59748 L
.81429 .59873 L
Mistroke
.81746 .59987 L
.82063 .49859 L
.82381 .49319 L
.82698 .59271 L
.83016 .59656 L
.83333 .59797 L
.83651 .59922 L
.83968 .60037 L
.84286 .49909 L
.84603 .49369 L
.84921 .59321 L
.85238 .59705 L
.85556 .59847 L
.85873 .59972 L
.8619 .60087 L
.86508 .49958 L
.86825 .49418 L
.87143 .5937 L
.8746 .59755 L
.87778 .59896 L
.88095 .60021 L
.88413 .60136 L
.8873 .50008 L
.89048 .49468 L
.89365 .59419 L
.89683 .59804 L
.9 .59946 L
.90317 .6007 L
.90635 .60185 L
.90952 .50057 L
.9127 .49517 L
.91587 .59469 L
.91905 .59853 L
.92222 .59995 L
.9254 .60119 L
.92857 .60234 L
.93175 .50106 L
.93492 .49566 L
.9381 .59518 L
.94127 .59902 L
.94444 .60044 L
.94762 .60168 L
.95079 .60283 L
.95397 .50155 L
.95714 .49615 L
.96032 .59566 L
.96349 .59951 L
.96667 .60093 L
.96984 .60217 L
.97302 .60332 L
Mistroke
.97619 .50204 L
Mfstroke
0 1 1 r
.18254 .11422 m
.18571 .118 L
.18889 .11936 L
.19206 .12055 L
.19524 .12164 L
.19841 .02024 L
.20159 .01472 L
.20476 .11418 L
.20794 .11798 L
.21111 .11934 L
.21429 .12054 L
.21746 .12164 L
.22063 .02026 L
.22381 .01475 L
.22698 .11422 L
.23016 .11803 L
.23333 .1194 L
.23651 .12061 L
.23968 .12172 L
.24286 .02035 L
.24603 .01485 L
.24921 .11433 L
.25238 .11815 L
.25556 .11953 L
.25873 .12074 L
.2619 .12185 L
.26508 .02049 L
.26825 .01501 L
.27143 .11449 L
.2746 .11831 L
.27778 .1197 L
.28095 .12091 L
.28413 .12203 L
.2873 .02068 L
.29048 .0152 L
.29365 .11469 L
.29683 .11852 L
.3 .11991 L
.30317 .12113 L
.30635 .12225 L
.30952 .0209 L
.3127 .01543 L
.31587 .11493 L
.31905 .11875 L
.32222 .12015 L
.3254 .12137 L
.32857 .1225 L
.33175 .02116 L
.33492 .01569 L
.3381 .11519 L
.34127 .11902 L
.34444 .12042 L
.34762 .12164 L
.35079 .12277 L
.35397 .02144 L
.35714 .01598 L
.36032 .11548 L
.36349 .11931 L
.36667 .12071 L
.36984 .12194 L
.37302 .12307 L
.37619 .02174 L
.37937 .01628 L
.38254 .11578 L
.38571 .11962 L
.38889 .12102 L
.39206 .12225 L
.39524 .12339 L
.39841 .02206 L
.40159 .0166 L
.40476 .11611 L
.40794 .11994 L
.41111 .12135 L
.41429 .12258 L
.41746 .12372 L
.42063 .02239 L
.42381 .01694 L
.42698 .11645 L
.43016 .12028 L
.43333 .12169 L
.43651 .12292 L
.43968 .12406 L
.44286 .02274 L
.44603 .01729 L
.44921 .1168 L
.45238 .12063 L
.45556 .12204 L
.45873 .12328 L
.4619 .12442 L
.46508 .02309 L
.46825 .01765 L
.47143 .11716 L
.4746 .121 L
.47778 .1224 L
.48095 .12364 L
.48413 .12478 L
.4873 .02346 L
.49048 .01802 L
.49365 .11753 L
.49683 .12137 L
.5 .12277 L
.50317 .12401 L
.50635 .12515 L
.50952 .02384 L
.5127 .01839 L
.51587 .1179 L
.51905 .12174 L
.52222 .12315 L
.5254 .12439 L
.52857 .12553 L
.53175 .02422 L
.53492 .01878 L
.5381 .11829 L
.54127 .12213 L
.54444 .12354 L
.54762 .12478 L
.55079 .12592 L
.55397 .0246 L
.55714 .01917 L
.56032 .11868 L
.56349 .12252 L
.56667 .12393 L
.56984 .12517 L
.57302 .12631 L
.57619 .025 L
.57937 .01956 L
.58254 .11907 L
.58571 .12291 L
.58889 .12432 L
.59206 .12557 L
.59524 .12671 L
.59841 .02539 L
.60159 .01996 L
.60476 .11947 L
.60794 .12331 L
.61111 .12472 L
.61429 .12596 L
.61746 .12711 L
.62063 .02579 L
.62381 .02036 L
.62698 .11987 L
.63016 .12371 L
.63333 .12512 L
.63651 .12637 L
.63968 .12751 L
.64286 .0262 L
.64603 .02076 L
.64921 .12028 L
.65238 .12412 L
.65556 .12553 L
.65873 .12677 L
.6619 .12792 L
.66508 .0266 L
.66825 .02117 L
.67143 .12068 L
.6746 .12453 L
.67778 .12594 L
.68095 .12718 L
.68413 .12832 L
.6873 .02701 L
.69048 .02158 L
.69365 .12109 L
.69683 .12493 L
.7 .12635 L
.70317 .12759 L
.70635 .12873 L
.70952 .02742 L
.7127 .02199 L
.71587 .1215 L
.71905 .12534 L
.72222 .12676 L
.7254 .128 L
.72857 .12914 L
.73175 .02783 L
.73492 .0224 L
.7381 .12191 L
.74127 .12576 L
.74444 .12717 L
.74762 .12841 L
.75079 .12956 L
.75397 .02824 L
.75714 .02281 L
.76032 .12233 L
.76349 .12617 L
.76667 .12758 L
.76984 .12882 L
.77302 .12997 L
.77619 .02866 L
.77937 .02323 L
.78254 .12274 L
.78571 .12658 L
.78889 .12799 L
.79206 .12924 L
.79524 .13038 L
.79841 .02907 L
.80159 .02364 L
.80476 .12315 L
.80794 .127 L
.81111 .12841 L
.81429 .12965 L
.81746 .1308 L
.82063 .02949 L
.82381 .02405 L
.82698 .12357 L
.83016 .12741 L
.83333 .12882 L
.83651 .13007 L
.83968 .13121 L
.84286 .0299 L
.84603 .02447 L
.84921 .12398 L
.85238 .12783 L
.85556 .12924 L
.85873 .13048 L
.8619 .13163 L
.86508 .03032 L
.86825 .02488 L
.87143 .1244 L
.8746 .12824 L
.87778 .12965 L
.88095 .1309 L
.88413 .13204 L
.8873 .03073 L
.89048 .0253 L
.89365 .12481 L
.89683 .12866 L
.9 .13007 L
.90317 .13131 L
.90635 .13245 L
.90952 .03115 L
.9127 .02572 L
.91587 .12523 L
.91905 .12907 L
.92222 .13048 L
.9254 .13173 L
.92857 .13287 L
.93175 .03156 L
.93492 .02613 L
.9381 .12564 L
.94127 .12949 L
.94444 .1309 L
.94762 .13214 L
.95079 .13328 L
.95397 .03197 L
.95714 .02654 L
.96032 .12606 L
.96349 .1299 L
.96667 .13131 L
.96984 .13255 L
.97302 .1337 L
.97619 .03239 L
.97619 .50204 L
.97302 .60332 L
.96984 .60217 L
.96667 .60093 L
.96349 .59951 L
.96032 .59566 L
.95714 .49615 L
.95397 .50155 L
.95079 .60283 L
.94762 .60168 L
.94444 .60044 L
.94127 .59902 L
.9381 .59518 L
.93492 .49566 L
.93175 .50106 L
.92857 .60234 L
.9254 .60119 L
.92222 .59995 L
.91905 .59853 L
.91587 .59469 L
.9127 .49517 L
.90952 .50057 L
.90635 .60185 L
.90317 .6007 L
.9 .59946 L
.89683 .59804 L
.89365 .59419 L
.89048 .49468 L
.8873 .50008 L
.88413 .60136 L
.88095 .60021 L
.87778 .59896 L
.8746 .59755 L
.87143 .5937 L
.86825 .49418 L
.86508 .49958 L
.8619 .60087 L
.85873 .59972 L
.85556 .59847 L
.85238 .59705 L
.84921 .59321 L
.84603 .49369 L
.84286 .49909 L
.83968 .60037 L
.83651 .59922 L
.83333 .59797 L
.83016 .59656 L
.82698 .59271 L
.82381 .49319 L
.82063 .49859 L
.81746 .59987 L
.81429 .59873 L
.81111 .59748 L
.80794 .59606 L
.80476 .59221 L
.80159 .4927 L
.79841 .4981 L
.79524 .59938 L
.79206 .59823 L
.78889 .59698 L
.78571 .59556 L
.78254 .59172 L
.77937 .4922 L
.77619 .4976 L
.77302 .59888 L
.76984 .59773 L
.76667 .59648 L
.76349 .59507 L
.76032 .59122 L
.75714 .4917 L
.75397 .4971 L
.75079 .59838 L
.74762 .59723 L
.74444 .59598 L
.74127 .59457 L
.7381 .59072 L
.73492 .4912 L
.73175 .4966 L
.72857 .59788 L
.7254 .59673 L
.72222 .59548 L
.71905 .59406 L
.71587 .59022 L
.7127 .4907 L
.70952 .4961 L
.70635 .59737 L
.70317 .59623 L
.7 .59498 L
.69683 .59356 L
.69365 .58972 L
.69048 .4902 L
.6873 .49559 L
.68413 .59687 L
.68095 .59572 L
.67778 .59448 L
.6746 .59306 L
.67143 .58921 L
.66825 .4897 L
.66508 .49509 L
.6619 .59637 L
.65873 .59522 L
.65556 .59397 L
.65238 .59256 L
.64921 .58871 L
.64603 .48919 L
.64286 .49459 L
.63968 .59587 L
.63651 .59472 L
.63333 .59347 L
.63016 .59206 L
.62698 .58821 L
.62381 .48869 L
.62063 .49409 L
.61746 .59537 L
.61429 .59422 L
.61111 .59297 L
.60794 .59155 L
.60476 .58771 L
.60159 .48819 L
.59841 .49359 L
.59524 .59486 L
.59206 .59372 L
.58889 .59247 L
.58571 .59105 L
.58254 .58721 L
.57937 .48769 L
.57619 .49308 L
.57302 .59436 L
.56984 .59321 L
.56667 .59197 L
.56349 .59055 L
.56032 .58671 L
.55714 .48719 L
.55397 .49258 L
.55079 .59386 L
.54762 .59271 L
.54444 .59147 L
.54127 .59005 L
.5381 .58621 L
.53492 .48669 L
.53175 .49209 L
.52857 .59336 L
.5254 .59222 L
.52222 .59097 L
.51905 .58956 L
.51587 .58571 L
.5127 .4862 L
.50952 .49159 L
.50635 .59287 L
.50317 .59172 L
.5 .59047 L
.49683 .58906 L
.49365 .58522 L
.49048 .4857 L
.4873 .4911 L
.48413 .59237 L
.48095 .59123 L
.47778 .58998 L
.4746 .58857 L
.47143 .58473 L
.46825 .48521 L
.46508 .4906 L
.4619 .59188 L
.45873 .59074 L
.45556 .58949 L
.45238 .58808 L
.44921 .58424 L
.44603 .48473 L
.44286 .49012 L
.43968 .5914 L
.43651 .59025 L
.43333 .58901 L
.43016 .5876 L
.42698 .58376 L
.42381 .48425 L
.42063 .48964 L
.41746 .59092 L
.41429 .58977 L
.41111 .58853 L
.40794 .58712 L
.40476 .58328 L
.40159 .48377 L
.39841 .48916 L
.39524 .59044 L
.39206 .5893 L
.38889 .58806 L
.38571 .58665 L
.38254 .58281 L
.37937 .4833 L
.37619 .4887 L
.37302 .58997 L
.36984 .58884 L
.36667 .5876 L
.36349 .58619 L
.36032 .58235 L
.35714 .48285 L
.35397 .48824 L
.35079 .58952 L
.34762 .58838 L
.34444 .58714 L
.34127 .58574 L
.3381 .5819 L
.33492 .4824 L
.33175 .48779 L
.32857 .58907 L
.3254 .58794 L
.32222 .5867 L
.31905 .5853 L
.31587 .58147 L
.3127 .48197 L
.30952 .48736 L
.30635 .58864 L
.30317 .58751 L
.3 .58628 L
.29683 .58488 L
.29365 .58105 L
.29048 .48155 L
.2873 .48694 L
.28413 .58822 L
.28095 .58709 L
.27778 .58587 L
.2746 .58447 L
.27143 .58064 L
.26825 .48115 L
.26508 .48654 L
.2619 .58782 L
.25873 .5867 L
.25556 .58548 L
.25238 .58409 L
.24921 .58026 L
.24603 .48077 L
.24286 .48617 L
.23968 .58745 L
.23651 .58633 L
.23333 .58511 L
.23016 .58373 L
.22698 .57991 L
.22381 .48043 L
.22063 .48582 L
.21746 .5871 L
.21429 .58599 L
.21111 .58478 L
.20794 .5834 L
.20476 .57959 L
.20159 .48011 L
.19841 .48551 L
.19524 .58679 L
.19206 .58569 L
.18889 .58448 L
.18571 .58311 L
.18254 .57931 L
F
0 g
.18254 .11422 m
.18571 .118 L
.18889 .11936 L
.19206 .12055 L
.19524 .12164 L
.19841 .02024 L
.20159 .01472 L
.20476 .11418 L
.20794 .11798 L
.21111 .11934 L
.21429 .12054 L
.21746 .12164 L
.22063 .02026 L
.22381 .01475 L
.22698 .11422 L
.23016 .11803 L
.23333 .1194 L
.23651 .12061 L
.23968 .12172 L
.24286 .02035 L
.24603 .01485 L
.24921 .11433 L
.25238 .11815 L
.25556 .11953 L
.25873 .12074 L
.2619 .12185 L
.26508 .02049 L
.26825 .01501 L
.27143 .11449 L
.2746 .11831 L
.27778 .1197 L
.28095 .12091 L
.28413 .12203 L
.2873 .02068 L
.29048 .0152 L
.29365 .11469 L
.29683 .11852 L
.3 .11991 L
.30317 .12113 L
.30635 .12225 L
.30952 .0209 L
.3127 .01543 L
.31587 .11493 L
.31905 .11875 L
.32222 .12015 L
.3254 .12137 L
.32857 .1225 L
.33175 .02116 L
.33492 .01569 L
.3381 .11519 L
Mistroke
.34127 .11902 L
.34444 .12042 L
.34762 .12164 L
.35079 .12277 L
.35397 .02144 L
.35714 .01598 L
.36032 .11548 L
.36349 .11931 L
.36667 .12071 L
.36984 .12194 L
.37302 .12307 L
.37619 .02174 L
.37937 .01628 L
.38254 .11578 L
.38571 .11962 L
.38889 .12102 L
.39206 .12225 L
.39524 .12339 L
.39841 .02206 L
.40159 .0166 L
.40476 .11611 L
.40794 .11994 L
.41111 .12135 L
.41429 .12258 L
.41746 .12372 L
.42063 .02239 L
.42381 .01694 L
.42698 .11645 L
.43016 .12028 L
.43333 .12169 L
.43651 .12292 L
.43968 .12406 L
.44286 .02274 L
.44603 .01729 L
.44921 .1168 L
.45238 .12063 L
.45556 .12204 L
.45873 .12328 L
.4619 .12442 L
.46508 .02309 L
.46825 .01765 L
.47143 .11716 L
.4746 .121 L
.47778 .1224 L
.48095 .12364 L
.48413 .12478 L
.4873 .02346 L
.49048 .01802 L
.49365 .11753 L
.49683 .12137 L
Mistroke
.5 .12277 L
.50317 .12401 L
.50635 .12515 L
.50952 .02384 L
.5127 .01839 L
.51587 .1179 L
.51905 .12174 L
.52222 .12315 L
.5254 .12439 L
.52857 .12553 L
.53175 .02422 L
.53492 .01878 L
.5381 .11829 L
.54127 .12213 L
.54444 .12354 L
.54762 .12478 L
.55079 .12592 L
.55397 .0246 L
.55714 .01917 L
.56032 .11868 L
.56349 .12252 L
.56667 .12393 L
.56984 .12517 L
.57302 .12631 L
.57619 .025 L
.57937 .01956 L
.58254 .11907 L
.58571 .12291 L
.58889 .12432 L
.59206 .12557 L
.59524 .12671 L
.59841 .02539 L
.60159 .01996 L
.60476 .11947 L
.60794 .12331 L
.61111 .12472 L
.61429 .12596 L
.61746 .12711 L
.62063 .02579 L
.62381 .02036 L
.62698 .11987 L
.63016 .12371 L
.63333 .12512 L
.63651 .12637 L
.63968 .12751 L
.64286 .0262 L
.64603 .02076 L
.64921 .12028 L
.65238 .12412 L
.65556 .12553 L
Mistroke
.65873 .12677 L
.6619 .12792 L
.66508 .0266 L
.66825 .02117 L
.67143 .12068 L
.6746 .12453 L
.67778 .12594 L
.68095 .12718 L
.68413 .12832 L
.6873 .02701 L
.69048 .02158 L
.69365 .12109 L
.69683 .12493 L
.7 .12635 L
.70317 .12759 L
.70635 .12873 L
.70952 .02742 L
.7127 .02199 L
.71587 .1215 L
.71905 .12534 L
.72222 .12676 L
.7254 .128 L
.72857 .12914 L
.73175 .02783 L
.73492 .0224 L
.7381 .12191 L
.74127 .12576 L
.74444 .12717 L
.74762 .12841 L
.75079 .12956 L
.75397 .02824 L
.75714 .02281 L
.76032 .12233 L
.76349 .12617 L
.76667 .12758 L
.76984 .12882 L
.77302 .12997 L
.77619 .02866 L
.77937 .02323 L
.78254 .12274 L
.78571 .12658 L
.78889 .12799 L
.79206 .12924 L
.79524 .13038 L
.79841 .02907 L
.80159 .02364 L
.80476 .12315 L
.80794 .127 L
.81111 .12841 L
.81429 .12965 L
Mistroke
.81746 .1308 L
.82063 .02949 L
.82381 .02405 L
.82698 .12357 L
.83016 .12741 L
.83333 .12882 L
.83651 .13007 L
.83968 .13121 L
.84286 .0299 L
.84603 .02447 L
.84921 .12398 L
.85238 .12783 L
.85556 .12924 L
.85873 .13048 L
.8619 .13163 L
.86508 .03032 L
.86825 .02488 L
.87143 .1244 L
.8746 .12824 L
.87778 .12965 L
.88095 .1309 L
.88413 .13204 L
.8873 .03073 L
.89048 .0253 L
.89365 .12481 L
.89683 .12866 L
.9 .13007 L
.90317 .13131 L
.90635 .13245 L
.90952 .03115 L
.9127 .02572 L
.91587 .12523 L
.91905 .12907 L
.92222 .13048 L
.9254 .13173 L
.92857 .13287 L
.93175 .03156 L
.93492 .02613 L
.9381 .12564 L
.94127 .12949 L
.94444 .1309 L
.94762 .13214 L
.95079 .13328 L
.95397 .03197 L
.95714 .02654 L
.96032 .12606 L
.96349 .1299 L
.96667 .13131 L
.96984 .13255 L
.97302 .1337 L
Mistroke
.97619 .03239 L
Mfstroke
.18254 .57931 m
.18571 .58311 L
.18889 .58448 L
.19206 .58569 L
.19524 .58679 L
.19841 .48551 L
.20159 .48011 L
.20476 .57959 L
.20794 .5834 L
.21111 .58478 L
.21429 .58599 L
.21746 .5871 L
.22063 .48582 L
.22381 .48043 L
.22698 .57991 L
.23016 .58373 L
.23333 .58511 L
.23651 .58633 L
.23968 .58745 L
.24286 .48617 L
.24603 .48077 L
.24921 .58026 L
.25238 .58409 L
.25556 .58548 L
.25873 .5867 L
.2619 .58782 L
.26508 .48654 L
.26825 .48115 L
.27143 .58064 L
.2746 .58447 L
.27778 .58587 L
.28095 .58709 L
.28413 .58822 L
.2873 .48694 L
.29048 .48155 L
.29365 .58105 L
.29683 .58488 L
.3 .58628 L
.30317 .58751 L
.30635 .58864 L
.30952 .48736 L
.3127 .48197 L
.31587 .58147 L
.31905 .5853 L
.32222 .5867 L
.3254 .58794 L
.32857 .58907 L
.33175 .48779 L
.33492 .4824 L
.3381 .5819 L
Mistroke
.34127 .58574 L
.34444 .58714 L
.34762 .58838 L
.35079 .58952 L
.35397 .48824 L
.35714 .48285 L
.36032 .58235 L
.36349 .58619 L
.36667 .5876 L
.36984 .58884 L
.37302 .58997 L
.37619 .4887 L
.37937 .4833 L
.38254 .58281 L
.38571 .58665 L
.38889 .58806 L
.39206 .5893 L
.39524 .59044 L
.39841 .48916 L
.40159 .48377 L
.40476 .58328 L
.40794 .58712 L
.41111 .58853 L
.41429 .58977 L
.41746 .59092 L
.42063 .48964 L
.42381 .48425 L
.42698 .58376 L
.43016 .5876 L
.43333 .58901 L
.43651 .59025 L
.43968 .5914 L
.44286 .49012 L
.44603 .48473 L
.44921 .58424 L
.45238 .58808 L
.45556 .58949 L
.45873 .59074 L
.4619 .59188 L
.46508 .4906 L
.46825 .48521 L
.47143 .58473 L
.4746 .58857 L
.47778 .58998 L
.48095 .59123 L
.48413 .59237 L
.4873 .4911 L
.49048 .4857 L
.49365 .58522 L
.49683 .58906 L
Mistroke
.5 .59047 L
.50317 .59172 L
.50635 .59287 L
.50952 .49159 L
.5127 .4862 L
.51587 .58571 L
.51905 .58956 L
.52222 .59097 L
.5254 .59222 L
.52857 .59336 L
.53175 .49209 L
.53492 .48669 L
.5381 .58621 L
.54127 .59005 L
.54444 .59147 L
.54762 .59271 L
.55079 .59386 L
.55397 .49258 L
.55714 .48719 L
.56032 .58671 L
.56349 .59055 L
.56667 .59197 L
.56984 .59321 L
.57302 .59436 L
.57619 .49308 L
.57937 .48769 L
.58254 .58721 L
.58571 .59105 L
.58889 .59247 L
.59206 .59372 L
.59524 .59486 L
.59841 .49359 L
.60159 .48819 L
.60476 .58771 L
.60794 .59155 L
.61111 .59297 L
.61429 .59422 L
.61746 .59537 L
.62063 .49409 L
.62381 .48869 L
.62698 .58821 L
.63016 .59206 L
.63333 .59347 L
.63651 .59472 L
.63968 .59587 L
.64286 .49459 L
.64603 .48919 L
.64921 .58871 L
.65238 .59256 L
.65556 .59397 L
Mistroke
.65873 .59522 L
.6619 .59637 L
.66508 .49509 L
.66825 .4897 L
.67143 .58921 L
.6746 .59306 L
.67778 .59448 L
.68095 .59572 L
.68413 .59687 L
.6873 .49559 L
.69048 .4902 L
.69365 .58972 L
.69683 .59356 L
.7 .59498 L
.70317 .59623 L
.70635 .59737 L
.70952 .4961 L
.7127 .4907 L
.71587 .59022 L
.71905 .59406 L
.72222 .59548 L
.7254 .59673 L
.72857 .59788 L
.73175 .4966 L
.73492 .4912 L
.7381 .59072 L
.74127 .59457 L
.74444 .59598 L
.74762 .59723 L
.75079 .59838 L
.75397 .4971 L
.75714 .4917 L
.76032 .59122 L
.76349 .59507 L
.76667 .59648 L
.76984 .59773 L
.77302 .59888 L
.77619 .4976 L
.77937 .4922 L
.78254 .59172 L
.78571 .59556 L
.78889 .59698 L
.79206 .59823 L
.79524 .59938 L
.79841 .4981 L
.80159 .4927 L
.80476 .59221 L
.80794 .59606 L
.81111 .59748 L
.81429 .59873 L
Mistroke
.81746 .59987 L
.82063 .49859 L
.82381 .49319 L
.82698 .59271 L
.83016 .59656 L
.83333 .59797 L
.83651 .59922 L
.83968 .60037 L
.84286 .49909 L
.84603 .49369 L
.84921 .59321 L
.85238 .59705 L
.85556 .59847 L
.85873 .59972 L
.8619 .60087 L
.86508 .49958 L
.86825 .49418 L
.87143 .5937 L
.8746 .59755 L
.87778 .59896 L
.88095 .60021 L
.88413 .60136 L
.8873 .50008 L
.89048 .49468 L
.89365 .59419 L
.89683 .59804 L
.9 .59946 L
.90317 .6007 L
.90635 .60185 L
.90952 .50057 L
.9127 .49517 L
.91587 .59469 L
.91905 .59853 L
.92222 .59995 L
.9254 .60119 L
.92857 .60234 L
.93175 .50106 L
.93492 .49566 L
.9381 .59518 L
.94127 .59902 L
.94444 .60044 L
.94762 .60168 L
.95079 .60283 L
.95397 .50155 L
.95714 .49615 L
.96032 .59566 L
.96349 .59951 L
.96667 .60093 L
.96984 .60217 L
.97302 .60332 L
Mistroke
.97619 .50204 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0031746 -0.15408 44.0605 [
[.18254 .27402 -6 -9 ]
[.18254 .27402 6 0 ]
[.34127 .27402 -9 -9 ]
[.34127 .27402 9 0 ]
[.5 .27402 -9 -9 ]
[.5 .27402 9 0 ]
[.65873 .27402 -9 -9 ]
[.65873 .27402 9 0 ]
[.81746 .27402 -9 -9 ]
[.81746 .27402 9 0 ]
[.97619 .27402 -9 -9 ]
[.97619 .27402 9 0 ]
[1.025 .28652 0 -6.28125 ]
[1.025 .28652 28 6.28125 ]
[.01131 .02216 -30 -4.5 ]
[.01131 .02216 0 4.5 ]
[.01131 .11028 -30 -4.5 ]
[.01131 .11028 0 4.5 ]
[.01131 .1984 -30 -4.5 ]
[.01131 .1984 0 4.5 ]
[.01131 .37465 -30 -4.5 ]
[.01131 .37465 0 4.5 ]
[.01131 .46277 -30 -4.5 ]
[.01131 .46277 0 4.5 ]
[.01131 .55089 -30 -4.5 ]
[.01131 .55089 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .28652 m
.18254 .29277 L
s
[(50)] .18254 .27402 0 1 Mshowa
.34127 .28652 m
.34127 .29277 L
s
[(100)] .34127 .27402 0 1 Mshowa
.5 .28652 m
.5 .29277 L
s
[(150)] .5 .27402 0 1 Mshowa
.65873 .28652 m
.65873 .29277 L
s
[(200)] .65873 .27402 0 1 Mshowa
.81746 .28652 m
.81746 .29277 L
s
[(250)] .81746 .27402 0 1 Mshowa
.97619 .28652 m
.97619 .29277 L
s
[(300)] .97619 .27402 0 1 Mshowa
.125 Mabswid
.05556 .28652 m
.05556 .29027 L
s
.0873 .28652 m
.0873 .29027 L
s
.11905 .28652 m
.11905 .29027 L
s
.15079 .28652 m
.15079 .29027 L
s
.21429 .28652 m
.21429 .29027 L
s
.24603 .28652 m
.24603 .29027 L
s
.27778 .28652 m
.27778 .29027 L
s
.30952 .28652 m
.30952 .29027 L
s
.37302 .28652 m
.37302 .29027 L
s
.40476 .28652 m
.40476 .29027 L
s
.43651 .28652 m
.43651 .29027 L
s
.46825 .28652 m
.46825 .29027 L
s
.53175 .28652 m
.53175 .29027 L
s
.56349 .28652 m
.56349 .29027 L
s
.59524 .28652 m
.59524 .29027 L
s
.62698 .28652 m
.62698 .29027 L
s
.69048 .28652 m
.69048 .29027 L
s
.72222 .28652 m
.72222 .29027 L
s
.75397 .28652 m
.75397 .29027 L
s
.78571 .28652 m
.78571 .29027 L
s
.84921 .28652 m
.84921 .29027 L
s
.88095 .28652 m
.88095 .29027 L
s
.9127 .28652 m
.9127 .29027 L
s
.94444 .28652 m
.94444 .29027 L
s
.25 Mabswid
0 .28652 m
1 .28652 L
s
gsave
1.025 .28652 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .02216 m
.03006 .02216 L
s
[(0.004)] .01131 .02216 1 0 Mshowa
.02381 .11028 m
.03006 .11028 L
s
[(0.006)] .01131 .11028 1 0 Mshowa
.02381 .1984 m
.03006 .1984 L
s
[(0.008)] .01131 .1984 1 0 Mshowa
.02381 .37465 m
.03006 .37465 L
s
[(0.012)] .01131 .37465 1 0 Mshowa
.02381 .46277 m
.03006 .46277 L
s
[(0.014)] .01131 .46277 1 0 Mshowa
.02381 .55089 m
.03006 .55089 L
s
[(0.016)] .01131 .55089 1 0 Mshowa
.125 Mabswid
.02381 .04419 m
.02756 .04419 L
s
.02381 .06622 m
.02756 .06622 L
s
.02381 .08825 m
.02756 .08825 L
s
.02381 .13231 m
.02756 .13231 L
s
.02381 .15434 m
.02756 .15434 L
s
.02381 .17637 m
.02756 .17637 L
s
.02381 .22043 m
.02756 .22043 L
s
.02381 .24246 m
.02756 .24246 L
s
.02381 .26449 m
.02756 .26449 L
s
.02381 .30855 m
.02756 .30855 L
s
.02381 .33058 m
.02756 .33058 L
s
.02381 .35262 m
.02756 .35262 L
s
.02381 .39668 m
.02756 .39668 L
s
.02381 .41871 m
.02756 .41871 L
s
.02381 .44074 m
.02756 .44074 L
s
.02381 .4848 m
.02756 .4848 L
s
.02381 .50683 m
.02756 .50683 L
s
.02381 .52886 m
.02756 .52886 L
s
.02381 .00013 m
.02756 .00013 L
s
.02381 .57292 m
.02756 .57292 L
s
.02381 .59495 m
.02756 .59495 L
s
.02381 .61698 m
.02756 .61698 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bq) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 12.813 moveto
(\\220) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(day) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[36]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol0035oo`800?moogioo`00<Goo00<0
07ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`000Woo1000
1Woo0P001Woo10001Goo10001Woo10001Woo00<007ooOol0ogooOGoo00000goo001oo`03Ool00`00
Oomoo`03Ool20005Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol01Goo00<007oo
Ool01Goo00<007ooOol0>Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007oo
Ool017oo00<007ooOol0ogoo8goo00000goo001oo`03Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0>7oo0P001Woo0P00
1Goo0P001Woo0P001Goo0P001goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol0gWoo00000goo001oo`03Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo0000
17oo00@007ooOomoo`H000Ioo`03001oogoo03Qoo`8000Ioo`8000Eoo`8000Ioo`8000Eoo`8000Io
o`8000Eoo`8000Ioo`8000Eoo`8000Ioo`8000Ioo`8000Eoo`8000Ioo`8000Eoo`8000Moo`03001o
ogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001o
ogoo00Eoo`03001oogoo00Aoo`03001oogoo0:9oo`0000=oo`00Ool00goo00<007ooOol02Woo00<0
07ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`04001oogoo0007Ool3000hOol20006
Ool20005Ool20006Ool20005Ool20006Ool20005Ool20006Ool20005Ool20006Ool20005Ool00`00
0ol00005Ool20006Ool20005Ool20006Ool20005Ool20006Ool20005Ool20006Ool20005Ool20006
Ool20005Ool20007Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`1]Ool00003Ool007oo00=oo`03001oogoo
00Yoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`02Ool01000Oomoo`001goo00<0
07ooOol0>7oo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P00
1Woo0P001Goo00<000?o00001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P00
1Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P00
1Woo0P001Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol0@7oo00000goo001oo`03Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00<007ooOol00goo00<007oo00001goo00<007ooOol0>7oo0P001Woo0P00
1Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo00<000?o0000
1Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P00
1Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P00
1Woo0P001Goo0P001Woo0P001Goo0P00@Woo00000goo001oo`03Ool00`00Oomoo`0:Ool00`00Oomo
o`02Ool01@00Oomoogoo000017oo00<007ooOol00goo00<007oo00001goo00<007ooOol0>7oo0P00
1Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo00<0
00?o00001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P00
1Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P00
1Woo0P001Goo00<000?o00001Goo0P001Goo00<000?o00001Goo0P001Woo00<007ooOol0>Goo0002
Ool4000>Ool40005Ool40007Ool20007Ool00`00Oomoo`0hOol20006Ool20005Ool20006Ool20005
Ool20006Ool20005Ool20006Ool20005Ool20006Ool20005Ool00`000ol00005Ool20006Ool20005
Ool20006Ool20005Ool20006Ool20005Ool20006Ool20005Ool20006Ool20005Ool20006Ool20005
Ool20006Ool20005Ool20006Ool20005Ool20006Ool20005Ool20006Ool20005Ool00`000ol00005
Ool20005Ool00`000ol00005Ool20006Ool00`00Oomoo`0iOol0035oo`03001oogoo03Qoo`8000Io
o`8000Eoo`8000Ioo`8000Eoo`8000Ioo`8000Eoo`8000Ioo`8000Eoo`8000Ioo`8000Eoo`030003
o`0000Eoo`8000Ioo`8000Eoo`8000Ioo`8000Eoo`8000Ioo`8000Eoo`8000Ioo`8000Eoo`8000Io
o`8000Eoo`8000Ioo`8000Eoo`8000Ioo`8000Eoo`8000Ioo`8000Eoo`8000Ioo`8000Eoo`8000Io
o`8000Eoo`030003o`0000Eoo`8000Eoo`030003o`0000Eoo`8000Ioo`03001oogoo03Uoo`00<Goo
00<007ooOol0>7oo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo
0P001Woo0P001Goo00<000?o00001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo
0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo
0P001Woo0P001Goo0P001Woo0P001Goo00<000?o00001Goo0P001Goo00<000?o00001Goo0P001Woo
00<007ooOol0>Goo000aOol2000iOol20006Ool20005Ool20006Ool20005Ool20006Ool20005Ool0
0`000ol00005Ool20005Ool00`000ol00005Ool20005Ool00`000ol00005Ool20006Ool20005Ool2
0006Ool20005Ool20006Ool20005Ool20006Ool20005Ool20006Ool20005Ool20006Ool20005Ool2
0006Ool20005Ool20006Ool20005Ool20006Ool20005Ool20006Ool20005Ool00`000ol00005Ool2
0005Ool00`000ol00005Ool20006Ool00`00Oomoo`0iOol0035oo`03001oogoo03Qoo`8000Ioo`80
00Eoo`8000Ioo`8000Eoo`8000Ioo`8000Eoo`030003o`0000Eoo`8000Eoo`030003o`0000Eoo`80
00Eoo`030003o`0000Eoo`8000Ioo`8000Eoo`8000Ioo`8000Eoo`8000Ioo`8000Eoo`8000Ioo`80
00Eoo`8000Ioo`8000Eoo`8000Ioo`8000Eoo`8000Ioo`8000Eoo`8000Ioo`8000Eoo`8000Ioo`80
00Eoo`8000Ioo`8000Eoo`030003o`0000Eoo`8000Eoo`030003o`0000Eoo`8000Ioo`03001oogoo
03Uoo`00<Goo00<007ooOol0>7oo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo00<0
00?o00001Goo0P001Goo00<000?o00001Goo0P001Goo00<000?o00001Goo0P001Goo00<000?o0000
1Goo0P001Goo00<000?o00001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P00
1Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo00<000?o00001Goo0P001Goo0P001Woo0P00
1Goo00<000?o00001Goo0P001Goo00<000?o00001Goo0P001Woo00<007ooOol0>Goo000aOol00`00
Oomoo`0hOol20006Ool20005Ool20006Ool20005Ool20006Ool20005Ool00`000ol00005Ool20005
Ool00`000ol00005Ool20005Ool00`000ol00005Ool20005Ool00`000ol00005Ool20005Ool00`00
0ol00005Ool20006Ool20005Ool20006Ool20005Ool20006Ool20005Ool20006Ool20005Ool20006
Ool20005Ool20006Ool20005Ool00`000ol00005Ool20005Ool00`000ol00005Ool20005Ool00`00
0ol00005Ool20005Ool00`000ol00005Ool20006Ool00`00Oomoo`0iOol0035oo`03001oogoo03Qo
o`8000Ioo`8000Eoo`8000Ioo`8000Eoo`8000Ioo`8000Eoo`030003o`0000Eoo`8000Eoo`030003
o`0000Eoo`8000Eoo`030003o`0000Eoo`8000Eoo`030003o`0000Eoo`8000Eoo`030003o`0000Eo
o`8000Ioo`8000Eoo`8000Ioo`8000Eoo`8000Ioo`8000Eoo`8000Ioo`8000Eoo`8000Ioo`8000Eo
o`8000Ioo`8000Eoo`030003o`0000Eoo`8000Eoo`030003o`0000Eoo`8000Eoo`030003o`0000Eo
o`8000Eoo`030003o`0000Eoo`8000Ioo`03001oogoo03Uoo`00<Goo00<007ooOol0>7oo0P001Woo
0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo00<000?o00001Goo0P001Goo00<000?o00001Goo
0P001Goo00<000?o00001Goo0P001Goo00<000?o00001Goo0P001Goo00<000?o00001Goo0P001Woo
0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo
0P001Goo00<000?o00001Goo0P001Goo00<000?o00001Goo0P001Goo00<000?o00001Goo0P001Goo
00<000?o00001Goo0P001Goo00<007ooOol0>Woo000aOol00`00Oomoo`0hOol20006Ool20005Ool2
0006Ool20005Ool20006Ool20005Ool00`000ol00005Ool20005Ool00`000ol00005Ool20005Ool0
0`000ol00005Ool20005Ool00`000ol00005Ool20005Ool00`000ol00005Ool20006Ool20005Ool2
0006Ool20005Ool20006Ool20005Ool20006Ool20005Ool20006Ool20005Ool20006Ool20005Ool0
0`000ol00005Ool20005Ool00`000ol00005Ool20005Ool00`000ol00005Ool20005Ool00`000ol0
0005Ool20005Ool00`00Oomoo`0jOol0035oo`03001oogoo03Qoo`8000Ioo`8000Eoo`8000Ioo`80
00Eoo`8000Ioo`8000Eoo`030003o`0000Eoo`8000Eoo`030003o`0000Eoo`8000Eoo`030003o`00
00Eoo`8000Eoo`030003o`0000Eoo`8000Eoo`030003o`0000Eoo`8000Ioo`8000Eoo`8000Ioo`80
00Eoo`8000Ioo`8000Eoo`8000Ioo`8000Eoo`8000Ioo`8000Eoo`8000Ioo`8000Eoo`030003o`00
00Eoo`8000Eoo`030003o`0000Eoo`8000Eoo`030003o`0000Eoo`8000Eoo`030003o`0000Eoo`80
00Eoo`03001oogoo03Yoo`00<Goo0P00>Goo00<000?o00001Goo00<000?o000017oo00<000?o0000
1Goo00<000?o000017oo00<000?o00001Goo00<000?o000017oo00<000?o00001Goo00<000?o0000
17oo00<000?o00001Goo0P001Goo00<000?o00001Goo0P001Goo00<000?o00001Goo0P001Goo00<0
00?o00001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P001Woo0P001Goo0P00
1Woo0P001Goo0P001Woo0P001Goo00<000?o00001Goo0P001Goo00<000?o00001Goo0P001Goo00<0
00?o00001Goo0P001Goo00<000?o00001Goo0P001Goo00<007ooOol0>Woo000aOol00`00Oomoo`0g
Ool010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0005Ool00`000ol00004Ool00`000ol0
0005Ool00`000ol00004Ool00`000ol00005Ool00`000ol00004Ool00`000ol00005Ool00`000ol0
0004Ool010000ol3o`0017oo00<000?o000017oo00@000?o0ol000Aoo`030003o`0000Aoo`040003
o`?o0004Ool00`000ol00005Ool00`000ol00004Ool20006Ool20005Ool20006Ool20005Ool20006
Ool20005Ool20006Ool20005Ool20006Ool20005Ool00`000ol00005Ool20005Ool00`000ol00005
Ool20005Ool00`000ol00005Ool20005Ool00`000ol00005Ool20005Ool00`00Oomoo`0jOol0035o
o`03001oogoo03Moo`040003o`?o0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o
0003Ool010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`000goo00@0
00?o0ol000Aoo`040003o`?o0003Ool01@000ol3o`?o00000goo00@000?o0ol000Aoo`040003o`?o
0004Ool00`000ol00004Ool010000ol3o`0017oo00<000?o00001Goo00<000?o000017oo00<000?o
00001Goo00<000?o000017oo00<000?o00001Goo00<000?o000017oo00<000?o00001Goo00<000?o
000017oo00<000?o00001Goo0P001Goo0P001Woo0P001Goo00<000?o00001Goo0P001Goo00<000?o
00001Goo0P001Goo00<000?o00001Goo0P001Goo00<000?o00001Goo0P001Goo00<007ooOol0>Woo
000aOol00`00Oomoo`0gOol010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool01000
0ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo00@000?o0ol000=o
o`040003o`?o0004Ool010000ol3o`000goo00D000?o0ol3o`0000=oo`040003o`?o0004Ool01000
0ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo00@000?o0ol000=o
o`040003o`?o0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o0004Ool00`000ol0
0005Ool00`000ol00004Ool00`000ol00005Ool00`000ol00004Ool00`000ol00005Ool00`000ol0
0004Ool00`000ol00005Ool00`000ol00004Ool00`000ol00005Ool00`000ol00004Ool00`000ol0
0005Ool20005Ool00`000ol00005Ool20005Ool00`00Oomoo`0jOol0035oo`03001oogoo03Moo`04
0003o`?o0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`00
17oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003
o`?o0003Ool01@000ol3o`?o00000goo00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`00
17oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003
o`?o0003Ool010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`000goo
00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o
0005Ool00`000ol00004Ool00`000ol00005Ool00`000ol00004Ool010000ol3o`0017oo00<000?o
000017oo00@000?o0ol000Aoo`030003o`0000Aoo`03001oogoo03Yoo`00<Goo00<007ooOol0=goo
00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o
0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo00@0
00?o0ol000=oo`050003o`?o0ol00003Ool010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o
0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo00@0
00?o0ol000=oo`040003o`?o0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003
Ool010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`000goo00@000?o
0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo00@000?o0ol000=oo`050003o`?o0ol00003
Ool010000ol3o`000goo00D000?o0ol3o`0000=oo`040003o`?o0004Ool00`00Oomoo`0jOol0035o
o`03001oogoo03Moo`040003o`?o0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o
0003Ool010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`000goo00@0
00?o0ol000Aoo`040003o`?o0003Ool01@000ol3o`?o00000goo00@000?o0ol000Aoo`040003o`?o
0003Ool010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`000goo00@0
00?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004
Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo00@000?o
0ol000=oo`040003o`?o0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool0
1@000ol3o`?o00000goo00@000?o0ol000=oo`050003o`?o0ol00003Ool010000ol3o`0017oo00<0
07ooOol0>Woo000aOol2000hOol010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool0
10000ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo00@000?o0ol0
00=oo`040003o`?o0004Ool010000ol3o`000goo00D000?o0ol3o`0000=oo`040003o`?o0004Ool0
10000ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo00@000?o0ol0
00=oo`040003o`?o0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool01000
0ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`000goo00@000?o0ol000Ao
o`040003o`?o0003Ool010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3
o`000goo00D000?o0ol3o`0000=oo`040003o`?o0003Ool01@000ol3o`?o00000goo00@000?o0ol0
00Aoo`03001oogoo03Yoo`00<Goo00<007ooOol0=goo00@000?o0ol000Aoo`040003o`?o0003Ool0
10000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`000goo00D000?o0ol3
o`0000=oo`040003o`?o0003Ool01@000ol3o`?o00000goo00@000?o0ol000=oo`050003o`?o0ol0
0003Ool010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`000goo00@0
00?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004
Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo00@000?o
0ol000=oo`040003o`?o0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool0
10000ol3o`0017oo00@000?o0ol000=oo`050003o`?o0ol00003Ool010000ol3o`000goo00D000?o
0ol3o`0000=oo`040003o`?o0004Ool00`00Oomoo`0jOol0035oo`03001oogoo03Moo`040003o`?o
0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo00@0
00?o0ol000=oo`050003o`?o0ol00003Ool010000ol3o`000goo00D000?o0ol3o`0000=oo`040003
o`?o0003Ool01@000ol3o`?o00000goo00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`00
17oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003
o`?o0003Ool010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`000goo
00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o
0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool01@000ol3o`?o00000goo
00@000?o0ol000=oo`050003o`?o0ol00003Ool010000ol3o`0017oo00<007ooOol0>Woo000aOol0
0`00Oomoo`0gOol010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`00
0goo00@000?o0ol000Aoo`040003o`?o0003Ool01@000ol3o`?o00000goo00@000?o0ol000=oo`05
0003o`?o0ol00003Ool010000ol3o`000goo00D000?o0ol3o`0000=oo`040003o`?o0004Ool01000
0ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo00@000?o0ol000=o
o`040003o`?o0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3
o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`000goo00@000?o0ol000Aoo`04
0003o`?o0003Ool010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`00
0goo00D000?o0ol3o`0000=oo`040003o`?o0003Ool01@000ol3o`?o00000goo00@000?o0ol000Ao
o`03001oogoo03Yoo`000Woo10001Woo0P001Woo10001Goo10001Woo10001Woo00<007ooOol0=goo
00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o
0004Ool010000ol3o`000goo00D000?o0ol3o`0000=oo`040003o`?o0003Ool01@000ol3o`?o0000
0goo00@000?o0ol000=oo`050003o`?o0ol00003Ool010000ol3o`000goo00D000?o0ol3o`0000=o
o`040003o`?o0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3
o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`000goo00@000?o0ol000Aoo`04
0003o`?o0003Ool010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`00
0goo00D000?o0ol3o`0000=oo`040003o`?o0003Ool01@000ol3o`?o00000goo00@000?o0ol000=o
o`050003o`?o0ol00003Ool010000ol3o`000goo00D000?o0ol3o`0000=oo`040003o`?o0004Ool0
0`00Oomoo`0jOol00003Ool007oo00=oo`03001oogoo00=oo`8000Eoo`03001oogoo009oo`05001o
ogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0gOol0
10000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`000goo00@000?o0ol0
00Aoo`040003o`?o0003Ool01@000ol3o`?o00000goo00@000?o0ol000=oo`050003o`?o0ol00003
Ool010000ol3o`000goo00D000?o0ol3o`0000=oo`040003o`?o0003Ool01@000ol3o`?o00000goo
00@000?o0ol000=oo`050003o`?o0ol00003Ool010000ol3o`0017oo00@000?o0ol000=oo`040003
o`?o0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo
00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o
0003Ool01@000ol3o`?o00000goo00@000?o0ol000=oo`050003o`?o0ol00003Ool010000ol3o`00
0goo00D000?o0ol3o`0000=oo`040003o`?o0003Ool01@000ol3o`?o00000goo00@000?o0ol000Ao
o`03001oogoo03Yoo`0000=oo`00Ool00goo00<007ooOol02Woo00<007ooOol00Woo00D007ooOomo
o`0000Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo03Moo`040003
o`?o0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo
00@000?o0ol000=oo`050003o`?o0ol00003Ool010000ol3o`000goo00D000?o0ol3o`0000=oo`04
0003o`?o0003Ool01@000ol3o`?o00000goo00@000?o0ol000=oo`050003o`?o0ol00003Ool01000
0ol3o`000goo00D000?o0ol3o`0000=oo`040003o`?o0004Ool010000ol3o`000goo00@000?o0ol0
00Aoo`040003o`?o0003Ool010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool01000
0ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo00@000?o0ol000=o
o`050003o`?o0ol00003Ool010000ol3o`000goo00D000?o0ol3o`0000=oo`040003o`?o0003Ool0
1@000ol3o`?o00000goo00@000?o0ol000=oo`050003o`?o0ol00003Ool010000ol3o`0017oo00<0
07ooOol0>Woo00000goo001oo`03Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo0000
17oo00<007ooOol00Woo0P000goo00<007ooOol00goo00<007ooOol0=goo00@000?o0ol000Aoo`04
0003o`?o0003Ool010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`00
0goo00D000?o0ol3o`0000=oo`040003o`?o0003Ool01@000ol3o`?o00000goo00@000?o0ol000=o
o`050003o`?o0ol00003Ool010000ol3o`000goo00D000?o0ol3o`0000=oo`040003o`?o0003Ool0
1@000ol3o`?o00000goo00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo00@000?o
0ol000=oo`040003o`?o0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool0
10000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`000goo00D000?o0ol3
o`0000=oo`040003o`?o0003Ool01@000ol3o`?o00000goo00@000?o0ol000=oo`050003o`?o0ol0
0003Ool010000ol3o`000goo00D000?o0ol3o`0000=oo`040003o`?o0004Ool00`00Oomoo`0jOol0
0003Ool007oo00=oo`03001oogoo00Yoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomo
o`02Ool00`00Ool000020006Ool3000gOol010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o
0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool01@000ol3o`?o00000goo
00@000?o0ol000=oo`050003o`?o0ol00003Ool010000ol3o`000goo00D000?o0ol3o`0000=oo`04
0003o`?o0003Ool01@000ol3o`?o00000goo00@000?o0ol000=oo`050003o`?o0ol00003Ool01000
0ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`000goo00@000?o0ol000Ao
o`040003o`?o0003Ool010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3
o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool01@000ol3o`?o00000goo00@000?o0ol000=o
o`050003o`?o0ol00003Ool010000ol3o`000goo00D000?o0ol3o`0000=oo`040003o`?o0003Ool0
1@000ol3o`?o00000goo00@000?o0ol000=oo`030003ogoo03]oo`0000=oo`00Ool00goo00<007oo
Ool02Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo00Qoo`03
001oogoo03=oo`05001oogooOol000020ol00`00Oomoo`02Ool010000ol3o`000goo00@000?o0ol0
00Aoo`040003o`?o0003Ool010000ol3o`0017oo00@000?o0ol000=oo`050003o`?o0ol00003Ool0
10000ol3o`000goo00D000?o0ol3o`0000=oo`040003o`?o0003Ool01@000ol3o`?o00000goo00@0
00?o0ol000=oo`050003o`?o0ol00003Ool010000ol3o`000goo00D000?o0ol3o`0000=oo`040003
o`?o0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo
00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o
0003Ool010000ol3o`0017oo00@000?o0ol000=oo`050003o`?o0ol00003Ool010000ol3o`000goo
00D000?o0ol3o`0000=oo`040003o`?o0003Ool01@000ol3o`?o00000goo00@000?o0ol000=oo`05
0003o`?o0ol00003Ool010000ol3o`000goo00<000?oOol0>goo00000goo001oo`03Ool00`00Oomo
o`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol00goo00<007ooOol01goo00<0
07ooOol0<goo00D3o`00Oomoo`0000<3o`05001oogooOol000030ol01000Oomoo`000`?o00D007oo
Oomoo`0000<3o`04001oogoo00030ol20002Ool01@000ol3o`?o00000Woo00D000?o0ol3o`0000=o
o`040003o`?o0003Ool01@000ol3o`?o00000goo00@000?o0ol000=oo`050003o`?o0ol00003Ool0
10000ol3o`000goo00D000?o0ol3o`0000=oo`040003o`?o0003Ool01@000ol3o`?o00000goo00@0
00?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004
Ool010000ol3o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo00@000?o
0ol000=oo`040003o`?o0004Ool010000ol3o`000goo00D000?o0ol3o`0000=oo`040003o`?o0003
Ool01@000ol3o`?o00000goo00@000?o0ol000=oo`050003o`?o0ol00003Ool010000ol3o`000goo
00D000?o0ol3o`0000=oo`040003o`?o0003Ool00`000omoo`0kOol00003Ool007oo00=oo`03001o
ogoo00Yoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`06Ool0
0`00Oomoo`0cOol20ol300040ol400040ol300040ol400040ol300050ol300040ol300040ol40003
0ol200000goo0003o`030ol200000goo0003o`020ol200000goo0003o`030ol200000goo0003o`02
0ol01000Oomoo`0010?o00@007ooOol000<3o`04001oogoo00030ol01@00Oomoogoo00000P?o00<0
07ooOol00Woo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3o`000goo00@000?o0ol000Ao
o`040003o`?o0003Ool010000ol3o`0017oo00@000?o0ol000=oo`040003o`?o0004Ool010000ol3
o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool01@000ol3o`?o00000goo00@000?o0ol000=o
o`050003o`?o0ol00003Ool010000ol3o`000goo00D000?o0ol3o`0000=oo`040003o`?o0003Ool0
1@000ol3o`?o00000goo00@000?o0ol000=oo`030003ogoo03]oo`000Woo10003Woo10001Goo1000
27oo0`001Goo00<007ooOol0<goo6`?o00<000?o0ol010?o00<000?o0ol01@?o00<000?o0ol010?o
00<000?o0ol01@?o00<000?o0ol00`?o0P001P?o0P001@?o0P001P?o0P0010?o0`001@?o0`0010?o
0`0010?o10000`?o0P000Woo00@000?o0ol3o`800003Ool000?o0083o`80009oo`050003o`?o0ol0
0002Ool01@000ol3o`?o00000goo00D000?o0ol3o`00009oo`050003o`?o0ol00003Ool010000ol3
o`000goo00@000?o0ol000Aoo`040003o`?o0003Ool010000ol3o`0017oo00@000?o0ol000=oo`05
0003o`?o0ol00003Ool010000ol3o`000goo00D000?o0ol3o`0000=oo`040003o`?o0003Ool01@00
0ol3o`?o00000goo00@000?o0ol000=oo`050003o`?o0ol00003Ool010000ol3o`000goo00<000?o
Ool0>goo000aOol00`00Oomoo`0cOomV0ol00`000ol3o`040ol00`000ol3o`050ol00`000ol3o`03
0ol300050ol200050ol300040ol300040ol400040ol300040ol400030ol400030ol300000goo0003
o`020ol200000goo0003o`020ol300000goo0003o`020ol01000Oomoo`0010?o00@007ooOol000<3
o`04001oogoo00030ol01@00Oomoogoo00000P?o00D007ooOomoo`0000<3o`05001oogooOol00002
0ol01@00Oomoogoo00000`?o00D007ooOomoo`000083o`06001oogooOol000?o?7oo000aOol00`00
Oomoo`0cOonR0ol00`000ol3o`050ol00`000ol3o`040ol00`000ol3o`040ol200050ol200060ol2
00040ol300050ol300040ol300040ol400030ol200000goo0003o`030ol200000goo0003o`020ol2
00000goo0003o`030ol01000Oomoo`000`?o00D007ooOol000?o03aoo`00<Goo0P00=7ooe`?o00<0
00?o0ol010?o00<000?o0ol01@?o00<000?o0ol00`?o0P001P?o0P001@?o0P001@?o0`0010?o0`00
00<3ogooOol0>Woo000aOol00`00Oomoo`0cOooo0ol<0ol00`000omoo`0kOol0035oo`03001oogoo
03=oool3o`h3ocaoo`00<Goo00<007ooOol0<gooo`?o3P?o?7oo000aOol00`00Oomoo`0cOooo0ol>
0ollOol0035oo`03001oogoo03=oool3o`h3ocaoo`00<Goo00<007ooOol0<gooo`?o3P?o?7oo000a
Ool00`00Oomoo`0cOooo0ol>0ollOol0035oo`8003Aoool3o`h3ocaoo`00<Goo00<007ooOol0<goo
o`?o3P?o?7oo000aOol00`00Oomoo`0cOooo0ol>0ollOol0035oo`03001oogoo03=oool3o`h3ocao
o`00<Goo00<007ooOol0<gooo`?o3P?o?7oo000aOol00`00Oomoo`0cOooo0ol>0ollOol0035oo`03
001oogoo03=oool3o`h3ocaoo`00<Goo0P00=7ooo`?o3P?o?7oo000aOol00`00Oomoo`0cOooo0ol>
0ollOol0035oo`03001oogoo03=oool3o`h3ocaoo`00<Goo00<007ooOol0<gooo`?o3P?o?7oo0002
Ool40006Ool20006Ool40005Ool40005Ool40007Ool00`00Oomoo`0cOooo0ol>0ollOol00003Ool0
07oo00=oo`03001oogoo00=oo`8000Eoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomo
ogoo000017oo00<007ooOol017oo00<007ooOol0<gooo`?o3P?o?7oo00000goo001oo`03Ool00`00
Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo
00Aoo`03001oogoo03=oool3o`h3ocaoo`0000=oo`00Ool00goo00<007ooOol02Woo00<007ooOol0
0Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool3000cOooo0ol>0oll
Ool00003Ool007oo00=oo`03001oogoo00Yoo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`02Ool40007Ool00`00Oomoo`0cOooo0ol>0ollOol00003Ool007oo00=oo`03001oogoo00Yo
o`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol017oo00<0
07ooOol0<gooo`?o3P?o?7oo00000goo001oo`03Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01@00
Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo03=oool3o`h3ocao
o`0000=oo`00Ool00goo00<007ooOol02Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001o
ogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`0cOooo0ol>0ollOol0009oo`@000ioo`@000Eo
o`@000Eoo`@000Moo`03001oogoo03=oool3o`h3ocaoo`00<Goo00<007ooOol0<gooo`?o3P?o?7oo
000aOol00`00Oomoo`0cOooo0ol>0ollOol0035oo`8003Aoool3o`h3ocaoo`00<Goo00<007ooOol0
<gooo`?o3P?o?7oo000aOol00`00Oomoo`0cOooo0ol>0ollOol0035oo`03001oogoo03=oool3o`h3
ocaoo`00<Goo00<007ooOol0<gooo`?o3P?o?7oo000aOol00`00Oomoo`0cOooo0ol>0ollOol0035o
o`03001oogoo02aoo`@000=oo`83o`@002<3o`L000<3o`@000D3o`@001l3o`L000<3o`@000D3o`@0
01l3o`H000@3o`@000D3o`@001h3o`H000@3o`@000D3o`@00203o`@000D3o`@000Eoo`@0039oo`00
<Goo0P00;7oo00<007ooOol00Woo00D007ooOol3o`0000@3o`030003o`?o02<3o`030003o`?o00<3
o`030003o`?o0083o`050003o`?o0ol000040ol00`000ol3o`0O0ol00`000ol3o`030ol00`000ol3
o`020ol01@000ol3o`?o000010?o00<000?o0ol070?o00<000?o0ol00P?o00D000?o0ol3o`0000@3
o`050003o`?o0ol000040ol00`000ol3o`0K0ol00`000ol3o`020ol01@000ol3o`?o000010?o00D0
00?o0ol3o`0000@3o`030003o`?o01`3o`030003o`?o0083o`050003o`?o0ol000030ol00goo001o
o`02Ool00`00Oomoo`02Ool00`00Oomoo`0_Ool0035oo`03001oogoo031oo`05001oogoo0ol00004
0ol00`000ol3o`0S0ol00`000ol3o`030ol00`000ol3o`020ol01@000ol3o`?o000010?o00<000?o
0ol07`?o00<000?o0ol020?o00D000?o0ol3o`0000@3o`030003o`?o01d3o`030003o`?o00D3o`03
0003o`?o0083o`050003o`?o0ol000040ol00`000ol3o`0L0ol00`000ol3o`0:0ol01@000ol3o`?o
000010?o00<000?o0ol08@?o00D000?o0ol3o`0000<3o`03Ool007oo009oo`03001oogoo009oo`03
001oogoo02moo`00<Goo00<007ooOol0<7oo00D007ooOol3o`0000@3o`030003o`?o02<3o`030003
o`?o00<3o`030003o`?o0083o`050003o`?o0ol000040ol00`000ol3o`0O0ol00`000ol3o`080ol0
1@000ol3o`?o000010?o00<000?o0ol07P?o00<000?o0ol010?o00<000?o0ol00P?o00D000?o0ol3
o`0000@3o`030003o`?o01d3o`030003o`?o00T3o`050003o`?o0ol000040ol00`000ol3o`0Q0ol0
1@000ol3o`?o00000`?o00=oo`00Ool00Woo00<007ooOol00Woo00<007ooOol0;goo000aOol00`00
Oomoo`0`Ool01@00Oomoo`?o000010?o00<000?o0ol08`?o00<000?o0ol00`?o00<000?o0ol00P?o
00D000?o0ol3o`0000@3o`030003o`?o01l3o`030003o`?o00P3o`050003o`?o0ol000040ol00`00
0ol3o`0O0ol00`000ol3o`030ol00`000ol3o`020ol01@000ol3o`?o000010?o00<000?o0ol07P?o
00<000?o0ol020?o00D000?o0ol3o`0000@3o`030003o`?o01l3o`8000@3o`060003o`?o0omoo`00
0goo00<007ooOol00Woo00<007ooOol0;goo000aOol00`00Oomoo`0/Ool40003Ool00`?o0003o`03
0ol00`000ol3o`0S0ol00`000ol3o`030ol00`000ol3o`020ol01@000ol3o`?o000010?o00<000?o
0ol07`?o00<000?o0ol010?o100010?o00<000?o0ol00P?o00<000?o0ol080?o00<000?o0ol00P?o
00<000?o0ol00P?o00D000?o0ol3o`0000@3o`030003o`?o01l3o`030003o`?o00<3o`@000@3o`03
0003o`?o0083o`030003o`?o0243o`050003o`?o0ol000030ol00goo001oo`02Ool00`00Oomoo`02
Ool00`00Oomoo`0_Ool0035oo`03001oogoo02aoo`03001oogoo00Aoo`030ol000?o00<3o`030003
o`?o02<3o`030003o`?o00<3o`030003o`?o0083o`050003o`?o0ol000040ol00`000ol3o`0O0ol0
0`000ol3o`040ol00`000ol3o`050ol00`000ol3o`020ol00`000ol3o`0L0ol00`000ol3o`020ol0
1@000ol3o`?o000010?o00D000?o0ol3o`0000@3o`030003o`?o01/3o`030003o`?o0083o`030003
o`?o0083o`030003o`?o00D3o`030003o`?o0083o`030003o`?o0243o`050003o`?o0ol000030ol0
0goo001oo`02Ool00`00Oomoo`02Ool00`00Oomoo`0_Ool0035oo`03001oogoo02aoo`03001oogoo
00Aoo`030ol000?o00<3o`030003o`?o0243o`<000D3o`030003o`?o0083o`050003o`?o0ol00004
0ol00`000ol3o`0M0ol300060ol00`000ol3o`050ol00`000ol3o`020ol00`000ol3o`0L0ol00`00
0ol3o`020ol01@000ol3o`?o000010?o00D000?o0ol3o`0000@3o`030003o`?o01/3o`030003o`?o
0083o`030003o`?o0083o`030003o`?o00D3o`030003o`?o0083o`030003o`?o01`3o`030003o`?o
0083o`050003o`?o0ol000030ol00goo001oo`02Ool00`00Oomoo`02Ool00`00Oomoo`0_Ool0035o
o`03001oogoo02aoo`D0009oo`83o`@002H3o`030003o`?o00@3o`@000D3o`@00283o`030003o`?o
00@3o`D000@3o`@00203o`@000D3o`@000D3o`@001l3o`@000D3o`D000@3o`@00203o`@000D3o`@0
00Eoo`@0039oo`00<Goo0P00=7ooo`?o3P?o?7oo000aOol00`00Oomoo`0cOooo0ol>0olWOol3000B
Ool0035oo`03001oogoo03=oool3o`h3obUoo`03001oogoo011oo`00<Goo00<007ooOol0<gooo`?o
3P?o:Goo00<007ooOol047oo000aOol00`00Oomoo`0cOooo0ol>0olEOol300000goo00000004Ool5
0005Ool20005Ool50007Ool0035oo`03001oogoo03=oool3o`h3oaAoo`04001oogooOol20004Ool0
1@00Oomoogoo00001Woo0P001Goo00<007ooOol00Woo00<007ooOol017oo000aOol00`00Oomoo`0c
Oooo0ol>0olDOol00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00001Goo00@007ooOol0
00Uoo`03001oogoo00Aoo`00:Gooo`00E@002goo00<007ooOol00Woo00<007ooOol00goo10001Goo
00@007ooOol000Eoo`@000Moo`00<Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo
00<007ooOol027oo00<007ooOol027oo00<000?o0ol020?o00<000?o0ol01`?o00<000?o0ol020?o
00<000?o0ol020?o00<000?o0ol020?o00<000?o0ol01`?o00<000?o0ol020?o00<000?o0ol020?o
00<000?o0ol020?o00<000?o0ol01`?o00<000?o0ol020?o00<000?o0ol020?o00<000?o0ol020?o
00<000?o0ol01`?o00<000?o0ol020?o00<000?o0ol020?o00<000?o0ol020?o00<000?o0ol01`?o
00<000?o0ol020?o00<000?o0ol020?o00<000?o0ol020?o00<000?o0ol01`?o00<000?o0ol020?o
00<000?o0ol020?o00<000?o0ol020?o00<007ooOol04Goo00@007ooOomoo`8000Aoo`05001oogoo
Ool00004Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo000aOol00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`000ol3
o`080ol00`000ol3o`070ol00`000ol3o`080ol00`000ol3o`080ol00`000ol3o`080ol00`000ol3
o`070ol00`000ol3o`080ol00`000ol3o`080ol00`000ol3o`080ol00`000ol3o`070ol00`000ol3
o`080ol00`000ol3o`080ol00`000ol3o`080ol00`000ol3o`070ol00`000ol3o`080ol00`000ol3
o`080ol00`000ol3o`080ol00`000ol3o`070ol00`000ol3o`080ol00`000ol3o`080ol00`000ol3
o`080ol00`000ol3o`070ol00`000ol3o`080ol00`000ol3o`080ol00`000ol3o`080ol00`00Oomo
o`0BOol300000goo001oo`04Ool30004Ool30002Ool30003Ool50006Ool0035oo`03001oogoo03=o
ool3o`h3oaUoo`03001oogoo021oo`00<Goo00<007ooOol0<gooo`?o3P?o6Goo00<007ooOol087oo
000aOol00`00Oomoo`0cOooo0ol>0olHOol2000ROol0035oo`03001oogoo03=oool3o`h3ocaoo`00
<Goo00<007ooOol0<gooo`?o3P?o?7oo000aOol2000dOooo0ol>0ollOol0035oo`03001oogoo03=o
ool3o`h3ocaoo`00<Goo00<007ooOol0<gooo`?o3P?o?7oo000aOol00`00Oomoo`0cOooo0ol>0oll
Ool0035oo`03001oogoo03=oool3o`h3ocaoo`00<Goo00<007ooOol0<gooo`?o3P?o?7oo000aOol0
0`00Oomoo`0cOooo0ol>0ollOol0035oo`8003Aoool3o`h3ocaoo`00<Goo00<007ooOol0<gooo`?o
3P?o?7oo000aOol00`00Oomoo`0cOooo0ol>0ollOol0035oo`03001oogoo03=oool3o`h3ocaoo`00
<Goo00<007ooOol0<gooo`?o3P?o?7oo000aOol00`00Oomoo`0cOooo0ol>0ollOol0035oo`03001o
ogoo03=oool3o`h3ocaoo`00<Goo00<007ooOol0<gooo`?o3P?o?7oo000aOol2000dOooo0ol>0oll
Ool0035oo`03001oogoo03=oool3o`h3ocaoo`00<Goo00<007ooOol0<gooo`?o3P?o?7oo000aOol0
0`00Oomoo`0cOooo0ol>0ollOol0009oo`@000Ioo`8000Ioo`@000Aoo`L0009oo`H000Ioo`03001o
ogoo03=oool3o`h3ocaoo`0000=oo`00Ool00goo00<007ooOol00goo0P001Goo00<007ooOol00Woo
00<007ooOol017oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0<goo
o`?o3P?o?7oo00000goo001oo`03Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0cOooo0ol>0ollOol00003Ool007oo00=oo`03
001oogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Moo`<0
03=oool3o`h3ocaoo`0000=oo`00Ool00goo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol0
17oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0<gooo`?o3P?o?7oo00000goo001oo`03
Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`05
Ool00`00Oomoo`0cOooo0ol>0ollOol00003Ool007oo00=oo`03001oogoo00Yoo`03001oogoo009o
o`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=o
ool3o`h3ocaoo`0000=oo`00Ool00goo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol00Woo
0`001Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0<gooo`?o3P?o?7oo0002Ool4000>
Ool40007Ool00`00Oomoo`04Ool40007Ool00`00Oomoo`0cOooo0ol>0ollOol0035oo`03001oogoo
03=oool3o`h3ocaoo`00<Goo00<007ooOol0<gooo`?o3P?o?7oo000aOol2000dOooo0ol>0ollOol0
035oo`03001oogoo03=oool3o`h3ocaoo`00<Goo00<007ooOol0<gooo`?o3P?o?7oo000aOol00`00
Oomoo`0cOooo0ol>0ollOol0035oo`03001oogoo03=oool3o`h3ocaoo`00<Goo00<007ooOol0<goo
o`?o3P?o?7oo000aOol00`00Oomoo`0cOooo0ol>0ollOol0035oo`8003Aoool3o`h3ocaoo`00<Goo
00<007ooOol0<gooo`?o3P?o?7oo000aOol00`00Oomoo`0cOooo0ol>0ollOol0035oo`03001oogoo
03=oool3o`h3ocaoo`00<Goo00<007ooOol0<gooo`?o3P?o?7oo000aOol00`00Oomoo`0cOooo0ol>
0ollOol0035oo`03001oogoo03=oool3o`h3ocaoo`00<Goo00<007ooOol0<gooo`?o3P?o?7oo000a
Ool2000dOooo0ol>0ollOol0035oo`03001oogoo03=oool3o`h3ocaoo`00<Goo00<007ooOol0<goo
o`?o3P?o?7oo0002Ool40006Ool20006Ool40004Ool70004Ool40006Ool00`00Oomoo`0cOooo0ol>
0ollOol00003Ool007oo00=oo`03001oogoo00=oo`8000Eoo`03001oogoo009oo`03001oogoo00Ao
o`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo03=oool3o`h3ocaoo`0000=oo`00Ool00goo
00<007ooOol02Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol01goo00<007ooOol01Goo
00<007ooOol0<gooo`?o3P?o?7oo00000goo001oo`03Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool60006Ool00`00Oomoo`0cOooo0ol>0ollOol00003Ool007oo
00=oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo
0007Ool3000cOooo0ol>0ollOol00003Ool007oo00=oo`03001oogoo00Yoo`03001oogoo009oo`03
001oogoo00Aoo`03001oogoo00Aoo`04001oogoo0007Ool00`00Oomoo`0cOooo0ol>0ollOol00003
Ool007oo00=oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Eoo`03
001oo`0000Moo`03001oogoo03=oool3o`h3ocaoo`0000=oo`00Ool00goo00<007ooOol02Woo00<0
07ooOol00Woo00<007ooOol00Woo0`001goo00<007oo00001goo00<007ooOol0<gooo`?o3P?o?7oo
0002Ool4000>Ool40007Ool00`00Oomoo`06Ool20007Ool00`00Oomoo`0cOooo0ol>0ollOol0035o
o`03001oogoo03=oool3o`h3ocaoo`00<Goo00<007ooOol0<goo1P?o00<000?o0ol01@?o00<000?o
0ol010?o00<000?o0ol01@?o00<000?o0ol010?o00<000?o0ol01@?o00<000?o0ol0gP?o?7oo000a
Ool2000dOol50ol200060ol200050ol200060ol200050ol200060ol200060ol00`000ol3o`050ol0
0`000ol3o`040ol00`000ol3o`050ol00`000ol3o`050ol00`000ol3o`040ol00`000ol3o`2a0oll
Ool0035oo`03001oogoo03=oo`D3o`8000H3o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3o`80
00H3o`8000D3o`8000H3o`8000H3o`8000D3o`8000L3o`030003o`?o00@3o`030003o`?o00D3o`03
0003o`?o00@3o`030003o`?o00D3o`030003o`?o00@3o`030003o`?o08@3ocaoo`00<Goo00<007oo
Ool0<goo1@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o0P00
1P?o0P001@?o00<007oo00001@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o0P00
1`?o00<000?o0ol010?o00<000?o0ol01@?o00<000?o0ol010?o00<000?o0ol01@?o00<000?o0ol0
10?o00<000?o0ol0E`?o?7oo000aOol00`00Oomoo`0cOol50ol200060ol200050ol200060ol20005
0ol200060ol200050ol200060ol200050ol200060ol200050ol00`00Ool000050ol200060ol20005
0ol200060ol200050ol200060ol200050ol200060ol200050ol200060ol200050ol200060ol20005
0ol200070ol00`000ol3o`040ol00`000ol3o`050ol00`000ol3o`040ol00`000ol3o`050ol00`00
0ol3o`040ol00`000ol3o`0Z0ollOol0035oo`03001oogoo03=oo`D3o`8000H3o`8000D3o`8000H3
o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3o`03001oo`0000D3o`8000H3
o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3o`8000H3
o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3o`8000L3o`030003o`?o00D3
o`030003o`?o00@3o`030003o`?o00D3o`030003o`?o00@3o`030003o`?o00@3ocaoo`00<Goo00<0
07ooOol0<goo1@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o
0P001P?o0P001@?o00<007oo00001@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o
0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o
0P001P?o0P001@?o0P001P?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o?7oo000aOol00`00
Oomoo`0cOol50ol200060ol200050ol200060ol200050ol200060ol200050ol200060ol200050ol2
00060ol200050ol00`00Ool000050ol200060ol200050ol200060ol200050ol200060ol200050ol2
00060ol200050ol200060ol200050ol200060ol200050ol200060ol200050ol200060ol200050ol2
00060ol200050ol200060ol200050ol00`00Ool000050ol200050ol00`00Ool000050ol200060ol0
0`00Oomoo`0iOol0035oo`03001oogoo03=oo`D3o`8000H3o`8000D3o`8000H3o`8000D3o`8000H3
o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3o`03001oo`0000D3o`8000H3o`8000D3o`8000H3
o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3o`8000H3
o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3o`03001oo`0000D3o`8000D3
o`03001oo`0000D3o`8000H3o`03001oogoo03Uoo`00<Goo0P00=7oo1@?o0P001P?o0P001@?o0P00
1P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o00<007oo00001@?o0P00
1P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o0P00
1P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o00<0
07oo00001@?o0P001@?o00<007oo00001@?o0P001P?o00<007ooOol0>Goo000aOol00`00Oomoo`0c
Ool50ol200060ol200050ol200060ol200050ol200060ol200050ol00`00Ool000050ol200050ol0
0`00Ool000050ol200050ol00`00Ool000050ol200060ol200050ol200060ol200050ol200060ol2
00050ol200060ol200050ol200060ol200050ol200060ol200050ol200060ol200050ol200060ol2
00050ol200060ol200050ol200060ol200050ol00`00Ool000050ol200050ol00`00Ool000050ol2
00060ol00`00Oomoo`0iOol0035oo`03001oogoo03=oo`D3o`8000H3o`8000D3o`8000H3o`8000D3
o`8000H3o`8000D3o`03001oo`0000D3o`8000D3o`03001oo`0000D3o`8000D3o`03001oo`0000D3
o`8000H3o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3
o`8000H3o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3
o`03001oo`0000D3o`8000D3o`03001oo`0000D3o`8000H3o`03001oogoo03Uoo`00<Goo00<007oo
Ool0<goo1@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o00<007oo00001@?o0P00
1@?o00<007oo00001@?o0P001@?o00<007oo00001@?o0P001@?o00<007oo00001@?o0P001P?o0P00
1@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P00
1@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o00<007oo00001@?o0P001@?o00<0
07oo00001@?o0P001P?o00<007ooOol0>Goo000aOol00`00Oomoo`0cOol50ol200060ol200050ol2
00060ol200050ol200060ol200050ol00`00Ool000050ol200050ol00`00Ool000050ol200050ol0
0`00Ool000050ol200050ol00`00Ool000050ol200050ol00`00Ool000050ol200060ol200050ol2
00060ol200050ol200060ol200050ol200060ol200050ol200060ol200050ol200060ol200050ol0
0`00Ool000050ol200050ol00`00Ool000050ol200050ol00`00Ool000050ol200050ol00`00Ool0
00050ol200060ol00`00Oomoo`0iOol0035oo`03001oogoo03=oo`D3o`8000H3o`8000D3o`8000H3
o`8000D3o`8000H3o`8000D3o`03001oo`0000D3o`8000D3o`03001oo`0000D3o`8000D3o`03001o
o`0000D3o`8000D3o`03001oo`0000D3o`8000D3o`03001oo`0000D3o`8000H3o`8000D3o`8000H3
o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3o`03001o
o`0000D3o`8000D3o`03001oo`0000D3o`8000D3o`03001oo`0000D3o`8000D3o`03001oo`0000D3
o`8000H3o`03001oogoo03Uoo`00<Goo00<007ooOol0<goo1@?o0P001P?o0P001@?o0P001P?o0P00
1@?o0P001P?o0P001@?o00<007oo00001@?o0P001@?o00<007oo00001@?o0P001@?o00<007oo0000
1@?o0P001@?o00<007oo00001@?o0P001@?o00<007oo00001@?o0P001P?o0P001@?o0P001P?o0P00
1@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o00<007oo0000
1@?o0P001@?o00<007oo00001@?o0P001@?o00<007oo00001@?o0P001@?o00<007oo00001@?o0P00
1P?o00<007ooOol0>Goo000aOol2000dOol50ol200060ol200050ol200060ol200050ol200060ol2
00050ol00`00Ool000050ol200050ol00`00Ool000050ol200050ol00`00Ool000050ol200050ol0
0`00Ool000050ol200050ol00`00Ool000050ol200060ol200050ol200060ol200050ol200060ol2
00050ol200060ol200050ol200060ol200050ol200060ol200050ol00`00Ool000050ol200050ol0
0`00Ool000050ol200050ol00`00Ool000050ol200050ol00`00Ool000050ol200050ol00`00Oomo
o`0jOol0035oo`03001oogoo03=oo`D3o`8000H3o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3
o`03001oo`0000D3o`8000D3o`03001oo`0000D3o`8000D3o`03001oo`0000D3o`8000D3o`03001o
o`0000D3o`8000D3o`03001oo`0000D3o`8000H3o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3
o`8000H3o`8000D3o`8000H3o`8000D3o`8000H3o`8000D3o`03001oo`0000D3o`8000D3o`03001o
o`0000D3o`8000D3o`03001oo`0000D3o`8000D3o`03001oo`0000D3o`8000D3o`03001oogoo03Yo
o`00<Goo00<007ooOol0<goo1@?o00<007oo00001@?o00<007oo000010?o00<007oo00001@?o00<0
07oo000010?o00<007oo00001@?o00<007oo000010?o00<007oo00001@?o00<007oo000010?o00<0
07oo00001@?o0P001@?o00<007oo00001@?o0P001@?o00<007oo00001@?o0P001@?o00<007oo0000
1@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P00
1@?o0P001P?o0P001@?o00<007oo00001@?o0P001@?o00<007oo00001@?o0P001@?o00<007oo0000
1@?o0P001@?o00<007oo00001@?o0P001@?o00<007ooOol0>Woo000aOol00`00Oomoo`0cOol40ol0
1000Oomoo`0010?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol0
00D3o`03001oo`0000@3o`03001oo`0000D3o`03001oo`0000@3o`03001oo`0000D3o`03001oo`00
00@3o`04001oogoo00040ol00`00Ool000040ol01000Oomoo`0010?o00<007oo000010?o00<007oo
00001@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o0P001P?o
0P001@?o0P001P?o0P001@?o00<007oo00001@?o0P001@?o00<007oo00001@?o0P001@?o00<007oo
00001@?o0P001@?o00<007oo00001@?o0P001@?o00<007ooOol0>Woo0002Ool40006Ool20006Ool4
0004Ool70004Ool40006Ool00`00Oomoo`0cOol40ol01000Oomoo`0010?o00@007ooOol000<3o`04
001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001oogoo00030ol01000Oomoo`00
10?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00D007ooOomoo`0000@3o`03
001oo`0000@3o`04001oogoo00040ol00`00Ool000040ol01000Oomoo`0010?o00<007oo00001@?o
00<007oo000010?o00<007oo00001@?o00<007oo000010?o00<007oo00001@?o0P001@?o0P001P?o
0P001@?o0P001P?o0P001@?o0P001P?o0P001@?o00<007oo00001@?o0P001@?o00<007oo00001@?o
0P001@?o00<007oo00001@?o0P001@?o00<007oo00001@?o0P001@?o00<007ooOol0>Woo00000goo
001oo`03Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`04
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0cOol40ol01000Oomoo`0010?o00@007oo
Ool000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001oogoo00030ol0
1000Oomoo`0010?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00D007ooOomo
o`0000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001oogoo00030ol0
1000Oomoo`0010?o00@007ooOol000@3o`03001oo`0000D3o`03001oo`0000@3o`03001oo`0000D3
o`03001oo`0000@3o`03001oo`0000D3o`03001oo`0000@3o`03001oo`0000D3o`03001oo`0000@3
o`03001oo`0000D3o`8000D3o`03001oo`0000D3o`8000D3o`03001oo`0000D3o`8000D3o`03001o
o`0000D3o`8000D3o`03001oo`0000D3o`8000D3o`03001oogoo03Yoo`0000=oo`00Ool00goo00<0
07ooOol02Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol017oo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol0<goo10?o00@007ooOol000@3o`04001oogoo00030ol01000Oomoo`00
10?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001o
ogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`05001oogooOol000030ol01000Oomoo`00
10?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001o
ogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o
00@007ooOol000@3o`04001oogoo00040ol00`00Ool000050ol00`00Ool000040ol00`00Ool00005
0ol00`00Ool000040ol00`00Ool000050ol00`00Ool000040ol00`00Ool000050ol00`00Ool00004
0ol01000Oomoo`0010?o0P001@?o00<007oo00001@?o0P001@?o00<007ooOol0>Woo00000goo001o
o`03Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`04Ool20003Ool0
0`00Oomoo`03Ool00`00Oomoo`0cOol40ol01000Oomoo`0010?o00@007ooOol000<3o`04001oogoo
00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001oogoo00030ol01000Oomoo`0010?o00@0
07ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00D007ooOomoo`0000<3o`04001oogoo
00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001oogoo00030ol01000Oomoo`0010?o00@0
07ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001oogoo0003
0ol01000Oomoo`0010?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007oo
Ool000@3o`04001oogoo00030ol01000Oomoo`0010?o00@007ooOol000@3o`03001oo`0000D3o`03
001oo`0000@3o`04001oogoo00040ol00`00Ool000040ol01000Oomoo`0010?o00<007oo000010?o
00<007ooOol0>Woo00000goo001oo`03Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Oomoo`04Ool00`00Ool000020006Ool3000cOol40ol01000Oomoo`0010?o00@007ooOol0
00<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001oogoo00030ol01000
Oomoo`0010?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00D007ooOomoo`00
00<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001oogoo00030ol01000
Oomoo`0010?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3
o`04001oogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`04001oogoo00040ol01000Oomo
o`000`?o00@007ooOol000@3o`04001oogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`04
001oogoo00040ol01000Oomoo`000`?o00D007ooOomoo`0000<3o`04001oogoo00030ol01@00Oomo
ogoo00000`?o00@007ooOol000@3o`03001oogoo03Yoo`0000=oo`00Ool00goo00<007ooOol02Woo
00<007ooOol00Woo00<007ooOol017oo00<007ooOol017oo00<007ooOol027oo00<007ooOol0<goo
10?o00@007ooOol000@3o`04001oogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`04001o
ogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001oogoo00030ol01000Oomoo`0010?o
00@007ooOol000<3o`05001oogooOol000030ol01000Oomoo`0010?o00@007ooOol000<3o`04001o
ogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001oogoo00030ol01000Oomoo`0010?o
00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001oogoo
00030ol01000Oomoo`0010?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00@0
07ooOol000@3o`04001oogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`05001oogooOol0
00030ol01000Oomoo`000`?o00D007ooOomoo`0000<3o`04001oogoo00040ol00`00Oomoo`0jOol0
0003Ool007oo00=oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Eo
o`03001oogoo00Moo`03001oogoo03=oo`@3o`04001oogoo00040ol01000Oomoo`000`?o00@007oo
Ool000@3o`04001oogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`05001oogooOol00003
0ol01000Oomoo`000`?o00@007ooOol000@3o`04001oogoo00030ol01@00Oomoogoo00000`?o00@0
07ooOol000@3o`04001oogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`04001oogoo0004
0ol01000Oomoo`000`?o00@007ooOol000@3o`04001oogoo00030ol01000Oomoo`0010?o00@007oo
Ool000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001oogoo00030ol0
1000Oomoo`0010?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol0
00@3o`04001oogoo00030ol01@00Oomoogoo00000`?o00@007ooOol000<3o`05001oogooOol00003
0ol01000Oomoo`0010?o00<007ooOol0>Woo00000goo001oo`03Ool00`00Oomoo`0:Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool30008Ool00`00Oomoo`06Ool00`00Oomoo`0cOol40ol01000Oomoo`00
10?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001o
ogoo00030ol01@00Oomoogoo00000`?o00@007ooOol000<3o`05001oogooOol000030ol01000Oomo
o`000`?o00D007ooOomoo`0000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3
o`04001oogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`04001oogoo00040ol01000Oomo
o`000`?o00@007ooOol000@3o`04001oogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`04
001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001oogoo00030ol01000Oomoo`00
10?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00D007ooOomoo`0000<3o`04
001oogoo00030ol01@00Oomoogoo00000`?o00@007ooOol000@3o`03001oogoo03Yoo`000Woo1000
3Woo10001goo00<007ooOol01goo0`001Goo00<007ooOol0<goo10?o00@007ooOol000@3o`04001o
ogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o
00D007ooOomoo`0000<3o`04001oogoo00030ol01@00Oomoogoo00000`?o00@007ooOol000<3o`05
001oogooOol000030ol01000Oomoo`0010?o00@007ooOol000<3o`04001oogoo00040ol01000Oomo
o`000`?o00@007ooOol000@3o`04001oogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`04
001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001oogoo00030ol01000Oomoo`00
10?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001o
ogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`05001oogooOol000030ol01000Oomoo`00
0`?o00D007ooOomoo`0000<3o`04001oogoo00040ol00`00Oomoo`0jOol0035oo`03001oogoo03=o
o`@3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001oogoo00030ol01000
Oomoo`0010?o00@007ooOol000<3o`05001oogooOol000030ol01000Oomoo`000`?o00D007ooOomo
o`0000<3o`04001oogoo00030ol01@00Oomoogoo00000`?o00@007ooOol000@3o`04001oogoo0003
0ol01000Oomoo`0010?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007oo
Ool000@3o`04001oogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`04001oogoo00040ol0
1000Oomoo`000`?o00@007ooOol000@3o`04001oogoo00030ol01000Oomoo`0010?o00@007ooOol0
00<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001oogoo00030ol01@00
Oomoogoo00000`?o00@007ooOol000<3o`05001oogooOol000030ol01000Oomoo`0010?o00<007oo
Ool0>Woo000aOol00`00Oomoo`0cOol40ol01000Oomoo`0010?o00@007ooOol000<3o`04001oogoo
00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001oogoo00030ol01@00Oomoogoo00000`?o
00@007ooOol000<3o`05001oogooOol000030ol01000Oomoo`000`?o00D007ooOomoo`0000<3o`04
001oogoo00030ol01@00Oomoogoo00000`?o00@007ooOol000<3o`05001oogooOol000030ol01000
Oomoo`0010?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3
o`04001oogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`04001oogoo00040ol01000Oomo
o`000`?o00@007ooOol000@3o`04001oogoo00030ol01@00Oomoogoo00000`?o00@007ooOol000<3
o`05001oogooOol000030ol01000Oomoo`000`?o00D007ooOomoo`0000<3o`04001oogoo00030ol0
1@00Oomoogoo00000`?o00@007ooOol000@3o`03001oogoo03Yoo`00<Goo0P00=7oo10?o00@007oo
Ool000@3o`04001oogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`04001oogoo00040ol0
1000Oomoo`000`?o00D007ooOomoo`0000<3o`04001oogoo00030ol01@00Oomoogoo00000`?o00@0
07ooOol000<3o`05001oogooOol000030ol01000Oomoo`000`?o00D007ooOomoo`0000<3o`04001o
ogoo00030ol01@00Oomoogoo00000`?o00@007ooOol000@3o`04001oogoo00030ol01000Oomoo`00
10?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001o
ogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o
00D007ooOomoo`0000<3o`04001oogoo00030ol01@00Oomoogoo00000`?o00@007ooOol000<3o`05
001oogooOol000030ol01000Oomoo`000`?o00D007ooOomoo`0000<3o`04001oogoo00040ol00`00
Oomoo`0jOol0035oo`03001oogoo03=oo`@3o`04001oogoo00040ol01000Oomoo`000`?o00@007oo
Ool000@3o`04001oogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`05001oogooOol00003
0ol01000Oomoo`000`?o00D007ooOomoo`0000<3o`04001oogoo00030ol01@00Oomoogoo00000`?o
00@007ooOol000<3o`05001oogooOol000030ol01000Oomoo`000`?o00D007ooOomoo`0000<3o`04
001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001oogoo00030ol01000Oomoo`00
10?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001o
ogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`05001oogooOol000030ol01000Oomoo`00
0`?o00D007ooOomoo`0000<3o`04001oogoo00030ol01@00Oomoogoo00000`?o00@007ooOol000<3
o`05001oogooOol000030ol01000Oomoo`0010?o00<007ooOol0>Woo000aOol00`00Oomoo`0cOol0
1@000ol3o`?o00000Woo00<000?o0ol00P?o00@007ooOol000<3o`04001oogoo00040ol01000Oomo
o`000`?o00@007ooOol000@3o`04001oogoo00030ol01@00Oomoogoo00000`?o00@007ooOol000<3
o`05001oogooOol000030ol01000Oomoo`000`?o00D007ooOomoo`0000<3o`04001oogoo00030ol0
1@00Oomoogoo00000`?o00@007ooOol000<3o`05001oogooOol000030ol01000Oomoo`0010?o00@0
07ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001oogoo0003
0ol01000Oomoo`0010?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007oo
Ool000@3o`04001oogoo00030ol01@00Oomoogoo00000`?o00@007ooOol000<3o`05001oogooOol0
00030ol01000Oomoo`000`?o00D007ooOomoo`0000<3o`04001oogoo00030ol01@00Oomoogoo0000
0`?o00@007ooOol000@3o`03001oogoo03Yoo`00<Goo00<007ooOol0<goo00D000?o0ol3o`00009o
o`030003o`?o0083o`04001oogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`04001oogoo
00040ol01000Oomoo`000`?o00D007ooOomoo`0000<3o`04001oogoo00030ol01@00Oomoogoo0000
0`?o00@007ooOol000<3o`05001oogooOol000030ol01000Oomoo`000`?o00D007ooOomoo`0000<3
o`04001oogoo00030ol01@00Oomoogoo00000`?o00@007ooOol000@3o`04001oogoo00030ol01000
Oomoo`0010?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3
o`04001oogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`04001oogoo00040ol01000Oomo
o`000`?o00D007ooOomoo`0000<3o`04001oogoo00030ol01@00Oomoogoo00000`?o00@007ooOol0
00<3o`05001oogooOol000030ol01000Oomoo`000`?o00D007ooOomoo`0000<3o`04001oogoo0003
0ol00`00Oomoo`0kOol0035oo`03001oogoo03Aoo`8000030ol007oo009oo`<000030ol007oo009o
o`8000030ol007oo009oo`050003o`?o0ol00003Ool010000ol3o`000goo0P000P?o00D007ooOomo
o`000083o`05001oogooOol000030ol01000Oomoo`000`?o00D007ooOomoo`0000<3o`04001oogoo
00030ol01@00Oomoogoo00000`?o00@007ooOol000<3o`05001oogooOol000030ol01000Oomoo`00
0`?o00D007ooOomoo`0000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04
001oogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`00
0`?o00@007ooOol000@3o`04001oogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`05001o
ogooOol000030ol01000Oomoo`000`?o00D007ooOomoo`0000<3o`04001oogoo00030ol01@00Oomo
ogoo00000`?o00@007ooOol000<3o`05001oogooOol000030ol01000Oomoo`000`?o00<007ooOol0
>goo000aOol00`00Oomoo`0fOol20006Ool20005Ool20004Ool40004Ool30005Ool30004Ool30004
Ool40003Ool200000`?o001oo`03Ool200000`?o001oo`02Ool010000ol3o`0017oo00@000?o0ol0
00=oo`040003o`?o0003Ool01@000ol3o`?o00000Woo00D000?o0ol3o`0000=oo`050003o`?o0ol0
0002Ool00`000ol3o`020ol01000Oomoo`000`?o00@007ooOol000@3o`04001oogoo00030ol01000
Oomoo`0010?o00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3
o`04001oogoo00030ol01000Oomoo`0010?o00@007ooOol000<3o`05001oogooOol000030ol01000
Oomoo`000`?o00D007ooOomoo`0000<3o`04001oogoo00030ol01@00Oomoogoo00000`?o00@007oo
Ool000<3o`05001oogooOol000030ol01000Oomoo`000`?o00<007ooOol0>goo000aOol00`00Oomo
o`1MOol00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`03Ool20006Ool20004Ool30005Ool3
0004Ool30004Ool40003Ool200000`?o001oo`03Ool200000`?o001oo`02Ool01@000ol3o`?o0000
0goo00@000?o0ol000=oo`050003o`?o0ol00002Ool01@000ol3o`?o00000Woo00<000?o0ol00P?o
00@007ooOol000<3o`04001oogoo00040ol01000Oomoo`000`?o00@007ooOol000@3o`04001oogoo
00030ol01000Oomoo`0010?o00@007ooOol000<3o`05001oogooOol000030ol01000Oomoo`000`?o
00D007ooOomoo`0000<3o`04001oogoo00030ol01@00Oomoogoo00000`?o00@007ooOol000<3o`05
001oogooOol000030ol01000Oomoo`000`?o00<007ooOol0>goo000aOol00`00Oomoo`2:Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`03Ool20006Ool20004Ool40004Ool30004Ool20000
0`?o001oo`02Ool40003Ool200020ol01000Oomoogoo0P0000<3o`00Ool00Woo00D000?o0ol3o`00
00=oo`040003o`?o0003Ool01@000ol3o`?o00000Woo00D000?o0ol3o`0000=oo`050003o`?o0ol0
0002Ool01@000ol3o`?o00000goo00D000?o0ol3o`00009oo`050003o`?o0ol00003Ool01@000ol3
o`?o00000Woo00D000?o0ol3o`0000=oo`050003o`?o0ol00002Ool01@000ol3o`?o00000goo00D0
00?o0ol3o`00009oo`050003o`?o0ol0000mOol0035oo`800;Qoo`03001oogoo00Aoo`8000Ioo`03
001oogoo00=oo`<000Eoo`8000Aoo`@000Aoo`<000Aoo`@000=oo`@000Aoo`8000030ol007oo009o
o`8000030ol007oo00=oo`040003o`?o0003Ool010000ol3o`0017oo00@000?o0ol0009oo`050003
o`?o0ol00003Ool01@000ol3o`?o00000Woo00D000?o0ol3o`0000=oo`050003o`?o0ol00002Ool0
1@000ol3o`?o0000?Goo000aOol00`00Oomoo`3TOol00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`04Ool20005Ool20005Ool30004Ool30005Ool30003Ool40004Ool200000`?o001oo`02Ool2
00000`?o001oo`03Ool010000ol3o`000goo00@000?o0ol003eoo`00<Goo00<007ooOol0ogoo4Woo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo0P001Goo0P001Goo0`0017oo0`00?Goo
000aOol00`00Oomoo`3oOoloOol00`00Oomoo`0kOol0035oo`03001oogoo0?moogeoo`00<Goo00<0
07ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`800?moogioo`00<Goo00<007ooOol0
ogooOGoo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`0097oo0`007Woo0`00ogooJGoo000UOol0
0`00Oomoo`0OOol00`00Oomoo`3oOomWOol002Eoo`03001oogoo009oo`03001oogoo01Yoo`03001o
ogoo0?moofMoo`005goo1P0017oo0`0000=oo`00Ool017oo00<007ooOol01Goo0`0000=oo`000000
17oo1@001Goo0P00ogooJ7oo000HOol00`00Oomoo`02Ool01000Oomoo`000goo0P001Goo00<007oo
Ool017oo00@007ooOomoo`8000Aoo`05001oogooOol00006Ool2003oOomXOol001Qoo`03001oogoo
009oo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool01@00Oomoogoo00001Goo00@007ooOol00?moofMoo`0067oo00<007ooOol00Woo00@007oo
Ool000Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`@000Eo
o`04001oogoo003oOomWOol001Qoo`D000=oo`04001oogooOol20006Ool00`00Oomoo`03Ool01000
Oomoogoo0P0017oo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo0?moofAoo`0067oo
00<007ooOol00Woo00@007ooOomoo`<00003Ool0000000Ioo`03001oogoo00=oo`<00003Ool007oo
00Aoo`<000Aoo`<0009oo`<00?moofEoo`0067oo00<007ooOol00Woo00<007ooOol03Goo00<007oo
Ool01goo00<007ooOol0ogooMgoo000GOol6000@Ool00`00Oomoo`07Ool00`00Oomoo`3oOomgOol0
02ioo`03001oogoo00Eoo`800?moogUoo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003o
OonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5o
o`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.000937647, -5.00002*^-06, \
0.0034868, 0.00564177}, {{0.375, 430.563}, {265.875, 0}} -> {-46.1577, \
0.00251375, 1.39566, 0.000100559}, {{0.375, 430.563}, {265.875, 0}} -> \
{-46.1577, 0.00251375, 1.39566, 0.000100559}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[36]="]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->Automatic,
WindowToolbars->"EditBar",
WindowSize->{928, 647},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageFooters->{{Inherited, Cell[ 
        TextData[ {
          "\[Copyright]2005 Guillermo Sanchez & ENUSA. All rights \
reserved."}], "PageFooter"], Inherited}, {Inherited, Cell[ 
        TextData[ {
          "\[Copyright]2005 Guillermo Sanchez & ENUSA . All rights \
reserved."}], "PageFooter"], Inherited}},
ShowSelection->True,
Magnification->1.5,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "ICRP 78"->{
    Cell[2144, 72, 82, 1, 58, "MathCaption",
      CellTags->"ICRP 78"]},
  "Introduction"->{
    Cell[2811, 99, 116, 3, 40, "Input",
      CellTags->"Introduction"]},
  "Examples"->{
    Cell[3637, 135, 72, 1, 54, "Section",
      CellTags->"Examples"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"ICRP 78", 156261, 4688},
  {"Introduction", 156355, 4691},
  {"Examples", 156445, 4694}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 33, 0, 136, "Chapter"],
Cell[1812, 55, 58, 0, 47, "Commentary"],

Cell[CellGroupData[{
Cell[1895, 59, 65, 2, 40, "Input"],
Cell[1963, 63, 101, 2, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2101, 70, 40, 0, 58, "SubsectionIcon"],
Cell[2144, 72, 82, 1, 58, "MathCaption",
  CellTags->"ICRP 78"],

Cell[CellGroupData[{
Cell[2251, 77, 87, 2, 40, "Input"],
Cell[2341, 81, 91, 2, 32, "Print"],
Cell[2435, 85, 118, 2, 32, "Print"],
Cell[2556, 89, 89, 2, 32, "Print"],
Cell[2648, 93, 148, 3, 57, "Print"]
}, Open  ]],
Cell[2811, 99, 116, 3, 40, "Input",
  CellTags->"Introduction"],
Cell[2930, 104, 96, 2, 40, "Input"],
Cell[3029, 108, 90, 2, 40, "Input"],
Cell[3122, 112, 105, 2, 40, "Input"],
Cell[3230, 116, 98, 2, 40, "Input"],
Cell[3331, 120, 94, 2, 40, "Input"],
Cell[3428, 124, 69, 2, 40, "Input"],
Cell[3500, 128, 100, 2, 40, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3637, 135, 72, 1, 54, "Section",
  CellTags->"Examples"],
Cell[3712, 138, 137, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[3874, 145, 38, 0, 35, "SubsubsectionIcon"],
Cell[3915, 147, 321, 9, 80, "MathCaption"],
Cell[4239, 158, 170, 4, 66, "Input"],
Cell[4412, 164, 109, 2, 40, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4558, 171, 38, 0, 27, "SubsubsectionIcon"],
Cell[4599, 173, 128, 3, 34, "Text"],
Cell[4730, 178, 190, 4, 80, "MathCaption"],

Cell[CellGroupData[{
Cell[4945, 186, 108, 2, 40, "Input"],
Cell[5056, 190, 1184, 18, 170, "Output"]
}, Open  ]],
Cell[6255, 211, 74, 0, 58, "MathCaption"],
Cell[6332, 213, 109, 2, 40, "Input"],
Cell[6444, 217, 618, 20, 107, "MathCaption"],

Cell[CellGroupData[{
Cell[7087, 241, 158, 3, 66, "Input"],
Cell[7248, 246, 641, 25, 70, "Output"]
}, Open  ]],
Cell[7904, 274, 231, 6, 66, "Input"],
Cell[8138, 282, 235, 4, 80, "MathCaption"],

Cell[CellGroupData[{
Cell[8398, 290, 202, 4, 96, "Input"],
Cell[8603, 296, 1082, 16, 70, "Output"]
}, Open  ]],
Cell[9700, 315, 98, 2, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9823, 321, 187, 4, 66, "Input"],
Cell[10013, 327, 21788, 545, 70, 5227, 335, "GraphicsData", "PostScript", \
"Graphics"],
Cell[31804, 874, 155, 4, 70, "Output"]
}, Open  ]],
Cell[31974, 881, 142, 3, 66, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[32153, 889, 38, 0, 27, "SubsubsectionIcon"],
Cell[32194, 891, 151, 3, 80, "MathCaption"],

Cell[CellGroupData[{
Cell[32370, 898, 139, 3, 40, "Input"],
Cell[32512, 903, 2311, 35, 363, "Output"]
}, Open  ]],
Cell[34838, 941, 204, 4, 80, "MathCaption"],
Cell[35045, 947, 227, 4, 66, "Input"],
Cell[35275, 953, 95, 1, 43, "Input"],
Cell[35373, 956, 281, 6, 85, "MathCaption"],
Cell[35657, 964, 129, 4, 70, "Input"],

Cell[CellGroupData[{
Cell[35811, 972, 111, 3, 43, "Input"],
Cell[35925, 977, 613, 19, 96, "Output"]
}, Open  ]],
Cell[36553, 999, 74, 2, 40, "Input"],
Cell[36630, 1003, 110, 2, 40, "Input"],
Cell[36743, 1007, 142, 4, 70, "Input"],
Cell[36888, 1013, 77, 0, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[36990, 1017, 180, 4, 65, "Input"],
Cell[37173, 1023, 100, 2, 38, "Output"]
}, Open  ]],
Cell[37288, 1028, 155, 3, 80, "MathCaption"],

Cell[CellGroupData[{
Cell[37468, 1035, 165, 4, 66, "Input"],
Cell[37636, 1041, 1122, 17, 144, "Output"]
}, Open  ]],
Cell[38773, 1061, 114, 3, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[38912, 1068, 187, 4, 66, "Input"],
Cell[39102, 1074, 21439, 531, 276, 5043, 323, "GraphicsData", "PostScript", \
"Graphics"],
Cell[60544, 1607, 155, 4, 38, "Output"]
}, Open  ]],
Cell[60714, 1614, 173, 3, 66, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[60924, 1622, 38, 0, 27, "SubsubsectionIcon"],
Cell[60965, 1624, 425, 7, 100, "Text"],
Cell[61393, 1633, 79, 0, 58, "MathCaption"],
Cell[61475, 1635, 331, 6, 118, "Input"],
Cell[61809, 1643, 101, 2, 58, "MathCaption"],
Cell[61913, 1647, 151, 4, 40, "Input"],
Cell[62067, 1653, 111, 2, 40, "Input"],
Cell[62181, 1657, 185, 4, 56, "Text"],

Cell[CellGroupData[{
Cell[62391, 1665, 171, 3, 66, "Input"],
Cell[62565, 1670, 92382, 2977, 276, 37595, 2296, "GraphicsData", \
"PostScript", "Graphics"],
Cell[154950, 4649, 155, 4, 38, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

