(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    549527,      15375]*)
(*NotebookOutlinePosition[    551961,      15451]*)
(*  CellTagsIndexPosition[    551726,      15440]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["SysModel 1.3", "Title"],

Cell[TextData[{
  "A ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package for solving system of differential equations and for fitting \
coefficients with application for modeling Biokinetic Systems."
}], "FramedBox",
  FontSize->14,
  Background->RGBColor[0.500008, 0.996109, 0.996109]],

Cell[TextData[{
  StyleBox["Author",
    FontWeight->"Bold"],
  ": Guillermo Sanchez:  ",
  StyleBox["guillermo@usal.es, ",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  StyleBox[ButtonBox["http://web.usal.es/~guillerm/",
    ButtonData:>{
      URL[ "http://web.usal.es/~guillerm/"], None}],
    ButtonBoxOptions -> {DefaultStyle -> "Hyperlink"}]
}], "Text"],

Cell["Last update of this help:  \t 2005-8-22 ", "Commentary"],

Cell[CellGroupData[{

Cell[BoxData[
    \($Version\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("5.1 for Microsoft Windows (January 28, 2005)"\)], "Output",
  CellLabel->"Out[1]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Introduction", "SubsectionIcon"],

Cell[TextData[{
  StyleBox["SysModel", "Input"],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "is a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " program that solves System of Ordinary Differential Equations (SODE). ",
  StyleBox["The package is more friendly than used directly ",
    CellDingbat->None],
  StyleBox["Mathematica",
    CellDingbat->None,
    FontSlant->"Italic"],
  StyleBox["'s functions ",
    CellDingbat->None],
  StyleBox["DSolve", "Input",
    CellDingbat->None],
  StyleBox[" or ",
    CellDingbat->None],
  StyleBox["NDSolve", "Input",
    CellDingbat->None],
  StyleBox[", even in many occasion is faster.",
    CellDingbat->None]
}], "Text",
  CellDingbat->None],

Cell[TextData[{
  StyleBox["The package has some features to be applied for solving \
compartmental and physiological models in an easy way. ",
    CellDingbat->None],
  "It has the following innovations:\na) The program uses symbolic \
computation (eigenvalues and eigensystem methods, laplace transformation, \
analytic integration, etc.) for solving linear models.  \nb) Also, applied \
numeric methods for  linear and Nonlinear models.\nc) Besides acute and \
constant inputs, it can practically be used for any kind of continuous inputs \
(exponentials, periodic, etc.), even for random inputs. \nd) The user can \
build himself compartmental models in a very easy way generating \
automatically the System of ODE."
}], "Text",
  CellDingbat->None,
  Background->None],

Cell[TextData[{
  StyleBox["SysModel", "Input"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "is a package included in ",
  StyleBox["Biokmod",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Biokmod",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " is a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Toolbox for solving compartmental and physiological models, for fitting \
parameters and convolution. It can be applied in Medicine, Pharmacology and \
Radioprotection. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Installing and loading the package", "SubsectionIcon"],

Cell["\<\
To install the package:

1. Extract the file \"biokmod.zip\" with a zip utility (ex:winzip). It will \
create a folder called Biokmod.Copy this folder in Mathematica \
directory'AddOns\\Applications

2 Open Mathematica and  select in Help : \"Rebuild Help Index\". Then  in \
Add-ons help you will find a new item called Biokmod where usage of package \
is described. \
\>", "Commentary"],

Cell["Load the package as usual", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Needs["\<Biokmod`SysModel`\>"]\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \("SysModel, guillermo@usal.es, version 1.3.   2005-07-15"\)], "Print",
  CellLabel->"From In[2]:="]
}, Open  ]],

Cell["Here are the package's functions ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?"\<Biokmod`SysModel`*\>"\)\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[GridBox[{
        {
          StyleBox["Biokmod`SysModel`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["AcuteInput",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703364-6461276", 
                    "Biokmod`SysModel`AcuteInput"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`SysModel`"], 
                ButtonBox[
                  StyleBox["CoefMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703364-6461276", 
                    "Biokmod`SysModel`CoefMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`SysModel`"], 
                ButtonBox[
                  StyleBox["matrixExp",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703364-6461276", 
                    "Biokmod`SysModel`matrixExp"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`SysModel`"], 
                ButtonBox[
                  StyleBox["ShowODE",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703364-6461276", 
                    "Biokmod`SysModel`ShowODE"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`SysModel`"], 
                ButtonBox[
                  StyleBox["SystemLTSolve",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703364-6461276", 
                    "Biokmod`SysModel`SystemLTSolve"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`SysModel`"], "", "", ""},
              {
                ButtonBox[
                  StyleBox["Catenary",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703364-6461276", 
                    "Biokmod`SysModel`Catenary"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`SysModel`"], 
                ButtonBox[
                  StyleBox["CompartMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703364-6461276", 
                    "Biokmod`SysModel`CompartMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`SysModel`"], 
                ButtonBox[
                  StyleBox["MultiExpInput",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703364-6461276", 
                    "Biokmod`SysModel`MultiExpInput"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`SysModel`"], 
                ButtonBox[
                  StyleBox["SystemDSolve",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703364-6461276", 
                    "Biokmod`SysModel`SystemDSolve"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`SysModel`"], 
                ButtonBox[
                  StyleBox["SystemNDSolve",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703364-6461276", 
                    "Biokmod`SysModel`SystemNDSolve"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`SysModel`"], "", "", ""}
              },
            RowMinHeight->{1, 1.05}]}
        },
      RowSpacings->{2, 3},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->RGBColor[0.964706, 0.929412, 0.839216],
  ButtonBoxOptions->{Active->True},
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Open  ]],

Cell[TextData[{
  "Also, we load other packages and write some functions to avoid some \
warning messages",
  Cell[BoxData[
      ButtonBox["",
        ButtonFunction:>(Internal`PutInformation[ #, LongForm -> False]&),
        ButtonData:>{"Info3227296827-4685341", 
          "Biomod`SysModelLite`AcuteInput"},
        ButtonFrame->"None",
        ButtonNote->"Biomod`SysModelLite`"]],
    CellMargins->{{20, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
    Background->GrayLevel[0.930022],
    ButtonBoxOptions->{Active->True}]
}], "Text"],

Cell[BoxData[{
    \(Off[General::spell]; \), "\[IndentingNewLine]", 
    \(Off[General::spell1]; \), "\[IndentingNewLine]", 
    \(Needs["\<Graphics`Legend`\>"]\), "\[IndentingNewLine]", 
    \(Needs["\<Graphics`Graphics`\>"]\)}], "Input",
  CellLabel->"In[4]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Package functions. System of ODE overview ", "SubsectionIcon"],

Cell["\<\
A system of ordinary differential equations can be represented:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)\_1\)]],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") = ",
  Cell[BoxData[
      \(TraditionalForm\`a\_11\)]],
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") + ",
  Cell[BoxData[
      \(TraditionalForm\`a\_12\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`x\_2\)]],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") +...+ ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(1  n\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") + ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[\(b\_1\),
              "TraditionalForm"], "(", "t", ")"}]}], TraditionalForm]]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)\_2\)]],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") = ",
  Cell[BoxData[
      \(TraditionalForm\`a\_21\)]],
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") + ",
  Cell[BoxData[
      \(TraditionalForm\`a\_22\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`x\_2\)]],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") +...+ ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(2  n\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") + ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[\(b\_2\),
              "TraditionalForm"], "(", "t", ")"}]}], TraditionalForm]]],
  "\n... ... ...\n",
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)\_n\)]],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") = ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n1\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") + ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n2\)]],
  Cell[BoxData[
      \(TraditionalForm\`x\_2\)]],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") +...+ ",
  Cell[BoxData[
      \(TraditionalForm\`a\_nn\)]],
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") ",
  Cell[BoxData[
      FormBox[
        RowBox[{"+", " ", 
          RowBox[{
            FormBox[\(b\_n\),
              "TraditionalForm"], "(", "t", ")"}]}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "with initial conditions: ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  "(0) = ",
  Cell[BoxData[
      \(TraditionalForm\`x\_01\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\_2\)]],
  "(0) = ",
  Cell[BoxData[
      \(TraditionalForm\`x\_02\)]],
  ", ..., ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  "(0) = ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(0  n\)\)]],
  ", "
}], "Text"],

Cell["in matrix notation ", "Text"],

Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[
              OverscriptBox[
                StyleBox["x",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "."],
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", "t", ")"}], " ", "=", 
          RowBox[{
            RowBox[{
              StyleBox["A",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              RowBox[{
                StyleBox["x",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "(", "t", ")"}]}], "+", " ", 
            RowBox[{
              StyleBox["b",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", "t", ")"}]}]}], ",", 
        " ", \(t \[GreaterEqual] 0\)}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{
        RowBox[{"Initial", " ", 
          RowBox[{"conditions", ":", " ", 
            RowBox[{
              StyleBox["x",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", "0", ")"}]}]}], " ", "=", 
        SubscriptBox[
          RowBox[{
            StyleBox["x",
              FontWeight->"Bold",
              FontSlant->"Plain"], " "}], "0"]}], 
      TraditionalForm]}], "NumberedEquation",
  TextAlignment->Left,
  TextJustification->0],

Cell["with", "Text"],

Cell[BoxData[
    RowBox[{"\t", 
      RowBox[{
        StyleBox["x",
          FontWeight->"Bold"], 
        FormBox[\(\((t)\) = \ {\(x\_1\)(t), \ \(x\_2\)(t), \  ... , \ \
\(x\_n\)(t)}\^T\),
          "TraditionalForm"]}]}]], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    RowBox[{"\t", 
      RowBox[{
        StyleBox["b",
          FontWeight->"Bold"], 
        FormBox[\(\((t)\)\(\ \)\(=\)\(\ \)\({\(b\_1\)(t), \ \(b\_2\)(
                    t),  ... , \ \(b\_n\)(t)}\^T\)\(\ \)\),
          "TraditionalForm"]}]}]], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          RowBox[{
            StyleBox["x",
              FontWeight->"Bold",
              FontSlant->"Plain"], " "}], "0"], "=", 
        SuperscriptBox[
          
          FormBox[\(\(\ \)\({\(x\_1\)(0), \ \(x\_2\)(0), \  ... , \ \(x\_n\)(
                0)}\)\),
            "TraditionalForm"], "T"]}], TraditionalForm]], "DisplayFormula"],

Cell[TextData[{
  "\t(Note: ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " mean Transpose)"
}], "SmallText"],

Cell[TextData[{
  "where the coefficients matrix ",
  StyleBox["A",
    FontWeight->"Bold"],
  " is a ",
  Cell[BoxData[
      \(TraditionalForm\`n\ \[Times]\ n\)]],
  " matrix  given by"
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    RowBox[{
      StyleBox["A",
        FontWeight->"Bold",
        FontSlant->"Plain"], "=", " ", 
      RowBox[{"(", GridBox[{
            {\(a\_11\), \(a\_12\), \(\(...\) \(a\_\(1  n\)\)\)},
            {\(a\_21\), \(a\_22\), \(\(...\) \(a\_\(2  n\)\)\)},
            {\(\(...\)\(\[IndentingNewLine]\)\(a\_n1\)\), \(\(...\)\(\
\[IndentingNewLine]\)\(a\_n2\)\), \(\(\(...\)\(...\)\)\[IndentingNewLine]\(\(\
...\) \(a\_nn\)\)\)}
            }], ")"}]}]], "DisplayFormula",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "An easy way for build ",
  StyleBox["A",
    FontWeight->"Bold"],
  " is using the package function ",
  StyleBox["CoefMatrix", "Input"]
}], "Text"],

Cell[TextData[{
  StyleBox["CoefMatrix[n,{coeffs}]", "Input"],
  ", gives the matrix of coefficients, for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(n\)\)\)]],
  " number of retention variables and coeffs are coefficients of the matrix. \
They are given as ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"1", ",", " ", "2", ",", " ", 
                FormBox[\(a\_12\),
                  "TraditionalForm"]}], "}"}], ",", 
            RowBox[{"...", 
              RowBox[{"{", 
                RowBox[{"i", ",", " ", "j", ",", " ", 
                  FormBox[\(a\_ij\),
                    "TraditionalForm"]}], "}"}]}], ",", "...", ",", " ", 
            RowBox[{"{", 
              RowBox[{"n", ",", "n", ",", " ", 
                FormBox[\(a\_nn\),
                  "TraditionalForm"]}], "}"}]}], "}"}], TraditionalForm]]],
  " where",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", Cell["ij"], " "}], TraditionalForm]]],
  "is position of the coef. in the matrix (i=file, j=column) and are the \
values  of this coeff (By default ",
  Cell[BoxData[
      \(TraditionalForm\`a\_ij\)]],
  " = 0)."
}], "DefinitionBox"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[\(CoefMatrix[
          3, {{1, 1, a11}, {1, 2, \ a12}, \ {2, 2, \ a22}, \ {2, 3, 
              a23}, \ \ {3, 3, a33}}]\),
        "Input"], "//", "MatrixForm"}]], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"a11", "a12", "0"},
            {"0", "a22", "a23"},
            {"0", "0", "a33"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[8]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "In compatmental analysis can be better  build ",
  StyleBox["A",
    FontWeight->"Bold"],
  " using the package funcion CompartMatrix"
}], "Text"],

Cell[TextData[{
  StyleBox["CompartMatrix[n,{transcoeff},lambda]", "Input"],
  ", gives the matrix of coefficients,also called  constant transfer \
coefficients matrix.  Where n isthe number of compartments and transcoeff are \
the transfer coefficients, also called clearance coeffs. or dissolution \
rates. They are given as {{1, 2, ",
  Cell[BoxData[
      \(TraditionalForm\`k\_12\)]],
  "},...{i, j, ",
  Cell[BoxData[
      \(TraditionalForm\`k\_ij\)]],
  "},..., {n,n, ",
  Cell[BoxData[
      \(TraditionalForm\`k\_nn\)]],
  "}}where ",
  Cell[BoxData[
      \(TraditionalForm\`k\_ij\)]],
  " is the transfer coeff. from compartment i to compartment j (By default \
kij = 0); lambda is the  radioactive decay constant, in the same unit as the \
trans. coef. (by default lambda = 0, which means thatit is not a radioactive \
substance.)"
}], "DefinitionBox"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[\(CompartMatrix[
          3, {{1, 1, k11}, {1, 2, \ k12}, \ {2, 2, \ k22}, \ {2, 3, 
              k23}, \ \ {3, 3, k33}, {2, 0, k20}}, \ \[Lambda]]\),
        "Input"], "//", "MatrixForm"}]], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(-k12\) - \[Lambda]\), "0", "0"},
            {"k12", \(\(-k20\) - k23 - \[Lambda]\), "0"},
            {"0", "k23", \(-\[Lambda]\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[9]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "The solution of eq(1) when the coeffs ",
  Cell[BoxData[
      \(TraditionalForm\`a\_ij\)]],
  "are constants is eq(2)"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      StyleBox["x",
        FontWeight->"Bold"]]],
  Cell[BoxData[
      \(TraditionalForm\`\(\((t)\)\(\ \)\(=\)\)\)]],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["x",
            FontWeight->"Bold",
            FontSlant->"Plain"], "0"], TraditionalForm]],
    TextAlignment->Left,
    TextJustification->0],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["Exp",
            "TraditionalForm"], "(", 
          RowBox[{
            StyleBox["A",
              FontWeight->"Bold",
              FontSlant->"Plain"], " ", 
            FormBox[\(\(t\)\()\)\),
              "TraditionalForm"], " "}]}], TraditionalForm]]],
  "+ ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Integral]\_0\%t\), 
          RowBox[{
            RowBox[{"[", 
              RowBox[{\(Exp(t - \[Tau])\), 
                StyleBox["A",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], "]"}], " ", 
            RowBox[{
              StyleBox["b",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", "\[Tau]", 
              ")"}], \(\[DifferentialD]\[Tau]\)}]}], TraditionalForm]]],
  " \t"
}], "NumberedEquation",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "The exponential matrix Exp(",
  StyleBox["A",
    FontWeight->"Bold"],
  " t) can be build using the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function MatrixExp, however usually is faster the package function \
matrixExp"
}], "Text"],

Cell[TextData[{
  StyleBox["matrixExp[matrixA,t]", "Input"],
  " gives the exponential matrix Exp[A t]"
}], "DefinitionBox"],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(matrixExp[
        CoefMatrix[
          3, {{1, 1, a11}, {1, 2, \ a12}, \ {2, 2, \ a22}, \ {2, 3, 
              a23}, \ \ {3, 3, a33}}], \ t]\),
      "Input"]], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \({{\[ExponentialE]\^\(a11\ t\), \(a12\ \[ExponentialE]\^\(a11\ \
t\)\)\/\(a11 - a22\) - \(a12\ \[ExponentialE]\^\(a22\ t\)\)\/\(a11 - a22\), \
\((\(a12\ a23\)\/\(\((a11 - a22)\)\ \((a22 - a33)\)\) + \(a12\ \
a23\)\/\(\((a11 - a33)\)\ \((\(-a22\) + a33)\)\))\)\ \[ExponentialE]\^\(a11\ \
t\) - \(a12\ a23\ \[ExponentialE]\^\(a22\ t\)\)\/\(\((a11 - a22)\)\ \((a22 - \
a33)\)\) - \(a12\ a23\ \[ExponentialE]\^\(a33\ t\)\)\/\(\((a11 - a33)\)\ \
\((\(-a22\) + a33)\)\)}, {0, \[ExponentialE]\^\(a22\ t\), \(a23\ \
\[ExponentialE]\^\(a22\ t\)\)\/\(a22 - a33\) - \(a23\ \[ExponentialE]\^\(a33\ \
t\)\)\/\(a22 - a33\)}, {0, 0, \[ExponentialE]\^\(a33\ t\)}}\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell[TextData[{
  "For solving eq.(1) (with ",
  Cell[BoxData[
      \(TraditionalForm\`a\_ij\)]],
  " constants) the package has the function ",
  StyleBox["SystemDSolve. ", "Input"],
  "It applies, by default,  an method developed by the author, based in \
eq(2), usually faster that the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " build-up function ",
  StyleBox["DSolve", "Input"],
  ". The package also gives the option so that the user can choose other \
methods:  LaplaceTransform ( Method\[RightArrow] \"LaplaceTransform\"),  the \
eigenvalues-Eigensystem method (Method\[RightArrow]\"EigenValues\"), and  \
Method\[RightArrow]\"DSolve\", in this case is applied the Mathematica \
function ",
  StyleBox["DSolve", "Input"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["SystemDSolve[A, IC, B(t), t, t1, x, options]", "Input"],
  " gives  the solution X(t)= {",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  "(t), ..., ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  "(t) at time t1 of an ODE system X'(t) = A X(t) + B(t), with initial \
conditions X(0) = IC , where the  coeffsmatrix A = {{",
  Cell[BoxData[
      \(TraditionalForm\`a\_11\)]],
  ",..., ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(1  n\)\)]],
  "}, ...,{",
  Cell[BoxData[
      \(TraditionalForm\`a\_n1\)]],
  ", ..., ",
  Cell[BoxData[
      \(TraditionalForm\`a\_nn\)]],
  "}}; IC = {",
  Cell[BoxData[
      \(TraditionalForm\`c\_1\)]],
  ",.., ",
  Cell[BoxData[
      \(TraditionalForm\`c\_i\)]],
  ", .",
  Cell[BoxData[
      \(TraditionalForm\`\(\(..\)\(,\)\(\ \)\(c\_n\)\)\)]],
  "};  B(t) ={",
  Cell[BoxData[
      \(TraditionalForm\`b\_1\)]],
  "[t],...,",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(b\_n\)\)\)]],
  "[t]};  x is the symbol that represents X; with options can be choose the \
method applied for solving the SODE, by default is apply: Method-> Automatic, \
other methods are LaplaceTransform, EigenValues, is applied the \
Eigenvalues-eigensisystem method, and DSolve is applied the Mathematica \
function ",
  StyleBox["DSolve",
    FontWeight->"Bold"],
  "."
}], "DefinitionBox"],

Cell[BoxData[
    \(matrixA\  = \ {{\(-2.86\), \ 0, \ 0.046}, \ {0.83, \ 0.095, \ 
          0}, \ {0, \ 0087, \ 0.144}}; \)], "Input",
  CellLabel->"In[11]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(initialconditions = \ {1, \ 0, \ 0}\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \({1, 0, 0}\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bb\  = \ {1\  + \ Cos[0.1  t], \ 0, \ 0}\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \({1 + Cos[0.1`\ t], 0, 0}\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(SystemDSolve[matrixA, initialconditions, bb, \ t, \ t, \ 
      x]\)\(\ \)\)\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \({x\_1[t] \[Rule] \(-0.004167510526620122`\) + 
          0.24089540705294588`\ \[ExponentialE]\^\(\(-2.2858036768319776`\)\ \
t\) + 0.4567247761064498`\ \[ExponentialE]\^\(\(-1.37761557126222`\)\ t\) + 
          0.30751070531726227`\ \[ExponentialE]\^\(1.0424192480941987`\ t\) - 
          0.0009633779500384243`\ Cos[0.1`\ t] - 
          0.007243076986801947`\ Sin[0.1`\ t], 
      x\_2[t] \[Rule] \(\(0.03641088144309934`\)\(\[InvisibleSpace]\)\) - 
          0.08398138401734995`\ \[ExponentialE]\^\(\(-2.2858036768319776`\)\ \
t\) - 0.2574205865848829`\ \[ExponentialE]\^\(\(-1.37761557126222`\)\ t\) + 
          0.2693990922463827`\ \[ExponentialE]\^\(1.0424192480941987`\ t\) + 
          0.035591996912750945`\ Cos[0.1`\ t] + 
          0.025816360081794856`\ Sin[0.1`\ t], 
      x\_3[t] \[Rule] \(-21.998240871872447`\) + 
          3.006983847779683`\ \[ExponentialE]\^\(\(-2.2858036768319776`\)\ \
t\) + 14.718297746064128`\ \[ExponentialE]\^\(\(-1.37761557126222`\)\ t\) + 
          26.087732509241455`\ \[ExponentialE]\^\(1.0424192480941987`\ t\) - 
          21.814773231212826`\ Cos[0.1`\ t] - 
          0.44823613885325486`\ Sin[0.1`\ t]}\)], "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(SystemDSolve[matrixA, initialconditions, bb, \ t, \ 3, \ 
      x]\)\(\ \)\)\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \({x\_1[3] \[Rule] 7.01508056283246`, x\_2[3] \[Rule] 6.219179922911658`, 
      x\_3[3] \[Rule] 552.3641637747199`}\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell[TextData[{
  "To solve ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[
              OverscriptBox[
                StyleBox["x",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "."],
              FontWeight->"Bold",
              FontSlant->"Plain"], \((t)\)}], " ", "=", 
          RowBox[{
            StyleBox["A",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[" ",
              FontWeight->"Bold"], 
            StyleBox["x",
              FontWeight->"Bold",
              FontSlant->"Plain"], \((t)\)}]}], ",", 
        " ", \(t \[GreaterEqual] 0\)}]],
    TextAlignment->Left,
    TextJustification->0],
  " with i.c.: ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["x",
            FontWeight->"Bold",
            FontSlant->"Plain"], \((0)\)}], " ", "=", 
        SubscriptBox[
          RowBox[{
            StyleBox["x",
              FontWeight->"Bold",
              FontSlant->"Plain"], " "}], "0"]}]],
    TextAlignment->Left,
    TextJustification->0],
  " can be used ",
  StyleBox["SystemDSolve", "Input"],
  ", however it is faster ",
  StyleBox["AcuteInput", "Input"]
}], "Text"],

Cell[TextData[{
  StyleBox["AcuteInput[A, IC,t1, x]", "Input"],
  "gives  the solution X(t)= {x1(t), ..., xn(t) at time t1 of an ODE system \
X'(t) = A X(t) , with initial conditions X(0) = IC "
}], "DefinitionBox"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(AcuteInput[matrixA, initialconditions, \ 
      t, \ \ x]\)\(\ \)\)\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \({x\_1[t] \[Rule] 
        1.9138440754466381`\ \[ExponentialE]\^\(\(-2.2858036768319776`\)\ t\) \
- 1.0195227187671598`\ \[ExponentialE]\^\(\(-1.37761557126222`\)\ t\) + 
          0.10567864332052093`\ \[ExponentialE]\^\(1.0424192480941987`\ t\), 
      x\_2[t] \[Rule] \(-0.66720771564602`\)\ \
\[ExponentialE]\^\(\(-2.2858036768319776`\)\ t\) + 
          0.5746264490816414`\ \[ExponentialE]\^\(\(-1.37761557126222`\)\ t\) \
+ 0.0925812665643788`\ \[ExponentialE]\^\(1.0424192480941987`\ t\), 
      x\_3[t] \[Rule] 
        23.889613722573078`\ \[ExponentialE]\^\(\(-2.2858036768319776`\)\ t\) \
- 32.85488267488791`\ \[ExponentialE]\^\(\(-1.37761557126222`\)\ t\) + 
          8.96526895231483`\ \[ExponentialE]\^\(1.0424192480941987`\ t\)}\)], \
"Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell[TextData[{
  "To solve ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[
              OverscriptBox[
                StyleBox["x",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "."],
              FontWeight->"Bold",
              FontSlant->"Plain"], \((t)\)}], " ", "=", 
          RowBox[{
            RowBox[{
              StyleBox["A",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              StyleBox["x",
                FontWeight->"Bold",
                FontSlant->"Plain"], \((t)\)}], " ", "+", " ", 
            RowBox[{
              StyleBox["a",
                FontWeight->"Bold"], " ", 
              RowBox[{"Exp", "[", 
                RowBox[{
                  StyleBox["b",
                    FontWeight->"Bold"], 
                  StyleBox[" ",
                    FontWeight->"Bold"], \((t)\)}], "]"}]}]}]}], ",", 
        " ", \(t \[GreaterEqual] 0\)}]],
    TextAlignment->Left,
    TextJustification->0],
  " with i.c.: ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["x",
            FontWeight->"Bold",
            FontSlant->"Plain"], \((0)\)}], " ", "=", 
        SubscriptBox[
          RowBox[{
            StyleBox["x",
              FontWeight->"Bold",
              FontSlant->"Plain"], " "}], "0"]}]],
    TextAlignment->Left,
    TextJustification->0],
  " can be used ",
  StyleBox["SystemDSolve", "Input"],
  ", however it is bit faster  ",
  StyleBox["MultiExpInput", "Input"]
}], "Text"],

Cell[TextData[{
  StyleBox["MultiExpInput[A, IC, B(t), t, t1, x, options]", "Input"],
  " gives  the solution X(t)= {x1(t), ..., xn(t) at time t1 of an ODE system \
X'(t) = A X(t) + B(t), with initial conditions X(0) = IC , being B(t) = ",
  StyleBox["a",
    FontWeight->"Bold"],
  " Exp[",
  StyleBox["b",
    FontWeight->"Bold"],
  " (t)]"
}], "DefinitionBox"],

Cell[BoxData[
    \(ee\  = \ {\ 
        0.1\ Exp[\(-\ 0.3\)\ t]\  + \ \ 0.2\ \ Exp[\(-\ 0.001\)\ \ t], \ 0, \ 
        3.0\ \ Exp[\(-\ 0.017\)\ \ t]}; \)], "Input",
  CellLabel->"In[17]:="],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["MultiExpInput",
          "Input"], "[", \(matrixA, initialconditions, ee, \ t, \ t, \ x\), 
        "]"}], " "}]], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \({x\_1[t] \[Rule] 
        1.6978487262492685`\ \[ExponentialE]\^\(\(-2.2858036768319776`\)\ t\) \
- 0.8447506317928553`\ \[ExponentialE]\^\(\(-1.37761557126222`\)\ t\) - 
          0.006105085162074073`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) + 
          0.004726034588046782`\ \[ExponentialE]\^\(\(-0.017`\)\ t\) - 
          0.0008482987368832184`\ \[ExponentialE]\^\(\(-0.001`\)\ t\) + 
          0.14912925485449655`\ \[ExponentialE]\^\(1.0424192480941987`\ t\), 
      x\_2[t] \[Rule] \(-0.5919070339567298`\)\ \
\[ExponentialE]\^\(\(-2.2858036768319776`\)\ t\) + 
          0.4761208818314343`\ \[ExponentialE]\^\(\(-1.37761557126222`\)\ t\) \
+ 0.012828406796256853`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
          0.03502329203641795`\ \[ExponentialE]\^\(\(-0.017`\)\ t\) + 
          0.007334249495969183`\ \[ExponentialE]\^\(\(-0.001`\)\ t\) + 
          0.13064678786948747`\ \[ExponentialE]\^\(1.0424192480941987`\ t\), 
      x\_3[t] \[Rule] 
        21.193445563213892`\ \[ExponentialE]\^\(\(-2.2858036768319776`\)\ t\) \
- 27.22272136382891`\ \[ExponentialE]\^\(\(-1.37761557126222`\)\ t\) - 
          2.5136743046719463`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) + 
          0.29208948551776004`\ \[ExponentialE]\^\(\(-0.017`\)\ t\) - 
          4.4005496975815`\ \[ExponentialE]\^\(\(-0.001`\)\ t\) + 
          12.651410317350702`\ \[ExponentialE]\^\(1.0424192480941987`\ \
t\)}\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell[TextData[{
  "Sometime the user can be interested in obtaining the laplace transform ",
  StyleBox["X",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\((s)\)\)]],
  " of ",
  Cell[BoxData[
      StyleBox["x",
        FontWeight->"Bold"]]],
  Cell[BoxData[
      \(TraditionalForm\`\(\((t)\)\(\ \)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Taken the laplace transform of eq(1) (",
  StyleBox["X",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\((s)\)\)]],
  " and ",
  StyleBox["B",
    FontWeight->"Bold"],
  "(s) are de Laplace transform of ",
  StyleBox["x",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\((t)\)\)]],
  " and ",
  StyleBox["b",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\((t)\)\)]],
  ")"
}], "Text"],

Cell[TextData[{
  "s ",
  StyleBox["X",
    FontWeight->"Bold"],
  "(s) - ",
  StyleBox["x",
    FontWeight->"Bold"],
  "(0) = ",
  StyleBox["A",
    FontWeight->"Bold"],
  " ",
  StyleBox["X",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\((s)\)\)]],
  " + ",
  StyleBox["B",
    FontWeight->"Bold"],
  "(s) \[DoubleRightArrow](",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  StyleBox[" I",
    FontWeight->"Bold"],
  " - ",
  StyleBox["A",
    FontWeight->"Bold"],
  ") ",
  StyleBox["X",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((s)\)\)]],
  "  =  ",
  StyleBox["x",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\(\((0)\)\(\ \)\)\)]],
  " + ",
  StyleBox["B",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\((s)\)\)]],
  " and from here"
}], "Text"],

Cell[TextData[{
  StyleBox["X",
    FontWeight->"Bold"],
  " (s)= (s",
  StyleBox[" I",
    FontWeight->"Bold"],
  " - ",
  StyleBox["A",
    FontWeight->"Bold"],
  ")",
  Cell[BoxData[
      \(\^\(-1\)\)]],
  StyleBox["x",
    FontWeight->"Bold"],
  "(0) + (s",
  StyleBox[" I",
    FontWeight->"Bold"],
  " - ",
  StyleBox["A",
    FontWeight->"Bold"],
  ")",
  Cell[BoxData[
      \(\^\(-1\)\)]],
  StyleBox["B",
    FontWeight->"Bold"],
  "(s)"
}], "NumberedEquation"],

Cell[TextData[{
  StyleBox["X",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\((s)\)\)]],
  " can be obtained using the package function ",
  StyleBox["SystemLTSolve", "Input"],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["SystemLTSolve[A, IC, B(t), t, s, X]", "Input"],
  " gives  the laplace transform solution X(s)= {",
  Cell[BoxData[
      \(TraditionalForm\`X\_1\)]],
  "(s), ..., ",
  Cell[BoxData[
      \(TraditionalForm\`X\_n\)]],
  "(s)}  of an ODE system x'(t) = A x(t) + b(t),  with initial conditions \
IC.: x(0) ."
}], "DefinitionBox"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["SystemLTSolve",
          "Input"], "[", \(matrixA, initialconditions, ee, \ t, \ s, \ X\), 
        "]"}], " "}]], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \({X\_1[s] \[Rule] 
        0.10567864332052096`\/\(\(-1.0424192480941987`\) + s\) - 
          1.0195227187671618`\/\(\(\(1.377615571262221`\)\(\[InvisibleSpace]\)\
\) + s\) + 
          1.9138440754466408`\/\(\(\(2.2858036768319776`\)\(\[InvisibleSpace]\
\)\) + s\) + \(3.`\ \((0.005410856460450931`\/\(\(-1.0424192480941987`\) + \
s\) + 0.030821217887765342`\/\(\(\(1.377615571262221`\)\(\[InvisibleSpace]\)\)\
 + s\) - 0.036232074348216264`\/\(\(\(2.2858036768319776`\)\(\[InvisibleSpace]\
\)\) + s\))\)\)\/\(\(\(0.017`\)\(\[InvisibleSpace]\)\) + s\) + \
\((0.2`\/\(\(\(0.001`\)\(\[InvisibleSpace]\)\) + s\) + 
                0.1`\/\(\(\(0.3`\)\(\[InvisibleSpace]\)\) + s\))\)\ \
\((0.10567864332052096`\/\(\(-1.0424192480941987`\) + s\) - 
                1.0195227187671618`\/\(\(\(1.377615571262221`\)\(\
\[InvisibleSpace]\)\) + s\) + 
                1.9138440754466408`\/\(\(\(2.2858036768319776`\)\(\
\[InvisibleSpace]\)\) + s\))\), 
      X\_2[s] \[Rule] 
        0.09258126656437883`\/\(\(-1.0424192480941987`\) + s\) + 
          0.5746264490816423`\/\(\(\(1.377615571262221`\)\(\[InvisibleSpace]\)\
\) + s\) - 
          0.6672077156460211`\/\(\(\(2.2858036768319776`\)\(\[InvisibleSpace]\
\)\) + s\) + \((0.2`\/\(\(\(0.001`\)\(\[InvisibleSpace]\)\) + s\) + 
                0.1`\/\(\(\(0.3`\)\(\[InvisibleSpace]\)\) + s\))\)\ \
\((0.09258126656437883`\/\(\(-1.0424192480941987`\) + s\) + 
                0.5746264490816423`\/\(\(\(1.377615571262221`\)\(\
\[InvisibleSpace]\)\) + s\) - 
                0.6672077156460211`\/\(\(\(2.2858036768319776`\)\(\
\[InvisibleSpace]\)\) + s\))\) + \(3.`\ \
\((0.004740257147200947`\/\(\(-1.0424192480941987`\) + s\) - \
0.017371547161435012`\/\(\(\(1.377615571262221`\)\(\[InvisibleSpace]\)\) + \
s\) + 0.012631290014234063`\/\(\(\(2.2858036768319776`\)\(\[InvisibleSpace]\)\
\) + s\))\)\)\/\(\(\(0.017`\)\(\[InvisibleSpace]\)\) + s\), 
      X\_3[s] \[Rule] 
        8.965268952314835`\/\(\(-1.0424192480941987`\) + s\) - 
          32.85488267488795`\/\(\(\(1.377615571262221`\)\(\[InvisibleSpace]\)\
\) + s\) + 
          23.88961372257312`\/\(\(\(2.2858036768319776`\)\(\[InvisibleSpace]\)\
\) + s\) + \(3.`\ \((0.45903109565083816`\/\(\(-1.0424192480941987`\) + s\) + \
0.993236814599079`\/\(\(\(1.377615571262221`\)\(\[InvisibleSpace]\)\) + s\) - \
0.45226791024991714`\/\(\(\(2.2858036768319776`\)\(\[InvisibleSpace]\)\) + \
s\))\)\)\/\(\(\(0.017`\)\(\[InvisibleSpace]\)\) + s\) + \((0.2`\/\(\(\(0.001`\
\)\(\[InvisibleSpace]\)\) + s\) + 
                0.1`\/\(\(\(0.3`\)\(\[InvisibleSpace]\)\) + s\))\)\ \
\((8.965268952314835`\/\(\(-1.0424192480941987`\) + s\) - 
                32.85488267488795`\/\(\(\(1.377615571262221`\)\(\
\[InvisibleSpace]\)\) + s\) + 
                23.88961372257312`\/\(\(\(2.2858036768319776`\)\(\
\[InvisibleSpace]\)\) + s\))\)}\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell[TextData[{
  "The inverse laplace transform of (3) gives ",
  StyleBox["x",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((t)\)\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["x",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((t)\)\)]],
  "= ",
  Cell[BoxData[
      \(LT\^\(-1\)\)]],
  "[(s",
  StyleBox[" I",
    FontWeight->"Bold"],
  " - ",
  StyleBox["A",
    FontWeight->"Bold"],
  ")",
  Cell[BoxData[
      \(\^\(-1\)\)]],
  StyleBox["x",
    FontWeight->"Bold"],
  "(0)] + ",
  Cell[BoxData[
      \(LT\^\(-1\)\)]],
  "[(s",
  StyleBox[" I",
    FontWeight->"Bold"],
  " - ",
  StyleBox["A",
    FontWeight->"Bold"],
  ")",
  Cell[BoxData[
      \(\^\(-1\)\)]],
  StyleBox["B",
    FontWeight->"Bold"],
  "(s)]"
}], "NumberedEquation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(InverseLaplaceTransform[{X\_1[s], X\_2[s], X\_3[s]}\  /. %, \ s, \ 
      t]\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({1.6978487262492707`\ \[ExponentialE]\^\(\(-2.2858036768319776`\)\ t\) \
- 0.8447506317928567`\ \[ExponentialE]\^\(\(-1.377615571262221`\)\ t\) - 
        0.006105085162074049`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) + 
        0.004726034588046756`\ \[ExponentialE]\^\(\(-0.017`\)\ t\) - 
        0.0008482987368832027`\ \[ExponentialE]\^\(\(-0.001`\)\ t\) + 
        0.1491292548544967`\ \[ExponentialE]\^\(1.0424192480941987`\ t\), \
\(-0.5919070339567306`\)\ \[ExponentialE]\^\(\(-2.2858036768319776`\)\ t\) + 
        0.4761208818314351`\ \[ExponentialE]\^\(\(-1.377615571262221`\)\ t\) \
+ 0.012828406796256835`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) - 
        0.03502329203641793`\ \[ExponentialE]\^\(\(-0.017`\)\ t\) + 
        0.007334249495969181`\ \[ExponentialE]\^\(\(-0.001`\)\ t\) + 
        0.13064678786948752`\ \[ExponentialE]\^\(1.0424192480941987`\ t\), 
      21.193445563213935`\ \[ExponentialE]\^\(\(-2.2858036768319776`\)\ t\) - 
        27.222721363828953`\ \[ExponentialE]\^\(\(-1.377615571262221`\)\ t\) \
- 2.513674304671948`\ \[ExponentialE]\^\(\(-0.3`\)\ t\) + 
        0.2920894855177604`\ \[ExponentialE]\^\(\(-0.017`\)\ t\) - 
        4.400549697581502`\ \[ExponentialE]\^\(\(-0.001`\)\ t\) + 
        12.651410317350718`\ \[ExponentialE]\^\(1.0424192480941987`\ t\)}\)], \
"Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell[TextData[{
  "This is the method applied for ",
  StyleBox["SystemDSolve", "Input"],
  " when the user chose  Method\[RightArrow] \"LaplaceTransform\""
}], "Text"],

Cell[TextData[{
  "For solving eq.(1) when ",
  Cell[BoxData[
      \(TraditionalForm\`a\_ij\)]],
  " are not constants it can be applied  the package function ",
  StyleBox["SystemNDSolve", "Input"],
  "  that applied the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["NDSolve", "Input"],
  " for solving eq.(1). Of course, it can be also applied when ",
  Cell[BoxData[
      \(TraditionalForm\`a\_ij\)]],
  " are constants. "
}], "Text"],

Cell[TextData[{
  StyleBox["SystemNDSolve[A, IC, B(t), {t,tmin, tmax}, t1, x, options]", 
    "Input"],
  " gives  the numeric solution X(t)= {",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  "(t), ..., ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  "(t) at time t1 of an ODE system X'(t) = A(t)   X(t) + B(t), with initial \
conditions X(0) = IC , where the  coeffsmatrix A = {{",
  Cell[BoxData[
      \(TraditionalForm\`\(a\_11\)(t)\)]],
  ",..., ",
  Cell[BoxData[
      \(TraditionalForm\`\(a\_\(1  n\)\)(t)\)]],
  "}, ...,{",
  Cell[BoxData[
      \(TraditionalForm\`\(a\_n1\)(t)\)]],
  ", ..., ",
  Cell[BoxData[
      \(TraditionalForm\`\(a\_nn\)(t)\)]],
  "}}; IC = {",
  Cell[BoxData[
      \(TraditionalForm\`c\_1\)]],
  ",.., ",
  Cell[BoxData[
      \(TraditionalForm\`c\_i\)]],
  ", .",
  Cell[BoxData[
      \(TraditionalForm\`\(\(..\)\(,\)\(\ \)\(c\_n\)\)\)]],
  "};  B(t) ={",
  Cell[BoxData[
      \(TraditionalForm\`b\_1\)]],
  "[t],...,",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(b\_n\)\)\)]],
  "[t]};  x is the symbol that represents X; ; options are the options of ",
  StyleBox["NDSolve",
    FontWeight->"Bold"],
  ". "
}], "DefinitionBox"],

Cell[BoxData[
    \(matrixA1\  = \ {{0.0286\ Cos[\ \(-\ 0.2\)\ t], \ 0, \ 
          0.046\ \ Sin[0.05\ t]}, \ {0.083, \ 0.0095, \ 0}, \ {0, \ 002, \ 
          0.0014}}; \)], "Input",
  CellLabel->"In[21]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(SystemNDSolve[matrixA1, initialconditions, 
      bb, \ {t, \ 0, \ 100}, \ 10, \ x]\)\(\ \)\)\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \({x\_1[10] \[Rule] 23.280474189642238`, 
      x\_2[10] \[Rule] 10.058472670612655`, 
      x\_3[10] \[Rule] 68.8452743624067`}\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell["Other functions", "Text"],

Cell[TextData[{
  StyleBox["ShowODE[A, IC, B(t), t, t1, x, options]", "Input"],
  " represents in classic mathematical notation a System od ODE  X'(t) = A \
X(t) + B(t), with initial conditions X(0) = IC , where the  coeffsmatrix A = \
{{",
  Cell[BoxData[
      \(TraditionalForm\`a\_11\)]],
  ",..., ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(1  n\)\)]],
  "}, ...,{",
  Cell[BoxData[
      \(TraditionalForm\`a\_n1\)]],
  ", ..., ",
  Cell[BoxData[
      \(TraditionalForm\`a\_nn\)]],
  "}}; IC = {",
  Cell[BoxData[
      \(TraditionalForm\`c\_1\)]],
  ",.., ",
  Cell[BoxData[
      \(TraditionalForm\`c\_i\)]],
  ", .",
  Cell[BoxData[
      \(TraditionalForm\`\(\(..\)\(,\)\(\ \)\(c\_n\)\)\)]],
  "};  B(t) ={",
  Cell[BoxData[
      \(TraditionalForm\`b\_1\)]],
  "[t],...,",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(b\_n\)\)\)]],
  "[t]};  x is the symbol that represents X."
}], "DefinitionBox"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowODE[matrixA, initialconditions, bb, \ t, \ x] // TableForm\)\  // 
      TraditionalForm\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              RowBox[{
                RowBox[{
                  SuperscriptBox[\(x\_1\), "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], 
                "\[LongEqual]", \(cos(0.1`\ t) - 2.86`\ \(\(x\_1\)(t)\) + 
                  0.046`\ \(\(x\_3\)(t)\) + 1\)}]},
            {
              RowBox[{
                RowBox[{
                  SuperscriptBox[\(x\_2\), "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], 
                "\[LongEqual]", \(0.83`\ \(\(x\_1\)(t)\) + 
                  0.095`\ \(\(x\_2\)(t)\)\)}]},
            {
              RowBox[{
                RowBox[{
                  SuperscriptBox[\(x\_3\), "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], 
                "\[LongEqual]", \(87\ \(\(x\_2\)(t)\) + 
                  0.144`\ \(\(x\_3\)(t)\)\)}]},
            {\(\(x\_1\)(0) \[LongEqual] 1\)},
            {\(\(x\_2\)(0) \[LongEqual] 0\)},
            {\(\(x\_3\)(0) \[LongEqual] 0\)}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {
          Equal[ 
            Derivative[ 1][ 
              Subscript[ x, 1]][ t], 
            Plus[ 1, 
              Cos[ 
                Times[ .10000000000000001, t]], 
              Times[ -2.8599999999999999, 
                Subscript[ x, 1][ t]], 
              Times[ .045999999999999999, 
                Subscript[ x, 3][ t]]]], 
          Equal[ 
            Derivative[ 1][ 
              Subscript[ x, 2]][ t], 
            Plus[ 
              Times[ .82999999999999996, 
                Subscript[ x, 1][ t]], 
              Times[ .095000000000000001, 
                Subscript[ x, 2][ t]]]], 
          Equal[ 
            Derivative[ 1][ 
              Subscript[ x, 3]][ t], 
            Plus[ 
              Times[ 87, 
                Subscript[ x, 2][ t]], 
              Times[ .14399999999999999, 
                Subscript[ x, 3][ t]]]], 
          Equal[ 
            Subscript[ x, 1][ 0], 1], 
          Equal[ 
            Subscript[ x, 2][ 0], 0], 
          Equal[ 
            Subscript[ x, 3][ 0], 0]}]], TraditionalForm]], "Output",
  CellLabel->"Out[23]//TraditionalForm="]
}, Open  ]],

Cell["In compartmental analysis can be useful this function", "Text"],

Cell[TextData[{
  StyleBox["Catenary[b, n, t, K, k, lambda]", "Input"],
  " gives the amount  (activity,mass,concentration, etc.) in the n-th \
compartment of a one-way catenary chain at any time t after a single intake b \
in the first compartment of the chain, K is the general symbol applied for \
indicate the total transfer since one compartment and k notate the transfer \
since any compartments of the catenary chain;  lambda is the radioactive \
decay constant, in the same unit that the trans. coef. (by default i lambda = \
0, which means it that is not a radioactive substance. "
}], "DefinitionBox"],

Cell["\<\
The transfer coefficients are given as ki and Ki where ki is the transfer \
coeffs, from compartment i to compartment i+1 and Ki is the total transfer \
coeffs. from i to others. \";\
\>", "Commentary"],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(Catenary[b, \ 3, \ t, \ K, \ k, \[Lambda]]\),
      "Input"]], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \(b\ \[ExponentialE]\^\(\(-t\)\ \[Lambda]\)\ k\_1\ k\_2\ \((\
\[ExponentialE]\^\(\(-t\)\ K\_3\)\/\(\((K\_1 - K\_3)\)\ \((K\_2 - K\_3)\)\) + \
\[ExponentialE]\^\(\(-t\)\ K\_1\)\/\(\((\(-K\_1\) + K\_2)\)\ \((\(-K\_1\) + K\
\_3)\)\) + \[ExponentialE]\^\(\(-t\)\ K\_2\)\/\(\((K\_1 - K\_2)\)\ \((\(-K\_2\
\) + K\_3)\)\))\)\)], "Output",
  CellLabel->"Out[24]="]
}, Open  ]],

Cell[TextData[{
  "To see how can be fitted coefficients in System of ODE see in the package \
help: ",
  StyleBox["Model fitting", "Input"]
}], "Text"],

Cell[BoxData[
    \(ClearAll[matrixA\ , initialconditions, bb\ , \ ee, \ 
      matrixA1]\)], "Input",
  CellLabel->"In[25]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["DSolve ", "SubsectionIcon"],

Cell[TextData[{
  "If  we have a short number of variables the the analytical solution of the \
SODE can be obteined using ",
  StyleBox["DSolve", "DisplayMath"],
  ".  A short introduction to ",
  StyleBox["DSolve", "DisplayMath"],
  " follow."
}], "Text"],

Cell[TextData[{
  " ",
  StyleBox["DSolve[eqn, y[t], t]", "DisplayMath"],
  " solves the differential equation eqn for the function ",
  Cell[BoxData[
      \(TraditionalForm\`y(t)\)]],
  ", with independent variable\[NonBreakingSpace]",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ". "
}], "Text"],

Cell["\<\
Here is the solution to a first\[Hyphen]order differential equation. \
\>", "MathCaption",
  CellTags->"DSolve"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DSolve", "[", 
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "x", "]"}], "==", \(a\ y[x]\)}], 
        ",", \(y[x]\), ",", "x"}], "]"}]], "Input",
  CellLabel->"In[26]:=",
  CellTags->"DSolve"],

Cell[BoxData[
    \({{y[x] \[Rule] \[ExponentialE]\^\(a\ x\)\ C[1]}}\)], "Output",
  CellLabel->"Out[26]=",
  CellTags->"DSolve"]
}, Open  ]],

Cell["\<\
You can add constraints and boundary conditions for differential equations by \
explicitly giving additional equations such as y[0] \[Equal] b as in this \
example.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DSolve", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "==", \(a\ y[t]\)}], ",", \(y[0] == b\)}], "}"}], ",", \(y[t]\),
         ",", "t"}], "]"}]], "Input",
  CellLabel->"In[27]:=",
  CellTags->"DSolve"],

Cell[BoxData[
    \({{y[t] \[Rule] b\ \[ExponentialE]\^\(a\ t\)}}\)], "Output",
  CellLabel->"Out[27]=",
  CellTags->"DSolve"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      RowBox[{
        StyleBox["DSolve",
          "MR"], 
        StyleBox["[",
          "MR"], 
        RowBox[{
          RowBox[{
            FormBox["{",
              "TraditionalForm"], 
            RowBox[{
              FormBox[
                
                SubscriptBox["\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"eqn\\\\\\\"\\\
\", \\\"TI\\\"]\\)\"\>", "1"],
                "TraditionalForm"], 
              StyleBox[",",
                "MR"], " ", 
              FormBox[
                
                SubscriptBox["\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"eqn\\\\\\\"\\\
\", \\\"TI\\\"]\\)\"\>", "2"],
                "TraditionalForm"], 
              StyleBox[",",
                "MR"], "\[Ellipsis]"}], 
            FormBox["}",
              "TraditionalForm"]}], 
          StyleBox[",",
            "MR"], " ", 
          RowBox[{
            FormBox["{",
              "TraditionalForm"], 
            RowBox[{
              FormBox[
                
                SubscriptBox["\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"y\\\\\\\"\\\",\
 \\\"TI\\\"]\\)\"\>", "1"],
                "TraditionalForm"], 
              StyleBox[",",
                "MR"], " ", 
              FormBox[
                
                SubscriptBox["\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"y\\\\\\\"\\\",\
 \\\"TI\\\"]\\)\"\>", "2"],
                "TraditionalForm"], 
              StyleBox[",",
                "MR"], "\[Ellipsis]"}], 
            FormBox["}",
              "TraditionalForm"]}]}], "]"}]]],
  "solves a list of differential equations"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DSolve", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{\(y[t]\), "==", 
              RowBox[{"-", 
                RowBox[{
                  SuperscriptBox["z", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
            RowBox[{\(z[t]\), "==", 
              RowBox[{"-", 
                RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}], 
        ",", \({y[t], z[t]}\), ",", "t"}], "]"}]], "Input",
  CellLabel->"In[28]:=",
  CellTags->"DSolve"],

Cell[BoxData[
    \({{z[t] \[Rule] 
          1\/2\ \[ExponentialE]\^\(-t\)\ \((1 + \[ExponentialE]\^\(2\ t\))\)\ \
C[1] - 1\/2\ \[ExponentialE]\^\(-t\)\ \((\(-1\) + \[ExponentialE]\^\(2\ \
t\))\)\ C[2], 
        y[t] \[Rule] \(-\(1\/2\)\)\ \[ExponentialE]\^\(-t\)\ \((\(-1\) + \
\[ExponentialE]\^\(2\ t\))\)\ C[1] + 
            1\/2\ \[ExponentialE]\^\(-t\)\ \((1 + \[ExponentialE]\^\(2\ \
t\))\)\ C[2]}}\)], "Output",
  CellLabel->"Out[28]=",
  CellTags->"DSolve"]
}, Open  ]],

Cell["Being the following  linear differential equation system", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\_1' \((t)\)\)\(\ \)\(=\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(1\)\(-\)\(\ \)\(2.5\ \(\(x\_1\)(
            t)\)\)\(\ \ \)\(+\)\(\ \)\(\(x\_2\)(t)\)\(\ \ \)\)\)]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\_2' \((t)\)\)\(\ \)\(=\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(2\ \(\(x\_1\)(
            t)\)\)\(\ \ \)\(-\)\(\ \)\(\(x\_2\)(t)\)\(\ \)\)\)\)]],
  "\nInitial conditions: ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(x\_1\)(0)\)\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(x\_1\)(0)\)\)\)]],
  " = 0"
}], "DisplayFormula"],

Cell["Here is the solution", "MathCaption"],

Cell[BoxData[
    \(Clear[x1, x2]\)], "Input",
  CellLabel->"In[29]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DSolve[\[IndentingNewLine]{\(x1'\)[t] \[Equal] \ 
              1 - \ 2.5\ x1[t] + \ \ x2[t], \[IndentingNewLine]\(x2'\)[
                t] \[Equal] 2\ x1[t]\  - \ \ \ x2[t], x1[0] == 0, \ 
            x2[0] == \ 0}, \[IndentingNewLine]{x1[t], x2[t]}, \ t] // 
        FullSimplify\) // Chop\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \({{x1[t] \[Rule] \(\(2.`\)\(\[InvisibleSpace]\)\) - 
            0.2191311905569695`\ \[ExponentialE]\^\(\(-3.350781059358212`\)\ \
t\) - 1.7808688094430303`\ \[ExponentialE]\^\(\(-0.14921894064178787`\)\ t\), 
        x2[t] \[Rule] \(\(4.`\)\(\[InvisibleSpace]\)\) + 
            0.18643266644048473`\ \[ExponentialE]\^\(\(-3.350781059358212`\)\ \
t\) - 4.186432666440485`\ \[ExponentialE]\^\(\(-0.14921894064178787`\)\ t\)}}\
\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell["We extract x1[t] and x2[t] with %[[1]] ", "MathCaption"],

Cell[BoxData[
    \({x1[t_], x2[t_]} = {x1[t], x2[t]} /. %[\([\)\(1\)\(]\)]\ ; \)], "Input",\

  CellLabel->"In[31]:="],

Cell["\<\
If we plot the solution we realize that solution go back unstable when the \
time is increasing\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{x1[t], \ x2[t]}, \ {t, 0, 100}]\)], "Input",
  CellLabel->"In[32]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0147151 0.147151 [
[.21429 .00222 -6 -9 ]
[.21429 .00222 6 0 ]
[.40476 .00222 -6 -9 ]
[.40476 .00222 6 0 ]
[.59524 .00222 -6 -9 ]
[.59524 .00222 6 0 ]
[.78571 .00222 -6 -9 ]
[.78571 .00222 6 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .16187 -6 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .45617 -6 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(20)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(40)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(60)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(80)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(100)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16187 m
.03006 .16187 L
s
[(1)] .01131 .16187 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(2)] .01131 .30902 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(3)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(4)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .03042 L
.02605 .04138 L
.02846 .05908 L
.03068 .07084 L
.03279 .07997 L
.04262 .1138 L
.06244 .16596 L
.08265 .20478 L
.10458 .23509 L
.12442 .25484 L
.14545 .27005 L
.16498 .28032 L
.18328 .28748 L
.20353 .29333 L
.22205 .29728 L
.24104 .3003 L
.26176 .30272 L
.28144 .30439 L
.30241 .30569 L
.32382 .30663 L
.34399 .30728 L
.36407 .30775 L
.38254 .30807 L
.40136 .30831 L
.42203 .30851 L
.44154 .30864 L
.46245 .30875 L
.48369 .30882 L
.50381 .30888 L
.52372 .30891 L
.54214 .30894 L
.56081 .30896 L
.58141 .30898 L
.60076 .30899 L
.62161 .30899 L
.64165 .309 L
.66275 .30901 L
.68249 .30901 L
.70086 .30901 L
.72132 .30901 L
.73991 .30901 L
.75909 .30901 L
.77989 .30902 L
.79976 .30902 L
.82081 .30902 L
.84038 .30902 L
.85869 .30902 L
.87898 .30902 L
.89752 .30902 L
Mistroke
.91654 .30902 L
.93728 .30902 L
.95613 .30902 L
.97619 .30902 L
Mfstroke
.02381 .01472 m
.04262 .14455 L
.06244 .26703 L
.08255 .35792 L
.10458 .42954 L
.12415 .47543 L
.14509 .5112 L
.16639 .53734 L
.18653 .5552 L
.20651 .56813 L
.22495 .57696 L
.24367 .58366 L
.2643 .58909 L
.28371 .59282 L
.30459 .59575 L
.32572 .59788 L
.34581 .59935 L
.36562 .60041 L
.384 .60114 L
.40453 .60174 L
.42313 .60214 L
.44238 .60245 L
.4632 .60269 L
.48314 .60286 L
.5042 .60299 L
.52384 .60308 L
.54217 .60314 L
.56253 .60319 L
.58108 .60322 L
.60017 .60325 L
.62093 .60327 L
.6407 .60328 L
.66171 .60329 L
.68118 .6033 L
.69946 .6033 L
.71964 .60331 L
.73815 .60331 L
.75707 .60331 L
.77777 .60331 L
.79738 .60332 L
.81833 .60332 L
.83968 .60332 L
.85983 .60332 L
.87985 .60332 L
.8983 .60332 L
.91706 .60332 L
.9377 .60332 L
.95626 .60332 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[32]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00?@3oool4000000<0oooo0P00000/0?ooo`<000000P3oool2000002/0oooo0`0000040?oo
o`800000;03oool2000000@0oooo0P00000X0?ooo`D000000P3oool2000000@0oooo0P0000080?oo
o`00?@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000002`0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0X0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000:P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
02T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool01@3oool003h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
000Y0?ooo`D0000000D0oooo0000003oool0oooo0000000Z0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000:P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000002T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool01@3oool003l0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo02L0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000Z
0?ooo`<000000`3oool010000000oooo0?ooo`00000[0?ooo`8000000`3oool010000000oooo0?oo
o`00000Y0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00D0oooo000m0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000:P3oool00`000000oooo000000020?ooo`040000003oool0oooo000002/0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000Z0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000:@3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`00?P3oool2000000@0oooo0P00000/
0?ooo`8000000`3oool2000002`0oooo0`0000030?ooo`800000;03oool2000000@0oooo0P00000Y
0?ooo`800000103oool2000000@0oooo0P0000080?ooo`00o`3ooolQ0?ooo`003P3oool00`000000
oooo0?ooo`3o0?oooa00oooo000>0?ooo`030000003oool0oooo0?l0oooo403oool000h0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`003P3oool00`000000oooo0?ooo`3o0?oooa00oooo00070?oo
ool000004P0000080?ooo`003P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0303oool000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo00`0oooo000>0?ooo`030000003oool0oooo0?l0oooo403o
ool000h0oooo0P00003o0?oooa40oooo000>0?ooo`800000o`3ooolA0?ooo`003P3oool200000?l0
oooo4@3oool000h0oooo0P00003o0?oooa40oooo000>0?ooo`800000o`3ooolA0?ooo`003P3oool2
00000?l0oooo4@3oool000h0oooo0P00003o0?oooa40oooo000>0?ooo`<00000o`3oool@0?ooo`00
3P3oool300000?l0oooo403oool000h0oooo0`00003o0?oooa00oooo000>0?ooo`030000003oool0
00000?l0oooo403oool000h0oooo00<000000?ooo`000000o`3oool@0?ooo`003P3oool300000?l0
oooo403oool000h0oooo00<000000?ooo`000000o`3oool@0?ooo`003P3oool010000000oooo0000
0000003o0?ooo`l0oooo000>0?ooo`040000003oool0000000000?l0oooo3`3oool000h0oooo00@0
00000?ooo`3oool00000o`3oool?0?ooo`003P3oool010000000oooo0?ooo`00003o0?ooo`l0oooo
000>0?ooo`040000003oool0oooo00000?l0oooo3`3oool000h0oooo00<000000?ooo`3oool00P00
003o0?ooo`h0oooo000>0?ooo`80000000<0oooo000000000000o`3oool>0?ooo`003P3oool01@00
0000oooo0?ooo`3oool000000?l0oooo3P3oool000h0oooo00@000000?ooo`3oool0oooo0P00003o
0?ooo`d0oooo000>0?ooo`040000003oool0oooo0?ooo`800000o`3oool=0?ooo`003P3oool01000
0000oooo0?ooo`3oool200000?l0oooo3@3oool000h0oooo00L000000?ooo`3oool0oooo0000003o
ool000000?l0oooo303oool000h0oooo00L000000?ooo`3oool0oooo0000003oool000000?l0oooo
303oool000h0oooo00L000000?ooo`3oool0oooo0000003oool000000?l0oooo303oool000h0oooo
0P0000030?ooo`030000003oool000000?l0oooo2`3oool000h0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0000003o0?ooo`/0oooo000>0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`000000o`3oool;0?ooo`003P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000?l0oooo2P3oool000h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00003o
0?ooo`X0oooo000>0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000003o
0?ooo`T0oooo00050?ooo`D00000103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000o`3oool90?ooo`001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool00000o`3oool90?ooo`001`3oool00`000000oooo0?ooo`040?oo
o`800000103oool01@000000oooo0?ooo`3oool000000?l0oooo203oool000L0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000o`3oool8
0?ooo`001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`D0oooo00060?ooo`8000001P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool50?ooo`00
3P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
o`3oool40?ooo`003P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0o`3oool40?ooo`003P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0o`3oool30?ooo`003P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool30?ooo`003P3oool2000000D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooo`80oooo000>0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooo`80oooo
000>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3o0?ooo`40oooo000>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`3o0?ooo`40oooo000>0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`3o0?ooo`003P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0oP3oool000h0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?h0oooo000>0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3m0?ooo`003P3oool2
000000H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3l0?ooo`003P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0n`3oool000h0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?/0
oooo000>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`3j0?ooo`003P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0n@3oool000h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0?P0oooo000>0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`3g0?ooo`003P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0mP3oool000h0oooo0P0000070?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0m@3oool000h0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?@0oooo000>0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool03`3oool200000?@0oooo000>0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3a0?ooo`003P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0180oooo0P00003a0?ooo`003P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0kP3oool000h0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0E0?ooo`800000kP3oool000h0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0G0?ooo`800000k03oool000h0oooo0P0000090?oo
o`030000003oool0oooo01P0oooo0P00003Z0?ooo`003P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo01X0oooo0P00003X0?ooo`003P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo01`0oooo0`00003U0?ooo`003P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo01l0oooo0`00003R0?ooo`003P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0240oooo1000003N0?ooo`003P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
02D0oooo1@00003I0?ooo`001@3oool4000000D0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0Z0?ooo`X00000c`3oool000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo03@0oooo4@00002n0?ooo`001P3oool00`000000oooo0?oo
o`050?ooo`8000002`3oool00`000000oooo0?ooo`140?oook0000003P3oool000L0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo0`3oool0
00D0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0?l0oooo0`3oool000H0oooo0P0000060?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0o`3oool30?ooo`003P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0
oooo0P3oool000h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooo`80oooo
000>0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3oool20?ooo`003P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo0P3oool000h0oooo0P00000=0?oo
o`030000003oool0oooo0?l0oooo0@3oool000h0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`3o0?ooo`40oooo000>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
o`3oool10?ooo`003P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo0@3o
ool000h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooo`003P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo000>0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0o`3oool000h0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`3n0?ooo`003P3oool2000000l0oooo00<000000?ooo`3oool0oP3oool000h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`3n0?ooo`003P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0?h0oooo000>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0o@3oool000h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3m0?ooo`003P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?d0oooo000>0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0o03oool000h0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`3l0?ooo`003P3oool200000140oooo00<000000?ooo`3oool0o03oool000h0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3k0?ooo`003P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0?/0oooo000>0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0n`3oool000h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3k0?oo
o`003P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?X0oooo000>0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0nP3oool000h0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`3j0?ooo`003P3oool2000001@0oooo00<000000?ooo`3oool0n@3oool0
00h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3i0?ooo`003P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0?T0oooo000>0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0n03oool000h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`3h0?ooo`003P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?L0oooo00060?oo
o`8000001P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?L0oooo00050?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3g0?oo
o`001`3oool00`000000oooo0?ooo`040?ooo`8000005`3oool00`000000oooo0?ooo`3f0?ooo`00
203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
mP3oool000D0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo0?D0oooo00060?ooo`8000001P3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo0?D0oooo000>0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0m03oool0
00h0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3d0?ooo`003P3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo0?<0oooo000>0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0l`3oool000h0oooo0P00000K0?ooo`030000003oool0oooo0?80oooo000>
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0lP3oool000h0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`3a0?ooo`003P3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo0?00oooo000>0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
l03oool000h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3_0?ooo`003P3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0>l0oooo000>0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0kP3oool000h0oooo0P00000P0?ooo`030000003oool0oooo0>d0
oooo000>0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0k@3oool000h0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`3/0?ooo`003P3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo0>/0oooo000>0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0jP3oool000h0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3Z0?ooo`00
3P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0>T0oooo000>0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0j03oool000h0oooo0P00000V0?ooo`030000003oool0
oooo0>L0oooo000>0?ooo`030000003oool0oooo02H0oooo0P00003W0?ooo`003P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0>@0oooo000>0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0h`3oool000h0oooo00<000000?ooo`3oool0:P3oool200000><0oooo000>
0?ooo`030000003oool0oooo02`0oooo0P00003Q0?ooo`003P3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo0=h0oooo000>0?ooo`030000003oool0oooo02l0oooo0P00003N0?ooo`00
3P3oool200000380oooo0P00003L0?ooo`003P3oool00`000000oooo0?ooo`0c0?ooo`800000fP3o
ool000h0oooo00<000000?ooo`3oool0=@3oool300000=L0oooo000>0?ooo`030000003oool0oooo
03P0oooo1000003C0?ooo`003P3oool00`000000oooo0?ooo`0l0?ooo`D00000cP3oool000h0oooo
00<000000?ooo`3oool0@@3oool500000<T0oooo00070?ooo`<00000103oool00`000000oooo0?oo
o`160?ooo`H00000``3oool000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1<
0?oooaH00000[@3oool000D0oooo1@0000040?ooo`800000H`3ooonO000000h0oooo00050?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0o`3oool@0?ooo`001P3oool00`000000
oooo000000050?ooo`030000003oool0oooo0?l0oooo403oool000L0oooo0P0000050?ooo`030000
003oool0oooo0?l0oooo403oool000h0oooo00<000000?ooo`3oool0o`3oool@0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.49367, -0.30988, \
0.386179, 0.024994}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell[TextData[{
  " It is  usually a good idea  r",
  StyleBox["ationalize", "InlineInput"],
  " the coefficients inside differential equation "
}], "MathCaption"],

Cell[BoxData[
    \(Clear[x1, x2]\)], "Input",
  CellLabel->"In[33]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[\[IndentingNewLine]{\(x1'\)[t] \[Equal] \ 
            1 - \ Rationalize[2.5]\ x1[t] + \ \ x2[
                t], \[IndentingNewLine]\(x2'\)[t] \[Equal] 
            2\ x1[t]\  - \ \ \ x2[t], x1[0] == 0, \ 
          x2[0] == \ 0}, \[IndentingNewLine]{x1[t], x2[t]}, \ t] // \ 
      FullSimplify\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \({{x1[t] \[Rule] 
          2 - 2\/41\ \[ExponentialE]\^\(\(\(-7\)\ t\)/4\)\ \((41\ Cosh[\(\@41\
\ t\)\/4] + 5\ \@41\ Sinh[\(\@41\ t\)\/4])\), 
        x2[t] \[Rule] 
          4 - 4\/41\ \[ExponentialE]\^\(\(\(-7\)\ t\)/4\)\ \((41\ Cosh[\(\@41\
\ t\)\/4] + 7\ \@41\ Sinh[\(\@41\ t\)\/4])\)}}\)], "Output",
  CellLabel->"Out[34]="]
}, Open  ]],

Cell[TextData[{
  "For more details look at ",
  StyleBox[ButtonBox["DSolve",
    ButtonData:>{"DSolve", "TAG"}],
    ButtonBoxOptions -> {DefaultStyle -> "MainBookLink"}],
  " in the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Book. These problems can be avoid using SysModel"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Solution of System of ODE using SystemDSolve and SystemNDSolve\
\>", "SubsectionIcon"],

Cell[TextData[{
  Cell[BoxData[
      ButtonBox[
        StyleBox["SystemDSolve",
          FontColor->RGBColor[0, 0, 1],
          FontVariations->{"Underline"->True}],
        ButtonFunction:>(Internal`PutInformation[ #, LongForm -> False]&),
        ButtonData:>{"Info3234081075-1445498", 
          "Biokmod`SysModel`SystemDSolve"},
        ButtonFrame->"None",
        ButtonNote->"Biokmod`SysModel`"]],
    CellMargins->{{20, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
    Background->GrayLevel[0.930022],
    ButtonBoxOptions->{Active->True}],
  " can be applied for solving this system when A are constants. "
}], "Text"],

Cell[CellGroupData[{

Cell["SODE with constant coefficients", "SubsubsectionIcon"],

Cell[TextData[{
  "In  the follow SODE  some coeffs. are constants. In these case we need use \
",
  Cell[BoxData[
      ButtonBox[
        StyleBox["SystemDSolve",
          FontColor->RGBColor[0, 0, 1],
          FontVariations->{"Underline"->True}],
        ButtonFunction:>(Internal`PutInformation[ #, LongForm -> False]&),
        ButtonData:>{"Info3234081075-1445498", 
          "Biokmod`SysModel`SystemDSolve"},
        ButtonFrame->"None",
        ButtonNote->"Biokmod`SysModel`"]],
    CellMargins->{{20, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
    Background->GrayLevel[0.930022],
    ButtonBoxOptions->{Active->True}],
  "  . "
}], "Text"],

Cell[BoxData[
    \("SystemDSolve[MatrixCoefs, incond, input, t, t1, x,  options] gives  \
the solution X(t)= {x1(t), ..., xn(t) at time t1 of a ODE system  X'(t) = A \
X(t) + B(t),  with initial conditions X(0) = IC , where MatrixCoefs is the  \
coeffs matrix A = {{a11,...a1n}, ...,{am1, ..., amn}}; incond are IC =  \
{c1,..,ci,..cn}; B(t) ={b1[t],..., bn[t]};  x is the symbol that represents \
X;  with options can be choose the method applied for solving the SODE, by \
default is apply:  Method-> Automatic, other methods are LaplaceTransform, \
EigenValues, is applied the  Eigenvalues-eigensisystem method, and DSolve is \
applied the Mathematica  function DSolve."\)], "Print",
  CellTags->"Info3234081075-1445498"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              RowBox[{
                RowBox[{
                  SubsuperscriptBox["x", "1", "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], 
                "\[Equal]", \(1 + cos(0.1`\ t) - 
                  2.8586433975699928`\ \(\(x\_1\)(t)\) + 
                  0.0462`\ \(\(x\_3\)(t)\)\)}]},
            {
              RowBox[{
                RowBox[{
                  SubsuperscriptBox["x", "2", "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], "\[Equal]", 
                " ", \(0.8316`\ \(\(x\_1\)(t)\) - 
                  0.09530589756999316`\ \(\(x\_2\)(t)\)\)}]},
            {
              RowBox[{
                RowBox[{
                  SubsuperscriptBox["x", "3", "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], "\[Equal]", 
                " ", \(0.0086625`\ \(\(x\_2\)(t)\) - 
                  0.14439339756999314`\ \(\(x\_3\)(t)\)\)}]},
            {\(Initial\ \(conditions : \(x\_1\)(0) \[Equal] \ 1\); \(x\_2\)(
                  0) \[Equal] \ 0; \(x\_3\)(0) \[Equal] \ 0\)}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {
          Equal[ 
            Derivative[ 1][ 
              Subscript[ x, 1]][ t], 
            Plus[ 1, 
              Cos[ 
                Times[ 0.1, t]], 
              Times[ -1, 
                Times[ 2.85864339756999, 
                  Subscript[ x, 1][ t]]], 
              Times[ 0.0462, 
                Subscript[ x, 3][ t]]]], 
          Equal[ 
            Derivative[ 1][ 
              Subscript[ x, 2]][ t], 
            Plus[ 
              Times[ 0.8316, 
                Subscript[ x, 1][ t]], 
              Times[ -1, 
                Times[ 0.0953058975699932, 
                  Subscript[ x, 2][ t]]]]], 
          Equal[ 
            Derivative[ 1][ 
              Subscript[ x, 3]][ t], 
            Plus[ 
              Times[ 0.0086625, 
                Subscript[ x, 2][ t]], 
              Times[ -1, 
                Times[ 0.144393397569993, 
                  Subscript[ x, 3][ t]]]]], 
          Equal[ 
            Subscript[ x, 1][ 0], 0], 
          Equal[ 
            Subscript[ x, 2][ 0], 0], 
          Equal[ 
            Subscript[ x, 3][ 0], 0]}]], TraditionalForm]], "Text"],

Cell["Here it is solved (by default applied an Automatic method)", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(SystemDSolve[{{\(-2.86\), \ 0, \ 0.046}, \ {0.83, \ 0.095, \ 
          0}, \ {0, \ 0087, \ 0.144}}, {1, \ 0, \ 
        0}, \ {1\  + \ Cos[0.1  t], \ 0, \ 0}, \ t, \ t1, \ 
      x]\)\(\ \)\)\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \({x\_1[t1] \[Rule] \(-0.004167510526620122`\) + 
          0.24089540705294588`\ \[ExponentialE]\^\(\(-2.2858036768319776`\)\ \
t1\) + 0.4567247761064498`\ \[ExponentialE]\^\(\(-1.37761557126222`\)\ t1\) + 
          0.30751070531726227`\ \[ExponentialE]\^\(1.0424192480941987`\ t1\) \
- 0.0009633779500384243`\ Cos[0.1`\ t1] - 
          0.007243076986801947`\ Sin[0.1`\ t1], 
      x\_2[t1] \[Rule] \(\(0.03641088144309934`\)\(\[InvisibleSpace]\)\) - 
          0.08398138401734995`\ \[ExponentialE]\^\(\(-2.2858036768319776`\)\ \
t1\) - 0.2574205865848829`\ \[ExponentialE]\^\(\(-1.37761557126222`\)\ t1\) + 
          0.2693990922463827`\ \[ExponentialE]\^\(1.0424192480941987`\ t1\) + 
          0.035591996912750945`\ Cos[0.1`\ t1] + 
          0.025816360081794856`\ Sin[0.1`\ t1], 
      x\_3[t1] \[Rule] \(-21.998240871872447`\) + 
          3.006983847779683`\ \[ExponentialE]\^\(\(-2.2858036768319776`\)\ t1\
\) + 14.718297746064128`\ \[ExponentialE]\^\(\(-1.37761557126222`\)\ t1\) + 
          26.087732509241455`\ \[ExponentialE]\^\(1.0424192480941987`\ t1\) - 
          21.814773231212826`\ Cos[0.1`\ t1] - 
          0.44823613885325486`\ Sin[0.1`\ t1]}\)], "Output",
  CellLabel->"Out[35]="]
}, Open  ]],

Cell["Other methods can be chosen", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(SystemDSolve[{{\(-2.86\), \ 0, \ 0.046}, \ {0.83, \ 0.095, \ 
          0}, \ {0, \ 0087, \ 0.144}}, {1, \ 0, \ 
        0}, \ {1\  + \ Cos[0.1  t], \ 0, \ 0}, \ t, \ t1, \ x, \ 
      Method \[Rule] \ "\<LaplaceTransform\>"]\)\(\ \)\)\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \({x\_1[t1] \[Rule] \(-0.0041675105266199`\) + 
          0.2408954070529461`\ \[ExponentialE]\^\(\(-2.2858036768319776`\)\ \
t1\) + 0.4567247761064497`\ \[ExponentialE]\^\(\(-1.377615571262221`\)\ t1\) \
+ 0.30751070531726254`\ \[ExponentialE]\^\(1.0424192480941987`\ t1\) - 
          0.0009633779500385926`\ Cos[0.1`\ t1] - 
          0.0072430769868013145`\ Sin[0.1`\ t1], 
      x\_2[t1] \[Rule] \(\(0.03641088144309928`\)\(\[InvisibleSpace]\)\) - 
          0.08398138401735011`\ \[ExponentialE]\^\(\(-2.2858036768319776`\)\ \
t1\) - 0.2574205865848823`\ \[ExponentialE]\^\(\(-1.377615571262221`\)\ t1\) \
+ 0.2693990922463826`\ \[ExponentialE]\^\(1.0424192480941987`\ t1\) + 
          0.03559199691275072`\ Cos[0.1`\ t1] + 
          0.025816360081800847`\ Sin[0.1`\ t1], 
      x\_3[t1] \[Rule] \(-21.99824087187246`\) + 
          3.006983847779683`\ \[ExponentialE]\^\(\(-2.2858036768319776`\)\ t1\
\) + 14.718297746064131`\ \[ExponentialE]\^\(\(-1.377615571262221`\)\ t1\) + 
          26.08773250924149`\ \[ExponentialE]\^\(1.0424192480941987`\ t1\) - 
          21.814773231212836`\ Cos[0.1`\ t1] - 
          0.44823613885336816`\ Sin[0.1`\ t1]}\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SODE with coefficients variables", "SubsubsectionIcon"],

Cell[TextData[{
  "Be the follow SODE where some coeffs. are function of the time. In these \
case we need use ",
  Cell[BoxData[
      ButtonBox[
        StyleBox["SystemNDSolve",
          FontColor->RGBColor[0, 0, 1],
          FontVariations->{"Underline"->True}],
        ButtonFunction:>(Internal`PutInformation[ #, LongForm -> False]&),
        ButtonData:>{"Info3234081075-1445498", 
          "Biokmod`SysModel`SystemNDSolve"},
        ButtonFrame->"None",
        ButtonNote->"Biokmod`SysModel`"]],
    CellMargins->{{20, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
    Background->GrayLevel[0.930022],
    ButtonBoxOptions->{Active->True}],
  " that applied the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function DSolve"
}], "Text"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              RowBox[{
                RowBox[{
                  SubsuperscriptBox["x", "1", "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], 
                "==", \(cos(
                    0.1`\ t) + \((\(-0.8316`\)\ \((cos(0.2`\ t) + 1)\) - 
                        2.027`)\)\ \(\(x\_1\)(t)\) + 
                  0.0462`\ \((cos(1.2`\ t) + 1)\)\ \(\(x\_3\)(t)\) + 1\)}]},
            {
              RowBox[{
                RowBox[{
                  SubsuperscriptBox["x", "2", "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], 
                "==", \(0.8316`\ \((cos(0.2`\ t) + 1)\)\ \(\(x\_1\)(
                      t)\) + \((\(-0.00866`\)\ \((cos(0.3`\ t) + 1)\) - 
                        0.0866`)\)\ \(\(x\_2\)(t)\)\)}]},
            {
              RowBox[{
                RowBox[{
                  SubsuperscriptBox["x", "3", "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], 
                "==", \(0.00866`\ \((cos(0.3`\ t) + 1.`)\)\ \(\(x\_2\)(
                      t)\) + \((\(-0.0462`\)\ \(cos(1.2`\ t)\) - 
                        0.1442`)\)\ \(\(x\_3\)(t)\)\)}]},
            {\(\(x\_1\)(0) == 1\)},
            {\(\(x\_2\)(0) == 0\)},
            {\(\(x\_3\)(0) == 0\)}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {
          Equal[ 
            Derivative[ 1][ 
              Subscript[ x, 1]][ t], 
            Plus[ 1, 
              Cos[ 
                Times[ 0.1, t]], 
              Times[ 
                Plus[ -2.027, 
                  Times[ -1, 
                    Times[ 0.8316, 
                      Plus[ 1, 
                        Cos[ 
                          Times[ 0.2, t]]]]]], 
                Subscript[ x, 1][ t]], 
              Times[ 
                Times[ 0.0462, 
                  Plus[ 1, 
                    Cos[ 
                      Times[ 1.2, t]]]], 
                Subscript[ x, 3][ t]]]], 
          Equal[ 
            Derivative[ 1][ 
              Subscript[ x, 2]][ t], 
            Plus[ 
              Times[ 
                Times[ 0.8316, 
                  Plus[ 1, 
                    Cos[ 
                      Times[ 0.2, t]]]], 
                Subscript[ x, 1][ t]], 
              Times[ 
                Plus[ -0.0866, 
                  Times[ -1, 
                    Times[ 0.00866, 
                      Plus[ 1, 
                        Cos[ 
                          Times[ 0.3, t]]]]]], 
                Subscript[ x, 2][ t]]]], 
          Equal[ 
            Derivative[ 1][ 
              Subscript[ x, 3]][ t], 
            Plus[ 
              Times[ 
                Times[ 0.00866, 
                  Plus[ 1., 
                    Cos[ 
                      Times[ 0.3, t]]]], 
                Subscript[ x, 2][ t]], 
              Times[ 
                Plus[ -0.1442, 
                  Times[ -1, 
                    Times[ 0.0462, 
                      Cos[ 
                        Times[ 1.2, t]]]]], 
                Subscript[ x, 3][ t]]]], 
          Equal[ 
            Subscript[ x, 1][ 0], 1], 
          Equal[ 
            Subscript[ x, 2][ 0], 0], 
          Equal[ 
            Subscript[ x, 3][ 0], 0]}]], TraditionalForm]], "Text"],

Cell[BoxData[
    \({\ x1[t_], x2[t_], x3[t_]}\  = \ 
      Map[Last, 
        SystemNDSolve[{{\(-2.027\) - 
                0.8316\ \((1\[InvisibleSpace] + Cos[0.2\ t])\), 0, 
              0.0462\ \((1\[InvisibleSpace] + 
                    Cos[1.2\ t])\)}, {0.8316\ \((1\[InvisibleSpace] + 
                    Cos[0.2\ t])\), \(-0.0866\) - 
                0.00866\ \((1 + Cos[0.3`\ t])\), 0}, {0, 
              0.00866\ \((1. \[InvisibleSpace] + 
                    Cos[0.3\ t])\), \(-0.1442\) - 
                0.0462`\ Cos[1.2\ t]}}, {1, \ 0, \ 
            0}, \ {1\  + \ Cos[0.1  t], \ 0, \ 0}, \ {t, \ 1, 100}, \ t, \ 
          x]]\ ; \)], "Input",
  CellLabel->"In[37]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{\ x1[t], x2[t], x3[t]}, \ {t, \ 1, \ 100}, \ 
      PlotRange \[Rule] \ All]\)], "Input",
  CellLabel->"In[38]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0141895 0.00962001 0.0145134 0.0914602 [
[.20659 .00201 -6 -9 ]
[.20659 .00201 6 0 ]
[.39899 .00201 -6 -9 ]
[.39899 .00201 6 0 ]
[.59139 .00201 -6 -9 ]
[.59139 .00201 6 0 ]
[.78379 .00201 -6 -9 ]
[.78379 .00201 6 0 ]
[.97619 .00201 -9 -9 ]
[.97619 .00201 9 0 ]
[.00169 .10597 -6 -4.5 ]
[.00169 .10597 0 4.5 ]
[.00169 .19743 -6 -4.5 ]
[.00169 .19743 0 4.5 ]
[.00169 .28889 -6 -4.5 ]
[.00169 .28889 0 4.5 ]
[.00169 .38035 -6 -4.5 ]
[.00169 .38035 0 4.5 ]
[.00169 .47181 -6 -4.5 ]
[.00169 .47181 0 4.5 ]
[.00169 .56327 -6 -4.5 ]
[.00169 .56327 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20659 .01451 m
.20659 .02076 L
s
[(20)] .20659 .00201 0 1 Mshowa
.39899 .01451 m
.39899 .02076 L
s
[(40)] .39899 .00201 0 1 Mshowa
.59139 .01451 m
.59139 .02076 L
s
[(60)] .59139 .00201 0 1 Mshowa
.78379 .01451 m
.78379 .02076 L
s
[(80)] .78379 .00201 0 1 Mshowa
.97619 .01451 m
.97619 .02076 L
s
[(100)] .97619 .00201 0 1 Mshowa
.125 Mabswid
.06229 .01451 m
.06229 .01826 L
s
.11039 .01451 m
.11039 .01826 L
s
.15849 .01451 m
.15849 .01826 L
s
.25469 .01451 m
.25469 .01826 L
s
.30279 .01451 m
.30279 .01826 L
s
.35089 .01451 m
.35089 .01826 L
s
.44709 .01451 m
.44709 .01826 L
s
.49519 .01451 m
.49519 .01826 L
s
.54329 .01451 m
.54329 .01826 L
s
.63949 .01451 m
.63949 .01826 L
s
.68759 .01451 m
.68759 .01826 L
s
.73569 .01451 m
.73569 .01826 L
s
.83189 .01451 m
.83189 .01826 L
s
.87999 .01451 m
.87999 .01826 L
s
.92809 .01451 m
.92809 .01826 L
s
.25 Mabswid
0 .01451 m
1 .01451 L
s
.01419 .10597 m
.02044 .10597 L
s
[(1)] .00169 .10597 1 0 Mshowa
.01419 .19743 m
.02044 .19743 L
s
[(2)] .00169 .19743 1 0 Mshowa
.01419 .28889 m
.02044 .28889 L
s
[(3)] .00169 .28889 1 0 Mshowa
.01419 .38035 m
.02044 .38035 L
s
[(4)] .00169 .38035 1 0 Mshowa
.01419 .47181 m
.02044 .47181 L
s
[(5)] .00169 .47181 1 0 Mshowa
.01419 .56327 m
.02044 .56327 L
s
[(6)] .00169 .56327 1 0 Mshowa
.125 Mabswid
.01419 .03281 m
.01794 .03281 L
s
.01419 .0511 m
.01794 .0511 L
s
.01419 .06939 m
.01794 .06939 L
s
.01419 .08768 m
.01794 .08768 L
s
.01419 .12427 m
.01794 .12427 L
s
.01419 .14256 m
.01794 .14256 L
s
.01419 .16085 m
.01794 .16085 L
s
.01419 .17914 m
.01794 .17914 L
s
.01419 .21573 m
.01794 .21573 L
s
.01419 .23402 m
.01794 .23402 L
s
.01419 .25231 m
.01794 .25231 L
s
.01419 .2706 m
.01794 .2706 L
s
.01419 .30719 m
.01794 .30719 L
s
.01419 .32548 m
.01794 .32548 L
s
.01419 .34377 m
.01794 .34377 L
s
.01419 .36206 m
.01794 .36206 L
s
.01419 .39865 m
.01794 .39865 L
s
.01419 .41694 m
.01794 .41694 L
s
.01419 .43523 m
.01794 .43523 L
s
.01419 .45352 m
.01794 .45352 L
s
.01419 .49011 m
.01794 .49011 L
s
.01419 .5084 m
.01794 .5084 L
s
.01419 .52669 m
.01794 .52669 L
s
.01419 .54498 m
.01794 .54498 L
s
.01419 .58157 m
.01794 .58157 L
s
.01419 .59986 m
.01794 .59986 L
s
.25 Mabswid
.01419 0 m
.01419 .61803 L
s
.5 Mabswid
.02381 .0652 m
.02499 .06485 L
.02605 .06464 L
.02729 .0645 L
.02846 .06443 L
.02954 .0644 L
.03053 .06439 L
.03163 .06439 L
.03279 .06441 L
.03395 .06444 L
.0352 .06447 L
.03746 .06455 L
.04262 .06479 L
.04793 .06512 L
.05297 .06552 L
.06244 .06641 L
.08429 .06836 L
.09493 .06931 L
.09957 .06975 L
.10458 .07021 L
.10699 .07041 L
.10954 .07059 L
.1119 .07073 L
.11305 .07078 L
.1141 .07083 L
.11509 .07086 L
.11616 .07089 L
.1173 .07091 L
.11837 .07092 L
.11956 .07092 L
.12081 .0709 L
.12188 .07088 L
.12307 .07085 L
.12431 .07081 L
.12562 .07074 L
.12796 .0706 L
.13048 .07039 L
.13323 .07011 L
.13817 .06944 L
.14277 .06864 L
.1533 .06612 L
.16323 .06278 L
.17215 .05886 L
.18182 .05377 L
.2013 .04279 L
.22274 .03236 L
.23255 .02809 L
.24309 .02428 L
.25305 .02168 L
.26214 .01988 L
Mistroke
.27135 .01827 L
.28116 .01676 L
.28681 .01605 L
.29192 .01556 L
.29439 .01537 L
.29706 .0152 L
.2996 .01508 L
.3019 .01499 L
.30428 .01492 L
.30683 .01486 L
.3092 .01481 L
.31143 .01478 L
.31403 .01475 L
.31644 .01473 L
.31769 .01473 L
.31908 .01472 L
.31977 .01472 L
.32052 .01472 L
.32123 .01472 L
.32188 .01472 L
.32311 .01472 L
.32442 .01472 L
.32566 .01473 L
.32679 .01474 L
.32811 .01475 L
.32955 .01478 L
.33215 .01483 L
.33489 .01491 L
.33778 .01503 L
.34296 .01531 L
.3479 .01568 L
.35242 .01611 L
.36257 .01734 L
.3809 .02042 L
.39079 .02269 L
.39996 .02532 L
.42071 .03332 L
.45994 .05351 L
.46952 .0585 L
.47961 .06294 L
.48823 .06592 L
.49766 .06835 L
.5025 .06927 L
.50516 .06968 L
.50767 .07 L
.51001 .07025 L
.51255 .07046 L
.51367 .07053 L
.51485 .0706 L
.51595 .07064 L
Mistroke
.51698 .07068 L
.51827 .07071 L
.51945 .07073 L
.52072 .07074 L
.52144 .07074 L
.52211 .07073 L
.52333 .07071 L
.52443 .07069 L
.52571 .07065 L
.52691 .07061 L
.52964 .07048 L
.53216 .07033 L
.53783 .06991 L
.55827 .06797 L
.57734 .0662 L
.58676 .0654 L
.59139 .06506 L
.59568 .06479 L
.59807 .06468 L
.60061 .06458 L
.60192 .06454 L
.60315 .06452 L
.60381 .0645 L
.6045 .06449 L
.60526 .06449 L
.60596 .06448 L
.60708 .06448 L
.60828 .06448 L
.60941 .06448 L
.61044 .06449 L
.61165 .0645 L
.61296 .06452 L
.61533 .06455 L
.61769 .06459 L
.61899 .0646 L
.62023 .06462 L
.62137 .06463 L
.62262 .06464 L
.62375 .06464 L
.62481 .06464 L
.62546 .06465 L
.62617 .06464 L
.62745 .06464 L
.6287 .06464 L
.62985 .06463 L
.63263 .0646 L
.63399 .06459 L
.63522 .06458 L
.63644 .06458 L
.63758 .06458 L
Mistroke
.63879 .06458 L
.64011 .06459 L
.64075 .0646 L
.64146 .06461 L
.64289 .06464 L
.64422 .06468 L
.64547 .06473 L
.64818 .06488 L
.65067 .06508 L
.65627 .06569 L
.66623 .06703 L
.6691 .06736 L
.6718 .06763 L
.67685 .06801 L
.69597 .06902 L
.70556 .07007 L
.71025 .07064 L
.71453 .07108 L
.71564 .07117 L
.71685 .07126 L
.71789 .07132 L
.71904 .07138 L
.72026 .07142 L
.72155 .07145 L
.72275 .07146 L
.72388 .07145 L
.72513 .07142 L
.72646 .07138 L
.72758 .07132 L
.72882 .07125 L
.73158 .07103 L
.73415 .07076 L
.73923 .07008 L
.74385 .06931 L
.75422 .06715 L
.76371 .0645 L
.77269 .06105 L
.81114 .04018 L
.83062 .03104 L
.84094 .02661 L
.84664 .02458 L
.85205 .02301 L
.86268 .02074 L
.87239 .01902 L
.88239 .01732 L
.89144 .01606 L
.89381 .0158 L
.89638 .01556 L
.89861 .01539 L
.90104 .01524 L
Mistroke
.90364 .01511 L
.90637 .01502 L
.90891 .01495 L
.91127 .01491 L
.91366 .01488 L
.91592 .01485 L
.92016 .01482 L
.92237 .0148 L
.92471 .01479 L
.92594 .01479 L
.92664 .01479 L
.92729 .01478 L
.92844 .01478 L
.92967 .01479 L
.93093 .01479 L
.93207 .0148 L
.93339 .01481 L
.93464 .01483 L
.93686 .01487 L
.93811 .0149 L
.93926 .01493 L
.94169 .01501 L
.94435 .01513 L
.94974 .01547 L
.955 .01593 L
.96065 .01655 L
.97085 .01794 L
.97619 .01878 L
Mfstroke
.02381 .10961 m
.04262 .23361 L
.0522 .28346 L
.06244 .32718 L
.07286 .3614 L
.07751 .37332 L
.08255 .3839 L
.08564 .38916 L
.08848 .39321 L
.09115 .39632 L
.09409 .39898 L
.09535 .39989 L
.09672 .4007 L
.09789 .40127 L
.09918 .40175 L
.09993 .40196 L
.10063 .40211 L
.10129 .40221 L
.102 .40228 L
.1027 .40231 L
.10335 .4023 L
.10458 .40217 L
.10574 .40194 L
.10699 .40156 L
.10816 .40108 L
.10923 .40054 L
.11186 .39883 L
.11434 .3967 L
.11928 .39105 L
.12466 .38291 L
.13425 .36392 L
.14313 .34245 L
.16338 .2877 L
.1824 .24115 L
.20056 .20871 L
.21078 .19572 L
.22015 .18638 L
.25977 .1563 L
.29788 .12475 L
.31913 .1066 L
.33844 .09268 L
.34808 .0872 L
.35315 .08486 L
.35853 .08283 L
.36322 .08142 L
.36571 .08082 L
.36839 .08027 L
.37085 .07985 L
.37309 .07954 L
.37535 .07929 L
Mistroke
.37749 .07912 L
.37874 .07903 L
.38009 .07897 L
.38136 .07892 L
.38253 .07889 L
.38359 .07887 L
.38475 .07887 L
.38597 .07887 L
.3871 .07889 L
.38774 .07891 L
.38843 .07892 L
.38968 .07897 L
.39204 .07908 L
.39479 .07924 L
.39733 .07943 L
.40619 .08019 L
.41084 .08056 L
.41338 .08073 L
.41573 .08084 L
.4169 .08088 L
.41814 .08092 L
.41885 .08093 L
.41952 .08094 L
.42077 .08094 L
.42192 .08092 L
.42299 .08089 L
.42415 .08085 L
.42538 .08078 L
.42646 .0807 L
.42761 .0806 L
.4297 .08037 L
.43217 .08002 L
.43443 .07961 L
.4395 .0784 L
.44502 .07661 L
.45505 .07229 L
.46523 .06706 L
.4748 .06245 L
.4796 .06069 L
.48091 .0603 L
.4823 .05995 L
.4836 .05968 L
.48478 .05948 L
.48609 .05932 L
.48682 .05926 L
.4875 .05922 L
.48872 .05919 L
.49004 .05924 L
.49073 .0593 L
.49149 .05939 L
Mistroke
.49229 .05951 L
.49304 .05965 L
.49437 .05997 L
.4958 .06043 L
.49834 .0615 L
.50105 .06305 L
.50591 .067 L
.5089 .07018 L
.5117 .07373 L
.51695 .08187 L
.5266 .10202 L
.53704 .1311 L
.557 .20437 L
.57807 .29715 L
.61606 .46052 L
.63558 .52708 L
.64653 .55565 L
.6565 .57609 L
.66132 .58416 L
.66643 .59137 L
.67079 .59632 L
.67313 .59846 L
.6756 .60032 L
.67689 .60112 L
.67829 .60185 L
.67959 .60239 L
.68076 .60278 L
.68143 .60295 L
.68215 .6031 L
.68292 .60322 L
.68364 .60329 L
.68432 .60332 L
.68503 .60331 L
.68632 .6032 L
.68751 .60299 L
.68879 .60263 L
.69 .60219 L
.6911 .60169 L
.69381 .60008 L
.69637 .59806 L
.70142 .5927 L
.70599 .58632 L
.71623 .56689 L
.72571 .54272 L
.73463 .51515 L
.77326 .37217 L
.79286 .30979 L
.80323 .28372 L
.81433 .26102 L
.83481 .22976 L
Mistroke
.85389 .20627 L
.89532 .15979 L
.91608 .1366 L
.93524 .11809 L
.95388 .10363 L
.96328 .09838 L
.96863 .09606 L
.97364 .09432 L
.97619 .09357 L
Mfstroke
.02381 .01537 m
.04262 .01964 L
.0522 .02204 L
.05756 .02307 L
.06244 .02377 L
.06501 .02404 L
.0678 .02429 L
.07286 .02462 L
.0779 .02487 L
.08014 .02496 L
.08255 .02504 L
.08393 .02507 L
.08518 .0251 L
.08644 .02512 L
.08764 .02513 L
.08831 .02513 L
.08903 .02513 L
.09032 .02512 L
.09111 .02511 L
.09185 .0251 L
.09252 .02508 L
.09325 .02506 L
.09461 .025 L
.09612 .02491 L
.09915 .02468 L
.10196 .02438 L
.10458 .02405 L
.11503 .02242 L
.12017 .02167 L
.12244 .0214 L
.12493 .02114 L
.12701 .02096 L
.12924 .02082 L
.13047 .02075 L
.1316 .02071 L
.13268 .02067 L
.13382 .02065 L
.13498 .02063 L
.13621 .02063 L
.13738 .02063 L
.13844 .02064 L
.13968 .02067 L
.14104 .02071 L
.14349 .0208 L
.14838 .02105 L
.15295 .02133 L
.16336 .02209 L
.16857 .02257 L
.17351 .02313 L
.1792 .02396 L
Mistroke
.18441 .0249 L
.19402 .02684 L
.19929 .02779 L
.20188 .02817 L
.20425 .02847 L
.20647 .02869 L
.20889 .02887 L
.21133 .02901 L
.21391 .02911 L
.21609 .02917 L
.21843 .02923 L
.22265 .02935 L
.22522 .02945 L
.22795 .02959 L
.23285 .02993 L
.23857 .03041 L
.24137 .03063 L
.24259 .03072 L
.24393 .0308 L
.24502 .03085 L
.24618 .03089 L
.24741 .03092 L
.24854 .03094 L
.24919 .03094 L
.24988 .03093 L
.25115 .0309 L
.25238 .03086 L
.25351 .03079 L
.25477 .0307 L
.25595 .0306 L
.25864 .03031 L
.26407 .02951 L
.30294 .02479 L
.31253 .02326 L
.32273 .0217 L
.32804 .02109 L
.33107 .02082 L
.33391 .02062 L
.3389 .02035 L
.34427 .02014 L
.35438 .01978 L
.3599 .01954 L
.36503 .01933 L
.36729 .01925 L
.36943 .01919 L
.37061 .01916 L
.37189 .01913 L
.37305 .01911 L
.37413 .0191 L
.37532 .01909 L
Mistroke
.37643 .01908 L
.37765 .01908 L
.37896 .01909 L
.37962 .0191 L
.38033 .01911 L
.38164 .01913 L
.38408 .0192 L
.39507 .01967 L
.40046 .01992 L
.40282 .02001 L
.40542 .02009 L
.40775 .02015 L
.40993 .02019 L
.41224 .02022 L
.41353 .02023 L
.41471 .02024 L
.41724 .02025 L
.41992 .02027 L
.42222 .02029 L
.42352 .0203 L
.42475 .02032 L
.42717 .02036 L
.42939 .02041 L
.43438 .02056 L
.43939 .02074 L
.44203 .02083 L
.44486 .02092 L
.44615 .02095 L
.44738 .02097 L
.44848 .02098 L
.44967 .02099 L
.4508 .02099 L
.45199 .02099 L
.45301 .02098 L
.45414 .02096 L
.45541 .02093 L
.45657 .02089 L
.45918 .02079 L
.4639 .02053 L
.50368 .01857 L
.51403 .01794 L
.51911 .01761 L
.52377 .01735 L
.52802 .01715 L
.53019 .01708 L
.53251 .01701 L
.53373 .01698 L
.53484 .01696 L
.53597 .01694 L
.53701 .01693 L
Mistroke
.53823 .01692 L
.53955 .01692 L
.54071 .01692 L
.54194 .01693 L
.54316 .01694 L
.54428 .01695 L
.54557 .01698 L
.54679 .017 L
.54896 .01706 L
.55133 .01715 L
.55392 .01727 L
.55669 .01743 L
.56167 .01782 L
.56734 .01843 L
.57268 .01923 L
.57747 .02019 L
.58266 .02153 L
.59216 .02493 L
.60259 .02965 L
.62365 .03841 L
.6345 .04318 L
.64479 .04829 L
.64926 .05021 L
.65172 .05104 L
.65402 .05165 L
.65521 .05189 L
.6565 .05209 L
.65719 .05217 L
.65793 .05224 L
.65924 .05231 L
.66043 .05233 L
.66154 .0523 L
.66276 .05222 L
.66406 .0521 L
.66534 .05193 L
.66668 .05172 L
.66909 .05126 L
.67454 .05004 L
.68444 .04808 L
.6894 .04732 L
.69412 .04659 L
.69835 .04575 L
.70296 .0445 L
.70785 .04272 L
.71239 .04073 L
.72253 .03608 L
.72709 .03435 L
.73139 .03308 L
.73377 .03253 L
.73635 .03207 L
Mistroke
.73869 .03174 L
.74084 .03152 L
.7421 .03142 L
.7433 .03134 L
.74555 .03123 L
.7468 .03118 L
.74796 .03115 L
.75059 .0311 L
.75969 .03097 L
.76218 .03092 L
.76349 .0309 L
.76487 .03088 L
.76608 .03087 L
.76676 .03086 L
.7674 .03086 L
.76852 .03086 L
.76972 .03087 L
.77037 .03087 L
.77108 .03089 L
.77237 .03092 L
.77363 .03096 L
.77478 .03102 L
.77607 .0311 L
.77749 .03121 L
.78036 .03151 L
.7912 .03352 L
.79653 .0348 L
.80147 .03591 L
.80594 .03668 L
.8082 .03695 L
.80949 .03707 L
.8107 .03716 L
.81192 .03723 L
.81322 .03728 L
.81432 .03731 L
.81553 .03732 L
.81683 .03731 L
.81756 .03731 L
.81823 .0373 L
.81952 .03727 L
.82074 .03724 L
.82317 .03718 L
.82436 .03715 L
.82545 .03713 L
.82659 .03712 L
.82782 .03711 L
.82846 .03711 L
.82916 .03711 L
.83043 .03713 L
.83161 .03716 L
Mistroke
.83268 .03719 L
.83391 .03725 L
.83507 .03731 L
.83938 .03761 L
.84411 .03799 L
.84535 .03808 L
.84669 .03817 L
.84793 .03824 L
.8491 .03828 L
.84975 .0383 L
.85046 .03831 L
.85171 .03832 L
.85243 .03831 L
.8532 .03829 L
.85385 .03827 L
.85457 .03823 L
.85582 .03815 L
.85717 .03802 L
.85961 .03771 L
.86201 .03731 L
.86457 .03678 L
.86918 .03567 L
.87965 .03313 L
.88534 .03207 L
.89071 .0313 L
.90075 .02999 L
.91944 .02614 L
.92437 .02507 L
.92967 .0241 L
.93466 .0234 L
.93923 .02294 L
.94355 .02262 L
.94826 .02236 L
.95683 .0219 L
.97619 .02076 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[38]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00?03oool4000000<0oooo0P00000]0?ooo`<000000P3oool2000002/0oooo0`0000040?oo
o`800000;@3oool2000000@0oooo0P00000X0?ooo`D000000P3oool2000000@0oooo0P0000070?oo
o`00?03oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000002d0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0X0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000:`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
02T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
000Z0?ooo`D0000000D0oooo0000003oool0oooo0000000Z0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000002T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0103oool003h0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000Z
0?ooo`<000000`3oool010000000oooo0?ooo`00000/0?ooo`8000000`3oool010000000oooo0?oo
o`00000Y0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00@0oooo000l0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000:`3oool00`000000oooo000000020?ooo`040000003oool0oooo000002/0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000[0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000:@3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`00?@3oool2000000@0oooo0P00000]
0?ooo`8000000`3oool2000002`0oooo0`0000030?ooo`800000;@3oool2000000@0oooo0P00000Y
0?ooo`800000103oool2000000@0oooo0P0000070?ooo`00o`3ooolQ0?ooo`00303oool00`000000
oooo0?ooo`3o0?oooa80oooo000<0?ooo`030000003oool0oooo0?l0oooo4P3oool000`0oooo00<0
00000?ooo`3oool0o`3ooolB0?ooo`00303oool00`000000oooo0?ooo`3o0?oooa80oooo00080?oo
ool000004`0000060?ooo`00303oool00`000000oooo0?ooo`030?ooo`<00000103oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0:0?ooo`P000001@3oool00`000000oooo0?ooo`0:0?oooa0000002P3oool00`000000
oooo0?ooo`080?oooaP00000103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool01`3oool6000000X0oooo00<000000?ooo`3oool01P3oool5000000d0
oooo000<0?ooo`030000003oool0oooo00H0oooo1@00000=0?oooa800000203oool00`000000oooo
0?ooo`080?ooo`<000003P3oool;000000H0oooo1P0000000`3oool000000?ooo`0F000001P0oooo
1@00000d0?ooo`030000003oool0oooo00l0oooo1@00000B0?ooo``000003@3oool000`0oooo00<0
00000?ooo`3oool02`3oool=00000180oooo1@00000<0?ooo`8000002P3oool7000001L0oooo0`00
000b0?ooo`800000@P3oool300000140oooo1P00000I0?ooo`00303oool00`000000oooo0?ooo`0_
0?oooaP000008@3oool300000340oooo0`00000W0?ooo`P000003P3oool200000100oooo1000000O
0?ooo`00303oool2000003L0oooo0P00000c0?ooo`800000<P3oool3000001d0oooo1`0000070?oo
o`D00000203oool2000000`0oooo1P00000S0?ooo`00303oool00`000000oooo0?ooo`0d0?ooo`80
0000=`3oool2000003<0oooo0P00000I0?ooo`8000004`3ooolF000002T0oooo000<0?ooo`030000
003oool0oooo0380oooo0P00000k0?ooo`800000<`3oool2000001D0oooo0P00000I0?ooo`800000
>@3oool000`0oooo00<000000?ooo`3oool0<03oool2000003l0oooo0P00000c0?ooo`800000403o
ool3000001T0oooo0P00000k0?ooo`00303oool00`000000oooo0?ooo`0^0?ooo`800000@`3oool2
000003<0oooo0P0000090?ooo`D000006P3oool2000003d0oooo000<0?ooo`800000;@3oool20000
04L0oooo0P00000c0?ooo`T000007P3oool00`000000oooo0?ooo`0m0?ooo`00303oool00`000000
oooo0?ooo`0Z0?ooo`800000B`3oool00`000000oooo0?ooo`1E0?ooo`800000@03oool000`0oooo
00<000000?ooo`3oool0:03oool2000004h0oooo0`0000000`3oool0000000000003000004`0oooo
0P0000120?ooo`00303oool00`000000oooo0?ooo`0U0?ooo`<00000DP3oool3000000@0oooo0P00
00180?ooo`800000A03oool000`0oooo00<000000?ooo`3oool03@00000E0?ooo`<00000D`3oool2
000000<0oooo0`0000030?ooo`030000003oool0oooo00l0oooo7000000E0?ooo`D00000AP3oool0
00`0oooo0P00000>0?oooaD00000E03oool2000000P0oooo5@00000L0?oooaD00000B`3oool000`0
oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo08T0
oooo000<0?ooo`030000003oool0oooo0740oooo1000000@0?ooo`030000003oool0oooo08T0oooo
000<0?ooo`030000003oool0oooo05`0oooo5@00000E0?ooo`030000003oool0oooo08P0oooo000<
0?ooo`030000003oool0oooo05T0oooo0`00000Z0?ooo`030000003oool0oooo08P0oooo000<0?oo
o`800000F03oool2000002h0oooo00<000000?ooo`3oool0Q`3oool000`0oooo00<000000?ooo`3o
ool0E@3oool200000300oooo00<000000?ooo`3oool0Q`3oool000`0oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo07H0oooo0`00000=0?ooo`00103o
ool5000000<0oooo00<000000?ooo`3oool0DP3oool2000003@0oooo00<000000?ooo`3oool0M03o
ool200000100oooo00060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0740oooo0P00000B0?ooo`001P3oool00`00
0000oooo0?ooo`030?ooo`<00000D03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
0700oooo00<000000?ooo`3oool04P3oool000H0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`00001>0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0K@3oool20000
01D0oooo00060?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000C@3oool00`00
0000oooo0?ooo`0i0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool05@3oool000D0
oooo0P0000050?ooo`040000003oool0oooo000004/0oooo0P00000l0?ooo`030000003oool0oooo
06/0oooo00<000000?ooo`3oool05P3oool000`0oooo00@000000?ooo`3oool00000BP3oool00`00
0000oooo0?ooo`0m0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool05`3oool000`0
oooo0P0000020?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`1X0?ooo`030000003oool0oooo01P0oooo000<0?ooo`050000003oool0oooo0?ooo`00
0000A`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3o
ool06@3oool000`0oooo00D000000?ooo`3oool0oooo000000160?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0J0?ooo`00303oool01@000000oooo
0?ooo`3oool0000004D0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`1T0?ooo`03
0000003oool0oooo01/0oooo000<0?ooo`050000003oool0oooo0?ooo`000000A03oool00`000000
oooo0?ooo`130?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0703oool000`0oooo
0P0000020?ooo`030000003oool0oooo0400oooo0P0000170?ooo`030000003oool0oooo0640oooo
00<000000?ooo`3oool07@3oool000`0oooo00D000000?ooo`3oool0oooo000000110?ooo`030000
003oool0oooo04L0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0N0?ooo`00303o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo01h0oooo000<0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo05l0oooo00<000000?ooo`3oool07`3oool000`0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`0P0?ooo`00303oool2000000<0oooo00<000000?ooo`3oool0>@3oool2000004h0
oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0Q0?ooo`00303oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`1K0?ooo`030000003oool0oooo0280oooo000<0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool08`3oool000`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0e
0?ooo`800000D`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo02@0oooo000<0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool09@3oool000`0oooo0P0000040?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo02H0oooo000<0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
<03oool2000005L0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0W0?ooo`00303o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo02L0oooo00040?ooo`@00000103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0F@3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo02P0oooo00040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
05X0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0Y0?ooo`001@3oool00`000000
oooo0?ooo`040?ooo`<00000103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05/0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0Z0?ooo`001P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`1M0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0:`3oool000@0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo02`0oooo
00050?ooo`8000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0GP3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo02d0oooo000<
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1O
0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0;@3oool000`0oooo0P0000050?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo02h0oooo000<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool0;`3oool000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo0640oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0`0?ooo`00303o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0HP3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0300oooo000<0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool0<@3oool000`0oooo0P0000060?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
0380oooo000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`1T0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0<`3oool000`0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06D0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0c0?ooo`00303oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo03@0oooo000<0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool0=@3oool000`0oooo0P0000070?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03H0oooo000<0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1X0?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0=P3oool000`0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0g0?ooo`00303oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo03P0oooo000<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0>03oool0
00`0oooo0P0000080?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0JP3oool00`00
0000oooo0?ooo`0m0?ooo`030000003oool0oooo03T0oooo000<0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool0>@3oool000`0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0j0?ooo`001@3oool2000000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0j0?ooo`00103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0>P3oool000H0oooo00<000000?ooo`3oool00`3oool3000000L0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool0>`3oool000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo03/0oooo00040?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo06l0oooo00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`0l0?ooo`001@3oool2000000D0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0l0?ooo`00303oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo03d0oooo000<0?ooo`8000002P3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo0740oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0m0?ooo`00303oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0LP3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03d0oooo000<0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool0?P3oool000`0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`0n0?ooo`00303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03h0oooo
000<0?ooo`8000002`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo07@0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0n0?ooo`00303oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo03l0oooo000<0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool0?`3oool000`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo07H0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`00
303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0400oooo000<0?ooo`800000303o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`100?ooo`00303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo0400oooo000<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0@@3oool000`0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`110?ooo`00303oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0NP3oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo0440oooo000<0?ooo`8000003P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`110?ooo`00303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0N`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0480oooo000<0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1k0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool0@P3oool000H0oooo0`0000030?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1m0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0@P3oool000L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo04<0oooo00040?ooo`D000000`3o
ool3000000l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool0@`3oool000@0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0OP3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo04<0oooo00050?ooo`030000003oool0
000000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0800oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`130?ooo`001P3oool20000
00@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0800oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`140?ooo`00303oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo0P0000230?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0A03oool000`0oooo0P00000D0?ooo`80000000@0oooo000000000000
0000Q03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo04@0oooo000<0?ooo`030000
003oool0oooo01@0oooo0`0000260?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
A@3oool000`0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo04D0oooo000<0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`150?ooo`00303oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool0A@3oool000`0oooo0P00002O0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0AP3oool000`0oooo00<000000?ooo`3oool0W`3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo04H0oooo000<0?ooo`030000003oool0oooo09l0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`160?ooo`00303oool00`000000oooo0?ooo`2O
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0A`3oool000`0oooo00<000000?oo
o`3oool0W`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04L0oooo000<0?ooo`80
0000X03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04L0oooo000<0?ooo`030000
003oool0oooo0:00oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`170?ooo`00303o
ool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0B03o
ool000`0oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo04P0oooo000<0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`180?ooo`00303oool200000:80oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`180?ooo`00303oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0B@3oool000`0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo04T0oooo00050?ooo`8000001@3oool00`000000oooo0?ooo`2Q
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0B@3oool000@0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0BP3oool000L0oooo00<000000?ooo`3oool00P3oool300000:80oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`1:0?ooo`001@3oool2000000D0oooo00<000000?ooo`3o
ool0XP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo04X0oooo00050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo04X0oooo00050?ooo`<00000103oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0B`3oool000`0oooo00<000000?ooo`3oool0X`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04/0oooo000<0?ooo`800000Y03oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo04/0oooo000<0?ooo`030000003oool0oooo0:<0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1<0?ooo`00303oool00`000000oooo
0?ooo`2T0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0C03oool000`0oooo00<0
00000?ooo`3oool0Y03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo04`0oooo000<
0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1<
0?ooo`00303oool200000:H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1=0?oo
o`00303oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0C@3oool000`0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo04d0oooo000<0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`1>0?ooo`00303oool00`000000oooo0?ooo`2V0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0CP3oool000`0oooo0P00002W0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0CP3oool000`0oooo00<000000?ooo`3oool0YP3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo04h0oooo000<0?ooo`030000003oool0oooo0:L0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1?0?ooo`00303oool00`000000oooo0?oo
o`2W0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0C`3oool000`0oooo00<00000
0?ooo`3oool0Z03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04l0oooo000<0?oo
o`800000Z@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04l0oooo000<0?ooo`03
0000003oool0oooo0:T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1@0?ooo`00
303oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
D03oool000@0oooo0`0000050?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`1A0?ooo`00103oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0:X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1A0?ooo`00103oool0
10000000oooo0?ooo`0000040?ooo`<00000ZP3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0580oooo00040?ooo`<000001@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0DP3oool000D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2[0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0DP3oool000D0
oooo0`0000040?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`1C0?ooo`00303oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0D`3oool000`0oooo0P00002^0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0E03oool000`0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo05@0oooo000<0?ooo`030000003oool0oooo0:l0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`1E0?ooo`00303oool00`000000oooo0?ooo`2_0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0EP3oool000`0oooo00<000000?ooo`3oool0
/03oool2000000D0oooo00<000000?ooo`3oool0E`3oool000`0oooo0P00002b0?ooo`H00000FP3o
ool000`0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`00303oool00`000000oooo0?ooo`3o0?oo
oa80oooo000<0?ooo`030000003oool0oooo0?l0oooo4P3oool000`0oooo00<000000?ooo`3oool0
o`3ooolB0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.79543, -0.497705, \
0.381308, 0.0401069}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[38]="]
}, Open  ]],

Cell["Or we can show the numeric values as function of t", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[{t, \ x1[t], x2[t], x3[t]}, \ {t, \ 10, \ 100, 10}] // 
      TableForm\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"10", "0.6137404107155459`", "4.213227094074609`", 
            "0.09459054326888736`"},
          {"20", "0.27940956627158486`", "2.035053629798864`", 
            "0.1550689734806524`"},
          {"30", "0.004883603744591261`", "1.1573378978205167`", 
            "0.11256109248632122`"},
          {"40", "0.11486087780276485`", "0.7111946543838655`", 
            "0.05840816873529622`"},
          {"50", "0.5826187053860109`", "0.4997429631694928`", 
            "0.04838581349282436`"},
          {"60", "0.5526357581713017`", "3.7496765120434787`", 
            "0.1104401246428803`"},
          {"70", "0.5902861923155686`", "6.433980449210407`", 
            "0.36165027539152433`"},
          {"80", "0.4467592195956336`", "3.521854843262446`", 
            "0.19127597920837044`"},
          {"90", "0.0350072476692631`", "1.7800306863103925`", 
            "0.20278969013521572`"},
          {"100", "0.046656299465681686`", "0.8644185298466441`", 
            "0.06829624580590202`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[39]//TableForm="]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Solving compartmental models with constants coefficients ", \
"SubsectionIcon"],

Cell[TextData[{
  "This figure  represents the iodine biokinetic model  where compartment 1 \
is the blood, compartment 2 is the thyroid and compartment 3 is the rest of \
the body. Coefficient transfer values, in ",
  Cell[BoxData[
      \(TraditionalForm\`days\^\(-1\)\)]],
  ", taken from ICRP 78 are ",
  Cell[BoxData[
      \(TraditionalForm\`k\_10\)]],
  "= 1.9404, ",
  Cell[BoxData[
      \(TraditionalForm\`k\_12\)]],
  "= 0.8316,  ",
  Cell[BoxData[
      \(TraditionalForm\`k\_23\)]],
  " = 0.0086625, ",
  Cell[BoxData[
      \(TraditionalForm\`k\_30\)]],
  "= 0.01155 and ",
  Cell[BoxData[
      \(TraditionalForm\`k\_31\)]],
  "= 0.0462. "
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .90909 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 0.17316 0.627706 0.17316 [
[ 0 0 0 0 ]
[ 1 .90909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .90909 L
0 .90909 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125  moveto 0 0 lineto 
-0.05 -0.0125  lineto stroke
} ifelse
grestore
} def
/MAarrowhead2 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.11039 .88745 m
.11039 .71429 L
s
% Start of user PostScript
0 1.5 0 0.5 MAarrowhead1
% End of user PostScript
gsave
.04113 .80087 -80.3438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
75.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.688 12.813 moveto
(H) show
85.688 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 12.813 moveto
(L) show
97.688 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.11039 .62771 .08658 0 365.73 arc
s
gsave
.11039 .62771 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.19697 .62771 m
.62987 .62771 L
s
% Start of user PostScript
0.5 0 3. 0 MAarrowhead2
% End of user PostScript
newpath
.11039 .28139 .08658 0 365.73 arc
s
gsave
.11039 .28139 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .19481 m
.11039 .02165 L
s
% Start of user PostScript
0 -2.5 0 -3.5 MAarrowhead2
% End of user PostScript
gsave
.16234 .14286 -70.4375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.41342 .69697 -70.4375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .54113 m
.11039 .36797 L
s
% Start of user PostScript
0 -0.5 0 -1.5 MAarrowhead2
% End of user PostScript
gsave
.16234 .48918 -70.4375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.71645 .62771 .08658 0 365.73 arc
s
gsave
.71645 .62771 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.71645 .54113 m
.71645 .36797 L
s
% Start of user PostScript
3.5 -0.5 3.5 -1.5 MAarrowhead2
% End of user PostScript
gsave
.6645 .45455 -70.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.71645 .28139 .08658 0 365.73 arc
s
gsave
.71645 .28139 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.62987 .31602 m
.17965 .57576 L
s
% Start of user PostScript
3. -1.8 0.4 -0.3 MAarrowhead2
% End of user PostScript
gsave
.45671 .45455 -70.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(31) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.80303 .28139 m
.97619 .28139 L
s
% Start of user PostScript
4. -2. 5. -2. MAarrowhead2
% End of user PostScript
gsave
.85498 .28139 -70.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[15]:=",
  ImageSize->{288, 261.813},
  ImageMargins->{{1, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00011B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`007`3oool00`001000oooo0?ooo`3n0?ooo`007`3oool00`001000oooo0?ooo`3n0?ooo`00
7`3oool200040?l0oooo000N0?ooo`<000@0o`3oool001h0oooo0`00103o0?ooo`007P3oool30004
0?l0oooo000N0?ooo`@000@0oP3oool001d0oooo1@00103n0?ooo`007@3oool500040?h0oooo000M
0?ooo`H000@0o@3oool001d0oooo1P00103m0?ooo`007@3oool600040?d0oooo000L0?ooo`L000@0
o@3oool001`0oooo2000103l0?ooo`00703oool800040?`0oooo000O0?ooo`030004003oool0oooo
0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo
000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?oo
o`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004
003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0
oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0
oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O
0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`03
0004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo00d0oooo00<000@00?ooo`3oool0
0P00103/0?ooo`007`3oool00`001000oooo0?ooo`050?ooo`8000@000<0oooo0004000010000P3o
ool200040080oooo0P00103/0?ooo`007`3oool00`001000oooo0?ooo`060?ooo`030004003oool0
00@000<0oooo0P0010020?ooo`8000@0k03oool001l0oooo00<000@00?ooo`3oool01P3oool30004
00@0oooo00<000@00?ooo`3oool00P00103/0?ooo`007`3oool00`001000oooo0?ooo`060?ooo`04
0004003oool000@000040?@0oooo000O0?ooo`030004003oool0oooo00H0oooo00<000@00?ooo`3o
ool0m@3oool001l0oooo00<000@00?ooo`3oool01@3oool200040?L0oooo000O0?ooo`030004003o
ool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo
0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo
000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?oo
o`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004
003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000I0?ooo``000@0XP3oool<
000404d0oooo000G0?ooo`8000@0303oool5000409/0oooo0P00100<0?ooo`@000@0B@3oool001D0
oooo0P00100C0?ooo`8000@0U`3oool200040180oooo0P0010170?ooo`004`3oool2000401L0oooo
00<000@00?ooo`3oool0TP3oool2000401H0oooo0P0010150?ooo`004@3oool2000401X0oooo00<0
00@00?ooo`3oool0S`3oool2000401X0oooo00<000@00?ooo`3oool0@P3oool00100oooo00<000@0
0?ooo`3oool06`3oool2000408h0oooo00<000@00?ooo`3oool06`3oool200040480oooo000?0?oo
o`030004003oool0oooo01h0oooo00<000@00?ooo`3oool0RP3oool00`001000oooo0?ooo`0M0?oo
o`030004003oool0oooo0400oooo000>0?ooo`030004003oool0oooo0200oooo00<000@00?ooo`3o
ool0R03oool00`001000oooo0?ooo`0O0?ooo`030004003oool0oooo03l0oooo000=0?ooo`030004
003oool0oooo0280oooo00<000@00?ooo`3oool0QP3oool00`001000oooo0?ooo`0Q0?ooo`8000@0
?`3oool000/0oooo0P00100V0?ooo`030004003oool0oooo08<0oooo0P00100V0?ooo`030004003o
ool0oooo03`0oooo000:0?ooo`030004003oool0oooo02L0oooo00<000@00?ooo`3oool0P@3oool0
0`001000oooo0?ooo`0W0?ooo`030004003oool0oooo03/0oooo000:0?ooo`030004003oool0oooo
02L0oooo00<000@00?ooo`3oool0P@3oool00`001000oooo0?ooo`0W0?ooo`030004003oool0oooo
03/0oooo000:0?ooo`030004003oool0oooo02P0oooo00<000@00?ooo`3oool0P03oool00`001000
oooo0?ooo`0X0?ooo`030004003oool0oooo03X0oooo00090?ooo`030004003oool0oooo02T0oooo
00<000@00?ooo`3oool0O`3oool00`001000oooo0?ooo`0Y0?ooo`030004003oool0oooo03X0oooo
00090?ooo`030004003oool0oooo02T0oooo00<000@00?ooo`3oool0O`3oool00`001000oooo0?oo
o`0Y0?ooo`030004003oool0oooo03X0oooo00080?ooo`030004003oool0oooo02/0oooo00<000@0
0?ooo`3oool0O@3oool00`001000oooo0?ooo`0[0?ooo`030004003oool0oooo03T0oooo00080?oo
o`030004003oool0oooo02/0oooo00<000@00?ooo`3oool0O@3oool00`001000oooo0?ooo`0[0?oo
o`030004003oool0oooo03T0oooo00070?ooo`030004003oool0oooo02d0oooo00<000@00?ooo`3o
ool0N`3oool00`001000oooo0?ooo`0]0?ooo`030004003oool0oooo03P0oooo00070?ooo`030004
003oool0oooo02d0oooo00<000@00?ooo`3oool0N`3oool00`001000oooo0?ooo`0]0?ooo`030004
003oool0oooo03P0oooo00070?ooo`030004003oool0oooo02h0oooo00<000@00?ooo`3oool0NP3o
ool00`001000oooo0?ooo`0]0?ooo`030004003oool0oooo03P0oooo00070?ooo`030004003oool0
oooo02h0oooo00<000@00?ooo`3oool0NP3oool00`001000oooo0?ooo`0]0?ooo`030004003oool0
oooo03P0oooo00070?ooo`030004003oool0oooo02h0oooo00<000@00?ooo`3oool0NP3oool00`00
1000oooo0?ooo`0^0?ooo`030004003oool0oooo0200oooo0`00100D0?ooo`001P3oool00`001000
oooo0?ooo`0_0?ooo`030004003oool0oooo07T0oooo00<000@00?ooo`3oool0;`3oool00`001000
oooo0?ooo`0P0?ooo`P000@03`3oool000H0oooo00<000@00?ooo`3oool05P3oool3000401H0oooo
00<000@00?ooo`3oool0N@3oool00`001000oooo0?ooo`0E0?ooo`8000@0603oool00`001000oooo
0?ooo`0P0?ooo`d000@02P3oool000H0oooo00<000@00?ooo`3oool05`3oool00`001000oooo0?oo
o`0E0?ooo`030004003oool0oooo07T0oooo00<000@00?ooo`3oool0503oool010001000oooo0?oo
o`00100G0?oooc<000@01`3oool000H0oooo00<000@00?ooo`3oool0503oool5000401H0oooo00<0
00@00?ooo`3oool0N@3oool00`001000oooo0?ooo`0F0?ooo`030004003oool0oooo01H0oooo00<0
00@00?ooo`3oool0803oool>000400T0oooo00060?ooo`030004003oool0oooo01@0oooo00@000@0
0?ooo`3oool000@05`3oool00`001000oooo0?ooo`1i0?ooo`030004003oool0oooo01L0oooo00<0
00@00?ooo`3oool05@3oool00`001000oooo0?ooo`0P0?ooo`X000@03@3oool000H0oooo00<000@0
0?ooo`3oool05@3oool00`001000oooo0004000G0?ooo`030004003oool0oooo07T0oooo00<000@0
0?ooo`3oool0503oool010001000oooo0?ooo`00100G0?ooo`030004003oool0oooo0200oooo1P00
100A0?ooo`001`3oool00`001000oooo0?ooo`0E0?ooo`8000@05`3oool00`001000oooo0?ooo`1j
0?ooo`030004003oool0oooo01@0oooo0P00100G0?ooo`030004003oool0oooo00`0oooo0`001000
0`3oool000@00004000?0?ooo`8000@05@3oool000L0oooo00<000@00?ooo`3oool0;P3oool00`00
1000oooo0?ooo`1j0?ooo`030004003oool0oooo02d0oooo00<000@00?ooo`3oool01@3oool20004
00030?ooo`00100000@000@0oooo00@000@00?ooo`00100000@09P3oool000L0oooo00<000@00?oo
o`3oool0;P3oool00`001000oooo0?ooo`1j0?ooo`030004003oool0oooo02d0oooo00<000@00?oo
o`3oool01P3oool00`001000oooo000400040?ooo`030004003oool0oooo008000@09P3oool000L0
oooo00<000@00?ooo`3oool0;@3oool00`001000oooo0?ooo`1k0?ooo`030004003oool0oooo02d0
oooo00<000@00?ooo`3oool01P3oool3000400<0oooo0`0010000`3oool000@00004000V0?ooo`00
1`3oool00`001000oooo0?ooo`0]0?ooo`030004003oool0oooo07/0oooo00<000@00?ooo`3oool0
;@3oool00`001000oooo0?ooo`060?ooo`040004003oool000@0000402h0oooo00080?ooo`030004
003oool0oooo02/0oooo00<000@00?ooo`3oool0O@3oool00`001000oooo0?ooo`0[0?ooo`030004
003oool0oooo00L0oooo00<000@00?ooo`3oool0;`3oool000P0oooo00<000@00?ooo`3oool0:`3o
ool00`001000oooo0?ooo`1k0?ooo`030004003oool000@002d0oooo00<000@00?ooo`3oool01P3o
ool200040340oooo00090?ooo`030004003oool0oooo02T0oooo00<000@00?ooo`3oool0NP3oool2
000400<0oooo00<000@00?ooo`3oool0:@3oool00`001000oooo0?ooo`0j0?ooo`002@3oool00`00
1000oooo0?ooo`0Y0?ooo`030004003oool0oooo07P0oooo0P0010050?ooo`030004003oool0oooo
02T0oooo00<000@00?ooo`3oool0>P3oool000X0oooo00<000@00?ooo`3oool09`3oool00`001000
oooo0?ooo`1g0?ooo`8000@0203oool00`001000oooo0?ooo`0W0?ooo`030004003oool0oooo03/0
oooo000:0?ooo`030004003oool0oooo02L0oooo00<000@00?ooo`3oool0MP3oool00`001000oooo
0?ooo`080?ooo`030004003oool0oooo02L0oooo00<000@00?ooo`3oool0>`3oool000/0oooo00<0
00@00?ooo`3oool09@3oool00`001000oooo0?ooo`1e0?ooo`8000@0303oool00`001000oooo0?oo
o`0U0?ooo`030004003oool0oooo03`0oooo000<0?ooo`030004003oool0oooo02<0oooo00<000@0
0?ooo`3oool0M03oool2000400l0oooo00<000@00?ooo`3oool08`3oool00`001000oooo0?ooo`0m
0?ooo`003@3oool00`001000oooo0?ooo`0Q0?ooo`030004003oool0oooo07@0oooo00<000@00?oo
o`3oool0403oool00`001000oooo0?ooo`0Q0?ooo`030004003oool0oooo03h0oooo000>0?ooo`03
0004003oool0oooo0200oooo00<000@00?ooo`3oool0LP3oool2000401@0oooo00<000@00?ooo`3o
ool07`3oool00`001000oooo0?ooo`0o0?ooo`003`3oool00`001000oooo0?ooo`0N0?ooo`030004
003oool0oooo0740oooo0P00100G0?ooo`030004003oool0oooo01d0oooo00<000@00?ooo`3oool0
@03oool00100oooo00<000@00?ooo`3oool0703oool00`001000oooo0?ooo`1`0?ooo`8000@06P3o
ool00`001000oooo0?ooo`0L0?ooo`030004003oool0oooo0400oooo000A0?ooo`030004003oool0
oooo01T0oooo0P00101b0?ooo`030004003oool0oooo01/0oooo00<000@00?ooo`3oool06@3oool2
000404<0oooo000B0?ooo`8000@0603oool00`001000oooo0?ooo`1`0?ooo`8000@07`3oool20004
01L0oooo0P0010150?ooo`00503oool2000401@0oooo0P00101a0?ooo`8000@08`3oool2000401@0
oooo00<000@00?ooo`3oool0A@3oool001H0oooo0`00100=0?ooo`@000@0LP3oool00`001000oooo
0?ooo`0U0?ooo`<000@0303oool5000404P0oooo000I0?ooo`d000@0M03oool2000402/0oooo3000
101=0?ooo`007`3oool00`001000oooo0?ooo`1f0?ooo`8000@0<`3oool00`001000oooo0?ooo`1@
0?ooo`007`3oool2000407D0oooo0P00100d0?ooo`<000@0D@3oool001h0oooo0`00101d0?ooo`03
0004003oool0oooo03@0oooo0`00101A0?ooo`007P3oool300040780oooo0P00100g0?ooo`<000@0
D@3oool001h0oooo0`00101`0?ooo`8000@0>@3oool300040540oooo000N0?ooo`@000@0KP3oool0
0`001000oooo0?ooo`0h0?ooo`D000@0D03oool001h0oooo1000101/0?ooo`8000@0>`3oool50004
0500oooo000M0?ooo`D000@0JP3oool2000403d0oooo1@00101@0?ooo`007@3oool5000406P0oooo
0P00100o0?ooo`D000@0D03oool001d0oooo1P00101V0?ooo`030004003oool0oooo03h0oooo1`00
101?0?ooo`007@3oool6000406@0oooo0P0010110?ooo`L000@0C`3oool001d0oooo1P00101R0?oo
o`8000@0@`3oool7000404l0oooo000L0?ooo`L000@0H03oool2000404D0oooo1`00101?0?ooo`00
703oool8000405h0oooo00<000@00?ooo`3oool0A03oool9000404h0oooo000L0?ooo`P000@0G03o
ool2000404L0oooo2@00101>0?ooo`007`3oool00`001000oooo0?ooo`1L0?ooo`8000@0C@3oool0
0`001000oooo0?ooo`1@0?ooo`007`3oool00`001000oooo0?ooo`1K0?ooo`030004003oool0oooo
04d0oooo00<000@00?ooo`3oool0D03oool001l0oooo00<000@00?ooo`3oool0F@3oool200040500
oooo00<000@00?ooo`3oool0D03oool001l0oooo00<000@00?ooo`3oool0E`3oool200040580oooo
00<000@00?ooo`3oool0D03oool001l0oooo00<000@00?ooo`3oool0E@3oool2000405@0oooo00<0
00@00?ooo`3oool0D03oool001l0oooo00<000@00?ooo`3oool0E03oool00`001000oooo0?ooo`1D
0?ooo`030004003oool0oooo0500oooo000O0?ooo`030004003oool0oooo0580oooo0P00101G0?oo
o`030004003oool0oooo0500oooo000O0?ooo`030004003oool0oooo0500oooo0P00101I0?ooo`03
0004003oool0oooo0500oooo000O0?ooo`030004003oool0oooo04l0oooo00<000@00?ooo`3oool0
F@3oool00`001000oooo0?ooo`1@0?ooo`007`3oool00`001000oooo0?ooo`1=0?ooo`8000@0G03o
ool00`001000oooo0?ooo`1@0?ooo`007`3oool00`001000oooo0?ooo`1;0?ooo`8000@0GP3oool0
0`001000oooo0?ooo`1@0?ooo`007`3oool00`001000oooo0?ooo`190?ooo`8000@0H03oool00`00
1000oooo0?ooo`1@0?ooo`007`3oool00`001000oooo0?ooo`180?ooo`030004003oool0oooo01D0
oooo0`0010000`3oool000@00004000f0?ooo`8000@00P3oool3000400P0oooo00<000@00?ooo`3o
ool0D03oool001l0oooo00<000@00?ooo`3oool0AP3oool2000401X0oooo00@000@00?ooo`3oool0
00@0=P3oool00`001000oooo0?ooo`030?ooo`030004003oool0oooo00H0oooo00<000@00?ooo`3o
ool0D03oool001l0oooo00<000@00?ooo`3oool0A03oool2000401<0oooo0P0010000`3oool000@0
000400030?ooo`050004003oool0oooo0?ooo`001000;`3oool2000400030?ooo`00100000@000<0
oooo00D000@00?ooo`3oool0oooo000400090?ooo`030004003oool0oooo0500oooo000O0?ooo`03
0004003oool0oooo04<0oooo00<000@00?ooo`3oool0503oool00`001000oooo000400030?ooo`<0
00@000<0oooo000400001000<03oool00`001000oooo000400030?ooo`8000@00P3oool3000400P0
oooo00<000@00?ooo`3oool0D03oool001l0oooo00<000@00?ooo`3oool0303oool2000400<0oooo
00<000@00?ooo`3oool0;@3oool2000401L0oooo0`00100i0?ooo`<000@04P3oool00`001000oooo
0?ooo`1@0?ooo`007`3oool00`001000oooo0?ooo`050?ooo`8000@000<0oooo0004000010000`3o
ool00`001000oooo0?ooo`02000402d0oooo0P00100I0?ooo`040004003oool000@0000403P0oooo
00@000@00?ooo`00100000@04@3oool00`001000oooo0?ooo`1@0?ooo`007`3oool00`001000oooo
0?ooo`060?ooo`030004003oool000@000@0oooo00<000@00?ooo`3oool00P00100[0?ooo`8000@0
6`3oool00`001000oooo0?ooo`0i0?ooo`030004003oool0oooo0180oooo00<000@00?ooo`3oool0
D03oool001l0oooo00<000@00?ooo`3oool01P3oool3000400<0oooo0P0010030?ooo`030004003o
ool0oooo02P0oooo00<000@00?ooo`3oool06P3oool2000403X0oooo0P00100D0?ooo`030004003o
ool0oooo0500oooo000O0?ooo`030004003oool0oooo00H0oooo00@000@00?ooo`00100000@0<03o
ool2000406l0oooo00<000@00?ooo`3oool0D03oool001l0oooo00<000@00?ooo`3oool01P3oool0
0`001000oooo0?ooo`0_0?ooo`8000@0L@3oool00`001000oooo0?ooo`1@0?ooo`007`3oool00`00
1000oooo0?ooo`050?ooo`8000@0;`3oool2000407<0oooo00<000@00?ooo`3oool0D03oool001l0
oooo00<000@00?ooo`3oool0=@3oool00`001000oooo0?ooo`1c0?ooo`030004003oool0oooo0500
oooo000O0?ooo`030004003oool0oooo03<0oooo0P00101f0?ooo`030004003oool0oooo0500oooo
000O0?ooo`030004003oool0oooo0340oooo0P00101h0?ooo`030004003oool0oooo0500oooo000O
0?ooo`030004003oool0oooo0300oooo00<000@00?ooo`3oool0N03oool00`001000oooo0?ooo`1@
0?ooo`007`3oool00`001000oooo0?ooo`0^0?ooo`8000@0N`3oool00`001000oooo0?ooo`1@0?oo
o`007`3oool00`001000oooo0?ooo`0/0?ooo`8000@0O@3oool00`001000oooo0?ooo`1@0?ooo`00
7`3oool00`001000oooo0?ooo`0Z0?ooo`8000@0O`3oool00`001000oooo0?ooo`1@0?ooo`007`3o
ool00`001000oooo0?ooo`0Y0?ooo`030004003oool0oooo07l0oooo00<000@00?ooo`3oool0D03o
ool001l0oooo00<000@00?ooo`3oool09`3oool200040880oooo00<000@00?ooo`3oool0D03oool0
01l0oooo00<000@00?ooo`3oool09@3oool2000408@0oooo00<000@00?ooo`3oool0D03oool001l0
oooo00<000@00?ooo`3oool0903oool00`001000oooo0?ooo`240?ooo`030004003oool0oooo0500
oooo000L0?ooo`T000@06@3oool00`001000oooo0?ooo`030?ooo`8000@0Q03oool9000404d0oooo
000G0?ooo`D000@02@3oool2000401H0oooo0P0010030?ooo`8000@0P@3oool5000400T0oooo0P00
101;0?ooo`005@3oool200040100oooo0`00100B0?ooo`H000@0P@3oool200040100oooo0P001019
0?ooo`004`3oool2000401D0oooo0P00100?0?ooo`D000@0P@3oool2000401@0oooo0`0010160?oo
o`004P3oool00`001000oooo0?ooo`0G0?ooo`8000@0303oool7000407l0oooo00<000@00?ooo`3o
ool05`3oool2000404@0oooo000A0?ooo`030004003oool0oooo01X0oooo0P0010080?ooo`T000@0
OP3oool00`001000oooo0?ooo`0J0?ooo`8000@0@P3oool000l0oooo0P00100O0?ooo`030004003o
ool0oooo00@0oooo2`00101k0?ooo`8000@07P3oool00`001000oooo0?ooo`100?ooo`003P3oool0
0`001000oooo0?ooo`0P0?ooo`030004003oool0oooo0080oooo2P00101l0?ooo`030004003oool0
oooo01l0oooo00<000@00?ooo`3oool0?`3oool000d0oooo00<000@00?ooo`3oool08@3oool01000
1000oooo0?ooo`3oool7000407l0oooo00<000@00?ooo`3oool08@3oool00`001000oooo0?ooo`0n
0?ooo`00303oool00`001000oooo0?ooo`0S0?ooo`030004003oool000@000@000@0P@3oool00`00
1000oooo0?ooo`0S0?ooo`030004003oool0oooo03d0oooo000;0?ooo`030004003oool0oooo02D0
oooo0P0010240?ooo`030004003oool0oooo02D0oooo00<000@00?ooo`3oool0?03oool000X0oooo
00<000@00?ooo`3oool09`3oool00`001000oooo0?ooo`210?ooo`030004003oool0oooo02L0oooo
00<000@00?ooo`3oool0>`3oool000X0oooo00<000@00?ooo`3oool09`3oool00`001000oooo0?oo
o`210?ooo`030004003oool0oooo02L0oooo00<000@00?ooo`3oool0>`3oool000T0oooo00<000@0
0?ooo`3oool0:@3oool00`001000oooo0?ooo`1o0?ooo`030004003oool0oooo02T0oooo00<000@0
0?ooo`3oool0>P3oool000T0oooo00<000@00?ooo`3oool0:@3oool00`001000oooo0?ooo`1o0?oo
o`030004003oool0oooo02T0oooo00<000@00?ooo`3oool0>P3oool000P0oooo00<000@00?ooo`3o
ool0:`3oool00`001000oooo0?ooo`1m0?ooo`030004003oool0oooo02/0oooo00<000@00?ooo`3o
ool0>@3oool000P0oooo00<000@00?ooo`3oool0:`3oool00`001000oooo0?ooo`1m0?ooo`030004
003oool0oooo02/0oooo00<000@00?ooo`3oool0>@3oool000P0oooo00<000@00?ooo`3oool0;03o
ool00`001000oooo0?ooo`1l0?ooo`030004003oool0oooo02`0oooo00<000@00?ooo`3oool0>03o
ool000L0oooo00<000@00?ooo`3oool0;@3oool00`001000oooo0?ooo`1k0?ooo`030004003oool0
oooo02d0oooo00<000@00?ooo`3oool0>03oool000L0oooo00<000@00?ooo`3oool0;P3oool00`00
1000oooo0?ooo`1j0?ooo`030004003oool0oooo02d0oooo00<000@00?ooo`3oool0>03oool000L0
oooo00<000@00?ooo`3oool0;P3oool00`001000oooo0?ooo`1j0?ooo`030004003oool0oooo02d0
oooo00<000@00?ooo`3oool0>03oool000L0oooo00<000@00?ooo`3oool0;P3oool00`001000oooo
0?ooo`1[0?ooo`8000@03@3oool00`001000oooo0?ooo`0]0?ooo`030004003oool0oooo03P0oooo
00070?ooo`030004003oool0oooo02h0oooo00<000@00?ooo`3oool0J`3oool6000400T0oooo00<0
00@00?ooo`3oool0;P3oool00`001000oooo0?ooo`0g0?ooo`001P3oool00`001000oooo0?ooo`0D
0?ooo`D000@05P3oool00`001000oooo0?ooo`1[0?ooo`T000@01@3oool00`001000oooo0?ooo`0D
0?ooo`@000@05`3oool00`001000oooo0?ooo`0g0?ooo`001P3oool00`001000oooo0?ooo`0F0?oo
o`030004003oool0oooo01H0oooo00<000@00?ooo`3oool0J`3oool=000400030?ooo`001000oooo
01D0oooo00<000@00?ooo`3oool0603oool00`001000oooo0?ooo`0g0?ooo`001P3oool00`001000
oooo0?ooo`0F0?ooo`030004003oool0oooo01H0ooooO@00100G0?ooo`030004003oool0oooo01L0
oooo00<000@00?ooo`3oool0=`3oool000H0oooo00<000@00?ooo`3oool05P3oool00`001000oooo
0?ooo`0F0?ooo`030004003oool0oooo06/0oooo300010020?ooo`030004003oool0oooo01H0oooo
00<000@00?ooo`3oool05P3oool00`001000oooo0?ooo`0g0?ooo`001P3oool00`001000oooo0?oo
o`0F0?ooo`030004003oool0oooo01H0oooo00<000@00?ooo`3oool0J`3oool8000400H0oooo00<0
00@00?ooo`3oool0503oool010001000oooo0?ooo`00100G0?ooo`030004003oool0oooo03L0oooo
00070?ooo`030004003oool0oooo01@0oooo0P00100H0?ooo`030004003oool0oooo06/0oooo0`00
100<0?ooo`030004003oool0oooo01@0oooo0P00100H0?ooo`030004003oool0oooo03L0oooo0007
0?ooo`030004003oool0oooo02h0oooo00<000@00?ooo`3oool0NP3oool00`001000oooo0?ooo`0]
0?ooo`030004003oool0oooo03P0oooo00070?ooo`030004003oool0oooo02h0oooo00<000@00?oo
o`3oool0NP3oool00`001000oooo0?ooo`0]0?ooo`030004003oool0oooo03P0oooo00070?ooo`03
0004003oool0oooo02d0oooo00<000@00?ooo`3oool0N`3oool00`001000oooo0?ooo`0]0?ooo`03
0004003oool0oooo03P0oooo00070?ooo`030004003oool0oooo02d0oooo00<000@00?ooo`3oool0
N`3oool00`001000oooo0?ooo`0]0?ooo`030004003oool0oooo03P0oooo00080?ooo`030004003o
ool0oooo02/0oooo00<000@00?ooo`3oool0O@3oool00`001000oooo0?ooo`0[0?ooo`030004003o
ool0oooo03T0oooo00080?ooo`030004003oool0oooo02/0oooo00<000@00?ooo`3oool0O@3oool0
0`001000oooo0?ooo`0[0?ooo`030004003oool0oooo03T0oooo00090?ooo`030004003oool0oooo
02X0oooo00<000@00?ooo`3oool0OP3oool00`001000oooo0?ooo`0Z0?ooo`030004003oool0oooo
03T0oooo00090?ooo`030004003oool0oooo02T0oooo00<000@00?ooo`3oool0O`3oool00`001000
oooo0?ooo`0Y0?ooo`030004003oool0oooo03X0oooo00090?ooo`030004003oool0oooo02T0oooo
00<000@00?ooo`3oool0O`3oool00`001000oooo0?ooo`0Y0?ooo`030004003oool0oooo03X0oooo
000:0?ooo`030004003oool0oooo02L0oooo00<000@00?ooo`3oool0P@3oool00`001000oooo0?oo
o`0W0?ooo`030004003oool0oooo03/0oooo000:0?ooo`030004003oool0oooo02L0oooo00<000@0
0?ooo`3oool0P@3oool00`001000oooo0?ooo`0W0?ooo`030004003oool0oooo03/0oooo000;0?oo
o`030004003oool0oooo02D0oooo00<000@00?ooo`3oool0P`3oool00`001000oooo0?ooo`0U0?oo
o`030004003oool0oooo03`0oooo000<0?ooo`030004003oool0oooo02<0oooo00<000@00?ooo`3o
ool0Q@3oool00`001000oooo0?ooo`0S0?ooo`030004003oool0oooo03d0oooo000=0?ooo`030004
003oool0oooo0240oooo00<000@00?ooo`3oool0@P3oool200040080oooo0P00100o0?ooo`030004
003oool0oooo0240oooo00<000@00?ooo`3oool0?P3oool000h0oooo0P00100Q0?ooo`030004003o
ool0oooo03/0oooo0P0010000`3oool000@0000400030?ooo`040004003oool0oooo00040440oooo
0P00100P0?ooo`030004003oool0oooo03l0oooo000@0?ooo`030004003oool0oooo01`0oooo0P00
100o0?ooo`030004003oool000@000@0oooo00D000@00?ooo`3oool0oooo000400120?ooo`030004
003oool0oooo01`0oooo00<000@00?ooo`3oool0@03oool00140oooo00<000@00?ooo`3oool06P3o
ool00`001000oooo0?ooo`0o0?ooo`<000@00`3oool200040080oooo0P0010130?ooo`030004003o
ool0oooo01X0oooo00<000@00?ooo`3oool0@@3oool00180oooo0P00100I0?ooo`030004003oool0
oooo0400oooo00@000@00?ooo`00100000@0C03oool2000401P0oooo0P0010140?ooo`00503oool2
000401@0oooo0`0010130?ooo`030004003oool0oooo04l0oooo0P00100D0?ooo`8000@0AP3oool0
01H0oooo0`00100?0?ooo`8000@0A@3oool2000405<0oooo0`00100?0?ooo`8000@0B03oool001T0
oooo1@0010050?ooo`D000@0W`3oool4000400H0oooo1@00101:0?ooo`007P3oool500040:P0oooo
1P00101?0?ooo`007`3oool00`001000oooo0?ooo`3n0?ooo`007`3oool200040?l0oooo000N0?oo
o`<000@0o`3oool001h0oooo0`00103o0?ooo`007P3oool300040?l0oooo000N0?ooo`8000@000<0
oooo0004003oool0o@3oool001d0oooo00D000@00?ooo`001000oooo0004003n0?ooo`007@3oool0
1@001000oooo0004003oool000@00?h0oooo000M0?ooo`030004003oool000@00080oooo00<000@0
0?ooo`3oool0n`3oool001d0oooo00<000@00?ooo`0010000P3oool00`001000oooo0?ooo`3k0?oo
o`007@3oool00`001000oooo000400020?ooo`030004003oool0oooo0?/0oooo000L0?ooo`040004
003oool0oooo00040080oooo00<000@00?ooo`3oool0n`3oool001`0oooo00@000@00?ooo`3oool0
00@00`3oool00`001000oooo0?ooo`3j0?ooo`00703oool010001000oooo0?ooo`0010030?ooo`03
0004003oool0oooo0?X0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003o
ool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo
0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo
000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?oo
o`030004003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000O0?ooo`030004
003oool0oooo0?h0oooo000O0?ooo`030004003oool0oooo0?h0oooo000?0?ooo`030004003oool0
oooo00H0oooo00<000@00?ooo`3oool0103oool00`001000oooo0?ooo`3n0?ooo`001`3oool20004
00D0oooo00<000@00?ooo`3oool0203oool00`001000oooo0?ooo`030?ooo`030004003oool0oooo
0?h0oooo0004000400@0oooo00<000@00?ooo`3oool00P3oool00`001000oooo0?ooo`030?ooo`80
00@01@3oool00`001000oooo0?ooo`020?ooo`030004003oool0oooo0?h0oooo00001@3oool000@0
0?ooo`3oool000@000<0oooo00<000@00?ooo`3oool00P3oool00`001000oooo0?ooo`020?ooo`04
0004003oool0oooo000400@0oooo00<000@00?ooo`3oool00P3oool00`001000oooo0?ooo`3n0?oo
o`0000D0oooo0004003oool0oooo000400020?ooo`8000@0103oool00`001000oooo0?ooo`020?oo
o`030004003oool0oooo00D0oooo00<000@00?ooo`3oool00P3oool00`001000oooo0?ooo`3n0?oo
o`0000@0oooo00040000100000@02@3oool010001000oooo0?ooo`3oool5000400@0oooo00<000@0
0?ooo`3oool00P3oool00`001000oooo0?ooo`3n0?ooo`0000<0oooo0004003oool02`3oool01@00
1000oooo0?ooo`3oool000@000H0oooo00<000@00?ooo`3oool00`3oool00`001000oooo0?ooo`3n
0?ooo`000P00100=0?ooo`030004003oool0oooo00H0oooo00<000@00?ooo`3oool0103oool00`00
1000oooo0?ooo`3n0?ooo`007`3oool00`001000oooo0?ooo`3n0?ooo`007`3oool00`001000oooo
0?ooo`3n0?ooo`007`3oool00`001000oooo0?ooo`3n0?ooo`007`3oool00`001000oooo0?ooo`3n
0?ooo`007`3oool00`001000oooo0?ooo`3n0?ooo`007`3oool00`001000oooo0?ooo`3n0?ooo`00
7`3oool00`001000oooo0?ooo`3n0?ooo`007`3oool00`001000oooo0?ooo`3n0?ooo`007`3oool0
0`001000oooo0?ooo`3n0?ooo`007`3oool00`001000oooo0?ooo`3n0?ooo`007`3oool00`001000
oooo0?ooo`3n0?ooo`007`3oool00`001000oooo0?ooo`3n0?ooo`007`3oool00`001000oooo0?oo
o`3n0?ooo`007`3oool00`001000oooo0?ooo`3n0?ooo`007`3oool00`001000oooo0?ooo`3n0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{94, 381}, {334.813, 74}} -> {-2.53078, -2.13544, \
0.0201296, 0.0201296}}],

Cell[TextData[{
  "We will refer to iodine 131 which has a radioactive half-life of 8 days, \
this meaning that radioactive decay constant \[Lambda] is Log[2]/8  ",
  Cell[BoxData[
      \(TraditionalForm\`day\^\(-1\)\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell["Example 1.- Continuous input", "SubsubsectionIcon"],

Cell[TextData[{
  "The first step for solving a model usually consists in building the \
compartmental matrix A. It is easy with SysModel using the command ",
  Cell[BoxData[
      ButtonBox[
        StyleBox["CompartMatrix",
          FontColor->RGBColor[0, 0, 1],
          FontVariations->{"Underline"->True}],
        ButtonFunction:>(Internal`PutInformation[ #, LongForm -> False]&),
        ButtonData:>{"Info3234081075-1445498", 
          "Biokmod`SysModel`CompartMatrix"},
        ButtonFrame->"None",
        ButtonNote->"Biokmod`SysModel`"]],
    CellMargins->{{20, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
    Background->GrayLevel[0.930022],
    ButtonBoxOptions->{Active->True}],
  ".  Here is an example. The compartmental matrix of the model drawn in \
figure1 is given by "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(iodine\  = 
      CompartMatrix[
        3, {{1, 2, \ 0.8316}, {1, 0, 1.9404}, {2, 3, 0.0086625}\ , {3, 0, 
            0.01155}\ , {3, 1, 0.0462}}, \ Log[2]/8]\)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \({{\(-2.8586433975699928`\), 0, 
        0.0462`}, {0.8316`, \(-0.09530589756999316`\), 0}, {0, 
        0.0086625`, \(-0.14439339756999314`\)}}\)], "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell["\<\
The second step is to define the input function to each compartments. \
\>", "Text"],

Cell[TextData[{
  "We suppose an input function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(b\_1\),
            "TraditionalForm"], "(", "t", ")"}], TraditionalForm]]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(=\)\(\ \)\(1 + Cos[0.1\ t]\)\)\)]],
  ", in mg/day,  into compartment 1. Not inputs are assumed in other \
compartments"
}], "Text"],

Cell[BoxData[
    \(b1Iodine\  = \ {1 + \ Cos[0.1\ t], \ 0, \ 0}; \)], "Input",
  CellLabel->"In[41]:="],

Cell[TextData[{
  "The third step is to give the initial conditions. In our example it is \
assumed that the initial concentration of iodine in all compartment is \"0\", \
that is  ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  "(0) =  ",
  Cell[BoxData[
      \(TraditionalForm\`x\_2\)]],
  "(0)  = ",
  Cell[BoxData[
      \(TraditionalForm\`x\_3\)]],
  "(0) = 0 "
}], "Text"],

Cell[BoxData[
    \(icIodine\  = \ {0, 0, 0}; \)], "Input",
  CellLabel->"In[42]:="],

Cell[TextData[{
  "How is assumed a continuous input it is applied the SysModel command ",
  Cell[BoxData[
      ButtonBox[
        StyleBox["SystemDSolve",
          FontColor->RGBColor[0, 0, 1],
          FontVariations->{"Underline"->True}],
        ButtonFunction:>(Internal`PutInformation[ #, LongForm -> False]&),
        ButtonData:>{"Info3234081075-1445498", 
          "Biokmod`SysModel`SystemDSolve"},
        ButtonFrame->"None",
        ButtonNote->"Biokmod`SysModel`"]],
    CellMargins->{{20, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
    Background->GrayLevel[0.930022],
    ButtonBoxOptions->{Active->True}],
  " . Here is solved the before example."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\ x1[t_], x2[t_], 
        x3[t_]}\  = \ {x\_1[t], x\_2[t], x\_3[t]} /. 
          SystemDSolve[iodine, icIodine, b1Iodine, t, t, \ x] // 
        Chop\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \({\(\(0.35280099212137916`\)\(\[InvisibleSpace]\)\) - 
        0.6992385095349931`\ \[ExponentialE]\^\(\(-2.8585990234247185`\)\ t\) \
+ 0.009642999510116155`\ \[ExponentialE]\^\(\(-0.14677770424391592`\)\ t\) - 
        0.012729867194943253`\ \[ExponentialE]\^\(\(-0.0929659650413442`\)\ t\
\) + 0.34952438509844114`\ Cos[0.1`\ t] + 
        0.01389412443806384`\ Sin[
            0.1`\ t], \(\(3.0783961174351484`\)\(\[InvisibleSpace]\)\) + 
        0.21043252309667226`\ \[ExponentialE]\^\(\(-2.8585990234247185`\)\ \
t\) - 0.1557963263930923`\ \[ExponentialE]\^\(\(-0.14677770424391592`\)\ t\) \
- 4.524129405315418`\ \[ExponentialE]\^\(\(-0.0929659650413442`\)\ t\) + 
        1.3910970911766896`\ Cos[0.1`\ t] + 
        1.580847217662625`\ Sin[
            0.1`\ t], \(\(0.18468023341826006`\)\(\[InvisibleSpace]\)\) - 
        0.0006716041385961265`\ \[ExponentialE]\^\(\(-2.8585990234247185`\)\ \
t\) + 0.5660285617368866`\ \[ExponentialE]\^\(\(-0.14677770424391592`\)\ t\) \
- 0.7620499225138813`\ \[ExponentialE]\^\(\(-0.0929659650413442`\)\ t\) + 
        0.012012731497330731`\ Cos[0.1`\ t] + 
        0.10315819437322396`\ Sin[0.1`\ t]}\)], "Output",
  CellLabel->"Out[43]="]
}, Open  ]],

Cell["\<\
With options other method can be used (\"LaplaceTransform\", \"EigenValues\" \
or \"DSolve\")\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SystemDSolve[iodine, icIodine, b1Iodine, t, t, \ x, \ 
      Method \[Rule] \ "\<LaplaceTransform\>"]\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \({x\_1[t] \[Rule] \(\(0.3528009921213792`\)\(\[InvisibleSpace]\)\) - 
          0.6992385095349931`\ \[ExponentialE]\^\(\(-2.858599023424719`\)\ \
t\) + 0.00964299951078637`\ \[ExponentialE]\^\(\(-0.14677770424391592`\)\ t\) \
- 0.012729867196055844`\ \[ExponentialE]\^\(\(-0.0929659650413442`\)\ t\) + 
          0.3495243850988833`\ Cos[0.1`\ t] + 
          0.01389412443801235`\ Sin[0.1`\ t], 
      x\_2[t] \[Rule] \(\(3.0783961174351493`\)\(\[InvisibleSpace]\)\) + 
          0.210432523096672`\ \[ExponentialE]\^\(\(-2.858599023424719`\)\ t\) \
- 0.15579632639306684`\ \[ExponentialE]\^\(\(-0.14677770424391592`\)\ t\) - 
          4.524129405315461`\ \[ExponentialE]\^\(\(-0.0929659650413442`\)\ \
t\) + 1.3910970911767064`\ Cos[0.1`\ t] + 1.5808472176626231`\ Sin[0.1`\ t], 
      x\_3[t] \[Rule] \(\(0.18468023341826012`\)\(\[InvisibleSpace]\)\) - 
          0.0006716041385962082`\ \[ExponentialE]\^\(\(-2.858599023424719`\)\ \
t\) + 0.5660285617368889`\ \[ExponentialE]\^\(\(-0.14677770424391592`\)\ t\) \
- 0.7620499225138848`\ \[ExponentialE]\^\(\(-0.0929659650413442`\)\ t\) + 
          0.012012731497332042`\ Cos[0.1`\ t] + 
          0.10315819437322392`\ Sin[0.1`\ t]}\)], "Output",
  CellLabel->"Out[44]="]
}, Open  ]],

Cell[TextData[{
  "This solution look like easier than the applied ",
  Cell[BoxData[
      ButtonBox[
        StyleBox["SystemDSolve",
          FontColor->RGBColor[0, 0, 1],
          FontVariations->{"Underline"->True}],
        ButtonFunction:>(Internal`PutInformation[ #, LongForm -> False]&),
        ButtonData:>{"Info3234081075-1445498", 
          "Biokmod`SysModel`SystemDSolve"},
        ButtonFrame->"None",
        ButtonNote->"Biokmod`SysModel`"]],
    CellMargins->{{20, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
    Background->GrayLevel[0.930022],
    ButtonBoxOptions->{Active->True}],
  " by default, however we can test that both solutions are already equals"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(SystemDSolve[iodine, icIodine, b1Iodine, t, t, \ x] // Simplify\) // 
      Chop\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \({x\_1[t] \[Rule] \(\(0.35280099212137916`\)\(\[InvisibleSpace]\)\) - 
          0.6992385095349931`\ \[ExponentialE]\^\(\(-2.8585990234247185`\)\ t\
\) + 0.009642999510116155`\ \[ExponentialE]\^\(\(-0.14677770424391592`\)\ t\) \
- 0.012729867194943253`\ \[ExponentialE]\^\(\(-0.0929659650413442`\)\ t\) + 
          0.34952438509844114`\ Cos[0.1`\ t] + 
          0.01389412443806384`\ Sin[0.1`\ t], 
      x\_2[t] \[Rule] \(\(3.0783961174351484`\)\(\[InvisibleSpace]\)\) + 
          0.21043252309667226`\ \[ExponentialE]\^\(\(-2.8585990234247185`\)\ \
t\) - 0.1557963263930923`\ \[ExponentialE]\^\(\(-0.14677770424391592`\)\ t\) \
- 4.524129405315418`\ \[ExponentialE]\^\(\(-0.0929659650413442`\)\ t\) + 
          1.3910970911766896`\ Cos[0.1`\ t] + 
          1.580847217662625`\ Sin[0.1`\ t], 
      x\_3[t] \[Rule] \(\(0.18468023341826006`\)\(\[InvisibleSpace]\)\) - 
          0.0006716041385961265`\ \[ExponentialE]\^\(\(-2.8585990234247185`\)\
\ t\) + 0.5660285617368866`\ \[ExponentialE]\^\(\(-0.14677770424391592`\)\ \
t\) - 0.7620499225138813`\ \[ExponentialE]\^\(\(-0.0929659650413442`\)\ t\) + 
          0.012012731497330731`\ Cos[0.1`\ t] + 
          0.10315819437322396`\ Sin[0.1`\ t]}\)], "Output",
  CellLabel->"Out[45]="]
}, Open  ]],

Cell[BoxData[
    RowBox[{
    "It", " ", "can", " ", "be", " ", "shown", " ", "the", " ", "System", " ",
       "of", " ", "ODE", " ", "of", " ", "the", " ", "model", " ", 
      ButtonBox[
        StyleBox["ShowODE",
          FontColor->RGBColor[0, 0, 1],
          FontVariations->{"Underline"->True}],
        ButtonFunction:>(Internal`PutInformation[ #, LongForm -> False]&),
        ButtonData:>{"Info3234081075-1445498", "Biokmod`SysModel`ShowODE"},
        ButtonFrame->"None",
        ButtonNote->"Biokmod`SysModel`"]}]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowODE[iodine, \ icIodine, \ b1Iodine, \ t, \ x] // TableForm\) // 
      TraditionalForm\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              RowBox[{
                RowBox[{
                  SuperscriptBox[\(x\_1\), "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], 
                "\[LongEqual]", \(cos(0.1`\ t) - 
                  2.8586433975699928`\ \(\(x\_1\)(t)\) + 
                  0.0462`\ \(\(x\_3\)(t)\) + 1\)}]},
            {
              RowBox[{
                RowBox[{
                  SuperscriptBox[\(x\_2\), "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], 
                "\[LongEqual]", \(0.8316`\ \(\(x\_1\)(t)\) - 
                  0.09530589756999316`\ \(\(x\_2\)(t)\)\)}]},
            {
              RowBox[{
                RowBox[{
                  SuperscriptBox[\(x\_3\), "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], 
                "\[LongEqual]", \(0.0086625`\ \(\(x\_2\)(t)\) - 
                  0.14439339756999314`\ \(\(x\_3\)(t)\)\)}]},
            {\(\(x\_1\)(0) \[LongEqual] 0\)},
            {\(\(x\_2\)(0) \[LongEqual] 0\)},
            {\(\(x\_3\)(0) \[LongEqual] 0\)}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {
          Equal[ 
            Derivative[ 1][ 
              Subscript[ x, 1]][ t], 
            Plus[ 1, 
              Cos[ 
                Times[ .10000000000000001, t]], 
              Times[ -2.8586433975699928, 
                Subscript[ x, 1][ t]], 
              Times[ .046199999999999998, 
                Subscript[ x, 3][ t]]]], 
          Equal[ 
            Derivative[ 1][ 
              Subscript[ x, 2]][ t], 
            Plus[ 
              Times[ .83160000000000001, 
                Subscript[ x, 1][ t]], 
              Times[ -.095305897569993164, 
                Subscript[ x, 2][ t]]]], 
          Equal[ 
            Derivative[ 1][ 
              Subscript[ x, 3]][ t], 
            Plus[ 
              Times[ .0086625000000000001, 
                Subscript[ x, 2][ t]], 
              Times[ -.14439339756999314, 
                Subscript[ x, 3][ t]]]], 
          Equal[ 
            Subscript[ x, 1][ 0], 0], 
          Equal[ 
            Subscript[ x, 2][ 0], 0], 
          Equal[ 
            Subscript[ x, 3][ 0], 0]}]], TraditionalForm]], "Output",
  CellLabel->"Out[46]//TraditionalForm="]
}, Open  ]],

Cell["Now we plot the evolution in each compartment", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{\ x1[t], x2[t], x3[t]}, \ {t, \ 1, \ 200}, \[IndentingNewLine]\ 
      PlotStyle \[Rule] {\[IndentingNewLine]{AbsoluteThickness[0.5], \ 
            AbsoluteDashing[{4, 4}]}, {AbsoluteThickness[1.5], \ 
            AbsoluteDashing[{1, 6}]}, {AbsoluteThickness[1.5], \ 
            AbsoluteDashing[{1, 10}]}}, \ 
      AxesLabel \[Rule] {"\<days\>", \ "\<r\>"}, 
      PlotLegend \[Rule] {"\<x1\>", "\<x2\>", "\<x3\>"}, 
      LegendPosition \[Rule] {0.5, \ 0}, 
      LegendSize \[Rule] {0.25, \ 
          0.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Iodine Model: input \
1 + Cos [0.1 t]\>"]\)], "Input",
  CellLabel->"In[47]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.0147151 0.11354 [
[.2619 .00222 -6 -9 ]
[.2619 .00222 6 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[1.025 .01472 0 -6.25 ]
[1.025 .01472 28 6.25 ]
[.01131 .12826 -6 -4.5 ]
[.01131 .12826 0 4.5 ]
[.01131 .2418 -6 -4.5 ]
[.01131 .2418 0 4.5 ]
[.01131 .35534 -6 -4.5 ]
[.01131 .35534 0 4.5 ]
[.01131 .46888 -6 -4.5 ]
[.01131 .46888 0 4.5 ]
[.01131 .58242 -6 -4.5 ]
[.01131 .58242 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12.5 ]
[.5 .63053 -107.094 0 ]
[.5 .63053 107.094 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(50)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(100)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(150)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(200)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .12826 m
.03006 .12826 L
s
[(1)] .01131 .12826 1 0 Mshowa
.02381 .2418 m
.03006 .2418 L
s
[(2)] .01131 .2418 1 0 Mshowa
.02381 .35534 m
.03006 .35534 L
s
[(3)] .01131 .35534 1 0 Mshowa
.02381 .46888 m
.03006 .46888 L
s
[(4)] .01131 .46888 1 0 Mshowa
.02381 .58242 m
.03006 .58242 L
s
[(5)] .01131 .58242 1 0 Mshowa
.125 Mabswid
.02381 .03742 m
.02756 .03742 L
s
.02381 .06013 m
.02756 .06013 L
s
.02381 .08284 m
.02756 .08284 L
s
.02381 .10555 m
.02756 .10555 L
s
.02381 .15096 m
.02756 .15096 L
s
.02381 .17367 m
.02756 .17367 L
s
.02381 .19638 m
.02756 .19638 L
s
.02381 .21909 m
.02756 .21909 L
s
.02381 .2645 m
.02756 .2645 L
s
.02381 .28721 m
.02756 .28721 L
s
.02381 .30992 m
.02756 .30992 L
s
.02381 .33263 m
.02756 .33263 L
s
.02381 .37804 m
.02756 .37804 L
s
.02381 .40075 m
.02756 .40075 L
s
.02381 .42346 m
.02756 .42346 L
s
.02381 .44617 m
.02756 .44617 L
s
.02381 .49159 m
.02756 .49159 L
s
.02381 .51429 m
.02756 .51429 L
s
.02381 .537 m
.02756 .537 L
s
.02381 .55971 m
.02756 .55971 L
s
.02381 .60513 m
.02756 .60513 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -168.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Iodine) show
105.188 12.750 moveto
(Model) show
135.188 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
147.188 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(input) show
183.188 12.750 moveto
(1) show
195.188 12.750 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
207.188 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Cos) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
231.188 12.750 moveto
(@) show
237.188 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
261.188 12.750 moveto
(t) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
267.188 12.750 moveto
(D) show
273.188 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02857 .08949 m
.02974 .09171 L
.03081 .09269 L
.03203 .09319 L
.0332 .09333 L
.03427 .09331 L
.03526 .09322 L
.03635 .09307 L
.0375 .09287 L
.04216 .09175 L
.04729 .0901 L
.05747 .08561 L
.06701 .08012 L
.10894 .04758 L
.12738 .03338 L
.13713 .02702 L
.14752 .02152 L
.15324 .01915 L
.15842 .01744 L
.16092 .01677 L
.16363 .01616 L
.16617 .01571 L
.16854 .01538 L
.16971 .01526 L
.17096 .01515 L
.17167 .0151 L
.17234 .01506 L
.17361 .01501 L
.17425 .015 L
.17494 .01499 L
.17617 .015 L
.17685 .01501 L
.17749 .01504 L
.1782 .01507 L
.17896 .01511 L
.18012 .0152 L
.18139 .01532 L
.18395 .01565 L
.18633 .01606 L
.18853 .01653 L
.19356 .01789 L
.199 .01983 L
.20889 .0245 L
.22738 .03651 L
.2681 .06942 L
.27786 .07663 L
.28835 .08335 L
.29826 .08843 L
.30264 .09022 L
.3073 .0918 L
Mistroke
.30982 .09251 L
.31211 .09306 L
.31443 .09353 L
.31656 .09388 L
.31905 .09419 L
.32037 .0943 L
.32104 .09435 L
.32175 .0944 L
.32296 .09445 L
.32409 .09448 L
.32477 .09448 L
.32542 .09448 L
.32664 .09446 L
.3277 .09442 L
.32886 .09435 L
.33008 .09425 L
.33122 .09414 L
.33325 .09388 L
.33544 .09352 L
.34043 .09239 L
.345 .091 L
.35478 .08692 L
.36387 .08191 L
.38448 .06725 L
.42338 .03582 L
.4336 .02883 L
.44466 .0226 L
.44974 .02031 L
.45511 .0183 L
.45969 .01696 L
.4623 .01635 L
.46472 .01589 L
.46722 .01552 L
.46853 .01537 L
.46993 .01524 L
.47114 .01515 L
.47227 .0151 L
.47352 .01506 L
.47422 .01506 L
.47486 .01506 L
.47598 .01507 L
.47701 .01511 L
.47815 .01517 L
.47937 .01526 L
.48064 .01539 L
.48185 .01553 L
.48411 .01586 L
.48663 .01634 L
.4893 .01696 L
.49409 .01837 L
Mistroke
.50491 .02288 L
.51429 .02813 L
.52437 .03491 L
.54258 .04919 L
.56221 .06541 L
.57257 .07342 L
.58362 .08098 L
.59437 .087 L
.60412 .09104 L
.60883 .09246 L
.61131 .09306 L
.61392 .09358 L
.61621 .09395 L
.61743 .0941 L
.61873 .09424 L
.61992 .09434 L
.62101 .09441 L
.62211 .09445 L
.62315 .09448 L
.62428 .09449 L
.62551 .09447 L
.62666 .09443 L
.62772 .09437 L
.62889 .09429 L
.63018 .09417 L
.63276 .09383 L
.63532 .09339 L
.63805 .0928 L
.64297 .09141 L
.65258 .08759 L
.66131 .08297 L
.68041 .06981 L
.70111 .05293 L
.72051 .03736 L
.7308 .03011 L
.74184 .02362 L
.74728 .02101 L
.75244 .01895 L
.75707 .01745 L
.75972 .01676 L
.76211 .01623 L
.7644 .01581 L
.76688 .01546 L
.76824 .01532 L
.76949 .01521 L
.77069 .01514 L
.77195 .01508 L
.77304 .01506 L
.7742 .01506 L
.7753 .01508 L
Mistroke
.7763 .01512 L
.77748 .01518 L
.77875 .01528 L
.78107 .01553 L
.7834 .01588 L
.78591 .01636 L
.79045 .01749 L
.79585 .01928 L
.8008 .02131 L
.81152 .02694 L
.82172 .03359 L
.85971 .06403 L
.88091 .07976 L
.89092 .08566 L
.90014 .08988 L
.90482 .09153 L
.90976 .09289 L
.91233 .09344 L
.91473 .09385 L
.91736 .09418 L
.91883 .09431 L
.91947 .09436 L
.92018 .0944 L
.92134 .09446 L
.92259 .09448 L
.92374 .09449 L
.92482 .09447 L
.92609 .09442 L
.92725 .09435 L
.92853 .09425 L
.92987 .09411 L
.93214 .09381 L
.93426 .09344 L
.93906 .09233 L
.94386 .09084 L
.94906 .08882 L
.95851 .08412 L
.97619 .07241 L
Mfstroke
1.5 Mabswid
[ 1 6 ] 0 Mabsdash
.02857 .05734 m
.0375 .16184 L
.04729 .25492 L
.0575 .32857 L
.06701 .37726 L
.07247 .39715 L
.07515 .40491 L
.07762 .41093 L
.07982 .4154 L
.08225 .41939 L
.08468 .42242 L
.08602 .42368 L
.08727 .42461 L
.08861 .42534 L
.08936 .42564 L
.09006 .42583 L
.09135 .42601 L
.09207 .42601 L
.09272 .42594 L
.09395 .42565 L
.09465 .42539 L
.09529 .4251 L
.09647 .42442 L
.09771 .4235 L
.10048 .42074 L
.10306 .41733 L
.10894 .40677 L
.11392 .39508 L
.11934 .37989 L
.12919 .34704 L
.14765 .27509 L
.16694 .20043 L
.17719 .16669 L
.18257 .15161 L
.18823 .13807 L
.19325 .12827 L
.19591 .12398 L
.19874 .12011 L
.20136 .1172 L
.20374 .11513 L
.20488 .11433 L
.20613 .1136 L
.20721 .11309 L
.20838 .11267 L
.20956 .11239 L
.21066 .11225 L
.21197 .11224 L
.21316 .11238 L
.21441 .11268 L
.21511 .11292 L
Mistroke
.21576 .11318 L
.21703 .11382 L
.21822 .11457 L
.22053 .11643 L
.22262 .11856 L
.2273 .12493 L
.23195 .13336 L
.23704 .14494 L
.24732 .17526 L
.26571 .24891 L
.30598 .4473 L
.32456 .52651 L
.33506 .5609 L
.34475 .58416 L
.34964 .59246 L
.35242 .5961 L
.35502 .5988 L
.35636 .59991 L
.35776 .60087 L
.35896 .60153 L
.36027 .60207 L
.36102 .6023 L
.36169 .60246 L
.36247 .60259 L
.3632 .60264 L
.36451 .6026 L
.36525 .6025 L
.36592 .60236 L
.36708 .602 L
.36832 .60146 L
.37056 .60007 L
.37323 .59774 L
.37566 .59497 L
.38095 .58688 L
.38596 .57667 L
.39555 .55067 L
.40574 .51475 L
.42406 .43419 L
.46159 .25156 L
.47095 .21254 L
.48082 .17777 L
.48598 .16267 L
.49164 .14885 L
.49678 .13892 L
.50156 .13202 L
.50417 .12925 L
.50658 .12731 L
.50783 .12654 L
.50922 .12588 L
.50991 .12563 L
Mistroke
.51066 .12541 L
.51137 .12526 L
.51202 .12517 L
.51327 .12511 L
.51444 .12522 L
.51572 .12549 L
.51643 .12572 L
.51708 .12597 L
.51827 .12655 L
.51956 .12735 L
.52189 .12923 L
.52413 .13156 L
.52658 .13471 L
.53152 .1429 L
.54038 .16345 L
.55054 .19551 L
.55981 .23144 L
.58062 .3281 L
.60123 .43056 L
.62029 .51481 L
.62984 .54878 L
.63879 .57396 L
.64329 .58385 L
.64814 .59232 L
.65076 .59591 L
.65352 .59895 L
.65587 .60091 L
.6572 .60177 L
.65845 .6024 L
.65972 .60287 L
.66036 .60305 L
.66106 .60319 L
.66231 .60332 L
.66348 .60329 L
.66418 .6032 L
.66485 .60307 L
.6661 .60269 L
.6668 .60241 L
.66745 .60211 L
.66893 .60125 L
.67144 .59926 L
.67372 .59689 L
.67882 .58967 L
.6834 .58097 L
.68835 .56933 L
.69732 .5427 L
.71721 .46281 L
.73819 .36052 L
.758 .26419 L
.77604 .19099 L
Mistroke
.78604 .16043 L
.79064 .14935 L
.7955 .13977 L
.79797 .1358 L
.8007 .13214 L
.8032 .12945 L
.80549 .12755 L
.80687 .12667 L
.80819 .12602 L
.80886 .12575 L
.80957 .12552 L
.81036 .12534 L
.81109 .12522 L
.81177 .12516 L
.8125 .12515 L
.8132 .1252 L
.81384 .12528 L
.81505 .12556 L
.81633 .12603 L
.81754 .12663 L
.81886 .12745 L
.82126 .12942 L
.8236 .13191 L
.82576 .13471 L
.83066 .1428 L
.83586 .15396 L
.84453 .17803 L
.8541 .21172 L
.89409 .3995 L
.91247 .48591 L
.92288 .52766 L
.93257 .55957 L
.94221 .58329 L
.94498 .5885 L
.9476 .59271 L
.94994 .59589 L
.95251 .59874 L
.95505 .6009 L
.95644 .60179 L
.95774 .60244 L
.95896 .60289 L
.96007 .60316 L
.96136 .60331 L
.96258 .6033 L
.96389 .60311 L
.96462 .60292 L
.96529 .6027 L
.96658 .60214 L
.9678 .60146 L
.97054 .59935 L
Mistroke
.9735 .5962 L
.97619 .59256 L
Mfstroke
[ 1 10 ] 0 Mabsdash
.02857 .01486 m
.06701 .0255 L
.07668 .02856 L
.08702 .03135 L
.09296 .03267 L
.09837 .03368 L
.10386 .0345 L
.10894 .03507 L
.11365 .03545 L
.11603 .03558 L
.11737 .03564 L
.11864 .03569 L
.1193 .03571 L
.12001 .03573 L
.12126 .03575 L
.12197 .03576 L
.12273 .03577 L
.12344 .03577 L
.12408 .03577 L
.12534 .03576 L
.12605 .03576 L
.12671 .03575 L
.12791 .03572 L
.12918 .03569 L
.13146 .0356 L
.1339 .03548 L
.1383 .03518 L
.14354 .0347 L
.14831 .03417 L
.1673 .03135 L
.18796 .02776 L
.20763 .02478 L
.21757 .02369 L
.22323 .02324 L
.22598 .02307 L
.22854 .02294 L
.2308 .02285 L
.23195 .02281 L
.23321 .02277 L
.23392 .02276 L
.23459 .02275 L
.23589 .02273 L
.23707 .02272 L
.23832 .02271 L
.23954 .02272 L
.24085 .02273 L
.24209 .02275 L
.24322 .02277 L
.24455 .02281 L
.24599 .02286 L
Mistroke
.24862 .02297 L
.25325 .02325 L
.25817 .02367 L
.26703 .02469 L
.27729 .02628 L
.28837 .02844 L
.30846 .03314 L
.32794 .03803 L
.33826 .04048 L
.34931 .04284 L
.35996 .04474 L
.36967 .04607 L
.37434 .04656 L
.37681 .04677 L
.37942 .04697 L
.3817 .04711 L
.38422 .04723 L
.38532 .04728 L
.3865 .04732 L
.38761 .04735 L
.38865 .04737 L
.3899 .04739 L
.39104 .04741 L
.39227 .04741 L
.39296 .04741 L
.3936 .04741 L
.39466 .0474 L
.39583 .04738 L
.39706 .04736 L
.3982 .04733 L
.40083 .04723 L
.40323 .04711 L
.40863 .04674 L
.41379 .04625 L
.41941 .04558 L
.42963 .044 L
.44929 .03997 L
.47018 .0349 L
.48975 .03027 L
.50771 .02679 L
.51707 .02545 L
.52178 .02492 L
.52694 .02446 L
.52961 .02428 L
.53213 .02413 L
.53352 .02407 L
.53504 .02401 L
.53629 .02397 L
.53768 .02393 L
.53898 .02391 L
Mistroke
.5402 .0239 L
.54149 .02389 L
.54222 .02389 L
.54288 .02389 L
.54406 .0239 L
.54534 .02392 L
.54656 .02395 L
.54768 .02398 L
.55032 .02407 L
.55274 .02419 L
.55821 .02458 L
.56303 .02503 L
.56812 .02563 L
.58663 .02872 L
.62444 .03759 L
.64549 .04239 L
.65546 .04426 L
.66468 .04566 L
.66921 .04621 L
.67421 .04671 L
.67924 .04709 L
.68199 .04724 L
.68322 .0473 L
.68457 .04735 L
.68569 .04739 L
.68688 .04742 L
.68814 .04745 L
.68931 .04746 L
.69047 .04747 L
.69158 .04748 L
.69257 .04747 L
.69364 .04746 L
.69482 .04745 L
.69611 .04742 L
.69746 .04738 L
.69873 .04734 L
.70099 .04724 L
.70341 .04711 L
.70865 .04672 L
.7135 .04624 L
.7245 .04475 L
.73419 .04304 L
.7445 .04089 L
.76443 .03614 L
.78595 .03095 L
.79608 .02878 L
.80677 .02682 L
.81589 .0255 L
.82106 .02492 L
.82589 .02449 L
Mistroke
.82831 .02431 L
.83089 .02416 L
.83223 .0241 L
.83371 .02403 L
.83508 .02399 L
.83632 .02395 L
.83758 .02392 L
.83878 .02391 L
.84004 .02389 L
.84075 .02389 L
.84142 .02389 L
.84263 .0239 L
.84373 .02391 L
.845 .02393 L
.84619 .02396 L
.84844 .02403 L
.85081 .02414 L
.85507 .0244 L
.85965 .02478 L
.86467 .02531 L
.87482 .02673 L
.88408 .02838 L
.90488 .03298 L
.92547 .03804 L
.94452 .04235 L
.95987 .04509 L
.96763 .04612 L
.97619 .04693 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.7619 .28521 m
.7619 .40426 L
.88095 .40426 L
.88095 .28521 L
F
1 g
.7381 .30902 m
.7381 .42806 L
.85714 .42806 L
.85714 .30902 L
F
0 g
.001 w
[ ] 0 setdash
.7381 .30902 m
.85714 .30902 L
.85714 .42806 L
.7381 .42806 L
.7381 .30902 L
s
% Start of sub-graphic
p
0.738095 0.309017 0.857143 0.428065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0271739 0.271739 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.048913 0.35119 0.320652 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
1.5 Mabswid
[ 1 10 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .18478 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x3) show
75.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.36413 0.35119 0.63587 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
1.5 Mabswid
[ 1 6 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .5 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x2) show
75.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.679348 0.35119 0.951087 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .81522 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x1) show
75.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[47]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00A@3oool2
000000@0oooo0P00000[0?ooo`D000000P3oool2000000@0oooo0P00000W0?ooo`D000000P3oool2
000000@0oooo0P00000X0?ooo`@000000`3oool2000000@0oooo0P00000/0?ooo`00A03oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000002`0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool09P3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`00000[0?ooo`00A`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02X0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000:`3oool004D0oooo0P0000030?ooo`040000003oool0oooo000002`0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`020?ooo`8000000`3oool010000000oooo0?ooo`00000Y
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo02T0oooo00150?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
;03oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`00000W0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000[0?ooo`00A@3oool3000000<0oooo0P00000/0?ooo`800000
103oool2000000@0oooo0P00000X0?ooo`800000103oool3000000<0oooo0P00000Y0?ooo`800000
103oool2000000@0oooo0P00000/0?ooo`00o`3ooolQ0?ooo`004`3oool00`000000oooo0?ooo`3a
0?ooo`8000005`3oool001<0oooo00<000000?ooo`3oool0lP3oool00`000000oooo0?ooo`0E0?oo
o`004`3oool00`000000oooo0?ooo`3V0?ooo`@0000000<0oooo0000000000000`0000030?ooo`04
0000003oool0oooo0?ooo`<00000403oool001<0oooo00<000000?ooo`3oool0i@3oool010000000
oooo0?ooo`0000020?ooo`@000000`3oool00`000000oooo000000050?ooo`030000003oool0oooo
00d0oooo000=0?ooonL000001`3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool00`00000@0?ooo`004`3oool00`000000oooo0?ooo`020?oo
o`8000000`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00D000000?oo
o`3oool0oooo000000070?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3o
ool3000000P0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`040000003o
ool0oooo000000L0oooo00@000000?ooo`00000000001`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0<0?ooo`<0
00000`3oool3000000050?ooo`00000000000000003oool00P0000000`3oool00000000000020000
00l0oooo000C0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02`3oool2000000D0
oooo0P0000030?ooo`800000:@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0
oooo1000000[0?ooo`8000004`3oool200000300oooo00<000000?ooo`3oool07`3oool001<0oooo
00<000000?ooo`3oool05P3oool2000000X0oooo0P0000040?ooo`030000003oool0oooo03d0oooo
0P0000020?ooo`8000004@3oool2000001l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0<0?ooo`800000903oool200000240oooo000C0?ooo`030000003oool0oooo00`0oooo0P00
00090?ooo`8000008`3oool2000001`0oooo00<000000?ooo`3oool0C@3oool2000000L0oooo0P00
001E0?ooo`004`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0:@3oool2000001L0oooo00<000000?ooo`3oool0:03oool2000001L0oooo00<00000
0?ooo`3oool04`3oool2000003d0oooo000C0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`8000003@3oool2000000D0oooo0P00000C0?oo
o`030000003oool0oooo01@0oooo0P00000?0?ooo`8000000`3oool2000006T0oooo000C0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0Q0?ooo`80
00007`3oool00`000000oooo0?ooo`0N0?ooo`8000000`3oool00`000000oooo0?ooo`0j0?ooo`80
0000<P3oool001<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo04l0oooo000C0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0I03o
ool2000004l0oooo000C0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo04`0oooo000C0?ooo`800000303oool00`00
0000oooo0?ooo`0U0?ooo`8000006`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
01T0oooo0P00001d0?ooo`004`3oool2000000/0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0M03oool001<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0<03oool001<0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`1`0?ooo`800000503oool2000003<0oooo000C0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0;`3oool200000140oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0?
0?ooo`800000<03oool200000140oooo00<000000?ooo`3oool0<`3oool001<0oooo00<000000?oo
o`3oool0103oool2000003@0oooo0P00000>0?ooo`030000003oool0oooo0340oooo0P00000=0?oo
o`800000@P3oool00`000000oooo0?ooo`0f0?ooo`004`3oool2000000<0oooo0P00000h0?ooo`03
0000003oool0000000H0oooo0P00000i0?ooo`8000002P3oool00`000000oooo0?ooo`0f0?ooo`<0
00001`3oool3000003P0oooo000C0?ooo`800000?`3oool010000000oooo0?ooo`3oool300000400
oooo1@00000n0?ooo`8000000`3oool2000003/0oooo000C0?ooo`800000o`3oool<0?ooo`004`3o
ool00`000000oooo0?ooo`3o0?ooo`/0oooo000C0?ooo`030000003oool0oooo0?l0oooo2`3oool0
01<0oooo00<000000?ooo`3oool0o`3oool;0?ooo`004`3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo0>80oooo000;0?ooo`D000000`3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0V`3oool000d0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0000000[0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0V`3o
ool000d0oooo00<000000?ooo`3oool00`3oool3000006/0oooo00D000000?ooo`3oool0oooo0000
00130?ooo`800000E@3oool000d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1`
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0F@3oool000d0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo05T0oooo000<0?ooo`80
00001@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0>D0oooo000C0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool0iP3oool001<0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo09l0oooo000C0?ooo`040000003oool0
oooo000002d0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool0D03oool001<0oooo00@000000?ooo`3oool00000LP3o
ool00`000000oooo0?ooo`2D0?ooo`004`3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0
oooo05`0oooo000C0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0G03oool001<0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3X0?ooo`004`3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0XP3oool001<0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0540oooo00<0
00000?ooo`3oool0CP3oool001<0oooo00@000000?ooo`3oool00000;`3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0CP3oool001<0oooo00@00000
0?ooo`3oool00000M03oool00`000000oooo0?ooo`2B0?ooo`004`3oool00`000000oooo0?ooo`3o
0?ooo`/0oooo000C0?ooo`030000003oool0oooo0?l0oooo2`3oool001<0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo05l0oooo000C0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1<0?ooo`004`3o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo04`0oooo000C0?ooo`050000003oool0
oooo0?ooo`000000M@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo04`0oooo000C
0?ooo`050000003oool0oooo0?ooo`000000o`3oool90?ooo`004`3oool00`000000oooo0?ooo`3o
0?ooo`/0oooo000C0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0j`3oool000/0
oooo100000040?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0R@3oool00`000000
oooo0?ooo`1P0?ooo`002`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0640oooo
000<0?ooo`030000003oool0oooo00@0oooo0P00000e0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo04/0oooo000=
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1c
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0BP3oool000/0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`/0oooo000<0?ooo`8000001@3oool00`00
0000oooo0?ooo`3o0?ooo`/0oooo000C0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool0R03oool00`000000oooo0?ooo`1R0?ooo`004`3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool0HP3oool001<0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0HP3o
ool001<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo04T0oooo000C0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo04T0oooo000C0?ooo`030000003oool0oooo0?l0
oooo2`3oool001<0oooo00<000000?ooo`3oool0o`3oool;0?ooo`004`3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo0>l0oooo000C0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo06<0oooo000C0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0B03oool001<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0@P3oool010000000oooo0?ooo`3ooolR000002@0oooo000C0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`160?ooob800000903oool001<0oooo
00<000000?ooo`3oool0a03ooolR000002@0oooo000C0?ooo`030000003oool0oooo0<@0oooo8P00
000T0?ooo`004`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0:/0oooo8P00000T
0?ooo`004`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`0O0?ooob800000903oool001<0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool0603ooolY000002@0oooo000C0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
7`3oool7000002@0oooo000C0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0M@3o
ool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01l0oooo1`00000T0?ooo`004`3oool0
0`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01l0oooo1`00000T0?ooo`00303oool20000
00D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo
01l0oooo1`00000T0?ooo`002`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00`0oooo0P0000000`3oool00000000000030?ooo`8000002@3oool7000002@0oooo000=0?ooo`03
0000003oool0oooo00<0oooo0P00001M0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool06@3oool010000000oooo00000000000<0?ooo`030000003oool0000000<0oooo00@000000?oo
o`3oool00000203oool7000002@0oooo000>0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0>@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo05h0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo1`00000T0?oo
o`002`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool0303oool2000000030?ooo`000000000000D0oooo00<000000?ooo`3oool01P3oool70000
02@0oooo000<0?ooo`8000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo07D0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo0000
00P0oooo1`00000T0?ooo`004`3oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01@0
oooo0P0000090?ooo`L00000903oool001<0oooo00<000000?ooo`3oool04P3oool200000:T0oooo
00<000000?ooo`3oool07`3oool7000002@0oooo000C0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0RP3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01l0oooo1`00
000T0?ooo`004`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01l0oooo1`00000T
0?ooo`004`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0H03oool00`000000oooo0?ooo`0O0?ooo`L00000903oool001<0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool07`3oool7000002@0oooo000C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
/P3oool00`000000oooo0?ooo`0<0?ooo`80000000<0oooo0000000000000P3oool4000000P0oooo
1`00000T0?ooo`004`3oool00`000000oooo0?ooo`2m0?ooo`040000003oool00000000000D0oooo
0P0000050?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool02@3oool7000002@0oooo
000C0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool7000002@0oooo000C
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo00`0oooo0P0000000`3oool00000000000040?ooo`030000003oool0
oooo00L0oooo1`00000T0?ooo`004`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01<0oooo00@000000?ooo`3oool00000203oool7000002@0oooo000C0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0D0?ooo`8000002@3oool70000
02@0oooo000C0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0L`3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo01l0oooo1`00000T0?ooo`004`3oool00`000000oooo
0?ooo`2m0?ooo`030000003oool0oooo01l0oooo1`00000T0?ooo`004`3oool00`000000oooo0?oo
o`2m0?ooo`030000003oool0oooo01l0oooo1`00000T0?ooo`004`3oool00`000000oooo0?ooo`2m
0?ooo`030000003oool0oooo01l0oooo1`00000T0?ooo`004`3oool00`000000oooo0?ooo`2M0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0303oool2000000030?ooo`0000000000
0080oooo1@0000070?ooo`L00000903oool001<0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool01`3oool7000002@0
oooo000C0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`000000100000030?ooo`<00000
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
:03oool001<0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo00`0oooo0P0000000`3oool00000000000040?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0:03oool000d0oooo0`0000030?ooo`030000003oool0oooo0;d0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02P0oooo000>0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0D0?oo
o`8000002@3oool00`000000oooo0?ooo`0X0?ooo`002`3oool5000000<0oooo0P00002n0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0:03oool000/0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0X0?ooo`00303oool00`000000oooo000000040?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo01l0oooo8`00000Z0?ooo`003@3oool2000000@0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`0o0?ooo`004`3oool00`000000oooo0?ooo`240?ooo`030000003oool0
oooo08<0oooo000C0?ooo`030000003oool0oooo0?l0oooo2`3oool001<0oooo00<000000?ooo`3o
ool0o`3oool;0?ooo`004`3oool00`000000oooo0?ooo`3o0?ooo`/0oooo000C0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1^0?ooo`004`3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo03d0oooo000C0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
03d0oooo000C0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0PP3oool001<0oooo
00<000000?ooo`3oool0o`3oool;0?ooo`004`3oool00`000000oooo0?ooo`3o0?ooo`/0oooo000C
0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0K`3oool001<0oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0700oooo000C0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1f0?ooo`03
0000003oool0oooo03/0oooo000C0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo03/0oooo000C0?ooo`030000003o
ool0oooo08L0oooo00<000000?ooo`3oool0P03oool001<0oooo00<000000?ooo`3oool0o`3oool;
0?ooo`004`3oool00`000000oooo0?ooo`3o0?ooo`/0oooo000C0?ooo`030000003oool0oooo09H0
oooo00<000000?ooo`3oool0L@3oool001<0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0LP3oool001<0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`0i0?ooo`00303oool2000000D0oooo00<00000
0?ooo`3oool0RP3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03T0oooo000;0?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool;0?ooo`003P3oool00`00
0000oooo0?ooo`020?ooo`800000o`3oool<0?ooo`00303oool2000000D0oooo00<000000?ooo`3o
ool0T`3oool00`000000oooo0?ooo`1d0?ooo`00303oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`110?ooo`800000
MP3oool000`0oooo0`0000040?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0=P3o
ool001<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo03D0oooo000C0?ooo`030000003oool0oooo0?l0oooo2`3oool001<0oooo00<000000?ooo`3o
ool0o`3oool;0?ooo`004`3oool00`000000oooo0?ooo`3o0?ooo`/0oooo000C0?ooo`030000003o
ool0oooo0?l0oooo2`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool007L0oooo0`0000180?ooo`800000803oool2000003X0oooo001h0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo03P0oooo000I0?ooo`<000000`3oool2000000@0oooo100000020?ooo`<0
000000<0oooo0000000000000P3oool200000080oooo0`0000070?ooo`80000000@0oooo00000000
000000000P3oool2000000@0oooo100000020?ooo`<000000P3oool3000000@0oooo00<000000?oo
o`3oool02@3oool3000000030?ooo`00000000000080oooo0P000000103oool00000000000000004
0?ooo`@000000P3oool2000000T0oooo1@0000090?ooo`030000003oool0oooo00P0oooo0`000003
0?ooo`8000000`3oool3000000/0oooo00<000000?ooo`3oool00P3oool2000000@0oooo0P000003
0?ooo`D00000203oool2000000@0oooo00<000000?ooo`3oool0>03oool001X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000002P3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0403oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`07
0?ooo`D000001`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool0>03oool001X0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0100000070?ooo`050000003oool000000?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo100000030?ooo`030000003oool0oooo0100
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080
oooo0`00000;0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0h0?oo
o`004@3oool4000000D0oooo00<000000?ooo`3oool00P3oool2000000@0oooo0`0000030?ooo`80
00000P3oool4000000@0oooo0P0000080?ooo`80000000<0oooo0000000000000`3oool2000000@0
oooo0`0000030?ooo`800000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0
oooo0P0000020?ooo`@000000P3oool400000080oooo0P000000103oool000000000003oool50000
00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00@0oooo0P0000030?ooo`@000002P3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`D000000`3oool00`000000oooo0?ooo`0h
0?ooo`004P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool05`3oool2000000030?ooo`000000000000/0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04`3oool01000
0000oooo0?ooo`00000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0h0?ooo`004P3oool00`000000oooo0?ooo`040?ooo`<000002P3oool2000000@0oooo00<00000
0?ooo`3oool04P3oool2000000040?ooo`0000000000000000T0oooo0P0000080?ooo`8000004P3o
ool00`000000oooo0?ooo`0P0?ooo`8000005P3oool3000001H0oooo0P0000030?ooo`8000002P3o
ool2000000l0oooo0P00000j0?ooo`004@3oool400000?l0oooo303oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.05261, -0.648943, \
0.00733523, 0.00733523}, {{7.125, 279.813}, {172.688, 4.1875}} -> {-17.4562, \
-0.618804, 0.915453, 0.0383944}, {{211.625, 245.688}, {88.4375, 54.375}} -> \
{-20.9754, -9.66137, 0.0986432, 0.108038}, {{213.438, 223.563}, {86.75, \
77.5}} -> {-22.1595, -31.8187, 0.103705, 0.335595}, {{213.438, 223.563}, {76, \
66.75}} -> {-22.1595, -35.4263, 0.103705, 0.335595}, {{213.438, 223.563}, \
{65.25, 56}} -> {-22.1595, -39.034, 0.103705, 0.335595}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[47]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[x1, x2, x3, icIodine, b1Iodine]\)], "Input",
  CellLabel->"In[48]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 2.- Single-impulsive input", "SubsubsectionIcon"],

Cell[TextData[{
  "One specific case is the acute or impulsive-injection input ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["x",
            FontWeight->"Bold",
            FontSlant->"Plain"], "0"], TraditionalForm]],
    TextAlignment->Left,
    TextJustification->0],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  " which is equivalent to making ",
  StyleBox["x",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\(\((0)\)\(\ \)\)\)]],
  "=  ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["x",
            FontWeight->"Bold",
            FontSlant->"Plain"], "0"], TraditionalForm]],
    TextAlignment->Left,
    TextJustification->0],
  " as initial condition with ",
  StyleBox["b",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\((t)\)\)]],
  " = 0 for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"t", "\[GreaterEqual]", 
          RowBox[{"0.", Cell[""]}]}], TraditionalForm]]],
  "In this case is applied the package function",
  Cell[BoxData[
      ButtonBox[
        RowBox[{" ", 
          ButtonBox[
            StyleBox["AcuteInput",
              FontColor->RGBColor[0, 0, 1],
              FontVariations->{"Underline"->True}],
            ButtonFunction:>(Internal`PutInformation[ #, LongForm -> False]&),
            
            
            ButtonData:>{"Info3227552928-2607283", 
              "Biokmod`SysModelLite`AcuteInput"},
            ButtonFrame->"None",
            ButtonNote->"Biokmod`SysModelLite`"]}],
        ButtonFunction:>(Internal`PutInformation[ #, LongForm -> False]&),
        ButtonData:>{"Info3227296827-4685341", 
          "Biomod`SysModelLite`AcuteInput"},
        ButtonFrame->"None",
        ButtonNote->"Biomod`SysModelLite`"]],
    CellMargins->{{20, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
    Background->GrayLevel[0.930022],
    ButtonBoxOptions->{Active->True}],
  "."
}], "Text"],

Cell["\<\
We illustrate this case using the iodine model by applying an unit \
impulsive-injection input into compartment 1.\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\ x1[t_], x2[t_], x3[t_]} = 
      Map[Last, \ AcuteInput[iodine, {1, \ 0, \ 0}, t, x]]\)], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \({1.0000324083305385`\ \[ExponentialE]\^\(\(-2.8585990234247185`\)\ t\) \
- 0.0008409950263963222`\ \[ExponentialE]\^\(\(-0.14677770424391592`\)\ t\) + 
        0.0008085866958576026`\ \[ExponentialE]\^\(\(-0.0929659650413442`\)\ \
t\), \(-0.30095502463584706`\)\ \[ExponentialE]\^\(\(-2.8585990234247185`\)\ \
t\) + 0.013587466792874536`\ \[ExponentialE]\^\(\(-0.14677770424391592`\)\ \
t\) + 0.2873675578429726`\ \[ExponentialE]\^\(\(-0.0929659650413442`\)\ t\), 
      0.0009605104624624938`\ \[ExponentialE]\^\(\(-2.8585990234247185`\)\ \
t\) - 0.04936505541865897`\ \[ExponentialE]\^\(\(-0.14677770424391592`\)\ t\) \
+ 0.04840454495619647`\ \[ExponentialE]\^\(\(-0.0929659650413442`\)\ t\)}\)], \
"Output",
  CellLabel->"Out[49]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LogPlot[{\ x1[t], x2[t], x3[t]}, \ {t, \ 1, \ 30}, \[IndentingNewLine]\ 
      PlotStyle \[Rule] {\[IndentingNewLine]{AbsoluteThickness[0.5], \ 
            AbsoluteDashing[{4, 4}]}, {AbsoluteThickness[1.5], \ 
            AbsoluteDashing[{1, 6}]}, {AbsoluteThickness[1.5], \ 
            AbsoluteDashing[{1, 10}]}}, \ 
      AxesLabel \[Rule] {"\<days\>", \ "\<r\>"}, \[IndentingNewLine]PlotLabel \
\[Rule] "\<Iodine Model: impulsive-injection in 1\>"]; \)], "Input",
  CellLabel->"In[50]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.603319 0.133645 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -3 -9 ]
[.18254 -0.0125 3 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6.25 ]
[1.025 0 28 6.25 ]
[-0.0125 .06874 -40 -6.25 ]
[-0.0125 .06874 0 6.25 ]
[-0.0125 .20238 -34 -6.25 ]
[-0.0125 .20238 0 6.25 ]
[-0.0125 .33603 -28 -6.25 ]
[-0.0125 .33603 0 6.25 ]
[-0.0125 .46967 -22 -6.25 ]
[-0.0125 .46967 0 6.25 ]
[-0.0125 .60332 -10 -6.25 ]
[-0.0125 .60332 0 6.25 ]
[0 .64303 -5 0 ]
[0 .64303 5 12.5 ]
[.5 .63053 -116.094 0 ]
[.5 .63053 116.094 12.5 ]
[ -0.0005 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(10)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(25)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(30)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .06874 m
.00625 .06874 L
s
gsave
-0.0125 .06874 -101 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0001) show
99.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .20238 m
.00625 .20238 L
s
gsave
-0.0125 .20238 -95 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
93.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .33603 m
.00625 .33603 L
s
gsave
-0.0125 .33603 -89 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .46967 m
.00625 .46967 L
s
gsave
-0.0125 .46967 -83 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -71 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .01556 m
.00375 .01556 L
s
0 .02851 m
.00375 .02851 L
s
0 .03909 m
.00375 .03909 L
s
0 .04804 m
.00375 .04804 L
s
0 .05579 m
.00375 .05579 L
s
0 .06262 m
.00375 .06262 L
s
0 .10897 m
.00375 .10897 L
s
0 .1325 m
.00375 .1325 L
s
0 .1492 m
.00375 .1492 L
s
0 .16215 m
.00375 .16215 L
s
0 .17274 m
.00375 .17274 L
s
0 .18168 m
.00375 .18168 L
s
0 .18943 m
.00375 .18943 L
s
0 .19627 m
.00375 .19627 L
s
0 .24262 m
.00375 .24262 L
s
0 .26615 m
.00375 .26615 L
s
0 .28285 m
.00375 .28285 L
s
0 .2958 m
.00375 .2958 L
s
0 .30638 m
.00375 .30638 L
s
0 .31533 m
.00375 .31533 L
s
0 .32308 m
.00375 .32308 L
s
0 .32991 m
.00375 .32991 L
s
0 .37626 m
.00375 .37626 L
s
0 .39979 m
.00375 .39979 L
s
0 .41649 m
.00375 .41649 L
s
0 .42944 m
.00375 .42944 L
s
0 .44003 m
.00375 .44003 L
s
0 .44897 m
.00375 .44897 L
s
0 .45672 m
.00375 .45672 L
s
0 .46356 m
.00375 .46356 L
s
0 .50991 m
.00375 .50991 L
s
0 .53344 m
.00375 .53344 L
s
0 .55014 m
.00375 .55014 L
s
0 .56309 m
.00375 .56309 L
s
0 .57367 m
.00375 .57367 L
s
0 .58262 m
.00375 .58262 L
s
0 .59037 m
.00375 .59037 L
s
0 .5972 m
.00375 .5972 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -177.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Iodine) show
105.188 12.750 moveto
(Model) show
135.188 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
147.188 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(impulsive) show
201.188 12.750 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
207.188 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(injection) show
267.188 12.750 moveto
(in) show
285.188 12.750 moveto
(1) show
291.188 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.05556 .43741 m
.0929 .24364 L
.11234 .1507 L
.11767 .1291 L
.12336 .10932 L
.12874 .09445 L
.13363 .08432 L
.13601 .08051 L
.13854 .07719 L
.14072 .07487 L
.14306 .07288 L
.14558 .07125 L
.14793 .07012 L
.14937 .06959 L
.15073 .06919 L
.15196 .06891 L
.1533 .06867 L
.15456 .06851 L
.15574 .06841 L
.15681 .06835 L
.15796 .06832 L
.15922 .06832 L
.15986 .06834 L
.16055 .06836 L
.16179 .06843 L
.16294 .06852 L
.1652 .06874 L
.16726 .06899 L
.17189 .06967 L
.19189 .07316 L
.2104 .076 L
.22837 .07814 L
.23755 .07901 L
.24746 .07981 L
.25727 .08046 L
.26628 .08095 L
.27482 .08132 L
.28395 .08163 L
.28891 .08176 L
.29342 .08186 L
.29801 .08194 L
.30224 .082 L
.30459 .08202 L
.30718 .08204 L
.30978 .08206 L
.3112 .08207 L
.31253 .08207 L
.31379 .08208 L
.31498 .08208 L
.31605 .08208 L
Mistroke
.31722 .08208 L
.31848 .08208 L
.31919 .08208 L
.31983 .08207 L
.32108 .08207 L
.32225 .08207 L
.32459 .08205 L
.32677 .08204 L
.33171 .08199 L
.33654 .08193 L
.3417 .08184 L
.35105 .08164 L
.35957 .08142 L
.37805 .08078 L
.39813 .0799 L
.43761 .07763 L
.47562 .0749 L
.51216 .07187 L
.55107 .06826 L
.58852 .06448 L
.62834 .06018 L
.66669 .0558 L
.70358 .05139 L
.74284 .04652 L
.78064 .04167 L
.8208 .03637 L
.8595 .03114 L
.89673 .02599 L
.93634 .02042 L
.97448 .01496 L
.97619 .01472 L
Mfstroke
1.5 Mabswid
[ 1 6 ] 0 Mabsdash
.05556 .52431 m
.05669 .52448 L
.05773 .5246 L
.05892 .52471 L
.06005 .52478 L
.06109 .52482 L
.06205 .52484 L
.06311 .52485 L
.06423 .52483 L
.06536 .5248 L
.06657 .52475 L
.06771 .52469 L
.06876 .52462 L
.07374 .52417 L
.07843 .5236 L
.08356 .52289 L
.0929 .52145 L
.13363 .51451 L
.17292 .50769 L
.21075 .50113 L
.25095 .49417 L
.28968 .48748 L
.32694 .48104 L
.36658 .4742 L
.40475 .46761 L
.44146 .46129 L
.48053 .45456 L
.51814 .4481 L
.55813 .44122 L
.59664 .43461 L
.6337 .42825 L
.67312 .42148 L
.71108 .41498 L
.74757 .40872 L
.78643 .40207 L
.82383 .39567 L
.8636 .38886 L
.9019 .38231 L
.93874 .37601 L
.97619 .36961 L
s
[ 1 10 ] 0 Mabsdash
.05556 .22731 m
.06423 .24478 L
.07374 .25877 L
.08366 .26981 L
.0929 .27791 L
.11258 .29067 L
.1236 .29601 L
.13363 .30008 L
.15214 .30607 L
.17223 .31092 L
.19141 .31437 L
.21174 .31707 L
.23062 .31888 L
.24831 .32009 L
.25834 .32059 L
.26788 .32097 L
.27644 .32122 L
.28129 .32133 L
.28579 .32141 L
.2907 .32148 L
.29346 .3215 L
.29601 .32153 L
.29824 .32154 L
.2995 .32155 L
.30068 .32155 L
.30193 .32155 L
.30307 .32156 L
.3037 .32156 L
.30438 .32156 L
.30563 .32156 L
.30674 .32156 L
.30778 .32155 L
.30893 .32155 L
.31016 .32155 L
.31267 .32153 L
.31497 .32152 L
.31918 .32148 L
.32362 .32142 L
.33284 .32127 L
.3427 .32104 L
.36045 .32049 L
.38109 .31963 L
.40057 .31864 L
.43775 .31632 L
.47731 .31332 L
.5154 .31001 L
.55202 .30651 L
.59102 .30247 L
.62855 .29833 L
.66845 .2937 L
Mistroke
.70688 .28904 L
.74385 .2844 L
.78319 .2793 L
.82107 .27426 L
.86132 .26877 L
.9001 .26338 L
.93741 .2581 L
.97619 .25252 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[50]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00;P3oool200000200oooo0P00
000K0?ooo`D000000P3oool2000001T0oooo1@0000020?ooo`800000603oool4000000<0oooo0P00
000I0?ooo`@000000`3oool2000001T0oooo0P0000040?ooo`800000903oool002d0oooo00@00000
0?ooo`3oool000007P3oool010000000oooo0?ooo`00000L0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0H0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000603oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo000001L0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000S0?ooo`00;@3oool010000000oooo0?ooo`00000Q0?ooo`03
0000003oool0oooo01X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000006@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01L0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0240oooo000]
0?ooo`040000003oool0oooo000001l0oooo0P00000M0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo0P00000J0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080
oooo0P00000K0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool08@3oool002d0
oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`0L0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool05`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000001P0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000008`3oool002h0oooo0P00000P0?ooo`<000006`3oool20000
00@0oooo0P00000J0?ooo`800000103oool3000001P0oooo0P0000040?ooo`8000006P3oool20000
00@0oooo0`00000H0?ooo`800000103oool2000002@0oooo003o0?ooob40oooo003o0?oooa<0oooo
0P00000<0?ooo`00o`3ooolD0?ooo`030000003oool0oooo00X0oooo003o0?ooo`P0oooo10000000
0`3oool0000000000003000000<0oooo00@000000?ooo`3oool0oooo0`0000050?ooo`00o`3oool7
0?ooo`040000003oool0oooo00000080oooo100000030?ooo`030000003oool0000000D0oooo00<0
00000?ooo`3oool00P3oool002X0ooooe00000080?ooo`040000003oool0oooo000000D0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`03000000D0oooo000Z0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0303oool3000000<0oooo0`0000001@3oool000000000
00000000oooo0080000000<0oooo0000000000000P0000040?ooo`00:P3oool00`000000oooo0?oo
o`3L0?ooo`030000003oool0oooo01@0oooo000Z0?ooo`800000c03oool00`000000oooo0?ooo`0=
0?ooo`8000005P3oool002X0oooo00<000000?ooo`3oool0``3oool5000002/0oooo000Z0?ooo`03
0000003oool0oooo0;/0oooo1@00000c0?ooo`00:P3oool200000;@0oooo1@00000k0?ooo`00:P3o
ool00`000000oooo0?ooo`2[0?ooo`D00000@`3oool002X0oooo0P00002T0?ooo`D00000B`3oool0
02X0oooo00<000000?ooo`3oool0V`3oool5000005<0oooo000Z0?ooo`800000U03oool5000005/0
oooo000Z0?ooo`030000003oool0oooo08/0oooo1@00001S0?ooo`00:P3oool2000008@0oooo1@00
001[0?ooo`00103oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P000003
0?ooo`D00000103oool2000007`0oooo1@00001c0?ooo`000`3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00@0oooo0P00000P0?ooo`<00000C03oool2000000<0
oooo1@00001k0?ooo`000`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`040?ooo`8000000`3o
ool2000003X0oooo1@0000030?ooo`<00000Q@3oool000<0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01X0oooo0P00000=0?oo
o`<000000`3oool00`000000oooo0?ooo`0Q0?ooo`D000000`3oool5000009<0oooo00030?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo01<0oooo100000030?ooo`D000000`3oool200000080oooo
1@0000030?ooo`D00000X`3oool000@0oooo0P00000:0?ooo`800000103oool2000000@0oooo0P00
00040?ooo`8000001P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0=L0oooo000Z
0?ooo`030000003oool0oooo0?<0oooo000Z0?ooo`030000003oool0oooo0?<0oooo000Z0?ooo`03
0000003oool0oooo0?<0oooo000Z0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
f@3oool002X0oooo0P00000H0?ooo`030000003oool0oooo0=T0oooo000Z0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0f@3oool002X0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`3J0?ooo`00:P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0=X0
oooo000Z0?ooo`030000003oool0oooo0?<0oooo000Z0?ooo`800000m03oool002X0oooo00<00000
0?ooo`3oool0l`3oool002X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3K0?oo
o`00:P3oool2000001H0oooo00<000000?ooo`3oool0f`3oool002X0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`3K0?ooo`00:P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo0=`0oooo000Z0?ooo`8000005@3oool00`000000oooo0?ooo`3L0?ooo`00:P3oool00`00
0000oooo0?ooo`3c0?ooo`00:P3oool200000?@0oooo000Z0?ooo`030000003oool0oooo0?<0oooo
000Z0?ooo`8000005@3oool00`000000oooo0?ooo`3L0?ooo`00:P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo0=`0oooo000Z0?ooo`800000503oool00`000000oooo0?ooo`3M0?oo
o`002P3oool2000000@0oooo0P0000040?ooo`800000103oool2000000<0oooo1@0000040?ooo`80
0000503oool00`000000oooo0?ooo`3M0?ooo`002@3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`04
0?ooo`800000503oool00`000000oooo0?ooo`3M0?ooo`002@3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0?<0oooo00090?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0l`3oool000T0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0=h0oooo000:0?ooo`8000002P3oool2
000000@0oooo0P0000040?ooo`8000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo0=h0oooo000Z0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0g`3oool002X0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3O0?ooo`00:P3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0=l0oooo000Z0?ooo`030000003oool0oooo0?<0oooo000Z
0?ooo`800000m03oool002X0oooo00<000000?ooo`3oool0l`3oool002X0oooo00<000000?ooo`3o
ool0303oool01@000000oooo0?ooo`3oool000000>80oooo000Z0?ooo`030000003oool0oooo00`0
oooo00D000000?ooo`3oool0oooo0000002f0?ooo`800000:P3oool002X0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`2Y0?ooo`800000=@3oool002X0oooo0P00000A0?ooo`030000
003oool0oooo0>00oooo000Z0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0WP3o
ool200000400oooo000Z0?ooo`030000003oool0oooo0:H0oooo0P00001;0?ooo`00:P3oool20000
0?@0oooo000Z0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0Q03oool2000005H0
oooo000Z0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`1h0?ooo`800000H@3oool002X0oooo0P00000@0?ooo`030000003oool0oooo0>40oooo000Z
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0L03oool200000700oooo000Z0?oo
o`8000003`3oool00`000000oooo0?ooo`1U0?ooo`800000N`3oool002X0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0=0?ooo`800000B`3oool2000008H0oooo000Z0?ooo`800000
:`3oool00`000000oooo0?ooo`0c0?ooo`800000T@3oool002X0oooo00<000000?ooo`3oool0:@3o
ool2000000T0oooo0P00000D0?ooo`8000002@3oool2000009`0oooo000Z0?ooo`800000@03oool2
00000;80oooo000@0?ooo`800000103oool2000000@0oooo0P0000030?ooo`D00000103oool20000
00h0oooo00<000000?ooo`3oool0h`3oool000l0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`3S0?ooo`003`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0103oool2000000h0oooo00<000000?ooo`3oool0h`3o
ool000l0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3S0?ooo`003`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0><0oooo000@0?ooo`800000
2P3oool2000000@0oooo0P0000060?ooo`030000003oool0oooo0?<0oooo000Z0?ooo`030000003o
ool0oooo0?<0oooo000Z0?ooo`030000003oool0oooo0?<0oooo000Z0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0i03oool002X0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`2k0?ooo`8000009`3oool002X0oooo0P00000<0?ooo`030000003oool0oooo0;D0oooo
0P00000^0?ooo`00:P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0:h0oooo0P00
000e0?ooo`00:P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0:P0oooo00<00000
0?ooo`3oool0>P3oool002X0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0k0?oo
o`00:P3oool00`000000oooo0?ooo`2^0?ooo`800000@`3oool002X0oooo0P00002Y0?ooo`800000
B@3oool002X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2D0?ooo`800000D03o
ool002X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2=0?ooo`800000E`3oool0
02X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`270?ooo`800000GP3oool002X0
oooo0P00000:0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0H`3oool002X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo06@0oooo
000Z0?ooo`800000QP3oool2000006`0oooo000Z0?ooo`030000003oool0oooo07h0oooo0P00001c
0?ooo`00:P3oool00`000000oooo0?ooo`1g0?ooo`800000NP3oool002X0oooo0P00001a0?ooo`80
0000P@3oool002X0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`260?ooo`00:P3o
ool2000006X0oooo00<000000?ooo`3oool0Q`3oool002X0oooo0P00001T0?ooo`800000SP3oool0
01H0oooo0P0000040?ooo`8000000`3oool5000000@0oooo00<000000?ooo`3oool0G03oool20000
09D0oooo000E0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool20000
05H0oooo0P00002L0?ooo`005@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
00@0oooo0P00001?0?ooo`800000X`3oool001D0oooo00@000000?ooo`3oool000002P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo04L0oooo0P00002Z0?ooo`005@3oool010000000
oooo0?ooo`00000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0l`3oool001H0
oooo0P00000:0?ooo`8000001P3oool00`000000oooo0?ooo`100?ooo`800000/@3oool002X0oooo
00<000000?ooo`3oool0>@3oool200000;P0oooo000Z0?ooo`030000003oool0oooo0380oooo0P00
002o0?ooo`00:P3oool00`000000oooo0?ooo`0[0?ooo`800000aP3oool002X0oooo00<000000?oo
o`3oool0903oool200000<d0oooo000Z0?ooo`800000803oool00`000000oooo0?ooo`3A0?ooo`00
:P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0=80oooo000Z0?ooo`030000003o
ool0oooo01L0oooo0P00003J0?ooo`00:P3oool00`000000oooo0?ooo`090?ooo`8000001@3oool2
00000>40oooo000Z0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0iP3oool002X0
oooo0P00003d0?ooo`00:P3oool00`000000oooo0?ooo`3c0?ooo`00:P3oool00`000000oooo0?oo
o`3c0?ooo`00:P3oool00`000000oooo0?ooo`3c0?ooo`00:P3oool200000?@0oooo000Z0?ooo`03
0000003oool0oooo0?<0oooo000Z0?ooo`030000003oool0oooo0?<0oooo000Z0?ooo`800000m03o
ool002X0oooo00<000000?ooo`3oool0l`3oool002X0oooo0P00003d0?ooo`00:P3oool00`000000
oooo0?ooo`3c0?ooo`00:P3oool200000?@0oooo000Z0?ooo`800000m03oool002X0oooo00<00000
0?ooo`3oool0l`3oool00240oooo1@0000040?ooo`800000m03oool002<0oooo00<000000?ooo`3o
ool0103oool200000?@0oooo000S0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
l`3oool002<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3c0?ooo`008`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0?<0oooo000R0?ooo`800000o03oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00880oooo0`00000j0?oo
o`@00000G@3oool008<0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1K0?ooo`00
903oool3000000<0oooo0P0000040?ooo`@000000P3oool3000000030?ooo`00000000000080oooo
0P0000020?ooo`<000001`3oool2000000040?ooo`000000000000000080oooo0P0000040?ooo`@0
00000P3oool300000080oooo0`0000040?ooo`030000003oool0oooo00T0oooo0`000000203oool0
00000000003oool000000?ooo`000000oooo0`0000040?ooo`@0000000@0oooo0000000000000000
0`3oool3000000@0oooo0`0000030?ooo`800000103oool3000000T0oooo0`0000000`3oool00000
000000020?ooo`800000103oool010000000oooo0?ooo`3oool3000000<0oooo0`0000030?ooo`80
0000103oool3000000<0oooo0P0000020?ooo`8000000P3oool2000000P0oooo0`0000000`3oool0
0000000000020?ooo`8000001`3oool5000001X0oooo000U0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000X0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0100oooo00/000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`040000003oool0oooo00000080oooo00D000000?oo
o`3oool0oooo000000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2
000000<0oooo00<000000?ooo`3oool00`3oool4000000@0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0J0?ooo`009@3oool0
0`000000oooo0?ooo`0500000080oooo00@000000?ooo`3oool00000103oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0100000070?ooo`050000003oool000000?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo10000003
0?ooo`030000003oool0oooo0100oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`<000001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
1000000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0J0?ooo`009@3oool010000000oooo0?ooo`3oool3000000@0oooo0`00
00030?ooo`8000000P3oool4000000@0oooo0P0000080?ooo`80000000<0oooo0000000000000`3o
ool2000000@0oooo0`0000030?ooo`800000103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00T0oooo0P0000020?ooo`<0000000<0oooo0000003oool0100000020?ooo`80000000<0
oooo0000000000000`3oool00`000000oooo0?ooo`020?ooo`@000000`3oool200000080oooo0P00
00020?ooo`8000000P3oool2000000X0oooo0P0000020?ooo`@000000`3oool4000000<0oooo0P00
00040?ooo`<0000000<0oooo0000000000000`0000030?ooo`800000103oool200000080oooo1000
000:0?ooo`8000000P3oool4000000/0oooo00<000000?ooo`3oool06P3oool002D0oooo00D00000
0?ooo`3oool0oooo000000080?ooo`030000003oool0oooo01L0oooo0P0000000`3oool000000000
000;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool06P3oool002@0oooo0`000000
0`3oool0000000000002000000D0oooo0P0000040?ooo`030000003oool0oooo0180oooo0P000000
103oool000000000000000090?ooo`800000203oool200000180oooo00<000000?ooo`3oool04`3o
ool2000000`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0>0?ooo`800000703o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-7.11316, -5.2294, 0.149231, \
0.0354483}}]
}, Open  ]],

Cell[BoxData[
    \(Clear[x1, x2, x3]\)], "Input",
  CellLabel->"In[51]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 3.- Constant input 1", "SubsubsectionIcon"],

Cell[TextData[{
  "Here is supposed a constant input. This input form is illustrated for the \
iodine model with an example that consists of a unit-input at ",
  StyleBox["t ",
    FontSlant->"Italic"],
  "= 0 with a constant input of 0.1 into compartment 1. Your realize that a \
unit-input in compartment 1 is equivalent take as initial conditions: {1, 0, \
0}"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\ x1[t_], x2[t_], x3[t_]} = 
      Map[Last, 
        SystemDSolve[iodine, {1, \ 0, \ 0}, {0.1, \ 0, \ 0}, t, t, \ 
          x]]\)], "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    \({\(\(0.035280099212137914`\)\(\[InvisibleSpace]\)\) + 
        0.9650491035670583`\ \[ExponentialE]\^\(\(-2.8585990234247185`\)\ t\) \
- 0.0002680231089457314`\ \[ExponentialE]\^\(\(-0.14677770424391592`\)\ t\) - 
        0.00006117967025068738`\ \[ExponentialE]\^\(\(-0.0929659650413442`\)\ \
t\), \(\(0.3078396117435149`\)\(\[InvisibleSpace]\)\) - 
        0.29042696448576377`\ \[ExponentialE]\^\(\(-2.8585990234247185`\)\ \
t\) + 0.00433029325765231`\ \[ExponentialE]\^\(\(-0.14677770424391592`\)\ t\) \
- 0.02174294051540332`\ \[ExponentialE]\^\(\(-0.0929659650413442`\)\ t\), \
\(\(0.018468023341826005`\)\(\[InvisibleSpace]\)\) + 
        0.0009269097211695872`\ \[ExponentialE]\^\(\(-2.8585990234247185`\)\ \
t\) - 0.01573252541490317`\ \[ExponentialE]\^\(\(-0.14677770424391592`\)\ t\) \
- 0.0036624076480924264`\ \[ExponentialE]\^\(\(-0.0929659650413442`\)\ \
t\)}\)], "Output",
  CellLabel->"Out[52]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{\ x1[t], x2[t], x3[t]}, \ {t, \ 1, \ 30}, \[IndentingNewLine]\ 
      PlotStyle \[Rule] {\[IndentingNewLine]{AbsoluteThickness[0.5], \ 
            AbsoluteDashing[{4, 4}]}, {AbsoluteThickness[1.5], \ 
            AbsoluteDashing[{1, 6}]}, {AbsoluteThickness[1.5], \ 
            AbsoluteDashing[{1, 10}]}}, \ 
      AxesLabel \[Rule] {"\<days\>", \ "\<r\>"}, \[IndentingNewLine]PlotLabel \
\[Rule] "\<Iodine Model: Constantinput in 1\>"]; \)], "Input",
  CellLabel->"In[53]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0147151 1.92005 [
[.18254 .00222 -3 -9 ]
[.18254 .00222 3 0 ]
[.34127 .00222 -6 -9 ]
[.34127 .00222 6 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.65873 .00222 -6 -9 ]
[.65873 .00222 6 0 ]
[.81746 .00222 -6 -9 ]
[.81746 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[1.025 .01472 0 -6.25 ]
[1.025 .01472 28 6.25 ]
[.01131 .11072 -24 -4.5 ]
[.01131 .11072 0 4.5 ]
[.01131 .20672 -18 -4.5 ]
[.01131 .20672 0 4.5 ]
[.01131 .30272 -24 -4.5 ]
[.01131 .30272 0 4.5 ]
[.01131 .39873 -18 -4.5 ]
[.01131 .39873 0 4.5 ]
[.01131 .49473 -24 -4.5 ]
[.01131 .49473 0 4.5 ]
[.01131 .59073 -18 -4.5 ]
[.01131 .59073 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12.5 ]
[.5 .63053 -98.0938 0 ]
[.5 .63053 98.0938 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(10)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(15)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(20)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(25)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(30)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .11072 m
.03006 .11072 L
s
[(0.05)] .01131 .11072 1 0 Mshowa
.02381 .20672 m
.03006 .20672 L
s
[(0.1)] .01131 .20672 1 0 Mshowa
.02381 .30272 m
.03006 .30272 L
s
[(0.15)] .01131 .30272 1 0 Mshowa
.02381 .39873 m
.03006 .39873 L
s
[(0.2)] .01131 .39873 1 0 Mshowa
.02381 .49473 m
.03006 .49473 L
s
[(0.25)] .01131 .49473 1 0 Mshowa
.02381 .59073 m
.03006 .59073 L
s
[(0.3)] .01131 .59073 1 0 Mshowa
.125 Mabswid
.02381 .03392 m
.02756 .03392 L
s
.02381 .05312 m
.02756 .05312 L
s
.02381 .07232 m
.02756 .07232 L
s
.02381 .09152 m
.02756 .09152 L
s
.02381 .12992 m
.02756 .12992 L
s
.02381 .14912 m
.02756 .14912 L
s
.02381 .16832 m
.02756 .16832 L
s
.02381 .18752 m
.02756 .18752 L
s
.02381 .22592 m
.02756 .22592 L
s
.02381 .24512 m
.02756 .24512 L
s
.02381 .26432 m
.02756 .26432 L
s
.02381 .28352 m
.02756 .28352 L
s
.02381 .32192 m
.02756 .32192 L
s
.02381 .34112 m
.02756 .34112 L
s
.02381 .36032 m
.02756 .36032 L
s
.02381 .37953 m
.02756 .37953 L
s
.02381 .41793 m
.02756 .41793 L
s
.02381 .43713 m
.02756 .43713 L
s
.02381 .45633 m
.02756 .45633 L
s
.02381 .47553 m
.02756 .47553 L
s
.02381 .51393 m
.02756 .51393 L
s
.02381 .53313 m
.02756 .53313 L
s
.02381 .55233 m
.02756 .55233 L
s
.02381 .57153 m
.02756 .57153 L
s
.02381 .60993 m
.02756 .60993 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -159.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Iodine) show
105.188 12.750 moveto
(Model) show
135.188 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
147.188 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Constantinput) show
231.188 12.750 moveto
(in) show
249.188 12.750 moveto
(1) show
255.188 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.05556 .18817 m
.05773 .16931 L
.06005 .15283 L
.06423 .13057 L
.06679 .12057 L
.06921 .11301 L
.07374 .10262 L
.07606 .09873 L
.07852 .0954 L
.08293 .091 L
.08538 .08922 L
.08767 .08787 L
.09039 .0866 L
.0929 .08567 L
.09541 .08493 L
.09816 .08429 L
.10078 .08381 L
.10315 .08347 L
.10769 .08299 L
.11018 .0828 L
.11253 .08265 L
.11509 .08253 L
.11781 .08242 L
.12012 .08235 L
.12267 .08229 L
.1254 .08224 L
.12834 .0822 L
.13111 .08217 L
.13363 .08215 L
.13584 .08214 L
.13828 .08213 L
.14083 .08212 L
.14199 .08212 L
.14322 .08212 L
.14428 .08211 L
.14544 .08211 L
.14651 .08211 L
.14748 .08211 L
.14863 .08211 L
.14987 .08211 L
.15101 .08211 L
.15208 .08211 L
.15324 .08211 L
.15452 .08211 L
.15516 .08211 L
.15585 .08211 L
.15709 .08211 L
.15951 .08211 L
.16171 .08211 L
.17215 .08212 L
Mistroke
.21059 .08217 L
.24756 .08221 L
.2869 .08225 L
.32477 .08228 L
.36502 .08231 L
.4038 .08233 L
.44112 .08235 L
.4808 .08236 L
.51903 .08238 L
.55578 .08239 L
.59491 .0824 L
.63257 .0824 L
.6726 .08241 L
.71117 .08242 L
.74827 .08242 L
.78775 .08243 L
.82576 .08243 L
.8623 .08243 L
.90121 .08244 L
.93866 .08244 L
.97619 .08244 L
Mfstroke
1.5 Mabswid
[ 1 6 ] 0 Mabsdash
.05556 .54294 m
.05773 .54879 L
.06005 .55393 L
.06423 .56095 L
.06679 .56416 L
.06921 .56662 L
.07374 .57009 L
.07606 .57144 L
.07852 .57263 L
.08293 .57428 L
.08767 .57557 L
.0929 .57662 L
.09819 .57741 L
.10303 .578 L
.11393 .57903 L
.13363 .58049 L
.17202 .58292 L
.20894 .58504 L
.24823 .58709 L
.28605 .58889 L
.32625 .59062 L
.36498 .59213 L
.40225 .59345 L
.44188 .59471 L
.48005 .59582 L
.51676 .59678 L
.55584 .5977 L
.59345 .59851 L
.63343 .59928 L
.67195 .59994 L
.709 .60052 L
.74842 .60107 L
.78638 .60155 L
.82287 .60197 L
.86174 .60237 L
.89913 .60271 L
.9389 .60304 L
.97619 .60332 L
s
[ 1 10 ] 0 Mabsdash
.05556 .01779 m
.0929 .02249 L
.13363 .0269 L
.17189 .03038 L
.20867 .03323 L
.24783 .0358 L
.28553 .0379 L
.32559 .03978 L
.36419 .04132 L
.40132 .04257 L
.44083 .04371 L
.47887 .04464 L
.51544 .0454 L
.55438 .04609 L
.59186 .04666 L
.63171 .04717 L
.6701 .04759 L
.70702 .04794 L
.74631 .04826 L
.78413 .04852 L
.82433 .04875 L
.86306 .04895 L
.90033 .04911 L
.93996 .04926 L
.97619 .04937 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[53]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00?P3oool2000001l0oooo1@00
00020?ooo`800000703oool500000080oooo0P00000L0?ooo`@000000`3oool2000001/0oooo1000
00030?ooo`8000007@3oool2000000@0oooo0P00000U0?ooo`00?@3oool010000000oooo0?ooo`00
000P0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0K0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
000001/0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000T0?ooo`00@03o
ool00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000001/0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0K0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0R0?oo
o`00?P3oool200000240oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool00P3oool2000001h0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3oool2000001l0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0R0?ooo`00?P3oool00`000000oooo0?ooo`0P
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool06`3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000001X0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0K0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000903oool003h0oooo0`00000O
0?ooo`800000103oool2000001d0oooo0P0000040?ooo`<00000703oool2000000@0oooo0P00000L
0?ooo`800000103oool3000001`0oooo0P0000040?ooo`8000009@3oool00?l0oooo8@3oool001X0
oooo00<000000?ooo`3oool0m@3oool2000000`0oooo000J0?ooo`030000003oool0oooo0?H0oooo
00<000000?ooo`3oool02P3oool001X0oooo00<000000?ooo`3oool0jP3oool4000000030?ooo`00
0000000000<000000`3oool010000000oooo0?ooo`3oool3000000D0oooo000J0?ooo`030000003o
ool0oooo0>T0oooo00@000000?ooo`3oool000000P3oool4000000<0oooo00<000000?ooo`000000
1@3oool00`000000oooo0?ooo`020?ooo`005@3ooooY000000P0oooo00@000000?ooo`3oool00000
1@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<000001@3oool001X0oooo
00<000000?ooo`3oool01@3oool2000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0=0?ooo`<000000`3oool3000000050?ooo`00000000000000003oool00P0000000`3oool0
000000000002000000@0oooo000J0?ooo`030000003oool0oooo0100oooo0P00003J0?ooo`030000
003oool0oooo01@0oooo000J0?ooo`030000003oool0oooo01/0oooo0P00003>0?ooo`8000005P3o
ool001X0oooo0P00000W0?ooo`800000f`3oool001X0oooo00<000000?ooo`3oool0<@3oool20000
00T0oooo0P0000350?ooo`006P3oool00`000000oooo0?ooo`170?ooo`8000002@3oool200000:l0
oooo000J0?ooo`030000003oool0oooo05d0oooo0P0000090?ooo`800000203oool2000000T0oooo
0P0000090?ooo`800000N@3oool001X0oooo00<000000?ooo`3oool0T`3oool2000000T0oooo0P00
00090?ooo`8000002@3oool2000000T0oooo0P0000090?ooo`8000002@3oool2000002`0oooo000J
0?ooo`800000o`3oool50?ooo`006P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000J0?ooo`03
0000003oool0oooo0?l0oooo103oool001X0oooo00<000000?ooo`3oool0o`3oool40?ooo`006P3o
ool200000?l0oooo1@3oool001X0oooo00<000000?ooo`3oool0o`3oool40?ooo`006P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0>h0oooo000J0?ooo`030000003oool0oooo00h0
oooo1@0000030?ooo`D000000`3oool300000080oooo1@0000030?ooo`D000000`3oool5000000<0
oooo1@0000030?ooo`D000000`3oool5000000<0oooo1@0000030?ooo`D000000`3oool5000000<0
oooo1@0000030?ooo`D000000`3oool5000000<0oooo1@0000030?ooo`D000000`3oool5000000<0
oooo1@0000030?ooo`D000000`3oool5000000<0oooo1@0000030?ooo`D000000`3oool5000000<0
oooo1@0000030?ooo`D00000:`3oool001X0oooo00<000000?ooo`3oool0o`3oool40?ooo`006P3o
ool2000000`0oooo00<000000?ooo`3oool0m@3oool001X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`3f0?ooo`000P3oool2000000@0oooo0P0000040?ooo`800000103oool20000
00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3g0?ooo`0000D0oooo0000003o
ool0oooo000000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?P0oooo00001@3oool000000?ooo`3o
ool0000000P0oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`3oool300000?l0
oooo103oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000030?oo
o`800000103oool00`000000oooo0?ooo`3o0?ooo`@0oooo00001@3oool000000?ooo`3oool00000
00P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0?l0oooo103oool00080oooo0P00000:0?ooo`800000103oool3000000<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`3i0?ooo`006P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0?T0oooo000J0?ooo`800000203oool00`000000oooo0?ooo`3i0?ooo`006P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?X0oooo000J0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0nP3oool001X0oooo00<000000?ooo`3oool0o`3oool40?oo
o`006P3oool200000?l0oooo1@3oool001X0oooo00<000000?ooo`3oool0o`3oool40?ooo`006P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?X0oooo000J0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0nP3oool001X0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`3k0?ooo`006P3oool2000000H0oooo00<000000?ooo`3oool0n`3oool001X0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3k0?ooo`006P3oool00`000000oooo0?oo
o`3o0?ooo`@0oooo000J0?ooo`030000003oool0oooo0?l0oooo103oool001X0oooo0P00003o0?oo
o`D0oooo000J0?ooo`030000003oool0oooo0?l0oooo103oool000P0oooo0P0000040?ooo`800000
0`3oool500000080oooo00<000000?ooo`3oool0o`3oool40?ooo`001`3oool010000000oooo0?oo
o`00000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool40?ooo`001`3o
ool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0080oooo0`00003o0?ooo`@0oooo
00070?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`3o0?ooo`@0oooo00070?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo00080?ooo`8000002P3oool2000000@0oooo00<0
00000?ooo`3oool0o`3oool40?ooo`006P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000J0?oo
o`800000o`3oool50?ooo`006P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000J0?ooo`030000
003oool0oooo0?l0oooo103oool001X0oooo00<000000?ooo`3oool0o`3oool40?ooo`006P3oool2
00000?l0oooo1@3oool001X0oooo00<000000?ooo`3oool0o`3oool40?ooo`006P3oool00`000000
oooo0?ooo`3o0?ooo`@0oooo000J0?ooo`030000003oool0oooo0?l0oooo103oool001X0oooo00<0
00000?ooo`3oool0o`3oool40?ooo`006P3oool200000?l0oooo1@3oool001X0oooo00<000000?oo
o`3oool0o`3oool40?ooo`006P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000J0?ooo`030000
003oool0oooo0?l0oooo103oool001X0oooo0P00003o0?ooo`D0oooo000J0?ooo`030000003oool0
oooo0?l0oooo103oool001X0oooo00<000000?ooo`3oool0o`3oool40?ooo`000P3oool2000000@0
oooo0P0000030?ooo`D000000P3oool2000000@0oooo00<000000?ooo`3oool0o`3oool40?ooo`00
00D0oooo0000003oool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool000000?l0oooo1P3oool000050?ooo`000000oooo0?ooo`0000002P3oool0
0`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`<00000o`3oool40?ooo`0000D0oooo
0000003oool0oooo0000000:0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003o
ool0oooo0?l0oooo103oool000050?ooo`000000oooo0?ooo`0000002P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool40?ooo`000P3oool2
000000X0oooo0P0000040?ooo`<000000`3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000J0?oo
o`800000o`3oool50?ooo`006P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000J0?ooo`030000
003oool0oooo0?l0oooo103oool001X0oooo00<000000?ooo`3oool0o`3oool40?ooo`006P3oool0
0`000000oooo0?ooo`3o0?ooo`@0oooo000J0?ooo`800000o`3oool50?ooo`006P3oool00`000000
oooo0?ooo`3o0?ooo`@0oooo000J0?ooo`030000003oool0oooo0?l0oooo103oool001X0oooo00<0
00000?ooo`3oool0o`3oool40?ooo`006P3oool200000?l0oooo1@3oool001X0oooo00<000000?oo
o`3oool0o`3oool40?ooo`006P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000J0?ooo`030000
003oool0oooo0?l0oooo103oool001X0oooo0P00003o0?ooo`D0oooo000J0?ooo`030000003oool0
oooo0?l0oooo103oool001X0oooo00<000000?ooo`3oool0o`3oool40?ooo`00203oool2000000@0
oooo0P0000030?ooo`@000000`3oool00`000000oooo0?ooo`3o0?ooo`@0oooo00070?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooo`@0
oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00`3oool300000?l0
oooo103oool000L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0?l0oooo103oool000L0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo0?l0oooo103oool000P0oooo0P00000:0?ooo`80
0000103oool00`000000oooo0?ooo`3o0?ooo`@0oooo000J0?ooo`800000o`3oool50?ooo`006P3o
ool00`000000oooo0?ooo`3o0?ooo`@0oooo000J0?ooo`030000003oool0oooo0?l0oooo103oool0
01X0oooo00<000000?ooo`3oool0o`3oool40?ooo`006P3oool00`000000oooo0?ooo`3o0?ooo`@0
oooo000J0?ooo`800000o`3oool50?ooo`006P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000J
0?ooo`030000003oool0oooo0?l0oooo103oool001X0oooo00<000000?ooo`3oool0o`3oool40?oo
o`006P3oool200000?l0oooo1@3oool001X0oooo00<000000?ooo`3oool0o`3oool40?ooo`006P3o
ool00`000000oooo0?ooo`3o0?ooo`@0oooo000J0?ooo`030000003oool0oooo0?l0oooo103oool0
01X0oooo00<000000?ooo`3oool0o`3oool40?ooo`006P3oool200000?l0oooo1@3oool001X0oooo
00<000000?ooo`3oool0o`3oool40?ooo`000P3oool2000000@0oooo0P0000030?ooo`@000000`3o
ool2000000@0oooo00<000000?ooo`3oool0o`3oool40?ooo`0000D0oooo0000003oool0oooo0000
00080?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`3o0?ooo`@0oooo00001@3oool000000?ooo`3oool0000000T0oooo00<000000?ooo`3oool0
1@3oool010000000oooo0?ooo`3oool300000?l0oooo103oool000050?ooo`000000oooo0?ooo`00
00002P3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`3o0?ooo`@0
oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo103oool00080oooo0P00000:0?ooo`80
0000103oool3000000<0oooo00<000000?ooo`3oool0o`3oool40?ooo`006P3oool00`000000oooo
0?ooo`3o0?ooo`@0oooo000J0?ooo`800000o`3oool50?ooo`006P3oool00`000000oooo0?ooo`3o
0?ooo`@0oooo000J0?ooo`030000003oool0oooo0?l0oooo103oool001X0oooo00<000000?ooo`3o
ool0o`3oool40?ooo`006P3oool200000?l0oooo1@3oool001X0oooo00<000000?ooo`3oool0o`3o
ool40?ooo`006P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?/0oooo000J0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0n`3oool001X0oooo00<000000?ooo`3o
ool0o`3oool40?ooo`006P3oool200000?l0oooo1@3oool001X0oooo00<000000?ooo`3oool0o`3o
ool40?ooo`006P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000J0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0n03oool001X0oooo0P00000:0?ooo`030000003oool0oooo0?L0
oooo000J0?ooo`030000003oool0oooo00l0oooo0P00003b0?ooo`00203oool2000000@0oooo0P00
00040?ooo`800000103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo0P00
00050?ooo`030000003oool0oooo0><0oooo00070?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00<0oooo
0P0000050?ooo`800000eP3oool000L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`020?ooo`<00000<P3oool2000000D0oooo0P0000050?ooo`800000`@3oool000L0oooo00@0
00000?ooo`3oool000002`3oool01@000000oooo0?ooo`3oool0000004T0oooo0P0000050?ooo`80
00001@3oool2000000D0oooo0P00002U0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0H`3oool2000000D0oooo0P0000050?oo
o`8000001@3oool2000000D0oooo0P0000050?ooo`8000001@3oool00`000000oooo0?ooo`1c0?oo
o`00203oool2000000X0oooo0P0000040?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool00`3oool2000000D0oooo0P0000050?ooo`8000001@3oool2000000D0oooo0P0000050?ooo`80
00001@3oool2000000D0oooo0P0000050?ooo`8000001@3oool2000000D0oooo00<000000?ooo`3o
ool09P3oool001X0oooo00<000000?ooo`3oool0o`3oool40?ooo`006P3oool200000?l0oooo1@3o
ool001X0oooo00<000000?ooo`3oool0o`3oool40?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
o`@0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo002i0?oo
o`<00000I03oool00;X0oooo00<000000?ooo`3oool0H`3oool002/0oooo0`0000030?ooo`800000
103oool400000080oooo0`0000000`3oool00000000000020?ooo`8000000P3oool3000000L0oooo
0P000000103oool000000000000000020?ooo`800000103oool400000080oooo0`0000020?ooo`<0
0000103oool00`000000oooo0?ooo`090?ooo`<000000`3oool200000080oooo0P0000020?ooo`80
000000@0oooo0000000000000000103oool2000000<0oooo1`0000020?ooo`8000000P3oool20000
00@0oooo0`0000000`3oool00000000000020?ooo`80000000@0oooo0000000000000000103oool4
00000080oooo0P00000:0?ooo`<0000000<0oooo0000000000000P3oool2000000L0oooo1@00000g
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000050?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0100000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0g0?ooo`00;03oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`04000000L0
oooo00D000000?ooo`000000oooo000000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool4000000<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool3000000<0
oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000=0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03L0oooo000H0?oo
o`@00000403oool00`000000oooo0?ooo`020?ooo`800000103oool3000000<0oooo0P0000020?oo
o`@00000103oool2000000P0oooo0P0000000`3oool00000000000030?ooo`800000103oool30000
00<0oooo0P0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`040?ooo`8000000P3oool4000000<0oooo100000000`3oool00000000000030000
00<0oooo0`0000000`3oool000000000000200000080oooo1@0000030?ooo`8000000P3oool40000
0080oooo100000020?ooo`80000000@0oooo000000000000oooo1@0000090?ooo`8000000P3oool4
000000/0oooo00<000000?ooo`3oool0=`3oool001T0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo01L0oooo0P0000000`3oool000000000000;0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000D
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo03L0oooo000I0?ooo`030000003oool0oooo00l0oooo0`00000:0?oo
o`800000103oool00`000000oooo0?ooo`0B0?ooo`80000000@0oooo00000000000000002@3oool2
000000P0oooo0P00000A0?ooo`<00000;P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo00h0oooo0P00000i0?ooo`00603oool400000?l0oooo1@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.65499, -0.0344583, \
0.135879, 0.00224662}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 4.-  Constant input 2", "SubsubsectionIcon"],

Cell[TextData[{
  "Now, we are going to suppose a continuous flow in compartment 1 ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_1\)(t)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`b\_1\)]],
  "=1  for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < T\)]],
  ", in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(t = T\)\)\)]],
  " it is cut the input. We want know the retention in the thyroid."
}], "Text"],

Cell[TextData[{
  "Here is the retention for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < T\)]],
  ", ",
  " being ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(t\_1\)\(\ \)\(=\)\(\ \ \)\(t\)\(\ \)\)\)\
\)]],
  " "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x1[t1_] = 
      Map[Last, 
        SystemDSolve[iodine, \ {0, \ 0, 0}, {1, \ 0, \ 0}, \ t, 
          t1, \ \ x]]\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \({\(\(0.35280099212137916`\)\(\[InvisibleSpace]\)\) - 
        0.34983304763480216`\ \[ExponentialE]\^\(\(-2.8585990234247185`\)\ t1\
\) + 0.005729719174505907`\ \[ExponentialE]\^\(\(-0.14677770424391592`\)\ \
t1\) - 0.008697663661082898`\ \[ExponentialE]\^\(\(-0.0929659650413442`\)\ t1\
\), \(\(3.0783961174351484`\)\(\[InvisibleSpace]\)\) + 
        0.1052806015008326`\ \[ExponentialE]\^\(\(-2.8585990234247185`\)\ \
t1\) - 0.09257173535222227`\ \[ExponentialE]\^\(\(-0.14677770424391592`\)\ t1\
\) - 3.091104983583759`\ \[ExponentialE]\^\(\(-0.0929659650413442`\)\ t1\), \
\(\(0.18468023341826006`\)\(\[InvisibleSpace]\)\) - 
        0.0003360074129290658`\ \[ExponentialE]\^\(\(-2.8585990234247185`\)\ \
t1\) + 0.33632530003755795`\ \[ExponentialE]\^\(\(-0.14677770424391592`\)\ t1\
\) - 0.520669526042889`\ \[ExponentialE]\^\(\(-0.0929659650413442`\)\ \
t1\)}\)], "Output",
  CellLabel->"Out[54]="]
}, Open  ]],

Cell[TextData[{
  "Here is the retention for  ",
  Cell[BoxData[
      \(TraditionalForm\`t\  \[GreaterEqual] T\)]],
  "  being ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(t\_2\  = \ \ \(\(t\)\(\ \)\(-\)\(\ \)\(T\)\
\(\ \)\)\)\)\)]],
  " "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x2[t2_] = 
      Map[Last, AcuteInput[iodine, \ x1[100], \ t2, \ x2]]\)], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    \({0.184632611317255`\ \((\(-0.01702210651424822`\)\ \
\[ExponentialE]\^\(\(-2.8585990234247185`\)\ t2\) + 
              0.016295710046219006`\ \
\[ExponentialE]\^\(\(-0.14677770424391592`\)\ t2\) + 
              0.0007263964680292148`\ \
\[ExponentialE]\^\(\(-0.0929659650413442`\)\ t2\))\) + 
        0.3528001966522969`\ \((1.0000324083305385`\ \
\[ExponentialE]\^\(\(-2.8585990234247185`\)\ t2\) - 
              0.0008409950263963222`\ \
\[ExponentialE]\^\(\(-0.14677770424391592`\)\ t2\) + 
              0.0008085866958576026`\ \
\[ExponentialE]\^\(\(-0.0929659650413442`\)\ t2\))\) + 
        3.0781125129801348`\ \((0.00005336169235902664`\ \
\[ExponentialE]\^\(\(-2.8585990234247185`\)\ t2\) - 
              0.002742503078814387`\ \
\[ExponentialE]\^\(\(-0.14677770424391592`\)\ t2\) + 
              0.0026891413864553607`\ \
\[ExponentialE]\^\(\(-0.0929659650413442`\)\ t2\))\), 
      0.184632611317255`\ \((0.005122722466466635`\ \
\[ExponentialE]\^\(\(-2.8585990234247185`\)\ t2\) - 
              0.263280295566182`\ \
\[ExponentialE]\^\(\(-0.14677770424391592`\)\ t2\) + 
              0.2581575730997153`\ \
\[ExponentialE]\^\(\(-0.0929659650413442`\)\ t2\))\) + 
        0.3528001966522969`\ \((\(-0.30095502463584706`\)\ \
\[ExponentialE]\^\(\(-2.8585990234247185`\)\ t2\) + 
              0.013587466792874536`\ \
\[ExponentialE]\^\(\(-0.14677770424391592`\)\ t2\) + 
              0.2873675578429726`\ \
\[ExponentialE]\^\(\(-0.0929659650413442`\)\ t2\))\) + 
        3.0781125129801348`\ \((\(-0.000016058948994794227`\)\ \
\[ExponentialE]\^\(\(-2.8585990234247185`\)\ t2\) + 
              0.044309024837426346`\ \
\[ExponentialE]\^\(\(-0.14677770424391592`\)\ t2\) + 
              0.9557070341115684`\ \
\[ExponentialE]\^\(\(-0.0929659650413442`\)\ t2\))\), 
      0.184632611317255`\ \((\(-0.00001634938154392521`\)\ \
\[ExponentialE]\^\(\(-2.8585990234247185`\)\ t2\) + 
              0.9565319701889701`\ \[ExponentialE]\^\(\(-0.14677770424391592`\
\)\ t2\) + 
              0.04348437919257395`\ \[ExponentialE]\^\(\(-0.0929659650413442`\
\)\ t2\))\) + 
        0.3528001966522969`\ \((0.0009605104624624938`\ \
\[ExponentialE]\^\(\(-2.8585990234247185`\)\ t2\) - 
              
              0.04936505541865897`\ \
\[ExponentialE]\^\(\(-0.14677770424391592`\)\ t2\) + 
              0.04840454495619647`\ \[ExponentialE]\^\(\(-0.0929659650413442`\
\)\ t2\))\) + 
        3.0781125129801348`\ \((5.125280278777622`*^-8\ \
\[ExponentialE]\^\(\(-2.8585990234247185`\)\ t2\) - 
              0.16098051976791944`\ \
\[ExponentialE]\^\(\(-0.14677770424391592`\)\ t2\) + 
              0.16098046851511666`\ \[ExponentialE]\^\(\(-0.0929659650413442`\
\)\ t2\))\)}\)], "Output",
  CellLabel->"Out[55]="]
}, Open  ]],

Cell[BoxData[
    \(x[t_, T_] := If[t < T, x1[t], x2[t - T]]; \)], "Input",
  CellLabel->"In[56]:="],

Cell[TextData[{
  "The retention, with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(T\)\(\ \)\(=\)\)\)]],
  "100 days,  in the thyroid is plotted here. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\(x[t, 100]\)[\([\)\(2\)\(]\)], \ {t, 0, 200}]\)], "Input",
  CellLabel->"In[57]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.0147151 0.191223 [
[.2619 .00222 -6 -9 ]
[.2619 .00222 6 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .11033 -18 -4.5 ]
[.01131 .11033 0 4.5 ]
[.01131 .20594 -6 -4.5 ]
[.01131 .20594 0 4.5 ]
[.01131 .30155 -18 -4.5 ]
[.01131 .30155 0 4.5 ]
[.01131 .39716 -6 -4.5 ]
[.01131 .39716 0 4.5 ]
[.01131 .49277 -18 -4.5 ]
[.01131 .49277 0 4.5 ]
[.01131 .58838 -6 -4.5 ]
[.01131 .58838 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(50)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(100)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(150)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(200)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11033 m
.03006 .11033 L
s
[(0.5)] .01131 .11033 1 0 Mshowa
.02381 .20594 m
.03006 .20594 L
s
[(1)] .01131 .20594 1 0 Mshowa
.02381 .30155 m
.03006 .30155 L
s
[(1.5)] .01131 .30155 1 0 Mshowa
.02381 .39716 m
.03006 .39716 L
s
[(2)] .01131 .39716 1 0 Mshowa
.02381 .49277 m
.03006 .49277 L
s
[(2.5)] .01131 .49277 1 0 Mshowa
.02381 .58838 m
.03006 .58838 L
s
[(3)] .01131 .58838 1 0 Mshowa
.125 Mabswid
.02381 .03384 m
.02756 .03384 L
s
.02381 .05296 m
.02756 .05296 L
s
.02381 .07208 m
.02756 .07208 L
s
.02381 .0912 m
.02756 .0912 L
s
.02381 .12945 m
.02756 .12945 L
s
.02381 .14857 m
.02756 .14857 L
s
.02381 .16769 m
.02756 .16769 L
s
.02381 .18682 m
.02756 .18682 L
s
.02381 .22506 m
.02756 .22506 L
s
.02381 .24418 m
.02756 .24418 L
s
.02381 .2633 m
.02756 .2633 L
s
.02381 .28243 m
.02756 .28243 L
s
.02381 .32067 m
.02756 .32067 L
s
.02381 .33979 m
.02756 .33979 L
s
.02381 .35892 m
.02756 .35892 L
s
.02381 .37804 m
.02756 .37804 L
s
.02381 .41628 m
.02756 .41628 L
s
.02381 .4354 m
.02756 .4354 L
s
.02381 .45453 m
.02756 .45453 L
s
.02381 .47365 m
.02756 .47365 L
s
.02381 .51189 m
.02756 .51189 L
s
.02381 .53102 m
.02756 .53102 L
s
.02381 .55014 m
.02756 .55014 L
s
.02381 .56926 m
.02756 .56926 L
s
.02381 .60751 m
.02756 .60751 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.04262 .18402 L
.06244 .31997 L
.07286 .37258 L
.08255 .41273 L
.09388 .45082 L
.10458 .47977 L
.11437 .5014 L
.125 .52061 L
.14357 .54589 L
.15301 .5556 L
.16341 .56441 L
.17439 .57195 L
.18444 .57756 L
.20385 .58572 L
.21455 .58906 L
.22473 .59164 L
.23431 .59365 L
.24453 .59541 L
.26292 .59781 L
.27321 .59883 L
.28433 .59971 L
.29395 .60034 L
.3045 .60091 L
.32444 .6017 L
.33533 .60202 L
.34551 .60227 L
.35596 .60247 L
.36586 .60263 L
.38441 .60286 L
.39407 .60294 L
.40432 .60302 L
.42274 .60313 L
.43211 .60317 L
.44221 .60321 L
.46049 .60326 L
.47007 .60328 L
.48053 .60329 L
.48582 .6033 L
.49146 .60331 L
.49421 .60331 L
.49679 .60332 L
.49792 .60332 L
.49912 .60332 L
.50043 .60274 L
.50163 .59648 L
.50284 .58639 L
.50416 .57353 L
.50656 .54872 L
.51107 .50343 L
Mistroke
.52121 .41458 L
.53952 .29318 L
.54987 .24178 L
.55923 .20352 L
.57017 .16695 L
.58022 .13965 L
.5995 .10025 L
.60964 .08482 L
.62034 .07155 L
.62984 .06189 L
.64002 .05336 L
.65836 .0417 L
.66856 .03681 L
.67964 .03251 L
.68922 .02947 L
.69977 .02671 L
.71959 .02286 L
.73044 .0213 L
.74061 .02012 L
.75047 .01917 L
.76083 .01835 L
.77935 .01725 L
.78892 .01682 L
.79913 .01644 L
.81751 .01592 L
.82778 .0157 L
.8389 .01551 L
.8485 .01537 L
.85906 .01525 L
.87897 .01508 L
.88986 .01501 L
.90003 .01495 L
.91046 .01491 L
.92036 .01488 L
.93891 .01483 L
.94829 .01481 L
.95827 .01479 L
.97619 .01477 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[57]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00D@3oool2000000@0oooo0P00000d0?ooo`D000000P3oool2000000@0
oooo0P00000a0?ooo`D000000P3oool2000000@0oooo0P00000b0?ooo`@000000`3oool2000000@0
oooo0P0000030?ooo`00D03oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
03D0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0<03oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`00D`3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo03<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`040?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00540oooo0P0000030?oo
o`040000003oool0oooo000003D0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`020?ooo`800000
0`3oool010000000oooo0?ooo`00000c0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`4000000@3oool10?ooo`00D@3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000003D0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000<@3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00540oooo0`000003
0?ooo`800000=@3oool2000000@0oooo0P0000040?ooo`800000<P3oool2000000@0oooo0`000003
0?ooo`800000<`3oool2000000@0oooo0P0000040?ooo`8000000`3oool00?l0oooo8@3oool001D0
oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo
000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`003P3ooooo0000010000000`3oool001D0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo3P00000<0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0
oooo000E0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`0f0?ooo`P00000@03oool00`000000oooo0?ooo`070?ooo`005@3oool00`000000oooo0?oo
o`2b0?ooo`@00000DP3oool001D0oooo00<000000?ooo`3oool0/03oool2000005H0oooo000E0?oo
o`800000[P3oool3000005P0oooo000E0?ooo`800000Z`3oool3000005/0oooo000E0?ooo`800000
Z@3oool2000005h0oooo000E0?ooo`800000Y`3oool200000600oooo000E0?ooo`800000Y@3oool2
00000680oooo000E0?ooo`800000Y03oool00`000000oooo0?ooo`1R0?ooo`005@3oool200000:<0
oooo00<000000?ooo`3oool0H`3oool001D0oooo0P00002R0?ooo`030000003oool0oooo06@0oooo
000E0?ooo`800000X@3oool00`000000oooo0?ooo`1U0?ooo`005@3oool00`000000oooo0000002O
0?ooo`030000003oool0oooo06H0oooo000E0?ooo`<00000WP3oool00`000000oooo0?ooo`1W0?oo
o`005@3oool00`000000oooo0000002M0?ooo`030000003oool0oooo06P0oooo000E0?ooo`030000
003oool0000009`0oooo00<000000?ooo`3oool0J@3oool001D0oooo00<000000?ooo`000000W03o
ool00`000000oooo0?ooo`1Y0?ooo`005@3oool00`000000oooo0000002K0?ooo`030000003oool0
oooo06X0oooo000E0?ooo`030000003oool0000009X0oooo00<000000?ooo`3oool0J`3oool001D0
oooo0`00002I0?ooo`030000003oool0oooo06`0oooo000E0?ooo`030000003oool0000009T0oooo
00<000000?ooo`3oool0K03oool001D0oooo00<000000?ooo`000000V03oool00`000000oooo0?oo
o`1]0?ooo`000P3oool2000000@0oooo0P0000040?ooo`8000001@3oool010000000oooo0?ooo`00
002G0?ooo`030000003oool0oooo06d0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@0
00000?ooo`3oool00000103oool010000000oooo0?ooo`00002F0?ooo`030000003oool0oooo06h0
oooo00001@3oool000000?ooo`3oool0000000/0oooo00<000000?ooo`3oool00P3oool4000009H0
oooo00<000000?ooo`3oool0KP3oool000050?ooo`000000oooo0?ooo`0000002@3oool2000000D0
oooo00@000000?ooo`3oool00000U@3oool00`000000oooo0?ooo`1_0?ooo`0000D0oooo0000003o
ool0oooo000000090?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000U@3oool0
0`000000oooo0?ooo`1_0?ooo`000P3oool2000000X0oooo0`0000040?ooo`040000003oool0oooo
000009@0oooo00<000000?ooo`3oool0L03oool001D0oooo00@000000?ooo`3oool00000U03oool0
0`000000oooo0?ooo`1`0?ooo`005@3oool2000000030?ooo`000000oooo0980oooo00<000000?oo
o`3oool0L@3oool001D0oooo00@000000?ooo`3oool00000T`3oool00`000000oooo0?ooo`1a0?oo
o`005@3oool01@000000oooo0?ooo`3oool000000940oooo00<000000?ooo`3oool0LP3oool001D0
oooo00D000000?ooo`3oool0oooo0000002A0?ooo`030000003oool0oooo0780oooo000E0?ooo`05
0000003oool0oooo0?ooo`000000T@3oool00`000000oooo0?ooo`1b0?ooo`005@3oool200000080
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`1c0?ooo`005@3oool01@000000oooo
0?ooo`3oool000000900oooo00<000000?ooo`3oool0L`3oool001D0oooo00D000000?ooo`3oool0
oooo0000002?0?ooo`030000003oool0oooo07@0oooo000E0?ooo`050000003oool0oooo0?ooo`00
0000S`3oool00`000000oooo0?ooo`1d0?ooo`005@3oool01@000000oooo0?ooo`3oool0000008h0
oooo00<000000?ooo`3oool0M@3oool001D0oooo0P0000020?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool0M@3oool001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`2;0?ooo`030000003oool0oooo07D0oooo000E0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0RP3oool00`000000oooo0?ooo`1f0?ooo`005@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo08X0oooo00<000000?ooo`3oool0MP3oool001D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo07H0oooo000E0?ooo`800000
0`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo07L0oooo000E0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`1g0?ooo`005@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0M`3oool0
00d0oooo1@0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0R@3oool00`00
0000oooo0?ooo`1g0?ooo`003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`1h0?ooo`003`3oool00`000000oooo
0?ooo`030?ooo`<000000`3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo07P0oooo
000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`270?ooo`030000003oool0oooo07P0oooo000?0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo07P0oooo000>0?oo
o`8000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0N@3oool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo07T0oooo000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`1i0?ooo`005@3oool2000000D0oooo00<000000?ooo`3oool0Q@3o
ool00`000000oooo0?ooo`1i0?ooo`005@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo08D0oooo00<000000?ooo`3oool0N@3oool001D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`240?ooo`030000003oool0oooo07X0oooo000E0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`1j0?ooo`005@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0NP3oool001D0oooo0P00
00050?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0NP3oool001D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo07X0oooo000E0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`1k0?oo
o`005@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0880oooo00<000000?ooo`3o
ool0N`3oool001D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`220?ooo`030000
003oool0oooo07/0oooo000E0?ooo`8000001P3oool00`000000oooo0?ooo`220?ooo`030000003o
ool0oooo07/0oooo000E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0P@3oool0
0`000000oooo0?ooo`1l0?ooo`005@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0840oooo00<000000?ooo`3oool0O03oool001D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`210?ooo`030000003oool0oooo07`0oooo000E0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`1l0?ooo`005@3oool2000000L0oooo00<0
00000?ooo`3oool0P03oool00`000000oooo0?ooo`1l0?ooo`005@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0O@3oool001D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo07d0oooo00000`3oool0
00000000000300000080oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo07l0oooo00<000000?ooo`3oool0O@3oool000<0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0O`3oool00`000000oooo0?ooo`1m0?ooo`000`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0080oooo0`0000060?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0
O@3oool000<0oooo00<000000?ooo`3oool0203oool2000000D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo07d0oooo00030?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo07d0oooo00<000000?ooo`3oool0OP3oool00080oooo0P00000:0?ooo`<00000103oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0OP3oool001D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo07h0
oooo000E0?ooo`800000203oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo07h0oooo
000E0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?oo
o`1n0?ooo`005@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo07d0oooo00<00000
0?ooo`3oool0OP3oool001D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1k0?oo
o`030000003oool0oooo07l0oooo000E0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0N`3oool00`000000oooo0?ooo`1o0?ooo`005@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo07/0oooo00<000000?ooo`3oool0O`3oool001D0oooo0P0000090?ooo`030000003o
ool0oooo07/0oooo00<000000?ooo`3oool0O`3oool001D0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`1k0?ooo`030000003oool0oooo07l0oooo000E0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`1o0?ooo`005@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0O`3oool001D0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0800oooo
000E0?ooo`8000002P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0800oooo000E
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`20
0?ooo`005@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool0P03oool001D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo0800oooo000E0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`200?ooo`005@3oool2000000`0oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`200?ooo`005@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo07H0oooo00<000000?ooo`3oool0P@3oool001D0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1f0?ooo`030000003oool0oooo0840oooo000=0?ooo`@00000103oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0P@3oool000d0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07D0oooo
00<000000?ooo`3oool0P@3oool000h0oooo00<000000?ooo`3oool0103oool3000000`0oooo00<0
00000?ooo`3oool0M@3oool00`000000oooo0?ooo`210?ooo`003`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`21
0?ooo`003@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`220?ooo`003P3oool2000000D0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0880oooo000E0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`220?ooo`00
5@3oool2000000h0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`220?ooo`005@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0PP3o
ool001D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0
oooo0880oooo000E0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0LP3oool00`00
0000oooo0?ooo`220?ooo`005@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0740
oooo00<000000?ooo`3oool0P`3oool001D0oooo0P00000@0?ooo`030000003oool0oooo0700oooo
00<000000?ooo`3oool0P`3oool001D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`1`0?ooo`030000003oool0oooo08<0oooo000E0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0L03oool00`000000oooo0?ooo`230?ooo`005@3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo06l0oooo00<000000?ooo`3oool0P`3oool001D0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo08<0oooo000E0?ooo`800000
4@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo08<0oooo000E0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`230?ooo`005@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0Q03oool0
01D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo
08@0oooo000E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0K03oool00`000000
oooo0?ooo`240?ooo`005@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo06`0oooo
00<000000?ooo`3oool0Q03oool001D0oooo0P00000D0?ooo`030000003oool0oooo06/0oooo00<0
00000?ooo`3oool0Q03oool001D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1[
0?ooo`030000003oool0oooo08@0oooo000E0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`240?ooo`0000<0oooo0000000000000P0000030?ooo`80
0000103oool2000000D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Z0?ooo`03
0000003oool0oooo08@0oooo00000`3oool000000?ooo`0:0?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo08D0
oooo00020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool3000001@0oooo
00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`250?ooo`000`3oool00`000000oooo0?oo
o`080?ooo`8000001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo06P0oooo00<0
00000?ooo`3oool0Q@3oool000050?ooo`000000oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?oo
o`250?ooo`000P3oool2000000X0oooo0`0000040?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0I`3oool00`000000oooo0?ooo`250?ooo`005@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo06L0oooo00<000000?ooo`3oool0Q@3oool001D0oooo0P00000H0?ooo`03
0000003oool0oooo06H0oooo00<000000?ooo`3oool0Q@3oool001D0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo08D0oooo000E0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`250?ooo`005@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0Q@3oool0
01D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo
08H0oooo000E0?ooo`8000006`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo08H0
oooo000E0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`260?ooo`005@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0600oooo00<0
00000?ooo`3oool0QP3oool001D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1P
0?ooo`030000003oool0oooo08H0oooo000E0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0G`3oool00`000000oooo0?ooo`260?ooo`005@3oool2000001l0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`260?ooo`005@3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo05d0oooo00<000000?ooo`3oool0QP3oool001D0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo08H0oooo000E0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`260?ooo`005@3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0Q`3oool001D0
oooo0P00000T0?ooo`800000F@3oool00`000000oooo0?ooo`270?ooo`005@3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0Q`3oool001D0oooo00<0
00000?ooo`3oool09P3oool2000005H0oooo00<000000?ooo`3oool0Q`3oool001D0oooo00<00000
0?ooo`3oool0:03oool2000005@0oooo00<000000?ooo`3oool0Q`3oool000h0oooo0P0000050?oo
o`030000003oool0oooo02X0oooo0P00001B0?ooo`030000003oool0oooo08L0oooo000=0?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0;03oool3000004l0oooo00<000000?oo
o`3oool0Q`3oool000l0oooo00<000000?ooo`3oool00`3oool3000002l0oooo1P0000190?ooo`03
0000003oool0oooo08L0oooo000@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
=@3oool6000004<0oooo00<000000?ooo`3oool0Q`3oool000d0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0k0?ooo`L00000?03oool00`000000oooo0?ooo`270?ooo`003P3o
ool2000000D0oooo00<000000?ooo`3oool0@P3oool[00000100oooo00<000000?ooo`3oool0R03o
ool001D0oooo00<000000?ooo`3oool0K@3ooolA000008X0oooo000E0?ooo`800000o`3oool:0?oo
o`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo
2@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-16.6539, -0.259423, \
0.779335, 0.0194073}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[57]="]
}, Open  ]],

Cell[BoxData[
    \(\(\(Clear[iodine, \ x, \ x1, x2]\)\(\ \)\)\)], "Input",
  CellLabel->"In[58]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 5.- Multiexponential input", "SubsubsectionIcon"],

Cell["\<\
An example of a multiexponential input form is provided by the iodine model \
with input to the plasma via the breathing mechanism. The input is into \
compartment 1 is given by\
\>", "Text"],

Cell[BoxData[
    \(inputtoB\  = \ 
      34.33\ \[ExponentialE]\^\(\(-200.`\)\ t\) + 
        1.09\ \[ExponentialE]\^\(\(-110.`\)\ t\) + 
        0.808\ \[ExponentialE]\^\(\(-102.`\)\ t\) + 
        1.03\ \[ExponentialE]\^\(\(-100.03`\)\ t\) + 
        1.626\ \[ExponentialE]\^\(\(-100.02`\)\ t\) + 
        3.194\ \[ExponentialE]\^\(\(-100.001`\)\ t\) + 
        0.4434`\ \[ExponentialE]\^\(\(-100.00012`\)\ t\) + 
        0.129`\ \[ExponentialE]\^\(\(-100.`\)\ t\) + 
        5.457`\ \[ExponentialE]\^\(\(-24.`\)\ t\); \)], "Input",
  CellLabel->"In[59]:="],

Cell[TextData[{
  "This expression that represents the flow from respiratory tract to blood \
has been obtained by using the ",
  StyleBox[ButtonBox["Humorap",
    ButtonData:>{
      URL[ 
      "http://www.mathsource.com/Content/Applications/LifeScience/0211-554"], 
      None}],
    ButtonBoxOptions -> {DefaultStyle -> "Hyperlink"}],
  " (included in this Toolbox, see Help) "
}], "SmallText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(iodine\  = 
      CompartMatrix[
        3, {{1, 2, \ 0.8316}, {1, 0, 1.9404}, {2, 3, 0.0086625}\ , {3, 0, 
            0.01155}\ , {3, 1, 0.0462}}, \ Log[2]/8]\)], "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    \({{\(-2.8586433975699928`\), 0, 
        0.0462`}, {0.8316`, \(-0.09530589756999316`\), 0}, {0, 
        0.0086625`, \(-0.14439339756999314`\)}}\)], "Output",
  CellLabel->"Out[60]="]
}, Open  ]],

Cell["The retention in each compartment is", "Text",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SystemDSolve[iodine, \ {0, \ 0, \ 0}, {inputtoB\ , \ 0, \ 0}\ , t, t, \ 
      x]\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \({x\_1[
          t] \[Rule] \(-0.17413900660013107`\)\ \[ExponentialE]\^\(\(-200.`\)\
\ t\) - 0.010173475810692173`\ \[ExponentialE]\^\(\(-110.`\)\ t\) - 
          0.008149979256173227`\ \[ExponentialE]\^\(\(-102.`\)\ t\) - 
          0.010599831428316516`\ \[ExponentialE]\^\(\(-100.03`\)\ t\) - 
          0.016735048339179485`\ \[ExponentialE]\^\(\(-100.02`\)\ t\) - 
          0.0328795811694692`\ \[ExponentialE]\^\(\(-100.001`\)\ t\) - 
          0.004564476630949547`\ \[ExponentialE]\^\(\(-100.00012`\)\ t\) - 
          0.0013279616886930593`\ \[ExponentialE]\^\(\(-100.`\)\ t\) - 
          0.2581196633677896`\ \[ExponentialE]\^\(\(-24.`\)\ t\) + 
          0.2581274939303366`\ \[ExponentialE]\^\(\(-2.85859902342472`\)\ t\) \
+ 0.25857766350547234`\ \[ExponentialE]\^\(\(-2.8585990234247163`\)\ t\) - 
          0.0002614999671440888`\ \
\[ExponentialE]\^\(\(-0.14677770424391667`\)\ t\) - 
          0.00014446281588324845`\ \[ExponentialE]\^\(\(-0.14677770424390246`\
\)\ t\) + 
          0.00038982963861222404`\ \[ExponentialE]\^\(\(-0.09296596504134413`\
\)\ t\), x\_2[t] \[Rule] 
        0.0007244151946450145`\ \[ExponentialE]\^\(\(-200.`\)\ t\) + 
          0.00007697817234527489`\ \[ExponentialE]\^\(\(-110.`\)\ t\) + 
          0.00006650844506359173`\ \[ExponentialE]\^\(\(-102.`\)\ t\) + 
          0.00008820580174842075`\ \[ExponentialE]\^\(\(-100.03`\)\ t\) + 
          0.00013927354318038574`\ \[ExponentialE]\^\(\(-100.02`\)\ t\) + 
          0.00027368469781608937`\ \[ExponentialE]\^\(\(-100.001`\)\ t\) + 
          0.00003799435292883759`\ \[ExponentialE]\^\(\(-100.00012`\)\ t\) + 
          0.000011053864387842408`\ \[ExponentialE]\^\(\(-100.`\)\ t\) + 
          0.008979504658661722`\ \[ExponentialE]\^\(\(-24.`\)\ t\) - 
          0.07768224874299968`\ \[ExponentialE]\^\(\(-2.85859902342472`\)\ \
t\) - 0.07781772514801086`\ \[ExponentialE]\^\(\(-2.8585990234247163`\)\ t\) \
+ 0.00422490265505288`\ \[ExponentialE]\^\(\(-0.14677770424391667`\)\ t\) + 
          0.002334001571959083`\ \[ExponentialE]\^\(\(-0.14677770424390246`\)\
\ t\) + 0.1385434509332214`\ \[ExponentialE]\^\(\(-0.09296596504134413`\)\ \
t\), x\_3[
          t] \[Rule] \(-3.139890208947449`*^-8\)\ \[ExponentialE]\^\(\(-200.`\
\)\ t\) - 6.069998961040664`*^-9\ \[ExponentialE]\^\(\(-110.`\)\ t\) - 
          5.65633473278938`*^-9\ \[ExponentialE]\^\(\(-102.`\)\ t\) - 
          7.64957818865774`*^-9\ \[ExponentialE]\^\(\(-100.03`\)\ t\) - 
          1.2079596898814139`*^-8\ \[ExponentialE]\^\(\(-100.02`\)\ t\) - 
          2.3741981381971214`*^-8\ \[ExponentialE]\^\(\(-100.001`\)\ t\) - 
          3.2960160968272846`*^-9\ \[ExponentialE]\^\(\(-100.00012`\)\ t\) - 
          9.589256278814311`*^-10\ \[ExponentialE]\^\(\(-100.`\)\ t\) - 
          3.260657354137858`*^-6\ \[ExponentialE]\^\(\(-24.`\)\ t\) + 
          0.0002479261236975463`\ \[ExponentialE]\^\(\(-2.85859902342472`\)\ \
t\) + 0.00024835850227167874`\ \[ExponentialE]\^\(\(-2.8585990234247163`\)\ t\
\) - 0.015349627482769492`\ \[ExponentialE]\^\(\(-0.14677770424391667`\)\ t\) \
- 0.00847973494275028`\ \[ExponentialE]\^\(\(-0.14677770424390246`\)\ t\) + 
          0.023336429308238663`\ \[ExponentialE]\^\(\(-0.09296596504134413`\)\
\ t\)}\)], "Output",
  CellLabel->"Out[61]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 6.- Solving  large compartmental models", "SubsubsectionIcon"],

Cell["\<\
Sometime we need solving models with many compartments. An example  is \
provided by the uranium model with input from the respiratory tract to the \
plasma via the breathing mechanism. It is shown in the figure. The input is \
into compartment 1 (Plasma) and the output is to the environment from \
compartments 16 (gastrointestinal tract) and 17 (urinary bladder).\
\>", "Text"],

Cell["", "Text"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@000=jh0@0006@000000000000006P100020@00
00000000001D>000Q2P00215CDH00040^=h000d000010000000000000000000080<005P200100@00
l000000000000000000004H0003TKP00eVh004M4BD<1002000<002TXg;400000_Vh000402@000elg
000004Dg000000@000030@P01@0000`2N?hQ0PD0000;0P000015=`00@@/P0<`0R04Q0P00001hoR42
000002P0000Q0P00R04000400@000000@6h00000000000000000000000000000oooo0?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooP0000?ooooooooooooooooooooooooooooool00000000000000000oooooooooo
ooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooomooooooooooo
ooooonooooP000000000000OooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
oooomoooooooooooooooonoooo_ooooooooooooOooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooomoooooooooooooooonoooo_ooooooooooooOoooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooomoooooooooooooooonoooo_ooooooooooooOoooooooo
ooooooooooooooooP0000?oooooooooooooooooooooooooooooomoooooooooooooooonoooo_ooooo
oooooooOooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooomooooooooooo
ooooonoooo_ooooooooooooOooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
oooomoooooooooooooooonoooo_ooooooooooooOooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooomoooooooooooooooonoooo_ooooooooooooOoooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooomoooooooooooooooonoooo_ooooooooooooOoooooooo
ooooooooooooooooP0000?oooooooooooooooooooooooooooooomoooooooooooooooonoooo_ooooo
oooooooOooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooomooooooooooo
ooooonoooo_ooooooooooooOooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
oooomoooooooooooooooonoooo_ooooooooooooOooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooomoooooooooooooooonoooo_ooooooooooooOoooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooomol0000000000001onoooo_oP00000000ooOoooooooo
ooooooooooooooooP0000?oooooooooooooooooooooooooooooomomoooooooooooomonoooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooomomooooooooo
ooomonoooo_o_ooooooonooOooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
oooomomoooooooooooomonoooo_o_ooooooonooOooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooomomoooooooooooomonoooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooomomoooooooooooomonoooo_o_ooooooonooOoooooooo
ooooooooooooooooP0000?oooooooooooooooooooooooooooooomomoooooooooooomonoooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooomomooooooino
ooomonoooo_o_ooooooonooOooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
oooomomoooooomnoooomonoooo_o_ooooooonooOooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooomomohMef:mnW53_moVoooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooomomok]efblnJiK_mn>oooo_o_ooooooonooOoooooooo
ooooooooooooooooP0000?oooooooooooooooooooooooooooooomomog]efjlnjmK_m`>oooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooomomog]ef:kNk
=K_m0Noooo_o_ooooooonooOooooooooooooooooooooooooP0000?ooooooooooooo`0000000000?o
oooomomog]efRcNjaK_l000000?o_ooooooonooOooooooooooooooooooooooooP0000?oooooooooo
ooogoooooooooo_ooooomomog/dfjGNKMI_m`Noooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?ooooooooooooogoooooooooo_ooooomomog]E?6WNWS0Oml>oooo_o_ooooooonooOoooooooo
ooooooooooooooooP0000?ooooooooooooogoooooooooo_ooooomomog_oooooooKomoVoooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?ooooooooooooogoooooooooo_ooooomomog_gooooo
okomonoooo_o_ooooooonooOooooooooooooooooooooooooP0000?ooooooooooooogoooooooooo_o
oooomomoooooooooooomonoooo_o_ooooooonooOooooooooooooooooooooooooP0000?oooooooooo
ooogoooooooooo_ooooomomoooooooooooomonoooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?ooooooooooooogoooooooooo_ooooomomoooooooooooomonoooo_o_ooooooonooOoooooooo
ooooooooooooooooP0000?ooooooooooooogoooooooooo_ooooomomoooooooooooomonoooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?ooooooooooooogoooooooooo_ooooomomooooooooo
ooomonoooo_o_ooooooonooOooooooooooooooooooooooooP0000?ooooooooooooogoooooooooo_o
oooomomoooooooooooomonoooo_o_ooooooonooOooooooooooooooooooooooooP0000?oooooooooo
ooogoooooooooo_ooooomomoooooooooooomonoooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?ooooooooooooogoooooooooo_ooooomomoooooooooooomonoooo_o_ooooooonooOoooooooo
ooooooooooooooooP0000?ooooooooooooogoooooooooo_ooooomol0000000000001onoooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?ooooooooooooogoooooooooo_ooooomooooooooooo
ooooonoooo_o_ooooooonooOooooooooooooooooooooooooP0000?ooooooooooooogoooooooooo_o
oooomoooooooooooooooonoooo_o_ooooooonooOooooooooooooooooooooooooP0000?oooooooooo
ooogoooooooooo_`oooomoooooooooooooooonoooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?ooooooooooooogocc]R=f8oo_1oooomoooooooooooooooonoooo_o_ooooooonooOoooooooo
ooooooooooooooooP0000?ooooooooooooogo]=]/UffooX3oooomoooooooooooooooonoooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?ooooooooooooogo_M]]mfnooP00000000000000000
0000000000?o_ooooooonooOooooooooooooooooooooooooP0000?ooooooooooooogo_M]/5f`ooX0
00000000000000000000000000?o_ooooooonooOooooooooooooooooooooooooP0000?oooooooooo
ooogo_M]]efgoo_Qoooomoooooooooooooooonoooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?ooooooooooooogoQQQR<40oo_`oooomoooooooooooooooonoooo_o_ooooooonooOoooooooo
ooooooooooooooooP0000?ooooooooooooogoooo_onooo_ooooomoooooooooooooooonoooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?ooooooooooooogoooo_onooo_ooooomooooooooooo
ooooonoooo_o_ooooooonooOooooooooooooooooooooooooP0000?ooooooooooooogoooooooooo_o
oooomoooooooooooooooonoooo_o_ooooooonooOoooooooooWh/lNN?ooooooooP0000?oooooooooo
ooogoooooooooo_ooooomol0000000000001onoooo_o_ooooooonooOoooooooooW`8L<<7oooooooo
P0000?ooooooooooooogoooooooooo_ooooomomoooooooooooomonoooo_o_ooooooonooOoooooooo
oWa99<T7ooooooooP0000?ooooooooooooogoooooooooo_ooooomomoooooooooooomonoooo_o_ooo
oooonooOoooooooooWh89l6?ooooooooP0000?ooooooooooooogoh=1P`@goo_ooooomomooooooooo
ooomonoooo_o_ooooooonooOoooooooooP@89<47ooooooooP0000?ooooooooooooogokeM^_GGoo_o
oooomomoooooooooooomonoooo_o_ooooooonooOoooooooooW`8L<<7ooooooooP0000?oooo`9VISo
`oogoke5^_@Goo_ooooomomoooooooooooomonoooo_o_ooooooonooOoooooooooWhLlNN?oooooooo
P0000?ooooW9VI9o1oogokei^_GGoo_ooooomomoooooooooooomonoooo_o_ooooooonooOoooooooo
oPOoooooooooooooP0000?ooooWYVI1h1oogoiU=/VFCoo_ooooomomoooooooooooomonoooo_o_ooo
oooonooOoooooooooPOoooooooooooooP0000?ooooWYVI1P0007ojMabiIaoo_ooooomomooooooooo
ooomonoooo_o_ooooooonooOooooooooooooooooooooooooP0000?ooooWXVI9h0007okmonoOooo_o
oooomomoooiLHiLoooomonoooo_o_ooooooonooOooooooooooooooooooooooooP0000?ooooWX61Sn
1oogokmonoOooo_ooooomomoookK[FC?ooomn6oooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?ooooW_ooooaoogoooooooooo_ooooomomoookO_GGoooomh>oooo_o_ooooooonooOoooooooo
ooooooooooooooooP0000?ooooW_WoooloogoooooonOoo_ooooomomoookHHg@?ooom0Noooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?ooooooooooooogooooooo_oo_ooooomomoookKkgG_
oool000000?o_ooooooonooOooooooooooonooooooooooooP0000?ooooooooooooogon7M]P__oo_o
oooomomoooaH8GHOooom000000?o_ooooooonooOooooooooooonOoooooooooooP0000?oooooooooo
ooogomgM]/_?oo_ooooomomoookooooooooml>oooo_o_ooooooonooOooooooooooonOooooooooooo
P0000?ooooooooooooogokkM]^_?oo_ooooomomoookOooooooomn6oooo_o_ooooooonooOoooooooo
oool?oooooooooooP0000?ooooooooooooogokkM]R^goo_ooooomomoooooooooooomonoooo_o_ooo
oooonooOoooooooooool?oooooooooooP0000?ooooooooooooogokkM]l^goo_ooooomomooooooooo
ooomonoooo_o_ooooooonooOoooooooooool?oooooooooooP0000?ooooooooooooogokkM]^Ucoo_o
oooomomoooooooooolOmonoooo_o_ooooooonooOoooooooooooh?oooooooooooP0000?oooooooooo
ooogokk5SaQkoo_ooooomomoooooooooooOmonoooo_o_ooooooonooOoooooooooooh7ooooooooooo
P0000?ooooooooooooogokkooooooo_ooooomomoPiK3_f<5^6?monoooo_o_ooooooonooOoooooooo
oooh7oooooooooooP0000?ooooooooooooogokkmoooooo_loooomomoNkKM_e]e]f_monooio_o_ooo
oooonooOooooooooooobSoooooooooooP0000?ooooooooooooogoooooooooo_1oooomomoOKK1_a]e
/4_monool7_o_ooooooonooOooooooooooofkoooooooooooP0000?ooooooooooooogoooooooooo^3
oooomomoOKKM_e]e]e_monoon3_o_ooooooonooOooooooooooonooooooooooooP0000?oooooooooo
ooogooooooooooP000001omoOKKI_d]T/eWl000000?o_ooooooonooOooooooooooonoooooooooooo
P0000?ooooooooooooogooooooooooX000001omoOA7WSg>4?=gl000000_o_ooooooonooOoooooooo
ooonooooooooooooP0000?ooooooooooooogoooooooooo^1oooomomo>kOoogogooomonool3_o_ooo
oooonooOooooooooooonooooooooooooP0000?ooooooooooooogoooooooooo_aoooomomoaoOoog_g
ooomonoolO_o_ooooooonooOooooooooooonooooooooooooP0000?ooooooooooooogoooooooooo_l
oooomomoooooooooooomonooio_o_ooooooonooOooooooooooonooooooooooooP0000?oooooooooo
ooogoooooooooo_ooooomomoooooooooooomonoooo_o_ooooooonooOooooooooooonoooooooooooo
P0000?ooooooooooooogoooooooooo_ooooomomoooooooooooomonoooo_o_ooooooonooOoooooooo
ooonooooooooooooP0000?ooooooooooooogoooooooooo_ooooomomoooooooooooomonoooo_o_ooo
oooonooOooooooooooonooooooooooooP0000?ooooooooooooogoooooooooo_ooooomomooooooooo
ooomonoooo_o_ooooooonooOooooooooooonooooooooooooP0000?ooooooooooooogoooooooooo_o
oooomomoooooooooooomonoooo_o_ooooooonooOooooooooooonooooooooooooP0000?oooooooooo
ooogoooooooooo_ooooomomoooooooooooomonoooo_o_ooooooonooOooooooooooonoooooooooooo
P0000?ooooooooooooogoooooooooo_ooooomomoooooooooooomonoooo_o_ooooooonooOoooooooo
ooonooooooooooooP0000?ooooooooooooogoooooooooo_ooooomomoooooooooooomonoooo_o_ooo
oooonooOooooooooooonooooooooooooP0000?ooooooooooooogoooooooooo_ooooomomooooooooo
ooomonoooo_o_ooooooonooOooooooooooonooooooooooooP0000?ooooooooooooo`0000000000?o
oooomol0000000000001onoooo_o_ooooooonooOooooooooooonooooooooooooP0000?oooooooooo
oooooooooooooooooooomoooooooooooooooonoooo_o_ooooooonooOooooooooooonoooooooooooo
P0000?oooooooooooooooooooooooooooooomoooooooooooooooonoooo_o_ooooooonooOoooooooo
ooonooooooooooooP0000?oooooooooooooooooooooooooooooomoooooooooooooooonoooo_o_ooo
oooonooOooooooooooonooooooooooooP0000?oooooooooooooooooooooooooooooomooooooooooo
ooooonoooo_o_ooooooonooOooooooooooonooooooooooooP0000?oooooooooooooooooooooooooo
oooomoooooooooooooooonoooo_o_ooooooonooOooooooooooonooooooooooooP0000?oooooooooo
oooooooooooooooooooomoooooooooooooooonoooo_o_ooooooonooOooooooooooonoooooooooooo
P0000?oooooooooooooooooooooooooooooomoooooooooooooooonoooo_o_ooooooonooOoooooooo
ooonooooooooooooP0000?oooooooooooooooooooooooooooooomoooooooooooooooonoooo_o_ooo
oooonooOooooooooooonooooooooooooP0000?oooooooooooooooooooooooooooooomooooooooon?
ooooonoooo_o_ooooooonooOooooooooooonooooooooooooP0000?oooooooooooooooooooooooooo
oooomooooooooon?ooooonoooo_o_ooooooonooOooooooooooonooooooooooooP0000?oooooooooo
oooooooooooooooooooomooooiiLYg?V7oooonoooo_o_ooooooonooOooooooooooonoooooooooooo
P0000?oooooooooooooooooooooooooooooomooooiaH9f7V3oooonoooo_o_ooooooonooOoooooooo
ooonooooooooooooP0000?oooooooooooooooooooooooooooooomooooicA9dG2Soooonoooo_o_ooo
oooonooOoooooh000000000000003oooP0000?oooooooooooooooooooooooooooooomoooohgCYd72
7oooonoooo_o_ooooooonooOoooookooooooooooooookoooP0000?oooooooooooooooooooooooooo
oooomooooh7A8d6J3oooonoooo_o_ooooooonooOoooookooooooooooooookoooP0000?oooooooooo
oooooooooooooooooooomooooi?H864h3oooonoooo_o_ooooooonooOoooookooooooooooooookooo
P0000?oooooooooooooooooooooooooooooomooooiWLX7<h7oooonoooo_o_ooooooonooOoooookoo
ooooooooooookoooP0000?oooooooooooooooooooooooooooooomooooicO_oooooooonoooo_o_ooo
oooonooOoooookooooooooooooookoooP0000?oooooooooooooooooooooooooooooomooooiiO_ooo
ooooonoooo_o_ooooooonooOoooookooooooooooooookoooP0000?oooooooooooooooooooooooooo
oooomoooooooooooooooonoooo_o_ooooooonooOoooookooooooooooooookoooP0000?oooooooooo
oooooooooooooooooooomoooooooooooooooonoooo_o_ooooooonooOoooookooooooooooooookooo
P0000?oooooooooooooooooooooooooooooomoooooooooooooooonoooo_o_ooooooonooOoooookoo
ooooooooooookoooP0000?oooooooooooooooooooooooooooooomoooooooooooooooonoooo_o_ooo
oooonooOoooookooooooooooooookoooP0000?ooooooooooooooooooooooooooooool00000000000
000000oooo_o_ooooooonooOoooookooooooooooooookoooP0000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooo_o_ooooooonooOoooookooooooooooooookoooP0000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooo_o_ooooooonooOoooookooooooooooooookooo
P0000?oooooooooooooooooooooooooooooooooooooooooooooooooooo_o_ooooooonooOoooookoo
ooooooooooookoooP0000?oooooooooooooooooooooooooooooooooooooooooooooooooooo_o_ooo
oooonooOoooookooooooooooooookoooP0000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooo_o_ooooooonooOoooookooooooooooooookoooP0000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooo_o_ol??F?onooOoooookobh/AnLKHc]V?okoooP0000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooo_o_oibcEgonooOoooookofk9GiY;K/]^gokooo
P0000?oooooooooooooooooooooooooooooooooooooooooooooooooooo_o_ognoGgonooOoooookof
k[gkk[K_]_gokoooP0000?oooooooooooooooooooooooooooooooooooooooooooooooooooo_o_ogn
3D?onooOoooookofh;gkk[KP]^?okoooP0000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooo_o_ognkEoonooOoooookofk[gkk[K^]^ookoooP0000?ool00000000000000000000000
000000000000000?oooooooooo_o_ogn7D7onooOooon7koR8<Al<HHQQ67okoooP0000?oomooooooo
ooooooooooooooooooooooooooooooo_oooooooooo_o_okkoGoonooOoooo1kogoogoookoo_ookooo
P0000?oomoooooooooooooooooooooooooooooooooooooo_oooooooo7o_o_ol7oGoonooOoooo0;og
oogoookoo_ookoooP0000?oomoooooooooooooooooooooooooooooooooooooo_oooooooo0o_o_ooo
oooonoo0000003ooooooooooooookoooP0000?oomoooooooooooooooooooooooooooooooooooooo_
ooooooooPO_o_ooooooonoo000000;ooooooooooooookoooP0000?oomooooooP0000000000000000
00000000000000000000000003_o_ooooooonooOoooo0kooooooooooooookoooP0000?oomooooooP
000000000000000000000000000000000000000007_o_ooooooonooOoooo7kooooooooooooookooo
P0000?oomooooonOooooooooooooooooooooooooooooooo_oooooooo0O_o_o1/>67onooOooonOkhN
24G3mM4<4KX5koooP0000?oomooooonOooooooooooooooooooooooooooooooo_oooooooo7o_o_oN[
]egonooOoooookg^kefkmMK_eK[ekoooP0000?oomooooonOooooooooooooooooooooooooooooooo_
ooooooooOo_o_oN[]egonooOoooookgf:5fj=MH>5KXekoooP0000?oomooooonOoooooooooooooooo
ooooooooooooooo_oooooooooo_o_oM[]egonooOoooookf7RmfkmMK]mK_5koooP0000?oomooooonO
ooooooooooooooooooooooooooooooo_oooooooooo_o_o1Y/dgonooOoooookgnjefKm=I]eIYekooo
P0000?oomooooonOooooooooooooooooooooooooooooooo_oooooooooo_o_oN^O?7onooOoooookgo
6<AWmC6N8JN=koooP0000?oomooooonOooooooooooooooooooooooooooooooo_oooooooooo_o_oN_
oogonooOoooookg_omooooOomoomkoooP0000?oomooooonOooooooooooooooooooooooooooooooo_
oooooooooo_o_o1_oogonooOoooookhOomoomoOomOomkoooP0000?oomooooonOoooooooooooooooo
ooo`000000000?o_oooooooooo_o_ooooooonooOoooookooooooooooooookoooP0000?oomon00000
00000000000000007oogooooooooo_o_oooooooooo_o_ooooooonooOoooookooooooooooooookooo
P0000?oomonooooooooookoooooooooogoogooooooooo_o_oooooooooo_o_ooooooonooOoooookoo
ooooooooooookoooP0000?oomonooooooooookoooooooooogoogooooooooo_o_oooooooooo_o_ogg
?UoonooOoooookooooooooooooookoooP0000?oomonooooooooookoooooooooogoogooooooooo_o_
oooooooooo_o_og^gIoonooOoooookooooooooooooookoooP0000?oomonooooooooookoooooooooo
googooooooooo_o_oooooooooo_o_ogNkMoonooOoooookooooooooooooookoooP0000?oomonooooo
oooookoooooooooogoogooooooooo_o_oooooooooo_o_ogN3MoonooOoooookooooooooooooookooo
P0000?oomonooooooooookoooooooooogoogooooooooo_o_oooooooooo_o_o`>kMoonooOoooookoo
ooooooooooookoooP0000?oomonooooooooookoooooooooogoogooooooooo_o_oooooooooo_o_ogf
gIoonooOoooookooooooooooooookoooP0000?oomonooooooooookoooooooooogoogooooooooo_o_
oooooooooo_o_ogg?UoonooOoooookooooooooooooookoooP0000?oomonooooooooookoooooooooo
glogooooooooo_o_ooooooooio_o_ogWomoonooOoooookooooooooooooookoooP0000?oomonooooo
oooookooooooon?ogn?gooooooooo_o_oooooooolO_o_o`OomoonooOoooookooooooooooooookooo
P0000?oomonooooooooookooooooomcogn1gooooooooo_o_ooooooool3_o_ooooooonooOoooookoo
ooooooooooookoooP0000?oomono_LK_i^ifgko`3^K/=g:ogn0Gooooooooo_o_oooooooon0_o_ooo
oooonooOoooookooooooooooooookoooP0000?oomono^I[_f@Vfokogl=[[]dco`007oooooooooP00
0000000000?o_ooooooonooOoooooh000000000000003oooP0000?oomono^K[Xgi_fokognMk[]eko
gn1gooooooooo_o_oooooooon3_o_ooooooonooOooooooooooooooooooooooooP0000?oomono]K[_
`I_fokognMk/=ekogn7go3UM`iioo_o_ooooooool?_o_ooooooonooOoooooooooooooooooooooooo
P0000?oomono]K[_gI_foko`>Mk[]ekoglognkIM^ffoo_o_ooooooooio_o_ooooooonooOoooooooo
ooooooooooooooooP0000?oomono[MY_ffffokogm]Y]/fcogoogmmMM^_gOo_o_oooooooooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?oomonoWLJOi^iaokogk^HN=?;ogoogomMMR_`Oo_o_
oooooooooo_o_ooooooonooOooooooooooooooooooooooooP0000?oomono_Oooooogokogookooooo
googocMMl_gOo_o_oooooooooo_o_ooooooonooOooooooooooooooooooooooooP0000?oomono_Ooo
ooogoko`7okooooogoogn?M=VVfOo_o_oooooooooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?oomonooooooooookoooooooooogoogmoMDHiioo_o_oooooooooo_o_ooooooonooOoooooooo
ooooooooooooooooP0000?oomonooooooooonKoooooooooogoogliomooooo_o_oooooooooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?oomonooooooooohkoooooooooogoogo3onOoooo_o_
oooooooooo_o_ooooooonooOooooooooooooooooooooooooP0000?oomonooooooooo0koooooooooo
googooooooooo_o_oooooooooo_o_ooooooonooOooooooooooooooooooooooooP0000?oomonooooo
oool0koooooooooogoogooooooooo_o_oooooooooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?oomonoooooooo`0001oooooooogoogooooooooo_o_oooooooooo_o_ooooooonooOoooooooo
ooooooooooooooooP0000?oomonooooooooo0koooooooooogoogNl<NN>ER__o_oooooooooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?oomonooooooooo`koooooooooogoogNk]]^]UL__o_
oooooooooo_o_ooooooonooOooooooooooooooooooooooooP0000?oomonooooooooohKoooooooooo
googNk]eemeN__o_oooooooooo_o_ooooooonooOooooooooooooooooooooooooP0000?oomonooooo
oooookoooooooooogoogNl]d5meV__o_oooooooooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?oomonooooooooookoooooooooogoogNk=eemeH__o_oooooooooo_o_ooooooonooOoooooooo
ooooooooooooooooP0000?oomonooooooooookoooooooooogoogNM]]^]e^W_o_oooooooooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?oomonooooooooookoooooooooogoogN^<NN=ea[_o_
oooooooooo_o_ooooooonooOooooooooooooooooooooooooP0000?oomonooooooooookoooooooooo
googOomooomoo_o_oooooooooo_o_ooooooonooOooooooooooooooooooooooooP0000?oomonooooo
oooookoooooooooognod3omooomoo_l_oooooooooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?oomonooooooooookoooooooooog`ogooooooooo_a_oooooooooo_o_ooooooonooOoooooooo
ooooooooooooooooP0000?oomonooooooooookoooooooooog0ogooooooooo_1_oooooooooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?oomonooic01``@I0?ll<PBKQoo`1ogoooooooooX1_
oooooooooo_o_ooooooonooOooooooooooooooooooooooooP0000?oomonooic=4RRFI9?lhTTBK5oo
`007oooooooooP000000000000?o_ooooooonooOoooooh000000000000003oooP0000?oomonooic1
<PWgI1?hITVBK1oo`007oooooooooX000000000000?o_ooooooonooOoooookooooooooooooookooo
P0000?oomonooica<PWgIa?c9TVBK1oogPogooooooooo_Q_oooooooooo_o_ooooooonooOoooookoo
ooooooooooookoooP0000?oomonooi`10PPGI13c84V@31oog`ogooooooooo_`_oooooooooo_o_ooo
oooonooOoooookooooooooooooookoooP0000?oomonooi`Q1ihgIS3g^<V@Scoogoogooooooooo_o_
oooooooooo_o_ooooooonooOoooookooooooooooooookoooP0000?oomonoo0?o?oooikoWWloooooo
googooooooooo_o_oooooooooo_o_ooooooonooOoooookooooooooooooookoooP0000?oomonoo0?o
?oooikoWWloooooogoogooooooooo_o_oooooooooo_o_ooooooonooOoooookooooooooooooookooo
P0000?oomonooooooooookoooooooooogoogooooooooo_o_oooooooooo_o_ooooooonooOoooookoo
ooooooooooookoooP0000?oomonooooooooookoooooooooogoogooooooooo_o_oooooooooo_o_ooo
oooonooOoooookooooooooooooookoooP0000?oomonooooooooookoooooooooogoogooooooooo_o_
oooooooooo_o_ooooooonooOoooookooooooooooooookoooP0000?oomonooooooooookoooooooooo
googooooooooo_o_oooooooooo_o_ooooooonooOQooookooooooooooooookoooP0000?oomonooooo
oooookoooooooooogoo`000000000?o_oooooooooo_o_ooooooonooN3ooookoooo1MlgoOooookooo
P0000?oomon0000000000000000000007oooooooooooooo_oooooooooo_o_ooooooonoo07ooookoo
ooOHcGoOooookoooP0000?oomoooooooooooooooooooooooooooooooooooooo_oooooooooo_o_ooo
oooonoo0000003ooooOJggoOooookoooP0000?oomoooooooooooooooooooooooooooooooooooooo_
oooooooo?o_o_ooooooonoo0000003ooooOJ`GoOooWokoooP0000?oomooooooooooooooooooooooo
ooooooooooooooo_ooooooooSo_o_ooooooonooO3ooookooooOJgGoOooWokoooP0000?oomooooooo
ooooooooooooooooooooooooooooooo_ooooooooP?_o_ooooooonooOQooookooooOGHAmOooWokooo
P0000?oomoooooooooooooooooooooooooooooooooooooo_oooooooo`3_o_ooooooonooOoooookoo
ooOooonOooWokoooP0000?oomooooooP000000000000000000000000000000000000000001_o_ooo
oooonooOoooookooooOooonOooWokoooP0000?oomooooooP00000000000000000000000000000000
0000000003_o_ooooooonooOoooookooooOOoooOooWokoooP0000?oomoooooo_oooooooooooooooo
ooooooooooooooo_ooooooooPo_o_ooooooonooOoooookooooooooooooWokoooP0000?oomoooooo_
ooooooooooooooooooooooooooooooo_oooooooo3o_o_ooooooonooOoooookooooooooooooWokooo
P0000?oomoooooo_ooooooooooooooooooooooooooooooo_oooooooooo_o_ooooooonooOooonOkoo
ooooooooooWokoooP0000?oomoooooo_ooooooooooooooooooooooooooooooo_oooooooooo_o_ooo
oooonooOoooo1kooooooooooooWokoooP0000?oomoooooo_ooooooooooooooooooooooooooooooo_
oooooooooo_o_ooooooonooOoooo0kooooooooooooWokoooP0000?oomon000000000000000000000
7oool00000000?o_oooooooooo_oP00000000oo0000000000000000000003oooP0000?oomonooooo
oooookoooooooooogooomoooooooo_o_oooooooooo_ooogoooooooo000000;ooooooooooooWokooo
P0000?oomonooooooooookoooooooooogooomoooooooo_o_oooooooooo_ooogooooooooOoooo0koo
ooooooooooWokoooP0000?oomonooooooooookoooooooooogooomoooooooo_o_oooooooooo_ooogo
oonooooOoooo3kooooooooooooWokoooP0000?oomonooooooooookoooooooooogooomoooooooo_o_
oooooooooo_ooogooonOoooOooonOkooooooooooonVokoooP0000?oomonooooooooookoooooooooo
gooomoooooooo_o_oooooooooo_ooogooonOoooOoooookooooooooooon0okoooP0000?oomonooooo
oooookoooooooooogooomoooooooo_o_oooooooooo_ooogoool?oooOoooookooooooooooon0okooo
P0000?oomonooooooooookoooooooooogooomoooooooo_o_oooooooooo_ooogoool?oooOoooookoo
ooooooooon0okoooP0000?oomonooooooooookoooooooooogooomoooooooo_o_oooooooooo_ooogo
ooh?oooOoooookoooooooooooo1okoooP0000?oomonooooooooookoooooooooogooomoooooooo_o_
oooooooooo_ooogooo`7oooOoooookooon2kigh?oo1okoooP0000?oomonooooooooookoooooooooo
goo?moooooooo_o_ooooooooio_ooogooo`7oooOiooookooonnkfgkoooSokoooP0000?oomonooooo
oooookooooooon3ogooPmoooooooo_o_ooooooool7_ooogooo`3oooN3ooookooonni_GloooSokooo
P0000?oomonooooooooookooooooookogooPMoooooooo_o_oooooooon3_ooogooofkoooL7ooookoo
onniPGnoooSokoooP0000?oomonnnifocMSM_koh1g=^6g3OgooP5oooooooo_o_oooooooon0_ooogo
oonoooo07ooookooonnf_GoOoogokoooP0000?oomonnlfFo=;;Mokokn/e]VfKo`0001ooooooooP00
0000000000?ooogooonoooo0000003ooonnVVGo?oogokoooP0000?oomonnlgFQO[OMokokn]m]ffko
gooPMoooooooo_o_oooooooon3_ooogooonooooL7ooookooonn^iao_ooookoooP0000?oomonnbgFo
1SOMokokn=m^6fkogooQmn73MRiao_o_ooooooool?_ooogooonooooO3ooookooonooook?ooookooo
P0000?oomonnfgFoM[OMokoh6]m]ffkogoo?mnkCM/ffo_o_ooooooooio_oongOoonooooOiooookoo
onnooolOooookoooP0000?oomonn^``oQIS1okoklV4>673ogooommmKM^g^o_o_oooooooooo_oon0O
oonooooOoooookooooooooooooookoooP0000?oomonn^ooooooOokokoomooooogooomomKMRgPo_o_
oooooooooo_ooo0ooonooooOoooookooooooooooooookoooP0000?oomonnNooooooOokoh3omooooo
gooomn3KMXg^o_o_oooooooooo_ooo0ooonooooOoooookooooooooooooookoooP0000?oomonooooo
oooookoooooooooogooomnoKM^ffo_o_oooooooooo_ooo1ooonooooOoooookooooooooooooookooo
P0000?oomonooooooooookoooooooooogooommoK2aiao_o_oooooooooo_ooo1ooonooooOoooookoo
ooooooooooookoooP0000?oomonooooooooonKoooooooooogooomliomoooo_o_oooooooooo_oooQo
oonooooOoooookooooooooooooookoooP0000?oomonooooooooohkoooooooooogooomn7onoooo_o_
oooooooooo_ooocooonooooOoooookooooooooooooookoooP0000?oomonooooooooo0koooooooooo
gooomoooooooo_o_oooooooooo_ooocooonooooOoooookooooooooooooookoooP0000?oomonooooo
oool0koooooooooogooomoooooooo_o_oooooooooo_ooogooonooooOoooooh000000000000003ooo
P0000?oomonoooooooo`0001oooooooogooomoooooooo_o_oooooooooo_ooogooooooooOoooooooo
ooooooooooooooooP0000?oomonooooooooo0koooooooooogooomo3cN?<Eo_o_oooooooooo_ooooo
oooooooOooooooooooooooooooooooooP0000?oomonooooooooo`koooooooooogooomnm=N/eUo_o_
oooooooooo_ooooooooooooOooooooooooooooooooooooooP0000?oomonooooooooonKoooooooooo
gooommoMN]meo_o_oooooooooo_ooooooooooooOooooooooooooooooooooooooP0000?oomonooooo
oooookoooooooooogooommoMN]l5o_o_oooooooooo_ooooooooooooOoooooooooooooooooooooooo
P0000?oomonooooooooookoooooooooogooommoMN]meo_o_oooooooooo_ooooooooooooOoooooooo
ooooooooooooooooP0000?oomonooooooooookoooooooooogooommo]>^eeo_o_oooooooooo_oo_k3
SKL?oooOooooooooooooooooooooooooP0000?oomonooooooooookoooooooooogooomlmc@?>=o_o_
oooooooooo_oo_jkKKK_oooOooooooooooooooooooooooooP0000?oomonooooooooookoooooooooo
gooomnmonoomo_o_oooooooooo_oo_jkkKK_oooOooooooooooooooooooooooooP0000?oomonooooo
oooookoooooooooog`oomo3oo_omo_`_oooooooooo_ooPK33KL?oooOQooooooooooooooooooooooo
P0000?oomonooon7S>;SR[ilIPTcWooog0oomoooooooo_1_oooooooooo_oo_JkOKK_oooN3ooooooo
ooooooooooooooooP0000?oomonoool11>;10[i`90Tb3ooo`1oomooooooooX1_oooooooooo_oo_[3
30L?ooo07oooooooooooooooooooooooP0000?oomonoooikM>kO4[`cY<TbOooo`0001ooooooooP00
0000000000?oo_[oooooooo0000000000000ooooooooooooP0000?oomonoooioM>kOP[`CY<Tb3ooo
`0001ooooooooX000000000000?ooPKoooooooo0000000000000ooooooooooooP0000?oomonoooio
96k9<[fA9<TBKooogPoomoooooooo_Q_oooooooooo_ooooooooooooO3oooooooooonoooooooooooo
P0000?oomonoooio10;10[fH9<P33ooog`oomoooooooo_a_oooooooooo_ooooooooooooOSooooooo
ooonooooooooooooP0000?oomonooohaS8;SQ[WLI<QWWooognoomoooooooo_l_oooooooooo_ooooo
oooooooOioooooooooonooooooooooooP0000?oomonoool3onkoo[??iooooooogooomoooooooo_o_
oooooooooo_ooooooooooooOooooooooooonooooooooooooP0000?oomonooon7onkoo[??iooooooo
gooomoooooooo_o_oooooooooo_ooooooooooooOooooooooooonooooooooooooP0000?oomonooooo
oooookoooooooooogooomoooooooo_o_oooooooooo_ooooooooooooOooooooooooonoooooooooooo
P0000?oomonooooooooookoooooooooogooomoooooooo_o_oooooooooo_ooooooooooooOoooooooo
ooonooooooooooooP0000?oomonooooooooookoooooooooogooomoooooooo_o_ooooooooOo_ooooo
oooooooOooooooooooonooooooooooooP0000?oomonooooooooookoooooooooogooomoooooooo_o_
oooooooo0o_ooooooooooooOooooooooooonooooooooooooP0000?oomonooooooooookoooooooooo
gooomoooooooo_o_ooooooooPO_ooooooooooooOooooooooooonooooooooooooP0000?oomon00000
00000000000000007oool00000000?o_oh00000003_ooooooooooooOooooooooooonoooooooooooo
P0000?oomoooooooooooooooooooooooooooooooooooooo_oh00000007_oooooooooooo000000003
ooonooooooooooooP0000?oomoooooooooooooooooooooooooooooooooooooo_ocooooooPO_ooooo
ooooooo000000001ooonooooooooooooP0000?oomoooooooooooooooooooooooooooooooooooooo_
ocoooooo1o_ooooooooooooOoooooooiooonooooooooooooP0000?oomooooooooooooooooooooooo
ooooooooooooooo_ocooooooOo_ooooooooooooOoooooooiooonooooooooooooP0000?oomooooooo
ooooooooooooooooooooooooooooooo_ocoooooooo_ooooooooooooOoooooooiooonoooooooooooo
P0000?oomoooooooooooooooooooooooooooooooooooooo_ocoooooooo_ooooooooooooOoooooooi
ooonooooooooooooP0000?oomn39Q<<@C?ooooooooooooooooooooooooooooo_ocoooooooo_ooooo
oooooooOoooooooiooonooooooooooooP0000?oomlA;=<TRC?ooooooooooooooooooooooooooooo_
ocoooooooo_ooooooooooooOoooooooiooonooooooooooooP0000?oomla31<4WC?oooooooooooooo
ooooooooooooooo_ocooiooooo_ooooooooooooOoooooooiooonooooooooooooP0000?oomo331<4W
C?ooooooooooooooooooooooooooooo_ocooiooooo_ooooooooooooOoooooooiooonoooooooooooo
P0000?oomn73==TRA?ooooooooooooooooooooooooooooo_ocooh00000_ooooooooooooOoooooooi
ooonooooooooooooP0000?oomlI9Q<8@@?ooooooooooooooooooooooooooooo_ocooh00000_ooooo
oooooooOoooooooiooonooooooooooooP0000?oomla?o?loooooooooooooooooooooooooooooooo_
ocooiooooo_ooooooooooooOoooooooiooonooooooooooooP0000?oomn3?o?looooooooooooooooo
ooooooooooooooo_ocooioooooP000000000000OoooooooiooonooooooooooooP0000?oomooooooo
ooooooooooooooooooooooooooooooo_ocooiooooooooogooonooooooooooooiooonoooooooooooo
P0000?oomoooooooooooooooooooooooooooooooooooooo_ocooiooooooooogooolooooooooooooi
ooonooooooooooooP0000?oomoooooooooooooooooooooooooooooooooooooo_ocooiooooooooogo
oolooooooooooooiooonooooooooooooP0000?oomoooooooooooooooooooooooooooooooooooooo_
ocooiooooooooogooohOoooooooooooiooonooooooooooooP0000?oomooooooooooooooooooooooo
ooooooooooooooo_ocooiooooooooogooohOoooooooooooiooonooooooooooooP0000?ool0000000
0000000000000000000000000000000?ocooiooooooooogooo`?oooooooooooiooonoooooooooooo
P0000?ooooooooooooooooooooooooooooooooooooooooooocooiooooooooogooo`?oooooooooooi
ooonooooooooooooP0000?ooooooooooooooooooooooooooooooooooooooooooocooiooooooooogo
oo`?oooooooooooiooonooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooo
ocooiooooooooogoooP7oooooooooooiooonooooooooooooP0000?oooooooooooooooooooooooooo
ooooooooooooooooocooiooooooooogooo/goooooooooooiooonooooooooooooP0000?oooooooooo
ooooooooooooooooooooooooooooooooocooiooooooooogooolooooooooooooiooonoooooooooooo
P0000?ooooooooooooooooooooooooooooooooooooooooooocooiooooooooogooolooooooooooooi
ooonooooooooooooP0000?ooooooooooooooooooooooooooooooooooooooooooocooiooooooooogo
oolooooooooooooiooonooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooo
ocooiooooooooogooolooooooooooooiooonooooooooooooP0000?oooooooooooooooooooooooooo
ooooool000000000000000000000000000000000000000000000000000003oooP0000?oooooooooo
oooooooooooooooooooooomoooooooooocoo1?ooooooongOoolooooooooooooI_oonooooooookooo
P0000?oooooooooooooooooooooooooooooooomoooooooooocooPOooooooonDOooloooooooooooo1
?oonooooooookoooP0000?oooooooooooooooooooooooooooooooomoooooooooocooPOoooooooo0o
oolooooooooooooP?oonooooooookoooP0000?oooooooooooooooooooooooooooooooomooooooooo
ocoo`Ooooooooo0ooolooooooooooooP?oonooooooookoooP0000?oooooooooooooooooooooooooo
oooooomoooooooooocoo`Ooooooooo1oooloooooooooooo`OoonooooooookoooP0000?oooooooooo
oooooooooooooooooooooomoooooooooocoo`ooooooooo1oooloooooooooooo`Ooonooooooookooo
P0000?oooooooooooooooooooooooooooooooomoooooooooocoo`oooooooooQoooloooooooooooo`
ooonooooooookoooP0000?oooooooooooooooooooooooooooooooomoooooooooocooioooooooooco
ooloooooooooooohooonooooooookoooP0000?oooooooooooooooooooooooooooooooomooooooooo
ocooiooooooooocoooloooooooooooohooonooooooookoooP0000?oooooooooooooooooooooooooo
oooooomoooooooooocoomooooooooogoooloooooooooooomooonooooooookoooP0000?oooooooooo
oooooooooooooooooooooomon0000000000000oooo0000000000000Oooo00000000000007oookooo
P0000?oooooooooooooooooooooooooooooooomonoooooooooooonooooOooooooooooooOoooOoooo
oooooooogoookoooP0000?oooooooooooooooooooooooooooooooomonoooooooooooonooooOooooo
oooooooOoooOoooooooooooogoookoooP0000?oooooooooooooooooooooooooooooooomonooooooo
ooooonooooOooooooooooooOoooOoooooooooooogoookoooP0000?oooooooooooooooooooooooooo
oooooomonoooooooooooonooooOooooooooooooOoooOoooooooooooogoookoooP0000?oooooooooo
oooooooooooooooooooooomonoooooooooooonooooOooooooooooooOoooOoooooooooooogoookooo
P0000?oooooooooooooooooooooooooooooooomonoooooooooooonooooOooooooooooooOoooOoooo
oooooooogoookoooP0000?oooooooooooooooooooooooooooooooomonoooooooooooonooooOooooo
oooooooOoooOoooooooooooogoookoooP0000?oooooooooooooooooooooooooooooooomonooooooo
o_oooNooooOooooooooooooOoooOoooooooooooogoookoooP0000?oooooooooooooooooooooooooo
oooooomonooooooooOooo^ooooOooooooogooogOoooOooooooonoookgoookoooP0000?oooooooooo
oooooooooooooooooooooomoni3M^?O>oL?_c^ooooOooooooogoookOoooOooooooomooomgoookooo
P0000?oooooooooooooooooooooooooooooooomonkCM^gNfoMg_]fooooOooooooogoookOoooOoooo
ooomooomgoookoooP0000?oooooooooooooooooooooooooooooooomonkKM]g=joKk_MfooooL1fk3g
SOV3gmkOoooMhb6g;3KiPMh<goookoooP0000?oooooooooooooooooooooooooooooooomonkKM]g<2
oOk_MfooooM]fkM[MO^mgmkOoooMgFjgJmKk_MnngoookoooP0000?oooooooooooooooooooooooooo
oooooomonkKM]fejoL7_MfooooM]fkM[1O_mgmkOoooM`F2gJmKkoMnNgoookoooP0000?oooooooooo
oooooooooooooooooooooomonkK<^effoMo_MfooooM]fkMKMO_cgmkOoooMgFjgJmKklMo^goookooo
P0000?oooooooooooooooooooooooooooooooomonaKD>=g>?Kk_M^ooooM]bKII9?^?gmkOoooMbFbG
JIKkQmo^goookoooP0000?oooooooooooooooooooooooooooooooomonkoooooooMg_]^ooooL=`WWM
SGfogekOoooLH[66[W7m_mo]goookoooP0000?oooooooooooooooooooooooooooooooomonooooooo
o/<3cNooooMooooooofigikOoooOogooOoom_Mi]goookoooP0000?oooooooooooooooooooooooooo
oooooomonoooooooooooonooooOooooooog20mgOoooOooookoon``>;goookoooP0000?oooooooooo
oooooooooooooooooooooomonoooookoooooonooooOooooooooooooOoooOoooooooooooogoookooo
P0000?oooooooooooooooooooooooooooooooomonoooookoooooonooooOooooooooooooOoooOoooo
oooooooogoookoooP0000?oooooooooooooooooooooooooooooooomonoooNhHKUoooonooooOooooo
oooooooOoooOoooooooooooogoookoooP0000?oooooooooooooooooooooooooooooooomonoooLgIZ
IoooonooooO]fLgK^NFRW?oOoooOoklgH/KW;SoogoookoooP0000?oooooooooooooooooooooooooo
oooooomonoooMgKZmoooonooooO]fkGK]]V/^goOoooOokkGK=KJcMoogoookoooP0000?oooooooooo
oooooooooooooooooooooomonooo1hKZmoooonooooO]fgGK[ef^]goOoooOokgGK[jjkmoogoookooo
P0000?oooooooooooooooooooooooooooooooomonoooNgKZmoooonooooO]f`GKX5fR/7oOoooOok`G
H[jjkSoogoookoooP0000?oooooooooooooooooooooooooooooooomonoooNhH;1oooonooooO]fgGK
[efX]goOoooOokgGJ;jjkOoogoookoooP0000?oooooooooooooooooooooooooooooooomonoooNooo
moooonooooO/fkCI]]V^^goOoooOokkCK]KJkMoogoookoooP0000?oooooooooooooooooooooooooo
oooooomonooo0ookmoooonooooO]<Le2NNFa7?oOoooOokldlLKVkSoogoookoooP0000?oooooooooo
oooooooooooooooooooooomonoooooooooooonooooO_nooooogo_ooOoooOokoooooooooogoookooo
P0000?oooooooooooooooooooooooooooooooomonoooooooooooonooooO_oooooofooooOoooOoPOo
ookooooogoookoooP0000?oooooooooooooooooooooooooooooooomonoooooooooooonooooOooooo
oooooooOoooOoooooooooooogoookoooP0000?oooooooooooooooooooooooooooooooomonooooooo
ooooonooooOooooooooooooOoooOoooooooooooogoookoooP0000?oooooooooooooooooooooooooo
oooooomonoooooooooooonooooOooooooooooooOoooOoooooooooooogoookoooP0000?oooooooooo
oooooooooooooooooooooomonoooooooooooonooooOooooooooooooOoooOoooooooooooogoookooo
P0000?oooooooooooooooooooooooooooooooomonoooooooooooonooooOooooooooooooOoooOoooo
oooooooogoookoooP0000?oooooooooooooooooooooooooooooooomonoooooooooooonooooOooooo
oooooooOoooOoooooooooooogoookoooP0000?oooooooooooooooooooooooooooooooomon0000000
000000oooo0000000000000Oooo00000000000007oookoooP0000?oooooooooooooooooooooooooo
oooooomoooooooooooooooooooooooooooooooooooooooooooooooooooookoooP0000?oooooooooo
oooooooooooooooooooooomoooooooooooooooooooooooooooooooooooooooooooooooooooookooo
P0000?oooooooooooooooooooooooooooooooomooooooooooooooooooooooooooooooooooooooooo
ooooooooooookoooP0000?oooooooooooooooooooooooooooooooomooooooooooooooooooooooooo
ooooooooooooooooooooooooooookoooP0000?oooooooooooooooooooooooooooooooomooooooooo
ooooooooooooooooooooooooooooooooooooooooooookoooP0000?oooooooooooooooooooooooooo
oooooomooooooooooooooooooo7`kW?`hIWbHHL7>7ooooooooooooooooookoooP0000?oooooooooo
oooooooooooooooooooooomoooooooooooooooooon1Pj1?P`97R@@8443ooooooooooooooooookooo
P0000?oooooooooooooooooooooooooooooooomoooooooooooooooooolmTjO?hc9?VLL9ToSoooooo
ooooooooooookoooP0000?oooooooooooooooooooooooooooooooomoooooooooooooooooolmTj1?P
c9?V@@IT47ooooooooooooooooookoooP0000?oooooooooooooooooooooooooooooooomooooooooo
ooooooooolmTJI7Vc9?VCC9TdcooooooooooooooooookoooP0000?oooooooooooooooooooooooooo
oooooomoooooooooooooooooolm0333Ph@7R@@9V43ooooooooooooooooookoooP0000?oooooooooo
oooooooooooooooooooooomooooooooooooooooooli0SW3`h@7RHHIW>7ooooooooooooooooookooo
P0000?oooooooooooooooooooooooooooooooomoooooooooooooooooon1Toooooh?VOooooooooooo
ooooooooooookoooP0000?oooooooooooooooooooooooooooooooomooooooooooooooooooo7doooo
ol?fOoooooooooooooooooooooookoooP0000?oooooooooooooooooooooooooooooooomooooooooo
ooooooooooooooooooooooooooooooooooooooooooookoooP0000?oooooooooooooooooooooooooo
oooooomoooooooooooooooooooooooooooooooooooooooooooooooooooookoooP0000?oooooooooo
oooooooooooooooooooooomoooooooooooooooooooooooooooooooooooooooooooooooooooookooo
P0000?oooooooooooooooooooooooooooooooomooooooooooooooooooooooooooooooooooooooooo
ooooooooooookoooP0000?ooooooooooooooooooooooooooooooool0000000000000000000000000
00000000000000000000000000003oooP0000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooP00000<0000000004@0000`0000800002`000100001Y0@000`4000T0000@0000
J@4000<10009000040000242001ho_oo2P00010000000000000004d0003LKP0000000000001X0@00
0P400000000000008@8007SnoolP0<`0000000000000080o000000000000080o00000000003oool0
000006`0000`0000W000041^000Q0P00R04002P0000Q0P00R04000400@000000@6h0000000000000
0000000000000000oooo0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
ooool00000000000000000ooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooomoooooooooooooooonooooP000000000000Ooooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooomoooooooooooooooonoooo_ooooooooooooOoooooooo
ooooooooooooooooP0000?oooooooooooooooooooooooooooooomoooooooooooooooonoooo_ooooo
oooooooOooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooomooooooooooo
ooooonoooo_ooooooooooooOooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
oooomoooooooooooooooonoooo_ooooooooooooOooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooomoooooooooooooooonoooo_ooooooooooooOoooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooomoooooooooooooooonoooo_ooooooooooooOoooooooo
ooooooooooooooooP0000?oooooooooooooooooooooooooooooomoooooooooooooooonoooo_ooooo
oooooooOooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooomooooooooooo
ooooonoooo_ooooooooooooOooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
oooomoooooooooooooooonoooo_ooooooooooooOooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooomoooooooooooooooonoooo_ooooooooooooOoooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooomoooooooooooooooonoooo_ooooooooooooOoooooooo
ooooooooooooooooP0000?oooooooooooooooooooooooooooooomoooooooooooooooonoooo_ooooo
oooooooOooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooomol000000000
0001onoooo_oP00000000ooOooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
oooomomoooooooooooomonoooo_o_ooooooonooOooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooomomoooooooooooomonoooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooomomoooooooooooomonoooo_o_ooooooonooOoooooooo
ooooooooooooooooP0000?oooooooooooooooooooooooooooooomomoooooooooooomonoooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooomomooooooooo
ooomonoooo_o_ooooooonooOooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
oooomomoooooooooooomonoooo_o_ooooooonooOooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooomomooooooinoooomonoooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooomomoooooomnoooomonoooo_o_ooooooonooOoooooooo
ooooooooooooooooP0000?oooooooooooooooooooooooooooooomomohMef:mnW53_moVoooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooomomok]efblnJ
iK_mn>oooo_o_ooooooonooOooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
oooomomog]efjlnjmK_m`>oooo_o_ooooooonooOooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooomomog]ef:kNk=K_m0Noooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?ooooooooooooo`0000000000?ooooomomog]efRcNjaK_l000000?o_ooooooonooOoooooooo
ooooooooooooooooP0000?ooooooooooooogoooooooooo_ooooomomog/dfjGNKMI_m`Noooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?ooooooooooooogoooooooooo_ooooomomog]E?6WNW
S0Oml>oooo_o_ooooooonooOooooooooooooooooooooooooP0000?ooooooooooooogoooooooooo_o
oooomomog_oooooooKomoVoooo_o_ooooooonooOooooooooooooooooooooooooP0000?oooooooooo
ooogoooooooooo_ooooomomog_gooooookomonoooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?ooooooooooooogoooooooooo_ooooomomoooooooooooomonoooo_o_ooooooonooOoooooooo
ooooooooooooooooP0000?ooooooooooooogoooooooooo_ooooomomoooooooooooomonoooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?ooooooooooooogoooooooooo_ooooomomooooooooo
ooomonoooo_o_ooooooonooOooooooooooooooooooooooooP0000?ooooooooooooogoooooooooo_o
oooomomoooooooooooomonoooo_o_ooooooonooOooooooooooooooooooooooooP0000?oooooooooo
ooogoooooooooo_ooooomomoooooooooooomonoooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?ooooooooooooogoooooooooo_ooooomomoooooooooooomonoooo_o_ooooooonooOoooooooo
ooooooooooooooooP0000?ooooooooooooogoooooooooo_ooooomomoooooooooooomonoooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?ooooooooooooogoooooooooo_ooooomomooooooooo
ooomonoooo_o_ooooooonooOooooooooooooooooooooooooP0000?ooooooooooooogoooooooooo_o
oooomol0000000000001onoooo_o_ooooooonooOooooooooooooooooooooooooP0000?oooooooooo
ooogoooooooooo_ooooomoooooooooooooooonoooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?ooooooooooooogoooooooooo_ooooomoooooooooooooooonoooo_o_ooooooonooOoooooooo
ooooooooooooooooP0000?ooooooooooooogoooooooooo_`oooomoooooooooooooooonoooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?ooooooooooooogocc]R=f8oo_1oooomooooooooooo
ooooonoooo_o_ooooooonooOooooooooooooooooooooooooP0000?ooooooooooooogo]=]/UffooX3
oooomoooooooooooooooonoooo_o_ooooooonooOooooooooooooooooooooooooP0000?oooooooooo
ooogo_M]]mfnooP000000000000000000000000000?o_ooooooonooOoooooooooooooooooooooooo
P0000?ooooooooooooogo_M]/5f`ooX000000000000000000000000000?o_ooooooonooOoooooooo
ooooooooooooooooP0000?ooooooooooooogo_M]]efgoo_Qoooomoooooooooooooooonoooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?ooooooooooooogoQQQR<40oo_`oooomooooooooooo
ooooonoooo_o_ooooooonooOooooooooooooooooooooooooP0000?ooooooooooooogoooo_onooo_o
oooomoooooooooooooooonoooo_o_ooooooonooOooooooooooooooooooooooooP0000?oooooooooo
ooogoooo_onooo_ooooomoooooooooooooooonoooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?ooooooooooooogoooooooooo_ooooomoooooooooooooooonoooo_o_ooooooonooOoooooooo
oWh/lNN?ooooooooP0000?ooooooooooooogoooooooooo_ooooomol0000000000001onoooo_o_ooo
oooonooOoooooooooW`8L<<7ooooooooP0000?ooooooooooooogoooooooooo_ooooomomooooooooo
ooomonoooo_o_ooooooonooOoooooooooWa99<T7ooooooooP0000?ooooooooooooogoooooooooo_o
oooomomoooooooooooomonoooo_o_ooooooonooOoooooooooWh89l6?ooooooooP0000?oooooooooo
ooogoh=1P`@goo_ooooomomoooooooooooomonoooo_o_ooooooonooOoooooooooP@89<47oooooooo
P0000?ooooooooooooogokeM^_GGoo_ooooomomoooooooooooomonoooo_o_ooooooonooOoooooooo
oW`8L<<7ooooooooP0000?oooo`9VISo`oogoke5^_@Goo_ooooomomoooooooooooomonoooo_o_ooo
oooonooOoooooooooWhLlNN?ooooooooP0000?ooooW9VI9o1oogokei^_GGoo_ooooomomooooooooo
ooomonoooo_o_ooooooonooOoooooooooPOoooooooooooooP0000?ooooWYVI1h1oogoiU=/VFCoo_o
oooomomoooooooooooomonoooo_o_ooooooonooOoooooooooPOoooooooooooooP0000?ooooWYVI1P
0007ojMabiIaoo_ooooomomoooooooooooomonoooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?ooooWXVI9h0007okmonoOooo_ooooomomoooiLHiLoooomonoooo_o_ooooooonooOoooooooo
ooooooooooooooooP0000?ooooWX61Sn1oogokmonoOooo_ooooomomoookK[FC?ooomn6oooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?ooooW_ooooaoogoooooooooo_ooooomomoookO_GGo
ooomh>oooo_o_ooooooonooOooooooooooooooooooooooooP0000?ooooW_WoooloogoooooonOoo_o
oooomomoookHHg@?ooom0Noooo_o_ooooooonooOooooooooooooooooooooooooP0000?oooooooooo
ooogooooooo_oo_ooooomomoookKkgG_oool000000?o_ooooooonooOooooooooooonoooooooooooo
P0000?ooooooooooooogon7M]P__oo_ooooomomoooaH8GHOooom000000?o_ooooooonooOoooooooo
ooonOoooooooooooP0000?ooooooooooooogomgM]/_?oo_ooooomomoookooooooooml>oooo_o_ooo
oooonooOooooooooooonOoooooooooooP0000?ooooooooooooogokkM]^_?oo_ooooomomoookOoooo
ooomn6oooo_o_ooooooonooOoooooooooool?oooooooooooP0000?ooooooooooooogokkM]R^goo_o
oooomomoooooooooooomonoooo_o_ooooooonooOoooooooooool?oooooooooooP0000?oooooooooo
ooogokkM]l^goo_ooooomomoooooooooooomonoooo_o_ooooooonooOoooooooooool?ooooooooooo
P0000?ooooooooooooogokkM]^Ucoo_ooooomomoooooooooolOmonoooo_o_ooooooonooOoooooooo
oooh?oooooooooooP0000?ooooooooooooogokk5SaQkoo_ooooomomoooooooooooOmonoooo_o_ooo
oooonooOoooooooooooh7oooooooooooP0000?ooooooooooooogokkooooooo_ooooomomoPiK3_f<5
^6?monoooo_o_ooooooonooOoooooooooooh7oooooooooooP0000?ooooooooooooogokkmoooooo_l
oooomomoNkKM_e]e]f_monooio_o_ooooooonooOooooooooooobSoooooooooooP0000?oooooooooo
ooogoooooooooo_1oooomomoOKK1_a]e/4_monool7_o_ooooooonooOooooooooooofkooooooooooo
P0000?ooooooooooooogoooooooooo^3oooomomoOKKM_e]e]e_monoon3_o_ooooooonooOoooooooo
ooonooooooooooooP0000?ooooooooooooogooooooooooP000001omoOKKI_d]T/eWl000000?o_ooo
oooonooOooooooooooonooooooooooooP0000?ooooooooooooogooooooooooX000001omoOA7WSg>4
?=gl000000_o_ooooooonooOooooooooooonooooooooooooP0000?ooooooooooooogoooooooooo^1
oooomomo>kOoogogooomonool3_o_ooooooonooOooooooooooonooooooooooooP0000?oooooooooo
ooogoooooooooo_aoooomomoaoOoog_gooomonoolO_o_ooooooonooOooooooooooonoooooooooooo
P0000?ooooooooooooogoooooooooo_loooomomoooooooooooomonooio_o_ooooooonooOoooooooo
ooonooooooooooooP0000?ooooooooooooogoooooooooo_ooooomomoooooooooooomonoooo_o_ooo
oooonooOooooooooooonooooooooooooP0000?ooooooooooooogoooooooooo_ooooomomooooooooo
ooomonoooo_o_ooooooonooOooooooooooonooooooooooooP0000?ooooooooooooogoooooooooo_o
oooomomoooooooooooomonoooo_o_ooooooonooOooooooooooonooooooooooooP0000?oooooooooo
ooogoooooooooo_ooooomomoooooooooooomonoooo_o_ooooooonooOooooooooooonoooooooooooo
P0000?ooooooooooooogoooooooooo_ooooomomoooooooooooomonoooo_o_ooooooonooOoooooooo
ooonooooooooooooP0000?ooooooooooooogoooooooooo_ooooomomoooooooooooomonoooo_o_ooo
oooonooOooooooooooonooooooooooooP0000?ooooooooooooogoooooooooo_ooooomomooooooooo
ooomonoooo_o_ooooooonooOooooooooooonooooooooooooP0000?ooooooooooooogoooooooooo_o
oooomomoooooooooooomonoooo_o_ooooooonooOooooooooooonooooooooooooP0000?oooooooooo
ooogoooooooooo_ooooomomoooooooooooomonoooo_o_ooooooonooOooooooooooonoooooooooooo
P0000?ooooooooooooo`0000000000?ooooomol0000000000001onoooo_o_ooooooonooOoooooooo
ooonooooooooooooP0000?oooooooooooooooooooooooooooooomoooooooooooooooonoooo_o_ooo
oooonooOooooooooooonooooooooooooP0000?oooooooooooooooooooooooooooooomooooooooooo
ooooonoooo_o_ooooooonooOooooooooooonooooooooooooP0000?oooooooooooooooooooooooooo
oooomoooooooooooooooonoooo_o_ooooooonooOooooooooooonooooooooooooP0000?oooooooooo
oooooooooooooooooooomoooooooooooooooonoooo_o_ooooooonooOooooooooooonoooooooooooo
P0000?oooooooooooooooooooooooooooooomoooooooooooooooonoooo_o_ooooooonooOoooooooo
ooonooooooooooooP0000?oooooooooooooooooooooooooooooomoooooooooooooooonoooo_o_ooo
oooonooOooooooooooonooooooooooooP0000?oooooooooooooooooooooooooooooomooooooooooo
ooooonoooo_o_ooooooonooOooooooooooonooooooooooooP0000?oooooooooooooooooooooooooo
oooomoooooooooooooooonoooo_o_ooooooonooOooooooooooonooooooooooooP0000?oooooooooo
oooooooooooooooooooomooooooooon?ooooonoooo_o_ooooooonooOooooooooooonoooooooooooo
P0000?oooooooooooooooooooooooooooooomooooooooon?ooooonoooo_o_ooooooonooOoooooooo
ooonooooooooooooP0000?oooooooooooooooooooooooooooooomooooiiLYg?V7oooonoooo_o_ooo
oooonooOooooooooooonooooooooooooP0000?oooooooooooooooooooooooooooooomooooiaH9f7V
3oooonoooo_o_ooooooonooOooooooooooonooooooooooooP0000?oooooooooooooooooooooooooo
oooomooooicA9dG2Soooonoooo_o_ooooooonooOoooooh000000000000003oooP0000?oooooooooo
oooooooooooooooooooomoooohgCYd727oooonoooo_o_ooooooonooOoooookooooooooooooookooo
P0000?oooooooooooooooooooooooooooooomooooh7A8d6J3oooonoooo_o_ooooooonooOoooookoo
ooooooooooookoooP0000?oooooooooooooooooooooooooooooomooooi?H864h3oooonoooo_o_ooo
oooonooOoooookooooooooooooookoooP0000?oooooooooooooooooooooooooooooomooooiWLX7<h
7oooonoooo_o_ooooooonooOoooookooooooooooooookoooP0000?oooooooooooooooooooooooooo
oooomooooicO_oooooooonoooo_o_ooooooonooOoooookooooooooooooookoooP0000?oooooooooo
oooooooooooooooooooomooooiiO_oooooooonoooo_o_ooooooonooOoooookooooooooooooookooo
P0000?oooooooooooooooooooooooooooooomoooooooooooooooonoooo_o_ooooooonooOoooookoo
ooooooooooookoooP0000?oooooooooooooooooooooooooooooomoooooooooooooooonoooo_o_ooo
oooonooOoooookooooooooooooookoooP0000?oooooooooooooooooooooooooooooomooooooooooo
ooooonoooo_o_ooooooonooOoooookooooooooooooookoooP0000?oooooooooooooooooooooooooo
oooomoooooooooooooooonoooo_o_ooooooonooOoooookooooooooooooookoooP0000?oooooooooo
ooooooooooooooooooool00000000000000000oooo_o_ooooooonooOoooookooooooooooooookooo
P0000?oooooooooooooooooooooooooooooooooooooooooooooooooooo_o_ooooooonooOoooookoo
ooooooooooookoooP0000?oooooooooooooooooooooooooooooooooooooooooooooooooooo_o_ooo
oooonooOoooookooooooooooooookoooP0000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooo_o_ooooooonooOoooookooooooooooooookoooP0000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooo_o_ooooooonooOoooookooooooooooooookoooP0000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooo_o_ooooooonooOoooookooooooooooooookooo
P0000?oooooooooooooooooooooooooooooooooooooooooooooooooooo_o_ol??F?onooOoooookob
h/AnLKHc]V?okoooP0000?oooooooooooooooooooooooooooooooooooooooooooooooooooo_o_oib
cEgonooOoooookofk9GiY;K/]^gokoooP0000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooo_o_ognoGgonooOoooookofk[gkk[K_]_gokoooP0000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooo_o_ogn3D?onooOoooookofh;gkk[KP]^?okoooP0000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooo_o_ognkEoonooOoooookofk[gkk[K^]^ookooo
P0000?ool00000000000000000000000000000000000000?oooooooooo_o_ogn7D7onooOooon7koR
8<Al<HHQQ67okoooP0000?oomoooooooooooooooooooooooooooooooooooooo_oooooooooo_o_okk
oGoonooOoooo1kogoogoookoo_ookoooP0000?oomoooooooooooooooooooooooooooooooooooooo_
oooooooo7o_o_ol7oGoonooOoooo0;ogoogoookoo_ookoooP0000?oomooooooooooooooooooooooo
ooooooooooooooo_oooooooo0o_o_ooooooonoo0000003ooooooooooooookoooP0000?oomooooooo
ooooooooooooooooooooooooooooooo_ooooooooPO_o_ooooooonoo000000;ooooooooooooookooo
P0000?oomooooooP000000000000000000000000000000000000000003_o_ooooooonooOoooo0koo
ooooooooooookoooP0000?oomooooooP000000000000000000000000000000000000000007_o_ooo
oooonooOoooo7kooooooooooooookoooP0000?oomooooonOooooooooooooooooooooooooooooooo_
oooooooo0O_o_o1/>67onooOooonOkhN24G3mM4<4KX5koooP0000?oomooooonOoooooooooooooooo
ooooooooooooooo_oooooooo7o_o_oN[]egonooOoooookg^kefkmMK_eK[ekoooP0000?oomooooonO
ooooooooooooooooooooooooooooooo_ooooooooOo_o_oN[]egonooOoooookgf:5fj=MH>5KXekooo
P0000?oomooooonOooooooooooooooooooooooooooooooo_oooooooooo_o_oM[]egonooOoooookf7
RmfkmMK]mK_5koooP0000?oomooooonOooooooooooooooooooooooooooooooo_oooooooooo_o_o1Y
/dgonooOoooookgnjefKm=I]eIYekoooP0000?oomooooonOooooooooooooooooooooooooooooooo_
oooooooooo_o_oN^O?7onooOoooookgo6<AWmC6N8JN=koooP0000?oomooooonOoooooooooooooooo
ooooooooooooooo_oooooooooo_o_oN_oogonooOoooookg_omooooOomoomkoooP0000?oomooooonO
ooooooooooooooooooooooooooooooo_oooooooooo_o_o1_oogonooOoooookhOomoomoOomOomkooo
P0000?oomooooonOooooooooooooooooooo`000000000?o_oooooooooo_o_ooooooonooOoooookoo
ooooooooooookoooP0000?oomon0000000000000000000007oogooooooooo_o_oooooooooo_o_ooo
oooonooOoooookooooooooooooookoooP0000?oomonooooooooookoooooooooogoogooooooooo_o_
oooooooooo_o_ooooooonooOoooookooooooooooooookoooP0000?oomonooooooooookoooooooooo
googooooooooo_o_oooooooooo_o_ogg?UoonooOoooookooooooooooooookoooP0000?oomonooooo
oooookoooooooooogoogooooooooo_o_oooooooooo_o_og^gIoonooOoooookooooooooooooookooo
P0000?oomonooooooooookoooooooooogoogooooooooo_o_oooooooooo_o_ogNkMoonooOoooookoo
ooooooooooookoooP0000?oomonooooooooookoooooooooogoogooooooooo_o_oooooooooo_o_ogN
3MoonooOoooookooooooooooooookoooP0000?oomonooooooooookoooooooooogoogooooooooo_o_
oooooooooo_o_o`>kMoonooOoooookooooooooooooookoooP0000?oomonooooooooookoooooooooo
googooooooooo_o_oooooooooo_o_ogfgIoonooOoooookooooooooooooookoooP0000?oomonooooo
oooookoooooooooogoogooooooooo_o_oooooooooo_o_ogg?UoonooOoooookooooooooooooookooo
P0000?oomonooooooooookooooooooooglogooooooooo_o_ooooooooio_o_ogWomoonooOoooookoo
ooooooooooookoooP0000?oomonooooooooookooooooon?ogn?gooooooooo_o_oooooooolO_o_o`O
omoonooOoooookooooooooooooookoooP0000?oomonooooooooookooooooomcogn1gooooooooo_o_
ooooooool3_o_ooooooonooOoooookooooooooooooookoooP0000?oomono_LK_i^ifgko`3^K/=g:o
gn0Gooooooooo_o_oooooooon0_o_ooooooonooOoooookooooooooooooookoooP0000?oomono^I[_
f@Vfokogl=[[]dco`007oooooooooP000000000000?o_ooooooonooOoooooh000000000000003ooo
P0000?oomono^K[Xgi_fokognMk[]ekogn1gooooooooo_o_oooooooon3_o_ooooooonooOoooooooo
ooooooooooooooooP0000?oomono]K[_`I_fokognMk/=ekogn7go3UM`iioo_o_ooooooool?_o_ooo
oooonooOooooooooooooooooooooooooP0000?oomono]K[_gI_foko`>Mk[]ekoglognkIM^ffoo_o_
ooooooooio_o_ooooooonooOooooooooooooooooooooooooP0000?oomono[MY_ffffokogm]Y]/fco
googmmMM^_gOo_o_oooooooooo_o_ooooooonooOooooooooooooooooooooooooP0000?oomonoWLJO
i^iaokogk^HN=?;ogoogomMMR_`Oo_o_oooooooooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?oomono_OooooogokogookooooogoogocMMl_gOo_o_oooooooooo_o_ooooooonooOoooooooo
ooooooooooooooooP0000?oomono_Oooooogoko`7okooooogoogn?M=VVfOo_o_oooooooooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?oomonooooooooookoooooooooogoogmoMDHiioo_o_
oooooooooo_o_ooooooonooOooooooooooooooooooooooooP0000?oomonooooooooonKoooooooooo
googliomooooo_o_oooooooooo_o_ooooooonooOooooooooooooooooooooooooP0000?oomonooooo
oooohkoooooooooogoogo3onOoooo_o_oooooooooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?oomonooooooooo0koooooooooogoogooooooooo_o_oooooooooo_o_ooooooonooOoooooooo
ooooooooooooooooP0000?oomonooooooool0koooooooooogoogooooooooo_o_oooooooooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?oomonoooooooo`0001oooooooogoogooooooooo_o_
oooooooooo_o_ooooooonooOooooooooooooooooooooooooP0000?oomonooooooooo0koooooooooo
googNl<NN>ER__o_oooooooooo_o_ooooooonooOooooooooooooooooooooooooP0000?oomonooooo
oooo`koooooooooogoogNk]]^]UL__o_oooooooooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?oomonooooooooohKoooooooooogoogNk]eemeN__o_oooooooooo_o_ooooooonooOoooooooo
ooooooooooooooooP0000?oomonooooooooookoooooooooogoogNl]d5meV__o_oooooooooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?oomonooooooooookoooooooooogoogNk=eemeH__o_
oooooooooo_o_ooooooonooOooooooooooooooooooooooooP0000?oomonooooooooookoooooooooo
googNM]]^]e^W_o_oooooooooo_o_ooooooonooOooooooooooooooooooooooooP0000?oomonooooo
oooookoooooooooogoogN^<NN=ea[_o_oooooooooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?oomonooooooooookoooooooooogoogOomooomoo_o_oooooooooo_o_ooooooonooOoooooooo
ooooooooooooooooP0000?oomonooooooooookoooooooooognod3omooomoo_l_oooooooooo_o_ooo
oooonooOooooooooooooooooooooooooP0000?oomonooooooooookoooooooooog`ogooooooooo_a_
oooooooooo_o_ooooooonooOooooooooooooooooooooooooP0000?oomonooooooooookoooooooooo
g0ogooooooooo_1_oooooooooo_o_ooooooonooOooooooooooooooooooooooooP0000?oomonooic0
1``@I0?ll<PBKQoo`1ogoooooooooX1_oooooooooo_o_ooooooonooOoooooooooooooooooooooooo
P0000?oomonooic=4RRFI9?lhTTBK5oo`007oooooooooP000000000000?o_ooooooonooOoooooh00
0000000000003oooP0000?oomonooic1<PWgI1?hITVBK1oo`007oooooooooX000000000000?o_ooo
oooonooOoooookooooooooooooookoooP0000?oomonooica<PWgIa?c9TVBK1oogPogooooooooo_Q_
oooooooooo_o_ooooooonooOoooookooooooooooooookoooP0000?oomonooi`10PPGI13c84V@31oo
g`ogooooooooo_`_oooooooooo_o_ooooooonooOoooookooooooooooooookoooP0000?oomonooi`Q
1ihgIS3g^<V@Scoogoogooooooooo_o_oooooooooo_o_ooooooonooOoooookooooooooooooookooo
P0000?oomonoo0?o?oooikoWWloooooogoogooooooooo_o_oooooooooo_o_ooooooonooOoooookoo
ooooooooooookoooP0000?oomonoo0?o?oooikoWWloooooogoogooooooooo_o_oooooooooo_o_ooo
oooonooOoooookooooooooooooookoooP0000?oomonooooooooookoooooooooogoogooooooooo_o_
oooooooooo_o_ooooooonooOoooookooooooooooooookoooP0000?oomonooooooooookoooooooooo
googooooooooo_o_oooooooooo_o_ooooooonooOoooookooooooooooooookoooP0000?oomonooooo
oooookoooooooooogoogooooooooo_o_oooooooooo_o_ooooooonooOoooookooooooooooooookooo
P0000?oomonooooooooookoooooooooogoogooooooooo_o_oooooooooo_o_ooooooonooOQooookoo
ooooooooooookoooP0000?oomonooooooooookoooooooooogoo`000000000?o_oooooooooo_o_ooo
oooonooN3ooookoooo1MlgoOooookoooP0000?oomon0000000000000000000007oooooooooooooo_
oooooooooo_o_ooooooonoo07ooookooooOHcGoOooookoooP0000?oomooooooooooooooooooooooo
ooooooooooooooo_oooooooooo_o_ooooooonoo0000003ooooOJggoOooookoooP0000?oomooooooo
ooooooooooooooooooooooooooooooo_oooooooo?o_o_ooooooonoo0000003ooooOJ`GoOooWokooo
P0000?oomoooooooooooooooooooooooooooooooooooooo_ooooooooSo_o_ooooooonooO3ooookoo
ooOJgGoOooWokoooP0000?oomoooooooooooooooooooooooooooooooooooooo_ooooooooP?_o_ooo
oooonooOQooookooooOGHAmOooWokoooP0000?oomoooooooooooooooooooooooooooooooooooooo_
oooooooo`3_o_ooooooonooOoooookooooOooonOooWokoooP0000?oomooooooP0000000000000000
00000000000000000000000001_o_ooooooonooOoooookooooOooonOooWokoooP0000?oomooooooP
000000000000000000000000000000000000000003_o_ooooooonooOoooookooooOOoooOooWokooo
P0000?oomoooooo_ooooooooooooooooooooooooooooooo_ooooooooPo_o_ooooooonooOoooookoo
ooooooooooWokoooP0000?oomoooooo_ooooooooooooooooooooooooooooooo_oooooooo3o_o_ooo
oooonooOoooookooooooooooooWokoooP0000?oomoooooo_ooooooooooooooooooooooooooooooo_
oooooooooo_o_ooooooonooOooonOkooooooooooooWokoooP0000?oomoooooo_oooooooooooooooo
ooooooooooooooo_oooooooooo_o_ooooooonooOoooo1kooooooooooooWokoooP0000?oomoooooo_
ooooooooooooooooooooooooooooooo_oooooooooo_o_ooooooonooOoooo0kooooooooooooWokooo
P0000?oomon0000000000000000000007oool00000000?o_oooooooooo_oP00000000oo000000000
0000000000003oooP0000?oomonooooooooookoooooooooogooomoooooooo_o_oooooooooo_ooogo
ooooooo000000;ooooooooooooWokoooP0000?oomonooooooooookoooooooooogooomoooooooo_o_
oooooooooo_ooogooooooooOoooo0kooooooooooooWokoooP0000?oomonooooooooookoooooooooo
gooomoooooooo_o_oooooooooo_ooogooonooooOoooo3kooooooooooooWokoooP0000?oomonooooo
oooookoooooooooogooomoooooooo_o_oooooooooo_ooogooonOoooOooonOkooooooooooonVokooo
P0000?oomonooooooooookoooooooooogooomoooooooo_o_oooooooooo_ooogooonOoooOoooookoo
ooooooooon0okoooP0000?oomonooooooooookoooooooooogooomoooooooo_o_oooooooooo_ooogo
ool?oooOoooookooooooooooon0okoooP0000?oomonooooooooookoooooooooogooomoooooooo_o_
oooooooooo_ooogoool?oooOoooookooooooooooon0okoooP0000?oomonooooooooookoooooooooo
gooomoooooooo_o_oooooooooo_ooogoooh?oooOoooookoooooooooooo1okoooP0000?oomonooooo
oooookoooooooooogooomoooooooo_o_oooooooooo_ooogooo`7oooOoooookooon2kigh?oo1okooo
P0000?oomonooooooooookoooooooooogoo?moooooooo_o_ooooooooio_ooogooo`7oooOiooookoo
onnkfgkoooSokoooP0000?oomonooooooooookooooooon3ogooPmoooooooo_o_ooooooool7_ooogo
oo`3oooN3ooookooonni_GloooSokoooP0000?oomonooooooooookooooooookogooPMoooooooo_o_
oooooooon3_ooogooofkoooL7ooookooonniPGnoooSokoooP0000?oomonnnifocMSM_koh1g=^6g3O
gooP5oooooooo_o_oooooooon0_ooogooonoooo07ooookooonnf_GoOoogokoooP0000?oomonnlfFo
=;;Mokokn/e]VfKo`0001ooooooooP000000000000?ooogooonoooo0000003ooonnVVGo?oogokooo
P0000?oomonnlgFQO[OMokokn]m]ffkogooPMoooooooo_o_oooooooon3_ooogooonooooL7ooookoo
onn^iao_ooookoooP0000?oomonnbgFo1SOMokokn=m^6fkogooQmn73MRiao_o_ooooooool?_ooogo
oonooooO3ooookooonooook?ooookoooP0000?oomonnfgFoM[OMokoh6]m]ffkogoo?mnkCM/ffo_o_
ooooooooio_oongOoonooooOiooookooonnooolOooookoooP0000?oomonn^``oQIS1okoklV4>673o
gooommmKM^g^o_o_oooooooooo_oon0OoonooooOoooookooooooooooooookoooP0000?oomonn^ooo
oooOokokoomooooogooomomKMRgPo_o_oooooooooo_ooo0ooonooooOoooookooooooooooooookooo
P0000?oomonnNooooooOokoh3omooooogooomn3KMXg^o_o_oooooooooo_ooo0ooonooooOoooookoo
ooooooooooookoooP0000?oomonooooooooookoooooooooogooomnoKM^ffo_o_oooooooooo_ooo1o
oonooooOoooookooooooooooooookoooP0000?oomonooooooooookoooooooooogooommoK2aiao_o_
oooooooooo_ooo1ooonooooOoooookooooooooooooookoooP0000?oomonooooooooonKoooooooooo
gooomliomoooo_o_oooooooooo_oooQooonooooOoooookooooooooooooookoooP0000?oomonooooo
oooohkoooooooooogooomn7onoooo_o_oooooooooo_ooocooonooooOoooookooooooooooooookooo
P0000?oomonooooooooo0koooooooooogooomoooooooo_o_oooooooooo_ooocooonooooOoooookoo
ooooooooooookoooP0000?oomonooooooool0koooooooooogooomoooooooo_o_oooooooooo_ooogo
oonooooOoooooh000000000000003oooP0000?oomonoooooooo`0001oooooooogooomoooooooo_o_
oooooooooo_ooogooooooooOooooooooooooooooooooooooP0000?oomonooooooooo0koooooooooo
gooomo3cN?<Eo_o_oooooooooo_ooooooooooooOooooooooooooooooooooooooP0000?oomonooooo
oooo`koooooooooogooomnm=N/eUo_o_oooooooooo_ooooooooooooOoooooooooooooooooooooooo
P0000?oomonooooooooonKoooooooooogooommoMN]meo_o_oooooooooo_ooooooooooooOoooooooo
ooooooooooooooooP0000?oomonooooooooookoooooooooogooommoMN]l5o_o_oooooooooo_ooooo
oooooooOooooooooooooooooooooooooP0000?oomonooooooooookoooooooooogooommoMN]meo_o_
oooooooooo_ooooooooooooOooooooooooooooooooooooooP0000?oomonooooooooookoooooooooo
gooommo]>^eeo_o_oooooooooo_oo_k3SKL?oooOooooooooooooooooooooooooP0000?oomonooooo
oooookoooooooooogooomlmc@?>=o_o_oooooooooo_oo_jkKKK_oooOoooooooooooooooooooooooo
P0000?oomonooooooooookoooooooooogooomnmonoomo_o_oooooooooo_oo_jkkKK_oooOoooooooo
ooooooooooooooooP0000?oomonooooooooookoooooooooog`oomo3oo_omo_`_oooooooooo_ooPK3
3KL?oooOQoooooooooooooooooooooooP0000?oomonooon7S>;SR[ilIPTcWooog0oomoooooooo_1_
oooooooooo_oo_JkOKK_oooN3oooooooooooooooooooooooP0000?oomonoool11>;10[i`90Tb3ooo
`1oomooooooooX1_oooooooooo_oo_[330L?ooo07oooooooooooooooooooooooP0000?oomonoooik
M>kO4[`cY<TbOooo`0001ooooooooP000000000000?oo_[oooooooo0000000000000oooooooooooo
P0000?oomonoooioM>kOP[`CY<Tb3ooo`0001ooooooooX000000000000?ooPKoooooooo000000000
0000ooooooooooooP0000?oomonoooio96k9<[fA9<TBKooogPoomoooooooo_Q_oooooooooo_ooooo
oooooooO3oooooooooonooooooooooooP0000?oomonoooio10;10[fH9<P33ooog`oomoooooooo_a_
oooooooooo_ooooooooooooOSoooooooooonooooooooooooP0000?oomonooohaS8;SQ[WLI<QWWooo
gnoomoooooooo_l_oooooooooo_ooooooooooooOioooooooooonooooooooooooP0000?oomonoool3
onkoo[??iooooooogooomoooooooo_o_oooooooooo_ooooooooooooOooooooooooonoooooooooooo
P0000?oomonooon7onkoo[??iooooooogooomoooooooo_o_oooooooooo_ooooooooooooOoooooooo
ooonooooooooooooP0000?oomonooooooooookoooooooooogooomoooooooo_o_oooooooooo_ooooo
oooooooOooooooooooonooooooooooooP0000?oomonooooooooookoooooooooogooomoooooooo_o_
oooooooooo_ooooooooooooOooooooooooonooooooooooooP0000?oomonooooooooookoooooooooo
gooomoooooooo_o_ooooooooOo_ooooooooooooOooooooooooonooooooooooooP0000?oomonooooo
oooookoooooooooogooomoooooooo_o_oooooooo0o_ooooooooooooOooooooooooonoooooooooooo
P0000?oomonooooooooookoooooooooogooomoooooooo_o_ooooooooPO_ooooooooooooOoooooooo
ooonooooooooooooP0000?oomon0000000000000000000007oool00000000?o_oh00000003_ooooo
oooooooOooooooooooonooooooooooooP0000?oomoooooooooooooooooooooooooooooooooooooo_
oh00000007_oooooooooooo000000003ooonooooooooooooP0000?oomooooooooooooooooooooooo
ooooooooooooooo_ocooooooPO_oooooooooooo000000001ooonooooooooooooP0000?oomooooooo
ooooooooooooooooooooooooooooooo_ocoooooo1o_ooooooooooooOoooooooiooonoooooooooooo
P0000?oomoooooooooooooooooooooooooooooooooooooo_ocooooooOo_ooooooooooooOoooooooi
ooonooooooooooooP0000?oomoooooooooooooooooooooooooooooooooooooo_ocoooooooo_ooooo
oooooooOoooooooiooonooooooooooooP0000?oomoooooooooooooooooooooooooooooooooooooo_
ocoooooooo_ooooooooooooOoooooooiooonooooooooooooP0000?oomn39Q<<@C?oooooooooooooo
ooooooooooooooo_ocoooooooo_ooooooooooooOoooooooiooonooooooooooooP0000?oomlA;=<TR
C?ooooooooooooooooooooooooooooo_ocoooooooo_ooooooooooooOoooooooiooonoooooooooooo
P0000?oomla31<4WC?ooooooooooooooooooooooooooooo_ocooiooooo_ooooooooooooOoooooooi
ooonooooooooooooP0000?oomo331<4WC?ooooooooooooooooooooooooooooo_ocooiooooo_ooooo
oooooooOoooooooiooonooooooooooooP0000?oomn73==TRA?ooooooooooooooooooooooooooooo_
ocooh00000_ooooooooooooOoooooooiooonooooooooooooP0000?oomlI9Q<8@@?oooooooooooooo
ooooooooooooooo_ocooh00000_ooooooooooooOoooooooiooonooooooooooooP0000?oomla?o?lo
ooooooooooooooooooooooooooooooo_ocooiooooo_ooooooooooooOoooooooiooonoooooooooooo
P0000?oomn3?o?loooooooooooooooooooooooooooooooo_ocooioooooP000000000000Ooooooooi
ooonooooooooooooP0000?oomoooooooooooooooooooooooooooooooooooooo_ocooiooooooooogo
oonooooooooooooiooonooooooooooooP0000?oomoooooooooooooooooooooooooooooooooooooo_
ocooiooooooooogooolooooooooooooiooonooooooooooooP0000?oomooooooooooooooooooooooo
ooooooooooooooo_ocooiooooooooogooolooooooooooooiooonooooooooooooP0000?oomooooooo
ooooooooooooooooooooooooooooooo_ocooiooooooooogooohOoooooooooooiooonoooooooooooo
P0000?oomoooooooooooooooooooooooooooooooooooooo_ocooiooooooooogooohOoooooooooooi
ooonooooooooooooP0000?ool00000000000000000000000000000000000000?ocooiooooooooogo
oo`?oooooooooooiooonooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooo
ocooiooooooooogooo`?oooooooooooiooonooooooooooooP0000?oooooooooooooooooooooooooo
ooooooooooooooooocooiooooooooogooo`?oooooooooooiooonooooooooooooP0000?oooooooooo
ooooooooooooooooooooooooooooooooocooiooooooooogoooP7oooooooooooiooonoooooooooooo
P0000?ooooooooooooooooooooooooooooooooooooooooooocooiooooooooogooo/goooooooooooi
ooonooooooooooooP0000?ooooooooooooooooooooooooooooooooooooooooooocooiooooooooogo
oolooooooooooooiooonooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooo
ocooiooooooooogooolooooooooooooiooonooooooooooooP0000?oooooooooooooooooooooooooo
ooooooooooooooooocooiooooooooogooolooooooooooooiooonooooooooooooP0000?oooooooooo
ooooooooooooooooooooooooooooooooocooiooooooooogooolooooooooooooiooonoooooooooooo
P0000?ooooooooooooooooooooooooooooooool00000000000000000000000000000000000000000
0000000000003oooP0000?oooooooooooooooooooooooooooooooomoooooooooocoo1?ooooooongO
oolooooooooooooI_oonooooooookoooP0000?oooooooooooooooooooooooooooooooomooooooooo
ocooPOooooooonDOooloooooooooooo1?oonooooooookoooP0000?oooooooooooooooooooooooooo
oooooomoooooooooocooPOoooooooo0ooolooooooooooooP?oonooooooookoooP0000?oooooooooo
oooooooooooooooooooooomoooooooooocoo`Ooooooooo0ooolooooooooooooP?oonooooooookooo
P0000?oooooooooooooooooooooooooooooooomoooooooooocoo`Ooooooooo1oooloooooooooooo`
OoonooooooookoooP0000?oooooooooooooooooooooooooooooooomoooooooooocoo`ooooooooo1o
ooloooooooooooo`OoonooooooookoooP0000?oooooooooooooooooooooooooooooooomooooooooo
ocoo`oooooooooQoooloooooooooooo`ooonooooooookoooP0000?oooooooooooooooooooooooooo
oooooomoooooooooocooiooooooooocoooloooooooooooohooonooooooookoooP0000?oooooooooo
oooooooooooooooooooooomoooooooooocooiooooooooocoooloooooooooooohooonooooooookooo
P0000?oooooooooooooooooooooooooooooooomoooooooooocoomooooooooogoooloooooooooooom
ooonooooooookoooP0000?oooooooooooooooooooooooooooooooomon0000000000000oooo000000
0000000Oooo00000000000007oookoooP0000?oooooooooooooooooooooooooooooooomonooooooo
ooooonooooOooooooooooooOoooOoooooooooooogoookoooP0000?oooooooooooooooooooooooooo
oooooomonoooooooooooonooooOooooooooooooOoooOoooooooooooogoookoooP0000?oooooooooo
oooooooooooooooooooooomonoooooooooooonooooOooooooooooooOoooOoooooooooooogoookooo
P0000?oooooooooooooooooooooooooooooooomonoooooooooooonooooOooooooooooooOoooOoooo
oooooooogoookoooP0000?oooooooooooooooooooooooooooooooomonoooooooooooonooooOooooo
oooooooOoooOoooooooooooogoookoooP0000?oooooooooooooooooooooooooooooooomonooooooo
ooooonooooOooooooooooooOoooOoooooooooooogoookoooP0000?oooooooooooooooooooooooooo
oooooomonoooooooooooonooooOooooooooooooOoooOoooooooooooogoookoooP0000?oooooooooo
oooooooooooooooooooooomonoooooooo_oooNooooOooooooooooooOoooOoooooooooooogoookooo
P0000?oooooooooooooooooooooooooooooooomonooooooooOooo^ooooOooooooogooogOoooOoooo
ooonoookgoookoooP0000?oooooooooooooooooooooooooooooooomoni3M^?O>oL?_c^ooooOooooo
oogoookOoooOooooooomooomgoookoooP0000?oooooooooooooooooooooooooooooooomonkCM^gNf
oMg_]fooooOooooooogoookOoooOooooooomooomgoookoooP0000?oooooooooooooooooooooooooo
oooooomonkKM]g=joKk_MfooooL1fk3gSOV3gmkOoooMhb6g;3KiPMh<goookoooP0000?oooooooooo
oooooooooooooooooooooomonkKM]g<2oOk_MfooooM]fkM[MO^mgmkOoooMgFjgJmKk_Mnngoookooo
P0000?oooooooooooooooooooooooooooooooomonkKM]fejoL7_MfooooM]fkM[1O_mgmkOoooM`F2g
JmKkoMnNgoookoooP0000?oooooooooooooooooooooooooooooooomonkK<^effoMo_MfooooM]fkMK
MO_cgmkOoooMgFjgJmKklMo^goookoooP0000?oooooooooooooooooooooooooooooooomonaKD>=g>
?Kk_M^ooooM]bKII9?^?gmkOoooMbFbGJIKkQmo^goookoooP0000?oooooooooooooooooooooooooo
oooooomonkoooooooMg_]^ooooL=`WWMSGfogekOoooLH[66[W7m_mo]goookoooP0000?oooooooooo
oooooooooooooooooooooomonoooooooo/<3cNooooMooooooofigikOoooOogooOoom_Mi]goookooo
P0000?oooooooooooooooooooooooooooooooomonoooooooooooonooooOooooooog20mgOoooOoooo
koon``>;goookoooP0000?oooooooooooooooooooooooooooooooomonoooookoooooonooooOooooo
oooooooOoooOoooooooooooogoookoooP0000?oooooooooooooooooooooooooooooooomonoooooko
ooooonooooOooooooooooooOoooOoooooooooooogoookoooP0000?oooooooooooooooooooooooooo
oooooomonoooNhHKUoooonooooOooooooooooooOoooOoooooooooooogoookoooP0000?oooooooooo
oooooooooooooooooooooomonoooLgIZIoooonooooO]fLgK^NFRW?oOoooOoklgH/KW;Soogoookooo
P0000?oooooooooooooooooooooooooooooooomonoooMgKZmoooonooooO]fkGK]]V/^goOoooOokkG
K=KJcMoogoookoooP0000?oooooooooooooooooooooooooooooooomonooo1hKZmoooonooooO]fgGK
[ef^]goOoooOokgGK[jjkmoogoookoooP0000?oooooooooooooooooooooooooooooooomonoooNgKZ
moooonooooO]f`GKX5fR/7oOoooOok`GH[jjkSoogoookoooP0000?oooooooooooooooooooooooooo
oooooomonoooNhH;1oooonooooO]fgGK[efX]goOoooOokgGJ;jjkOoogoookoooP0000?oooooooooo
oooooooooooooooooooooomonoooNooomoooonooooO/fkCI]]V^^goOoooOokkCK]KJkMoogoookooo
P0000?oooooooooooooooooooooooooooooooomonooo0ookmoooonooooO]<Le2NNFa7?oOoooOokld
lLKVkSoogoookoooP0000?oooooooooooooooooooooooooooooooomonoooooooooooonooooO_nooo
oogo_ooOoooOokoooooooooogoookoooP0000?oooooooooooooooooooooooooooooooomonooooooo
ooooonooooO_oooooofooooOoooOoPOoookooooogoookoooP0000?oooooooooooooooooooooooooo
oooooomonoooooooooooonooooOooooooooooooOoooOoooooooooooogoookoooP0000?oooooooooo
oooooooooooooooooooooomonoooooooooooonooooOooooooooooooOoooOoooooooooooogoookooo
P0000?oooooooooooooooooooooooooooooooomonoooooooooooonooooOooooooooooooOoooOoooo
oooooooogoookoooP0000?oooooooooooooooooooooooooooooooomonoooooooooooonooooOooooo
oooooooOoooOoooooooooooogoookoooP0000?oooooooooooooooooooooooooooooooomonooooooo
ooooonooooOooooooooooooOoooOoooooooooooogoookoooP0000?oooooooooooooooooooooooooo
oooooomonoooooooooooonooooOooooooooooooOoooOoooooooooooogoookoooP0000?oooooooooo
oooooooooooooooooooooomon0000000000000oooo0000000000000Oooo00000000000007oookooo
P0000?oooooooooooooooooooooooooooooooomooooooooooooooooooooooooooooooooooooooooo
ooooooooooookoooP0000?oooooooooooooooooooooooooooooooomooooooooooooooooooooooooo
ooooooooooooooooooooooooooookoooP0000?oooooooooooooooooooooooooooooooomooooooooo
ooooooooooooooooooooooooooooooooooooooooooookoooP0000?oooooooooooooooooooooooooo
oooooomoooooooooooooooooooooooooooooooooooooooooooooooooooookoooP0000?oooooooooo
oooooooooooooooooooooomoooooooooooooooooooooooooooooooooooooooooooooooooooookooo
P0000?oooooooooooooooooooooooooooooooomooooooooooooooooooo7`kW?`hIWbHHL7>7oooooo
ooooooooooookoooP0000?oooooooooooooooooooooooooooooooomoooooooooooooooooon1Pj1?P
`97R@@8443ooooooooooooooooookoooP0000?oooooooooooooooooooooooooooooooomooooooooo
ooooooooolmTjO?hc9?VLL9ToSooooooooooooooooookoooP0000?oooooooooooooooooooooooooo
oooooomoooooooooooooooooolmTj1?Pc9?V@@IT47ooooooooooooooooookoooP0000?oooooooooo
oooooooooooooooooooooomoooooooooooooooooolmTJI7Vc9?VCC9Tdcooooooooooooooooookooo
P0000?oooooooooooooooooooooooooooooooomoooooooooooooooooolm0333Ph@7R@@9V43oooooo
ooooooooooookoooP0000?oooooooooooooooooooooooooooooooomooooooooooooooooooli0SW3`
h@7RHHIW>7ooooooooooooooooookoooP0000?oooooooooooooooooooooooooooooooomooooooooo
ooooooooon1Toooooh?VOoooooooooooooooooooooookoooP0000?oooooooooooooooooooooooooo
oooooomooooooooooooooooooo7doooool?fOoooooooooooooooooooooookoooP0000?oooooooooo
oooooooooooooooooooooomoooooooooooooooooooooooooooooooooooooooooooooooooooookooo
P0000?oooooooooooooooooooooooooooooooomooooooooooooooooooooooooooooooooooooooooo
ooooooooooookoooP0000?oooooooooooooooooooooooooooooooomooooooooooooooooooooooooo
ooooooooooooooooooooooooooookoooP0000?oooooooooooooooooooooooooooooooomooooooooo
ooooooooooooooooooooooooooooooooooooooooooookoooP0000?oooooooooooooooooooooooooo
ooooool000000000000000000000000000000000000000000000000000003oooP0000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooP0000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
P0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooP0000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooP00002D0000<00001`00P2D0000<0000
0000P300000<00003`00P4/0000@0000000000D0000>000050000000000@00005000
\>"], "Text",
  ImageSize->{360, 258},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Uranium model from",
  StyleBox[ButtonBox[" ICRP 78",
    ButtonData:>"ref 4"],
    ButtonBoxOptions -> {DefaultStyle -> "Hyperlink"}],
  ". "
}], "NumberedFigureCaption",
  CellTags->"fig 4"],

Cell["The number for each compartment is the following ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({{1, "\<Plasma\>"}, {2, "\<RBC\>"}, {3, "\<ST0\>"}, {4, "\<ST1\>"}, {5, \
"\<ST2\>"}, {6, "\<Liver1\>"}, {6, "\<Liver1\>"}, {7, "\<Liver2\>"}, {8, \
"\<UrinaryPath\>"}, {9, "\<OtherKidney\>"}, {10, "\<TrabecularSurface\>"}, \
{11, "\<ExchTrabVol\>"}, {12, "\<NonExchTrabVol\>"}, {13, \
"\<CorticalSurf\>"}, {14, "\<CorticalVolExch\>"}, {15, \
"\<CorticalVolNonExch\>"}, {16, "\<GI\>"}, {17, "\<Bladder\>"}} // 
      TableForm\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "\<\"Plasma\"\>"},
          {"2", "\<\"RBC\"\>"},
          {"3", "\<\"ST0\"\>"},
          {"4", "\<\"ST1\"\>"},
          {"5", "\<\"ST2\"\>"},
          {"6", "\<\"Liver1\"\>"},
          {"6", "\<\"Liver1\"\>"},
          {"7", "\<\"Liver2\"\>"},
          {"8", "\<\"UrinaryPath\"\>"},
          {"9", "\<\"OtherKidney\"\>"},
          {"10", "\<\"TrabecularSurface\"\>"},
          {"11", "\<\"ExchTrabVol\"\>"},
          {"12", "\<\"NonExchTrabVol\"\>"},
          {"13", "\<\"CorticalSurf\"\>"},
          {"14", "\<\"CorticalVolExch\"\>"},
          {"15", "\<\"CorticalVolNonExch\"\>"},
          {"16", "\<\"GI\"\>"},
          {"17", "\<\"Bladder\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[62]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["A",
    FontWeight->"Bold"],
  " matrix for this model can be easily constructed as follows (The values \
for the transfer coefficients were obtained from ",
  StyleBox[ButtonBox["ICRP 78",
    ButtonData:>"ref 4"],
    ButtonBoxOptions -> {DefaultStyle -> "Hyperlink"}],
  "):"
}], "Text"],

Cell[BoxData[
    \(uranium = 
      CompartMatrix[
        17, {{1, 3, 10.5}, {1, 2,  .245}, {1, 17, 15.43}, {1, 8, 2.94}, {1, 
            9,  .0122}, {1, 16,  .122}, {1, 6,  .367}, {1, 4, 1.63}, {1, 
            5,  .0735}, {1, 10, 2.04}, {1, 13, 1.63}, {3, 1, 8.32}, {2, 
            1,  .347}, {8, 17,  .099}, {9, 1,  .00038}, {6, 1,  .092}, {6, 
            7,  .00693}, {4, 1,  .0347}, {5, 1,  .000019}, {13, 
            1,  .0693}, {13, 14,  .0693}, {7, 1,  .00019}, {12, 
            1,  .000493}, {15, 1,  .0000821}, {14, 13,  .0173}, {14, 
            15,  .00578}, {10, 1,  .0693}, {11, 10,  .0173}, {10, 
            11,  .0693}}]; \)], "Input",
  CellLabel->"In[63]:="],

Cell["\<\
The input from outside of the system to plasma (compartment 1) is\
\>", "Text"],

Cell[BoxData[
    \(toPlasma = \ 
      34. \ \[ExponentialE]\^\(\(-200. \)\ t\) + 
        1.09\ \[ExponentialE]\^\(\(-110. \)\ t\) + 
        0.807\ \[ExponentialE]\^\(\(-102. \)\ t\) + 
        6.40\ \[ExponentialE]\^\(\(-100. \)\ t\) + 
        5.46\ \[ExponentialE]\^\(\(-24. \) t\); \)], "Input",
  CellLabel->"In[64]:="],

Cell[TextData[{
  "This input already represents the flow from respiratory tract to blood (",
  StyleBox[ButtonBox["ICRP 66",
    ButtonData:>"ref 3"],
    ButtonBoxOptions -> {DefaultStyle -> "Hyperlink"}],
  ") , it has been obtained by using the ",
  StyleBox[ButtonBox["Humorap",
    ButtonData:>{
      URL[ 
      "http://www.mathsource.com/Content/Applications/LifeScience/0211-554"], 
      None}],
    ButtonBoxOptions -> {DefaultStyle -> "Hyperlink"}],
  "  (it is included in this toolbox)."
}], "SmallText"],

Cell["Here is retention in each compartment", "Text"],

Cell[BoxData[
    \({x1[t_], x2[t_], x3[t_], x4[t_], x5[t_], \ x6[t_], x7[t_], x8[t_], \ 
        x9[t_], x10[t_], x11[t_], x12[t_], x13[t_], x14[t_], x15[t_], \ 
        x16[t_], x17[t_]} = 
      Table[x\_i[t], {i, 1, 17}] /. 
        SystemDSolve[
          uranium, {0, 0, 0, \ 0, \ 0, \ 0, \ 0, \ 0, \ 0, 0, 0, \ 0, \ 0, \ 
            0, \ 0, \ 0, \ 0}, {toPlasma, 0, 0, \ 0, \ 0, \ 0, \ 0, \ 0, \ 0, 
            0, 0, \ 0, \ 0, \ 0, \ 0, \ 0, \ 0}, t, t, \ x]; \)], "Input",
  CellLabel->"In[65]:="],

Cell["\<\
The instantaneous rate from Gastrointestinal to faecal and the urine \
excretion (from the bladder to environment)  is given by the derivative of \
x16(t) and x17(t) . \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({faecalExcretion, \ urineExcretion} = \ {Chop[D[x16[t], t]], 
        Chop[D[x17[t], t]]}\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \({\(-0.025207777251916523`\)\ \[ExponentialE]\^\(\(-200.`\)\ t\) - 
        0.0017934589638612319`\ \[ExponentialE]\^\(\(-110.`\)\ t\) - 
        0.001490066876800568`\ \[ExponentialE]\^\(\(-102.`\)\ t\) - 
        0.012189883039453647`\ \[ExponentialE]\^\(\(-100.`\)\ t\) - 
        0.028901547044064314`\ \[ExponentialE]\^\(\(-37.949485606994486`\)\ t\
\) + 0.02327397207421394`\ \[ExponentialE]\^\(\(-37.94948560699447`\)\ t\) + 
        0.040178164551963616`\ \[ExponentialE]\^\(\(-24.`\)\ t\) + 
        0.0028674849233827513`\ \[ExponentialE]\^\(\(-5.378003509886696`\)\ t\
\) + 0.003219964488219102`\ \[ExponentialE]\^\(\(-5.378003509886689`\)\ t\) + 
        1.330880427125499`*^-6\ \[ExponentialE]\^\(\(-0.34363680006588027`\)\ \
t\) + 3.741485279989459`*^-6\ \[ExponentialE]\^\(\(-0.3436368000658767`\)\ \
t\) + 2.7605469549742915`*^-6\ \[ExponentialE]\^\(\(-0.34363680006586605`\)\ \
t\) + 3.342475892067853`*^-9\ \[ExponentialE]\^\(\(-0.14801218733194332`\)\ t\
\) + 4.497445432377721`*^-9\ \[ExponentialE]\^\(\(-0.14801218733193622`\)\ \
t\) + 1.6098923368342884`*^-9\ \[ExponentialE]\^\(\(-0.1480121873319291`\)\ t\
\) + 0.000010213394963833466`\ \[ExponentialE]\^\(\(-0.13858997694737596`\)\ \
t\) + 0.000011250237992362872`\ \[ExponentialE]\^\(\(-0.1385899769473724`\)\ \
t\) + 2.481656235355719`*^-6\ \[ExponentialE]\^\(\(-0.0972716157285447`\)\ \
t\) + 2.249660077133804`*^-6\ \[ExponentialE]\^\(\(-0.09727161572854115`\)\ t\
\) + 1.1160709420608441`*^-6\ \[ExponentialE]\^\(\(-0.03217613397627872`\)\ t\
\) + 3.106374874805733`*^-6\ \[ExponentialE]\^\(\(-0.03217613397627517`\)\ \
t\) + 2.318508130686485`*^-6\ \[ExponentialE]\^\(\(-0.03217613397626451`\)\ t\
\) + 3.630374417859192`*^-7\ \[ExponentialE]\^\(\(-0.01312072411062104`\)\ \
t\) + 4.860633748184241`*^-7\ \[ExponentialE]\^\(\(-0.013120724110610382`\)\ \
t\) + 1.7474078086495874`*^-7\ \[ExponentialE]\^\(\(-0.01312072411060683`\)\ \
t\) + 2.626532484775821`*^-7\ \[ExponentialE]\^\(\(-0.007615450681853986`\)\ \
t\) + 7.304749728923204`*^-7\ \[ExponentialE]\^\(\(-0.007615450681850433`\)\ \
t\) + 5.456970052098795`*^-7\ \[ExponentialE]\^\(\(-0.007615450681839775`\)\ \
t\) + 3.5815504820847916`*^-10\ \[ExponentialE]\^\(\(-0.00037975541196288987`\
\)\ t\) + 
        3.964382814658308`*^-10\ \
\[ExponentialE]\^\(\(-0.00037975541195578444`\)\ t\) + 
        4.113323490082117`*^-10\ \
\[ExponentialE]\^\(\(-0.00018974401865534674`\)\ t\) + 
        3.716083488072681`*^-10\ \
\[ExponentialE]\^\(\(-0.00018974401865179402`\)\ t\) + 
        2.326651650734449`*^-9\ \[ExponentialE]\^\(\(-0.00008067050055160507`\
\)\ t\) + 
        2.101949607459479`*^-9\ \[ExponentialE]\^\(\(-0.00008067050054805236`\
\)\ t\) + 
        1.2591308751899195`*^-10\ \
\[ExponentialE]\^\(\(-0.00001892434519845665`\)\ t\) + 
        1.1375247831894423`*^-10\ \
\[ExponentialE]\^\(\(-0.000018924345191351222`\)\ t\), \(-3.1878631143510487`\
\)\ \[ExponentialE]\^\(\(-200.`\)\ t\) - 
        0.22678952496040938`\ \[ExponentialE]\^\(\(-110.`\)\ t\) - 
        0.18842193302026708`\ \[ExponentialE]\^\(\(-102.`\)\ t\) - 
        1.5414293464369833`\ \[ExponentialE]\^\(\(-100.`\)\ t\) - 
        3.6535133262932415`\ \[ExponentialE]\^\(\(-37.949485606994486`\)\ t\) \
+ 2.942118184859619`\ \[ExponentialE]\^\(\(-37.94948560699447`\)\ t\) + 
        5.077539344839824`\ \[ExponentialE]\^\(\(-24.`\)\ t\) + 
        0.361370429699346`\ \[ExponentialE]\^\(\(-5.378003509886696`\)\ t\) + 
        0.405791131188122`\ \[ExponentialE]\^\(\(-5.378003509886689`\)\ t\) + 
        0.0001553446859381825`\ \[ExponentialE]\^\(\(-0.34363680006588027`\)\ \
t\) + 0.0004367183136186341`\ \[ExponentialE]\^\(\(-0.3436368000658767`\)\ \
t\) + 0.00032222000639404487`\ \[ExponentialE]\^\(\(-0.34363680006586605`\)\ \
t\) + 2.600412555084383`*^-7\ \[ExponentialE]\^\(\(-0.14801218733194332`\)\ t\
\) + 3.4989672164625813`*^-7\ \[ExponentialE]\^\(\(-0.14801218733193622`\)\ t\
\) + 1.2524800118896523`*^-7\ \[ExponentialE]\^\(\(-0.1480121873319291`\)\ \
t\) + 0.0006762723452233535`\ \[ExponentialE]\^\(\(-0.13858997694737596`\)\ t\
\) + 0.0007449261345867371`\ \[ExponentialE]\^\(\(-0.1385899769473724`\)\ t\) \
+ 0.00004744556439711075`\ \[ExponentialE]\^\(\(-0.09900000000000375`\)\ t\) \
+ 0.0001323376934092402`\ \[ExponentialE]\^\(\(-0.0990000000000002`\)\ t\) + 
        0.00009853055755814595`\ \[ExponentialE]\^\(\(-0.09899999999998954`\)\
\ t\) + 0.003739368795763019`\ \[ExponentialE]\^\(\(-0.0972716157285447`\)\ t\
\) + 0.0033897961263366335`\ \[ExponentialE]\^\(\(-0.09727161572854115`\)\ \
t\) + 0.00018100136163366122`\ \[ExponentialE]\^\(\(-0.03217613397627872`\)\ \
t\) + 0.0005037834611536542`\ \[ExponentialE]\^\(\(-0.03217613397627517`\)\ t\
\) + 0.00037600936714477266`\ \[ExponentialE]\^\(\(-0.03217613397626451`\)\ t\
\) + 0.000056000537647291514`\ \[ExponentialE]\^\(\(-0.01312072411062104`\)\ \
t\) + 0.00007497796972836777`\ \[ExponentialE]\^\(\(-0.013120724110610382`\)\ \
t\) + 0.0000269547340054135`\ \[ExponentialE]\^\(\(-0.01312072411060683`\)\ t\
\) + 0.00004007615430487281`\ \[ExponentialE]\^\(\(-0.007615450681853986`\)\ \
t\) + 0.00011145732215064932`\ \[ExponentialE]\^\(\(-0.007615450681850433`\)\ \
t\) + 0.0000832635328565704`\ \[ExponentialE]\^\(\(-0.007615450681839775`\)\ \
t\) + 5.396199108988465`*^-8\ \[ExponentialE]\^\(\(-0.00037975541196288987`\)\
\ t\) + 5.972999436740004`*^-8\ \[ExponentialE]\^\(\(-0.00037975541195578444`\
\)\ t\) + 
        6.195489743290615`*^-8\ \[ExponentialE]\^\(\(-0.00018974401865534674`\
\)\ t\) + 
        5.597166668529219`*^-8\ \[ExponentialE]\^\(\(-0.00018974401865179402`\
\)\ t\) + 
        3.5037843653923127`*^-7\ \
\[ExponentialE]\^\(\(-0.00008067050055160507`\)\ t\) + 
        3.165397866558239`*^-7\ \[ExponentialE]\^\(\(-0.00008067050054805236`\
\)\ t\) + 
        1.895978847432437`*^-8\ \[ExponentialE]\^\(\(-0.00001892434519845665`\
\)\ t\) + 
        1.7128663666769707`*^-8\ \
\[ExponentialE]\^\(\(-0.000018924345191351222`\)\ t\)}\)], "Output",
  CellLabel->"Out[66]="]
}, Open  ]],

Cell[TextData[{
  "Sometime it is better obtain a shorter expression, although it means to \
reduce the precision.  It can be done using ",
  StyleBox[ButtonBox["SetPrecision"],
    ButtonBoxOptions -> {DefaultStyle -> "MainBookLink"}]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({faecalExcretionShort, \ 
        urineExcretionShort}\  = \ {faecalExcretion, \ urineExcretion} /. 
        x_?NumberQ\  :> \ SetPrecision[x, \ 3]\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \({\(-0.025207777251916523`3.000000000000001\)\ \
\[ExponentialE]\^\(\(-200.`2.9999999999999996\)\ t\) - 
        0.0017934589638612319`2.9999999999999996\ \
\[ExponentialE]\^\(\(-110.`2.9999999999999996\)\ t\) - 
        0.0014900668768005681`3.0000000000000013\ \
\[ExponentialE]\^\(\(-102.`2.9999999999999996\)\ t\) - 
        0.0121898830394536473`2.9999999999999996\ \
\[ExponentialE]\^\(\(-100.`2.9999999999999996\)\ t\) - 
        0.0056275749698503734`2.0328545105730247\ \
\[ExponentialE]\^\(\(-37.94948560699448592`2.9999999999999996\)\ t\) + 
        0.040178164551963616`2.999999999999999\ \
\[ExponentialE]\^\(\(-24.`3.000000000000001\)\ t\) + 
        0.0060874494116018533`2.9999999999999996\ \
\[ExponentialE]\^\(\(-5.3780035098866960652`3.000000000000001\)\ t\) + 
        7.8329126620892`2.9999999999999987*^-6\ \
\[ExponentialE]\^\(\(-0.3436368000658802657`2.9999999999999996\)\ t\) + 
        9.4498136612798626797`2.9999999999999987*^-9\ \
\[ExponentialE]\^\(\(-0.1480121873319433234`3.000000000000001\)\ t\) + 
        0.0000214636329561963`3.0000000000000013\ \
\[ExponentialE]\^\(\(-0.1385899769473759591`3. \)\ t\) + 
        4.7313163124895`2.9999999999999996*^-6\ \
\[ExponentialE]\^\(\(-0.0972716157285447025`3.000000000000001\)\ t\) + 
        6.540953947553`3.000000000000001*^-6\ \
\[ExponentialE]\^\(\(-0.0321761339762787202`2.9999999999999996\)\ t\) + 
        1.0238415974693`3.000000000000001*^-6\ \
\[ExponentialE]\^\(\(-0.0131207241106210404`3. \)\ t\) + 
        1.5388252265798`3.000000000000001*^-6\ \
\[ExponentialE]\^\(\(-0.0076154506818539858`2.9999999999999996\)\ t\) + 
        7.545933296743099624`2.9999999999999996*^-10\ \
\[ExponentialE]\^\(\(-0.0003797554119628899`2.9999999999999996\)\ t\) + 
        7.829406978154797499`2.9999999999999996*^-10\ \
\[ExponentialE]\^\(\(-0.0001897440186553467`2.999999999999999\)\ t\) + 
        4.4286012581939276653`2.9999999999999996*^-9\ \
\[ExponentialE]\^\(\(-0.0000806705005516051`3. \)\ t\) + 
        2.39665565837936174`3.0000000000000018*^-10\ \
\[ExponentialE]\^\(\(-0.0000189243451984566`3.000000000000001\)\ t\), \
\(-3.1878631143510487433`2.9999999999999996\)\ \
\[ExponentialE]\^\(\(-200.`2.9999999999999996\)\ t\) - 
        0.2267895249604093832`2.9999999999999996\ \
\[ExponentialE]\^\(\(-110.`2.9999999999999996\)\ t\) - 
        0.1884219330202670795`3.000000000000001\ \
\[ExponentialE]\^\(\(-102.`2.9999999999999996\)\ t\) - 
        1.5414293464369832609`3.000000000000001\ \
\[ExponentialE]\^\(\(-100.`2.9999999999999996\)\ t\) - 
        0.7113951414336225909`2.0328545105730242\ \
\[ExponentialE]\^\(\(-37.94948560699448592`2.9999999999999996\)\ t\) + 
        5.0775393448398240537`3.000000000000001\ \
\[ExponentialE]\^\(\(-24.`3.000000000000001\)\ t\) + 
        0.7671615608874680081`3. \ \
\[ExponentialE]\^\(\(-5.3780035098866960652`3.000000000000001\)\ t\) + 
        0.0009142830059508615`3.000000000000002\ \
\[ExponentialE]\^\(\(-0.3436368000658802657`2.9999999999999996\)\ t\) + 
        7.351859783436`2.9999999999999836*^-7\ \
\[ExponentialE]\^\(\(-0.1480121873319433234`3.000000000000001\)\ t\) + 
        0.0014211984798100906`2.999999999999999\ \
\[ExponentialE]\^\(\(-0.1385899769473759591`3. \)\ t\) + 
        0.0002783138153644969`2.999999999999999\ \
\[ExponentialE]\^\(\(-0.0990000000000037517`2.9999999999999996\)\ t\) + 
        0.0071291649220996526`3.0000000000000018\ \
\[ExponentialE]\^\(\(-0.0972716157285447025`3.000000000000001\)\ t\) + 
        0.0010607941899320881`2.9999999999999996\ \
\[ExponentialE]\^\(\(-0.0321761339762787202`2.9999999999999996\)\ t\) + 
        0.0001579332413810728`2.999999999999999\ \
\[ExponentialE]\^\(\(-0.0131207241106210404`3. \)\ t\) + 
        0.0002347970093120925`3.0000000000000013\ \
\[ExponentialE]\^\(\(-0.0076154506818539858`2.9999999999999996\)\ t\) + 
        1.136919854572846878769`2.9999999999999996*^-7\ \
\[ExponentialE]\^\(\(-0.0003797554119628899`2.9999999999999996\)\ t\) + 
        1.179265641181983401912`3.000000000000001*^-7\ \
\[ExponentialE]\^\(\(-0.0001897440186553467`2.999999999999999\)\ t\) + 
        6.669182231951`3.0000000000000018*^-7\ \
\[ExponentialE]\^\(\(-0.0000806705005516051`3. \)\ t\) + 
        3.60884521410940768766`3.0000000000000018*^-8\ \
\[ExponentialE]\^\(\(-0.0000189243451984566`3.000000000000001\)\ t\)}\)], \
"Output",
  CellLabel->"Out[67]="]
}, Open  ]],

Cell["\<\
Now we can compare both solutions. The differences are negligible. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[{faecalExcretionShort/faecalExcretion, \ 
        urineExcretionShort/urineExcretion}, \ {t, 1, 1000, 100}]\)], "Input",\

  CellLabel->"In[68]:="],

Cell[BoxData[
    \({{0.9999999999999915`, 0.9999999999999971`}, {0.9999999653827282`, 
        0.999999919808356`}, {0.9999999999983765`, 
        0.999999999998634`}, {0.9999999999971857`, 
        0.9999999999979953`}, {0.999999999996772`, 
        0.9999999999974084`}, {0.9999999999969438`, 
        0.9999999999969407`}, {0.9999999999966895`, 
        0.9999999999966711`}, {0.9999999999967137`, 
        0.9999999999966623`}, {0.9999999999969632`, 
        0.999999999996872`}, {0.9999999999950945`, 
        0.9999999999948737`}}\)], "Output",
  CellLabel->"Out[68]="]
}, Open  ]],

Cell["\<\
This shows the uranium retention for plasma, and the instantaneous rate \
transfer from the bladder (urine excretion), and from the gastrointestinal \
tract (faecal excretion).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LogLogPlot[{faecalExcretion, \ urineExcretion}, {t, \ 0, \ 1000}, \ 
      PlotStyle \[Rule] {\[IndentingNewLine]{AbsoluteThickness[0.5], \ 
            AbsoluteDashing[{4, 4}]}, {AbsoluteThickness[1.5], \ 
            AbsoluteDashing[{1, 6}]}}, \ 
      AxesLabel \[Rule] {"\<days\>", \ "\<r\>"}, \[IndentingNewLine]PlotLabel \
\[Rule] "\<Uranium Model\>"]; \)], "Input",
  CellLabel->"In[69]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.426953 0.183079 0.736579 0.087984 [
[.06079 -0.0125 -14 -12.5 ]
[.06079 -0.0125 14 0 ]
[.24387 -0.0125 -11 -12.5 ]
[.24387 -0.0125 11 0 ]
[.42695 -0.0125 -5 -12.5 ]
[.42695 -0.0125 5 0 ]
[.61003 -0.0125 -8 -12.5 ]
[.61003 -0.0125 8 0 ]
[.79311 -0.0125 -11 -12.5 ]
[.79311 -0.0125 11 0 ]
[.97619 -0.0125 -14 -12.5 ]
[.97619 -0.0125 14 0 ]
[1.025 0 0 -6.25 ]
[1.025 0 28 6.25 ]
[-0.0125 .03271 -46.875 -6.59375 ]
[-0.0125 .03271 0 6.59375 ]
[-0.0125 .20867 -46.875 -6.59375 ]
[-0.0125 .20867 0 6.59375 ]
[-0.0125 .38464 -40 -6.25 ]
[-0.0125 .38464 0 6.25 ]
[-0.0125 .56061 -28 -6.25 ]
[-0.0125 .56061 0 6.25 ]
[0 .64303 -5 0 ]
[0 .64303 5 12.5 ]
[.5 .63053 -41.0938 0 ]
[.5 .63053 41.0938 12.5 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.06079 0 m
.06079 .00625 L
s
gsave
.06079 -0.0125 -75 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.24387 0 m
.24387 .00625 L
s
gsave
.24387 -0.0125 -72 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.42695 0 m
.42695 .00625 L
s
gsave
.42695 -0.0125 -66 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.61003 0 m
.61003 .00625 L
s
gsave
.61003 -0.0125 -69 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.79311 0 m
.79311 .00625 L
s
gsave
.79311 -0.0125 -72 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -75 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
87.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.11591 0 m
.11591 .00375 L
s
.14815 0 m
.14815 .00375 L
s
.17102 0 m
.17102 .00375 L
s
.18876 0 m
.18876 .00375 L
s
.20326 0 m
.20326 .00375 L
s
.21551 0 m
.21551 .00375 L
s
.22613 0 m
.22613 .00375 L
s
.2355 0 m
.2355 .00375 L
s
.29899 0 m
.29899 .00375 L
s
.33122 0 m
.33122 .00375 L
s
.3541 0 m
.3541 .00375 L
s
.37184 0 m
.37184 .00375 L
s
.38634 0 m
.38634 .00375 L
s
.39859 0 m
.39859 .00375 L
s
.40921 0 m
.40921 .00375 L
s
.41858 0 m
.41858 .00375 L
s
.48207 0 m
.48207 .00375 L
s
.5143 0 m
.5143 .00375 L
s
.53718 0 m
.53718 .00375 L
s
.55492 0 m
.55492 .00375 L
s
.56942 0 m
.56942 .00375 L
s
.58167 0 m
.58167 .00375 L
s
.59229 0 m
.59229 .00375 L
s
.60165 0 m
.60165 .00375 L
s
.66514 0 m
.66514 .00375 L
s
.69738 0 m
.69738 .00375 L
s
.72026 0 m
.72026 .00375 L
s
.738 0 m
.738 .00375 L
s
.7525 0 m
.7525 .00375 L
s
.76475 0 m
.76475 .00375 L
s
.77537 0 m
.77537 .00375 L
s
.78473 0 m
.78473 .00375 L
s
.84822 0 m
.84822 .00375 L
s
.88046 0 m
.88046 .00375 L
s
.90334 0 m
.90334 .00375 L
s
.92108 0 m
.92108 .00375 L
s
.93557 0 m
.93557 .00375 L
s
.94783 0 m
.94783 .00375 L
s
.95845 0 m
.95845 .00375 L
s
.96781 0 m
.96781 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .03271 m
.00625 .03271 L
s
gsave
-0.0125 .03271 -107.875 -10.5938 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.375 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
101.000 9.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
105.375 9.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .20867 m
.00625 .20867 L
s
gsave
-0.0125 .20867 -107.875 -10.5938 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.375 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
101.000 9.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
105.375 9.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .38464 m
.00625 .38464 L
s
gsave
-0.0125 .38464 -101 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0001) show
99.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .56061 m
.00625 .56061 L
s
gsave
-0.0125 .56061 -89 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .12766 m
.00375 .12766 L
s
0 .15252 m
.00375 .15252 L
s
0 .16745 m
.00375 .16745 L
s
0 .17816 m
.00375 .17816 L
s
0 .18652 m
.00375 .18652 L
s
0 .19337 m
.00375 .19337 L
s
0 .19918 m
.00375 .19918 L
s
0 .20422 m
.00375 .20422 L
s
0 .30363 m
.00375 .30363 L
s
0 .32849 m
.00375 .32849 L
s
0 .34342 m
.00375 .34342 L
s
0 .35413 m
.00375 .35413 L
s
0 .36249 m
.00375 .36249 L
s
0 .36934 m
.00375 .36934 L
s
0 .37515 m
.00375 .37515 L
s
0 .38019 m
.00375 .38019 L
s
0 .47959 m
.00375 .47959 L
s
0 .50445 m
.00375 .50445 L
s
0 .51939 m
.00375 .51939 L
s
0 .5301 m
.00375 .5301 L
s
0 .53846 m
.00375 .53846 L
s
0 .54531 m
.00375 .54531 L
s
0 .55112 m
.00375 .55112 L
s
0 .55616 m
.00375 .55616 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -102.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Uranium) show
111.188 12.750 moveto
(Model) show
141.188 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ 4 4 ] 0 Mabsdash
0 .38864 m
.4437 .35345 L
.49514 .34029 L
.52806 .33469 L
.55298 .32909 L
.58409 .32012 L
.60532 .31263 L
.66414 .28656 L
.72138 .25846 L
.78001 .2261 L
.81256 .20409 L
.83485 .18724 L
.85163 .17308 L
.8663 .15913 L
.87825 .14632 L
.88925 .13318 L
.89858 .12091 L
.90662 .10947 L
.91437 .09772 L
.92118 .08687 L
.92783 .07592 L
.93375 .06605 L
.93905 .05726 L
.94433 .04878 L
.94911 .04154 L
.95345 .03546 L
.95782 .02994 L
.96181 .02552 L
.96584 .02169 L
.96954 .01875 L
.97295 .01649 L
.97619 .01472 L
s
1.5 Mabswid
[ 1 6 ] 0 Mabsdash
0 .58507 m
.4437 .56347 L
.49514 .55525 L
.52806 .55061 L
.55298 .54578 L
.58409 .53761 L
.60532 .53029 L
.64116 .51388 L
.66414 .50031 L
.72138 .45909 L
.78001 .41921 L
.81157 .39731 L
.83334 .38076 L
.8514 .36552 L
.8656 .35202 L
.87835 .33836 L
.88896 .32568 L
.89798 .31384 L
.90657 .30163 L
.91405 .29029 L
.9213 .27873 L
.9277 .26816 L
.93341 .2586 L
.93907 .2492 L
.94416 .24099 L
.94877 .23393 L
.9534 .22738 L
.95761 .222 L
.96186 .21725 L
.96574 .21352 L
.96931 .21063 L
.97294 .20819 L
.97619 .20639 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[69]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<`3oool2000000@0oooo0P0000040?ooo`800000
0`3oool5000001<0oooo0P0000040?ooo`8000000`3oool5000001X0oooo1@00000N0?ooo`D00000
0P3oool2000001T0oooo1@0000020?ooo`800000103oool2000001@0oooo1@0000020?ooo`800000
103oool2000000@0oooo0P00000M0?ooo`00<P3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool04P3oool010000000oooo0?ooo`00000:0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0803oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0603oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool06P3oool00380oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo0200oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo01P0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01X0
oooo000b0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0B0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0P0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0H0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0J0?ooo`00<P3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
4P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0803oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0603oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0C0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool06P3oool003<0oooo0P00000:0?ooo`80
0000103oool2000001D0oooo0P00000:0?ooo`8000007@3oool200000240oooo0P0000040?ooo`80
00006P3oool2000000@0oooo0P0000040?ooo`8000005@3oool2000000@0oooo0P0000040?ooo`80
0000103oool2000001d0oooo003o0?ooob40oooo003o0?oooa<0oooo0P00000<0?ooo`00o`3ooolD
0?ooo`030000003oool0oooo00X0oooo003o0?ooo`P0oooo100000000`3oool00000000000030000
00<0oooo00@000000?ooo`3oool0oooo0`0000050?ooo`00o`3oool70?ooo`040000003oool0oooo
00000080oooo100000030?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool0
0340ooooc@0000080?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`03000000D0oooo000a0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00/0oooo0`000003
0?ooo`<0000000D0oooo00000000000000000?ooo`02000000030?ooo`000000000000800000103o
ool00340oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`0D0?ooo`00<@3oool00`00
0000oooo0?ooo`340?ooo`8000003P3oool2000001H0oooo00030?ooo`D000000P3oool2000000@0
oooo00D000000?ooo`3oool0oooo000000030?ooo`D000000P3oool200000100oooo00<000000?oo
o`3oool0k03oool000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo000000060?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0>`0oooo00050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool03@3oool200000<80oooo00<000000?oo
o`3oool0:03oool000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo000000060?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0<00oooo00<000000?ooo`3oool0:@3oool000D0oooo00<000000?ooo`3oool0203oool01@000000
oooo0?ooo`3oool0000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00D0oooo0P0000060?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0:P3oool0
00@0oooo0P00000C0?ooo`800000103oool2000000<0oooo0`0000020?ooo`8000001P3oool00`00
0000oooo0?ooo`2n0?ooo`030000003oool0oooo02/0oooo000Y0?ooo`8000001P3oool00`000000
oooo0?ooo`3/0?ooo`00:@3oool2000000H0oooo00<000000?ooo`3oool0k03oool00340oooo00<0
00000?ooo`3oool0_03oool00`000000oooo0?ooo`0]0?ooo`00<@3oool00`000000oooo0?ooo`2l
0?ooo`030000003oool0oooo02d0oooo000a0?ooo`030000003oool0oooo0;/0oooo00<000000?oo
o`3oool0;P3oool00340oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0^0?ooo`00
<@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo02l0oooo000a0?ooo`030000003o
ool0oooo0>`0oooo000a0?ooo`030000003oool0oooo0>`0oooo000a0?ooo`030000003oool0oooo
0;P0oooo00<000000?ooo`3oool0<@3oool00340oooo00<000000?ooo`3oool0^03oool00`000000
oooo0?ooo`0a0?ooo`00<@3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo0380oooo
000a0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0<`3oool00340oooo00<00000
0?ooo`3oool0k03oool00340oooo00<000000?ooo`3oool0k03oool00340oooo00<000000?ooo`3o
ool0k03oool00340oooo0P00002e0?ooo`030000003oool0oooo03D0oooo000a0?ooo`030000003o
ool0oooo0;<0oooo00<000000?ooo`3oool0=P3oool00340oooo00<000000?ooo`3oool0/P3oool0
0`000000oooo0?ooo`0g0?ooo`00<@3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo
03P0oooo000a0?ooo`030000003oool0oooo0>`0oooo000a0?ooo`800000k@3oool00340oooo00<0
00000?ooo`3oool0[P3oool00`000000oooo0?ooo`0k0?ooo`00<@3oool00`000000oooo0?ooo`2]
0?ooo`030000003oool0oooo03`0oooo000a0?ooo`800000[@3oool00`000000oooo0?ooo`0m0?oo
o`00<@3oool00`000000oooo0?ooo`3/0?ooo`00<@3oool200000>d0oooo000a0?ooo`030000003o
ool0oooo0:T0oooo00<000000?ooo`3oool0@03oool00340oooo0P00002Y0?ooo`030000003oool0
oooo0440oooo000a0?ooo`800000Y`3oool2000004@0oooo00030?ooo`D000000P3oool2000000@0
oooo00D000000?ooo`3oool0oooo000000030?ooo`D000000P3oool200000100oooo0P00002V0?oo
o`030000003oool0oooo04@0oooo00050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`00
00001P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool03@3oool20000
0>d0oooo00050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool03@3oool200000:<0oooo00<000000?oo
o`3oool0A`3oool000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo000000060?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0:00oooo0P00000P0?ooo`800000:03oool000D0oooo00<000000?ooo`3oool0203oool01@000000
oooo0?ooo`3oool0000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00D0oooo0`0000050?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0W0?ooo`00103oool2000001<0oooo0P0000040?ooo`8000000`3oool30000
0080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`3/0?ooo`00:@3oool2000000H0
oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`1>0?ooo`00:@3oool3000000D0oooo
00<000000?ooo`3oool0V@3oool200000540oooo000a0?ooo`030000003oool0oooo09P0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0[0?ooo`00<@3oool00`000000oooo0?ooo`2n
0?ooo`030000003oool0oooo02/0oooo000a0?ooo`030000003oool0oooo09@0oooo00<000000?oo
o`3oool0E@3oool00340oooo00<000000?ooo`3oool0TP3oool2000005P0oooo000a0?ooo`030000
003oool0oooo0940oooo00<000000?ooo`3oool0F03oool00340oooo00<000000?ooo`3oool0k03o
ool00340oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo02h0oooo000a0?ooo`030000003oool0oooo08/0oooo0P00000]0?ooo`030000003oool0oooo
02l0oooo000a0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0G`3oool00340oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1S0?ooo`00<@3oool00`000000oooo0?oo
o`250?ooo`030000003oool0oooo06@0oooo000a0?ooo`030000003oool0oooo08<0oooo0P00001W
0?ooo`00<@3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo0380oooo000a0?ooo`03
0000003oool0oooo07h0oooo0P00000f0?ooo`030000003oool0oooo03<0oooo000a0?ooo`800000
O03oool3000006h0oooo000a0?ooo`030000003oool0oooo0>`0oooo000a0?ooo`030000003oool0
oooo07L0oooo0P00001c0?ooo`00<@3oool00`000000oooo0?ooo`1d0?ooo`<00000M@3oool00340
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo03H0
oooo000a0?ooo`800000K@3oool400000480oooo00<000000?ooo`3oool0=`3oool00340oooo00<0
00000?ooo`3oool0I`3oool2000008<0oooo000a0?ooo`030000003oool0oooo06@0oooo0`000025
0?ooo`00<@3oool200000600oooo0P00002;0?ooo`00<@3oool00`000000oooo0?ooo`1L0?ooo`<0
0000C`3oool00`000000oooo0?ooo`0k0?ooo`00<@3oool200000540oooo0P0000030?ooo`D00000
E03oool00`000000oooo0?ooo`0k0?ooo`00<@3oool00`000000oooo0?ooo`150?ooo`D000000`3o
ool3000009`0oooo000a0?ooo`800000>@3oool2000000<0oooo1@00002Z0?ooo`00<@3oool20000
02h0oooo1@0000030?ooo`<00000]03oool00340oooo0P00000Q0?ooo`8000000`3oool5000007l0
oooo00<000000?ooo`3oool0@03oool000X0oooo0P0000040?ooo`800000103oool2000000@0oooo
0P0000040?ooo`8000000`3oool5000000D0oooo0P00000A0?ooo`8000000`3oool5000000<0oooo
0`0000280?ooo`030000003oool0oooo0440oooo00090?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool01@3oool2000000H0oooo1@0000030?ooo`<00000g03oool0
00T0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`D0
0000jP3oool000T0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0A@3oool000T0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0:<0oooo00<000000?ooo`3oool0AP3oool000X0oooo0P00000:0?ooo`800000103oool2000000@0
oooo0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`3/0?ooo`00<@3oool00`000000oooo
0?ooo`3/0?ooo`00<@3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo04/0oooo000a
0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0C03oool00340oooo00<000000?oo
o`3oool0k03oool00340oooo00<000000?ooo`3oool0k03oool00340oooo00<000000?ooo`3oool0
V03oool00`000000oooo0?ooo`1A0?ooo`00<@3oool00`000000oooo0?ooo`2G0?ooo`030000003o
ool0oooo0580oooo000a0?ooo`030000003oool0oooo0>`0oooo000a0?ooo`030000003oool0oooo
0>`0oooo000a0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0E`3oool00340oooo
00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`1G0?ooo`00<@3oool00`000000oooo0?oo
o`3/0?ooo`00<@3oool00`000000oooo0?ooo`3/0?ooo`00<@3oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo05`0oooo000a0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool0G@3oool00340oooo0P00003]0?ooo`00<@3oool00`000000oooo0?ooo`3/0?ooo`00<@3oool0
0`000000oooo0?ooo`270?ooo`030000003oool0oooo0680oooo000a0?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool0H`3oool00340oooo00<000000?ooo`3oool0k03oool00340oooo
0P00003]0?ooo`00<@3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo06P0oooo000a
0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0J@3oool00340oooo0P00003]0?oo
o`00<@3oool00`000000oooo0?ooo`1j0?ooo`800000L03oool00340oooo0P00003]0?ooo`00<@3o
ool00`000000oooo0?ooo`3/0?ooo`00<@3oool2000007@0oooo0P00001g0?ooo`00<@3oool20000
06d0oooo0P00001n0?ooo`00<@3oool200000>d0oooo000F0?ooo`800000103oool2000000@0oooo
0P0000030?ooo`D000001@3oool2000006L0oooo0P0000240?ooo`005@3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool200000600
oooo0P00002;0?ooo`005@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1:0?ooo`8000001@3oool20000
00D0oooo0P00002B0?ooo`005@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo00<0oooo0P0000050?ooo`800000Y`3oool001D0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`030?ooo`8000001@3oool2000000D0oooo00<000000?ooo`3oool0]03o
ool001H0oooo0P00000:0?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool04P3oool2
000000D0oooo0P0000050?ooo`030000003oool0oooo0<T0oooo000a0?ooo`8000001@3oool20000
00D0oooo0P00003O0?ooo`00<@3oool00`000000oooo0?ooo`3/0?ooo`00<@3oool00`000000oooo
0?ooo`3/0?ooo`00<@3oool00`000000oooo0?ooo`3/0?ooo`00<@3oool00`000000oooo0?ooo`3/
0?ooo`00<@3oool00`000000oooo0?ooo`3/0?ooo`00<@3oool00`000000oooo0?ooo`3/0?ooo`00
<@3oool00`000000oooo0?ooo`3/0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00LP3oool2000000<0oooo10000002
0?ooo`L000000P3oool200000080oooo0`0000030?ooo`H0000000@0oooo0000003oool000001P3o
ool2000000040?ooo`000000000000000080oooo0P0000040?ooo`@000000P3oool300000080oooo
0`00001T0?ooo`00L@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo
100000020?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`080000003oool0oooo0000003oool000000?ooo`0000060?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1S0?ooo`00L@3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`0000000P3oool020000000oooo0?ooo`000000oooo0000
003oool000001P3oool01@000000oooo0000003oool000000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`@000000`3oool00`000000oooo0?ooo`1S0?ooo`00
;`3oool4000003h0oooo00@000000?ooo`3oool000000P3oool4000000<0oooo0`0000000`3oool0
000000000002000000@0oooo0P0000020?ooo`80000000@0oooo000000000000oooo0`0000000`3o
ool000000?ooo`060?ooo`80000000<0oooo0000000000000`3oool2000000@0oooo0`0000030?oo
o`800000103oool00`000000oooo0?ooo`1S0?ooo`00<03oool00`000000oooo0?ooo`0n0?ooo`04
0000003oool0oooo000002/0oooo0P0000000`3oool000000000000;0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0H`3oool00300oooo00<000000?ooo`3oool0?@3oool200000004
0?ooo`0000000000000001D0oooo00<000000?ooo`3oool04P3oool2000000040?ooo`0000000000
000000T0oooo0P0000080?ooo`800000I@3oool002l0oooo1000003]0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.65266, -9.70651, \
0.0267154, 0.05559}}]
}, Open  ]],

Cell[TextData[{
  "The multiexponential input illustrated above frequently appears when the \
inputs to a system, ",
  StyleBox["b",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\(\((t)\)\(,\)\)\)]],
  " are outputs from other parts (compartments) of the system. We usually \
study those subsystems separately under the title of 'divide and conquer' in \
complex systems analysis. Specifically, a) the complex problem to be solved \
is decomposed into small, more manageable subproblems, b) solutions are \
programmed for each sub-problem, and c) the programmed solutions are \
interfaced in a fashion so as to provide a solution path for the original \
complex problem. Of course, in conjunction with these steps, a number of \
allied and fairly sophisticated concepts will need to be negotiated. But ",
  StyleBox["SysModel.m",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " considerably simplify these tasks of complex system analysis."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Solving compartmental models with variable transfer coefficients\
\>", "SubsectionIcon"],

Cell[TextData[{
  "Sometime we need to solve models where the rate transfer are not \
constants. In these cases we should use the command ",
  Cell[BoxData[GridBox[{
          {
            ButtonBox[
              StyleBox["SystemNDSolve",
                FontColor->RGBColor[0, 0, 1],
                FontVariations->{"Underline"->True}],
              
              ButtonFunction:>(
                Internal`PutInformation[ #, LongForm -> False]&),
              
              ButtonData:>{"Info3234081075-1445498", 
                "Biokmod`SysModel`SystemNDSolve"},
              ButtonFrame->"None",
              ButtonNote->"Biokmod`SysModel`"], ""}
          },
        RowMinHeight->{1, 1.05}]],
    CellMargins->{{20, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
    Background->GrayLevel[0.930022],
    ButtonBoxOptions->{Active->True}],
  ".  Here is an example. The compartmental matrix of the model drawn in \
figure1 is given by "
}], "Text"],

Cell[TextData[{
  " Here is an example. The compartmental matrix of the model drawn in the \
previous figure where the rate transfer coefficients are ",
  Cell[BoxData[
      \(TraditionalForm\`k\_10\)]],
  "= 1.9404, ",
  Cell[BoxData[
      \(TraditionalForm\`k\_12\)]],
  "= 0.8316 (1+Cos[0.2 t]),  ",
  Cell[BoxData[
      \(TraditionalForm\`k\_23\)]],
  " = 0.0086625 (1+Cos[0.3 t]), ",
  Cell[BoxData[
      \(TraditionalForm\`k\_30\)]],
  "= 0.01155 and ",
  Cell[BoxData[
      \(TraditionalForm\`k\_31\)]],
  "= 0.0462 (1+Cos[1.2 t]). Then the coefficients matrix is given by "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(iodineNonLinear\  = 
      CompartMatrix[
        3, {{1, 2, \ 0.8316 \((1 + Cos[0.2\ t])\)}, {1, 0, 1.9404}, {2, 3, 
            0.0086625 \((1 + Cos[0.3\ t])\)}\ , {3, 0, 0.01155}\ , {3, 1, 
            0.0462 \((1 + Cos[1.2\ t])\)}}, \ Log[2]/8]\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \({{\(-2.027043397569993`\) - 0.8316`\ \((1 + Cos[0.2`\ t])\), 0, 
        0.0462`\ \((1 + Cos[1.2`\ t])\)}, {0.8316`\ \((1 + 
              Cos[0.2`\ t])\), \(-0.0086625`\)\ \((1 + Cos[0.3`\ t])\) - 
          Log[2]\/8, 0}, {0, 
        0.0086625`\ \((1 + Cos[0.3`\ t])\), \(-0.09819339756999317`\) - 
          0.0462`\ \((1 + Cos[1.2`\ t])\)}}\)], "Output",
  CellLabel->"Out[70]="]
}, Open  ]],

Cell[TextData[{
  "We suppose an input function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(b\_1\),
            "TraditionalForm"], "(", "t", ")"}], TraditionalForm]]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(=\)\(\ \)\(1 + Cos[0.1\ t]\)\)\)]],
  ", in mg/day,  into compartment 1. Not inputs are assumed in other \
compartments"
}], "Text"],

Cell[BoxData[
    \(b1Iodine\  = \ {1 + \ Cos[0.1\ t], \ 0, \ 0}; \)], "Input",
  CellLabel->"In[71]:="],

Cell[TextData[{
  "It is assumed that the initial concentration of iodine in all compartment \
is \"0\", that is  ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  "(0) =  ",
  Cell[BoxData[
      \(TraditionalForm\`x\_2\)]],
  "(0)  = ",
  Cell[BoxData[
      \(TraditionalForm\`x\_3\)]],
  "(0) = 0 "
}], "Text"],

Cell[BoxData[
    \(icIodine\  = \ {0, 0, 0}; \)], "Input",
  CellLabel->"In[72]:="],

Cell[TextData[{
  "Them  it is applied the SysModel command ",
  Cell[BoxData[
      ButtonBox[
        StyleBox["SystemNDSolve",
          FontColor->RGBColor[0, 0, 1],
          FontVariations->{"Underline"->True}],
        ButtonFunction:>(Internal`PutInformation[ #, LongForm -> False]&),
        ButtonData:>{"Info3234081075-1445498", 
          "Biokmod`SysModel`SystemNDSolve"},
        ButtonFrame->"None",
        ButtonNote->"Biokmod`SysModel`"]],
    CellMargins->{{20, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
    Background->GrayLevel[0.930022],
    ButtonBoxOptions->{Active->True}],
  " . "
}], "Text"],

Cell[BoxData[
    \({\ x1[t_], x2[t_], x3[t_]}\  = \ 
      Map[Last, 
        SystemNDSolve[iodineNonLinear, icIodine, b1Iodine, {t, \ 0, \ 200}, 
          t, \ x]]; \)], "Input",
  CellLabel->"In[73]:="],

Cell["Now we plot the evolution in each compartment", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{\ x1[t], x2[t], x3[t]}, \ {t, \ 1, \ 200}, \ 
      PlotRange \[Rule] \ {0, 7}]\)], "Input",
  CellLabel->"In[74]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 -2.08167e-017 0.0882906 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .08829 -6 -4.5 ]
[.01131 .08829 0 4.5 ]
[.01131 .17658 -6 -4.5 ]
[.01131 .17658 0 4.5 ]
[.01131 .26487 -6 -4.5 ]
[.01131 .26487 0 4.5 ]
[.01131 .35316 -6 -4.5 ]
[.01131 .35316 0 4.5 ]
[.01131 .44145 -6 -4.5 ]
[.01131 .44145 0 4.5 ]
[.01131 .52974 -6 -4.5 ]
[.01131 .52974 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .08829 m
.03006 .08829 L
s
[(1)] .01131 .08829 1 0 Mshowa
.02381 .17658 m
.03006 .17658 L
s
[(2)] .01131 .17658 1 0 Mshowa
.02381 .26487 m
.03006 .26487 L
s
[(3)] .01131 .26487 1 0 Mshowa
.02381 .35316 m
.03006 .35316 L
s
[(4)] .01131 .35316 1 0 Mshowa
.02381 .44145 m
.03006 .44145 L
s
[(5)] .01131 .44145 1 0 Mshowa
.02381 .52974 m
.03006 .52974 L
s
[(6)] .01131 .52974 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(7)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01766 m
.02756 .01766 L
s
.02381 .03532 m
.02756 .03532 L
s
.02381 .05297 m
.02756 .05297 L
s
.02381 .07063 m
.02756 .07063 L
s
.02381 .10595 m
.02756 .10595 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14126 m
.02756 .14126 L
s
.02381 .15892 m
.02756 .15892 L
s
.02381 .19424 m
.02756 .19424 L
s
.02381 .2119 m
.02756 .2119 L
s
.02381 .22956 m
.02756 .22956 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .28253 m
.02756 .28253 L
s
.02381 .30019 m
.02756 .30019 L
s
.02381 .31785 m
.02756 .31785 L
s
.02381 .3355 m
.02756 .3355 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .38848 m
.02756 .38848 L
s
.02381 .40614 m
.02756 .40614 L
s
.02381 .42379 m
.02756 .42379 L
s
.02381 .45911 m
.02756 .45911 L
s
.02381 .47677 m
.02756 .47677 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .51209 m
.02756 .51209 L
s
.02381 .5474 m
.02756 .5474 L
s
.02381 .56506 m
.02756 .56506 L
s
.02381 .58272 m
.02756 .58272 L
s
.02381 .60038 m
.02756 .60038 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02857 .04671 m
.04729 .04998 L
.05682 .05169 L
.06701 .05349 L
.0698 .05395 L
.07117 .05413 L
.07244 .05426 L
.07359 .05435 L
.0748 .0544 L
.07603 .05441 L
.07672 .0544 L
.07737 .05437 L
.07862 .05429 L
.0798 .05416 L
.08086 .05401 L
.08202 .0538 L
.08461 .05318 L
.08702 .05241 L
.08989 .05123 L
.09259 .04986 L
.09763 .04653 L
.10306 .04176 L
.10894 .03549 L
.12839 .01602 L
.13372 .01171 L
.13665 .00972 L
.13943 .00814 L
.14482 .0058 L
.14974 .00407 L
.15448 .00257 L
.15707 .00187 L
.15951 .00133 L
.16158 .00096 L
.16381 .00067 L
.16502 .00055 L
.16629 .00045 L
.16737 .00039 L
.16856 .00033 L
.16994 .00028 L
.17124 .00025 L
.17241 .00022 L
.17368 .0002 L
.17434 .0002 L
.17507 .00019 L
.17582 .00019 L
.17653 .00019 L
.1778 .0002 L
.17851 .00021 L
.17916 .00023 L
.18042 .00027 L
Mistroke
.18158 .00032 L
.18286 .0004 L
.18422 .00051 L
.18674 .00079 L
.18903 .00113 L
.19389 .00212 L
.19903 .00351 L
.20821 .00693 L
.21333 .00957 L
.2181 .01267 L
.22894 .02163 L
.24752 .04083 L
.25262 .04549 L
.25802 .04936 L
.26263 .05176 L
.26525 .05277 L
.26771 .05348 L
.26895 .05375 L
.2703 .05398 L
.27099 .05407 L
.27172 .05414 L
.27303 .05424 L
.27435 .05427 L
.27559 .05426 L
.2767 .05421 L
.27791 .05412 L
.27923 .05399 L
.28068 .05382 L
.28362 .05337 L
.28888 .05241 L
.29936 .05046 L
.30432 .0496 L
.30892 .04888 L
.31123 .04858 L
.31241 .04846 L
.31368 .04836 L
.31495 .04829 L
.31615 .04824 L
.31684 .04823 L
.31757 .04823 L
.31887 .04824 L
.32 .04826 L
.3212 .0483 L
.32224 .04833 L
.32337 .04836 L
.32406 .04837 L
.3247 .04838 L
.32596 .04839 L
.3271 .04839 L
.3283 .04838 L
Mistroke
.32957 .04836 L
.33077 .04834 L
.33143 .04833 L
.33215 .04833 L
.33342 .04834 L
.33462 .04837 L
.3359 .04844 L
.33711 .04856 L
.33821 .04871 L
.33961 .04895 L
.3409 .04923 L
.34382 .04998 L
.34659 .0507 L
.34911 .05124 L
.35026 .05143 L
.35151 .0516 L
.35379 .05184 L
.35622 .05204 L
.35755 .05215 L
.3588 .05228 L
.36104 .05258 L
.3635 .05304 L
.36785 .05407 L
.37037 .05459 L
.37163 .05478 L
.37235 .05486 L
.37302 .05492 L
.37422 .05496 L
.37531 .05495 L
.37656 .05488 L
.37775 .05474 L
.37904 .05453 L
.38041 .05425 L
.38287 .05359 L
.38842 .05157 L
.39333 .04915 L
.39782 .04612 L
.40299 .04134 L
.40791 .03587 L
.42613 .01758 L
.43107 .01324 L
.43571 .00982 L
.43828 .00834 L
.44106 .00706 L
.4459 .00528 L
.45054 .0037 L
.45544 .00215 L
.45746 .00163 L
.45962 .00116 L
.46087 .00095 L
Mistroke
.462 .00079 L
.46306 .00067 L
.46421 .00057 L
.46539 .00049 L
.46649 .00043 L
.46781 .00038 L
.46901 .00035 L
.47026 .00033 L
.47162 .0003 L
.47293 .00029 L
.47411 .00027 L
.47529 .00026 L
.4764 .00026 L
.47758 .00027 L
.47885 .00029 L
.47996 .00032 L
.48114 .00037 L
.48215 .00043 L
.48325 .00051 L
.48464 .00064 L
.48595 .0008 L
.48841 .00117 L
.49106 .00169 L
.49394 .00237 L
.49909 .00383 L
.50393 .0055 L
.51327 .01002 L
.51824 .01337 L
.52359 .01765 L
.54449 .03856 L
.54948 .04351 L
.55482 .04781 L
.5574 .04949 L
.55985 .05084 L
.56207 .05187 L
.56442 .05276 L
.56561 .05314 L
.56692 .05349 L
.56813 .05376 L
.56923 .05395 L
.57053 .05412 L
.57125 .05419 L
.57193 .05424 L
.57313 .05429 L
.57445 .05428 L
.57519 .05426 L
.57589 .05423 L
.5772 .05413 L
.57861 .05399 L
.58014 .05379 L
Mistroke
.58541 .05292 L
.59569 .05098 L
.60528 .04931 L
.60776 .04893 L
.61011 .04862 L
.61141 .04848 L
.61209 .04842 L
.61282 .04836 L
.6141 .04829 L
.61528 .04825 L
.61658 .04823 L
.61731 .04823 L
.61798 .04824 L
.61921 .04827 L
.6205 .04831 L
.62183 .04834 L
.62256 .04836 L
.62325 .04838 L
.62406 .04839 L
.6248 .0484 L
.6255 .0484 L
.62625 .0484 L
.62748 .04838 L
.6286 .04837 L
.62981 .04835 L
.6305 .04834 L
.63113 .04833 L
.63226 .04833 L
.63347 .04836 L
.63452 .0484 L
.63569 .04849 L
.63634 .04856 L
.63703 .04865 L
.63826 .04885 L
.64103 .04946 L
.64606 .05077 L
.64856 .05129 L
.64996 .05151 L
.65123 .05167 L
.65371 .0519 L
.65606 .05209 L
.65738 .05221 L
.65879 .05237 L
.66131 .05276 L
.66402 .05334 L
.66701 .05406 L
.66948 .05458 L
.67016 .05469 L
.67088 .05479 L
.67218 .05492 L
Mistroke
.67282 .05495 L
.67351 .05497 L
.67476 .05495 L
.67597 .05486 L
.67709 .05472 L
.6782 .05454 L
.67923 .05433 L
.68158 .05373 L
.68632 .0521 L
.69157 .04969 L
.69635 .04663 L
.70187 .04168 L
.7071 .03588 L
.72523 .01767 L
.7302 .0133 L
.73281 .01126 L
.73556 .00942 L
.74061 .00691 L
.74524 .00523 L
.74979 .00368 L
.75464 .00215 L
.75744 .00145 L
.75997 .00097 L
.76119 .00079 L
.76252 .00065 L
.76377 .00054 L
.76493 .00047 L
.76613 .00041 L
.76742 .00037 L
.76865 .00034 L
.76976 .00032 L
.77107 .0003 L
.77249 .00028 L
.77314 .00027 L
.77383 .00027 L
.77508 .00026 L
.77581 .00026 L
.77648 .00026 L
.77721 .00027 L
.77799 .00029 L
.77929 .00032 L
.78003 .00035 L
.78072 .00039 L
.78201 .00047 L
.78319 .00058 L
.78583 .00089 L
.78811 .00126 L
.79063 .00177 L
.79572 .00306 L
.80486 .00618 L
Mistroke
.81 .00861 L
.81553 .01201 L
.82554 .02004 L
.84513 .04006 L
.8505 .0451 L
.85344 .0474 L
.85622 .04926 L
.85882 .05072 L
.86163 .05202 L
.86418 .05295 L
.86541 .05331 L
.86653 .05359 L
.86762 .05381 L
.86881 .05401 L
.87007 .05416 L
.87126 .05425 L
.87237 .05429 L
.87355 .05429 L
.87456 .05425 L
.87568 .05419 L
.87698 .05408 L
.87817 .05394 L
.88086 .05356 L
.88572 .05271 L
.89623 .05074 L
.90136 .04983 L
.90602 .04907 L
.90826 .04875 L
.90944 .0486 L
.91069 .04847 L
.91178 .04838 L
.91299 .0483 L
.91408 .04826 L
.91511 .04824 L
.91636 .04823 L
.91755 .04825 L
.91862 .04827 L
.91979 .04831 L
.92106 .04834 L
.92175 .04836 L
.9224 .04838 L
.92367 .04839 L
.92483 .0484 L
.92602 .04839 L
.92733 .04837 L
.92861 .04835 L
.92932 .04834 L
.92998 .04833 L
.93126 .04833 L
.93243 .04835 L
Mistroke
.93353 .04839 L
.93472 .04848 L
.936 .04862 L
.93742 .04884 L
.94028 .04947 L
.94542 .0508 L
.94737 .05122 L
.94918 .05151 L
.95108 .05174 L
.95315 .05192 L
.96023 .05271 L
.97619 .05474 L
Mfstroke
.02857 .05593 m
.0375 .17684 L
.04729 .27383 L
.05222 .3087 L
.05493 .32384 L
.0575 .33552 L
.05989 .34411 L
.06115 .34776 L
.06248 .35098 L
.0636 .35318 L
.06484 .35507 L
.06596 .35631 L
.06701 .35707 L
.06766 .35734 L
.06835 .35747 L
.0696 .35729 L
.07036 .35692 L
.07108 .3564 L
.07172 .35578 L
.07242 .35497 L
.07372 .35303 L
.0751 .35041 L
.07756 .34434 L
.08216 .32876 L
.08721 .30673 L
.09858 .24932 L
.10354 .22569 L
.10894 .20347 L
.11412 .18622 L
.11891 .1737 L
.12349 .16435 L
.12835 .15642 L
.14916 .12798 L
.16876 .09623 L
.17734 .08293 L
.1822 .07626 L
.18672 .07089 L
.19126 .06658 L
.19379 .06472 L
.1961 .06338 L
.19854 .0623 L
.19991 .06184 L
.20118 .06151 L
.20229 .06129 L
.20351 .06111 L
.20478 .06099 L
.20597 .06094 L
.20726 .06094 L
.20798 .06097 L
.20865 .06101 L
Mistroke
.20989 .06111 L
.2112 .06127 L
.21371 .06166 L
.21598 .06209 L
.21864 .06259 L
.22004 .06283 L
.22151 .06305 L
.22281 .06319 L
.22354 .06325 L
.22423 .06328 L
.22543 .0633 L
.22672 .06324 L
.22794 .06311 L
.22863 .063 L
.22928 .06287 L
.23059 .06254 L
.232 .06206 L
.23454 .06088 L
.23687 .05944 L
.24225 .05499 L
.2479 .04938 L
.2503 .0471 L
.25286 .04499 L
.2541 .04416 L
.25528 .04353 L
.25633 .0431 L
.25747 .0428 L
.25873 .04271 L
.25945 .04277 L
.26012 .04292 L
.26082 .04316 L
.26147 .04347 L
.26221 .04393 L
.26292 .04447 L
.26416 .0457 L
.26532 .04717 L
.26793 .05172 L
.27033 .05749 L
.27253 .0642 L
.27749 .08434 L
.28187 .10772 L
.28648 .13752 L
.30697 .30844 L
.31717 .39493 L
.32681 .46625 L
.33546 .51587 L
.34035 .53677 L
.34485 .55179 L
.34702 .55751 L
.34936 .5624 L
Mistroke
.3507 .56457 L
.35192 .56612 L
.35315 .56724 L
.35432 .5679 L
.35552 .56816 L
.3568 .56795 L
.35801 .56731 L
.35911 .56635 L
.36041 .56477 L
.36181 .56251 L
.36434 .55703 L
.36686 .54985 L
.36962 .54002 L
.3752 .51409 L
.38518 .4505 L
.39599 .37042 L
.40623 .30182 L
.41543 .25513 L
.42062 .23517 L
.42542 .22004 L
.46416 .13069 L
.4731 .11205 L
.48274 .09485 L
.48826 .08681 L
.49068 .08388 L
.49332 .08113 L
.49816 .0773 L
.50079 .07582 L
.50325 .07476 L
.54212 .06037 L
.54707 .05484 L
.54978 .05199 L
.55232 .04971 L
.55375 .04867 L
.55506 .04792 L
.5558 .0476 L
.55651 .04736 L
.55726 .04719 L
.55807 .04711 L
.55877 .04713 L
.5594 .04723 L
.56013 .04743 L
.56082 .04772 L
.56205 .04849 L
.56274 .04907 L
.56337 .04969 L
.56453 .05109 L
.56578 .05296 L
.56803 .05735 L
.5707 .06437 L
Mistroke
.57313 .07252 L
.57842 .09602 L
.58343 .12512 L
.60161 .26993 L
.61195 .36006 L
.62164 .43683 L
.63114 .49869 L
.63648 .52516 L
.64136 .54417 L
.64384 .55201 L
.64649 .55891 L
.64801 .56214 L
.64939 .56455 L
.65078 .56645 L
.65209 .56774 L
.65333 .56851 L
.65464 .56883 L
.65576 .56869 L
.65699 .56811 L
.65768 .56758 L
.65831 .56698 L
.65973 .5652 L
.66104 .56304 L
.66229 .56055 L
.66685 .54779 L
.66945 .53803 L
.67188 .52725 L
.68209 .46702 L
.70041 .33392 L
.71019 .27601 L
.7151 .25333 L
.72048 .2331 L
.73002 .20572 L
.73889 .18455 L
.75753 .14392 L
.77773 .10203 L
.78309 .09309 L
.78877 .08522 L
.79362 .08017 L
.79638 .078 L
.79896 .0764 L
.80155 .07515 L
.80401 .07427 L
.80622 .07369 L
.80747 .07344 L
.80862 .07325 L
.80998 .07308 L
.81126 .07296 L
.81241 .07288 L
.81365 .07282 L
Mistroke
.81624 .07272 L
.81766 .07267 L
.81836 .07264 L
.81901 .07261 L
.82024 .07253 L
.82089 .07247 L
.82157 .07239 L
.82269 .07224 L
.82391 .07202 L
.82505 .07176 L
.82627 .07142 L
.82849 .07059 L
.83113 .06924 L
.83391 .06737 L
.83888 .06295 L
.8441 .05729 L
.84902 .05197 L
.85174 .04955 L
.85328 .04848 L
.85401 .04806 L
.8547 .04773 L
.85589 .04732 L
.8572 .04712 L
.85848 .04721 L
.85919 .0474 L
.85985 .04765 L
.86106 .04836 L
.86236 .04948 L
.86346 .05074 L
.86468 .05248 L
.86739 .05774 L
.86994 .06452 L
.87455 .08142 L
.87952 .10632 L
.88905 .17087 L
.8978 .24356 L
.91819 .41697 L
.92814 .48597 L
.93719 .53154 L
.9417 .54791 L
.94407 .55488 L
.94659 .5609 L
.94879 .56486 L
.95005 .56653 L
.95122 .56769 L
.95229 .5684 L
.95327 .56875 L
.95441 .5688 L
.95549 .56849 L
.95672 .56772 L
Mistroke
.95784 .56662 L
.95913 .56491 L
.96034 .56286 L
.9625 .55819 L
.96485 .55169 L
.97017 .53149 L
.97506 .50647 L
.97619 .49987 L
Mfstroke
.02857 .00038 m
.0375 .0035 L
.04262 .00578 L
.04486 .00661 L
.04729 .00733 L
.04982 .00788 L
.05222 .00826 L
.05496 .00859 L
.05627 .00872 L
.0575 .00882 L
.05856 .00889 L
.0597 .00894 L
.06096 .00897 L
.06212 .00896 L
.06332 .00891 L
.06463 .00879 L
.06586 .00863 L
.06701 .00843 L
.07203 .00719 L
.07467 .00647 L
.07612 .00612 L
.07746 .00584 L
.07874 .00562 L
.07991 .00546 L
.0812 .00533 L
.08191 .00528 L
.08259 .00525 L
.08376 .00523 L
.08485 .00524 L
.08604 .00529 L
.08731 .00538 L
.08864 .0055 L
.09009 .00566 L
.0927 .006 L
.0956 .00641 L
.09865 .00691 L
.10121 .00741 L
.10402 .00811 L
.10894 .00976 L
.11146 .01074 L
.1142 .01175 L
.11545 .01216 L
.11678 .01253 L
.11793 .0128 L
.11916 .01304 L
.12036 .01321 L
.12145 .01333 L
.12254 .01342 L
.12358 .01348 L
.12614 .01362 L
Mistroke
.12845 .0138 L
.12974 .01393 L
.13096 .01409 L
.13363 .0145 L
.13596 .01488 L
.13724 .01504 L
.13842 .01516 L
.13972 .01522 L
.14041 .01522 L
.14115 .01519 L
.14246 .01508 L
.14365 .01489 L
.14504 .0146 L
.14655 .0142 L
.1493 .01337 L
.16901 .00891 L
.17392 .00739 L
.1766 .00666 L
.17908 .00613 L
.18179 .00571 L
.18322 .00555 L
.18474 .00541 L
.18993 .00506 L
.19516 .00466 L
.19774 .00447 L
.19886 .0044 L
.2001 .00433 L
.20122 .00429 L
.20226 .00427 L
.20336 .00426 L
.20454 .00428 L
.20583 .00432 L
.20705 .00439 L
.20934 .00456 L
.21356 .00495 L
.21588 .00514 L
.21701 .00521 L
.21805 .00527 L
.21918 .00532 L
.22039 .00535 L
.22165 .00538 L
.22298 .0054 L
.22404 .00542 L
.22517 .00543 L
.2264 .00546 L
.22754 .00549 L
.22876 .00554 L
.23009 .00561 L
.23251 .00576 L
.23486 .00593 L
Mistroke
.2359 .006 L
.23702 .00606 L
.23831 .00611 L
.23954 .00614 L
.24023 .00614 L
.24095 .00613 L
.24226 .00608 L
.24289 .00604 L
.24358 .00599 L
.24483 .00588 L
.24716 .00561 L
.26543 .00391 L
.27038 .00335 L
.27311 .00301 L
.2757 .00272 L
.2781 .00251 L
.27946 .00242 L
.28071 .00235 L
.28176 .00231 L
.28293 .00229 L
.28414 .00228 L
.28528 .00229 L
.2865 .00233 L
.28779 .00238 L
.28889 .00245 L
.29009 .00254 L
.29139 .00267 L
.29278 .00284 L
.29528 .00324 L
.29823 .00391 L
.30102 .00479 L
.30353 .00586 L
.30624 .00738 L
.32565 .02315 L
.33092 .02769 L
.33593 .03255 L
.3387 .03479 L
.33945 .03526 L
.34026 .03569 L
.34102 .036 L
.34171 .03622 L
.34301 .03644 L
.34375 .03646 L
.34442 .03642 L
.34567 .0362 L
.34698 .03581 L
.35665 .03203 L
.36725 .02712 L
.37192 .02297 L
.37438 .02083 L
Mistroke
.37699 .01892 L
.37927 .01768 L
.38057 .01715 L
.38178 .01676 L
.38289 .0165 L
.38391 .01631 L
.38509 .01617 L
.3862 .01607 L
.38743 .01601 L
.38873 .01596 L
.39108 .0159 L
.39381 .01582 L
.39447 .01579 L
.39516 .01577 L
.39639 .01575 L
.39751 .01575 L
.39873 .01578 L
.40004 .01588 L
.40126 .01603 L
.40237 .01622 L
.40339 .01646 L
.40567 .01717 L
.41091 .01948 L
.41379 .02072 L
.4152 .02121 L
.41649 .02155 L
.4176 .02176 L
.41878 .0219 L
.41995 .02197 L
.42124 .02197 L
.42256 .02193 L
.4233 .02189 L
.42397 .02186 L
.42527 .0218 L
.4265 .02178 L
.42759 .02179 L
.4288 .02185 L
.43006 .02196 L
.43123 .0221 L
.43348 .02245 L
.43458 .02262 L
.4356 .02276 L
.43679 .02288 L
.43809 .02294 L
.43919 .02291 L
.44036 .02278 L
.44103 .02267 L
.44175 .0225 L
.44305 .02212 L
.44548 .02113 L
Mistroke
.46613 .01373 L
.4711 .01156 L
.47383 .01037 L
.47641 .00941 L
.47882 .00871 L
.48008 .00842 L
.48143 .00816 L
.4838 .00781 L
.486 .00756 L
.496 .00641 L
.49851 .00613 L
.4992 .00607 L
.49992 .00602 L
.50122 .00594 L
.50195 .00591 L
.50264 .0059 L
.50339 .00589 L
.50419 .0059 L
.50494 .00592 L
.50564 .00595 L
.50628 .00598 L
.50697 .00602 L
.51152 .00643 L
.51272 .00655 L
.51403 .00666 L
.51518 .00674 L
.51641 .00681 L
.5171 .00684 L
.51786 .00686 L
.51856 .00687 L
.51921 .00688 L
.52044 .00688 L
.52113 .00688 L
.52177 .00687 L
.52303 .00686 L
.5242 .00685 L
.52543 .00684 L
.52608 .00685 L
.52678 .00686 L
.52746 .00687 L
.52818 .00689 L
.52948 .00694 L
.53088 .00702 L
.53241 .00711 L
.53498 .00728 L
.53572 .00732 L
.53643 .00735 L
.53706 .00738 L
.53774 .00739 L
.53904 .00739 L
Mistroke
.53976 .00738 L
.54042 .00735 L
.54169 .00727 L
.5429 .00716 L
.54522 .00686 L
.54772 .00646 L
.56757 .00424 L
.57239 .00354 L
.57505 .00319 L
.57756 .00293 L
.57898 .00282 L
.57973 .00277 L
.58053 .00273 L
.5812 .0027 L
.58193 .00268 L
.58323 .00266 L
.58455 .00267 L
.58529 .00268 L
.58597 .0027 L
.58721 .00275 L
.58853 .00283 L
.58976 .00293 L
.59109 .00306 L
.59351 .00338 L
.59586 .00381 L
.59803 .00435 L
.60038 .00511 L
.60296 .00623 L
.60566 .00776 L
.60818 .00954 L
.62645 .02464 L
.63141 .02913 L
.63403 .0317 L
.63681 .03418 L
.63819 .03517 L
.63949 .03589 L
.64066 .03633 L
.64192 .03659 L
.64312 .03663 L
.64438 .03647 L
.64546 .0362 L
.64665 .0358 L
.65613 .03207 L
.65839 .03141 L
.66079 .03059 L
.66283 .02965 L
.66509 .02825 L
.66997 .02411 L
.67253 .02179 L
.67528 .01961 L
Mistroke
.67656 .01876 L
.67777 .01808 L
.67896 .01752 L
.68006 .0171 L
.6811 .01679 L
.68221 .01653 L
.68343 .01632 L
.68455 .01619 L
.68585 .0161 L
.68651 .01606 L
.68723 .01604 L
.6897 .01597 L
.69238 .01588 L
.69387 .01583 L
.69459 .01581 L
.69527 .0158 L
.69658 .01579 L
.69727 .0158 L
.698 .01583 L
.69918 .01591 L
.70049 .01607 L
.7017 .01629 L
.70301 .01661 L
.70537 .01739 L
.70997 .01945 L
.7125 .02057 L
.71374 .02103 L
.71489 .02138 L
.71624 .0217 L
.71695 .02182 L
.71771 .02191 L
.71893 .02199 L
.71963 .02201 L
.72028 .02201 L
.72154 .02197 L
.7227 .02191 L
.7234 .02188 L
.72406 .02185 L
.7253 .02181 L
.72659 .02181 L
.72725 .02183 L
.72797 .02187 L
.72926 .02198 L
.73044 .02213 L
.73312 .02254 L
.73454 .02275 L
.73532 .02285 L
.73606 .02292 L
.7367 .02295 L
.73741 .02297 L
Mistroke
.73863 .02292 L
.73988 .02276 L
.74103 .02251 L
.74224 .02214 L
.74358 .02164 L
.74628 .02038 L
.76555 .01365 L
.77035 .01155 L
.77547 .00946 L
.77699 .00899 L
.77842 .00862 L
.77981 .00832 L
.78109 .00809 L
.7836 .00775 L
.78631 .00746 L
.79133 .00691 L
.79601 .00632 L
.79837 .00608 L
.79905 .00603 L
.79969 .00598 L
.8009 .00593 L
.80155 .00591 L
.80224 .0059 L
.80347 .0059 L
.80423 .00593 L
.80494 .00595 L
.80558 .00599 L
.80627 .00603 L
.8116 .00652 L
.8129 .00664 L
.81428 .00674 L
.81508 .00679 L
.81581 .00682 L
.81653 .00685 L
.81722 .00687 L
.81844 .00689 L
.81973 .00689 L
.82083 .00688 L
.82204 .00686 L
.82334 .00685 L
.82407 .00685 L
.82474 .00685 L
.82604 .00686 L
.82727 .00689 L
.82851 .00694 L
.82985 .00701 L
.83228 .00716 L
.83444 .0073 L
.83566 .00736 L
.83681 .00739 L
Mistroke
.83805 .0074 L
.83875 .00739 L
.83939 .00736 L
.84005 .00733 L
.84078 .00728 L
.84211 .00716 L
.84464 .00683 L
.84698 .00646 L
.85585 .00531 L
.86527 .00444 L
.86981 .0038 L
.87459 .00315 L
.8771 .0029 L
.87851 .0028 L
.87919 .00276 L
.87983 .00273 L
.88105 .00269 L
.88216 .00267 L
.88335 .00266 L
.88464 .00269 L
.88577 .00272 L
.88683 .00278 L
.88799 .00285 L
.88924 .00295 L
.89178 .00325 L
.8941 .00362 L
.89625 .00409 L
.89858 .00476 L
.90078 .0056 L
.90283 .00657 L
.90789 .00995 L
.91337 .01473 L
.92329 .02278 L
.93212 .03063 L
.93454 .03294 L
.93588 .03408 L
.93714 .035 L
.93831 .0357 L
.93958 .03624 L
.94074 .03654 L
.94181 .03664 L
.94277 .0366 L
.9438 .03643 L
.94478 .03617 L
.94567 .03586 L
.94993 .03402 L
.95404 .03246 L
.95622 .03181 L
.95854 .03111 L
.96088 .03022 L
Mistroke
.963 .0291 L
.96513 .02762 L
.96714 .02595 L
.97619 .0185 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[74]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00C@3oool2000000@0oooo0P00000b0?ooo`D000000P3oool2000000@0oooo0P00000_0?oo
o`D000000P3oool2000000@0oooo0P00000_0?ooo`@000000`3oool2000000@0oooo0P00000>0?oo
o`00C03oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
;P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`00000=0?ooo`00C`3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0340oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000003@3oool004d0oooo0P0000030?ooo`040000003oool0
oooo000003<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`8000000`3oool010000000
oooo0?ooo`00000`0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00/0oooo001=0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000<`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`00000^0?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`00000=0?ooo`00C@3oool3000000<0oooo0P00
000c0?ooo`800000103oool2000000@0oooo0P00000`0?ooo`800000103oool3000000<0oooo0P00
000`0?ooo`800000103oool2000000@0oooo0P00000>0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003P3ooooo000000D000003P3oool0
01@0oooo00<000000?ooo`0000000`0000060?ooo`L000001@3oool00`000000oooo0?ooo`040?oo
o`<000000`3oool00`000000oooo0?ooo`0J000000<0oooo100000000`3oool000000?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool3000000T0oooo1P0000080?oo
oa0000002@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00@000000?oo
o`0000000000203oool00`000000oooo00000005000000D0oooo00<000000?ooo`3oool03`000006
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04P3oool001@0oooo00<000000?oo
o`3oool00P3oool8000000H0oooo100000060?ooo`800000103oool5000000H0oooo1000000G0?oo
o`030000003oool0oooo01h0oooo0`0000070?ooo`D000001@3oool:000000l0oooo00<000000?oo
o`3oool07P3oool3000000P0oooo1@0000030?ooo`X000003`3oool2000002H0oooo000D0?ooo`03
0000003oool0oooo01<0oooo1`0000030?ooo`<000003`3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool01@3oool4000000/0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00D0oooo100000090?ooo`80
00005`3oool00`000000oooo0?ooo`0T0?ooo`00503oool2000001T0oooo1@00000C0?ooo`800000
5P3oool2000000l0oooo200000040?ooo`030000003oool0oooo00@0oooo0P00000@0?ooo`030000
003oool0oooo01D0oooo0P00000>0?ooo`P000001@3oool00`000000oooo0?ooo`040?ooo`800000
3`3oool2000001H0oooo00<000000?ooo`3oool08`3oool001@0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`060?ooo`H000000`3oool2000001<0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0:0?ooo`8000001`3oool700000080oooo0`00000C0?ooo`030000003o
ool0oooo01@0oooo0P00000>0?ooo`030000003oool0oooo0180oooo000D0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`04000001H0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool01000000F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02@3oool2
000001D0oooo000D0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00H0oooo0P00000;0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`800000303oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01P3oool20000
01L0oooo000D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0E0?ooo`8000000`3oool3000000`0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo0`00000<0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool05@3oool2000000@0oooo0`00000H0?ooo`00503oool2000001@0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0E0?ooo`@000003P3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo01H0oooo1000000>0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool05@3oool5000001/0oooo000D0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03@0oooo000D
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool08`3oool5000002<0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0<`3oool001@0oooo1000000?0?ooo`030000003oool0oooo02@0oooo0P0000020?oo
o`030000003oool0oooo00T0oooo2@00000>0?ooo`030000003oool0oooo02D0oooo0`00000;0?oo
o`T000003P3oool00`000000oooo0?ooo`0V0?ooo`<000002`3oool9000001h0oooo000D0?ooo`04
0000003oool0oooo0?ooo`H000001P3oool3000002L0oooo00<000000?ooo`0000000`0000040?oo
o`H00000203oool6000000H0oooo0`00000W0?ooo`D000001P3oool4000000T0oooo1P0000050?oo
o`<00000:03oool5000000@0oooo1P0000080?ooo`P000005`3oool001@0oooo0P0000080?ooo`H0
0000:03oool2000000D0oooo1@00000D0?ooo`H00000:@3oool00`000000oooo0?ooo`020?ooo`L0
00004`3oool5000002X0oooo00<000000?ooo`3oool00P3oool5000001H0oooo0`00000D0?ooo`00
503oool2000003D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`120?ooo`800000
1P3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
;`3oool001@0oooo0P00000Z0?ooo`/000002@3oool00`000000oooo0?ooo`100?ooo`800000203o
ool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0;`3o
ool001@0oooo0P00000Y0?ooo`8000004`3oool00`000000oooo0?ooo`0m0?ooo`<000002P3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;P3oool0
01@0oooo0P00000X0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0>`3oool20000
00h0oooo00<000000?ooo`3oool0?P3oool3000000T0oooo00<000000?ooo`3oool0;P3oool001@0
oooo0P00000W0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0>03oool300000100
oooo00<000000?ooo`3oool0>03oool7000000/0oooo00<000000?ooo`3oool0;P3oool001@0oooo
0P00000W0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo03L0oooo0P00000B0?ooo`030000003oool0oooo02d0oooo
000;0?ooo`D00000103oool2000002D0oooo0P00000H0?ooo`030000003oool0oooo03D0oooo0P00
000C0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0]0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`800000903oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo03@0oooo0P00000D0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0]0?ooo`003@3oool00`000000oooo0?ooo`040?oo
o`<000008`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0;@3oool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000R0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0]0?ooo`00
3@3oool00`000000oooo0?ooo`040?ooo`030000003oool000000280oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02`0oooo000<0?ooo`8000001P3o
ool00`000000oooo0000000Q0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0/0?ooo`00503oool300000240oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02`0oooo000D0?ooo`030000003oool00000
0200oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
02`0oooo000D0?ooo`030000003oool0000001l0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo02`0oooo000D0?ooo`030000003oool0000001l0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02/0oooo
000D0?ooo`030000003oool0000001h0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo02/0oooo000D0?ooo`<000007P3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0:`3oool001@0oooo00<000000?oo
o`0000007@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0:`3oool001@0oooo00<000000?ooo`000000703oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0:`3oool001@0oooo00<000000?ooo`000000
703oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
:`3oool001@0oooo0`00000K0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0Z0?ooo`00503oool00`000000oooo0000000J0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0Z0?ooo`00503oool00`00
0000oooo0000000I0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0Z0?ooo`00503oool010000000oooo0?ooo`00000H0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Z0?ooo`00503oool010000000
oooo0?ooo`00000G0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0Z0?ooo`00503oool2000000030?ooo`000000oooo01D0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02X0oooo000D0?ooo`040000
003oool0oooo000001H0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo02T0oooo000D0?ooo`040000003oool0oooo000001D0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02T0oooo000;0?ooo`@00000
1@3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0Y0?ooo`002`3oool00`000000oooo0?ooo`060?ooo`040000
003oool0oooo000001@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo02T0oooo000<0?ooo`030000003oool0oooo00D0oooo0P0000000`3oool00000
0?ooo`0C0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0Y0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000001<0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02T0oooo
000;0?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3oool000004`3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0:@3oool000`0oooo
0P0000060?ooo`040000003oool0oooo000001<0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo02P0oooo000D0?ooo`80000000<0oooo0000003oool0
4P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
:03oool001@0oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0X0?ooo`00503oool01@000000oooo0?oo
o`3oool000000140oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo02P0oooo000D0?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0:03oool001@0oooo00D0
00000?ooo`3oool0oooo0000000A0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0X0?ooo`00503oool200000080oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03o
ool001@0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`00503oool01@000000oooo0?ooo`3o
ool0000000l0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02P0oooo000D0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool001@0oooo0P000003
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo02L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool09`3oool001@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0W0?ooo`00
503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02L0oooo000D0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool09`3oool001@0oooo0P0000030?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo02L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool09`3oool000`0
oooo0P0000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool09`3oool000/0oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02H0
oooo000=0?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02H0oooo
000>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0V0?ooo`002`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool09P3oool000`0oooo0P0000060?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool09P3oool001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0V0?oo
o`00503oool2000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool09P3oool001@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`0V0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo0300oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo02D0oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool09@3oool0
01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0U0?ooo`00503oool2000000D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool09@3oool001@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0U0?ooo`00503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02D0oooo000D
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool09@3oool001@0oooo0P0000050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo02@0oooo000D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool0903oool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0T0?ooo`00503o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02@0oooo000D0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool0903oool001@0oooo0P0000060?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
02@0oooo000D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0<`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0903oool000d0oooo
0`0000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0i0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0903oool000h0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000
?03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo02<0oooo000;0?ooo`D00000103o
ool2000000P0oooo00@000000?ooo`3oool00000?03oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo02<0oooo000;0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
1`3oool3000003h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0S0?ooo`00303o
ool00`000000oooo000000050?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0S0?ooo`003@3oool2000000D0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo02<0oooo000D0?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0S0?ooo`00503oool2000004T0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0S0?ooo`00503oool00`000000oooo
0?ooo`180?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool08P3oool001@0oooo00<0
00000?ooo`3oool0B03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0280oooo000D
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0R
0?ooo`00503oool2000004X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0R0?oo
o`00503oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool08P3oool001@0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo0280oooo000D0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0R0?ooo`00503oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool08P3oool001@0oooo0P00001:0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool08@3oool001@0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo0240oooo000D0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0Q0?ooo`00503oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool08@3oool001@0oooo00<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0240oooo000D0?oo
o`800000B`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0240oooo000D0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0Q0?ooo`00
303oool2000000H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo0240oooo000;0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0200oooo000>0?ooo`030000003o
ool0oooo00<0oooo0P00001;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0803o
ool000`0oooo0P0000060?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0P0?ooo`00303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
04X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0P0?ooo`00303oool3000000D0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0200
oooo000D0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`0P0?ooo`00503oool2000004`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0P0?ooo`00503oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool0803oool001@0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo0200oooo000D0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`0O0?ooo`00503oool2000004`0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0O0?ooo`00503oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo03d0oooo00<000000?ooo`3oool07`3oool001@0oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01l0oooo000D0?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0O0?ooo`00503oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool07`3oool001@0oooo
0P00001=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool07`3oool001@0oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool04P3oool001@0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04`3oool001@0oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool04`3oool001@0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool04`3oool001@0oooo0P00001>0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0C0?ooo`00503o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0C0?ooo`002`3oool3000000H0oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0503oool0
00/0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0D0?ooo`002`3oool01000
0000oooo0?ooo`0000050?ooo`800000C`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0503oool000/0oooo0`0000060?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
01@0oooo000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0C`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0503oool000`0oooo
0`0000050?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo01@0oooo000D0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo000D
0?ooo`800000D@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool05@3oool001@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool001@0oooo00<000000?ooo`3o
ool0D03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool05P3oool001@0oooo00<000000?ooo`3oool0D03oool01@000000oooo0?ooo`3oool0000004T0
oooo00D000000?ooo`3oool0oooo000000190?ooo`040000003oool0oooo000001T0oooo000D0?oo
o`800000DP3oool010000000oooo0?ooo`0000190?ooo`8000000P3oool00`000000oooo0?ooo`17
0?ooo`040000003oool0oooo000001T0oooo000D0?ooo`030000003oool0oooo0580oooo0`00001:
0?ooo`<00000B`3oool3000001T0oooo000D0?ooo`030000003oool0oooo0?l0oooo2P3oool001@0
oooo00<000000?ooo`3oool0o`3oool:0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`X0oooo
000D0?ooo`800000o`3oool;0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`X0oooo000D0?oo
o`030000003oool0oooo0?l0oooo2P3oool001@0oooo00<000000?ooo`3oool0o`3oool:0?ooo`00
503oool200000?l0oooo2`3oool001@0oooo00<000000?ooo`3oool0o`3oool:0?ooo`00503oool0
0`000000oooo0?ooo`3o0?ooo`X0oooo000=0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0o`3oool:0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0
oooo2P3oool000d0oooo00<000000?ooo`3oool0103oool200000?l0oooo2`3oool000h0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`002`3oool010000000oooo0?ooo`00003o0?oooa80oooo000;
0?ooo`@00000o`3ooolB0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-16.3571, -0.53488, \
0.810174, 0.0436962}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[74]="]
}, Open  ]],

Cell["Or we can show the numeric values as function of t", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[{t, \ x1[t], x2[t], x3[t]}, \ {t, \ 10, \ 100, 10}] // 
      TableForm\)], "Input",
  CellLabel->"In[75]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"10", "0.6134125372390521`", "4.033054508595177`", 
            "0.08333143357601942`"},
          {"20", "0.27925624417610434`", "1.9637332290653013`", 
            "0.1474486022384011`"},
          {"30", "0.004851862364165711`", "1.1293430458630687`", 
            "0.10841235873582522`"},
          {"40", "0.11485436484442876`", "0.6995853746886171`", 
            "0.05674944680457082`"},
          {"50", "0.5826039326056103`", "0.4952021659252249`", 
            "0.047543490426472976`"},
          {"60", "0.5526280917179683`", "3.7471755192392657`", 
            "0.11013226698992883`"},
          {"70", "0.5902731463693087`", "6.431231772189919`", 
            "0.3611857611535052`"},
          {"80", "0.44673871634629964`", "3.5192530411432186`", 
            "0.1909203095312963`"},
          {"90", "0.03499735811230733`", "1.7783283091847824`", 
            "0.2023776517032434`"},
          {"100", "0.04664954749242876`", "0.8633413882060773`", 
            "0.06807459088067101`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[75]//TableForm="]
}, Open  ]],

Cell[BoxData[
    \(Clear[x1, x2, x3, iodineNonLinear\ , icIodine, b1Iodine]\)], "Input",
  CellLabel->"In[76]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Laplace transform and identifiably analysis ", "SubsectionIcon"],

Cell["\<\
The package function SystemLTSolve can be applied to obtain the laplace \
transform of a SODE. It can be very useful in  identifiably analysis.
(Example 6.5. Godfrey 1983). In a the model of the figure, the response in \
the central compartment (1) to a rapidly administered input of 1 unit to the \
central compartment is y(t)= 0.7 Exp[-5 t]+0.2 Exp[-t]+0.1 Exp[-0.1 t]; \
Determine the unknown rate constants if there is prior knowledge that the \
excretion is only from compartment central. \
\>", "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .375 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0833333 0.119048 0.1875 0.119048 [
[ 0 0 0 0 ]
[ 1 .375 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .375 L
0 .375 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
/MAarrowhead2 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125  moveto 0 0 lineto 
-0.05 -0.0125  lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.08333 .1875 .05952 0 365.73 arc
s
gsave
.08333 .1875 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.29167 .23512 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.14286 .21131 m
.44048 .21131 L
s
% Start of user PostScript
0.5 0.2 3. 0.2 MAarrowhead1
% End of user PostScript
gsave
.29167 .13988 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.44048 .16369 m
.14286 .16369 L
s
% Start of user PostScript
3. -0.2 0.5 -0.2 MAarrowhead1
% End of user PostScript
newpath
.5 .1875 .05952 0 365.73 arc
s
gsave
.5 .1875 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .36607 m
.5 .24702 L
s
% Start of user PostScript
3.5 1.5 3.5 0.5 MAarrowhead2
% End of user PostScript
gsave
.46429 .30655 -68.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
73.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12798 m
.5 .00893 L
s
% Start of user PostScript
3.5 -0.5 3.5 -1.5 MAarrowhead1
% End of user PostScript
gsave
.46429 .06845 -70.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.91667 .1875 .05952 0 365.73 arc
s
gsave
.91667 .1875 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 .21131 m
.85714 .21131 L
s
% Start of user PostScript
4. 0.2 6.5 0.2 MAarrowhead1
% End of user PostScript
gsave
.70833 .23512 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.85714 .16369 m
.55952 .16369 L
s
% Start of user PostScript
6.5 -0.2 4. -0.2 MAarrowhead1
% End of user PostScript
gsave
.70833 .13988 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(31) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[39]:=",
  ImageSize->{288, 108},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000Qa000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo002cOol00`00Oomoo`2bOol00;=oo`03001oogoo0;9oo`00/goo00<0
07ooOol0/Woo002bOol3002cOol00;9oo`<00;=oo`00/Woo0`00/goo002bOol3002cOol00;5oo`D0
0;9oo`00/Goo1@00/Woo002aOol5002bOol00;5oo`D00;9oo`00/Goo1@00/Woo002`Ool7002aOol0
0;1oo`L00;5oo`00/7oo1`00/Goo002`Ool7002aOol00:moo`T00;1oo`00[goo2@00/7oo002_Ool9
002`Ool00;=oo`03001oogoo0;9oo`00/goo00<007ooOol0/Woo002cOol00`00Oomoo`2bOol00;=o
o`03001oogoo0;9oo`00/goo00<007ooOol0/Woo002cOol00`00Oomoo`2bOol00:Aoo`D0009oo`03
001oogoo00Eoo`03001oogoo0;9oo`00YWoo00L007ooOomoo`00Ool00006Ool00`00Oomoo`2bOol0
09ioo`80009oo`<00003Ool007oo009oo`03001oo`0000Ioo`03001oogoo0;9oo`00Wgoo00@007oo
Ool000=oo`07001oogooOol007oo00001Woo00<007ooOol0/Woo002OOol00`00Ool00004Ool01`00
Oomoogoo001oo`0000Ioo`03001oogoo0;9oo`00Wgoo0`000goo0P0017oo00<007ooOol01Goo00<0
07ooOol0/Woo002OOol01000Oomoo`0047oo00<007ooOol0/Woo002OOol00`00Ool00003000>Ool0
0`00Oomoo`2bOol009moo`03001oogoo015oo`03001oogoo0;9oo`00WWoo0P004goo00<007ooOol0
/Woo002cOol00`00Oomoo`2bOol00;=oo`03001oogoo0;9oo`00/goo00<007ooOol0/Woo002cOol0
0`00Oomoo`2bOol00;=oo`03001oogoo0;9oo`00/goo00<007ooOol0/Woo002cOol00`00Oomoo`2b
Ool001]oo`H004Ioo`D00004Ool000000010Ool60016Ool20002Ool50010Ool6000MOol001Moo`@0
00Ioo`@004Aoo`05001oogooOol0000nOol40006Ool40014Ool01@00Oomoogoo0000?Woo10001Woo
10006Goo000EOol2000>Ool2000iOol20002Ool30002Ool00`00Oomoo`02Ool00`00Oomoo`0iOol2
000>Ool2000iOol20002Ool300000goo001oo`03Ool00`00Oomoo`0jOol2000>Ool2000GOol001=o
o`80019oo`8003Qoo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`0gOol2000BOol2000h
Ool01000Oomoo`0017oo00D007ooOomoo`0003Yoo`80019oo`8001Eoo`004Woo00<007ooOol057oo
0P00=Woo00<007oo00001Goo00L007ooOomoo`00Ool0000gOol00`00Oomoo`0DOol2000fOol00`00
Ool00003Ool00`00Ool00003Ool00`00Oomoo`0fOol2000FOol00`00Oomoo`0BOol0015oo`03001o
ogoo01Moo`03001oogoo03=oo`<000Aoo`8000Aoo`03001oogoo03Eoo`03001oogoo01Moo`03001o
ogoo03=oo`<000Aoo`04001oogooOol2000gOol00`00Oomoo`0GOol2000BOol0011oo`03001oogoo
01Uoo`8003=oo`04001oogoo0010Ool00`00Oomoo`0IOol2000cOol01000Oomoo`00@7oo00<007oo
Ool06Goo0P0047oo000?Ool00`00Oomoo`0KOol00`00Oomoo`0aOol00`00Ool00003000lOol2000M
Ool00`00Oomoo`0aOol00`00Ool00003000lOol2000MOol00`00Oomoo`0>Ool000ioo`03001oogoo
01eoo`03001oogoo031oo`03001oogoo03ioo`03001oogoo01ioo`03001oogoo031oo`03001oogoo
03ioo`03001oogoo01ioo`03001oogoo00eoo`003Goo00<007ooOol07goo00<007ooOol04Goo0`00
6Woo0P00@7oo00<007ooOol07goo00<007ooOol04Goo0`006Woo0P00@7oo00<007ooOol07Woo00<0
07ooOol03Goo000<Ool00`00Oomoo`0QOol00`00Oomoo`0<Ool7001KOol00`00Oomoo`0QOol00`00
Oomoo`0<Ool7001KOol00`00Oomoo`0POol00`00Oomoo`0<Ool000]oo`03001oogoo02=oo`03001o
ogoo00Ioo``005Yoo`03001oogoo02=oo`03001oogoo00Ioo``005Yoo`03001oogoo029oo`8000ao
o`002goo00<007ooOol08goo00<007ooOol00Woo4000FWoo00<007ooOol08goo00<007ooOol00Woo
4000FWoo00<007ooOol08goo00<007ooOol02Woo000:Ool00`00Oomoo`0UOom^000WOom^000VOol0
0`00Oomoo`0:Ool000Yoo`03001oogoo02Eoo`04001oogooOol@001IOol00`00Oomoo`0UOol01000
Oomoogoo4000FGoo00<007ooOol097oo00<007ooOol02Woo000:Ool00`00Oomoo`0UOol00`00Oomo
o`05Ool<001HOol00`00Oomoo`0VOol00`00Oomoo`05Ool<001HOol00`00Oomoo`0VOol00`00Oomo
o`09Ool000Yoo`03001oogoo02Eoo`03001oogoo00Yoo`L005Qoo`03001oogoo02Ioo`03001oogoo
00Yoo`L005Qoo`03001oogoo02Ioo`03001oogoo00Uoo`002Goo00<007ooOol09goo00<007ooOol0
3Goo0`00F7oo00<007ooOol09goo00<007ooOol03Goo0`00F7oo00<007ooOol09goo00<007ooOol0
27oo0009Ool00`00Oomoo`0WOol00`00Oomoo`1XOol00`00Oomoo`0WOol00`00Oomoo`1XOol00`00
Oomoo`0WOol00`00Oomoo`08Ool000Uoo`03001oogoo00moo`D001=oo`03001oogoo06Qoo`03001o
ogoo011oo`D0019oo`03001oogoo06Qoo`03001oogoo011oo`<001Aoo`03001oogoo00Qoo`002Goo
00<007ooOol03goo00D007ooOomoo`0001=oo`03001oogoo06Qoo`03001oogoo019oo`03001oogoo
019oo`03001oogoo06Qoo`03001oogoo00moo`05001oogooOol0000COol00`00Oomoo`08Ool000Uo
o`03001oogoo011oo`03001oogoo01Aoo`03001oogoo06Qoo`03001oogoo019oo`03001oogoo019o
o`03001oogoo06Qoo`03001oogoo01=oo`03001oogoo015oo`03001oogoo00Qoo`002Goo00<007oo
Ool04Goo00<007ooOol04goo00<007ooOol0J7oo00<007ooOol04Woo00<007ooOol04Woo00<007oo
Ool0J7oo00<007ooOol04goo00<007ooOol04Goo00<007ooOol027oo0009Ool00`00Oomoo`0BOol0
0`00Oomoo`0BOol00`00Oomoo`1XOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`1XOol0
0`00Oomoo`0AOol2000DOol00`00Oomoo`08Ool000Uoo`03001oogoo01=oo`03001oogoo015oo`03
001oogoo06Qoo`03001oogoo019oo`03001oogoo019oo`03001oogoo06Qoo`03001oogoo01=oo`03
001oogoo015oo`03001oogoo00Qoo`002Goo00<007ooOol03goo00D007ooOomoo`0001=oo`03001o
ogoo06Qoo`03001oogoo011oo`<001Aoo`03001oogoo06Qoo`03001oogoo00moo`05001oogooOol0
000COol00`00Oomoo`08Ool000Uoo`03001oogoo011oo`<001Aoo`03001oogoo05Ioo`<000moo`03
001oogoo019oo`03001oogoo019oo`03001oogoo05Ioo`<000moo`03001oogoo011oo`<001Aoo`03
001oogoo00Qoo`002Woo00<007ooOol09Goo00<007ooOol0Egoo1`002goo00<007ooOol09Woo00<0
07ooOol0Egoo1`002goo00<007ooOol09Woo00<007ooOol02Goo000:Ool00`00Oomoo`0UOol00`00
Oomoo`1GOol<0006Ool00`00Oomoo`0VOol00`00Oomoo`1GOol<0006Ool00`00Oomoo`0VOol00`00
Oomoo`09Ool000Yoo`03001oogoo02Eoo`03001oogoo05Mooa0000=oo`03001oogoo02Eoo`03001o
ogoo05Mooa0000=oo`03001oogoo02Aoo`03001oogoo00Yoo`002Woo00<007ooOol09GooKP009goo
KP009Woo00<007ooOol02Woo000;Ool00`00Oomoo`0SOol00`00Oomoo`1HOolA0003Ool00`00Oomo
o`0SOol00`00Oomoo`1HOolA0003Ool00`00Oomoo`0SOol00`00Oomoo`0:Ool000]oo`03001oogoo
02=oo`03001oogoo05Qoo`d000Moo`03001oogoo02=oo`03001oogoo05Qoo`d000Moo`03001oogoo
02=oo`03001oogoo00Yoo`0037oo00<007ooOol08Goo00<007ooOol0FGoo2P002goo00<007ooOol0
8Goo00<007ooOol0FGoo2P002goo00<007ooOol087oo0P003Goo000=Ool00`00Oomoo`0OOol00`00
Oomoo`1JOol6000@Ool00`00Oomoo`0OOol00`00Oomoo`1JOol6000@Ool00`00Oomoo`0NOol00`00
Oomoo`0=Ool000ioo`03001oogoo01eoo`03001oogoo03Moo`<00003Ool0000000<001]oo`8001Ao
o`03001oogoo01ioo`03001oogoo03Eoo`D00003Ool0000001ioo`8001Aoo`03001oogoo01ioo`03
001oogoo00eoo`003goo00<007ooOol06goo00<007ooOol0<7oo0P000Woo0`0000=oo`00Ool017oo
00<007ooOol0<Woo00<007ooOol077oo00<007ooOol0<7oo0P000Woo0`0000=oo`00Ool017oo00<0
07ooOol0<Woo00<007ooOol077oo00<007ooOol03Woo000@Ool00`00Oomoo`0JOol00`00Oomoo`0a
Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol0<goo0P0077oo00<007ooOol0<Goo00@0
07ooOol000=oo`03001oogoo009oo`03001oogoo03Aoo`8001aoo`03001oogoo00ioo`004Goo00<0
07ooOol05goo0P00=7oo00<007oo00001Goo00<007ooOol00Woo00<007ooOol0=Goo00<007ooOol0
5goo0P00=7oo00<007oo000017oo00<007ooOol00goo00<007ooOol0=7oo00<007ooOol067oo0P00
4Goo000BOol00`00Oomoo`0EOol00`00Oomoo`0dOol30004Ool00`00Ool00003Ool00`00Oomoo`0f
Ool00`00Oomoo`0EOol00`00Oomoo`0dOol30004Ool01`00Oomoogoo001oo`0003Moo`03001oogoo
01Eoo`8001=oo`004goo00<007ooOol04Woo0P00=goo00@007ooOol000Aoo`04001oogooOol2000i
Ool00`00Oomoo`0BOol2000gOol01000Oomoo`000Woo0P0017oo00<007ooOol0=goo0P0057oo00<0
07ooOol04goo000DOol2000@Ool2000iOol00`00Ool000030012Ool2000@Ool2000iOol00`00Ool0
00030012Ool2000@Ool2000FOol001Ioo`@000Qoo`@003]oo`03001oogoo04Moo`@000Qoo`@003]o
o`03001oogoo04Moo`@000Moo`D001Qoo`006Woo2000?Woo0P00CGoo2000?Woo0P00CGoo1`007Goo
002cOol00`00Oomoo`2bOol00;=oo`03001oogoo0;9oo`00/Woo0`00/goo002bOol3002cOol00;9o
o`<00;=oo`00/Woo0`00/goo002aOol01@00Ool007oo0000/Woo002aOol01@00Ool007oo0000/Woo
002aOol01@00Ool007oo0000/Woo002aOol01@00Ool007oo0000/Woo002aOol01@00Ool007oo0000
/Woo002`Ool01000Oomoo`000Woo00<007ooOol0[goo002`Ool01000Oomoo`000Woo00<007ooOol0
[goo002`Ool01000Oomoo`000Woo00<007ooOol0[goo002`Ool01000Oomoo`000Woo00<007ooOol0
[goo002_Ool01@00Oomoogoo00000goo00<007ooOol0[Woo002_Ool01@00Oomoogoo00000goo00<0
07ooOol0[Woo002_Ool01@00Oomoogoo00000goo00<007ooOol0[Woo002cOol00`00Oomoo`2bOol0
0;=oo`03001oogoo0;9oo`00/goo00<007ooOol0/Woo002cOol00`00Oomoo`2bOol00;=oo`03001o
ogoo0;9oo`00/goo00<007ooOol0/Woo002WOol50007Ool00`00Oomoo`2bOol00:Uoo`03001oogoo
00Moo`03001oogoo0;9oo`00Wgoo0P0000Aoo`00000000Aoo`03001oogoo00Moo`03001oogoo0;9o
o`00X7oo0P000goo00D007ooOomoo`0000Uoo`03001oogoo0;9oo`00X7oo00<007ooOol00Woo00D0
07ooOomoo`0000Uoo`03001oogoo0;9oo`00X7oo00<007ooOol00Woo00<007ooOol00P002Goo00<0
07ooOol0/Woo002POol20003Ool00`00Oomoo`0;Ool00`00Oomoo`2bOol00:1oo`03001oo`000080
00ioo`03001oogoo0;9oo`00X7oo00<007ooOol047oo00<007ooOol0/Woo002OOol2000BOol00`00
Oomoo`2bOol00;=oo`03001oogoo0;9oo`00/goo00<007ooOol0/Woo002cOol00`00Oomoo`2bOol0
0;=oo`03001oogoo0;9oo`00/goo00<007ooOol0/Woo002cOol00`00Oomoo`2bOol00;=oo`03001o
ogoo0;9oo`00/goo00<007ooOol0/Woo003oOomYOol00?moofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {134, 0}} -> {-0.719629, -1.57501, 0.0293845, \
0.0293845}}],

Cell["The compartments matrix of the system is", "Text"],

Cell[BoxData[
    \(model\  = 
      CompartMatrix[
        3, {{1, 2, k12}, {2, 1, k21}\ , {1, 3, k13}, \ {3, 1, k31}, \ {1, 0, 
            k10}}]; \)], "Input",
  CellLabel->"In[77]:="],

Cell["\<\
The laplace transform of the system is (the initial condition is {1,0,0}, \
this mean that there is a input =1 in compartment 1 in t=0 and any input \
later {0,0,0})\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({X1[s_], X2[s_], X3[s_]} = {X\_1[s], X\_2[s], X\_3[s]} /. 
        SystemLTSolve[model, {1, 0, 0}, {0, 0, 0}, \ t, s, \ X]\)], "Input",
  CellLabel->"In[78]:="],

Cell[BoxData[
    \({\(k21\ k31 + k21\ s + k31\ s + s\^2\)\/\(k10\ k21\ k31 + k10\ k21\ s + \
k13\ k21\ s + k10\ k31\ s + k12\ k31\ s + k21\ k31\ s + k10\ s\^2 + k12\ s\^2 \
+ k13\ s\^2 + k21\ s\^2 + k31\ s\^2 + s\^3\), \(k12\ k31 + k12\ s\)\/\(k10\ \
k21\ k31 + k10\ k21\ s + k13\ k21\ s + k10\ k31\ s + k12\ k31\ s + k21\ k31\ \
s + k10\ s\^2 + k12\ s\^2 + k13\ s\^2 + k21\ s\^2 + k31\ s\^2 + s\^3\), \(k13\
\ k21 + k13\ s\)\/\(k10\ k21\ k31 + k10\ k21\ s + k13\ k21\ s + k10\ k31\ s + \
k12\ k31\ s + k21\ k31\ s + k10\ s\^2 + k12\ s\^2 + k13\ s\^2 + k21\ s\^2 + \
k31\ s\^2 + s\^3\)}\)], "Output",
  CellLabel->"Out[78]="]
}, Open  ]],

Cell["The excretion from central compartment is known", "Text"],

Cell[BoxData[
    \(y[t_] = \ 
      0.7\ Exp[\(-5\)\ t] + 0.2\ Exp[\(-t\)] + 
        0.1\ Exp[\(-0.1\)\ t]; \)], "Input",
  CellLabel->"In[79]:="],

Cell["whose laplace transform is", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(yLT\  = LaplaceTransform[y[t], t, s]\)], "Input",
  CellLabel->"In[80]:="],

Cell[BoxData[
    \(0.1`\/\(\(\(0.1`\)\(\[InvisibleSpace]\)\) + s\) + 0.2`\/\(1 + s\) + 
      0.7`\/\(5 + s\)\)], "Output",
  CellLabel->"Out[80]="]
}, Open  ]],

Cell["\<\
We need to obtain   {k10,k21, k12,k13,k31}  knowing that yLT  = X1[s] . It is \
applied the following procedure\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveAlways[yLT \[Equal] X1[s], \ s]\)], "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    \({{k10 \[Rule] 0.746268656716418`, k12 \[Rule] 1.2548842674339162`, 
        k13 \[Rule] 1.7088470758496648`, k21 \[Rule] 0.32435368834411277`, 
        k31 \[Rule] 2.0656463116558883`}, {k10 \[Rule] 0.746268656716418`, 
        k12 \[Rule] 1.7088470758496648`, k13 \[Rule] 1.2548842674339162`, 
        k21 \[Rule] 2.0656463116558883`, 
        k31 \[Rule] 0.32435368834411277`}}\)], "Output",
  CellLabel->"Out[81]="]
}, Open  ]],

Cell["\<\
Two set of solutions are possible. Notice that neither set contains any \
negative rate constants, which would permit rejection is such a set\
\>", "Text"]
}, Closed]],

Cell["Additional information", "Subsection"],

Cell[CellGroupData[{

Cell["References", "SubsectionIcon"],

Cell[TextData[{
  "[1]\[ThickSpace]\[MediumSpace]Sanchez  G, ",
  StyleBox["\[NonBreakingSpace]Biomod. ", "SO"],
  StyleBox["Mathematica", "SO",
    FontSlant->"Italic"],
  StyleBox[" in Eduation and Research ", "SO"],
  ", 10 (2); 2005."
}], "Text",
  CellTags->"ref 1"],

Cell[TextData[{
  "[2]\[ThickSpace]\[MediumSpace]J. A. Jacquez, ",
  StyleBox["\[NonBreakingSpace]Compartmental Analysis in Biology and \
Medicine", "SO"],
  ", The University of Michigan Press, 1985."
}], "Text",
  CellTags->"ref 1"],

Cell[TextData[{
  "[3] ",
  StyleBox["Anderson, D.H. ",
    CharacterEncoding->"WindowsANSI"],
  StyleBox["Compartmental analysis and tracer kinetics",
    FontSlant->"Italic",
    CharacterEncoding->"WindowsANSI"],
  StyleBox[". Berlin: Springer-Verlag; 1983.",
    CharacterEncoding->"WindowsANSI"]
}], "Text",
  CellTags->"ref 4"],

Cell[TextData[{
  StyleBox["[4] Godfrey, K. ",
    CharacterEncoding->"WindowsANSI"],
  StyleBox["Compartmental models and their application",
    FontSlant->"Italic",
    CharacterEncoding->"WindowsANSI"],
  StyleBox[". London: Academic Press; 1983.",
    CharacterEncoding->"WindowsANSI"]
}], "Text",
  CellTags->"ref 4"]
}, Closed]],

Cell[CellGroupData[{

Cell["Additional Material", "SubsectionIcon"],

Cell[TextData[StyleBox[ButtonBox["http://web.usal.es/~guillerm/",
  ButtonData:>{
    URL[ "http://web.usal.es/~guillerm/"], None}],
  ButtonBoxOptions -> {DefaultStyle -> "Hyperlink"}]], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["About the Author and Copyright ", "SubsectionIcon"],

Cell["\<\
Guillermo Sanchez (Ph. D.) works in ENUSA Industrias Avanzadas. S.A. (Spain) \
and teachs Mathematics in Universidad de Salamanca (Spain).\
\>", "Text"],

Cell[CellGroupData[{

Cell["Copyright ", "SubsubsectionIcon"],

Cell[TextData[{
  StyleBox["This package is property",
    FontFamily->"Times New Roman"],
  " of ",
  StyleBox["Guillermo Sanchez. Commercial uses are not allowed",
    FontFamily->"Times New Roman"]
}], "Text"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Brackets",
WindowToolbars->"EditBar",
WindowSize->{896, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PageFooters->{{Inherited, Cell[ 
        TextData[ {
          "\[Copyright]2005 Guillermo Sanchez . All rights reserved."}], 
        "PageFooter"], Inherited}, {Inherited, Cell[ 
        TextData[ {
          "\[Copyright]2005 Guillermo Sanchez. All rights reserved."}], 
        "PageFooter"], Inherited}},
ShowSelection->True,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "DSolve"->{
    Cell[52783, 1703, 122, 3, 70, "MathCaption",
      CellTags->"DSolve"],
    Cell[52930, 1710, 314, 9, 70, "Input",
      CellTags->"DSolve"],
    Cell[53247, 1721, 129, 3, 70, "Output",
      CellTags->"DSolve"],
    Cell[53611, 1735, 415, 12, 70, "Input",
      CellTags->"DSolve"],
    Cell[54029, 1749, 126, 3, 70, "Output",
      CellTags->"DSolve"],
    Cell[55785, 1810, 634, 17, 70, "Input",
      CellTags->"DSolve"],
    Cell[56422, 1829, 467, 10, 70, "Output",
      CellTags->"DSolve"]},
  "Info3234081075-1445498"->{
    Cell[80538, 2493, 725, 10, 70, "Print",
      CellTags->"Info3234081075-1445498"]},
  "Examples"->{
    Cell[324298, 9817, 76, 1, 70, "Text",
      CellTags->"Examples"]},
  "fig 4"->{
    Cell[405534, 10851, 211, 7, 70, "NumberedFigureCaption",
      CellTags->"fig 4"]},
  "ref 1"->{
    Cell[547499, 15299, 271, 8, 70, "Text",
      CellTags->"ref 1"],
    Cell[547773, 15309, 234, 6, 70, "Text",
      CellTags->"ref 1"]},
  "ref 4"->{
    Cell[548010, 15317, 333, 10, 70, "Text",
      CellTags->"ref 4"],
    Cell[548346, 15329, 323, 9, 70, "Text",
      CellTags->"ref 4"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"DSolve", 550582, 15402},
  {"Info3234081075-1445498", 551115, 15417},
  {"Examples", 551219, 15420},
  {"fig 4", 551304, 15423},
  {"ref 1", 551405, 15426},
  {"ref 4", 551559, 15431}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 29, 0, 105, "Title"],
Cell[1808, 55, 301, 8, 61, "FramedBox"],
Cell[2112, 65, 358, 11, 25, "Text"],
Cell[2473, 78, 62, 0, 33, "Commentary"],

Cell[CellGroupData[{
Cell[2560, 82, 65, 2, 29, "Input"],
Cell[2628, 86, 104, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2769, 93, 38, 0, 39, "SubsectionIcon"],
Cell[2810, 95, 725, 25, 48, "Text"],
Cell[3538, 122, 773, 14, 125, "Text"],
Cell[4314, 138, 499, 17, 45, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4850, 160, 60, 0, 29, "SubsectionIcon"],
Cell[4913, 162, 398, 10, 109, "Commentary"],
Cell[5314, 174, 41, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[5380, 178, 87, 2, 29, "Input"],
Cell[5470, 182, 118, 2, 23, "Print"]
}, Open  ]],
Cell[5603, 187, 49, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[5677, 191, 86, 2, 29, "Input"],
Cell[5766, 195, 5603, 139, 87, "Print"]
}, Open  ]],
Cell[11384, 337, 617, 15, 25, "Text"],
Cell[12004, 354, 264, 5, 89, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[12305, 364, 68, 0, 29, "SubsectionIcon"],
Cell[12376, 366, 87, 2, 70, "Text"],
Cell[12466, 370, 2443, 114, 70, "Text"],
Cell[14912, 486, 437, 20, 70, "Text"],
Cell[15352, 508, 35, 0, 70, "Text"],
Cell[15390, 510, 1448, 44, 70, "NumberedEquation"],
Cell[16841, 556, 20, 0, 70, "Text"],
Cell[16864, 558, 282, 9, 70, "Text"],
Cell[17149, 569, 321, 9, 70, "Text"],
Cell[17473, 580, 411, 12, 70, "DisplayFormula"],
Cell[17887, 594, 116, 5, 70, "SmallText"],
Cell[18006, 601, 246, 10, 70, "Text"],
Cell[18255, 613, 535, 13, 70, "DisplayFormula"],
Cell[18793, 628, 167, 6, 70, "Text"],
Cell[18963, 636, 1215, 33, 70, "DefinitionBox"],

Cell[CellGroupData[{
Cell[20203, 673, 239, 6, 70, "Input"],
Cell[20445, 681, 403, 12, 70, "Output"]
}, Open  ]],
Cell[20863, 696, 165, 5, 70, "Text"],
Cell[21031, 703, 865, 21, 70, "DefinitionBox"],

Cell[CellGroupData[{
Cell[21921, 728, 268, 6, 70, "Input"],
Cell[22192, 736, 456, 12, 70, "Output"]
}, Open  ]],
Cell[22663, 751, 150, 5, 70, "Text"],
Cell[22816, 758, 1294, 45, 70, "NumberedEquation"],
Cell[24113, 805, 270, 9, 70, "Text"],
Cell[24386, 816, 124, 3, 70, "DefinitionBox"],

Cell[CellGroupData[{
Cell[24535, 823, 226, 6, 70, "Input"],
Cell[24764, 831, 705, 10, 70, "Output"]
}, Open  ]],
Cell[25484, 844, 764, 19, 70, "Text"],
Cell[26251, 865, 1362, 44, 70, "DefinitionBox"],
Cell[27616, 911, 160, 3, 70, "Input"],

Cell[CellGroupData[{
Cell[27801, 918, 93, 2, 70, "Input"],
Cell[27897, 922, 68, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28002, 929, 98, 2, 70, "Input"],
Cell[28103, 933, 83, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28223, 940, 138, 3, 70, "Input"],
Cell[28364, 945, 1219, 19, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29620, 969, 138, 3, 70, "Input"],
Cell[29761, 974, 173, 3, 70, "Output"]
}, Open  ]],
Cell[29949, 980, 1248, 43, 70, "Text"],
Cell[31200, 1025, 215, 4, 70, "DefinitionBox"],

Cell[CellGroupData[{
Cell[31440, 1033, 129, 3, 70, "Input"],
Cell[31572, 1038, 807, 14, 70, "Output"]
}, Open  ]],
Cell[32394, 1055, 1630, 53, 70, "Text"],
Cell[34027, 1110, 363, 10, 70, "DefinitionBox"],
Cell[34393, 1122, 190, 4, 70, "Input"],

Cell[CellGroupData[{
Cell[34608, 1130, 209, 6, 70, "Input"],
Cell[34820, 1138, 1446, 23, 70, "Output"]
}, Open  ]],
Cell[36281, 1164, 348, 13, 70, "Text"],
Cell[36632, 1179, 463, 20, 70, "Text"],
Cell[37098, 1201, 853, 43, 70, "Text"],
Cell[37954, 1246, 472, 26, 70, "NumberedEquation"],
Cell[38429, 1274, 217, 8, 70, "Text"],
Cell[38649, 1284, 355, 10, 70, "DefinitionBox"],

Cell[CellGroupData[{
Cell[39029, 1298, 209, 6, 70, "Input"],
Cell[39241, 1306, 2883, 49, 70, "Output"]
}, Open  ]],
Cell[42139, 1358, 177, 7, 70, "Text"],
Cell[42319, 1367, 625, 35, 70, "NumberedEquation"],

Cell[CellGroupData[{
Cell[42969, 1406, 134, 3, 70, "Input"],
Cell[43106, 1411, 1352, 20, 70, "Output"]
}, Open  ]],
Cell[44473, 1434, 168, 4, 70, "Text"],
Cell[44644, 1440, 476, 15, 70, "Text"],
Cell[45123, 1457, 1191, 41, 70, "DefinitionBox"],
Cell[46317, 1500, 209, 4, 70, "Input"],

Cell[CellGroupData[{
Cell[46551, 1508, 161, 3, 70, "Input"],
Cell[46715, 1513, 185, 4, 70, "Output"]
}, Open  ]],
Cell[46915, 1520, 31, 0, 70, "Text"],
Cell[46949, 1522, 921, 32, 70, "DefinitionBox"],

Cell[CellGroupData[{
Cell[47895, 1558, 152, 3, 70, "Input"],
Cell[48050, 1563, 2356, 65, 70, "Output"]
}, Open  ]],
Cell[50421, 1631, 69, 0, 70, "Text"],
Cell[50493, 1633, 611, 9, 70, "DefinitionBox"],
Cell[51107, 1644, 212, 4, 70, "Commentary"],

Cell[CellGroupData[{
Cell[51344, 1652, 125, 3, 70, "Input"],
Cell[51472, 1657, 374, 6, 70, "Output"]
}, Open  ]],
Cell[51861, 1666, 152, 4, 70, "Text"],
Cell[52016, 1672, 127, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[52180, 1680, 33, 0, 29, "SubsectionIcon"],
Cell[52216, 1682, 257, 7, 70, "Text"],
Cell[52476, 1691, 304, 10, 70, "Text"],
Cell[52783, 1703, 122, 3, 70, "MathCaption",
  CellTags->"DSolve"],

Cell[CellGroupData[{
Cell[52930, 1710, 314, 9, 70, "Input",
  CellTags->"DSolve"],
Cell[53247, 1721, 129, 3, 70, "Output",
  CellTags->"DSolve"]
}, Open  ]],
Cell[53391, 1727, 195, 4, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[53611, 1735, 415, 12, 70, "Input",
  CellTags->"DSolve"],
Cell[54029, 1749, 126, 3, 70, "Output",
  CellTags->"DSolve"]
}, Open  ]],
Cell[54170, 1755, 1590, 51, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[55785, 1810, 634, 17, 70, "Input",
  CellTags->"DSolve"],
Cell[56422, 1829, 467, 10, 70, "Output",
  CellTags->"DSolve"]
}, Open  ]],
Cell[56904, 1842, 72, 0, 70, "Text"],
Cell[56979, 1844, 689, 21, 70, "DisplayFormula"],
Cell[57671, 1867, 43, 0, 70, "MathCaption"],
Cell[57717, 1869, 71, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[57813, 1875, 352, 6, 70, "Input"],
Cell[58168, 1883, 486, 8, 70, "Output"]
}, Open  ]],
Cell[58669, 1894, 62, 0, 70, "MathCaption"],
Cell[58734, 1896, 119, 3, 70, "Input"],
Cell[58856, 1901, 119, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[59000, 1908, 95, 2, 70, "Input"],
Cell[59098, 1912, 18305, 479, 70, 4437, 303, "GraphicsData", "PostScript", \
"Graphics"],
Cell[77406, 2393, 155, 4, 70, "Output"]
}, Open  ]],
Cell[77576, 2400, 163, 4, 70, "MathCaption"],
Cell[77742, 2406, 71, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[77838, 2412, 362, 7, 70, "Input"],
Cell[78203, 2421, 350, 7, 70, "Output"]
}, Open  ]],
Cell[78568, 2431, 304, 9, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[78909, 2445, 96, 2, 29, "SubsectionIcon"],
Cell[79008, 2449, 707, 17, 70, "Text"],

Cell[CellGroupData[{
Cell[79740, 2470, 60, 0, 70, "SubsubsectionIcon"],
Cell[79803, 2472, 732, 19, 70, "Text"],
Cell[80538, 2493, 725, 10, 70, "Print",
  CellTags->"Info3234081075-1445498"],
Cell[81266, 2505, 2449, 67, 70, "Text"],
Cell[83718, 2574, 74, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[83817, 2578, 254, 5, 70, "Input"],
Cell[84074, 2585, 1228, 19, 70, "Output"]
}, Open  ]],
Cell[85317, 2607, 43, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[85385, 2611, 297, 5, 70, "Input"],
Cell[85685, 2618, 1217, 19, 70, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[86951, 2643, 61, 0, 70, "SubsubsectionIcon"],
Cell[87015, 2645, 837, 22, 70, "Text"],
Cell[87855, 2669, 3432, 97, 70, "Text"],
Cell[91290, 2768, 688, 14, 70, "Input"],

Cell[CellGroupData[{
Cell[92003, 2786, 140, 3, 70, "Input"],
Cell[92146, 2791, 36103, 1203, 70, 14108, 926, "GraphicsData", "PostScript", \
"Graphics"],
Cell[128252, 3996, 155, 4, 70, "Output"]
}, Open  ]],
Cell[128422, 4003, 66, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[128513, 4007, 135, 3, 70, "Input"],
Cell[128651, 4012, 1286, 29, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[129998, 4048, 85, 1, 29, "SubsectionIcon"],
Cell[130086, 4051, 666, 22, 70, "Text"],
Cell[130755, 4075, 37538, 953, 70, 15699, 678, "GraphicsData", "PostScript", \
"Graphics"],
Cell[168296, 5030, 241, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[168562, 5040, 57, 0, 70, "SubsubsectionIcon"],
Cell[168622, 5042, 882, 20, 70, "Text"],

Cell[CellGroupData[{
Cell[169529, 5066, 218, 5, 70, "Input"],
Cell[169750, 5073, 202, 4, 70, "Output"]
}, Open  ]],
Cell[169967, 5080, 94, 2, 70, "Text"],
Cell[170064, 5084, 380, 12, 70, "Text"],
Cell[170447, 5098, 104, 2, 70, "Input"],
Cell[170554, 5102, 387, 13, 70, "Text"],
Cell[170944, 5117, 84, 2, 70, "Input"],
Cell[171031, 5121, 757, 18, 70, "Text"],

Cell[CellGroupData[{
Cell[171813, 5143, 210, 5, 70, "Input"],
Cell[172026, 5150, 1208, 19, 70, "Output"]
}, Open  ]],
Cell[173249, 5172, 117, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[173391, 5179, 159, 3, 70, "Input"],
Cell[173553, 5184, 1245, 18, 70, "Output"]
}, Open  ]],
Cell[174813, 5205, 770, 18, 70, "Text"],

Cell[CellGroupData[{
Cell[175608, 5227, 140, 3, 70, "Input"],
Cell[175751, 5232, 1262, 19, 70, "Output"]
}, Open  ]],
Cell[177028, 5254, 539, 11, 70, "Text"],

Cell[CellGroupData[{
Cell[177592, 5269, 150, 3, 70, "Input"],
Cell[177745, 5274, 2448, 66, 70, "Output"]
}, Open  ]],
Cell[180208, 5343, 61, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[180294, 5347, 659, 12, 70, "Input"],
Cell[180956, 5361, 46795, 1606, 70, 24119, 1321, "GraphicsData", \
"PostScript", "Graphics"],
Cell[227754, 6969, 155, 4, 70, "Output"]
}, Open  ]],
Cell[227924, 6976, 95, 2, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[228056, 6983, 63, 0, 70, "SubsubsectionIcon"],
Cell[228122, 6985, 2035, 63, 70, "Text"],
Cell[230160, 7050, 171, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[230356, 7058, 146, 3, 70, "Input"],
Cell[230505, 7063, 756, 11, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[231298, 7079, 513, 8, 70, "Input"],
Cell[231814, 7089, 34586, 1125, 70, 17980, 915, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[266415, 8217, 75, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[266527, 8224, 57, 0, 70, "SubsubsectionIcon"],
Cell[266587, 8226, 375, 8, 70, "Text"],

Cell[CellGroupData[{
Cell[266987, 8238, 188, 5, 70, "Input"],
Cell[267178, 8245, 933, 14, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[268148, 8264, 504, 8, 70, "Input"],
Cell[268655, 8274, 26562, 785, 70, 10466, 581, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[295266, 9065, 58, 0, 70, "SubsubsectionIcon"],
Cell[295327, 9067, 431, 14, 70, "Text"],
Cell[295761, 9083, 250, 10, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[296036, 9097, 172, 5, 70, "Input"],
Cell[296211, 9104, 924, 14, 70, "Output"]
}, Open  ]],
Cell[297150, 9121, 268, 9, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[297443, 9134, 127, 3, 70, "Input"],
Cell[297573, 9139, 2750, 56, 70, "Output"]
}, Open  ]],
Cell[300338, 9198, 100, 2, 70, "Input"],
Cell[300441, 9202, 168, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[300634, 9211, 109, 2, 70, "Input"],
Cell[300746, 9215, 21548, 537, 70, 4644, 323, "GraphicsData", "PostScript", \
"Graphics"],
Cell[322297, 9754, 155, 4, 70, "Output"]
}, Open  ]],
Cell[322467, 9761, 100, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[322604, 9768, 63, 0, 70, "SubsubsectionIcon"],
Cell[322670, 9770, 201, 4, 70, "Text"],
Cell[322874, 9776, 560, 11, 70, "Input"],
Cell[323437, 9789, 398, 10, 70, "SmallText"],

Cell[CellGroupData[{
Cell[323860, 9803, 218, 5, 70, "Input"],
Cell[324081, 9810, 202, 4, 70, "Output"]
}, Open  ]],
Cell[324298, 9817, 76, 1, 70, "Text",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[324399, 9822, 139, 3, 70, "Input"],
Cell[324541, 9827, 3291, 49, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[327881, 9882, 76, 0, 70, "SubsubsectionIcon"],
Cell[327960, 9884, 390, 6, 70, "Text"],
Cell[328353, 9892, 16, 0, 70, "Text"],
Cell[328372, 9894, 77159, 955, 70, 77067, 952, "GraphicsData", "Metafile", \
"Text"],
Cell[405534, 10851, 211, 7, 70, "NumberedFigureCaption",
  CellTags->"fig 4"],
Cell[405748, 10860, 65, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[405838, 10864, 484, 8, 70, "Input"],
Cell[406325, 10874, 959, 27, 70, "Output"]
}, Open  ]],
Cell[407299, 10904, 328, 10, 70, "Text"],
Cell[407630, 10916, 684, 12, 70, "Input"],
Cell[408317, 10930, 89, 2, 70, "Text"],
Cell[408409, 10934, 327, 7, 70, "Input"],
Cell[408739, 10943, 519, 13, 70, "SmallText"],
Cell[409261, 10958, 53, 0, 70, "Text"],
Cell[409317, 10960, 507, 9, 70, "Input"],
Cell[409827, 10971, 192, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[410044, 10979, 147, 3, 70, "Input"],
Cell[410194, 10984, 6024, 91, 70, "Output"]
}, Open  ]],
Cell[416233, 11078, 247, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[416505, 11087, 205, 4, 70, "Input"],
Cell[416713, 11093, 4391, 76, 70, "Output"]
}, Open  ]],
Cell[421119, 11172, 91, 2, 70, "Text"],

Cell[CellGroupData[{
Cell[421235, 11178, 173, 4, 70, "Input"],
Cell[421411, 11184, 576, 11, 70, "Output"]
}, Open  ]],
Cell[422002, 11198, 200, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[422227, 11206, 417, 7, 70, "Input"],
Cell[422647, 11215, 39630, 1308, 70, 24992, 1122, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[462292, 12526, 1024, 21, 70, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[463365, 12553, 98, 2, 29, "SubsectionIcon"],
Cell[463466, 12557, 1037, 26, 70, "Text"],
Cell[464506, 12585, 598, 18, 70, "Text"],

Cell[CellGroupData[{
Cell[465129, 12607, 306, 6, 70, "Input"],
Cell[465438, 12615, 404, 7, 70, "Output"]
}, Open  ]],
Cell[465857, 12625, 380, 12, 70, "Text"],
Cell[466240, 12639, 104, 2, 70, "Input"],
Cell[466347, 12643, 320, 12, 70, "Text"],
Cell[466670, 12657, 84, 2, 70, "Input"],
Cell[466757, 12661, 697, 18, 70, "Text"],
Cell[467457, 12681, 206, 5, 70, "Input"],
Cell[467666, 12688, 61, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[467752, 12692, 143, 3, 70, "Input"],
Cell[467898, 12697, 53558, 1759, 70, 20520, 1346, "GraphicsData", \
"PostScript", "Graphics"],
Cell[521459, 14458, 155, 4, 70, "Output"]
}, Open  ]],
Cell[521629, 14465, 66, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[521720, 14469, 135, 3, 70, "Input"],
Cell[521858, 14474, 1288, 29, 70, "Output"]
}, Open  ]],
Cell[523161, 14506, 114, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[523312, 14513, 70, 0, 29, "SubsectionIcon"],
Cell[523385, 14515, 518, 8, 84, "Text"],
Cell[523906, 14525, 20759, 683, 114, 12246, 573, "GraphicsData", \
"PostScript", "Graphics"],
Cell[544668, 15210, 56, 0, 25, "Text"],
Cell[544727, 15212, 188, 5, 29, "Input"],
Cell[544918, 15219, 189, 4, 25, "Text"],

Cell[CellGroupData[{
Cell[545132, 15227, 180, 3, 29, "Input"],
Cell[545315, 15232, 626, 9, 114, "Output"]
}, Open  ]],
Cell[545956, 15244, 63, 0, 25, "Text"],
Cell[546022, 15246, 148, 4, 29, "Input"],
Cell[546173, 15252, 42, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[546240, 15256, 94, 2, 29, "Input"],
Cell[546337, 15260, 149, 3, 40, "Output"]
}, Open  ]],
Cell[546501, 15266, 135, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[546661, 15273, 94, 2, 29, "Input"],
Cell[546758, 15277, 438, 7, 46, "Output"]
}, Open  ]],
Cell[547211, 15287, 165, 3, 25, "Text"]
}, Closed]],
Cell[547391, 15293, 44, 0, 39, "Subsection"],

Cell[CellGroupData[{
Cell[547460, 15297, 36, 0, 39, "SubsectionIcon"],
Cell[547499, 15299, 271, 8, 70, "Text",
  CellTags->"ref 1"],
Cell[547773, 15309, 234, 6, 70, "Text",
  CellTags->"ref 1"],
Cell[548010, 15317, 333, 10, 70, "Text",
  CellTags->"ref 4"],
Cell[548346, 15329, 323, 9, 70, "Text",
  CellTags->"ref 4"]
}, Closed]],

Cell[CellGroupData[{
Cell[548706, 15343, 45, 0, 29, "SubsectionIcon"],
Cell[548754, 15345, 195, 3, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[548986, 15353, 57, 0, 29, "SubsectionIcon"],
Cell[549046, 15355, 162, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[549233, 15362, 39, 0, 70, "SubsubsectionIcon"],
Cell[549275, 15364, 212, 6, 70, "Text"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

