(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2882781,      84769]*)
(*NotebookOutlinePosition[   2884650,      84829]*)
(*  CellTagsIndexPosition[   2884414,      84818]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
SysModel applied for solving compartmental and physiological models \
\>", "Chapter"],

Cell[TextData[{
  StyleBox["Author",
    FontWeight->"Bold"],
  ": Guillermo Sanchez:  ",
  StyleBox["guillermo@usal.es, ",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  StyleBox[ButtonBox["http://web.usal.es/~guillerm/",
    ButtonData:>{
      URL[ "http://web.usal.es/~guillerm/"], None}],
    ButtonBoxOptions -> {DefaultStyle -> "Hyperlink"}]
}], "Text"],

Cell["Last update of this help:  \t 2005-08-22", "Commentary"],

Cell[CellGroupData[{

Cell[BoxData[
    \($Version\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("5.1 for Microsoft Windows (January 28, 2005)"\)], "Output",
  CellLabel->"Out[1]="]
}, Open  ]],

Cell[TextData[{
  "Update and additional material (for this tutorial is required Biokmod): ",
  StyleBox[ButtonBox["http://web.usal.es/~guillerm/biokmod.htm",
    ButtonData:>{
      URL[ "http://web.usal.es/~guillerm/"], None}],
    ButtonBoxOptions -> {DefaultStyle -> "Hyperlink"}]
}], "Text"],

Cell[CellGroupData[{

Cell["Introduction ", "SubsectionIcon"],

Cell[TextData[{
  "Here is introduced the compartmental analysis and it is shown how",
  StyleBox[" SysModel", "Input"],
  " can be applied for solving compartmental model with constant \
coefficients."
}], "Text"],

Cell["We will need download these packages", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Needs["\<Biokmod`SysModel`\>"]\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \("SysModel, guillermo@usal.es, version 1.3.   2005-07-15"\)], "Print",
  CellLabel->"From In[2]:="]
}, Open  ]],

Cell[BoxData[{
    \(Off[General::spell]; \), "\[IndentingNewLine]", 
    \(Off[General::spell1]; \), "\[IndentingNewLine]", 
    \(Needs["\<Graphics`Legend`\>"]\), "\[IndentingNewLine]", 
    \(Needs["\<Graphics`Graphics`\>"]\)}], "Input",
  CellLabel->"In[3]:="],

Cell["Help about SysModel can be obtained as usual", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?"\<Biokmod`SysModel`*\>"\)\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[GridBox[{
        {
          StyleBox["Biokmod`SysModel`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["AcuteInput",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703458-4549193", 
                    "Biokmod`SysModel`AcuteInput"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`SysModel`"], 
                ButtonBox[
                  StyleBox["CoefMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703458-4549193", 
                    "Biokmod`SysModel`CoefMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`SysModel`"], 
                ButtonBox[
                  StyleBox["matrixExp",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703458-4549193", 
                    "Biokmod`SysModel`matrixExp"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`SysModel`"], 
                ButtonBox[
                  StyleBox["ShowODE",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703458-4549193", 
                    "Biokmod`SysModel`ShowODE"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`SysModel`"], 
                ButtonBox[
                  StyleBox["SystemLTSolve",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703458-4549193", 
                    "Biokmod`SysModel`SystemLTSolve"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`SysModel`"], "", "", ""},
              {
                ButtonBox[
                  StyleBox["Catenary",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703458-4549193", 
                    "Biokmod`SysModel`Catenary"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`SysModel`"], 
                ButtonBox[
                  StyleBox["CompartMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703458-4549193", 
                    "Biokmod`SysModel`CompartMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`SysModel`"], 
                ButtonBox[
                  StyleBox["MultiExpInput",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703458-4549193", 
                    "Biokmod`SysModel`MultiExpInput"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`SysModel`"], 
                ButtonBox[
                  StyleBox["SystemDSolve",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703458-4549193", 
                    "Biokmod`SysModel`SystemDSolve"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`SysModel`"], 
                ButtonBox[
                  StyleBox["SystemNDSolve",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703458-4549193", 
                    "Biokmod`SysModel`SystemNDSolve"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`SysModel`"], "", "", ""}
              },
            RowMinHeight->{1, 1.05}]}
        },
      RowSpacings->{2, 3},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->RGBColor[0.964706, 0.929412, 0.839216],
  ButtonBoxOptions->{Active->True},
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Overview of Compartmental Analysis", "SubsectionIcon"],

Cell["\<\
Compartmental analysis has applications in clinical medicine, \
pharmacokinetics, internal dosimetry, nuclear medicine, ecosystem studies and \
chemical reaction kinetics.  It can be described as the analysis of a system \
in terms of compartments which separate the system into a finite number of \
component parts which are called compartments. Compartments interact through \
the exchange of species. Species may be a chemical substance, hormone, \
individuals in a population and so on.  A compartmental system is usually \
represented by a flow diagram or a block diagram. \
\>", "Text"],

Cell[TextData[{
  "We adopt the convention of  representing compartments with circles or \
rectangles. The flow into or out of the compartments is represented by \
arrows.  The ",
  Cell[BoxData[
      \(TraditionalForm\`i\^th\)]],
  " compartment  of a system of ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "compartments is labelled ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " and the size (amount or content) of the component in compartment  ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(x\_i\),
            "TraditionalForm"], 
          FormBox[
            RowBox[{"(", 
              FormBox["t",
                "TraditionalForm"], ")"}],
            "TraditionalForm"]}], TraditionalForm]]],
  ". The exchange between compartments, or between a compartment and the \
environment is labeled ",
  Cell[BoxData[
      \(TraditionalForm\`k\_ij\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " represents the flow from ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ". We can often write ",
  Cell[BoxData[
      \(TraditionalForm\`k\_i\)]],
  "  if compartment ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " is not ambiguous with ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ". The environment is usually represented by \"0\" (zero), so ",
  Cell[BoxData[
      \(TraditionalForm\`k\_i0\)]],
  " is the fractional excretion coefficient from the ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  "-th compartment to the outside environment.  The  input from the \
environment into the ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  "-th compartment is called ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_j\)(t)\)]],
  ". Environment represents the processes that are outside the system. With \
regards to the environment, we only need to know the flow, ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_j\)(t)\)]],
  ",  into the system from the outside. The ",
  Cell[BoxData[
      \(TraditionalForm\`k\_ij\)]],
  " are called fractional transfer rate coefficients and they may be a \
function of different variables or constants. "
}], "Text"],

Cell[TextData[{
  "The model of figure 1 consist in two compartments. There is an input",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[\(b\_i\),
              "TraditionalForm"], "(", "t", ")"}], " "}], TraditionalForm]]],
  " to compartment ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " and an exchange of flow between compartment ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ", with transfer coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`k\_ij\)]],
  " from compartment ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  "  and  ",
  Cell[BoxData[
      \(TraditionalForm\`k\_ji\)]],
  "  from compartment ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ". The model has an output of system from competent ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " with a transfer coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`k\_i0\)]],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .66667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.12963 0.21164 0.333333 0.21164 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125  moveto 0 0 lineto 
-0.05 -0.0125  lineto stroke
} ifelse
grestore
} def
/MAarrowhead2 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.12963 .65079 m
.12963 .43915 L
s
% Start of user PostScript
0 1.5 0 0.5 MAarrowhead1
% End of user PostScript
gsave
.21429 .54497 -77.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.875 12.750 moveto
(H) show
79.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
85.875 12.750 moveto
(L) show
91.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.12963 .33333 .10582 0 365.73 arc
s
gsave
.12963 .31217 -77.4375 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.875 12.750 moveto
(H) show
79.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
85.875 12.750 moveto
(L) show
91.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.12963 .3545 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.12963 .22751 m
.12963 .01587 L
s
% Start of user PostScript
0 -0.5 0 -1.5 MAarrowhead2
% End of user PostScript
gsave
.21429 .12169 -70.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i0) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23545 .37566 m
.76455 .37566 L
s
% Start of user PostScript
0.5 0.2 3. 0.2 MAarrowhead2
% End of user PostScript
gsave
.5 .41799 -70.625 -10.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.625 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ij) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.76455 .29101 m
.23545 .29101 L
s
% Start of user PostScript
3. -0.2 0.5 -0.2 MAarrowhead2
% End of user PostScript
gsave
.5 .24868 -70.625 -10.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.625 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ji) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.87037 .33333 .10582 0 365.73 arc
s
gsave
.87037 .31217 -77.4375 -10.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.625 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.875 12.750 moveto
(H) show
79.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
85.875 12.750 moveto
(L) show
91.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.87037 .3545 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{288, 192},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000l1000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00;Woo00<007ooOol0ogoo>7oo000^Ool0
0`00Oomoo`3oOolhOol002ioo`800?moocUoo`00;Goo0`00ogoo>Goo000]Ool3003oOoliOol002eo
o`<00?moocUoo`00;Goo1000ogoo>7oo000/Ool5003oOolhOol002aoo`D00?moocQoo`00;7oo1@00
ogoo>7oo000/Ool6003oOolgOol002aoo`H00?moocMoo`00:goo1`00ogoo=goo000[Ool8003oOolf
Ool002]oo`P00?moocIoo`00:goo2000ogoo=Woo000ZOol9003oOolfOol002Yoo`X00?moocEoo`00
:Woo2P00ogoo=Goo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo00<0
07ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo00<0
07ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo00<0
07ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo00<0
07ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo00<0
07ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo00<0
07ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo00<0
07ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo00<0
07ooOol06goo0`000goo00<007ooOol0ogoo57oo000^Ool00`00Oomoo`0LOol01`00Oomoogoo001o
o`000?mooaEoo`00;Woo00<007ooOol04goo0P000Woo0`000Woo00L007ooOomoo`00Ool0003oOolE
Ool002ioo`03001oogoo01Aoo`04001oogoo0003Ool20003Ool00`00Ool0003oOolEOol002ioo`03
001oogoo01Aoo`03001oo`0000Uoo`03001oo`000?mooaEoo`00;Woo00<007ooOol057oo0`001Goo
00<007ooOol00Woo00<007ooOol0ogoo57oo000^Ool00`00Oomoo`0DOol01000Oomoo`00ogoo87oo
000^Ool00`00Oomoo`0DOol00`00Ool00003003oOolNOol002ioo`03001oogoo01Aoo`03001oogoo
0?moob5oo`00;Woo00<007ooOol04goo0P00ogoo8goo000^Ool00`00Oomoo`3oOolhOol002ioo`03
001oogoo0?moocQoo`00;Woo00<007ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03
001oogoo0?moocQoo`00;Woo00<007ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03
001oogoo0?moocQoo`00;Woo00<007ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03
001oogoo0?moocQoo`00;Woo00<007ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03
001oogoo0?moocQoo`00;Woo00<007ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03
001oogoo0?moocQoo`00;Woo00<007ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03
001oogoo0?moocQoo`00;Woo00<007ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03
001oogoo0?moocQoo`00;Woo00<007ooOol0ogoo>7oo000ZOol:003oOol;000ZOol002Aoo`H000Yo
o`H00?Aoo`D000]oo`D002Eoo`008Woo0P005Woo00<007ooOol0MGoo0`00Mgoo0P005Goo0P008goo
000OOol3000IOol4001eOol00`00Oomoo`1aOol4000IOol3000POol001eoo`80021oo`8007=oo`03
001oogoo00<006aoo`80021oo`8001ioo`006goo0P0097oo00<007ooOol0L7oo00D007ooOomoo`00
06aoo`03001oogoo029oo`8001aoo`006Woo00<007ooOol09Goo0P00IWoo0P000Woo0`000goo00D0
07ooOomoo`0006Yoo`8002Moo`03001oogoo01Uoo`0067oo0P00:Woo00<007ooOol0I7oo00@007oo
Ool000=oo`<0009oo`8006Uoo`03001oogoo02Qoo`8001Uoo`005goo00<007ooOol0:goo0P00I7oo
00<007oo0000Lgoo00<007ooOol0:goo00<007ooOol05Woo000FOol00`00Oomoo`0^Ool00`00Oomo
o`1QOol30005Ool00`00Oomoo`02Ool00`00Oomoo`1UOol00`00Oomoo`0]Ool00`00Oomoo`0EOol0
01Eoo`03001oogoo031oo`03001oogoo061oo`04001oogoo001`Ool00`00Oomoo`0_Ool00`00Oomo
o`0DOol001=oo`8003Aoo`03001oogoo05moo`03001oo`0000<006aoo`8003=oo`03001oogoo01=o
o`004Woo00<007ooOol0=Goo00<007ooOol0GWoo00<007ooOol0KWoo00<007ooOol0=7oo00<007oo
Ool04Woo000AOol00`00Oomoo`0fOol00`00Oomoo`1MOol2001_Ool00`00Oomoo`0fOol00`00Oomo
o`0AOol0015oo`03001oogoo03Moo`03001oogoo0<eoo`03001oogoo03Moo`03001oogoo011oo`00
47oo00<007ooOol0>Goo00<007ooOol0bgoo00<007ooOol0>Goo00<007ooOol03goo000?Ool00`00
Oomoo`0kOol00`00Oomoo`39Ool00`00Oomoo`0jOol00`00Oomoo`0?Ool000moo`03001oogoo03ao
o`03001oogoo0<Moo`03001oogoo03aoo`03001oogoo00ioo`003Woo00<007ooOol0?Woo00<007oo
Ool04goo0P00/7oo00<007ooOol0?Woo00<007ooOol03Goo000=Ool00`00Oomoo`0oOol00`00Oomo
o`0?Ool6002_Ool00`00Oomoo`0oOol00`00Oomoo`0=Ool000eoo`03001oogoo041oo`03001oogoo
00]oo`T00:moo`03001oogoo041oo`03001oogoo00aoo`0037oo00<007ooOol0@Goo00<007ooOol0
1goo3@00[goo00<007ooOol0@7oo00<007ooOol037oo000<Ool00`00Oomoo`11Ool00`00Oomoo`03
OolA002_Ool00`00Oomoo`11Ool00`00Oomoo`0;Ool000]oo`03001oogoo04=oo`03001oogoo0;l0
009oo`03001oogoo04=oo`03001oogoo00Yoo`002goo00<007ooOol0@goo00<007ooOol00goo4000
[Goo00<007ooOol0A7oo00<007ooOol02Woo000;Ool00`00Oomoo`14Ool00`00Oomoo`06Ool<002]
Ool00`00Oomoo`0GOol3000ZOol00`00Oomoo`0:Ool000Yoo`03001oogoo01Qoo`<000Qoo`03001o
ogoo00Moo`03001oogoo01Eoo`03001oogoo00]oo`L00:eoo`03001oogoo01Uoo`03001oogoo00Io
o`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo00Yoo`002Woo00<007ooOol06Goo00<007oo
Ool01Woo00<007ooOol02Goo00<007ooOol057oo00<007ooOol03goo0`00[Goo00<007ooOol06Goo
00<007ooOol01Goo00<007ooOol02Goo00<007ooOol05Goo00<007ooOol02Goo0009Ool00`00Oomo
o`0AOol20002Ool20003Ool00`00Oomoo`05Ool00`00Oomoo`03Ool30005Ool00`00Oomoo`0COol0
0`00Oomoo`2nOol00`00Oomoo`0AOol20002Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`04Ool3
0004Ool00`00Oomoo`0DOol00`00Oomoo`09Ool000Uoo`03001oogoo019oo`04001oogoo0003Ool2
0007Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol057oo00<007ooOol0_Goo00<0
07ooOol04Woo00@007ooOol000Aoo`03001oogoo00Aoo`03001oogoo00=oo`05001oogooOol00003
Ool00`00Oomoo`0EOol00`00Oomoo`08Ool000Uoo`03001oogoo01=oo`8000eoo`03001oogoo009o
o`03001oogoo00Ioo`03001oogoo01Aoo`03001oogoo0;eoo`03001oogoo01=oo`8000=oo`<000Io
o`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo01Eoo`03001oogoo00Qoo`002Goo00<007oo
Ool04goo0P001Goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol057oo
00<007ooOol0_7oo00<007ooOol057oo0P0037oo00<007ooOol00goo00<007ooOol01Goo00<007oo
Ool05Goo00<007ooOol027oo0009Ool00`00Oomoo`0BOol01000Oomoo`0037oo00<007ooOol00Woo
00<007ooOol01Woo00<007ooOol05Goo00<007ooOol0^goo00<007ooOol04goo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo01Eoo`03001oogoo00Qo
o`0027oo00<007ooOol04Woo0P000Woo0P002goo00@007ooOomoo`D000Eoo`03001oogoo01Eoo`03
001oogoo0;]oo`03001oogoo019oo`80009oo`8000Yoo`03001oogoo009oo`D000Aoo`03001oogoo
01Eoo`03001oogoo00Qoo`0027oo00<007ooOol097oo00D007ooOomoo`0000Moo`03001oogoo01Io
o`03001oogoo0;]oo`03001oogoo02=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo01Mo
o`03001oogoo00Moo`0027oo00<007ooOol09Goo00<007ooOol01goo00<007ooOol05goo00<007oo
Ool0^goo00<007ooOol097oo00<007ooOol01goo00<007ooOol067oo00<007ooOol01goo0008Ool0
0`00Oomoo`19Ool00`00Oomoo`2kOol00`00Oomoo`19Ool00`00Oomoo`07Ool000Qoo`03001oogoo
04Uoo`03001oogoo0;]oo`03001oogoo04Uoo`03001oogoo00Moo`0027oo00<007ooOol0BGoo00<0
07ooOol0^goo00<007ooOol0BGoo00<007ooOol01goo0008Ool00`00Oomoo`19Ool00`00Oomoo`2k
Ool00`00Oomoo`19Ool00`00Oomoo`07Ool000Qoo`03001oogoo04Uoo`03001oogoo0;]oo`03001o
ogoo04Uoo`03001oogoo00Moo`0027oo00<007ooOol0BGoo00<007ooOol0^goo00<007ooOol087oo
10009Goo00<007ooOol01goo0008Ool00`00Oomoo`19Ool00`00Oomoo`2kOol00`00Oomoo`0TOol0
0`00Oomoo`0ROol00`00Oomoo`07Ool000Qoo`03001oogoo029oo`D0029oo`03001oogoo0;]oo`03
001oogoo02Aoo`03001oogoo025oo`03001oogoo00Qoo`002Goo00<007ooOol08goo00<007ooOol0
8Woo00<007ooOol0^goo00<007ooOol097oo00<007ooOol08Goo00<007ooOol027oo0009Ool00`00
Oomoo`0SOol00`00Oomoo`0QOol00`00Oomoo`2lOol00`00Oomoo`0TOol00`00Oomoo`0QOol00`00
Oomoo`08Ool000Uoo`03001oogoo02=oo`03001oogoo025oo`03001oogoo0;eoo`03001oogoo02=o
o`03001oogoo025oo`03001oogoo00Qoo`002Goo00<007ooOol08goo00<007ooOol08Goo00<007oo
Ool0_Goo00<007ooOol08goo00<007ooOol08Goo00<007ooOol027oo0009Ool00`00Oomoo`0QOol3
000ROol00`00Oomoo`2nOol00`00Oomoo`0POol4000ROol00`00Oomoo`09Ool000Yoo`03001oogoo
04Eoo`03001oogoo0:]oo`<0015oo`03001oogoo04Eoo`03001oogoo00Uoo`002Woo00<007ooOol0
8Woo00<007ooOol087oo00<007ooOol0Zgoo1`003Goo00<007ooOol08Goo00<007ooOol087oo00<0
07ooOol02Woo000;Ool00`00Oomoo`14Ool00`00Oomoo`2[Ool<0008Ool00`00Oomoo`14Ool00`00
Oomoo`0:Ool000]oo`03001oogoo04=oo`03001oogoo0:aooa0000Aoo`03001oogoo04Aoo`03001o
ogoo00Yoo`002goo00<007ooOol0@goo00<007ooOol0_`000Woo00<007ooOol0@goo00<007ooOol0
2Woo000<Ool00`00Oomoo`11Ool00`00Oomoo`2]OolA0005Ool00`00Oomoo`11Ool00`00Oomoo`0;
Ool000aoo`03001oogoo045oo`03001oogoo0:eoo`d000Uoo`03001oogoo041oo`03001oogoo00ao
o`003Goo00<007ooOol0@7oo00<007ooOol0[Goo2P0037oo00<007ooOol0@7oo00<007ooOol037oo
000=Ool00`00Oomoo`0oOol00`00Oomoo`2^Ool6000@Ool00`00Oomoo`0oOol00`00Oomoo`0=Ool0
00ioo`03001oogoo03ioo`03001oogoo0:ioo`8001Eoo`03001oogoo03ioo`03001oogoo00eoo`00
3goo00<007ooOol0?7oo00<007ooOol0agoo00<007ooOol0?7oo00<007ooOol03Woo000?Ool00`00
Oomoo`0kOol00`00Oomoo`39Ool00`00Oomoo`0jOol00`00Oomoo`0?Ool0011oo`03001oogoo03Uo
o`03001oogoo0<]oo`03001oogoo03Uoo`03001oogoo00moo`004Goo00<007ooOol0=goo00<007oo
Ool0JGoo0`00HGoo00<007ooOol0=goo00<007ooOol047oo000AOol00`00Oomoo`0fOol00`00Oomo
o`1/Ool00`00Oomoo`1OOol00`00Oomoo`0fOol00`00Oomoo`0AOol0019oo`03001oogoo03Eoo`03
001oogoo06Eoo`<000Aoo`03001oogoo061oo`03001oogoo03Aoo`03001oogoo019oo`004goo0P00
=7oo00<007ooOol0Igoo00<007ooOol00goo00<007ooOol0HGoo0P00<goo00<007ooOol04goo000E
Ool00`00Oomoo`0`Ool00`00Oomoo`1OOol20002Ool30002Ool00`00Oomoo`03Ool00`00Oomoo`1S
Ool00`00Oomoo`0_Ool00`00Oomoo`0DOol001Ioo`03001oogoo02ioo`03001oogoo065oo`04001o
ogoo0003Ool20003Ool3001VOol00`00Oomoo`0]Ool00`00Oomoo`0EOol001Moo`03001oogoo02ao
o`03001oogoo069oo`03001oo`0007=oo`03001oogoo02]oo`03001oogoo01Ioo`0067oo00<007oo
Ool0:Goo0P00IGoo0`001Goo00<007ooOol00Woo00<007ooOol0Igoo00<007ooOol0:Goo00<007oo
Ool05goo000IOol2000XOol00`00Oomoo`1UOol01000Oomoo`00M7oo00<007ooOol09Woo0P006Woo
000KOol00`00Oomoo`0SOol2001XOol00`00Ool00003001cOol2000UOol00`00Oomoo`0JOol001ao
o`80029oo`03001oogoo06Qoo`03001oogoo07Qoo`03001oogoo021oo`8001eoo`007Woo0`006goo
1000JWoo0P00Ngoo10006goo0`007goo000QOol2000GOol2003_Ool2000GOol2000ROol002=oo`H0
00aoo`D00?=oo`D000aoo`H002Aoo`00:Goo3000oGoo3000:Woo000^Ool00`00Oomoo`3oOolhOol0
02ioo`800?moocUoo`00;Goo0`00ogoo>Goo000]Ool3003oOoliOol002eoo`<00?moocUoo`00;Goo
0P0000=oo`00Ool0ogoo=goo000/Ool01@00Ool007oo0000ogoo>7oo000/Ool01@00Ool007oo0000
ogoo>7oo000/Ool01@00Ool007oo0000ogoo>7oo000/Ool00`00Ool00002Ool00`00Oomoo`3oOole
Ool002aoo`03001oo`00009oo`03001oogoo0?moocEoo`00:goo00@007ooOol0009oo`03001oogoo
0?moocEoo`00:goo00@007ooOol000=oo`03001oogoo0?moocAoo`00:goo00@007ooOol000=oo`03
001oogoo0?moocAoo`00:goo00@007ooOol000=oo`03001oogoo0?moocAoo`00:Woo00D007ooOomo
o`0000=oo`03001oogoo0?moocAoo`00:Woo00D007ooOomoo`0000Aoo`03001oogoo0?mooc=oo`00
:Woo00D007ooOomoo`0000Aoo`03001oogoo0?mooc=oo`00;Woo00<007ooOol0ogoo>7oo000^Ool0
0`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo00<007ooOol0ogoo>7oo000^Ool0
0`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo00<007ooOol0ogoo>7oo000^Ool0
0`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo00<007ooOol0ogoo>7oo000^Ool0
0`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo00<007ooOol0ogoo>7oo000^Ool0
0`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo00<007ooOol0ogoo>7oo000^Ool0
0`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo00<007ooOol0ogoo>7oo000^Ool0
0`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo00<007ooOol0ogoo>7oo000^Ool0
0`00Oomoo`3oOolhOol002ioo`03001oogoo019oo`<000Qoo`03001oogoo00Moo`03001oogoo0?mo
o`ioo`00;Woo00<007ooOol04goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol0ogoo3Goo
000^Ool00`00Oomoo`0:Ool2000017oo000000000goo00<007ooOol01Goo00<007ooOol017oo0`00
17oo00<007ooOol0ogoo37oo000^Ool00`00Oomoo`0;Ool20003Ool01000Ool000001goo00<007oo
Ool00goo00D007ooOomoo`0000=oo`03001oogoo0?moo`aoo`00;Woo00<007ooOol02goo00<007oo
Ool00Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol01Goo00<007ooOol0ogoo37oo000^
Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool01000Oomoo`001goo00<007ooOol00goo00<007ooOol0
1Goo00<007ooOol0ogoo37oo000^Ool00`00Oomoo`0;Ool20003Ool00`00Oomoo`08Ool00`00Oomo
o`03Ool00`00Oomoo`05Ool00`00Oomoo`3oOol<Ool002ioo`03001oogoo00]oo`03001oo`000080
00]oo`03001oogoo009oo`D000Aoo`03001oogoo0?moo`aoo`00;Woo00<007ooOol02goo00<007oo
Ool03Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0ogoo3Goo000^Ool00`00Oomoo`0:
Ool2000AOol00`00Oomoo`07Ool00`00Oomoo`3oOol>Ool002ioo`03001oogoo0?moocQoo`00;Woo
00<007ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo
00<007ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo
00<007ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo
00<007ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo
00<007ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo
00<007ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo
00<007ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo
00<007ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00ogoo
JGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00001\
\>"],
  ImageRangeCache->{{{90.625, 377.625}, {431.25, 240.25}} -> {-2.11129, \
2.38729, 0.0164924, 0.0164924}}],

Cell["Figure 1. A compartmental model.", "Text",
  CellTags->"fig 2"],

Cell[TextData[{
  "The compartmental system is represented mathematically in terms of \
quantities such as the concentration or amount of a compound presents in the \
system. In the fig. 2 ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(x\_i\)(t)\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_j\)(t)\)]],
  "  represent the quantities in compartment ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " at time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " since the input",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(b\_i\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\((t)\)\)]],
  " started. These quantities are called the state variables of the system \
and their evolution in the time are usually differential equations. So the \
system of the figure 2 can be described as it follow:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x\_i' \((t)\) = \(-k\_i0\)\ \(\(x\_i\)(t)\) - 
          k\_ij\ \(\(x\_i\)(t)\) + k\_ji\ \(\(x\_j\)(t)\) + b\ \((t)\)\)], 
    "DisplayFormula"],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`x\_j' \((t)\) = 
        k\_ij\ \(\(x\_i\)(t)\) - k\_ji\ \(\(x\_j\)(t)\)\)], "DisplayFormula"]
}], "Text"],

Cell["or in matrix notation", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(x\_i' \((t)\)\)},
              {\(x\_j' \((t)\)\)}
              }], ")"}], " ", "=", 
        RowBox[{
          FormBox[
            RowBox[{"(", GridBox[{
                  {\(\(-k\_i0\)\(-\)\(k\_ij\)\(\ \)\), \(k\_ji\)},
                  {\(k\_ij\), \(-k\_ji\)}
                  }], ")"}],
            "TraditionalForm"], "+", 
          FormBox[
            RowBox[{"(", GridBox[{
                  {\(b(t)\)},
                  {"0"}
                  }], ")"}],
            "TraditionalForm"]}]}], 
      TraditionalForm]], "DisplayFormula"]], "Text"],

Cell["\<\
These models are System of Ordinary Differential Equation with Constant \
Coefficients (SODECC). \
\>", "Text"],

Cell[TextData[{
  "On many ocasions we are interested in models where the inputs ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(b\_i\),
            "TraditionalForm"], "(", "t", ")"}], TraditionalForm]]],
  " are acute in ",
  Cell[BoxData[
      \(TraditionalForm\`t\  = \ 0\)]],
  ", this is  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(b\_i\),
            "TraditionalForm"], "(", "0", ")"}], TraditionalForm]]],
  " = ",
  Cell[BoxData[
      FormBox[
        FormBox[\(b\_i\),
          "TraditionalForm"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(b\_i\),
            "TraditionalForm"], "(", "0", ")"}], TraditionalForm]]],
  " = 0 for ",
  Cell[BoxData[
      \(TraditionalForm\`t \[NotEqual] 0\)]],
  ".  Another frequent situations are the ones  where the inputs ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(b\_i\),
            "TraditionalForm"], "(", "t", ")"}], TraditionalForm]]],
  " are continuous, this is  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(b\_i\),
            "TraditionalForm"], "(", "t", ")"}], TraditionalForm]]],
  " = ",
  Cell[BoxData[
      FormBox[
        FormBox[\(b\_i\),
          "TraditionalForm"], TraditionalForm]]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`t\  \[GreaterEqual] 0\)]],
  " or  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(b\_i\),
            "TraditionalForm"], "(", "t", ")"}], TraditionalForm]]],
  " = ",
  Cell[BoxData[
      FormBox[
        FormBox[\(b\_i\),
          "TraditionalForm"], TraditionalForm]]],
  " for  ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] t\  < T\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Figure 2",
    ButtonData:>"fig 2"],
    ButtonBoxOptions -> {DefaultStyle -> "Hyperlink"}],
  " shows a more complex compartmental model"
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.12963 0.21164 0.349206 0.21164 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125  moveto 0 0 lineto 
-0.05 -0.0125  lineto stroke
} ifelse
grestore
} def
/MAarrowhead2 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.12963 .66667 m
.12963 .45503 L
s
% Start of user PostScript
0 1.5 0 0.5 MAarrowhead1
% End of user PostScript
gsave
.04497 .56085 -80.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
75.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.875 12.750 moveto
(H) show
85.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.875 12.750 moveto
(L) show
97.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.12963 .34921 .10582 0 365.73 arc
s
gsave
.12963 .34921 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.12963 .24339 m
.12963 .03175 L
s
% Start of user PostScript
0 -0.5 0 -1.5 MAarrowhead2
% End of user PostScript
gsave
.06614 .13757 -70.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23545 .39153 m
.76455 .39153 L
s
% Start of user PostScript
0.5 0.2 3. 0.2 MAarrowhead2
% End of user PostScript
gsave
.5 .43386 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.76455 .30688 m
.23545 .30688 L
s
% Start of user PostScript
3. -0.2 0.5 -0.2 MAarrowhead2
% End of user PostScript
gsave
.5 .26455 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.87037 .34921 .10582 0 365.73 arc
s
gsave
.87037 .34921 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.87037 .66667 m
.87037 .45503 L
s
% Start of user PostScript
3.5 1.5 3.5 0.5 MAarrowhead1
% End of user PostScript
gsave
.95503 .56085 -77.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.875 12.750 moveto
(H) show
79.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
85.875 12.750 moveto
(L) show
91.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.87037 .24339 m
.87037 .03175 L
s
% Start of user PostScript
3.5 -0.5 3.5 -1.5 MAarrowhead2
% End of user PostScript
gsave
.80688 .13757 -70.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 1.30159 m
.5 1.08995 L
s
% Start of user PostScript
1.75 4.5 1.75 3.5 MAarrowhead1
% End of user PostScript
gsave
.40476 1.19577 -80.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
75.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.875 12.750 moveto
(H) show
85.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.875 12.750 moveto
(L) show
97.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.5 .98413 .10582 0 365.73 arc
s
gsave
.5 .98413 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15079 .45503 m
.41534 .92063 L
s
% Start of user PostScript
0.1 0.5 1.35 2.7 MAarrowhead2
% End of user PostScript
gsave
.23545 .70899 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.47884 .87831 m
.21429 .42328 L
s
% Start of user PostScript
1.65 2.5 0.4 0.35 MAarrowhead2
% End of user PostScript
gsave
.39418 .62434 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(31) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.58466 .92063 m
.84921 .45503 L
s
% Start of user PostScript
2.15 2.7 3.4 0.5 MAarrowhead2
% End of user PostScript
gsave
.60582 .62434 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.78571 .42328 m
.52116 .87831 L
s
% Start of user PostScript
3.1 0.35 1.85 2.5 MAarrowhead2
% End of user PostScript
gsave
.76455 .70899 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(32) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .87831 m
.5 .66667 L
s
% Start of user PostScript
1.75 2.5 1.75 1.5 MAarrowhead2
% End of user PostScript
gsave
.46825 .73016 -70.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "GraphicsOnly",
  ImageSize->{251.688, 335.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005i0001ma000`40O003h00O0VLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@02Ic@00?mW=7YW=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@1JcD00?mW=7YW=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@00?mW=7YW
=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@1JcD00?mW=7YW=0000VLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@02Ic@00?mW=7YW=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@1JcD00?mW=7YW=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@02F/eIcAW=6LdJcEW=000IcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=@00IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e0FLd0FLd000`Ic@0
0`00IcAW=03oIc@EIc@00`00IcAW=00_Ic@00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=080009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@00f/eIc@000020003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=004JcEW=6LdIc@1
JcD002mW=0<00?mW=1EW=0<0031W=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0`0000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=004JcEW=6LdIc@300000fLdJcEW=002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@5W=05W
=000;fLd0`00ofLd5FLd0`00<6Ld00001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@4
00000fLdJcEW=002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD01@000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@016/eIcAW=6Ld0F/e000_Ic@4
003oIc@CIc@5000_Ic@0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00A[=FLdIcAW=0D000=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@5
00001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@002iW=0D00?mW=1=W=0D002mW=000
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01V/eIcAW=6LdJcEW=0H00005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@700000fLdJcEW=002Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=05[=@00;VLd1P00ofLd4FLd1`00;VLd0002Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=003JcEW=6Ld00L0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=006JcEW=6LdIcA[=FLd1`000fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@1JcD1Ic@1Ic@002eW
=0L00?mW=15W=0L002iW=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD020000fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00=[=FLdIc@02@0000E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@016/eIcAW=6Ld0F/e000]Ic@8003oIc@?Ic@9000]Ic@0009W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00=[=FLdIc@0200000=W=6/eIc@00VLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00=[=@0000001`000VLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@1JcD1Ic@1Ic@002aW=0T00?mW=0mW=0T002eW=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@016/eIcAW
=6Ld2P000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00=[
=FLd00002P000fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@1JcD002aW=0X00?mW=0eW=0/002aW=0000VLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@02F/eIcAW=6LdJcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00IcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e0FLd0FLd000`Ic@00`00IcAW=03oIc@EIc@00`00IcAW
=00_Ic@00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005001W=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0VLd00<006/eIc@00VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@016/eIcAW=6Ld0F/e000`Ic@00`00IcAW
=03oIc@EIc@00`00IcAW=00_Ic@0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00U[=FLdIcAW=6/eIc@0
06LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcD006LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@5W=05W=000
<6Ld00<006LdIc@0ofLd5FLd00<006LdIc@0;fLd00001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=003001[=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00A[=FLdIcAW=05[=@00<6Ld00<006LdIc@0ofLd5FLd00<006LdIc@0;fLd0002Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=009JcEW=6LdIcA[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@1JcD1Ic@1Ic@0031W=003001W=6Ld0?mW=1EW=003001W=6Ld02mW=00000E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00D006LdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@00`00JcEW
=002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=004JcEW=6LdIc@1JcD0031W=003001W=6Ld0?mW=1EW=003
001W=6Ld02mW=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@02F/eIcAW=6LdJcEW=000IcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=@00IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e0FLd0FLd000`Ic@00`00IcAW
=03oIc@EIc@00`00IcAW=00_Ic@00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
001W=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00VLd00<006/eIc@00VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@016/eIcAW=6Ld
0F/e000`Ic@00`00IcAW=03oIc@EIc@00`00IcAW=00_Ic@0009W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00U[=FLdIcAW=6/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcD006LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=05[=@5W=05W=000<6Ld00<006LdIc@0ofLd5FLd00<006LdIc@0;fLd00001F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=003001[=FLd009W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00A[=FLdIcAW=05[=@00<6Ld00<006LdIc@0ofLd5FLd00<006LdIc@0;fLd
0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=009JcEW=6LdIcA[=FLd001W=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@1JcD1Ic@1Ic@0031W=003001W=6Ld0?mW=1EW=003
001W=6Ld02mW=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00D006LdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@02Ic@00`00JcEW=002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=004JcEW=6LdIc@1JcD0031W=003
001W=6Ld0?mW=1EW=003001W=6Ld02mW=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@02F/eIcAW=6Ld
JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=@00IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e0FLd
0FLd000GIc@50003Ic@3000>Ic@00`00IcAW=03kIc@50003Ic@3000>Ic@00`00IcAW=00_Ic@00005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=00=JcD006LdIcA[=FLd
001W=6/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005001W=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@02F/eIcAW=6Ld
JcEW=000IcA[=@03Ic@01V/e001W=6LdJcD0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=000JcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@016/eIcAW=6Ld0F/e000>Ic@20002Ic@30004Ic@00`00IcAW
=002Ic@01@00IcAW=6Ld00003FLd00<006LdIc@0lVLd0P000VLd0`000fLd00<006LdIc@00fLd00D0
06LdIcAW=00000eW=003001W=6Ld02mW=0000VLd00E[=FLdIcAW=6/e00=W=006JcEW=6LdIcA[=@00
0VLd00D006LdIcAW=6/e009W=003001[=FLd009W=005001W=6LdIc@00003Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005001W=6Ld001[=@03Ic@01F/eIc@006LdJcD00VLd00H006/eIcAW
=000JcD3Ic@01F/eIcAW=6LdJcD00fLd00E[=@00IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
0F/e0FLd0FLd000?Ic@00`00Ic@00007Ic@00`00IcAW=002Ic@01@00IcAW=6Ld00003FLd00<006Ld
Ic@0lfLd00<006Ld000026Ld00D006LdIcAW=00000=W=003001W=6Ld00]W=003001W=6Ld02mW=000
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@30002Ic@01V/eIcAW=6LdJcD0009W=009JcEW
=000IcA[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01V/eIcAW=6LdJcEW=0<000=W=00:JcEW
=000IcA[=FLd001W=6/e0002Ic@01F/e001W=6LdJcD00fLd00E[=FLdIcAW=6/e009W=003001[=FLd
009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00A[=FLdIcAW=05[=@003fLd00@006LdIc@000EW=08000EW
=0<000iW=003001W=6Ld0?=W=004001W=6Ld0005Ic@30004Ic@3000>Ic@00`00IcAW=00_Ic@0009W
=005JcEW=6LdIcA[=@03Ic@01f/eIcAW=6LdJcD006Ld00<0009W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@00`00Ic@000020003Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@1JcD1Ic@1Ic@000mW=003001W=6Ld01iW=003001W=6Ld0?=W
=003001W=6Ld01iW=003001W=6Ld02mW=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@0
0`00JcEW=002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6Ld00000fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld001[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=004JcEW
=6LdIc@1JcD000iW=080021W=003001W=6Ld0?9W=080021W=003001W=6Ld02mW=0000VLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@02F/eIcAW=6LdJcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00IcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd0F/e0FLd0FLd000`Ic@00`00IcAW=03oIc@EIc@00`00IcAW=00_Ic@0
0005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005001W=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd00<0
06/eIc@00VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@016/eIcAW=6Ld0F/e000`Ic@00`00IcAW=03oIc@E
Ic@00`00IcAW=00_Ic@0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00U[=FLdIcAW=6/eIc@006LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcD006LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@5W=05W=000<6Ld00<0
06LdIc@0ofLd5FLd00<006LdIc@0;fLd00001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e009W=003001[=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00A[=FLd
IcAW=05[=@00<6Ld00<006LdIc@0ofLd5FLd00<006LdIc@0;fLd0002Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=009JcEW=6LdIcA[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@1JcD1Ic@1Ic@0031W=003001W=6Ld0?mW=1EW=003001W=6Ld02mW=00000E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00D006LdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@00`00JcEW=002Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=004JcEW=6LdIc@1JcD0031W=003001W=6Ld0?mW=1EW=003001W=6Ld
02mW=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@02F/eIcAW=6LdJcEW=000IcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=@00IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e0FLd0FLd000`Ic@00`00IcAW=03oIc@E
Ic@00`00IcAW=00_Ic@00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005001W=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00VLd00<006/eIc@00VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@016/eIcAW=6Ld0F/e000`
Ic@00`00IcAW=03oIc@EIc@00`00IcAW=00_Ic@0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00U[=FLd
IcAW=6/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcD006LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[
=@5W=05W=000<6Ld00<006LdIc@0ofLd5FLd00<006LdIc@0;fLd00001F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=003001[=FLd009W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00A[=FLdIcAW=05[=@00<6Ld00<006LdIc@0ofLd5FLd00<006LdIc@0;fLd0002Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=009JcEW=6LdIcA[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@1JcD1Ic@1Ic@0031W=003001W=6Ld0?mW=1EW=003001W=6Ld
02mW=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00D006LdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02
Ic@00`00JcEW=002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=004JcEW=6LdIc@1JcD0031W=003001W=6Ld
0?mW=1EW=003001W=6Ld02mW=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@<00001F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@00f/eIcAW=00<00000fLdJcEW=002Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e009W=0009FLd1@0036Ld1000ofLd0fLd1@0036Ld1000:6Ld00001F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00=[
=FLdIc@00P000fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@00f/eIc@000030002Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLd000006/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00=[=@0000000P000fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=05[=@008FLd0P006fLd0P00NVLd1@000VLd1@00LVLd0P006fLd
0P008VLd0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
0f/eIcAW=00400000fLdJcEW=002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@00f/eIc@000020003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIc@00003Ic@01V/eIcAW=6LdJcD0009W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01V/eIcAW=6LdJcEW=0@0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@0300001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd000LIc@00`00IcAW=00TIc@2001/
Ic@20002Ic@30003Ic@00`00IcAW=005Ic@00`00IcAW=01]Ic@00`00IcAW=00TIc@2000MIc@00005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld001[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00800003IcA[=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=00:JcEW=6LdIcA[=FLd
001W=6/e0002Ic@01F/eIcAW=6Ld00000fLd00E[=FLdIc@006/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=004JcEW=6LdIc@20002Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@1JcD001YW=003001W=6Ld02YW=003001W
=6Ld06QW=003001W=00000QW=003001W=6Ld00=W=003001W=6Ld06]W=003001W=6Ld02YW=003001W
=6Ld01QW=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01V/eIcAW=6LdJcEW=080
0005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00U[=FLdIcAW=6/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00A[
=FLdIcAW=0<00003IcA[=FLd009W=005001W=6LdIc@00003Ic@01F/e001W=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00800003IcA[=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00D006Ld
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e0FLd0FLd000GIc@00`00
IcAW=00_Ic@00`00IcAW=01VIc@01000IcAW=0001FLd0`0016Ld0P00JVLd00<006LdIc@0;VLd0P00
66Ld00001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=009JcEW=6LdIcA[=FLd001W=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00I[=FLdIcAW=6/eIc@200001F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@026/eIcAW=6Ld
JcEW=000Ic@300000fLdJcEW=002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcD006LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@020000
0fLdJcEW=002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@005FLd00<006LdIc@0
=6Ld00<006LdIc@0HfLd00<006LdIc@0MfLd00<006LdIc@0=6Ld00<006LdIc@04fLd0002Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=000JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00D006LdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00IcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=0004fLd00<006LdIc@0>6Ld00<006LdIc@0H6Ld0P00
MfLd00<006LdIc@0>6Ld00<006LdIc@04FLd00001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00VLd00<006/eIc@00VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01V/eIcAW=6LdJcD0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=004
JcEW=6LdIc@1JcD0019W=003001W=6Ld03]W=003001W=6Ld0=EW=003001W=6Ld03aW=003001W=6Ld
00mW=0000VLd00E[=FLdIcAW=6/e00=W=006JcEW=6LdIcA[=FLd0P0000E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=009JcEW=6LdIcA[=FLd001W=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/e001W=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@5W=05W=0003fLd00<006LdIc@0?fLd
00<006LdIc@0dVLd00<006LdIc@0?fLd00<006LdIc@03VLd00001F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e009W=003001[=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@02F/eIcAW=6LdJcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00U[=FLdIcAW=6/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=006JcEW=6LdIcA[=@000VLd00E[=FLdIcAW
=6/e00=W=004JcEW=6LdIc@1JcD000iW=003001W=6Ld045W=003001W=6Ld01EW=0800;UW=003001W
=6Ld045W=003001W=6Ld00eW=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIc@00003Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcD006LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00A[=FLdIcAW=0H0009W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd
00<006/eIc@00VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=0003FLd00<0
06LdIc@0@fLd00<006LdIc@036Ld2P00^6Ld00<006LdIc@0@fLd00<006LdIc@036Ld00001F/eIcAW
=6LdJcD00fLd00I[=FLdIcAW=6/e0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIc@00003Ic@01V/eIcAW=6Ld
JcEW=0h00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00D006LdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd00<006/eIc@00VLd00E[=FLdIcAW
=6/e00=W=05[=@0036Ld00<006LdIc@0AFLd00<006LdIc@00fLd4P00]fLd00<006LdIc@0AFLd00<0
06LdIc@02fLd0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00I[=FLd
Ic@006/eIcC80002Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLd
IcAW=6/e009W=00036Ld00<006LdIc@0AfLd00@006LdIcAW=1800;IW=003001W=6Ld04QW=003001W
=6Ld00UW=00000E[=FLdIcAW=6/e00=W=005JcEW=6Ld001[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=009JcEW=6LdIcA[
=FLd001W=6/e00=W=003JcEW=00000d00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@02F/eIcAW=6LdJcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=006JcEW=6LdIcA[
=@000VLd00E[=FLdIcAW=6/e00=W=05[=@002fLd00<006LdIc@0B6Ld00<006LdIc@02FLd2P00]VLd
00<006LdIc@0B6Ld00<006LdIc@02FLd0002Ic@01F/eIcAW=6LdJcD00fLd00D006LdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=00000=W=005JcEW=6LdIcA[=@03Ic@016/eIcAW=6Ld1P000VLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld001[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@00`00JcEW=002Ic@01F/eIcAW=6LdJcD00VLd000:
Ic@00`00IcAW=01:Ic@00`00IcAW=00@Ic@2002eIc@00`00IcAW=01:Ic@00`00IcAW=008Ic@00005
JcEW=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd00<006/e
Ic@00VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00I[=FLdIcAW=6/e0002Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00A[=FLdIcAW=05[=@002VLd00<006LdIc@0BVLd00<0
06LdIc@0afLd00<006LdIc@0BVLd00<006LdIc@026Ld0002Ic@01F/eIcAW=6LdJcD00VLd00<006/e
Ic@00VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00IcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01@00IcAW=6Ld
JcD00fLd0F/e0FLd0FLd0009Ic@00`00IcAW=01<Ic@00`00IcAW=035Ic@00`00IcAW=01<Ic@00`00
IcAW=007Ic@00005JcEW=6LdIcA[=@03Ic@01F/e001W=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00D006LdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005001W=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@00`00JcEW=002Ic@016/eIcAW=6Ld0F/e0009Ic@00`00
IcAW=01<Ic@00`00IcAW=035Ic@00`00IcAW=01<Ic@00`00IcAW=007Ic@0009W=005JcEW=6LdIcA[
=@02Ic@00`00JcEW=002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcD006LdIcA[=@03Ic@1JcD1Ic@1Ic@000UW=003001W=6Ld025W=0L002AW=003001W=6Ld0<EW
=003001W=6Ld025W=0H002EW=003001W=6Ld00MW=00000E[=FLdIcAW=6/e00=W=005JcD006LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00D006LdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00VLd00<006/eIc@00VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=006001W=6LdIcA[=@000VLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld001[=@03
Ic@016/eIcAW=6Ld0F/e0009Ic@00`00IcAW=00TIc@00`00IcAW=00UIc@00`00IcAW=034Ic@00`00
IcAW=00SIc@00`00IcAW=00WIc@00`00IcAW=007Ic@0009W=009JcEW=6LdIcA[=FLd001W=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/e001W=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005001W=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00IcAW=6/e00=W
=05[=@5W=05W=00026Ld00<006LdIc@09FLd00<006LdIc@09FLd00<006LdIc@0a6Ld00<006LdIc@0
9FLd00<006LdIc@09FLd00<006LdIc@01fLd00001F/eIcAW=6LdJcD00fLd00E[=@00IcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005001W=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@02Ic@00`00JcEW=002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=00000=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=000JcD00fLd00A[
=FLdIcAW=05[=@002FLd00<006LdIc@096Ld00<006LdIc@09FLd00<006LdIc@0a6Ld00<006LdIc@0
8VLd00<006LdIc@00VLd00<006LdIc@08fLd00<006LdIc@01fLd0002Ic@01F/eIcAW=6LdJcD00VLd
00<006/eIc@00VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=0<00003IcA[=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=009JcEW=6LdIcA[=FLd001W=6/e009W=003001[=FLd009W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/e001W=6LdJcD00fLd0F/e0FLd0FLd0009Ic@00`00IcAW=00TIc@00`00IcAW=00UIc@00`00IcAW
=035Ic@00`00IcAW=00RIc@4000VIc@00`00IcAW=007Ic@00005JcEW=6LdIcA[=@03Ic@01F/e001W
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00D006LdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005001W=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@00`00JcEW
=002Ic@016/eIcAW=6Ld0F/e0009Ic@00`00IcAW=01;Ic@00`00IcAW=036Ic@00`00IcAW=01;Ic@0
0`00IcAW=008Ic@0009W=005JcEW=6LdIcA[=@02Ic@00`00JcEW=002Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/e001W=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd001W=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005001W=6LdIcA[=@03Ic@1JcD1Ic@1Ic@000UW=003
001W=6Ld04]W=003001W=6Ld0<IW=003001W=6Ld04]W=003001W=6Ld00QW=00000E[=FLdIcAW=6/e
00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@00`00JcEW=002Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01V/eIcAW=6LdJcD0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=000IcA[=@03Ic@016/eIcAW=6Ld0F/e000:Ic@00`00IcAW=019Ic@00`00IcAW=02cIc@2
000CIc@00`00IcAW=019Ic@00`00IcAW=009Ic@0009W=005JcEW=6LdIcA[=@03Ic@01@00IcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld00000fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=003JcEW=00000D00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00VLd00<006/eIc@00VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd00<006/eIc@00VLd00E[=FLd
IcAW=6/e009W=0002fLd00<006LdIc@0B6Ld00<006LdIc@0/fLd2P0036Ld00<006LdIc@0B6Ld00<0
06LdIc@02FLd00001F/eIcAW=6LdJcD00fLd00E[=FLdIc@006/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00I[=FLdIcAW
=6/e0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00A[=FLdIcAW=0h0009W=009JcEW=6LdIcA[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=000
00=W=005JcEW=6LdIcA[=@03Ic@1JcD000aW=003001W=6Ld04IW=003001W=6Ld0;AW=18000AW=003
001W=6Ld04MW=003001W=6Ld00YW=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=006JcEW=000IcA[=FLdb0000VLd00D006LdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00IcAW
=6/e00=W=005JcEW=6LdIcA[=@02Ic@000aW=003001W=6Ld04EW=003001W=6Ld0;EW=18000EW=003
001W=6Ld04EW=003001W=6Ld00]W=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIc@00003Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6Ld001[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00A[=FLdIcAW=0h0009W=005JcEW=6LdIcA[=@02Ic@00`00JcEW=002Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e000=Ic@00`00IcAW=013Ic@00`00
IcAW=02fIc@:000>Ic@00`00IcAW=013Ic@00`00IcAW=00<Ic@0009W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=000JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=003JcEW=00000D00005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd00<006/eIc@00VLd00E[=FLdIcAW
=6/e00=W=05[=@5W=05W=0003VLd00<006LdIc@0@FLd00<006LdIc@0]fLd0P005fLd00<006LdIc@0
@FLd00<006LdIc@03FLd00001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=003001[=FLd009W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01V/eIcAW
=6LdJcD0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld00000fLd00E[=FLdIcAW=6/e00=W=004JcEW=6LdIc@1JcD0
011W=003001W=6Ld03eW=003001W=6Ld0==W=003001W=6Ld03iW=003001W=6Ld00mW=0000VLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@00`00JcEW=002Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd001W=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00001W=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@5W=05W=0004VLd00<006LdIc@0>VLd00<006LdIc@0
efLd00<006LdIc@0>VLd00<006LdIc@046Ld00001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@02F/eIcAW
=6LdJcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=006JcEW=6LdIcA[=@000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcD006LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00A[=FLd
IcAW=05[=@004fLd00<006LdIc@0=fLd00<006LdIc@0JVLd1@000VLd1@00I6Ld00<006LdIc@0=fLd
00<006LdIc@04VLd0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@02F/eIc@006LdJcEW=000IcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@02F/eIcAW=6LdJcEW=000IcA[=@02Ic@00`00JcEW=002Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01V/e001W=6LdJcD0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=006
JcEW=6LdIcA[=@000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@1JcD1Ic@1Ic@001EW
=003001W=6Ld03=W=003001W=6Ld009W=08005mW=080009W=0<000AW=003001W=6Ld00=W=003001W
=6Ld065W=003001W=6Ld00=W=003001W=6Ld03=W=003001W=6Ld01AW=00000E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@02F/eIcAW=6LdJcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=009JcEW=6LdIcA[=FLd001W=6/e00=W=005JcD00000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=006JcEW=000IcA[=@000VLd00E[=FLd
IcAW=00000=W=005JcEW=6Ld001[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=009JcEW=6LdIcA[=FLd001W=6/e00=W=005JcD006LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=006JcEW=6LdIcA[=@000VLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@016/eIcAW=6Ld0F/e000GIc@2000`Ic@00`00IcAW=005Ic@3001NIc@00`00Ic@0
0007Ic@00`00IcAW=005Ic@00`00IcAW=01NIc@00`00IcAW=006Ic@2000`Ic@00`00IcAW=00FIc@0
009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=08000=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd001W=6/e00=W=003JcEW=6Ld00@00003IcA[=FLd009W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0`0000=W
=6/eIc@00VLd00E[=FLd001W=6/e009W=006001[=FLdIc@006/e0fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=000JcD00fLd00I[=FLd
IcAW=6/eIc@200001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=004JcEW=6LdIc@20002Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@001]W=003001W=6Ld02QW=08000YW=0@0
05aW=004001W=6Ld0005Ic@20005Ic@3001OIc@00`00IcAW=00;Ic@00`00IcAW=00XIc@00`00IcAW
=00IIc@00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=004JcEW
=6LdIc@20002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00A[=FLdIcAW=080009W=005JcEW=6LdIcA[=@03Ic@00f/eIc@000040000
0fLdJcEW=002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00Q[=FLdIcAW
=6/eIc@006Ld0`0000=W=6/eIc@00VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005001W=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00VLd0P000fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=003JcEW=6Ld008000=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@007VLd0P008VLd0P003VLd1P00
FVLd00<006LdIc@0KVLd00<006LdIc@03fLd0P008VLd0P007VLd0002Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01V/eIcAW=6LdJcEW=0800005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@00`00JcEW
=002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00H00003IcA[=FLd009W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld00000fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIc@00003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcD00000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd0F/e0FLd0FLd000RIc@2000KIc@2000BIc@7001GIc@2001_Ic@00`00IcAW=00DIc@2
000KIc@2000QIc@00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@016/eIcAW=6Ld0`0000=W=6/eIc@00VLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@02Ic@400000fLdJcEW=002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W
=0P00003IcA[=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcD006LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=003JcEW=6Ld00<0009W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00=[=FLd00000`000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@009fLd1P0026Ld1P006FLd2000aFLd
00<006LdIc@06VLd1P0026Ld1P009fLd0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=003JcEW=6Ld00P0
0006IcA[=FLd001W=6/e0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01V/eIcAW=6Ld
JcEW=0T00003IcA[=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00U[=FLdIcAW=6/eIc@006LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00I[=@00IcAW=6/eIc@80002Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=05[=@5W=05W=000<6Ld00<006LdIc@01VLd00<006LdIc@066Ld2P00
`FLd00<006LdIc@076Ld0P001fLd00<006LdIc@0;fLd00001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@20002Ic@01V/eIcAW=6LdJcD0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=003JcD0000000P00003IcA[=FLd009W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
Ic@006/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcD00000IcA[=@03Ic@00f/eIc@000020003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=004JcEW=6LdIc@1
JcD002mW=0<000QW=003001W=6Ld01QW=0P00<5W=003001W=6Ld01]W=0<000MW=0<0031W=0000VLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00`0000E[=FLdIcAW=6/e00=W=005001W=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=003JcEW=6Ld00H000=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005001W=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@040003Ic@016/eIcAW=6Ld0`0000=W=6/eIc@00VLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@1JcD1Ic@1Ic@002mW=0<000UW=003001W=6Ld01QW=0<00003Ic@006Ld0<5W=003
001W=6Ld01YW=0D000MW=0<0031W=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd
0P0000AW=000IcA[=@=W=005JcEW=6Ld001[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=009JcEW=6LdIcA[=FLd001W=6/e009W=003001[=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00I[=FLdIcAW=6/e
0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@00f/e0000
00030002Ic@02V/eIcAW=6LdJcD006Ld001[=@000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@016/eIcAW
=6Ld0F/e000_Ic@200000fLd001W=008Ic@00`00IcAW=00LIc@00`00IcAW=02nIc@00`00IcAW=00I
Ic@60007Ic@01@00Ic@006Ld0000;fLd0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=009JcEW=6LdIc@0
06Ld001W=00000=W=005JcEW=6LdIcA[=@02Ic@00`00JcEW=002Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01V/eIcAW=6LdJcEW=0H00005
JcEW=6LdIcA[=@02Ic@01P00JcD006Ld001[=@=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e0FLd0FLd
000^Ic@01@00Ic@006Ld00002VLd00<006LdIc@076Ld00<006LdIc@0_6Ld00<006LdIc@06FLd1`00
1fLd00D006Ld001W=00002mW=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@02F/eIcAW=6LdJcEW=000Ic@0
0002Ic@00`00JcEW=002Ic@02F/eIcAW=6LdJcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=009JcEW=6LdIcA[=FLd001W=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00I[=FLdIcAW=6/eIc@70003Ic@01F/eIcAW
=6Ld00000VLd00H006/eIc@006LdJcD3Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@00;VLd00<006Ld
00000VLd00<006LdIc@026Ld00<006LdIc@076Ld00<006LdIc@0^VLd00<006LdIc@066Ld20001fLd
00@006LdIc@0009W=003001W=6Ld02aW=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@02V/eIcAW=000
JcEW=000IcA[=@000VLd00E[=FLdIcAW=6/e00=W=005JcD006LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld001[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=006JcEW=6LdIcA[=FLd2@0000=W=6/eIc@00VLd
00I[=FLd001W=6/e0002Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@002eW=004
001W=6Ld0002Ic@00`00IcAW=009Ic@00`00IcAW=00MIc@00`00IcAW=02gIc@00`00IcAW=00GIc@9
0008Ic@01000IcAW=0000VLd00<006LdIc@0;6Ld00001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=006JcEW=6Ld
IcA[=@000VLd00D006LdIcAW=00000=W=005JcEW=6LdIcA[=@03Ic@01@00IcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd00<006/eIc@00VLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIc@0
0003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=006JcEW=6LdIcA[=FLd2P0000E[=FLd
IcAW=6/e009W=006001[=FLdIc@006/e0VLd00<006/eIc@00VLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@1
JcD002eW=004001W=6Ld0003Ic@00`00IcAW=00:Ic@00`00IcAW=00LIc@00`00IcAW=02dIc@00`00
IcAW=00IIc@90007Ic@01@00IcAW=6Ld00000fLd00<006LdIc@0:fLd0002Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=00=JcEW=6Ld001[=FLd001W=6/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e009W=003001[
=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=@00IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e009W=0L0009W=006JcEW=6LdIcA[=@000VLd00I[=@00IcAW=6/e0002Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=05[=@5W=05W=000;6Ld00D006LdIcAW=00000=W=003001W=6Ld00]W=003001W=6Ld01aW
=003001W=6Ld0;9W=003001W=6Ld01aW=003001W=00000<000QW=005001W=6LdIc@00003Ic@00`00
IcAW=00[Ic@00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=00000=W=006001W=6LdIcA[=@00
0VLd00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00U[=FLdIcAW=6/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00IcAW=6/e00800003IcA[=FLd009W=005JcEW
=000IcA[=@02Ic@00`00JcEW=002Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=004JcEW=6LdIc@1JcD002aW
=005001W=6LdIc@00004Ic@00`00IcAW=00;Ic@00`00IcAW=00LIc@00`00IcAW=02`Ic@00`00IcAW
=00LIc@00`00IcAW=00;Ic@00`00IcAW=002Ic@00`00IcAW=002Ic@00`00IcAW=00ZIc@0009W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00U[=FLdIcAW=6/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=006
JcEW=6LdIcA[=@000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00I[=FLdIcAW=6/e0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@02F/e
IcAW=6LdJcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=006JcEW=6LdIcA[=@000VLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd000`Ic@00`00IcAW=00AIc@00`00IcAW=00L
Ic@00`00IcAW=02^Ic@00`00IcAW=00LIc@00`00IcAW=00AIc@00`00IcAW=00_Ic@00005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005001W=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00I[=FLdIcAW=6/e0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6Ld00000fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIc@006/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6Ld001[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=003001[=FLd009W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00A[=FLdIcAW=05[=@00<6Ld00<006LdIc@04VLd00<006LdIc@0
76Ld00<006LdIc@0[6Ld00<006LdIc@076Ld00<006LdIc@04VLd00<006LdIc@0;fLd0002Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=009JcEW=6LdIcA[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00D006LdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e009W=003001[=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005001W=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@02Ic@00`00JcEW=002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcD006Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@5W=05W=000<6Ld00<006LdIc@04fLd00<006Ld
Ic@07FLd00<006LdIc@0ZFLd00<006LdIc@076Ld00<006LdIc@04fLd00<006LdIc@0;fLd00001F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@02Ic@00`00JcEW=002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01V/e
IcAW=6LdJcD0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIc@00003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld001[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=004JcEW=6LdIc@1JcD0031W=003001W=6Ld01AW=003001W
=6Ld01eW=003001W=6Ld0:IW=003001W=6Ld01eW=003001W=6Ld01AW=003001W=6Ld02mW=0000VLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@02F/eIcAW=6LdJcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
Ic@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=@00IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00IcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e0FLd0FLd000`Ic@00`00IcAW=00FIc@00`00IcAW=00L
Ic@00`00IcAW=02TIc@00`00IcAW=00MIc@00`00IcAW=00EIc@00`00IcAW=00_Ic@00005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005001W=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcD006LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@00`00
JcEW=002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
Ic@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=000JcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@016/eIcAW=6Ld0F/e000`Ic@00`00IcAW=00GIc@00`00IcAW=00L
Ic@00`00IcAW=02RIc@00`00IcAW=00LIc@00`00IcAW=00GIc@00`00IcAW=00_Ic@0009W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00U[=FLdIcAW=6/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6Ld00000fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=00000=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00D006LdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=003001[
=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00I[=FLdIcAW=6/e0002Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@0031W=003001W=6Ld01QW=003001W=6Ld01aW
=003001W=6Ld0:1W=003001W=6Ld01aW=003001W=6Ld01QW=003001W=6Ld02mW=00000E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00D006LdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIc@006/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld001[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=00000=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIc@00003Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@00`00JcEW=002Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=004JcEW=6LdIc@1JcD0031W=003001W=6Ld01UW=003001W=6Ld01aW
=003001W=6Ld09iW=003001W=6Ld01aW=003001W=6Ld01UW=003001W=6Ld02mW=0000VLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@02F/eIcAW=6LdJcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@00`00JcEW=002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcD006LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01V/eIcAW=6LdJcD0009W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=000<6Ld00<006LdIc@06VLd00<006LdIc@07FLd
00<006LdIc@0VfLd00<006LdIc@076Ld00<006LdIc@06VLd00<006LdIc@0;fLd00001F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@02F/eIcAW=6LdJcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00U[=FLdIcAW=6/eIc@006LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd001W=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=003001[=FLd009W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00A[=FLdIcAW=05[=@00<6Ld00<006LdIc@06fLd00<006LdIc@07FLd
00<006LdIc@0V6Ld00<006LdIc@07FLd00<006LdIc@06fLd00<006LdIc@0;fLd0002Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=009JcEW=6LdIcA[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcD006LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIc@006/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@1JcD1Ic@1Ic@0031W=003001W=6Ld01aW=003001W=6Ld01eW=003001W
=6Ld09IW=003001W=6Ld01eW=003001W=6Ld01aW=003001W=6Ld02mW=00000E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00D006LdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005001W=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00D006LdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=003001[=FLd009W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld001[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=004JcEW=6LdIc@1JcD001IW=003001W=6Ld00]W=003001W=6Ld00UW=003001W
=6Ld01iW=003001W=6Ld01aW=003001W=6Ld09AW=003001W=6Ld01eW=003001W=6Ld01eW=003001W
=6Ld01iW=003001W=6Ld00]W=040005W=05W=0000VLd00E[=FLdIcAW=6/e009W=0D00005JcEW=6Ld
IcA[=@02Ic@00`00JcEW=002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIc@006/e00=W=009JcEW=6Ld
IcA[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6Ld001[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=000JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=@00IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005001W=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@050002Ic@01V/eIcAW=6LdJcD0009W=005JcEW=6LdIcA[=@03Ic@01V/eIcAW=6LdJcD0005W
=0002fLd00<006LdIc@01fLd00<006LdIc@03FLd00<006LdIc@026Ld00<006LdIc@07fLd00<006Ld
Ic@076Ld00<006LdIc@0TVLd00<006LdIc@07FLd00<006LdIc@07VLd00<006LdIc@04FLd00<006Ld
Ic@02FLd00<006LdIc@03FLd0@000FLd0002000016Ld000000000VLd00E[=FLdIc@006/e00=W=005
JcEW=6LdIc@00003Ic@01F/eIcAW=6LdJcD010000fLd00E[=FLd001W=6/e00=W=005JcEW=6LdIc@0
0003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@02F/eIcAW
=6LdJcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01V/eIcAW
=6LdJcD0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=006
JcEW=6LdIcA[=@000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e009W=003001[=FLd009W=006JcEW=6LdIcA[=FLd0P0000E[=@00000006/e
00=W=005001W=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00=[=FLdIc@0100000=W=6/eIc@00VLd
0@0000000fLd00000003Ic@00`00IcAW=002Ic@00`00IcAW=006Ic@00`00IcAW=005Ic@00`00IcAW
=002Ic@00`00IcAW=002Ic@00`00IcAW=007Ic@00`00IcAW=00PIc@00`00IcAW=00MIc@00`00IcAW
=02?Ic@00`00IcAW=00LIc@00`00IcAW=00PIc@00`00IcAW=009Ic@20003Ic@00`00IcAW=002Ic@0
0`00IcAW=006Ic@00`00IcAW=005Ic@00`00IcAW=002Ic@00`00IcAW=002Ic@100000003Ic@006/e
00=W=006001W=6LdIcA[=@000VLd00U[=FLdIcAW=6/eIc@006LdJcD00fLd00E[=FLd001W=6/e00=W
=005JcEW=6LdIc@00003Ic@02F/eIcAW=6LdJcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01V/eIcAW=6LdJcD0009W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=006JcEW=6LdIcA[=@000VLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@02F/eIcAW=6LdJcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00I[=FLdIcAW=6/e0002Ic@01F/e
IcAW=6LdJcD00fLd00U[=@00IcAW=6/eIc@006LdJcD00fLd00D006LdIcAW=6/e00=W=005001W=6Ld
IcA[=@03Ic@01@00IcAW=6LdJcD00fLd0F/e0FLd0@0000000fLd001W=003Ic@00`00IcAW=002Ic@0
0`00IcAW=006Ic@00`00IcAW=005Ic@00`00IcAW=007Ic@00`00IcAW=007Ic@00`00IcAW=00QIc@0
0`00IcAW=00MIc@00`00IcAW=02=Ic@00`00IcAW=00LIc@00`00IcAW=00QIc@00`00IcAW=009Ic@0
0`00IcAW=002Ic@01000IcAW=0000fLd00<006LdIc@016Ld00<006LdIc@01FLd00<006LdIc@01fLd
0@0000002V/e000006LdJcEW=000IcA[=FLd0P0000E[=FLdIcAW=6/e00=W=005001W=6LdIcA[=@03
Ic@01@00IcAW=6LdJcD00fLd00E[=FLd001W=6/e00=W=005JcEW=6LdIc@00003Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
001W=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=003001[=FLd009W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld001[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00VLd00<006/eIc@00VLd00E[=FLdIcAW=6/e009W=08000=W=004001W=6LdIc@300000fLdJcEW
=002Ic@01F/eIc@006LdJcD00fLd00E[=FLd001W=6/e00=W=004JcEW=6LdIc@100000003Ic@006Ld
00<000iW=003001W=6Ld00=W=0L000EW=003001W=6Ld00MW=003001W=6Ld029W=003001W=6Ld01eW
=003001W=6Ld08]W=003001W=6Ld01aW=003001W=6Ld029W=003001W=6Ld00UW=003001W=0000080
00iW=003001W=6Ld00=W=0L000EW=040000000=W=000JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@02Ic@00`00JcEW=002Ic@01F/eIc@006LdJcD00fLd00E[=FLdIc@006/e00=W=009JcEW
=6LdIcA[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd00<006/eIc@00VLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00D006LdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=006JcEW=6LdIcA[=@000VLd00E[=FLdIcAW=6/e00=W=005JcD006Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00I[=FLdIcAW=6/e0002Ic@01F/eIcAW=6Ld00000fLd00I[
=FLdIcAW=6/e0001Ic@00003Ic@006Ld019W=003001W=6Ld00AW=003001W=6Ld00IW=003001W=6Ld
00QW=003001W=6Ld02=W=003001W=6Ld01eW=003001W=6Ld08QW=003001W=6Ld01eW=003001W=6Ld
02=W=003001W=6Ld00UW=003001W=6Ld015W=003001W=6Ld00AW=003001W=6Ld00IW=040005W=000
0P000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005001W=6LdIcA[=@03Ic@01F/eIcAW=6Ld00000fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld001[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=000
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=006JcEW=6LdIcA[=@000VLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=00000=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=000JcD0
0fLd00I[=FLdIcAW=6/eIc@200001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
Ic@00003Ic@01F/eIcAW=6LdJcD00fLd00A[=FLd001W=05[=@00<6Ld00<006LdIc@096Ld00<006Ld
Ic@07FLd00<006LdIc@0QVLd00<006LdIc@07FLd00<006LdIc@096Ld00<006LdIc@0;fLd0002Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=009JcEW=6LdIcA[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIc@006LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd001W
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@1JcD1Ic@1Ic@0031W=003001W=6Ld02IW=003001W=6Ld01aW
=003001W=6Ld08AW=003001W=6Ld01eW=003001W=6Ld02EW=003001W=6Ld02mW=00000E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00D006LdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00IcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00=[=FLdIc@00`000VLd00=[=@00
00000`000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@00f/eIc@0000400000fLdJcEW=0030003Ic@01F/eIcAW=6LdJcD00fLd
00U[=FLdIcAW=6/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=000JcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@016/eIcAW=6Ld0F/e000`Ic@00`00IcAW=00WIc@00`00IcAW=00MIc@00`00IcAW=00E
Ic@01@00IcAW=6Ld000016Ld00<006LdIc@0A6Ld00<006LdIc@016Ld00D006LdIcAW=000011W=003
001W=6Ld01eW=003001W=6Ld02IW=003001W=6Ld02mW=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
2F/eIcAW=6LdJcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=00000=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIc@00003Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01P00IcAW=6LdJcD0009W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00I[=FLdIcAW=6/e0002Ic@01F/eIcAW=6LdJcD00VLd00<006/eIc@00VLd00E[=FLdIcAW=6/e00=W
=005JcEW=6Ld001[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=000JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=006JcEW=6LdIcA[=@000VLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00VLd000`Ic@00`00IcAW=00XIc@00`00IcAW=00MIc@00`00IcAW=00;Ic@2
0002Ic@30004Ic@20005Ic@00`00IcAW=00kIc@20002Ic@30004Ic@00`00IcAW=004Ic@2000@Ic@0
0`00IcAW=00LIc@00`00IcAW=00XIc@00`00IcAW=00_Ic@00005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005001W=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIc@006/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld001[=@03Ic@01F/eIcAW
=6LdJcD00fLd00I[=FLd001W=6/e0002Ic@02F/eIcAW=6LdJcEW=000IcA[=@02Ic@00`00JcEW=002
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00I[=FLd
001W=6/e0002Ic@01V/eIcAW=6LdJcD0009W=006JcEW=6LdIcA[=@000VLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIc@00003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6Ld00000fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@00`00JcEW=002Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=004JcEW=6LdIc@1JcD0031W=003001W=6Ld02UW=003001W=6Ld01eW=003001W
=6Ld00]W=003001W=00000EW=005001W=6LdIc@00004Ic@00`00IcAW=00lIc@00`00Ic@00005Ic@0
1@00IcAW=6Ld00000VLd00D006LdIcAW=00000iW=003001W=6Ld01aW=003001W=6Ld02UW=003001W
=6Ld02mW=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@02F/eIcAW=6LdJcEW=000IcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e009W=003001[=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0`0000=W=6/eIc@0
0VLd00E[=@00000006/e00=W=080009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@016/eIcAW=6Ld0`0000=W=6/eIc@00VLd00E[=@00000006/e00=W=0<0
0003IcA[=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/e001W=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00IcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01V/eIcAW
=6LdJcD0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=000<6Ld00<006LdIc@0
:VLd00<006LdIc@07FLd00<006LdIc@02VLd00@006LdIc@004aW=004001W=6Ld000LIc@00`00IcAW
=00MIc@00`00IcAW=00ZIc@00`00IcAW=00_Ic@00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005001W=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00U[=FLdIcAW=6/eIc@006LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd001W=6/e00=W=008JcEW
=6LdIcA[=FLd001W=0<00003IcA[=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00Q[=FLdIcAW=6/eIc@006Ld0`0000=W
=6/eIc@00VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@02F/eIcAW=6LdJcEW=000IcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIc@0
06LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@00`00JcEW=002Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=004JcEW=6LdIc@1JcD0031W=003001W=6Ld02]W=003001W=6Ld01eW=003001W=6Ld00UW=003001W
=6Ld04eW=003001W=6Ld01aW=003001W=6Ld01eW=003001W=6Ld02]W=003001W=6Ld02mW=0000VLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@02F/eIcAW=6LdJcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcD006LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/e001W=6LdJcD00fLd00E[=FLdIcAW=00000=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIc@00003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=000JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIc@006/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00IcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e0FLd0FLd000`Ic@00`00IcAW=00/Ic@00`00IcAW=00M
Ic@00`00IcAW=007Ic@2001>Ic@2000MIc@00`00IcAW=00MIc@00`00IcAW=00/Ic@00`00IcAW=00_
Ic@00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005001W=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005001W=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00VLd00<006/eIc@00VLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=000JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@016/eIcAW=6Ld0F/e000`Ic@00`00IcAW=00^
Ic@00`00IcAW=00MIc@00`00IcAW=01cIc@00`00IcAW=00MIc@00`00IcAW=00]Ic@00`00IcAW=00_
Ic@0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00U[=FLdIcAW=6/eIc@006LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=000JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIc@006/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00D006LdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005001W=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcD0
06LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@5W=05W=000<6Ld00<006LdIc@0;fLd00<0
06LdIc@07FLd00<006LdIc@0LFLd00<006LdIc@07FLd00<006LdIc@0;VLd00<006LdIc@0;fLd0000
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1V/eIcAW=6LdJcD0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=006JcEW=6LdIcA[=@000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd00<0
06/eIc@00VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@016/eIcAW=6Ld0F/e000`Ic@00`00IcAW=00`Ic@0
0`00IcAW=00MIc@00`00IcAW=01_Ic@00`00IcAW=00MIc@00`00IcAW=00_Ic@00`00IcAW=00_Ic@0
009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00U[=FLdIcAW=6/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01V/eIcAW=6LdJcD0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=006JcEW=6LdIcA[=@000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=009
JcEW=6LdIcA[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=006JcEW=6LdIcA[=@00
0VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd000`Ic@00`00IcAW=00aIc@00`00
IcAW=00MIc@00`00IcAW=01/Ic@00`00IcAW=00MIc@00`00IcAW=00aIc@00`00IcAW=00_Ic@00005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005001W=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=006JcEW=6LdIcA[=@000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00I[=FLdIcAW=6/e0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIc@006/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6Ld001[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@00`00
JcEW=002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=004JcEW=6LdIc@1JcD0031W=003001W=6Ld039W=003
001W=6Ld01eW=003001W=6Ld03AW=003001W=6Ld03=W=003001W=6Ld01eW=003001W=6Ld039W=003
001W=6Ld02mW=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=00000=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIc@00003Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00D006LdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005001W=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@006IW=003001W=6Ld
01eW=003001W=6Ld039W=08003AW=003001W=6Ld01eW=003001W=6Ld06EW=00000E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e009W=003001[=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6Ld001[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@02Ic@30002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=05[=@00IfLd00<006LdIc@07VLd00<006LdIc@0<6Ld0`00<VLd
00<006LdIc@07FLd00<006LdIc@0IVLd0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@02F/eIcAW=6LdJcEW=000IcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIc@0
06LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00`0000E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcD006LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@1JcD1Ic@1
Ic@006UW=003001W=6Ld01eW=003001W=6Ld02iW=0@0035W=003001W=6Ld01eW=003001W=6Ld06MW
=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcD006LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@00f/eIc@000030002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=009JcEW=6LdIcA[=FLd
001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@016/eIcAW=6Ld0F/e001ZIc@00`00IcAW=00MIc@00`00
IcAW=00]Ic@5000_Ic@00`00IcAW=00MIc@00`00IcAW=01XIc@0009W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00D006LdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd1@000fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=000JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIc@006/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@02Ic@006]W=003001W=6Ld01eW=003001W=6Ld02]W=0H002iW=003001W=6Ld01eW=003001W=6Ld
06UW=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02
Ic@500000f/eIcAW=0030002Ic@01F/eIcAW=6LdJcD00VLd00<006/eIc@00VLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=00000=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00=[=@000000100000=W=6/eIc@00VLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01@00
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00D006LdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@00f/eIcAW=0030002Ic@00f/e000000030002
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@016/eIcAW=6Ld0F/e001IIc@00`00IcAW=002Ic@01@00
IcAW=6Ld00002FLd00<006LdIc@07FLd00<006LdIc@0:VLd1`00:fLd00<006LdIc@07VLd00<006Ld
Ic@03fLd00D006LdIcAW=000009W=003001W=6Ld055W=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@00`00JcEW=002Ic@01F/eIcAW=6Ld0000
0fLd00E[=FLdIcAW=6/e009W=003001[=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld001[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=0L0009W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcD006LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005001W=6LdIc@00003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00VLd001>Ic@20002Ic@30004Ic@00`00IcAW=004Ic@2000;Ic@00`00IcAW=00MIc@00`00
IcAW=00XIc@8000ZIc@00`00IcAW=00MIc@00`00IcAW=008Ic@20002Ic@30004Ic@20005Ic@00`00
IcAW=01?Ic@00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@01P00JcEW=000
IcA[=@=W=005JcD006LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00U[=FLdIcAW=6/eIc@006LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd001W
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@016/eIcAW=6Ld200000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd001W=6/e
00=W=00:JcEW=6LdIcA[=FLd001W=6/e0002Ic@02F/eIcAW=6LdJcEW=000IcA[=@03Ic@01@00IcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e001?Ic@00`00Ic@00007Ic@00`00IcAW
=002Ic@01@00IcAW=6Ld00002fLd00<006LdIc@07VLd00<006LdIc@09VLd2000:FLd00<006LdIc@0
7FLd00<006LdIc@02VLd00<006Ld00001FLd00D006LdIcAW=000009W=005001W=6LdIc@0001?Ic@0
009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@0300001V/eIcAW=6LdJcEW=080
0005JcEW=6LdIcA[=@0300001F/eIcAW=6LdJcD00fLd00I[=FLdIcAW=6/e0002Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01V/eIcAW=6LdJcD0009W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1V/eIcAW=6LdJcEW=0T00003IcA[=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIc@006/e00=W=005JcEW=6Ld
IcA[=@03Ic@300000fLdJcEW=002Ic@01F/e00000000JcD00fLd0`0000=W=6/eIc@00VLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd0F/e0FLd0FLd001?Ic@01000IcAW=00076Ld00<006LdIc@07VLd00<0
06LdIc@096Ld2P009fLd00<006LdIc@07FLd00<006LdIc@02fLd00@006LdIc@005mW=00000E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=003001[=@0000800005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIc@00003Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld00000fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=003
JcEW=6Ld00X000=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=000JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=00000=W=005JcEW=6LdIcA[=@03Ic@016/eIc@0
06Ld0`0000=W=6/eIc@00VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@1JcD004mW=003001W=6Ld01mW=003001W=6Ld01eW=003001W=6Ld02QW=003
001W=6Ld02QW=003001W=6Ld01eW=003001W=6Ld00aW=003001W=6Ld061W=0000VLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00I[=FLdIcAW=6/e0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd00<006/eIc@00VLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIc@006/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@02F/e
IcAW=6LdJcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=00000=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIc@00003Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=00000=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=000CVLd0P008VLd00<006LdIc@07FLd00<006LdIc@0
9fLd00<006LdIc@09fLd00<006LdIc@07FLd00<006LdIc@036Ld0P00HVLd00001F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=000JcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIc@00003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00I[=FLdIcAW=6/e0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01V/eIcAW=6LdJcD0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e001cIc@00`00IcAW=00MIc@00`00IcAW=00VIc@00`00IcAW
=00UIc@00`00IcAW=00NIc@00`00IcAW=01aIc@0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=@00IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd001W=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00VLd001dIc@00`00IcAW=00MIc@00`00IcAW=00UIc@00`00IcAW=00TIc@00`00IcAW=00NIc@0
0`00IcAW=01bIc@00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00I[
=FLdIcAW=6/e0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01V/eIcAW=6LdJcD0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld00000fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld001[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=000JcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@1JcD007EW=003001W
=6Ld01iW=003001W=6Ld02=W=003001W=6Ld02=W=003001W=6Ld01eW=003001W=6Ld07AW=0000VLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld00000fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=000
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00<00004JcEW=6Ld
Ic@300001VLdJcEW=000IcA[=@=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00D006LdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd001fIc@00`00IcAW=00NIc@00`00IcAW=00DIc@0
1@00IcAW=6Ld00000VLd00D006LdIcAW=000009W=003001W=6Ld029W=003001W=6Ld01eW=003001W
=6Ld07EW=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00VLd00<006/eIc@00VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIc@006/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e000006LdJcD00`0000Y[
=FLdIcAW=6/eIc@006LdJcD0009W=005JcD006LdIc@00003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00D006LdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcD006LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@00MfLd00<006Ld
Ic@07VLd00<006LdIc@02fLd00@006LdIc@000IW=08000=W=005001W=6LdIc@00002Ic@00`00IcAW
=00QIc@00`00IcAW=00MIc@00`00IcAW=01fIc@0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00U[=FLdIcAW=6/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIc@006/e00=W=005JcEW=6LdIcA[=@03
Ic@01@00Ic@006LdJcD00fLd00E[=FLdIcAW=000009W=00:001[=FLdIc@006/eIc@006LdJcD3Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01V/eIcAW=6LdJcD0
009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=009JcEW=6Ld
IcA[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
0F/e0FLd0FLd001iIc@00`00IcAW=00MIc@00`00IcAW=00:Ic@30005Ic@01@00IcAW=6Ld00000VLd
00D006LdIcAW=000009W=003001W=6Ld021W=003001W=6Ld01eW=003001W=6Ld07MW=00000E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=000IcA[=@03Ic@02V/eIcAW=6LdJcEW=000IcA[=@000VLd00=[=FLdIc@00`000VLd00=[=FLd
00000P000fLd00D006LdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=000JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@016/eIcAW=6Ld0F/e001jIc@00`00IcAW=00MIc@00`00IcAW=009Ic@0
0`00Ic@00002000AIc@00`00IcAW=00NIc@00`00IcAW=00NIc@00`00IcAW=01hIc@0009W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005001W
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/e001W=6LdJcD00fLd00E[=FLdIcAW=00000=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6Ld001[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=000JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd001kIc@00`00IcAW=00MIc@00`00IcAW=008Ic@00`00
IcAW=00CIc@00`00IcAW=00MIc@00`00IcAW=00NIc@00`00IcAW=01iIc@00005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld001[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
00000fLd00E[=FLdIcAW=6/e00800003IcA[=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00D006LdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005001W=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@016/eIcAW=6Ld0F/e001lIc@00`00IcAW=00NIc@00`00IcAW=00LIc@00`00
IcAW=00LIc@00`00IcAW=00NIc@00`00IcAW=01jIc@0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld001[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=000JcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd001W=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcD006LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00VLd001mIc@00`00IcAW=00NIc@00`00IcAW=00KIc@00`00IcAW=00KIc@00`00IcAW=00N
Ic@00`00IcAW=01kIc@00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=009JcEW=6LdIcA[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01V/eIcAW=6LdJcD0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=009JcEW=6LdIcA[=FLd001W=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@00OVLd00<0
06LdIc@07VLd00<006LdIc@06VLd00<006LdIc@06VLd00<006LdIc@07FLd00<006LdIc@0OFLd0002
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01V/eIcAW=6LdJcD0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=009JcEW=6LdIcA[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00U[=FLdIcAW=6/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
2F/eIcAW=6LdJcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=000JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e0FLd0FLd001oIc@00`00IcAW=00NIc@00`00IcAW
=00IIc@00`00IcAW=00IIc@00`00IcAW=00MIc@00`00IcAW=01nIc@00005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=@00IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=00000=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=003001[
=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIc@00003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@016/eIcAW=6Ld0F/e0021Ic@00`00IcAW=00MIc@00`00IcAW=00HIc@00`00IcAW
=00HIc@00`00IcAW=00MIc@00`00IcAW=01oIc@0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@00`00JcEW=002
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
00000fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@02F/eIcAW=6LdJcEW=000IcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIc@00003Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01V/eIcAW=6LdJcD0009W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@02Ic@0089W=003001W=6Ld01eW=003001W=6Ld01MW=003001W=6Ld01IW=003001W=6Ld
01iW=003001W=6Ld081W=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=000JcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld00000fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01V/eIcAW=6LdJcD0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=006JcEW=6LdIcA[=@000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@00PfLd
00<006LdIc@07VLd00<006LdIc@05FLd00<006LdIc@05FLd00<006LdIc@07VLd00<006LdIc@0PFLd
0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=000Q6Ld00<006LdIc@07VLd00<006Ld
Ic@056Ld00<006LdIc@056Ld00<006LdIc@07VLd00<006LdIc@0PVLd00001F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00I[=FLdIcAW=6/e0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01V/eIcAW=6LdJcD0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=00000=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd001W=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld001[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd0F/e0025Ic@00`00IcAW=00NIc@00`00IcAW=00CIc@00`00IcAW=00C
Ic@00`00IcAW=00NIc@00`00IcAW=023Ic@0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld0000
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00I[=FLdIcAW
=6/e0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=003001[=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIc@00003Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
0F/e0FLd0FLd0026Ic@00`00IcAW=00NIc@00`00IcAW=00BIc@00`00IcAW=00BIc@00`00IcAW=00M
Ic@00`00IcAW=025Ic@00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd00<006/eIc@00VLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=000
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00D006LdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6Ld00000fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00I[=FLdIcAW=6/e0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00A[=FLdIcAW=05[=@00
QfLd00<006LdIc@07VLd00<006LdIc@04FLd00<006LdIc@04FLd00<006LdIc@07FLd00<006LdIc@0
QVLd0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00U[=FLdIcAW=6/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIc@006/e00=W=005JcEW=6Ld
IcA[=@03Ic@02F/eIcAW=6LdJcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00VLd00<006/eIc@00VLd
00E[=@00IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e0FLd0FLd0029Ic@00`00IcAW=00M
Ic@00`00IcAW=00@Ic@00`00IcAW=00:Ic@30002Ic@00`00IcAW=00NIc@00`00IcAW=027Ic@00005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00IcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=00000=W=005JcEW=6LdIcA[=@03Ic@700000fLdJcEW=002Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=000JcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=004JcEW=6LdIc@1JcD008YW=003001W=6Ld01iW=003001W=6Ld00iW=003001W
=6Ld00UW=0L001mW=003001W=6Ld08QW=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=@00IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00I[=FLd
IcAW=6/eIc@900000fLdJcEW=002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@5W=05W=000RfLd00<0
06LdIc@07VLd00<006LdIc@03FLd00<006LdIc@02FLd2P006fLd00<006LdIc@0RFLd00001F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld001[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld00000fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIc@00003Ic@01F/eIcAW=6LdJcD00VLd2P000fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00D006LdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
16/eIcAW=6Ld0F/e002<Ic@00`00IcAW=00NIc@00`00IcAW=00<Ic@00`00IcAW=008Ic@9000LIc@0
0`00IcAW=02:Ic@0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIc@006/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
Ic@00003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@080003Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@008eW=003001W=6Ld01iW=003001W=6Ld
00]W=003001W=6Ld00QW=0L001eW=003001W=6Ld08]W=00000E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@02F/eIcAW=6LdJcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=000JcD00fLd00E[=FLdIcAW=6/e00=W=005001W=6Ld
IcA[=@03Ic@00f/eIc@000060003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@1
JcD008iW=003001W=6Ld01iW=003001W=6Ld00YW=003001W=6Ld00MW=0H001iW=003001W=6Ld08aW
=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01V/eIcAW=6LdJcD0009W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=009JcEW=6LdIcA[=FLd001W
=6/e00=W=009JcEW=6LdIcA[=FLd001W=6/e00=W=004JcEW=6LdIc@60002Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=000JcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@1JcD1Ic@1Ic@008mW=003001W=6Ld01iW=003001W=6Ld00UW
=003001W=6Ld00MW=0D001eW=003001W=6Ld08iW=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00D006LdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcD006LdIcA[=@03Ic@01F/eIcAW=6Ld00000fLd00E[
=FLdIcAW=6/e00D0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIc@00003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=004JcEW=6Ld
Ic@1JcD0095W=003001W=6Ld01iW=003001W=6Ld00MW=003001W=6Ld00IW=0@001iW=003001W=6Ld
08mW=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd00<0
06/eIc@00VLd00E[=@00IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=00000=W=009JcEW=6LdIcA[=FLd001W=6/e00=W=003JcEW=6Ld00<0009W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=006JcEW=6LdIcA[=@000VLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd002BIc@00`00IcAW=003
000KIc@00`00IcAW=006Ic@00`00IcAW=006Ic@2000OIc@00`00IcAW=02@Ic@00005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=003JcEW=00000H000=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=003001[=FLd009W=005JcEW=6Ld
Ic@00003Ic@016/eIcAW=6Ld0P000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00U[=FLdIcAW=6/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@016/eIcAW=6Ld0F/e002AIc@8000KIc@00`00Ic@0000;0002Ic@00`00IcAW=00NIc@0
0`00IcAW=02AIc@0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00X00003IcA[=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00A[=FLdIcAW=0@0
0005JcEW=6LdIcA[=@03Ic@016/eIcAW=6Ld100000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00U[=FLdIcAW=6/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd002>Ic@;000EIc@4000DIc@3000KIc@00`00IcAW
=02BIc@00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=0/0009W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0P000VLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIc@006/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=05[=@00T6Ld2P003fLd0`007fLd100056Ld00<006LdIc@0TfLd0002
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@900001F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00800003IcA[=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e000006LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIc@00003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@1JcD1Ic@1Ic@0099W=0P000aW=003001W=6Ld02QW=003001W=6Ld00iW
=003001W=6Ld09AW=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00=[=FLdIc@0200000=W=6/eIc@00VLd00U[=FLdIcAW=6/eIc@006LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=009JcEW
=6LdIcA[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e002DIc@70009Ic@2000]Ic@0
0`00IcAW=00;Ic@00`00IcAW=02EIc@0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=003JcEW=6Ld00H000=W=004JcEW=6LdIc@20002Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=006JcEW=6LdIcA[=FLd0P0000E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@1JcD1Ic@1Ic@009IW=0D0
00IW=003001W=6Ld039W=08000MW=003001W=6Ld09MW=00000E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=0D00005JcEW=6LdIc@00003Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld00000fLd00E[=FLdIc@0
06/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=004JcEW
=6LdIc@1JcD009QW=0@000AW=003001W=6Ld03IW=003001W=6Ld009W=003001W=6Ld09QW=0000VLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
009W=0<0009W=080009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@02Ic@00`00JcEW=002Ic@01@00IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e0FLd0FLd002JIc@200000fLd001W=00kIc@01000IcAW
=000VfLd00001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00=[=FLdIc@00`000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=006JcEW=6Ld001[=@000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@00W6Ld00<006LdIc@0?FLd
00<006LdIc@0VVLd0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=000JcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=000VfLd00<006Ld
Ic@0@6Ld00<006LdIc@0V6Ld00001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@02F/eIcAW=6LdJcEW=000IcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@016/eIcAW=6Ld0F/e002J
Ic@00`00IcAW=012Ic@00`00IcAW=02GIc@0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@00`00JcEW=002Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcD0
06LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@1
JcD1Ic@1Ic@009UW=003001W=6Ld04AW=003001W=6Ld09IW=00000E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005001W=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005001W=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@1JcD009MW=003001W=6Ld04IW=003001W=6Ld09IW=0000VLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00I[=FLdIcAW=6/e0002Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@02Ic@00`00JcEW=002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@1JcD1Ic@1Ic@009IW=003001W=6Ld04QW=003001W=6Ld09EW=00000E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00U[=FLdIcAW=6/eIc@0
06LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@02F/eIcAW=6LdJcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@1JcD009IW=003001W=6Ld04UW=003001W=6Ld09AW
=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=00000=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005001W=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@009EW=003001W=6Ld04YW=003001W
=6Ld09AW=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00I[
=FLdIcAW=6/e0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=000JcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e002EIc@00`00IcAW=01;
Ic@00`00IcAW=02CIc@0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6Ld001[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd002DIc@00`00
IcAW=01<Ic@00`00IcAW=02CIc@00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIc@00003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=000
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e002D
Ic@00`00IcAW=01<Ic@00`00IcAW=02CIc@0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd100000=W=6/eIc@00VLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02
Ic@009AW=003001W=6Ld025W=003001W=6Ld009W=003001W=6Ld02AW=003001W=6Ld099W=00000E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=00000=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01V/eIcAW=6LdJcD0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld00000fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e002DIc@00`00IcAW=00VIc@00`00IcAW=00T
Ic@00`00IcAW=02BIc@0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=@00001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIc@006LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd002DIc@00`00
IcAW=00VIc@00`00IcAW=00TIc@00`00IcAW=02BIc@00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIc@00003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00I[=FLdIcAW=6/e0002Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIc@006/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=05[=@00U6Ld00<006LdIc@08FLd00<006LdIc@00VLd00<006LdIc@08fLd00<006LdIc@0
TfLd0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
Ic@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e009W=0@00003IcA[=FLd009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd002DIc@00`00IcAW=01<Ic@00`00
IcAW=02CIc@00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIc@00003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=000JcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e002EIc@00`00IcAW=01;
Ic@00`00IcAW=02CIc@0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6Ld001[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01@00IcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd002EIc@00`00
IcAW=01:Ic@00`00IcAW=02DIc@00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=006JcEW=6LdIcA[=@000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd001W
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@00
UVLd00<006LdIc@0BFLd00<006LdIc@0U6Ld0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld00000fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd
00<006/eIc@00VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
0F/e0FLd0FLd002FIc@00`00IcAW=018Ic@00`00IcAW=02EIc@00005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@00`00JcEW=002Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIc@00003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@016/eIcAW=6Ld0F/e002GIc@00`00IcAW=016Ic@00`00IcAW=02FIc@0009W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=009JcEW=6LdIcA[=FLd001W
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=05[=@5W=05W=000V6Ld00<006LdIc@0A6Ld00<006LdIc@0UfLd0000
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=@00IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd00<006/eIc@00VLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00A[=FLdIcAW=05[=@00VFLd00<006LdIc@0@VLd00<0
06LdIc@0V6Ld0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00D006LdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld00000fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=000VfLd00<006LdIc@0
?fLd00<006LdIc@0VFLd00001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIc@006/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld00000fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@00W6Ld00<0
06LdIc@0?FLd00<006LdIc@0VVLd0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e001W=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=000
WFLd0P00>fLd00<006LdIc@0W6Ld00001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=003001[=FLd009W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=006JcEW=6LdIcA[=@000VLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=004JcEW=6Ld
Ic@1JcD00:1W=003001W=6Ld03EW=003001W=6Ld09iW=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=009JcEW=6LdIcA[=FLd001W
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcD006LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd0F/e0FLd0FLd002QIc@2000cIc@00`00IcAW=02PIc@00005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIc@006/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00I[=FLdIcAW=6/e0002Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=05[=@00Y6Ld0P00;FLd0P00Y6Ld0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=004JcEW
=6LdIc@20002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=08000=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e
0FLd0FLd002XIc@2000VIc@00`00IcAW=02VIc@00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01V/eIcAW=6LdJcEW=0800005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=05[=@00ZfLd0P007fLd0P00ZfLd0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@00f/eIcAW=0020003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@20002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@1JcD1Ic@1Ic@0
0:mW=0@001AW=0<00:mW=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=003JcEW=6Ld00H000=W=005JcEW=6LdIcA[=@0600000fLdJcEW=002Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@016/eIcAW=6Ld0F/e002iIc@8002hIc@0009W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLd001W=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd002kIc@2002lIc@00005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00=[=FLdIc@0
0`000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@1JcD00;]W=0<00;]W=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e00000000JcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@02Ic@00;YW=004001W=000002kIc@00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00A[=FLd001W=080009W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e
002jIc@01@00Ic@006Ld0000^VLd0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005001W=000Ic@00003Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=000
^FLd00H006LdIc@006Ld002jIc@00005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00U[=@00IcAW=000Ic@006LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=004JcEW=6LdIc@1JcD0
0;UW=004001W=6Ld0002Ic@00`00IcAW=02gIc@0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd00L006/eIc@006LdJcD00002
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e009W=000^6Ld00D006LdIcAW=000009W=003001W=6Ld0;MW=00000E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01@00IcAW
=6Ld00000VLd00<006/eIc@00VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=004JcEW=6LdIc@1JcD00;QW=005001W=6LdIc@00002Ic@00`00IcAW=02gIc@0
009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@04F/e
IcAW=6LdJcEW=000IcA[=FLd001W=6/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@5W=05W=000]fLd00<006LdIc@00VLd00D006Ld
IcAW=0000;QW=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@02Ic@00`00JcEW=002Ic@01@00IcAW=6Ld00000fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=004JcEW=6LdIc@1JcD00;aW=003
001W=6Ld0;YW=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@00;aW=003001W=6Ld
0;YW=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld00000fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@1JcD00;aW=003001W=6Ld0;YW=000
0VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@00;aW=003001W=6Ld0;YW=00000E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6Ld00000fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@1JcD00;aW=003001W=6Ld0;YW=0000VLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@02Ic@00;aW=003001W=6Ld0;YW=00000E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
00000fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@1JcD00;aW=003001W=6Ld0;YW=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIc@006LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@02Ic@00;aW=003001W=6Ld0;YW=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld00000fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@1JcD00;aW=003001W=6Ld0;YW=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@0
0;aW=003001W=6Ld0;YW=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld00000fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@1JcD00;aW=003
001W=6Ld0;YW=0000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@02Ic@00;aW=003001W=6Ld
0;YW=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=006JcEW=6LdIcA[=@000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld001[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=00000=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e002BIc@30007Ic@00`00IcAW
=00=Ic@00`00IcAW=00=Ic@00`00IcAW=02jIc@0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e009W=006001[=FLdIc@006/e0fLd00E[=FLd001W=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIc@006LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e009W=000R6Ld0P0000AW=000000000MW=003001W=6Ld00=W=003001W=6Ld00IW=0@000EW=003
001W=6Ld00aW=003001W=6Ld0;YW=00000E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@02F/e
000006LdJcEW=000IcA[=@02Ic@20003Ic@01F/eIcAW=000JcD00fLd00E[=FLdIc@006/e00=W=006
001W=6LdIcA[=@000VLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIc@00003Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@00
RFLd00<006LdIc@00VLd00<006LdIc@016Ld00<006LdIc@00fLd00<006LdIc@01FLd00<006LdIc@0
1fLd00<006LdIc@036Ld00<006LdIc@0^VLd0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
009W=003001[=FLd009W=005001W=6Ld001[=@02Ic@00`00JcEW=002Ic@01F/e001W=6LdJcD00fLd
00E[=@00IcAW=6/e00=W=005JcEW=6Ld001[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd001W=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00VLd0029Ic@20003Ic@01000IcAW=6Ld0`001VLd00<006LdIc@01FLd00<006LdIc@0
1fLd00<006LdIc@036Ld00<006LdIc@0^VLd00001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=003JcD006Ld00<0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=000JcD00fLd00=[=@0000001@00
00I[=FLdIcAW=6/e0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=00000=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd0F/e
0029Ic@00`00IcAW=00@Ic@00`00IcAW=004Ic@00`00IcAW=006Ic@00`00IcAW=00=Ic@00`00IcAW
=02jIc@0009W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00VLd00<006/eIc@00VLd00E[=FLd
IcAW=6/e00=W=009JcEW=6LdIcA[=FLd001W=6/e00=W=005JcD006LdIcA[=@03Ic@01F/eIc@006Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03
Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6Ld
JcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLd
IcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005
JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=000R6Ld0P004fLd00<0
06LdIc@02fLd00<006LdIc@03VLd00<006LdIc@0^VLd00001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIc@00003Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=05[=@00_6Ld00<006LdIc@0^VLd0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
009W=000_6Ld00<006LdIc@0^VLd00001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIc@00003Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@00
_6Ld00<006LdIc@0^VLd0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=000_6Ld00<0
06LdIc@0^VLd00001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIc@00003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@00_6Ld00<006LdIc@0
^VLd0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=000_6Ld00<006LdIc@0^VLd0000
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIc@00003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@00_6Ld00<006LdIc@0^VLd0002Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=000IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=000_6Ld00<006LdIc@0^VLd00001F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIc@00003Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=05[=@00_6Ld00<006LdIc@0^VLd0002Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=000
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e009W=000_6Ld00<006LdIc@0^VLd00001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIc@00003Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=05[=@00_6Ld00<006LdIc@0^VLd0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=000IcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6Ld
IcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/e
IcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd
00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e
009W=000_6Ld00<006LdIc@0^VLd00001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIc@00003Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@00
ofLdNVLd0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=000ofLdNVLd00001F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@00ofLdNVLd0002Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e009W=000ofLdNVLd00001F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@00
ofLdNVLd0002Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@0
1F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD0
0fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW
=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW
=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e009W=000ofLdNVLd00001F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[
=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W
=005JcEW=6LdIcA[=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[
=@03Ic@01F/eIcAW=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=005JcEW=6LdIcA[=@03Ic@01F/eIcAW
=6LdJcD00fLd00E[=FLdIcAW=6/e00=W=05[=@00\
\>"],
  ImageRangeCache->{{{0, 376.5}, {502.25, 0}} -> {-0.612526, -1.65161, \
0.0188249, 0.0188249}}],

Cell["\<\
Figure 2. The general multi-input multi-output (MIMO) three-compartment \
model.\
\>", "NumberedFigureCaption",
  CellTags->"fig 2"],

Cell["This model is represented by the following system of ODEs ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\(x\& . \)\_1\)(t)\)\(\ \)\(=\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_1\)(
          t)\  - \ \((k\_10\  + \ k\_12\  + \ k\_13)\)\ \(\(x\_1\)(
            t)\)\ \  + \ 
        k\_21\ \(\(x\_2\)(t)\)\  + \ \(\(k\_31\)\(\ \)\(\(x\_3\)(
            t)\)\(\ \)\)\)]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\(x\& . \)\_2\)(t)\)\(\ \)\(=\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_2\)(t)\  + \ 
        k\_12\ \(\(x\_1\)(
            t)\)\ \  - \ \((k\_20\  + \ k\_21\  + \ k\_23)\)\ \(\(x\_2\)(
            t)\)\  + \ k\_32\ \(\(x\_3\)(t)\)\)]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\(x\& . \)\_3\)(t)\)\(\ \)\(=\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`b\_3\ \((t)\)\  + \ k\_13\ \(\(x\_1\)(t)\)\ \  + \ 
        k\_23\ \(\(x\_2\)(
            t)\)\  - \ \(\((k\_30\  + \ k\_31\  + \ k\_32)\)\(\ \)\(\(x\_3\)(
            t)\)\(\ \)\)\)]]
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["in matrix notation ", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[
              OverscriptBox[
                StyleBox["x",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "."],
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", "t", ")"}], " ", "=", 
          RowBox[{
            StyleBox[
              RowBox[{
                StyleBox["A",
                  FontSlant->"Plain"], " ", 
                StyleBox["x",
                  FontSlant->"Plain"]}],
              FontWeight->"Bold"], 
            StyleBox[" ",
              FontWeight->"Bold"], "+", " ", 
            RowBox[{
              StyleBox["b",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", "t", ")"}]}]}], ",", 
        " ", \(t \[GreaterEqual] 0\)}], TraditionalForm]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["with", "Text"],

Cell[TextData[{
  StyleBox["x",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\((t)\) = \ {\(x\_1\)(t), \ \(x\_2\)(t), \ \
\(x\_3\)(t)}\^T\)]],
  " \n\n",
  StyleBox["b",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\(\((t)\)\(\ \)\(=\)\(\ \)\({\(b\_1\)(t), \ \(b\_2\)(
                t), \(b\_3\)(t)}\^T\)\(\ \)\)\)]]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "where  ",
  StyleBox["A",
    FontWeight->"Bold"],
  " is given by"
}], "DisplayFormula",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    RowBox[{"A", "=", " ", 
      RowBox[{"(", GridBox[{
            {\(a\_11\), \(a\_12\), \(a\_13\)},
            {\(a\_21\), \(a\_22\), \(a\_23\)},
            {\(a\_31\), \(a\_32\), \(a\_33\)}
            }], ")"}]}]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["with", "Text"],

Cell[BoxData[{
    \(a\_11 = \(-\ \((k\_10\  + \ k\_12\  + \ k\_13)\)\)\ ; 
    a\_12\  = \ k\_21; a\_13 = \ k\_31; \), "\n", 
    \(a\_21 = k\_12; 
    a\_22 = \(-\ \((k\_20\  + \ k\_21\  + \ k\_23)\)\)\ \ ; \ 
    a\_23 = k\_32; \), "\n", 
    \(a\_31 = k\_13; \ a\_32 = \ k\_23; \ 
    a\_33 = \(-\ \((k\_30\  + \ k\_31\  + \ k\_32)\)\); \)}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
If we suppose that the substance introduced into the system is a radioactive \
isotope we mush considered the radioactive decay, it is given by a constant \
rate represented by \[Lambda]. This constant is specific for each isotope. \
The decay constant can be interpreted by an equal flow going out of the \
system in each compartment. If we assume a radioactive decay in our \
example:\
\>", "Text"],

Cell[BoxData[{
    \(a\_11 = \(-\ \((k\_10\  + \ k\_12\  + \ k\_13 + \ \[Lambda])\)\)\ ; 
    a\_12\  = \ k\_21; a\_13 = \ k\_31; \), "\n", 
    \(a\_21 = k\_12; 
    a\_22 = \(-\ \((k\_20\  + \ k\_21\  + \ k\_23 + \ \[Lambda])\)\)\ \ ; \ 
    a\_23 = k\_32; \), "\n", 
    \(a\_31 = k\_13; \ a\_32 = \ k\_23; \ 
    a\_33 = \(-\ \((k\_30\  + \ k\_31\  + \ 
            k\_32 + \ \[Lambda])\)\); \)}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "In some circumstances, a physiological model better a compartmental model \
is required, for example, when blood flow or other physiological parameter is \
measured. In those circumstances the transfer rate constants are associated \
with physiologically meaningful values that correspond to the measured \
physiological parameter or may be a function of them. However, if the \
physiological parameters are constants, a compartmental model and a \
physiological model are mathematically equivalent. But the form of the A \
matrix for the compartmental model compared with that for the physiological \
model will be different. For these cases we will directly give the values  ",
  Cell[BoxData[
      \(TraditionalForm\`a\_ij\)]],
  " to the A matrix instead of ",
  Cell[BoxData[
      \(TraditionalForm\`k\_ij\)]],
  "."
}], "Text"],

Cell[TextData[{
  "The patterns that we have seen can be expanded to systems of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " compartments or ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " state variables (in the case of physiological models). The equation for \
any compartment ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " is given by"
}], "Text"],

Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[
              OverscriptBox[
                StyleBox["x",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "."],
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", "t", ")"}], " ", "=", 
          RowBox[{
            StyleBox[
              RowBox[{
                StyleBox["A",
                  FontSlant->"Plain"], " ", 
                StyleBox["x",
                  FontSlant->"Plain"]}],
              FontWeight->"Bold"], 
            StyleBox[" ",
              FontWeight->"Bold"], "+", " ", 
            RowBox[{
              StyleBox["b",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", "t", ")"}]}]}], ",", 
        " ", \(t \[GreaterEqual] 0\)}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox["x",
            FontWeight->"Bold",
            FontSlant->"Plain"], "(", "0", ")"}], " ", "=", " ", 
        SubscriptBox[
          StyleBox["x",
            FontWeight->"Bold",
            FontSlant->"Plain"], "0"]}], 
      TraditionalForm]}], "NumberedEquation",
  TextAlignment->Left,
  TextJustification->0,
  CellTags->"eq 1"],

Cell["where:", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "x",
  Cell[BoxData[
      \(TraditionalForm\`\((t)\) = \ {\(x\_1\)(t), \ \(x\_2\)(t), \  ... , \
\(x\_n\)(t)}\^T\)]],
  " is a column vector and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(x\_i\)\)\)]],
  "(t) denote the amount or content of species in compartment ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " at time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["A",
    FontWeight->"Bold"],
  " is a ",
  Cell[BoxData[
      \(TraditionalForm\`n\[Cross]n\)]],
  " is usually known as the compartmental matrix or system matrix. "
}], "Text"],

Cell[TextData[{
  StyleBox["b",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\(\((t)\)\(\ \)\(=\)\(\ \)\({\(b\_1\)(t), \ \(b\_2\)(
                t),  ... , \(b\_n\)(t)}\^T\)\(\ \)\)\)]],
  "is a column vector where {",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_i\)(t)\)]],
  "} is the input rate into compartment ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(i\)\(\ \)\)\)]],
  "from outside system. "
}], "Text"],

Cell[TextData[{
  StyleBox["x",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\(\((0)\)\(\ \)\)\)]],
  " = ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  FormBox[\(x\_1\),
                    "TraditionalForm"], "(", "0", ")"}], ",", " ", 
                RowBox[{
                  FormBox[\(x\_2\),
                    "TraditionalForm"], "(", "0", ")"}], ",", "  ", "...", 
                ",", " ", 
                RowBox[{
                  FormBox[\(x\_n\),
                    "TraditionalForm"], "(", "0", ")"}]}], "}"}], 
            FormBox[\(\^T\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  "are the initial conditions, so ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(x\_i\)(0)\)\(,\)\)\)]],
  " represents the amount or content of species in compartment ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " at time ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(t\)\)\)]],
  " = 0. "
}], "Text"],

Cell["\<\
SysModel.m provides a few functions to construct and solve Compartmental and \
Physiological models. Most of the examples are made using clearance rates, \
but also has been included some example of non linear models. The last \
example involved partial differential equations, it is solved using Laplace \
transform\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["One-compartmental Systems", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["Easy one compartmental models", "SubsubsectionIcon"],

Cell["\<\
The easiest example of compartmental model is the decay of a single \
radioactive isotope.\
\>", "Text"],

Cell[BoxData[
    StyleBox[Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214286 0.380952 0.2 0.380952 [
[ 0 0 0 0 ]
[ 1 .4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .4 L
0 .4 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.21429 .2 .19048 0 365.73 arc
s
.40476 .2 m
.97619 .2 L
s
% Start of user PostScript
0.5 0 2. 0 MAarrowhead1
% End of user PostScript
gsave
.21429 .2 -75 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 12.750 moveto
(H) show
75.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 12.750 moveto
(L) show
87.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.69048 .2 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
        ImageSize->{260, 103.75},
        ImageMargins->{{0, 0}, {0, 17.3125}},
        ImageRegion->{{0, 1}, {0, 1}},
        ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000550000PA000`40O003h00OogooAWoo003oOom6
Ool00?moodIoo`00?Goo4P00mWoo000gOol6000BOol6003`Ool003Aoo`<001ioo`<00>eoo`00<Goo
0`0097oo0`00jWoo000^Ool3000ZOol3003WOol002aoo`80031oo`800>Eoo`00:goo00<007ooOol0
<Woo0P00hgoo000YOol2000gOol00`00Oomoo`3POol002Moo`8003Yoo`800>1oo`009Goo0P00?Woo
0P00gWoo000TOol00`00Oomoo`10Ool00`00Oomoo`3KOol0029oo`8004Aoo`800=]oo`0087oo0P00
B7oo0P00fGoo000OOol00`00Oomoo`1:Ool00`00Oomoo`3FOol001ioo`03001oogoo04aoo`03001o
ogoo0=Eoo`007Goo00<007ooOol0CWoo00<007ooOol0e7oo000LOol00`00Oomoo`1@Ool00`00Oomo
o`3COol001]oo`03001oogoo059oo`03001oogoo0=9oo`006Woo00<007ooOol0E7oo0P00dWoo000I
Ool00`00Oomoo`1GOol00`00Oomoo`3?Ool001Qoo`03001oogoo05Uoo`03001oogoo0<ioo`0067oo
00<007ooOol0FGoo00<007ooOol0cWoo000GOol00`00Oomoo`1KOol00`00Oomoo`3=Ool001Ioo`03
001oogoo05aoo`03001oogoo0<eoo`005Goo00<007ooOol0GWoo00<007ooOol0c7oo000DOol00`00
Oomoo`1POol00`00Oomoo`3;Ool001Aoo`03001oogoo061oo`03001oogoo0<]oo`004goo00<007oo
Ool0HWoo00<007ooOol0bWoo000BOol00`00Oomoo`1TOol00`00Oomoo`39Ool0015oo`03001oogoo
06Ioo`03001oogoo0<Qoo`004Goo00<007ooOol0IWoo00<007ooOol0b7oo000@Ool00`00Oomoo`1X
Ool00`00Oomoo`37Ool0011oo`03001oogoo06Qoo`03001oogoo0<Moo`003goo00<007ooOol0JWoo
00<007ooOol0aWoo000?Ool00`00Oomoo`1ZOol00`00Oomoo`36Ool000ioo`03001oogoo06aoo`03
001oogoo0<Eoo`003Goo00<007ooOol0KGoo00<007ooOol0aGoo000=Ool00`00Oomoo`1^Ool00`00
Oomoo`34Ool000eoo`03001oogoo06ioo`03001oogoo0<Aoo`0037oo00<007ooOol0L7oo00<007oo
Ool0`goo000<Ool00`00Oomoo`1`Ool00`00Oomoo`33Ool000aoo`03001oogoo071oo`03001oogoo
0<=oo`002goo00<007ooOol0LWoo00<007ooOol0`Woo000;Ool00`00Oomoo`1bOol00`00Oomoo`32
Ool000]oo`03001oogoo079oo`03001oogoo0<9oo`002Woo00<007ooOol0M7oo00<007ooOol0`Goo
000:Ool00`00Oomoo`1dOol00`00Oomoo`31Ool000Yoo`03001oogoo07Aoo`03001oogoo0<5oo`00
2Woo00<007ooOol0MGoo00<007ooOol0`7oo000:Ool00`00Oomoo`1eOol00`00Oomoo`30Ool000Yo
o`03001oogoo07Eoo`03001oogoo0<1oo`002Goo00<007ooOol0MWoo00<007ooOol0`7oo0009Ool0
0`00Oomoo`1fOol00`00Oomoo`30Ool000Uoo`03001oogoo07Ioo`03001oogoo0<1oo`002Goo00<0
07ooOol0Mgoo00<007ooOol0_goo0009Ool00`00Oomoo`1gOol00`00Oomoo`2oOol000Uoo`03001o
ogoo07Moo`03001oogoo0;moo`0027oo00<007ooOol0>Goo00<007ooOol01goo00<007ooOol0<Woo
00<007ooOol0YGoo0P0067oo0008Ool00`00Oomoo`0hOol00`00Oomoo`09Ool00`00Oomoo`0aOol0
0`00Oomoo`2UOol6000DOol000Qoo`03001oogoo02eoo`80009oo`8000Aoo`03001oogoo00Aoo`<0
00Aoo`03001oogoo031oo`03001oogoo0:Eoo`X0011oo`0027oo00<007ooOol0;Woo00@007ooOol0
00Eoo`03001oogoo00=oo`05001oogooOol00003Ool00`00Oomoo`0`Ool00`00Oomoo`2UOol>000<
Ool000Qoo`03001oogoo02moo`8000Ioo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo031o
okT000Uoo`0027oo00<007ooOol0;goo0P001Woo00<007ooOol00goo00<007ooOol01Goo00<007oo
Ool0<7oo00<007ooOol0YGoo3`002goo0008Ool00`00Oomoo`0^Ool01000Oomoo`001Goo00<007oo
Ool00goo00<007ooOol01Goo00<007ooOol0<7oo00<007ooOol0YGoo2`003goo0008Ool00`00Oomo
o`0]Ool20002Ool20004Ool00`00Oomoo`02Ool50004Ool00`00Oomoo`0`Ool00`00Oomoo`2UOol7
000COol000Qoo`03001oogoo03Qoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo035oo`03
001oogoo0:Eoo`<001Moo`0027oo00<007ooOol0>Goo00<007ooOol01goo00<007ooOol0<Woo00<0
07ooOol0_goo0009Ool00`00Oomoo`1gOol00`00Oomoo`1FOol20002Ool3001ROol000Uoo`03001o
ogoo07Ioo`03001oogoo05Qoo`04001oogoo001TOol000Uoo`03001oogoo07Ioo`03001oogoo05Qo
o`03001oo`0006Eoo`002Goo00<007ooOol0MWoo00<007ooOol0F7oo0`00IGoo0009Ool00`00Oomo
o`1fOol00`00Oomoo`1HOol01000Oomoo`00I7oo0009Ool00`00Oomoo`1fOol00`00Oomoo`1HOol0
0`00Ool00003001ROol000Yoo`03001oogoo07Eoo`03001oogoo05Qoo`03001oogoo06Eoo`002Woo
00<007ooOol0MGoo00<007ooOol0Egoo0P00Igoo000:Ool00`00Oomoo`1dOol00`00Oomoo`31Ool0
00Yoo`03001oogoo07Aoo`03001oogoo0<5oo`002Woo00<007ooOol0M7oo00<007ooOol0`Goo000;
Ool00`00Oomoo`1bOol00`00Oomoo`32Ool000]oo`03001oogoo079oo`03001oogoo0<9oo`002goo
00<007ooOol0LWoo00<007ooOol0`Woo000<Ool00`00Oomoo`1`Ool00`00Oomoo`33Ool000aoo`03
001oogoo071oo`03001oogoo0<=oo`0037oo00<007ooOol0L7oo00<007ooOol0`goo000=Ool00`00
Oomoo`1^Ool00`00Oomoo`34Ool000eoo`03001oogoo06ioo`03001oogoo0<Aoo`003Goo00<007oo
Ool0KWoo00<007ooOol0a7oo000>Ool00`00Oomoo`1/Ool00`00Oomoo`35Ool000ioo`03001oogoo
06aoo`03001oogoo0<Eoo`003goo00<007ooOol0JWoo00<007ooOol0aWoo000@Ool00`00Oomoo`1X
Ool00`00Oomoo`37Ool0011oo`03001oogoo06Qoo`03001oogoo0<Moo`004Goo00<007ooOol0IWoo
00<007ooOol0b7oo000AOol00`00Oomoo`1VOol00`00Oomoo`38Ool0019oo`03001oogoo06Aoo`03
001oogoo0<Uoo`004Woo00<007ooOol0I7oo00<007ooOol0bGoo000COol00`00Oomoo`1ROol00`00
Oomoo`3:Ool001Aoo`03001oogoo061oo`03001oogoo0<]oo`005Goo00<007ooOol0GWoo00<007oo
Ool0c7oo000FOol00`00Oomoo`1MOol00`00Oomoo`3<Ool001Ioo`03001oogoo05aoo`03001oogoo
0<eoo`005goo00<007ooOol0Fgoo00<007ooOol0cGoo000HOol00`00Oomoo`1IOol00`00Oomoo`3>
Ool001Uoo`03001oogoo05Moo`03001oogoo0<moo`006Woo00<007ooOol0E7oo0P00dWoo000KOol0
0`00Oomoo`1BOol00`00Oomoo`3BOol001aoo`03001oogoo051oo`03001oogoo0==oo`007Goo00<0
07ooOol0CWoo00<007ooOol0e7oo000NOol00`00Oomoo`1<Ool00`00Oomoo`3EOol001moo`03001o
ogoo04Yoo`03001oogoo0=Ioo`0087oo0P00B7oo0P00fGoo000ROol00`00Oomoo`14Ool00`00Oomo
o`3IOol002=oo`03001oogoo049oo`03001oogoo0=Yoo`0097oo0P00@7oo0P00gGoo000VOol2000l
Ool2003OOol002Qoo`8003Uoo`03001oogoo0=moo`00:Woo00<007ooOol0=7oo0P00hWoo000[Ool3
000`Ool3003TOol002ioo`<002Yoo`<00>Moo`00<Goo0`0097oo0`00jWoo000dOol3000NOol3003]
Ool003Moo`<001Qoo`<00?1oo`00>Woo6000lgoo003oOom6Ool00?moodIoo`00ogooAWoo0000\
\>"],
        ImageRangeCache->{{{92.625, 351.625}, {303.375, 
        200.625}} -> {-1.51992, 1.5252, 0.0102191, 0.0102191}}],
      TextAlignment->Center]], "NumberedFigure"],

Cell[TextData[{
  "Let ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " be the number of isotope present in a sample at time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  "  and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  " the number present at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ". The number of atoms decaying per unit of time is directly proportional \
present at time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", being  ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " the constant of proportionality. Then ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  " is given by the first order linear differential equation"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[DifferentialD]x\/\[DifferentialD]t = \ \(-\ 
          k\)\ x\ \((t)\)\)], "NumberedEquation"],

Cell[TextData[{
  "Eq.(2) can be evaluated using ",
  StyleBox["DSolve ", "DisplayMath",
    FontFamily->"Courier New"],
  "which gives the solution in analytical form. Initial conditions x",
  StyleBox["[0]", "MR"],
  " ",
  StyleBox["==", "MR"],
  " ",
  StyleBox["x0 ", "MR"],
  "can have been added."
}], "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"eq1", " ", "=", " ", 
      RowBox[{"DSolve", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], 
                "\[Equal]", \(\(-k\)\ x[t]\)}], ",", \(x[0] \[Equal] x0\)}], 
            "}"}], ",", \(x[t]\), ",", "t"}], "]"}]}]], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \({{x[t] \[Rule] \[ExponentialE]\^\(\(-k\)\ t\)\ x0}}\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell[TextData[{
  "If  we know the values of ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  ", for instant",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(k\  = \ 0.1\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(\ \)\)\_0 = \ 100\)]],
  " with apropiated units, we can replace them in the previous expression to \
obtain ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["%", "MR"],
  " gives the last result generated in the before output and ",
  StyleBox["expr",
    FontSlant->"Italic"],
  " /.  ",
  StyleBox["rules", "TI"],
  " gives a rule of replacement  to be applied on expression ",
  StyleBox["expr", "TI"],
  ". "
}], "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {k \[Rule] 0.1, \ x0 \[Rule] \ 100}\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \({{x[t] \[Rule] 100\ \[ExponentialE]\^\(\(-0.1`\)\ t\)}}\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell[TextData[{
  "In many occasions it is better build a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function where ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " are parameters. They can be replaced with their values when ever it is \
necessary."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x[\ t_, \ x0_, \ k_] = x[t] /. eq1[\([\)\(1\)\(]\)]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-k\)\ t\)\ x0\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell[TextData[{
  "Now we can replace k and x",
  Cell[BoxData[
      \(TraditionalForm\`\_0\)]],
  " with their values or ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(k\  = \ 0.1\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(\ \)\)\_0 = \ 100\)]],
  " "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x[t, 0.1, 100]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(0.1`\ \[ExponentialE]\^\(\(-100\)\ t\)\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples of exponential decay", "SubsubsectionIcon"],

Cell[TextData[{
  "Example 1.- Cobalt 60 is a radioactive isotope whose half-life is 5.3 \
year. It is used in medicine as a radiation source to kill cancer cells using \
gamma-emissions from cobalt 60. As it is radioactive its activity decreases \
with the time and the source must be changed periodically according to the \
expression above obtained ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\  = \ x\_0\ \[ExponentialE]\^\(\(-k\)\ t\)\)]],
  ", where",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(k\)\)\)]],
  " is called the disintegration constant or transformation constant."
}], "Text"],

Cell[TextData[{
  "We are interested in evaluate the disintegration constant of ",
  Cell[BoxData[
      \(TraditionalForm\`\^60\)]],
  "Co. A half-life (",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ") of 5.3 year means that the radioactivity decrease to the half every 5.3 \
year, this is: if the activity is ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(t\)\(\ \)\(=\)\(\ \)\(0\)\(\ \)\)\)]],
  "after  a time ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " the activity will be ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0/2\)]],
  ".  Therefore we can calculate ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " doing ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\  = \(x\_0/2\ \ and\ t = \ T\)\)]],
  "  in expression  ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\  = \ x\_0\ \[ExponentialE]\^\(\(-k\)\ t\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "We use the function",
  StyleBox[" x[t, x0, k] ", "DisplayMath"],
  "before defined"
}], "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq = \ Solve[\ x[\ T, \ x0, \ k]\  \[Equal] \ x0/2\ , \ k]\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    RowBox[{\(Solve::"ifun"\), \(\(:\)\(\ \)\), "\<\"Inverse functions are \
being used by \\!\\(Solve\\), so some solutions may not be found; use Reduce \
for complete solution information. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Solve::ifun\\\"]\\)\"\>"}]], \
"Message",
  CellLabel->"From In[12]:="],

Cell[BoxData[
    \({{k \[Rule] Log[2]\/T}}\)], "Output",
  CellLabel->"Out[12]="],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message",
  CellLabel->"From In[8]:=",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[TextData[{
  " ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " gives results in terms of inverse functions. In these cases it prints a \
warning message. We can suppress these warning messages"
}], "Caption"],

Cell[BoxData[
    \(Off[Solve::"\<ifun\>"]; Off[InverseFunction::"\<ifun\>"]; \)], "Input",
  CellLabel->"In[13]:=",
  CellTags->"Solve"],

Cell[TextData[{
  "This solution is applicable not only to the cobalt 60. It is a general \
relationship between ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  "."
}], "Text"],

Cell[TextData[{
  "We replace ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " with its solution. We call it ",
  StyleBox["TransConst ", "DisplayMath"],
  "in order to be used later. "
}], "Text"],

Cell["\<\
We use %%[[1]] to indicate to extract the result from two outputs before\
\>", "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TransConst\  = \ k /. %%[\([\)\(1\)\(]\)]\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \(Log[2]\/T\)], "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell[TextData[{
  "As ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " is 5.3 year for Cobalt 60, and calling k = kCo60 "
}], "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(kCo60\  = \ TransConst /. T \[Rule] 5.3\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \(0.1307824868981029`\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell[TextData[{
  "We can evaluate how the ",
  Cell[BoxData[
      \(TraditionalForm\`\^60\)]],
  "Co as function of time  decrease. So if we have 10 g of  ",
  Cell[BoxData[
      \(TraditionalForm\`\^60\)]],
  "Co in ",
  Cell[BoxData[
      \(TraditionalForm\`t\  = \ 0\)]],
  ", it will decrease as it follows."
}], "Text"],

Cell["\<\
We replace x0 with its value and using Plot we represent the evolution of \
Cobalt 60 in the time.\
\>", "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[x[t, 10, kCo60], \ {t, 0, 20}]\)], "Input",
  CellLabel->"In[16]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.0147151 0.0588604 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .13244 -6 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -6 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -6 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -6 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -12 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(10)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(15)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(20)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(10)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.06244 .54406 L
.10458 .48622 L
.14415 .43766 L
.18221 .39569 L
.22272 .35557 L
.26171 .32096 L
.30316 .28801 L
.34309 .25962 L
.3815 .2351 L
.42237 .2117 L
.46172 .19152 L
.49955 .17407 L
.53984 .15738 L
.57861 .14297 L
.61984 .12924 L
.65954 .11741 L
.69774 .10718 L
.73838 .09742 L
.77751 .08899 L
.81909 .08097 L
.85916 .07407 L
.89771 .06811 L
.93871 .06242 L
.97619 .05775 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[16]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00DP3oool2000003X0oooo1@0000020?ooo`800000>03oool500000080oooo0P00000h0?oo
o`@000000`3oool2000000L0oooo001A0?ooo`040000003oool0oooo000003/0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo03L0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000060?ooo`00E03oool00`000000oooo0?ooo`0i0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000H0oooo001B0?ooo`800000
?03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`020?ooo`800000>P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0103oool00580oooo00<000000?ooo`3oool0>`3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
03L0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`00DP3oool3
000003X0oooo0P0000040?ooo`800000>@3oool2000000@0oooo0`00000h0?ooo`800000103oool2
000000L0oooo003o0?ooob40oooo000B0?ooo`030000003oool0oooo0?l0oooo303oool00180oooo
00<000000?ooo`3oool0o`3oool<0?ooo`004P3oool00`000000oooo0?ooo`3o0?ooo``0oooo000B
0?ooo`030000003oool0oooo0?l0oooo303oool000`0ooooo`00000A000000@0oooo000B0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`00
4P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00P0oooo000B0?ooo`030000003o
ool0oooo0?l0oooo303oool00180oooo00<000000?ooo`3oool0o`3oool<0?ooo`004P3oool00`00
0000oooo0?ooo`3o0?ooo``0oooo000B0?ooo`030000003oool0oooo0?l0oooo303oool00180oooo
00<000000?ooo`3oool0o`3oool<0?ooo`004P3oool200000?l0oooo3@3oool00180oooo00<00000
0?ooo`3oool0o`3oool<0?ooo`004P3oool00`000000oooo0?ooo`3o0?ooo``0oooo000B0?ooo`03
0000003oool0oooo0?l0oooo303oool00180oooo00<000000?ooo`3oool0o03oool5000000X0oooo
000B0?ooo`030000003oool0oooo0?40oooo2`00000?0?ooo`004P3oool00`000000oooo0?ooo`3Y
0?ooo`P000006P3oool00180oooo00<000000?ooo`3oool0h`3oool600000280oooo000B0?ooo`80
0000g`3oool5000002P0oooo000B0?ooo`030000003oool0oooo0=P0oooo1P00000]0?ooo`004P3o
ool00`000000oooo0?ooo`3C0?ooo`D00000<`3oool00180oooo00<000000?ooo`3oool0c@3oool6
000003P0oooo000B0?ooo`030000003oool0oooo0<P0oooo1@00000n0?ooo`004P3oool00`000000
oooo0?ooo`320?ooo`H00000@`3oool00180oooo00<000000?ooo`3oool0_P3oool4000004T0oooo
000B0?ooo`030000003oool0oooo0;X0oooo1000001=0?ooo`004P3oool200000;L0oooo1000001A
0?ooo`004P3oool00`000000oooo0?ooo`2c0?ooo`<00000E@3oool00180oooo00<000000?ooo`3o
ool0/03oool3000005P0oooo000B0?ooo`030000003oool0oooo0:`0oooo1000001K0?ooo`004P3o
ool00`000000oooo0?ooo`2Y0?ooo`<00000G`3oool00180oooo00<000000?ooo`3oool0Y@3oool4
00000680oooo000:0?ooo`@00000103oool00`000000oooo0?ooo`2Q0?ooo`@00000IP3oool000X0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2N0?ooo`<00000JP3oool000/0oooo
00<000000?ooo`3oool0103oool3000009/0oooo0`00001]0?ooo`00303oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo09T0oooo0P00001`0?ooo`002P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo09H0oooo0`00001b0?ooo`002`3oool2000000D0oooo00<00000
0?ooo`3oool0T`3oool3000007D0oooo000B0?ooo`030000003oool0oooo0900oooo0`00001h0?oo
o`004P3oool00`000000oooo0?ooo`2>0?ooo`800000N`3oool00180oooo00<000000?ooo`3oool0
R`3oool3000007d0oooo000B0?ooo`030000003oool0oooo08P0oooo0`0000200?ooo`004P3oool2
000008H0oooo0`0000230?ooo`004P3oool00`000000oooo0?ooo`230?ooo`800000QP3oool00180
oooo00<000000?ooo`3oool0P03oool3000008P0oooo000B0?ooo`030000003oool0oooo07h0oooo
0P00002;0?ooo`004P3oool00`000000oooo0?ooo`1l0?ooo`800000S@3oool00180oooo00<00000
0?ooo`3oool0NP3oool2000008l0oooo000B0?ooo`030000003oool0oooo07P0oooo0P00002A0?oo
o`004P3oool00`000000oooo0?ooo`1f0?ooo`800000T`3oool00180oooo0P00001e0?ooo`800000
U@3oool00180oooo00<000000?ooo`3oool0LP3oool2000009L0oooo000B0?ooo`030000003oool0
oooo0700oooo0P00002I0?ooo`004P3oool00`000000oooo0?ooo`1^0?ooo`800000V`3oool00180
oooo00<000000?ooo`3oool0K03oool2000009d0oooo000B0?ooo`030000003oool0oooo06X0oooo
0P00002O0?ooo`004P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo09l0oooo000B
0?ooo`030000003oool0oooo06L0oooo0P00002R0?ooo`004P3oool2000006H0oooo0P00002T0?oo
o`004P3oool00`000000oooo0?ooo`1S0?ooo`800000YP3oool00180oooo00<000000?ooo`3oool0
H@3oool200000:P0oooo000B0?ooo`030000003oool0oooo05l0oooo0P00002Z0?ooo`004P3oool0
0`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0:X0oooo000B0?ooo`030000003oool0oooo
05`0oooo0P00002]0?ooo`00303oool3000000<0oooo00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`2]0?ooo`003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool0[P3oool000X0oooo1@0000030?ooo`<00000F03oool200000;40oooo000:
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`2a0?ooo`002`3oool00`000000oooo000000040?ooo`030000003oool0oooo05D0oooo0P00002d
0?ooo`00303oool2000000@0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2d0?oo
o`004P3oool00`000000oooo0?ooo`1B0?ooo`800000]`3oool00180oooo00<000000?ooo`3oool0
D@3oool00`000000oooo0?ooo`2g0?ooo`004P3oool00`000000oooo0?ooo`1?0?ooo`800000^P3o
ool00180oooo00<000000?ooo`3oool0C@3oool200000;`0oooo000B0?ooo`800000C@3oool00`00
0000oooo0?ooo`2l0?ooo`004P3oool00`000000oooo0?ooo`1:0?ooo`800000_`3oool00180oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`2o0?ooo`004P3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo0<00oooo000B0?ooo`030000003oool0oooo04H0oooo0P000033
0?ooo`004P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0<<0oooo000B0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool0a03oool00180oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`350?ooo`004P3oool2000004<0oooo00<000000?ooo`3oool0aP3o
ool00180oooo00<000000?ooo`3oool0@03oool200000<T0oooo000B0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool0b@3oool00180oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`3:0?ooo`004P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0</0oooo
000B0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0c03oool00180oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`3=0?ooo`004P3oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo0<h0oooo000B0?ooo`800000>@3oool200000=40oooo000B0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool0d@3oool00180oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`3B0?ooo`004P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo0=<0oooo000B0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0e03oool00180
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`3E0?ooo`002P3oool3000000D0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`3F0?ooo`002P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0e`3oool000X0oooo00@0
00000?ooo`3oool00000103oool300000300oooo00<000000?ooo`3oool0f03oool000X0oooo0`00
00050?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0f@3oool000/0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0=X0oooo000;0?oo
o`<00000103oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0=/0oooo000B0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0g03oool00180oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`3M0?ooo`004P3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo0=h0oooo000B0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0g`3oool0
0180oooo0P00000Y0?ooo`030000003oool0oooo0>00oooo000B0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0h@3oool00180oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`3R0?ooo`004P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0><0oooo000B
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0i03oool00180oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`3U0?ooo`004P3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0>D0oooo000B0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
iP3oool00180oooo0P00000R0?ooo`030000003oool0oooo0>L0oooo000B0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0j03oool00180oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`3Y0?ooo`004P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0>X0
oooo000B0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0j`3oool00180oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`3/0?ooo`004P3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo0>d0oooo000B0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0k@3oool00180oooo0P00000K0?ooo`030000003oool0oooo0>h0oooo000B0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0k`3oool00180oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`3`0?ooo`004P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo0?40oooo000B0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0lP3oool00180
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3b0?ooo`002`3oool2000000D0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3c0?ooo`002P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0m03oool000X0oooo00@0
00000?ooo`3oool00000103oool3000001<0oooo00<000000?ooo`3oool0m@3oool000/0oooo0P00
00050?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0mP3oool000X0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?L0oooo000;
0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?L0oooo000B0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0n03oool00180oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`3i0?ooo`004P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0?X0oooo000B0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0nP3o
ool00180oooo0P00000>0?ooo`030000003oool0oooo0?/0oooo000B0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0o03oool00180oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`3m0?ooo`004P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?d0oooo
000B0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0oP3oool00180oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooo`004P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0?l0oooo0@3oool00180oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`3o0?ooo`40oooo000B0?ooo`800000203oool00`000000oooo0?ooo`3o0?ooo`80oooo
000B0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3oool30?ooo`004P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo0`3oool00180oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000B0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0o`3oool50?ooo`004P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0?l0oooo1@3oool00180oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`3o0?ooo`H0oooo000B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool6
0?ooo`004P3oool2000000<0oooo00<000000?ooo`3oool0o`3oool70?ooo`004P3oool01@000000
oooo0?ooo`3oool000000?l0oooo2P3oool00180oooo00D000000?ooo`3oool0oooo0000003o0?oo
o`X0oooo000B0?ooo`040000003oool0oooo00000?l0oooo2`3oool00180oooo00<000000?ooo`00
0000o`3oool<0?ooo`004P3oool00`000000oooo0000003o0?ooo``0oooo00040?ooo`D000000P3o
ool2000000D0oooo0P00003o0?ooo`d0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`020?ooo`800000o`3oool=0?ooo`001P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00P3oool300000?l0oooo303oool000H0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3o
ool<0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`3o0?ooo``0oooo00050?ooo`800000103oool2000000D0oooo00<00000
0?ooo`3oool0o`3oool<0?ooo`004P3oool00`000000oooo0?ooo`3o0?ooo``0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.428, -0.7747, 0.0772359, \
0.0624851}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[16]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example of iodine ", "SubsubsectionIcon"],

Cell["\<\
5 MBq of I-131 (Half-life 8.07 days) is needed for a diagnostic test.They are \
3 days between shipment of radioiodine and its use in the test.How many MBq \
must be shipped?\
\>", "Text"],

Cell[TextData[{
  "The equation to resolve is ",
  Cell[BoxData[
      \(TraditionalForm\`x\  = \ x\_0\ \[ExponentialE]\^\(\(-k\)\ t\)\)]],
  " where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["x",
            "TraditionalForm"], " ", "=", " ", "5"}], TraditionalForm]]],
  " MBq and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(t\)\(\ \)\(=\)\(\ \)\(3\)\(\ \)\)\)]],
  "days, ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " is de transformation constant of I-131 and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  " is the variable to be calculated."
}], "Text"],

Cell["The transformation constant of I-131 is ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(kI131\  = TransConst /. T \[Rule] 8.07\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \(0.08589184393555703`\)], "Output",
  CellLabel->"Out[17]="]
}, Open  ]],

Cell[TextData[{
  "We replace",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(t\)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " with their values. "
}], "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(Solve[\ x[\ 3\ , \ x0, kI131\ ]\  \[Equal] \ \ 5\ , \ 
      x0]\)\)\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \({{x0 \[Rule] 6.469594574862883`}}\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell["Therefore should be shipped 6.47 MBq ", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example of irradiation of a cell population", "SubsubsectionIcon"],

Cell[TextData[{
  "In a experiment where a cell population is irradiated the survival of \
cells is given by eq.(1) with ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " = 1 ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["days",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  ", and we are interested in calculating ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " for a specific value ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  " = 20% of initial population ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "We use ",
  StyleBox["Solve", "Input",
    FontFamily->"Courier New",
    FontWeight->"Plain"],
  StyleBox[" ",
    FontFamily->"Courier New"],
  "to obtain ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ". We can use the units as ",
  Cell[BoxData[
      \(TraditionalForm\`days\^\(-1\)\)]],
  ". \"%\" indicating that % is a symbol and not the ",
  StyleBox["Math",
    FontSlant->"Italic"],
  " instruction %  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[x[t, 100 "\<%\>", 1\ days\^\(-1\)] \[Equal] \ 20 "\<%\>", t] // 
      N\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \({{t \[Rule] 1.6094379124341003`\ days}}\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Isolated organ", "SubsubsectionIcon"],

Cell[TextData[{
  "The following figure represents an isolated organ of constant volume with \
a liquid, with a dissolved drug,  flowing through the organ with a constant \
inflow and outflow rates ",
  StyleBox["v.",
    FontSlant->"Italic"],
  " "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.125 0.238095 [
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125  moveto 0 0 lineto 
-0.05 -0.0125  lineto stroke
} ifelse
grestore
} def
/MAarrowhead2 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .125 .11905 0 365.73 arc
s
.02381 .125 m
.38095 .125 L
s
% Start of user PostScript
0 0 1.5 0 MAarrowhead1
% End of user PostScript
gsave
.20238 .125 -72.375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
75.750 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
81.750 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.61905 .125 m
.97619 .125 L
s
% Start of user PostScript
2.5 0 4. 0 MAarrowhead2
% End of user PostScript
gsave
.5 .125 -75 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 12.750 moveto
(H) show
75.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 12.750 moveto
(L) show
87.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.79762 .125 -72.375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
75.750 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
81.750 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{288, 72},
  ImageMargins->{{0.75, 0}, {0, 0.5}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000FQ000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00[7oo3`00[Goo002XOol4000?Ool5002XOol00:Ioo`8001Qoo`800:Ioo`00XWoo
100077oo0`00Xgoo002POol2000SOol2002QOol009ioo`8002Moo`8009moo`00W7oo0P00:goo0P00
WGoo002KOol00`00Oomoo`0]Ool00`00Oomoo`2JOol009Yoo`03001oogoo02moo`03001oogoo09Uo
o`00VGoo00<007ooOol0<Goo00<007ooOol0V7oo002GOol2000eOol2002HOol009Ioo`03001oogoo
03Moo`03001oogoo09Eoo`00UGoo00<007ooOol0>Goo00<007ooOol0U7oo002DOol00`00Oomoo`0k
Ool00`00Oomoo`2COol009=oo`03001oogoo03eoo`03001oogoo099oo`00Tgoo00<007ooOol0?Goo
00<007ooOol0TWoo002AOol20011Ool2002BOol0091oo`03001oogoo04=oo`03001oogoo08moo`00
T7oo00<007ooOol0@goo00<007ooOol0Sgoo002?Ool00`00Oomoo`15Ool00`00Oomoo`2>Ool008mo
o`03001oogoo04Eoo`03001oogoo08ioo`00SWoo00<007ooOol0Agoo00<007ooOol0SGoo002>Ool0
0`00Oomoo`17Ool00`00Oomoo`2=Ool008eoo`03001oogoo04Uoo`03001oogoo08aoo`00SGoo00<0
07ooOol0BGoo00<007ooOol0S7oo002<Ool00`00Oomoo`1;Ool00`00Oomoo`2;Ool008aoo`03001o
ogoo04]oo`03001oogoo08]oo`00Rgoo00<007ooOol0CGoo00<007ooOol0RWoo002;Ool00`00Oomo
o`1=Ool00`00Oomoo`2:Ool008]oo`03001oogoo04ioo`03001oogoo08Uoo`00Rgoo00<007ooOol0
CWoo00<007ooOol0RGoo002:Ool00`00Oomoo`1?Ool00`00Oomoo`29Ool008Yoo`03001oogoo04mo
o`03001oogoo08Uoo`00RGoo00<007ooOol0DGoo00<007ooOol0R7oo0029Ool00`00Oomoo`1AOol0
0`00Oomoo`28Ool008Uoo`03001oogoo055oo`03001oogoo08Qoo`00RGoo00<007ooOol0DGoo00<0
07ooOol0R7oo0029Ool00`00Oomoo`1AOol00`00Oomoo`28Ool007Moo`<000moo`03001oogoo02Io
o`03001oogoo00Moo`03001oogoo01ioo`03001oogoo06]oo`<001Yoo`00NWoo10002goo00<007oo
Ool09Goo00<007ooOol02Goo00<007ooOol07Goo00<007ooOol0Jgoo1`005Woo001nOol50006Ool0
0`00Oomoo`0JOol40006Ool00`00Oomoo`03Ool30005Ool00`00Oomoo`0LOol00`00Oomoo`1[Ool<
000AOol008=oo`@0009oo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
009oo`05001oogooOol00004Ool00`00Oomoo`0LOol00`00Oomoo`1[Ool@000=Ool000Uooh4001]o
o`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo01aooh4000Yoo`00Pgoo
10000Woo00<007ooOol06Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol01Woo00<007oo
Ool077oo00<007ooOol0Jgoo40003Goo001nOol50006Ool00`00Oomoo`0IOol01000Oomoogoo0P00
1Goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol077oo00<007ooOol0Jgoo30004Goo001j
Ool4000;Ool00`00Oomoo`0JOol300000goo001oo`04Ool01000Oomoogoo1@001Goo00<007ooOol0
77oo00<007ooOol0Jgoo1`005Woo001gOol3000?Ool00`00Oomoo`0UOol01@00Oomoogoo00001goo
00<007ooOol07Goo00<007ooOol0Jgoo0`006Woo0029Ool00`00Oomoo`0VOol00`00Oomoo`07Ool0
0`00Oomoo`0NOol00`00Oomoo`28Ool0041oo`8000]oo`800004Ool00000000fOol00`00Oomoo`1A
Ool00`00Oomoo`0dOol2000=Ool40011Ool0041oo`8000aoo`8000=oo`03001oogoo03=oo`03001o
ogoo055oo`03001oogoo03Aoo`8000aoo`03001oogoo009oo`03001oogoo03ioo`00?goo00@007oo
Ool000]oo`03001oogoo009oo`03001oogoo03=oo`03001oogoo055oo`03001oogoo03=oo`04001o
ogoo000;Ool00`00Oomoo`13Ool003moo`04001oogoo000;Ool00`00Oomoo`02Ool00`00Oomoo`0d
Ool00`00Oomoo`1?Ool00`00Oomoo`0dOol01000Oomoo`002goo00<007ooOol0@goo000nOol00`00
Oomoo`02Ool00`00Oomoo`08Ool20003Ool00`00Oomoo`0dOol00`00Oomoo`1?Ool00`00Oomoo`0c
Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01000Oomoogoo0P00@7oo000mOol30002Ool30009Ool0
0`00Ool00002000hOol00`00Oomoo`1>Ool00`00Oomoo`0bOol30002Ool3000:Ool300000goo001o
o`0oOol004ioo`03001oogoo03Yoo`03001oogoo04ioo`03001oogoo08Uoo`00CGoo0P00?7oo00<0
07ooOol0CGoo00<007ooOol0RWoo002;Ool00`00Oomoo`1=Ool00`00Oomoo`2:Ool008aoo`03001o
ogoo04]oo`03001oogoo08]oo`00S7oo00<007ooOol0Bgoo00<007ooOol0Rgoo002=Ool00`00Oomo
o`19Ool00`00Oomoo`2<Ool008eoo`03001oogoo04Uoo`03001oogoo08aoo`00SWoo00<007ooOol0
Agoo00<007ooOol0SGoo002>Ool00`00Oomoo`17Ool00`00Oomoo`2=Ool008moo`03001oogoo04Eo
o`03001oogoo08ioo`00Sgoo00<007ooOol0AGoo00<007ooOol0SWoo002@Ool00`00Oomoo`13Ool0
0`00Oomoo`2?Ool0091oo`03001oogoo04=oo`03001oogoo08moo`00TGoo00<007ooOol0@Goo00<0
07ooOol0T7oo002AOol00`00Oomoo`11Ool00`00Oomoo`2@Ool0099oo`8003moo`8009=oo`00U7oo
00<007ooOol0>goo00<007ooOol0Tgoo002DOol00`00Oomoo`0kOol00`00Oomoo`2COol009Eoo`03
001oogoo03Uoo`03001oogoo09Aoo`00UWoo00<007ooOol0=goo00<007ooOol0UGoo002GOol00`00
Oomoo`0eOol00`00Oomoo`2FOol009Qoo`8003=oo`8009Uoo`00VWoo00<007ooOol0;goo00<007oo
Ool0VGoo002KOol00`00Oomoo`0]Ool00`00Oomoo`2JOol009aoo`03001oogoo02]oo`03001oogoo
09]oo`00WGoo0P00:Goo0P00WWoo002OOol2000UOol2002POol00:5oo`@001eoo`@00:9oo`00YGoo
0P006Goo0P00YWoo002WOol4000AOol4002XOol00:]ooa400:aoo`00ogooJGoo003oOomYOol00001
\
\>"],
  ImageRangeCache->{{{128.375, 415.375}, {547.125, 476.125}} -> {-2.02073, \
6.51636, 0.0147889, 0.0147889}}],

Cell[TextData[{
  "Let ",
  Cell[BoxData[
      \(TraditionalForm\`c(t)\)]],
  " be concentration of the a drug in the organ. Let",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(b(t)\)\)\)]],
  " be the drug concentration in the liquid flowing into the organ. We assume \
a uniform and instantaneous mixing in the organ. The liquid enters with a ",
  StyleBox["v",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(b(t)\)\)\)]],
  "  rate and leave with a ",
  Cell[BoxData[
      \(TraditionalForm\`v\ x\)]],
  " rate.  We can describe the process as follows: In the instant t the \
concentration is ",
  Cell[BoxData[
      \(TraditionalForm\`c(t)\)]],
  ", a later instant dt the variation of concentration in the organ will be: \
",
  Cell[BoxData[
      FormBox[
        RowBox[{"c", "+", " ", 
          StyleBox["dc",
            FontSlant->"Italic"], " "}], TraditionalForm]]],
  Cell[BoxData[
      \(TraditionalForm\`\ \)]],
  " =  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"V", " ", 
          FormBox["c",
            "TraditionalForm"]}], TraditionalForm]]],
  " (drug in the organ in t) +",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"c", " ", "v", " ", 
            StyleBox["dt",
              FontSlant->"Italic"]}]}], TraditionalForm]]],
  " (drug flowing organ) - ",
  Cell[BoxData[
      FormBox[
        RowBox[{"q", " ", "v", " ", 
          StyleBox["dt",
            FontSlant->"Italic"]}], TraditionalForm]]],
  " (drug outflowing of the organ). Hence "
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\ \)\(V\ \ c' \((t)\) = \ \[Nu][
        b(t) - c(t)]\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "Let's consider the case for which the flowing concentration ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(b(t)\),
            "TraditionalForm"], " ", "=", " ", "b"}], TraditionalForm]]],
  " constant for and interval ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", "<", 
          FormBox[\(t < T\),
            "TraditionalForm"]}], TraditionalForm]]],
  " , and  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(b(t)\),
            "TraditionalForm"], " ", "=", "0"}], TraditionalForm]]],
  " since  ",
  Cell[BoxData[
      \(TraditionalForm\`t > T\)]],
  ",   "
}], "Text"],

Cell[BoxData[
    \(eq2\  = \ V\ \ \(c'\)[t] == \ \[Nu] \((b - c[t])\); \)], "Input",
  CellLabel->"In[20]:="],

Cell[TextData[{
  "Let ",
  Cell[BoxData[
      \(TraditionalForm\`c(0)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`c\_0\)]],
  " be the concentration drug in the organ at ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["t",
            "TraditionalForm"], " ", "=", " ", "0"}], TraditionalForm]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[{eq2, \ c[0] \[Equal] c0}, \ c[t], \ t]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \({{c[
            t] \[Rule] \[ExponentialE]\^\(-\(\(t\ \[Nu]\)\/V\)\)\ \((\(-b\) + 
                c0 + b\ \[ExponentialE]\^\(\(t\ \[Nu]\)\/V\))\)}}\)], "Output",\

  CellLabel->"Out[21]="]
}, Open  ]],

Cell["We simplify c(t) and define  c1[t] in order to be used later", "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(c1[t_] = c[t] /. \(FullSimplify[%]\)[\([\)\(1\)\(]\)]\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \(b + \((\(-b\) + 
            c0)\)\ \[ExponentialE]\^\(-\(\(t\ \[Nu]\)\/V\)\)\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell[TextData[{
  "If we know ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`c\_0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(b\)\(,\)\)\)]],
  " we can replace them with their values in the above function, even plot \
the evolution of c(t). As example  we suppose that ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  " = 5 L, ",
  Cell[BoxData[
      \(TraditionalForm\`c\_0\)]],
  " = 0, \[Nu] = 0.2 L/s, ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " = 5 g/L"
}], "Text"],

Cell[TextData[{
  "We plot ",
  Cell[BoxData[
      \(TraditionalForm\`c(t)\)]],
  ". We also use",
  StyleBox[" Timing", "InlineInput"],
  StyleBox[" ", "DisplayMath"],
  "that gives the time used in the computation."
}], "Caption"],

Cell[TextData[{
  "Using ",
  StyleBox["Evaluate", "InlineInput"],
  " the time of computation is reduced, but cannot always we can apply this \
criterion (see apart. 1.9.1 of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Book)."
}], "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[
        Evaluate\ [
          c1[t] /. {V \[Rule] 5, \ c0 \[Rule] 0, \ \[Nu] \[Rule] \ 0.2, \ 
              b \[Rule] 5}], \ {t, 0, 100}] // Timing\)], "Input",
  CellLabel->"In[23]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0147151 0.119917 [
[.21429 .00222 -6 -9 ]
[.21429 .00222 6 0 ]
[.40476 .00222 -6 -9 ]
[.40476 .00222 6 0 ]
[.59524 .00222 -6 -9 ]
[.59524 .00222 6 0 ]
[.78571 .00222 -6 -9 ]
[.78571 .00222 6 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .13463 -6 -4.5 ]
[.01131 .13463 0 4.5 ]
[.01131 .25455 -6 -4.5 ]
[.01131 .25455 0 4.5 ]
[.01131 .37447 -6 -4.5 ]
[.01131 .37447 0 4.5 ]
[.01131 .49438 -6 -4.5 ]
[.01131 .49438 0 4.5 ]
[.01131 .6143 -6 -4.5 ]
[.01131 .6143 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(20)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(40)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(60)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(80)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(100)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13463 m
.03006 .13463 L
s
[(1)] .01131 .13463 1 0 Mshowa
.02381 .25455 m
.03006 .25455 L
s
[(2)] .01131 .25455 1 0 Mshowa
.02381 .37447 m
.03006 .37447 L
s
[(3)] .01131 .37447 1 0 Mshowa
.02381 .49438 m
.03006 .49438 L
s
[(4)] .01131 .49438 1 0 Mshowa
.02381 .6143 m
.03006 .6143 L
s
[(5)] .01131 .6143 1 0 Mshowa
.125 Mabswid
.02381 .0387 m
.02756 .0387 L
s
.02381 .06268 m
.02756 .06268 L
s
.02381 .08667 m
.02756 .08667 L
s
.02381 .11065 m
.02756 .11065 L
s
.02381 .15862 m
.02756 .15862 L
s
.02381 .1826 m
.02756 .1826 L
s
.02381 .20658 m
.02756 .20658 L
s
.02381 .23057 m
.02756 .23057 L
s
.02381 .27853 m
.02756 .27853 L
s
.02381 .30252 m
.02756 .30252 L
s
.02381 .3265 m
.02756 .3265 L
s
.02381 .35048 m
.02756 .35048 L
s
.02381 .39845 m
.02756 .39845 L
s
.02381 .42243 m
.02756 .42243 L
s
.02381 .44642 m
.02756 .44642 L
s
.02381 .4704 m
.02756 .4704 L
s
.02381 .51837 m
.02756 .51837 L
s
.02381 .54235 m
.02756 .54235 L
s
.02381 .56633 m
.02756 .56633 L
s
.02381 .59032 m
.02756 .59032 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .10453 L
.10458 .18721 L
.14415 .25261 L
.18221 .30603 L
.22272 .35426 L
.26171 .39354 L
.30316 .42881 L
.34309 .45745 L
.3815 .48082 L
.42237 .50187 L
.46172 .519 L
.49955 .533 L
.53984 .54566 L
.57861 .55597 L
.61984 .56525 L
.65954 .57278 L
.69774 .57893 L
.73838 .58449 L
.77751 .589 L
.81909 .59306 L
.85916 .59635 L
.89771 .59903 L
.93871 .60145 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[23]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00?P3oool4000000<0oooo0P00000/0?ooo`<000000P3oool2000002X0oooo0`0000040?oo
o`800000:P3oool2000000@0oooo0P00000W0?ooo`D000000P3oool2000000@0oooo0P00000;0?oo
o`00?P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000002`0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0W0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000:03oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
02P0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0203oool003l0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
000Y0?ooo`D0000000D0oooo0000003oool0oooo0000000Y0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000:03oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000002P0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0203oool00400oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo02L0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000Y
0?ooo`<000000`3oool010000000oooo0?ooo`00000Y0?ooo`8000000`3oool010000000oooo0?oo
o`00000X0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00P0oooo000n0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000:P3oool00`000000oooo000000020?ooo`040000003oool0oooo000002X0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000X0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000:03oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`080?ooo`00?`3oool2000000@0oooo0P00000/
0?ooo`8000000`3oool2000002/0oooo0`0000030?ooo`800000:P3oool2000000@0oooo0P00000X
0?ooo`800000103oool2000000@0oooo0P00000;0?ooo`00o`3ooolQ0?ooo`00403oool00`000000
oooo0?ooo`3o0?ooo`h0oooo000@0?ooo`030000003oool0oooo0?l0oooo3P3oool00100oooo00<0
00000?ooo`3oool0o`3oool>0?ooo`00403oool00`000000oooo0?ooo`3o0?ooo`h0oooo000:0?oo
ool000003@00000:0?ooo`00403oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool03`3oool00100oooo0P00000a0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool03`3oool00100oooo0P00003o0?ooo`l0oooo000@0?ooo`030000003oool0
00000?l0oooo3P3oool00100oooo00<000000?ooo`000000o`3oool>0?ooo`00403oool300000?l0
oooo3P3oool00100oooo00@000000?ooo`3oool00000o`3oool=0?ooo`00403oool010000000oooo
0?ooo`00003o0?ooo`d0oooo000@0?ooo`050000003oool0oooo0?ooo`000000o`3oool<0?ooo`00
403oool01@000000oooo0?ooo`3oool000000?l0oooo303oool00100oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000@0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0o`3oool90?ooo`00403oool2000000<0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`00403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo203oool00100
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`P0oooo000@0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0o`3oool70?ooo`00403oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0?l0oooo1`3oool00100oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3o0?ooo`L0oooo000@0?ooo`8000001P3oool00`000000oooo0?ooo`3o0?oo
o`H0oooo000@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3oool60?ooo`00
403oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo1@3oool00100oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooo`D0oooo000@0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0o`3oool40?ooo`00403oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0?l0oooo103oool00100oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`3o0?ooo`<0oooo000@0?ooo`8000002@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo
000@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3oool20?ooo`00403oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo0P3oool00100oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`3o0?ooo`40oooo00080?ooo`D000000`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo0@3oool000X0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo000:0?ooo`030000003o
ool0oooo00<0oooo0`00000;0?ooo`030000003oool0oooo0?l0oooo000:0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3n0?ooo`002P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0oP3oool000T0
oooo0P0000050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o@3oool00100oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3l0?ooo`00403oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0?`0oooo000@0?ooo`800000403oool00`000000oooo0?ooo`3k
0?ooo`00403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?/0oooo000@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0nP3oool00100oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`3j0?ooo`00403oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0?T0oooo000@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0n@3oool0
0100oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3h0?ooo`00403oool2000001<0
oooo00<000000?ooo`3oool0n03oool00100oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`3g0?ooo`00403oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?H0oooo000@
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0mP3oool00100oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`3e0?ooo`00403oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo0?D0oooo000@0?ooo`8000005`3oool00`000000oooo0?ooo`3d0?ooo`00403o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0?<0oooo000@0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0l`3oool00100oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`3b0?ooo`00403oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0?80
oooo000@0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0l@3oool00100oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`3a0?ooo`00403oool2000001/0oooo00<00000
0?ooo`3oool0l03oool00100oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`3_0?oo
o`00403oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0>l0oooo000@0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0kP3oool000P0oooo100000040?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0kP3oool000P0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0>d0oooo00090?ooo`030000003oool0oooo
00@0oooo0`00000N0?ooo`030000003oool0oooo0>`0oooo000:0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3/0?ooo`00203oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0j`3oool000T0oooo
0P0000050?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0jP3oool00100oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`3Z0?ooo`00403oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo0>T0oooo000@0?ooo`8000008`3oool00`000000oooo0?ooo`3X0?oo
o`00403oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0>P0oooo000@0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0i`3oool00100oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`3V0?ooo`00403oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo0>H0oooo000@0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0i@3oool00100
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3T0?ooo`00403oool2000002L0oooo
00<000000?ooo`3oool0i03oool00100oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`3S0?ooo`00403oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0>80oooo000@0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0h@3oool00100oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`3P0?ooo`00403oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo0>00oooo000@0?ooo`800000;03oool00`000000oooo0?ooo`3O0?ooo`00403oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0=h0oooo000@0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0g@3oool00100oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`3L0?ooo`00403oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0=/0oooo
000@0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0f`3oool00100oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`3J0?ooo`00403oool200000380oooo00<000000?oo
o`3oool0f@3oool00100oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`3H0?ooo`00
403oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0=L0oooo000@0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0eP3oool000T0oooo0P0000050?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool0e@3oool000P0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0=@0oooo000:0?ooo`030000003oool0oooo
00<0oooo0`00000g0?ooo`800000e03oool000/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo0=40oooo00080?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`3@0?ooo`002@3oool2000000D0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3?0?ooo`00403oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo0<h0oooo000@0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0c@3oool00100oooo0P00000o0?ooo`030000003oool0oooo0<`0oooo000@0?ooo`03
0000003oool0oooo03l0oooo0P00003<0?ooo`00403oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo0<T0oooo000@0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0b03o
ool00100oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`370?ooo`00403oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo0<H0oooo000@0?ooo`030000003oool0oooo04D0
oooo0P0000360?ooo`00403oool2000004P0oooo00<000000?ooo`3oool0``3oool00100oooo00<0
00000?ooo`3oool0B03oool00`000000oooo0?ooo`320?ooo`00403oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo0<40oooo000@0?ooo`030000003oool0oooo04X0oooo0P0000310?oo
o`00403oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0;h0oooo000@0?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool0_@3oool00100oooo0P00001?0?ooo`030000003o
ool0oooo0;`0oooo000@0?ooo`030000003oool0oooo04l0oooo0P00002l0?ooo`00403oool00`00
0000oooo0?ooo`1A0?ooo`030000003oool0oooo0;T0oooo000@0?ooo`030000003oool0oooo0580
oooo00<000000?ooo`3oool0^03oool00100oooo00<000000?ooo`3oool0D`3oool200000;P0oooo
000@0?ooo`030000003oool0oooo05D0oooo0P00002f0?ooo`00403oool00`000000oooo0?ooo`1G
0?ooo`800000]03oool00100oooo0P00001J0?ooo`800000/P3oool00100oooo00<000000?ooo`3o
ool0F`3oool200000;00oooo000@0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0
[@3oool00100oooo00<000000?ooo`3oool0GP3oool200000:d0oooo000:0?ooo`<000000`3oool0
0`000000oooo0?ooo`1P0?ooo`800000Z`3oool000/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`1R0?ooo`030000003oool0oooo0:P0oooo00080?ooo`D000000`3oool3000006<0
oooo0P00002X0?ooo`00203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06D0
oooo0P00002V0?ooo`002@3oool00`000000oooo000000040?ooo`030000003oool0oooo06L0oooo
0P00002T0?ooo`002P3oool2000000@0oooo00<000000?ooo`3oool0J@3oool200000:80oooo000@
0?ooo`030000003oool0oooo06/0oooo0P00002P0?ooo`00403oool00`000000oooo0?ooo`1]0?oo
o`800000WP3oool00100oooo0P00001`0?ooo`800000W03oool00100oooo00<000000?ooo`3oool0
L@3oool3000009T0oooo000@0?ooo`030000003oool0oooo07@0oooo0`00002F0?ooo`00403oool0
0`000000oooo0?ooo`1g0?ooo`@00000TP3oool00100oooo00<000000?ooo`3oool0N`3oool30000
08l0oooo000@0?ooo`030000003oool0oooo07h0oooo0`00002<0?ooo`00403oool00`000000oooo
0?ooo`210?ooo`800000RP3oool00100oooo0P0000240?ooo`<00000Q`3oool00100oooo00<00000
0?ooo`3oool0QP3oool4000008<0oooo000@0?ooo`030000003oool0oooo08X0oooo1@00001n0?oo
o`00403oool00`000000oooo0?ooo`2?0?ooo`@00000NP3oool00100oooo00<000000?ooo`3oool0
T`3oool4000007H0oooo000@0?ooo`030000003oool0oooo09L0oooo1000001b0?ooo`00403oool2
000009`0oooo1000001^0?ooo`00403oool00`000000oooo0?ooo`2O0?ooo`H00000J03oool00100
oooo00<000000?ooo`3oool0Y@3oool5000006<0oooo000@0?ooo`030000003oool0oooo0:X0oooo
1@00001N0?ooo`00403oool00`000000oooo0?ooo`2_0?ooo`P00000EP3oool00100oooo00<00000
0?ooo`3oool0]`3oool:000004`0oooo000@0?ooo`030000003oool0oooo0<40oooo2`0000110?oo
o`00403oool200000<d0oooo2`00000f0?ooo`00403oool00`000000oooo0?ooo`3G0?ooo`X00000
;03oool00100oooo00<000000?ooo`3oool0h@3oool;00000240oooo000@0?ooo`030000003oool0
oooo0>`0oooo4000000A0?ooo`002@3oool2000000D0oooo00<000000?ooo`3oool0o`3oool>0?oo
o`00203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo3P3oool000/0
oooo00<000000?ooo`3oool00P3oool300000?l0oooo3P3oool000T0oooo0P0000050?ooo`030000
003oool0oooo0?l0oooo3P3oool000T0oooo00<000000?ooo`3oool0o`3ooolE0?ooo`002@3oool3
00000?l0oooo5@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-6.49535, -0.385299, \
0.393233, 0.0312306}}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(0.`\ Second\), ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False]}], "}"}]], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell[TextData[{
  "Suppose that the flow of the drug into the organ is cut in ",
  Cell[BoxData[
      \(TraditionalForm\`t\  = \ T\)]],
  ".  Since that moment ",
  Cell[BoxData[
      \(TraditionalForm\`b(t)\  = \ 0\)]],
  " but the liquid continue flowing with the same constant rates ",
  StyleBox["v.",
    FontSlant->"Italic"],
  " The process will be given by equation where ",
  Cell[BoxData[
      \(TraditionalForm\`t1\  = \ \(\(t\)\(\ \)\(-\)\(\ \)\(T\)\(\ \)\)\)]]
}], "Text"],

Cell[TextData[{
  "We do ",
  Cell[BoxData[
      \(TraditionalForm\`b\  = \ 0\)]],
  " in eq2"
}], "Caption"],

Cell[BoxData[
    \(V\ \ \(c'\)[t1] == \ \(-\[Nu]\)\ c[t1]; \)], "Input",
  CellLabel->"In[24]:="],

Cell["\<\
The concentration in t1 = 0 (or t = T) will be with an initial concentration \
c[0] = c1\
\>", "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[{%, \ c[0] \[Equal] c1}, \ c[t1], \ t1]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \({{c[t1] \[Rule] 
          c1\ \[ExponentialE]\^\(-\(\(t1\ \[Nu]\)\/V\)\)}}\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell[TextData[{
  "Replacing",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{Cell["t1"], " ", "=", " ", \(\(t\)\(-\)\(T\)\(\ \)\)}]}], 
        TraditionalForm]]],
  "and  ",
  Cell[BoxData[
      \(TraditionalForm\`c1 = \ c1[T]\)]],
  " is obtained the concentration ",
  Cell[BoxData[
      \(TraditionalForm\`c(t)\)]],
  " in the organ  when ",
  Cell[BoxData[
      \(TraditionalForm\`t \[GreaterEqual] T\)]]
}], "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(c2[t_, 
        T_] = \(c[t1] /. %[\([\)\(1\)\(]\)]\) /. {t1 \[Rule] \ t - T, \ 
          c1 \[Rule] \ c1[T]}\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(\((t - T)\)\ \[Nu]\)\/V\)\)\ \((b + \((\(-b\) + 
                c0)\)\ \[ExponentialE]\^\(-\(\(T\ \[Nu]\)\/V\)\))\)\)], \
"Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell[TextData[{
  "Now we can build a joint function with ",
  Cell[BoxData[
      \(TraditionalForm\`c(t)\  = \ c1(t)\)]],
  " when ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(0\  \[LessEqual] t < T\)\)\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`c(t)\  = \ c2(t)\)]],
  " when ",
  Cell[BoxData[
      \(TraditionalForm\`t \[GreaterEqual] T\)]],
  " "
}], "Text"],

Cell[TextData[{
  "Remember that ",
  StyleBox["f[",
    FontFamily->"Courier New"],
  StyleBox["pattern",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["/;condition", "MR",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]:= ", "MR"],
  StyleBox["expr", "MR",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " indicates that the ",
  StyleBox["expr", "MR",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " is evaluated only when  ",
  StyleBox["condition", "MR",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " is satisfied "
}], "Caption"],

Cell[BoxData[{
    \(c[t_, T_ /; t < T] := c1[t]; \), "\[IndentingNewLine]", 
    \(c[t_, T_ /; t \[GreaterEqual] T] := \ c2[t, T]\)}], "Input",
  CellLabel->"In[27]:="],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`T\  = \ 50\)]],
  " the plot of ",
  Cell[BoxData[
      \(TraditionalForm\`c(t)\)]],
  " is"
}], "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[
      c[t, 50] /. {V \[Rule] 5, \ c0 \[Rule] 0, \ \[Nu] \[Rule] \ 0.2, \ 
          b \[Rule] 5}, \ {t, \ 0, 100}]\)], "Input",
  CellLabel->"In[29]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0147151 0.136186 [
[.21429 .00222 -6 -9 ]
[.21429 .00222 6 0 ]
[.40476 .00222 -6 -9 ]
[.40476 .00222 6 0 ]
[.59524 .00222 -6 -9 ]
[.59524 .00222 6 0 ]
[.78571 .00222 -6 -9 ]
[.78571 .00222 6 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .1509 -6 -4.5 ]
[.01131 .1509 0 4.5 ]
[.01131 .28709 -6 -4.5 ]
[.01131 .28709 0 4.5 ]
[.01131 .42327 -6 -4.5 ]
[.01131 .42327 0 4.5 ]
[.01131 .55946 -6 -4.5 ]
[.01131 .55946 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(20)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(40)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(60)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(80)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(100)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .1509 m
.03006 .1509 L
s
[(1)] .01131 .1509 1 0 Mshowa
.02381 .28709 m
.03006 .28709 L
s
[(2)] .01131 .28709 1 0 Mshowa
.02381 .42327 m
.03006 .42327 L
s
[(3)] .01131 .42327 1 0 Mshowa
.02381 .55946 m
.03006 .55946 L
s
[(4)] .01131 .55946 1 0 Mshowa
.125 Mabswid
.02381 .04195 m
.02756 .04195 L
s
.02381 .06919 m
.02756 .06919 L
s
.02381 .09643 m
.02756 .09643 L
s
.02381 .12366 m
.02756 .12366 L
s
.02381 .17814 m
.02756 .17814 L
s
.02381 .20538 m
.02756 .20538 L
s
.02381 .23261 m
.02756 .23261 L
s
.02381 .25985 m
.02756 .25985 L
s
.02381 .31432 m
.02756 .31432 L
s
.02381 .34156 m
.02756 .34156 L
s
.02381 .3688 m
.02756 .3688 L
s
.02381 .39604 m
.02756 .39604 L
s
.02381 .45051 m
.02756 .45051 L
s
.02381 .47775 m
.02756 .47775 L
s
.02381 .50499 m
.02756 .50499 L
s
.02381 .53222 m
.02756 .53222 L
s
.02381 .5867 m
.02756 .5867 L
s
.02381 .61393 m
.02756 .61393 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .11671 L
.10458 .21061 L
.14415 .28488 L
.18221 .34556 L
.22272 .40033 L
.26171 .44494 L
.30316 .48499 L
.34309 .51752 L
.3815 .54406 L
.42237 .56797 L
.46172 .58742 L
.48147 .59604 L
.49012 .59959 L
.49468 .60141 L
.49719 .6024 L
.49842 .60288 L
.49955 .60332 L
.50085 .60139 L
.50154 .59971 L
.50226 .59794 L
.50471 .59196 L
.5095 .58046 L
.51896 .55842 L
.53984 .51278 L
.57781 .43936 L
.61824 .37305 L
.65714 .31902 L
.6985 .2705 L
.73835 .23108 L
.77668 .19891 L
.81746 .16991 L
.85673 .14632 L
.89448 .12702 L
.93468 .10957 L
.97337 .09535 L
.97619 .0944 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[29]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00?03oool4000000<0oooo0P00000]0?ooo`<000000P3oool2000002/0oooo0`0000040?oo
o`800000;03oool2000000@0oooo0P00000X0?ooo`D000000P3oool2000000@0oooo0P0000080?oo
o`00?03oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000002d0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0X0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000:P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
02T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool01@3oool003d0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
000Z0?ooo`D0000000D0oooo0000003oool0oooo0000000Z0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000:P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000002T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool01@3oool003h0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000Z
0?ooo`<000000`3oool010000000oooo0?ooo`00000[0?ooo`8000000`3oool010000000oooo0?oo
o`00000Y0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00D0oooo000l0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000:`3oool00`000000oooo000000020?ooo`040000003oool0oooo000002/0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000Z0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000:@3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`00?@3oool2000000@0oooo0P00000]
0?ooo`8000000`3oool2000002`0oooo0`0000030?ooo`800000;03oool2000000@0oooo0P00000Y
0?ooo`800000103oool2000000@0oooo0P0000080?ooo`00o`3ooolQ0?ooo`003@3oool00`000000
oooo0?ooo`3o0?oooa40oooo000=0?ooo`030000003oool0oooo0?l0oooo4@3oool000d0oooo00<0
00000?ooo`3oool0o`3ooolA0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooa40oooo00070?oo
ool000004`0000070?ooo`003@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0303oool000d0oooo0P00000b0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool0303oool000d0oooo0P00003o0?oooa80oooo000=0?ooo`030000003oool0
00000?l0oooo4@3oool000d0oooo00<000000?ooo`000000o`3ooolA0?ooo`003@3oool00`000000
oooo0000003o0?oooa40oooo000=0?ooo`80000000<0oooo0000003oool0o`3oool?0?ooo`003@3o
ool010000000oooo0?ooo`00003o0?oooa00oooo000=0?ooo`050000003oool0oooo0?ooo`000000
o`3oool?0?ooo`003@3oool01@000000oooo0?ooo`3oool000000?l0oooo3`3oool000d0oooo00D0
00000?ooo`3oool0oooo0000003o0?ooo`l0oooo000=0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0o`3oool<0?ooo`003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0?l0oooo303oool000d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?oo
o``0oooo000=0?ooo`800000103oool00`000000oooo0?ooo`3o0?ooo`/0oooo000=0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool;0?ooo`003@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0?l0oooo2P3oool000d0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3o0?ooo`X0oooo000=0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0o`3oool:0?ooo`003@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0
oooo2@3oool000d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo
000=0?ooo`8000001`3oool00`000000oooo0?ooo`3f0?ooo`<000003P3oool000d0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`3d0?ooo`8000004@3oool000d0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`3a0?ooo`<000004`3oool000d0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`3^0?ooo`8000005P3oool000d0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`3[0?ooo`<00000603oool000d0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`3X0?ooo`8000006`3oool000d0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`3V0?ooo`8000007@3oool000d0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`3T0?ooo`8000007`3oool000d0oooo0P00000:0?ooo`030000003oool0oooo0>40
oooo0P00000Q0?ooo`003@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0=h0oooo
0`00000S0?ooo`003@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0=/0oooo0P00
000V0?ooo`003@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0=T0oooo0P00000X
0?ooo`003@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0=H0oooo0P00000Z0?oo
o`001@3oool5000000<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3D0?ooo`80
0000;03oool000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0=40oooo0P00000^0?ooo`001`3oool00`000000oooo0?ooo`030?ooo`<00000303o
ool00`000000oooo0?ooo`3?0?ooo`800000<03oool000L0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0<d0oooo0P00000b0?ooo`001`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0b`3oool00`00
0000oooo0?ooo`0b0?ooo`001P3oool2000000D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`390?ooo`800000=@3oool000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`360?ooo`800000=`3oool000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`350?ooo`030000003oool0oooo03L0oooo000=0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0`P3oool2000003X0oooo000=0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0`@3oool00`000000oooo0?ooo`0j0?ooo`003@3oool200000100oooo00<000000?ooo`3o
ool0`03oool00`000000oooo0?ooo`0k0?ooo`003@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0;d0oooo0P00000n0?ooo`003@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0;`0oooo00<000000?ooo`3oool0?P3oool000d0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`2j0?ooo`030000003oool0oooo03l0oooo000=0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0^03oool200000480oooo000=0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`120?ooo`003@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0@`3oool000d0oooo0P00
000D0?ooo`030000003oool0oooo0;80oooo0P0000160?ooo`003@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0AP3oool000d0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo04L0oooo000=0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`180?ooo`00
3@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0
B@3oool000d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`2Z0?ooo`800000C03o
ool000d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0
oooo04`0oooo000=0?ooo`8000005`3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo
04d0oooo000=0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0Y@3oool00`000000
oooo0?ooo`1>0?ooo`003@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0:@0oooo
00<000000?ooo`3oool0C`3oool000d0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`2R0?ooo`030000003oool0oooo0500oooo000=0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0X@3oool00`000000oooo0?ooo`1A0?ooo`003@3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo09l0oooo00<000000?ooo`3oool0DP3oool000d0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo05<0oooo000=0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`1D0?ooo`003@3o
ool2000001/0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`1E0?ooo`003@3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0EP3oool0
00d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo
05L0oooo000=0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0UP3oool00`000000
oooo0?ooo`1H0?ooo`003@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo09D0oooo
00<000000?ooo`3oool0F@3oool000D0oooo100000040?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0T`3oool00`000000oooo0?ooo`1J0?ooo`001@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`1K
0?ooo`001P3oool00`000000oooo0?ooo`040?ooo`<000007P3oool00`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo05/0oooo00070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo05`0oooo00050?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo05d0oooo00060?ooo`8000001@3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0GP3oool000d0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo05l0oooo000=0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`1P0?ooo`003@3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0H03oool000d0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0640
oooo000=0?ooo`800000903oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0680oooo
000=0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?oo
o`1S0?ooo`003@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0840oooo00<00000
0?ooo`3oool0I03oool000d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`200?oo
o`030000003oool0oooo06@0oooo000=0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0O`3oool00`000000oooo0?ooo`1U0?ooo`003@3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo07d0oooo00<000000?ooo`3oool0IP3oool000d0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo06L0oooo000=0?ooo`800000:@3oool0
0`000000oooo0?ooo`1k0?ooo`030000003oool0oooo06L0oooo000=0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1X0?ooo`003@3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0J@3oool000d0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo06X0oooo
000=0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?oo
o`1Z0?ooo`003@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo07<0oooo00<00000
0?ooo`3oool0J`3oool000d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1a0?oo
o`030000003oool0oooo06`0oooo000=0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0L03oool00`000000oooo0?ooo`1]0?ooo`003@3oool2000002l0oooo00<000000?ooo`3oool0
K`3oool00`000000oooo0?ooo`1]0?ooo`003@3oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool0KP3oool000d0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`1[0?ooo`030000003oool0oooo06l0oooo000=0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1_0?ooo`003@3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0L03oool000d0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo0700oooo
000=0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`1a0?ooo`003@3oool2000003@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`1b
0?ooo`003@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool0LP3oool000d0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`1R0?ooo`03
0000003oool0oooo07<0oooo000=0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
H03oool00`000000oooo0?ooo`1d0?ooo`003@3oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo0600oooo00<000000?ooo`3oool0M03oool000H0oooo0P0000050?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1e0?ooo`001@3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0G@3oool0
0`000000oooo0?ooo`1e0?ooo`001`3oool00`000000oooo0?ooo`030?ooo`<00000>@3oool00`00
0000oooo0?ooo`1K0?ooo`030000003oool0oooo07H0oooo00080?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo07L0
oooo00050?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo07L0oooo00060?ooo`8000001@3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0N03oool000d0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo07P0oooo000=
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1i
0?ooo`003@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0580oooo00<000000?oo
o`3oool0NP3oool000d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`1A0?ooo`03
0000003oool0oooo07X0oooo000=0?ooo`800000@@3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo07/0oooo000=0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0CP3o
ool00`000000oooo0?ooo`1k0?ooo`003@3oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool0O03oool000d0oooo00<000000?ooo`3oool0@`3oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo07`0oooo000=0?ooo`030000003oool0oooo04@0
oooo0P00001:0?ooo`030000003oool0oooo07d0oooo000=0?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1m0?ooo`003@3oool00`000000oooo0?oo
o`170?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0OP3oool000d0oooo0P000019
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0OP3oool000d0oooo00<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo07l0oooo000=0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1o0?ooo`00
3@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
P03oool000d0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo0800oooo000=0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`210?ooo`003@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0P@3oool000d0oooo00<000000?ooo`3oool0C`3oool2000003X0
oooo00<000000?ooo`3oool0PP3oool000d0oooo0P00001B0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0PP3oool000d0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`0e0?ooo`030000003oool0oooo08<0oooo000=0?ooo`030000003oool0oooo05<0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`230?ooo`003@3oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool0Q03oool000d0oooo00<000000?ooo`3o
ool0E@3oool200000380oooo00<000000?ooo`3oool0Q03oool000d0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo08D0oooo000=0?ooo`030000003o
ool0oooo05P0oooo0P00000^0?ooo`030000003oool0oooo08D0oooo000=0?ooo`800000F`3oool2
000002/0oooo00<000000?ooo`3oool0QP3oool000d0oooo00<000000?ooo`3oool0G03oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo08H0oooo000=0?ooo`030000003oool0oooo05d0
oooo0P00000W0?ooo`030000003oool0oooo08L0oooo000=0?ooo`030000003oool0oooo05l0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`270?ooo`003@3oool00`000000oooo0?oo
o`1P0?ooo`8000008`3oool00`000000oooo0?ooo`280?ooo`003@3oool00`000000oooo0?ooo`1R
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0R03oool000L0oooo0`0000030?oo
o`030000003oool0oooo06<0oooo0P00000O0?ooo`030000003oool0oooo08T0oooo00080?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0I@3oool2000001d0oooo00<000000?ooo`3o
ool0R@3oool000D0oooo1@0000030?ooo`<00000I`3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo08T0oooo00050?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
J03oool2000001T0oooo00<000000?ooo`3oool0RP3oool000H0oooo00<000000?ooo`000000103o
ool00`000000oooo0?ooo`1Z0?ooo`8000005`3oool00`000000oooo0?ooo`2:0?ooo`001`3oool2
000000@0oooo00<000000?ooo`3oool0K03oool2000001D0oooo00<000000?ooo`3oool0RP3oool0
00d0oooo00<000000?ooo`3oool0KP3oool200000180oooo00<000000?ooo`3oool0R`3oool000d0
oooo00<000000?ooo`3oool0L03oool200000100oooo00<000000?ooo`3oool0R`3oool000d0oooo
00<000000?ooo`3oool0LP3oool2000000d0oooo00<000000?ooo`3oool0S03oool000d0oooo0P00
001e0?ooo`8000002`3oool00`000000oooo0?ooo`2<0?ooo`003@3oool00`000000oooo0?ooo`1f
0?ooo`800000203oool00`000000oooo0?ooo`2=0?ooo`003@3oool00`000000oooo0?ooo`1h0?oo
o`8000001P3oool00`000000oooo0?ooo`2=0?ooo`003@3oool00`000000oooo0?ooo`1j0?ooo`@0
00000P3oool00`000000oooo0?ooo`2=0?ooo`003@3oool00`000000oooo0?ooo`1n0?ooo`<00000
S`3oool000d0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`003@3oool00`000000oooo0?ooo`3o
0?oooa40oooo000=0?ooo`800000o`3ooolB0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooa40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.33027, -0.334106, \
0.385028, 0.0269259}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[29]="]
}, Open  ]],

Cell[TextData[{
  "We consider a bit more complicated situation: In eq.(2) we suppose that ",
  Cell[BoxData[
      \(TraditionalForm\`b(t)\  = \ A\ \(Exp(\(-k\)\ T)\)\)]],
  " when  ",
  Cell[BoxData[
      \(TraditionalForm\`0\  \[LessEqual] \ t\  < \ T\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`b(t)\  = \ 0\)]],
  " when",
  StyleBox[" t ",
    FontSlant->"Italic"],
  "\[GreaterEqual]",
  StyleBox[" T",
    FontSlant->"Italic"],
  " ."
}], "Text"],

Cell["\<\
The method is the same as we followed in the previous example. We have \
supposed that A= 1, k = 0.05\
\>", "Caption"],

Cell[BoxData[
    \(DSolve[{V\ \ \(c'\)[t] == \ \[Nu] \((A\ Exp[\(-k\)\ t] - c[t])\), \ 
          c[0] \[Equal] c0}, \ c[t], \ t] // FullSimplify; \)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(c3[t_] = c[t] /. %[\([\)\(1\)\(]\)]; \)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(DSolve[{\ V\ \ \(c'\)[t1] == \ \(-\[Nu]\)\ c[t1], \ 
        c[0] \[Equal] c1}, \ c[t1], \ t1]; \)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \(c4[t_, 
        T_] = \(c[t1] /. %[\([\)\(1\)\(]\)]\) /. {t1 \[Rule] \ t - T, \ 
          c1 \[Rule] \ c3[T]}; \)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[{
    \(c[t_, T_ /; t < T] := c3[t]; \), "\[IndentingNewLine]", 
    \(c[t_, T_ /; t \[GreaterEqual] T] := \ c4[t, T]\)}], "Input",
  CellLabel->"In[34]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[
      c[t, 30] /. {A \[Rule] \ 1, \ k \[Rule] \ 0.05, V \[Rule] 5, \ 
          c0 \[Rule] 0, \ \[Nu] \[Rule] \ 0.2, \ b \[Rule] 5}, \ {t, \ 0, 
        100}]\)], "Input",
  CellLabel->"In[36]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0147151 1.79628 [
[.21429 .00222 -6 -9 ]
[.21429 .00222 6 0 ]
[.40476 .00222 -6 -9 ]
[.40476 .00222 6 0 ]
[.59524 .00222 -6 -9 ]
[.59524 .00222 6 0 ]
[.78571 .00222 -6 -9 ]
[.78571 .00222 6 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .10453 -24 -4.5 ]
[.01131 .10453 0 4.5 ]
[.01131 .19434 -18 -4.5 ]
[.01131 .19434 0 4.5 ]
[.01131 .28416 -24 -4.5 ]
[.01131 .28416 0 4.5 ]
[.01131 .37397 -18 -4.5 ]
[.01131 .37397 0 4.5 ]
[.01131 .46378 -24 -4.5 ]
[.01131 .46378 0 4.5 ]
[.01131 .5536 -18 -4.5 ]
[.01131 .5536 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(20)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(40)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(60)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(80)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(100)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10453 m
.03006 .10453 L
s
[(0.05)] .01131 .10453 1 0 Mshowa
.02381 .19434 m
.03006 .19434 L
s
[(0.1)] .01131 .19434 1 0 Mshowa
.02381 .28416 m
.03006 .28416 L
s
[(0.15)] .01131 .28416 1 0 Mshowa
.02381 .37397 m
.03006 .37397 L
s
[(0.2)] .01131 .37397 1 0 Mshowa
.02381 .46378 m
.03006 .46378 L
s
[(0.25)] .01131 .46378 1 0 Mshowa
.02381 .5536 m
.03006 .5536 L
s
[(0.3)] .01131 .5536 1 0 Mshowa
.125 Mabswid
.02381 .03268 m
.02756 .03268 L
s
.02381 .05064 m
.02756 .05064 L
s
.02381 .0686 m
.02756 .0686 L
s
.02381 .08657 m
.02756 .08657 L
s
.02381 .12249 m
.02756 .12249 L
s
.02381 .14045 m
.02756 .14045 L
s
.02381 .15842 m
.02756 .15842 L
s
.02381 .17638 m
.02756 .17638 L
s
.02381 .21231 m
.02756 .21231 L
s
.02381 .23027 m
.02756 .23027 L
s
.02381 .24823 m
.02756 .24823 L
s
.02381 .26619 m
.02756 .26619 L
s
.02381 .30212 m
.02756 .30212 L
s
.02381 .32008 m
.02756 .32008 L
s
.02381 .33804 m
.02756 .33804 L
s
.02381 .35601 m
.02756 .35601 L
s
.02381 .39193 m
.02756 .39193 L
s
.02381 .4099 m
.02756 .4099 L
s
.02381 .42786 m
.02756 .42786 L
s
.02381 .44582 m
.02756 .44582 L
s
.02381 .48175 m
.02756 .48175 L
s
.02381 .49971 m
.02756 .49971 L
s
.02381 .51767 m
.02756 .51767 L
s
.02381 .53564 m
.02756 .53564 L
s
.02381 .57156 m
.02756 .57156 L
s
.02381 .58952 m
.02756 .58952 L
s
.02381 .60749 m
.02756 .60749 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.04262 .14454 L
.06244 .25757 L
.08426 .35751 L
.10458 .43088 L
.12297 .48317 L
.14264 .52637 L
.15285 .54424 L
.16394 .56047 L
.17353 .57205 L
.18408 .5824 L
.19432 .59024 L
.20392 .59577 L
.20921 .59812 L
.21405 .59986 L
.21672 .60066 L
.21964 .60141 L
.22495 .60245 L
.2275 .6028 L
.22884 .60295 L
.23026 .60308 L
.2315 .60317 L
.23216 .6032 L
.23287 .60324 L
.23411 .60329 L
.23527 .60331 L
.23647 .60332 L
.23778 .60331 L
.23902 .60327 L
.24016 .60322 L
.24119 .60317 L
.24232 .60309 L
.24462 .60288 L
.24734 .60256 L
.24983 .60219 L
.25544 .60109 L
.26039 .59984 L
.26559 .59825 L
.28534 .58994 L
.29415 .5852 L
.3037 .57942 L
.30636 .57771 L
.30782 .57675 L
.30853 .57628 L
.30918 .57585 L
.31034 .5737 L
.31158 .57079 L
.31422 .56465 L
.32416 .54217 L
.34275 .50256 L
Mistroke
.38251 .42753 L
.42075 .36627 L
.46145 .31104 L
.50063 .26607 L
.54227 .22575 L
.58239 .19302 L
.62099 .16634 L
.66204 .14232 L
.70158 .1228 L
.73961 .10684 L
.78008 .09244 L
.81905 .08071 L
.86046 .07017 L
.90036 .06162 L
.93874 .05463 L
.97619 .04882 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[36]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00B03oool4000000<0oooo0P00000[0?ooo`<00000
0P3oool2000002T0oooo0`0000040?ooo`800000:P3oool2000000@0oooo0P00000W0?ooo`D00000
0P3oool2000000@0oooo0P0000030?ooo`00B03oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo000002/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0V0?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000:03oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000002P0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo0@0000010?ooo`40oooo00190?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000:03oool5000000050?ooo`000000oooo0?ooo`000000:03oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002P0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`00000X0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`4000000@3oool10?ooo`00BP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool09P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000002P0oooo0`0000030?ooo`040000003oool0oooo000002T0oooo0P0000030?oo
o`040000003oool0oooo000002P0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo0@0000010?ooo`40oooo00180?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000:@3oool00`000000oooo000000020?ooo`040000003oool0oooo0000
02T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000X0?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000:03oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool100000040oooo0@3oool004T0oooo0P0000040?ooo`80
0000:`3oool2000000<0oooo0P00000Z0?ooo`<000000`3oool2000002X0oooo0P0000040?ooo`80
0000:03oool2000000@0oooo0P0000040?ooo`8000000`3oool00?l0oooo8@3oool00?l0oooo8@3o
ool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?oo
o`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0
o`3oool30?ooo`005@3ooooo000000T000000`3oool001/0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo000K0?ooo`030000003oool0oooo
0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool200000?l0oooo
103oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool20000
0?l0oooo103oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`800000m@3oool5000000T0oooo
000K0?ooo`800000k@3oool8000000h0oooo000K0?ooo`030000003oool000000>L0oooo1@00000F
0?ooo`006`3oool00`000000oooo0000003R0?ooo`D000006`3oool001/0oooo00<000000?ooo`00
0000g03oool600000200oooo000K0?ooo`<00000f03oool4000002H0oooo000K0?ooo`030000003o
ool000000=@0oooo1000000Z0?ooo`006`3oool00`000000oooo0000003@0?ooo`@00000;P3oool0
01/0oooo00<000000?ooo`000000c@3oool300000380oooo000K0?ooo`040000003oool0oooo0000
0<T0oooo0`00000e0?ooo`006`3oool2000000030?ooo`000000oooo0<@0oooo1000000h0?ooo`00
6`3oool010000000oooo0?ooo`0000320?ooo`<00000?03oool00080oooo0P0000040?ooo`800000
103oool2000000@0oooo0P0000050?ooo`040000003oool0oooo00000;l0oooo0`00000o0?ooo`00
00D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000103oool010000000oooo0?ooo`00002m0?ooo`800000@P3oool000050?ooo`000000
oooo0?ooo`000000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080oooo
0P0000000`3oool000000?ooo`2i0?ooo`<00000A03oool000050?ooo`000000oooo0?ooo`000000
203oool010000000oooo0?ooo`0000030?ooo`8000001@3oool01@000000oooo0?ooo`3oool00000
0;H0oooo0`0000170?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000;@0oooo0P00
001:0?ooo`000P3oool2000000X0oooo0P0000040?ooo`<00000103oool01@000000oooo0?ooo`3o
ool000000;40oooo0`00001<0?ooo`006`3oool01@000000oooo0?ooo`3oool000000:l0oooo0P00
001?0?ooo`006`3oool200000080oooo00<000000?ooo`3oool0Z`3oool200000540oooo000K0?oo
o`050000003oool0oooo0?ooo`000000Z`3oool2000005<0oooo000K0?ooo`050000003oool0oooo
0?ooo`000000Z@3oool2000005D0oooo000K0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0Y03oool2000005L0oooo000K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0XP3oool2000005T0oooo000K0?ooo`8000000`3oool00`000000oooo0?ooo`2P0?ooo`800000
F`3oool001/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2N0?ooo`800000G@3o
ool001/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0
oooo05d0oooo000K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0V`3oool20000
0600oooo000K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0V@3oool200000680
oooo000K0?ooo`800000103oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo0680oooo
000K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0U@3oool2000006D0oooo000K
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1U
0?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0980oooo0P00001X0?oo
o`006`3oool2000000@0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`1X0?ooo`00
6`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0
J@3oool001/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2=0?ooo`800000K03o
ool000P0oooo0P0000040?ooo`8000000`3oool5000000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo06`0oooo00070?ooo`040000003oool0oooo
000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo08X0oooo0P00001_0?ooo`001`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0
oooo00<0oooo0P0000050?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0K`3oool0
00L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0Q`3oool200000780oooo00070?ooo`040000003oool0oooo
000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0LP3oool000P0oooo0P00000:0?ooo`8000001@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0L`3oool001/0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`220?ooo`800000MP3oool001/0oooo
0P0000060?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0MP3oool001/0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo07L0oooo000K
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0OP3oool2000007X0oooo000K0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`1j0?oo
o`006`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3o
ool0N`3oool001/0oooo0P0000070?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
O03oool001/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo07d0oooo000K0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0N03oool0
0`000000oooo0?ooo`1n0?ooo`006`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
07L0oooo00<000000?ooo`3oool0O`3oool001/0oooo0P0000070?ooo`030000003oool0oooo07H0
oooo00<000000?ooo`3oool0P03oool001/0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0840oooo000K0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0L`3oool00`000000oooo0?ooo`220?ooo`006`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0P`3oool001/0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo08@0oooo000K0?ooo`80
0000203oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo08D0oooo000K0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`260?ooo`006`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0Q`3o
ool00080oooo0P0000040?ooo`8000000`3oool500000080oooo0P0000050?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`280?ooo`0000D0oooo0000
003oool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?oo
o`280?ooo`0000D0oooo0000003oool0oooo0000000:0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool2000000X0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?oo
o`290?ooo`0000D0oooo0000003oool0oooo0000000:0?ooo`030000003oool0oooo0080oooo0P00
00050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?oo
o`2:0?ooo`0000D0oooo0000003oool0oooo0000000:0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06P0oooo00<0
00000?ooo`3oool0R`3oool00080oooo0P00000:0?ooo`800000103oool3000000@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo08`0oooo000K0?oo
o`8000002`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo08d0oooo000K0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`2=0?ooo`00
6`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0
SP3oool001/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1S0?ooo`030000003o
ool0oooo08l0oooo000K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0HP3oool0
0`000000oooo0?ooo`2@0?ooo`006`3oool2000000`0oooo00<000000?ooo`3oool0H03oool00`00
0000oooo0?ooo`2A0?ooo`006`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0600
oooo00<000000?ooo`3oool0T@3oool001/0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`1O0?ooo`030000003oool0oooo0980oooo000K0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0GP3oool00`000000oooo0?ooo`2C0?ooo`006`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0U03oool001/0oooo0P00000=0?oo
o`030000003oool0oooo05/0oooo00<000000?ooo`3oool0U@3oool001/0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo09D0oooo000K0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`2F0?ooo`006`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0U`3o
ool001/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo09P0oooo000K0?ooo`8000003P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
09P0oooo000K0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`2I0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000103oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0VP3oool000L0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`2K0?ooo`001`3oool010000000oooo0?oo
o`0000090?ooo`030000003oool0oooo00@0oooo0P00000?0?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool0V`3oool000L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0DP3oool00`000000oooo
0?ooo`2L0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo09d0
oooo00080?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`1@0?ooo`030000003oool0oooo09d0oooo000K0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`2N0?ooo`006`3oool200000100oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`2N0?ooo`006`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo04d0oooo00<000000?ooo`3oool0W`3oool001/0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0:00oooo000K0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`2P0?ooo`006`3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0X@3o
ool001/0oooo0P00000B0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0XP3oool0
01/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
0:80oooo000K0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`2S0?ooo`006`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04P0oooo
00<000000?ooo`3oool0X`3oool001/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`160?ooo`030000003oool0oooo0:@0oooo000K0?ooo`8000004`3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo0:D0oooo000K0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`2U0?ooo`006`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo04<0oooo00<000000?ooo`3oool0YP3oool001/0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0:H0oooo000K0?ooo`800000503o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0:L0oooo000K0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`2W0?ooo`006`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0Z03oool00080
oooo0P0000040?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2X0?ooo`0000D0oooo0000003oool0
oooo000000080?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0Z@3oool00005
0?ooo`000000oooo0?ooo`0000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo0P00000F0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0Z@3oool00005
0?ooo`000000oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0ZP3oool00005
0?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo0:X0oooo00020?ooo`8000002P3oool2000000@0oooo0`0000040?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`2[0?ooo`006`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0Z`3oool001/0oooo
0P00000H0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[03oool001/0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:`0oooo000K
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2]
0?ooo`006`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0[@3oool001/0oooo0P00000J0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool0[P3oool001/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo0:h0oooo000K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`2^0?ooo`006`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool0[`3oool001/0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo0:l0oooo000K0?ooo`800000703oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo0;00oooo000K0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`2`0?ooo`006`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0/@3oool001/0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0;40oooo000K0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2b0?oo
o`006`3oool2000001l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`2b0?ooo`00
6`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
/`3oool001/0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo0;<0oooo00080?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`2d0?ooo`001`3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0;@0oooo00070?ooo`040000003oool0
oooo000000X0oooo00<000000?ooo`3oool00`3oool200000280oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`2e0?ooo`001`3oool010000000oooo0?ooo`00000;0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo0;D0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
]P3oool000P0oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0]P3oool001/0oooo0P00000U0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0]P3oool001/0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo0;L0oooo000K0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool07@3oool300000;T0oooo000K0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`2j0?ooo`006`3oool00`000000oooo0?oo
o`0X0?ooo`8000006P3oool00`000000oooo0?ooo`2k0?ooo`006`3oool2000002/0oooo00<00000
0?ooo`3oool0503oool300000;h0oooo000K0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0403oool300000<40oooo000K0?ooo`030000003oool0oooo02`0oooo0`00000=0?ooo`80
0000a03oool001/0oooo00<000000?ooo`3oool0;`3oool4000000D0oooo100000360?ooo`006`3o
ool00`000000oooo0?ooo`0b0?ooo`L00000b@3oool001/0oooo0P00003o0?ooo`@0oooo000K0?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-10.8859, -0.0321541, \
0.398872, 0.0021148}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[x1, x2, eq, \ x, \ eq1, eq2, c, c1, c2, c3, c4, \ 
      kI131\ ]\)], "Input",
  CellLabel->"In[37]:="]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Two  Compartmental Systems ", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["A easy example of a two compartmental model", "SubsubsectionIcon"],

Cell["\<\
This Figure is represented an easy example of a two compartmental system \
(Anderson 1983). It shows the ingestion and metabolism of a drug. We have \
modeled with two compartments. It is supposed that the drug is taken orally \
flowing to the GI tract (Compartment 1) , then it is absorbed into the blood \
(Compartment 2) and finally eliminated. \
\>", "Text"],

Cell[BoxData[Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.238095 0.375 0.238095 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125  moveto 0 0 lineto 
-0.05 -0.0125  lineto stroke
} ifelse
grestore
} def
/MAarrowhead2 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.14286 .73214 m
.14286 .49405 L
s
% Start of user PostScript
0 1.5 0 0.5 MAarrowhead1
% End of user PostScript
gsave
.2381 .6131 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 12.750 moveto
(H) show
81.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 12.750 moveto
(L) show
93.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.14286 .375 .11905 0 365.73 arc
s
gsave
.14286 .375 -96 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GI) show
81.000 12.750 moveto
(Tract) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.000 12.750 moveto
(H) show
117.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.000 12.750 moveto
(L) show
129.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.2619 .375 m
.7381 .375 L
s
% Start of user PostScript
0.5 0 2.5 0 MAarrowhead2
% End of user PostScript
gsave
.5 .47024 -111 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Flow) show
93.000 12.750 moveto
(from) show
123.000 12.750 moveto
(1) show
135.000 12.750 moveto
(to) show
153.000 12.750 moveto
(2) show
159.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.85714 .375 .11905 0 365.73 arc
s
gsave
.85714 .375 -90 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Blood) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 12.750 moveto
(H) show
105.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.000 12.750 moveto
(L) show
117.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.85714 .25595 m
.85714 .01786 L
s
% Start of user PostScript
3. -0.5 3. -1.5 MAarrowhead2
% End of user PostScript
gsave
.71429 .1369 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Elimination) show
129.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Text",
      ImageSize->{309.75, 232.25},
      ImageMargins->{{0, 0}, {0, 15.8125}},
      ImageRegion->{{0, 1}, {0, 1}},
      ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006300018Q000`40O003h00OogooQ7oo003oOon4
Ool00?moohAoo`00ogooQ7oo003oOon4Ool00?moohAoo`00ogooQ7oo003oOom;Ool00`00Oomoo`0f
Ool00?mood]oo`03001oogoo03Ioo`00ogooBWoo0`00=goo003oOom:Ool3000gOol00?moodYoo`<0
03Moo`00ogooBWoo0`00=goo003oOom9Ool5000fOol00?moodUoo`D003Ioo`00ogooBGoo1@00=Woo
003oOom9Ool5000fOol00?moodQoo`L003Eoo`00ogooB7oo1`00=Goo003oOom8Ool7000eOol00?mo
odQoo`L003Eoo`00ogooAgoo2@00=7oo003oOom7Ool9000dOol00?moodMoo`T003Aoo`00ogooAgoo
2@00=7oo003oOom6Ool;000cOol00?moodIoo`/003=oo`00ogooBgoo00<007ooOol0=Woo003oOom;
Ool00`00Oomoo`0fOol00?mood]oo`03001oogoo03Ioo`00ogooBgoo00<007ooOol0=Woo003oOom;
Ool00`00Oomoo`0fOol00?mood]oo`03001oogoo03Ioo`00ogooBgoo00<007ooOol0=Woo003oOom;
Ool00`00Oomoo`0fOol00?mood]oo`03001oogoo03Ioo`00ogooBgoo00<007ooOol0=Woo003oOom;
Ool00`00Oomoo`0fOol00?mood]oo`03001oogoo03Ioo`00ogooBgoo00<007ooOol0=Woo003oOom;
Ool00`00Oomoo`0fOol00?mood]oo`03001oogoo03Ioo`00ogooBgoo00<007ooOol0=Woo003oOom;
Ool00`00Oomoo`0fOol00?mood]oo`03001oogoo03Ioo`00ogooBgoo00<007ooOol0=Woo003oOom;
Ool00`00Oomoo`0fOol00?mood]oo`03001oogoo03Ioo`00ogooBgoo00<007ooOol0=Woo003oOom;
Ool00`00Oomoo`0fOol00?mood]oo`03001oogoo03Ioo`00ogooBgoo00<007ooOol0=Woo003oOom;
Ool00`00Oomoo`0fOol00?mood]oo`03001oogoo03Ioo`00ogooBgoo00<007ooOol0=Woo003oOom;
Ool00`00Oomoo`0fOol00?mood]oo`03001oogoo03Ioo`00ogooBgoo00<007ooOol0=Woo003oOom;
Ool00`00Oomoo`0fOol00>]oo`H000=oo`D000=oo`D00005Ool00000001oo`02000017oo001oogoo
1@000Woo0`0000Aoo`000000009oo`<00003Ool0000000=oo`<000Aoo`D000=oo`@000=oo`<00004
Ool000000008Ool00`00Oomoo`0fOol00>aoo`05001oogooOol00005Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`00009o
o`04001oogooOol20003Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00Woo00D0
07ooOomoo`0000=oo`03001oogoo00Moo`03001oogoo03Ioo`00k7oo00<007ooOol01goo00<007oo
Ool01Goo00<007ooOol00Woo00@007ooOol0009oo`03001oogoo009oo`03001oogoo00=oo`05001o
ogooOol00002Ool00`00Oomoo`02Ool01@00Oomoogoo00002Goo00<007ooOol00Woo00<007ooOol0
0Woo00D007ooOomoo`0000=oo`03001oogoo00Moo`03001oogoo03Ioo`00k7oo00<007oo00001goo
00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`03001oogoo009oo`03001oogoo00=o
o`05001oogooOol00003Ool50003Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000goo00<007ooOol01goo00<007ooOol0=Woo003/Ool30007Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool200001Goo000007oo000017oo00<007ooOol00goo0P000Woo00@007ooOol0
00Aoo`05001oogooOol00009Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoogoo0P000Woo
00<007ooOol01goo00<007ooOol0=Woo003/Ool00`00Ool00007Ool00`00Oomoo`03Ool30003Ool2
00001Goo001oogoo00000goo0`0017oo0P0000=oo`00000017oo10000goo1@0017oo0`001Goo1000
0goo0P0000=oo`0000002Woo00<007ooOol0=Woo003/Ool01@00Oomoogoo00001Goo00<007ooOol0
:goo00<007ooOol08goo00<007ooOol0=Woo003[Ool60004Ool20007Ool00`00Oomoo`0=Ool00`00
Oomoo`0MOol00`00Oomoo`0IOol00`00Oomoo`0fOol00?mood]oo`03001oogoo03Ioo`00ogooBgoo
00<007ooOol0=Woo003oOom;Ool00`00Oomoo`0fOol00?mood]oo`03001oogoo03Ioo`00ogooBgoo
00<007ooOol0=Woo003oOom;Ool00`00Oomoo`0fOol00?mood]oo`03001oogoo03Ioo`00ogooBgoo
00<007ooOol0=Woo003oOom;Ool00`00Oomoo`0fOol00?mood]oo`03001oogoo03Ioo`00ogooBgoo
00<007ooOol0=Woo003oOom;Ool00`00Oomoo`0fOol00?mood]oo`03001oogoo03Ioo`00ogooBgoo
00<007ooOol0=Woo003oOom;Ool00`00Oomoo`0fOol00?mood]oo`03001oogoo03Ioo`00ogooBgoo
00<007ooOol0=Woo003oOom;Ool00`00Oomoo`0fOol00?mood]oo`03001oogoo03Ioo`00ogooBgoo
00<007ooOol0=Woo003oOom;Ool00`00Oomoo`0fOol00?mood]oo`03001oogoo03Ioo`00ogooBgoo
00<007ooOol0=Woo003oOom;Ool00`00Oomoo`0fOol00?mood]oo`03001oogoo03Ioo`00ogooBgoo
00<007ooOol0=Woo003oOom;Ool00`00Oomoo`0fOol00?mood]oo`03001oogoo03Ioo`00ogooBgoo
00<007ooOol0=Woo003oOom;Ool00`00Oomoo`0fOol00?mood]oo`03001oogoo03Ioo`00ogooBgoo
00<007ooOol0=Woo000aOol=003oOol7Ool=000bOol002aoo`D000eoo`@00?ioo`@000eoo`D002eo
o`00:7oo10005Woo1@00mGoo10005Woo1000:Goo000VOol2000OOol2003`Ool3000NOol2000WOol0
02Aoo`8002=oo`800>aoo`8002=oo`8002Eoo`008Woo0P009goo0P00j7oo0P009goo0P008goo000P
Ool2000[Ool2003TOol2000[Ool2000QOol001ioo`8002moo`800>1oo`8002moo`8001moo`007Goo
00<007ooOol0<Goo00<007ooOol0g7oo00<007ooOol0<Goo00<007ooOol077oo000LOol00`00Oomo
o`0cOol00`00Oomoo`3KOol00`00Oomoo`0bOol00`00Oomoo`0KOol001Yoo`8003Moo`03001oogoo
0=Qoo`8003Ioo`8001]oo`0067oo0P00>Woo0P00eWoo0P00>Woo0P006Goo000GOol00`00Oomoo`0l
Ool00`00Oomoo`3BOol00`00Oomoo`0lOol00`00Oomoo`0FOol001Moo`03001oogoo03eoo`03001o
ogoo0=1oo`03001oogoo03eoo`03001oogoo01Ioo`005Woo00<007ooOol0?goo00<007ooOol0cWoo
00<007ooOol0?goo00<007ooOol05Goo000EOol00`00Oomoo`11Ool00`00Oomoo`3=Ool00`00Oomo
o`10Ool00`00Oomoo`0DOol001Aoo`03001oogoo04=oo`03001oogoo0<Yoo`8004Aoo`8001Aoo`00
4goo00<007ooOol0AGoo00<007ooOol0b7oo00<007ooOol0AWoo00<007ooOol04Goo000BOol00`00
Oomoo`16Ool00`00Oomoo`38Ool00`00Oomoo`16Ool00`00Oomoo`0AOol0015oo`03001oogoo04Qo
o`03001oogoo0<Ioo`03001oogoo04Qoo`03001oogoo011oo`004Goo00<007ooOol0BGoo00<007oo
Ool0a7oo00<007ooOol0BGoo00<007ooOol047oo000@Ool00`00Oomoo`1;Ool00`00Oomoo`32Ool0
0`00Oomoo`1;Ool00`00Oomoo`0?Ool0011oo`03001oogoo04]oo`03001oogoo0<9oo`03001oogoo
04aoo`03001oogoo00ioo`003goo00<007ooOol0CGoo00<007ooOol0`7oo00<007ooOol0CWoo00<0
07ooOol03Goo000?Ool00`00Oomoo`1=Ool00`00Oomoo`30Ool00`00Oomoo`1>Ool00`00Oomoo`0=
Ool000ioo`03001oogoo04moo`03001oogoo0;ioo`03001oogoo051oo`03001oogoo00aoo`003Goo
00<007ooOol0D7oo00<007ooOol0_Woo00<007ooOol0D7oo00<007ooOol037oo000=Ool00`00Oomo
o`1AOol00`00Oomoo`2lOol00`00Oomoo`1BOol00`00Oomoo`0;Ool000eoo`03001oogoo055oo`03
001oogoo0;aoo`03001oogoo059oo`03001oogoo00]oo`0037oo00<007ooOol0Dgoo00<007ooOol0
^Woo00<007ooOol0E7oo00<007ooOol02Woo000<Ool00`00Oomoo`1COol00`00Oomoo`2jOol00`00
Oomoo`1DOol00`00Oomoo`0:Ool000]oo`03001oogoo05Eoo`03001oogoo0;Qoo`03001oogoo05Eo
o`03001oogoo00Yoo`002goo00<007ooOol0EGoo00<007ooOol0^7oo00<007ooOol0EGoo00<007oo
Ool02Woo000;Ool00`00Oomoo`1EOol00`00Oomoo`2hOol00`00Oomoo`1EOol00`00Oomoo`0:Ool0
00Yoo`03001oogoo05Ioo`03001oogoo0;Qoo`03001oogoo05Ioo`03001oogoo00Uoo`002Woo00<0
07ooOol0EWoo00<007ooOol0^7oo00<007ooOol0EWoo00<007ooOol02Goo000:Ool00`00Oomoo`1G
Ool00`00Oomoo`2fOol00`00Oomoo`1GOol00`00Oomoo`09Ool000Yoo`03001oogoo05Moo`03001o
ogoo0;Ioo`03001oogoo05Moo`03001oogoo00Uoo`002Goo00<007ooOol0F7oo00<007ooOol0]Woo
00<007ooOol0F7oo00<007ooOol027oo0009Ool00`00Oomoo`1HOol00`00Oomoo`2fOol00`00Oomo
o`1HOol00`00Oomoo`08Ool000Uoo`03001oogoo05Uoo`03001oogoo0;Eoo`03001oogoo05Qoo`03
001oogoo00Qoo`002Goo00<007ooOol0FGoo00<007ooOol0XGoo0P004Woo00<007ooOol0F7oo00<0
07ooOol027oo0009Ool00`00Oomoo`14Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`2Q
Ool6000>Ool00`00Oomoo`0lOol00`00Oomoo`07Ool00`00Oomoo`0?Ool00`00Oomoo`08Ool000Uo
o`03001oogoo04=oo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo0:5oo`X000Uoo`03001o
ogoo03aoo`03001oogoo00Uoo`03001oogoo00ioo`03001oogoo00Qoo`002Goo00<007ooOol01Goo
0`0017oo1@002Woo0`000goo1@0017oo0`0000=oo`0000000Woo10001Goo0`0017oo00<007ooOol0
0Woo1@0017oo00<007ooOol01Woo00<007ooOol0XGoo3P001Goo00<007ooOol02goo1@0017oo1@00
0goo100017oo100017oo0`0000=oo`0000002Goo00@007ooOomoo`D000Eoo`03001oogoo00eoo`03
001oogoo00Qoo`002Goo00<007ooOol017oo00D007ooOomoo`0000Eoo`03001oogoo00]oo`03001o
ogoo00=oo`03001oogoo00Aoo`04001oogooOol20002Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo0:5ooa800003
Ool007oo00eoo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`00
17oo00@007ooOol000=oo`8000Yoo`05001oogooOol00003Ool00`00Oomoo`03Ool00`00Oomoo`0=
Ool00`00Oomoo`08Ool000Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001o
ogoo00]oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0008Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`06Oonh000>Ool01@00Oomoogoo
00001Goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Aoo`04001oogoo0004Ool00`00
Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0=Ool00`00Oomoo`08Ool000Uo
o`03001oogoo00=oo`04001oogooOol30004Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomo
o`05Ool50002Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`06Ool00`00Oomoo`2QOolB00000goo001oo`0=Ool01@00Oomoogoo00001Goo00<007oo
Ool00Woo00<007ooOol00Woo00@007ooOol000Aoo`04001oogoo0004Ool00`00Oomoo`08Ool00`00
Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`0=Ool00`00Oomoo`08Ool000Uoo`03001oogoo00=o
o`03001oogoo00Qoo`03001oogoo00]oo`03001oogoo00=oo`8000Eoo`03001oogoo009oo`04001o
ogoo0003Ool20003Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`06
Ool00`00Oomoo`2QOol>0005Ool00`00Oomoo`0<Ool40006Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool01000Oomoo`0017oo00@007ooOol000=oo`8000Yoo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00eoo`03001oogoo00Qoo`002Goo00<007ooOol00goo00<007ooOol027oo00<007ooOol0
2goo00<007ooOol00Woo0P0000Aoo`00000000=oo`@000Aoo`<00004Ool007ooOol50004Ool00`00
Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`2QOol:000:Ool00`00Oomoo`0;
Ool01@00Oomoogoo00001Goo00<007ooOol00goo100017oo100017oo0`0000=oo`00Ool02Goo00<0
07ooOol01Goo00<007ooOol00goo00<007ooOol03Goo00<007ooOol027oo0009Ool00`00Oomoo`04
Ool01@00Oomoogoo00001Goo00<007ooOol027oo00@007ooOol0009oo`03001oogoo01Qoo`03001o
ogoo00Ioo`04001oogooOol30005Ool00`00Oomoo`07Ool00`00Oomoo`2QOol6000>Ool00`00Oomo
o`0;Ool01@00Oomoogoo00001Goo00<007ooOol05goo00<007ooOol02Goo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo00ioo`03001oogoo00Qoo`002Goo00<007ooOol01Goo10000goo1@00
27oo1`0097oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol027oo00<007ooOol0XGoo0P00
4Woo00<007ooOol02Woo1@001Goo0P0067oo0P0037oo00<007ooOol00`0017oo00<007ooOol03goo
00<007ooOol027oo0009Ool00`00Oomoo`1HOol00`00Oomoo`2fOol00`00Oomoo`1HOol00`00Oomo
o`08Ool000Uoo`03001oogoo05Qoo`03001oogoo0;Ioo`03001oogoo05Qoo`03001oogoo00Qoo`00
2Woo00<007ooOol0Egoo00<007ooOol0]Woo00<007ooOol0Egoo00<007ooOol02Goo000:Ool00`00
Oomoo`1GOol00`00Oomoo`2fOol00`00Oomoo`1GOol00`00Oomoo`09Ool000Yoo`03001oogoo05Io
o`03001oogoo0;Qoo`03001oogoo05Ioo`03001oogoo00Uoo`002Woo00<007ooOol0EWoo00<007oo
Ool0^7oo00<007ooOol0EWoo00<007ooOol02Goo000;Ool00`00Oomoo`1EOol00`00Oomoo`2hOol0
0`00Oomoo`1EOol00`00Oomoo`0:Ool000]oo`03001oogoo05Eoo`03001oogoo0;Qoo`03001oogoo
05Eoo`03001oogoo00Yoo`002goo00<007ooOol0EGoo00<007ooOol0^7oo00<007ooOol0EGoo00<0
07ooOol02Woo000<Ool00`00Oomoo`1COol00`00Oomoo`2jOol00`00Oomoo`1DOol00`00Oomoo`0:
Ool000aoo`03001oogoo05=oo`03001oogoo0;Yoo`03001oogoo05Aoo`03001oogoo00Yoo`003Goo
00<007ooOol0DGoo00<007ooOol0_7oo00<007ooOol0DWoo00<007ooOol02goo000=Ool00`00Oomo
o`1AOol00`00Oomoo`2lOol00`00Oomoo`1BOol00`00Oomoo`0;Ool000eoo`03001oogoo051oo`03
001oogoo0;ioo`03001oogoo051oo`03001oogoo00aoo`003Goo00<007ooOol0D7oo00<007ooOol0
_Woo00<007ooOol0D7oo00<007ooOol037oo000>Ool00`00Oomoo`1>Ool00`00Oomoo`30Ool00`00
Oomoo`1>Ool00`00Oomoo`0=Ool000ioo`03001oogoo04ioo`03001oogoo0<1oo`03001oogoo04io
o`03001oogoo00eoo`003goo00<007ooOol0C7oo00<007ooOol0`Woo00<007ooOol0C7oo00<007oo
Ool03Woo000@Ool00`00Oomoo`1;Ool00`00Oomoo`32Ool00`00Oomoo`1<Ool00`00Oomoo`0>Ool0
015oo`03001oogoo04Uoo`03001oogoo0<Aoo`03001oogoo04Yoo`03001oogoo00moo`004Goo00<0
07ooOol0BGoo00<007ooOol0a7oo00<007ooOol0BGoo00<007ooOol047oo000BOol00`00Oomoo`17
Ool00`00Oomoo`36Ool00`00Oomoo`17Ool00`00Oomoo`0AOol0019oo`03001oogoo04Ioo`03001o
ogoo0<Qoo`03001oogoo04Ioo`03001oogoo015oo`004goo0P00AGoo00<007ooOol0bWoo00<007oo
Ool0A7oo00<007ooOol04Woo000EOol00`00Oomoo`11Ool00`00Oomoo`3<Ool00`00Oomoo`12Ool0
0`00Oomoo`0COol001Eoo`03001oogoo041oo`03001oogoo0<ioo`03001oogoo041oo`03001oogoo
01Aoo`005Woo00<007ooOol0?Woo00<007ooOol0d7oo00<007ooOol0?Woo00<007ooOol05Goo000G
Ool00`00Oomoo`0mOol00`00Oomoo`3@Ool00`00Oomoo`0mOol00`00Oomoo`0FOol001Qoo`03001o
ogoo03Yoo`8002moo`<000Ioo`D000=oo`@000Eoo`03001oo`0000Qoo`H0009oo`D000Aoo`@0009o
o`<00005Ool00000Ool00008Ool5000;Ool30004Ool40009Ool5000`Ool2000lOol00`00Oomoo`0G
Ool001Uoo`03001oogoo03Qoo`03001oogoo031oo`03001oogoo00Moo`03001oogoo009oo`03001o
ogoo009oo`09001oogooOol007oo001oo`0000Uoo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`002Woo00<007ooOol02Woo00D007ooOomoo`00009o
o`03001oogoo009oo`03001oogoo00Ioo`05001oogooOol0000bOol00`00Oomoo`0hOol00`00Oomo
o`0HOol001Yoo`03001oogoo03Ioo`03001oogoo035oo`03001oogoo00Moo`03001oogoo009oo`03
001oogoo009oo`09001oogooOol007oo001oo`0000Uoo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`002Woo00<007ooOol02Woo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol01goo00<007ooOol0=7oo00<007ooOol0=Woo00<007ooOol06Goo
000KOol2000eOol00`00Oomoo`0bOol00`00Ool00007Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
2@00Oomoogoo001oo`00Ool00009Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Yoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo009o
o`03001oogoo00Qoo`03001oogoo03Aoo`8003Aoo`8001aoo`007Goo0P00<Goo0P00=Goo0`001goo
00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00Moo`03001oogoo
00Aoo`8000Eoo`03001oogoo009oo`03001oogoo00800005Ool00000Ool0000:Ool00`00Oomoo`0:
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`0eOol00`00Oomoo`0_
Ool2000NOol001moo`03001oogoo02eoo`03001oogoo03Eoo`03001oo`0000Moo`03001oogoo00=o
o`@000=oo`<00004Ool000000006Ool60002Ool2000017oo000000000goo10000Woo0P0000Eoo`00
Oomoo`0000]oo`03001oogoo00Uoo`D000Aoo`@000eoo`03001oogoo03Eoo`03001oogoo02eoo`03
001oogoo01ioo`0087oo00<007ooOol0:goo00<007ooOol0=Woo00D007ooOomoo`0000Eoo`03001o
ogoo01Uoo`03001oogoo029oo`<000aoo`03001oogoo019oo`05001oogooOol0000hOol00`00Oomo
o`0[Ool00`00Oomoo`0OOol0025oo`8002Uoo`8003Qoo`H000Aoo`8001aoo`<002=oo`03001oogoo
021oo`<003Yoo`8002Uoo`80029oo`008goo0P009Goo0P00jWoo0`0097oo0P0097oo000UOol4000L
Ool5003_Ool4000LOol4000VOol002Uoo`<001Moo`800?Qoo`8001Qoo`8002Yoo`00;7oo1P002Woo
1`00o7oo1`002Woo1`00;7oo000bOol:003oOol;Ool:000cOol003Moo`03001oogoo0?moodYoo`00
=Woo0`00ogooBgoo000fOol3003oOom;Ool003Ioo`<00?mood]oo`00=Woo0`00ogooBgoo000eOol0
1@00Ool007oo0000ogooBWoo000eOol01@00Ool007oo0000ogooBWoo000eOol01@00Ool007oo0000
ogooBWoo000eOol01@00Ool007oo0000ogooBWoo000dOol01000Oomoo`000Woo00<007ooOol0ogoo
Agoo000dOol01000Oomoo`000Woo00<007ooOol0ogooAgoo000dOol01000Oomoo`000Woo00<007oo
Ool0ogooAgoo000dOol01000Oomoo`000Woo00<007ooOol0ogooAgoo000cOol01@00Oomoogoo0000
0goo00<007ooOol0ogooAWoo000cOol01@00Oomoogoo00000goo00<007ooOol0ogooAWoo000cOol0
1@00Oomoogoo00000goo00<007ooOol0ogooAWoo000cOol01@00Oomoogoo00000goo00<007ooOol0
ogooAWoo000bOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`3oOom5Ool0039oo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo0?moodEoo`00=goo00<007ooOol0ogooBWoo000gOol0
0`00Oomoo`3oOom:Ool003Moo`03001oogoo0?moodYoo`00=goo00<007ooOol0ogooBWoo000gOol0
0`00Oomoo`3oOom:Ool003Moo`03001oogoo0?moodYoo`00=goo00<007ooOol0ogooBWoo000gOol0
0`00Oomoo`3oOom:Ool003Moo`03001oogoo0?moodYoo`00=goo00<007ooOol0ogooBWoo000gOol0
0`00Oomoo`3oOom:Ool003Moo`03001oogoo0?moodYoo`00=goo00<007ooOol0ogooBWoo000gOol0
0`00Oomoo`3oOom:Ool003Moo`03001oogoo0?moodYoo`00=goo00<007ooOol0ogooBWoo000gOol0
0`00Oomoo`3oOom:Ool003Moo`03001oogoo0?moodYoo`00=goo00<007ooOol0ogooBWoo000gOol0
0`00Oomoo`3oOom:Ool003Moo`03001oogoo0?moodYoo`00=goo00<007ooOol0ogooBWoo000gOol0
0`00Oomoo`3oOom:Ool003Moo`03001oogoo0?moodYoo`00=goo00<007ooOol0ogooBWoo000gOol0
0`00Oomoo`3oOom:Ool003Moo`03001oogoo0?moodYoo`00=goo00<007ooOol0ogooBWoo000gOol0
0`00Oomoo`3oOom:Ool003Moo`03001oogoo02Aoo`03001oogoo00Moo`03001oogoo0?mooaUoo`00
=goo00<007ooOol08goo00<007ooOol02Goo00<007ooOol0ogoo67oo000gOol00`00Oomoo`0FOol2
000017oo000000001Woo00<007ooOol00goo0`001Goo00<007ooOol0ogoo5goo000gOol00`00Oomo
o`0GOol20003Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0
ogoo5goo000gOol00`00Oomoo`0GOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`3oOolGOol003Moo`03001oogoo01Moo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?mooaMoo`00=goo00<007ooOol0
5goo0P000goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ogoo5goo
000gOol00`00Oomoo`0GOol00`00Ool000020006Ool01000Oomoogoo1@001Goo00<007ooOol0ogoo
5goo000gOol00`00Oomoo`0GOol00`00Oomoo`09Ool01@00Oomoogoo00001goo00<007ooOol0ogoo
67oo000gOol00`00Oomoo`0FOol2000<Ool00`00Oomoo`07Ool00`00Oomoo`3oOolIOol003Moo`03
001oogoo0?moodYoo`00=goo00<007ooOol0ogooBWoo000gOol00`00Oomoo`3oOom:Ool003Moo`03
001oogoo0?moodYoo`00=goo00<007ooOol0ogooBWoo000gOol00`00Oomoo`3oOom:Ool003Moo`03
001oogoo0?moodYoo`00=goo00<007ooOol0ogooBWoo000gOol00`00Oomoo`3oOom:Ool003Moo`03
001oogoo0?moodYoo`00=goo00<007ooOol0ogooBWoo000gOol00`00Oomoo`3oOom:Ool003Moo`03
001oogoo0?moodYoo`00=goo00<007ooOol0ogooBWoo000gOol00`00Oomoo`3oOom:Ool003Moo`03
001oogoo0?moodYoo`00=goo00<007ooOol0ogooBWoo000gOol00`00Oomoo`3oOom:Ool003Moo`03
001oogoo0?moodYoo`00=goo00<007ooOol0ogooBWoo000gOol00`00Oomoo`3oOom:Ool003Moo`03
001oogoo0?moodYoo`00=goo00<007ooOol0ogooBWoo000gOol00`00Oomoo`3oOom:Ool003Moo`03
001oogoo0?moodYoo`00=goo00<007ooOol0ogooBWoo000gOol00`00Oomoo`3oOom:Ool003Moo`03
001oogoo0?moodYoo`00=goo00<007ooOol0ogooBWoo000gOol00`00Oomoo`3oOom:Ool003Moo`03
001oogoo0?moodYoo`00=goo00<007ooOol0ogooBWoo000gOol00`00Oomoo`3oOom:Ool003Moo`03
001oogoo0?moodYoo`00ogooQ7oo003oOon4Ool00?moohAoo`00ogooQ7oo003oOon4Ool00?moohAo
o`00\
\>"],
      ImageRangeCache->{{{134.625, 443.375}, {293.875, 
      62.625}} -> {-2.43669, -0.721954, 0.0136218, 0.0136218}}]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "We resolve the model of  fig. 1. Let",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[\(x\_1\),
              "TraditionalForm"], "(", "t", ")"}]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(x\_2\),
            "TraditionalForm"], "(", "t", ")"}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`t \[GreaterEqual] 0\)]],
  ", is the mass of the drug in compartment 1 and 2, respectively.  Then we \
can describe the process as follow"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\ \)\(\[DifferentialD]x\_1\/\[DifferentialD]t = \ 
      b(t)\  - \ 
        drug\ distribution\ rate\ from\ 1\ to\ 2\)\)\)], "NumberedEquation"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\ \)\(\[DifferentialD]x\_2\/\[DifferentialD]t = \ 
      inflow\ rate\  - \ 
        outflow\ rate\ \((elimination)\)\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "The previous equations are commonly called ",
  StyleBox["mass balance equation",
    FontWeight->"Bold"],
  ".  If it is assumed that rate of transference from each compartment ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " is proportional to the mass (or concentration) in this compartment, then \
(3) and (4) become"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[DifferentialD]x\_1\/\[DifferentialD]t = \ 
      b(t)\  - k\_12\ x\_1\)], "NumberedEquation"],

Cell[BoxData[
    \(TraditionalForm\`\[DifferentialD]x\_2\/\[DifferentialD]t = \ 
      k\_12\ x\_1\  - \ \(\(k\_20\ x\_1\)\(\[IndentingNewLine]\)\)\)], \
"NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`k\_12\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\_20\)]],
  "  are the constants  (>0) of  proportionality  from 1 to 2 and from 2 to \
environment (elimination). This process is a simple case of first-order \
kinetics. \nBoth ordinary differential equations (ODE) with appropriate \
initial conditions ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  "(0) and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(\ \)\)\_2\)]],
  "(0) constitute the compartmental metabolic model. In matrix-vector format \
the system of ordinary differential equation (SODE)  model is "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(x\_1' \((t)\)\)},
              {\(x\_2' \((t)\)\)}
              }], ")"}], " ", "=", 
        RowBox[{
          FormBox[
            RowBox[{"(", GridBox[{
                  {\(\(-k\_12\)\(\ \)\), "0"},
                  {\(k\_12\), \(k\_20\)}
                  }], ")"}],
            "TraditionalForm"], "+", 
          FormBox[
            RowBox[{"(", GridBox[{
                  {\(b(t)\)},
                  {"0"}
                  }], ")"}],
            "TraditionalForm"], "\n"}]}], 
      TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  "This system can be solved with ",
  StyleBox["DSolve", "DisplayMath"],
  " or using SystemDSolve. Here is assumed  k12= 0.3, and k20 = 0.05 and b(t) \
= {0, 0}, an as initial condition is taken {1,0}. The solution is plotted ."
}], "MathCaption"],

Cell["The first step is build the compartmental matrix", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(model1\  = \ 
      CompartMatrix[2, \ {{1, 2, \ 0.3}, \ {2, 0, \ 0.05}}]\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \({{\(-0.3`\), 0}, {0.3`, \(-0.05`\)}}\)], "Output",
  CellLabel->"Out[38]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({\ x1[t_], x2[t_]}\  = \ {x\_1[t], x\_2[t]} /. 
        SystemDSolve[model1, {1, 0}, {0, 0}, t, t, \ x]\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \({1.`\ \[ExponentialE]\^\(\(-0.3`\)\ t\), \(-1.2`\)\ \[ExponentialE]\^\(\
\(-0.3`\)\ t\) + 1.2`\ \[ExponentialE]\^\(\(-0.05`\)\ t\)}\)], "Output",
  CellLabel->"Out[39]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{x1[t], x2[t]}, \ {t, 0, 100}, \[IndentingNewLine]\ 
      PlotStyle \[Rule] {\[IndentingNewLine]{AbsoluteThickness[
              0.5]}, {AbsoluteThickness[1.5]}}, \ 
      AxesLabel \[Rule] {"\<days\>", \ "\<r\>"}, 
      PlotLegend \[Rule] {"\<x1\>", "\<x2\>"}, 
      LegendPosition \[Rule] {0.2, \ \(-0.2\)}, \ 
      LegendSize \[Rule] {0.3, \ 0.3}]\)], "Input",
  CellLabel->"In[40]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0147151 0.588605 [
[.21429 .00222 -6 -9 ]
[.21429 .00222 6 0 ]
[.40476 .00222 -6 -9 ]
[.40476 .00222 6 0 ]
[.59524 .00222 -6 -9 ]
[.59524 .00222 6 0 ]
[.78571 .00222 -6 -9 ]
[.78571 .00222 6 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[1.025 .01472 0 -6.25 ]
[1.025 .01472 28 6.25 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(20)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(40)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(60)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(80)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(100)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.03279 .45835 L
.04262 .3402 L
.05288 .25028 L
.06244 .18901 L
.0731 .1393 L
.0828 .1065 L
.094 .07923 L
.10458 .06094 L
.11428 .04877 L
.12455 .03935 L
.13333 .0334 L
.14299 .0285 L
.15313 .02473 L
.1624 .02219 L
.17311 .02005 L
.18328 .01859 L
.19287 .01758 L
.20309 .01679 L
.21273 .01625 L
.22147 .01588 L
.2315 .01556 L
.24072 .01535 L
.25085 .01518 L
.26154 .01504 L
.27102 .01496 L
.28118 .01489 L
.29077 .01485 L
.29951 .01481 L
.30943 .01479 L
.3186 .01477 L
.32866 .01475 L
.33936 .01474 L
.34873 .01474 L
.35883 .01473 L
.36837 .01473 L
.37711 .01472 L
.38691 .01472 L
.39603 .01472 L
.40604 .01472 L
.41673 .01472 L
.42698 .01472 L
.43808 .01472 L
.44856 .01472 L
.45823 .01472 L
.46792 .01472 L
.47699 .01472 L
.48694 .01472 L
.49763 .01472 L
.50776 .01472 L
Mistroke
.51881 .01472 L
.52924 .01472 L
.53891 .01472 L
.5495 .01472 L
.55947 .01472 L
.56842 .01472 L
.57809 .01472 L
.58762 .01472 L
.59807 .01472 L
.60898 .01472 L
.61915 .01472 L
.62963 .01472 L
.63954 .01472 L
.64844 .01472 L
.65811 .01472 L
.66753 .01472 L
.67792 .01472 L
.68877 .01472 L
.69894 .01472 L
.7088 .01472 L
.71916 .01472 L
.72801 .01472 L
.73768 .01472 L
.74798 .01472 L
.75733 .01472 L
.76812 .01472 L
.7783 .01472 L
.78804 .01472 L
.79835 .01472 L
.80715 .01472 L
.81681 .01472 L
.827 .01472 L
.8363 .01472 L
.84703 .01472 L
.85721 .01472 L
.86684 .01472 L
.87709 .01472 L
.88584 .01472 L
.8955 .01472 L
.90558 .01472 L
.91483 .01472 L
.92498 .01472 L
.93567 .01472 L
.9452 .01472 L
.95539 .01472 L
.96501 .01472 L
.97375 .01472 L
.97619 .01472 L
Mfstroke
1.5 Mabswid
.02381 .01472 m
.02846 .09387 L
.03279 .15616 L
.03793 .21789 L
.04262 .26405 L
.0522 .3344 L
.05746 .36197 L
.06244 .38222 L
.06754 .39802 L
.07034 .40484 L
.07295 .4102 L
.07757 .41746 L
.08001 .4203 L
.08265 .42265 L
.08401 .42361 L
.08546 .42443 L
.08705 .42514 L
.08852 .4256 L
.08924 .42577 L
.09003 .4259 L
.09077 .42599 L
.09145 .42603 L
.09274 .42603 L
.09339 .42599 L
.0941 .42591 L
.0948 .4258 L
.09547 .42567 L
.09672 .42535 L
.09806 .42491 L
.09952 .42432 L
.10458 .42146 L
.10943 .4177 L
.11398 .41342 L
.12435 .4016 L
.14536 .37249 L
.18405 .31472 L
.22519 .25886 L
.26481 .21366 L
.30292 .17777 L
.34348 .14655 L
.38253 .12213 L
.42403 .10111 L
.46401 .08475 L
.50247 .07195 L
.54339 .06088 L
.5828 .05225 L
.62068 .04548 L
.66102 .03961 L
.69985 .03502 L
.74112 .03106 L
Mistroke
.78088 .02798 L
.81913 .02557 L
.85983 .02348 L
.89901 .02185 L
.94064 .02045 L
.97619 .01947 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.61905 .18997 m
.61905 .33283 L
.7619 .33283 L
.7619 .18997 L
F
1 g
.59524 .21378 m
.59524 .35664 L
.7381 .35664 L
.7381 .21378 L
F
0 g
.001 w
[ ] 0 setdash
.59524 .21378 m
.7381 .21378 L
.7381 .35664 L
.59524 .35664 L
.59524 .21378 L
s
% Start of sub-graphic
p
0.595238 0.213779 0.738095 0.356636 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0396825 0.396825 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0714286 0.35119 0.468254 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
1.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .26984 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x2) show
75.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.531746 0.35119 0.928571 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .73016 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x1) show
75.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[40]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00@@3oool4000000<0oooo0P00000T0?ooo`<000000P3oool200000240
oooo0`0000040?ooo`8000008`3oool2000000@0oooo0P00000N0?ooo`D000000P3oool2000000@0
oooo0P00000Y0?ooo`00@@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000002@0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0N0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000008@3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000001l0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool09P3oool00480oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`00000Q0?ooo`D0000000D0oooo0000003oool0oooo0000000P0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000008@3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000001l0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool09P3oool004<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo01l0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`00000P0?ooo`<000000`3oool010000000oooo0?ooo`00000R0?ooo`8000000`3oool0
10000000oooo0?ooo`00000O0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo02H0oooo00110?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000008P3oool00`000000oooo000000020?ooo`040000003oool0oooo
00000240oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000Q0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000007`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0V0?ooo`00@P3oool20000
00@0oooo0P00000T0?ooo`8000000`3oool200000280oooo0`0000030?ooo`8000008`3oool20000
00@0oooo0P00000O0?ooo`800000103oool2000000@0oooo0P00000Y0?ooo`00o`3ooolQ0?ooo`00
6`3oool00`000000oooo0?ooo`3/0?ooo`800000503oool001/0oooo00<000000?ooo`3oool0k@3o
ool00`000000oooo0?ooo`0B0?ooo`006`3oool00`000000oooo0?ooo`3Q0?ooo`@0000000<0oooo
0000000000000`0000030?ooo`040000003oool0oooo0?ooo`<000003@3oool001H0ooooh@000007
0?ooo`040000003oool0oooo00000080oooo100000030?ooo`030000003oool0000000D0oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0oooo5P0000060?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`040000003o
ool0oooo000000D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`03000000d0
oooo000K0?ooo`030000003oool0oooo01`0oooo1@0000070?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo
7`00000>0?ooo`<000000`3oool3000000050?ooo`00000000000000003oool00P0000000`3oool0
000000000002000000`0oooo000K0?ooo`030000003oool0oooo01X0oooo0P0000270?oooa400000
;`3oool00`000000oooo0?ooo`0L0?ooo`006`3oool00`000000oooo0?ooo`0H0?ooo`800000P03o
ool9000003l0oooo0P00000N0?ooo`006`3oool00`000000oooo0?ooo`0F0?ooo`800000N@3oool9
000006P0oooo000K0?ooo`030000003oool0oooo01@0oooo0P00001b0?ooo`T00000L@3oool001/0
oooo0P00000D0?ooo`030000003oool0oooo06/0oooo1`00001j0?ooo`006`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo06P0oooo100000210?ooo`006`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo06D0oooo100000250?ooo`006`3oool200000140oooo00<00000
0?ooo`3oool0HP3oool4000008T0oooo000K0?ooo`800000403oool00`000000oooo0?ooo`1N0?oo
o`D00000S@3oool001/0oooo0P00000?0?ooo`030000003oool0oooo05X0oooo1@00002B0?ooo`00
6`3oool2000000l0oooo00<000000?ooo`3oool0EP3oool4000009L0oooo000K0?ooo`8000003P3o
ool00`000000oooo0?ooo`1E0?ooo`800000V`3oool001/0oooo0P00000>0?ooo`030000003oool0
oooo0580oooo0`00002M0?ooo`006`3oool2000000h0oooo00<000000?ooo`3oool0C`3oool30000
0:00oooo000K0?ooo`8000003@3oool00`000000oooo0?ooo`1>0?ooo`800000X`3oool001/0oooo
0P00000=0?ooo`030000003oool0oooo04`0oooo0P00002U0?ooo`006`3oool2000000d0oooo00<0
00000?ooo`3oool0BP3oool200000:L0oooo000K0?ooo`800000303oool00`000000oooo0?ooo`18
0?ooo`<00000Z@3oool001/0oooo0P00000<0?ooo`030000003oool0oooo04H0oooo0P00002/0?oo
o`006`3oool2000000`0oooo00<000000?ooo`3oool0A03oool200000:h0oooo000K0?ooo`800000
2`3oool00`000000oooo0?ooo`130?ooo`800000/03oool001/0oooo0P00000;0?ooo`030000003o
ool0oooo0440oooo0P00002b0?ooo`002@3oool2000000@0oooo0P0000030?ooo`@000000`3oool2
000000X0oooo00<000000?ooo`3oool0@03oool200000;@0oooo00080?ooo`040000003oool0oooo
000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo000000090?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool0]03oool000P0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0?ooo`030?ooo`<00000203oool00`000000oooo0?ooo`0n0?ooo`800000]`3oool0
00P0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000P0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`2g0?ooo`00203oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000203o
ool00`000000oooo0?ooo`0k0?ooo`800000^P3oool000T0oooo0P00000:0?ooo`800000103oool0
0`000000oooo000000080?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0^P3oool0
01/0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
0;/0oooo000K0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0>03oool200000;h0
oooo000K0?ooo`<000001`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0;h0oooo
000K0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`2o0?ooo`006`3oool00`000000oooo000000070?ooo`030000003oool0oooo03@0oooo0P000032
0?ooo`006`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool0`P3oool001/0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo0<<0oooo000K0?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`1E0?ooobT00000AP3oool001/0oooo00@000000?oo
o`3oool000001@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo05H0oooo:@000016
0?ooo`006`3oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`1G0?ooobT00000AP3oool001/0oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`0^0?ooo`800000FP3ooolY000004H0oooo000K0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1J0?ooobT00000AP3oool001/0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0F`3ooolY000004H0oooo000K0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo05D0oooo<00000160?ooo`006`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo02H0oooo1`0000160?ooo`006`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
02H0oooo1`0000160?ooo`006`3oool200000080oooo00D000000?ooo`3oool0oooo0000000[0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool09P3oool7000004H0oooo000K0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
05T0oooo00<000000?ooo`3oool09P3oool7000004H0oooo000K0?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo05X0oooo00<000000?oo
o`3oool09P3oool7000004H0oooo000K0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool09P3oool70000
04H0oooo00090?ooo`800000103oool2000000D0oooo0`0000020?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool09P3oool7000004H0oooo00080?ooo`040000003oool0oooo000000/0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0000002P0oooo00<000000?ooo`3oool0G03oool0
0`000000oooo0?ooo`0V0?ooo`L00000AP3oool000P0oooo00@000000?ooo`3oool00000203oool5
00000080oooo0`0000020?ooo`030000003oool0000002L0oooo00<000000?ooo`3oool0G@3oool0
0`000000oooo0?ooo`0?0?ooo`80000000<0oooo0000000000000P3oool4000000`0oooo1`000016
0?ooo`00203oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0000000V0?ooo`030000003oool0oooo05h0oooo00<0
00000?ooo`3oool0403oool00`000000oooo000000030?ooo`030000003oool0oooo00d0oooo1`00
00160?ooo`00203oool010000000oooo0?ooo`0000090?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0000000U0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool0300000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303o
ool7000004H0oooo00090?ooo`8000002`3oool2000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0000000T0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool03`3oool2
000000030?ooo`000000000000@0oooo00<000000?ooo`3oool02`3oool7000004H0oooo000K0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`000000903oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo01H0oooo00@000000?ooo`3oool00000303oool7000004H0oooo000K0?oo
o`030000003oool0oooo0080oooo0P00000T0?ooo`030000003oool0oooo0640oooo00<000000?oo
o`3oool05`3oool2000000d0oooo1`0000160?ooo`006`3oool00`000000oooo0?ooo`020?ooo`80
00008`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo02H0oooo1`0000160?ooo`00
6`3oool2000000<0oooo0P00000S0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0
9P3oool7000004H0oooo000K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo02H0oooo1`0000160?ooo`006`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0I03oool0
0`000000oooo0?ooo`0V0?ooo`L00000AP3oool001/0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool09P3oool70000
04H0oooo000K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`1U0?ooo`030000003oool0oooo02H0oooo1`0000160?ooo`006`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0IP3oool00`000000oooo
0?ooo`0V0?ooo`L00000AP3oool001/0oooo0P0000040?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0I`3oool00`000000oooo0?ooo`0V0?ooo`L00000AP3oool001/0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo06L0oooo00<00000
0?ooo`3oool09P3oool7000004H0oooo000K0?ooo`030000003oool0oooo0080oooo0P00000M0?oo
o`030000003oool0oooo06P0oooo00<000000?ooo`3oool09P3oool7000004H0oooo000K0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`0000006`3oool00`000000oooo0?ooo`1Y0?ooo`03
0000003oool0oooo02H0oooo1`0000160?ooo`006`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000001/0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0V0?ooo`L00000
AP3oool001/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000J0?ooo`030000003o
ool0oooo06X0oooo00<000000?ooo`3oool09P3oool7000004H0oooo000K0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0
oooo00l0oooo0P0000000`3oool00000000000020?ooo`D000002`3oool7000004H0oooo000K0?oo
o`8000000`3oool00`000000oooo0000000I0?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0403oool00`000000oooo000000050?ooo`030000003oool0oooo00/0oooo1`0000160?oo
o`006`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000001P0oooo00<000000?ooo`3o
ool0K03oool00`000000oooo0?ooo`0<000000D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0;0?ooo`L00000AP3oool001/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0000000G0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool03`3oool2000000030?oo
o`000000000000@0oooo00<000000?ooo`3oool02`3oool7000004H0oooo000K0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000005P3oool00`000000oooo0?ooo`1]0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool02`3oool7000004H0oooo00090?ooo`800000103o
ool2000000<0oooo0`0000040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
5@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo01L0oooo0P00000=0?ooo`L00000
AP3oool000P0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
06l0oooo00<000000?ooo`3oool09P3oool7000004H0oooo00080?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000000`3oool3000000030?ooo`000000oooo0080oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0BP3oool000P0oooo00@000000?ooo`3oool00000203oool3000000@0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0L03o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo04X0oooo00080?ooo`040000003oool0
oooo000000T0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0BP3oool000T0oooo0P00000:0?ooo`<000000`3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1a0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0BP3oool001/0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0LP3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo04X0oooo000K0?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`1:0?ooo`006`3oool01@000000oooo0?ooo`3oool0000000D0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1d0?ooobX00000C03oool001/0oooo0P00
00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`3Z0?ooo`006`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0j`3oool001/0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0>`0oooo000K0?ooo`040000003oool0oooo000000L0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`3/0?ooo`006`3oool010000000oooo0?ooo`00
00070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0k@3oool001/0oooo00@00000
0?ooo`3oool00000203oool2000000@0oooo0`00003`0?ooo`006`3oool010000000oooo0?ooo`00
000:0?ooo`@00000l`3oool001/0oooo0P0000000`3oool000000?ooo`3o0?ooo`40oooo000K0?oo
o`040000003oool0oooo00000?l0oooo0P3oool001/0oooo00@000000?ooo`3oool00000o`3oool2
0?ooo`006`3oool00`000000oooo0000003o0?ooo`<0oooo000K0?ooo`030000003oool000000?l0
oooo0`3oool001/0oooo00<000000?ooo`000000o`3oool30?ooo`006`3oool300000?l0oooo0`3o
ool001/0oooo00<000000?ooo`000000o`3oool30?ooo`006`3oool00`000000oooo0000003o0?oo
o`<0oooo000K0?ooo`030000003oool000000?l0oooo0`3oool001/0oooo00<000000?ooo`000000
o`3oool30?ooo`002@3oool2000000@0oooo0P0000040?ooo`800000103oool00`000000oooo0000
003o0?ooo`<0oooo00080?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0000003o0?ooo`<0oooo00080?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000`3oool300000?l0oooo0`3oool000P0oooo00@000000?ooo`3oool0
00002@3oool2000000@0oooo00<000000?ooo`000000o`3oool30?ooo`00203oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo0P00003o0?ooo`@0oooo00090?ooo`80
00002P3oool2000000@0oooo0P00003o0?ooo`@0oooo000K0?ooo`800000o`3oool40?ooo`006`3o
ool200000?l0oooo103oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`800000o`3oool40?oo
o`006`3oool200000?l0oooo103oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`800000o`3o
ool40?ooo`006`3oool200000?l0oooo103oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`80
0000o`3oool40?ooo`006`3oool200000?l0oooo103oool001/0oooo0P00003o0?ooo`@0oooo000K
0?ooo`800000o`3oool40?ooo`006`3oool200000?l0oooo103oool001/0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`006`3oool200000?l0oooo103oool001/0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo
0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00503oool500000080oooo
00<000000?ooo`3oool0o`3oool30?ooo`005P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0?l0oooo0`3oool001H0oooo00<000000?ooo`3oool00P3oool300000?l0oooo0`3oool0
01H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000F0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool30?ooo`005@3oool2000000@0oooo
00<000000?ooo`3oool0o`3oool30?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`006@3oool400000?l0oooo103oool001X0oooo00<00000
0?ooo`3oool0o`3oool40?ooo`006P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000I0?ooo`@0
0000o`3oool40?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.05261, -0.648943, \
0.00733523, 0.00733523}, {{7.125, 279.813}, {172.688, 4.1875}} -> {-13.1101, \
-0.135946, 0.469539, 0.00759728}, {{170.75, 211.625}, {115.688, 74.8125}} -> \
{-14.1361, -3.8762, 0.0822027, 0.0616521}, {{172.938, 185.063}, {112.75, \
96.5}} -> {-15.0012, -20.2648, 0.0865988, 0.28024}, {{172.938, 185.063}, \
{93.9375, 77.6875}} -> {-15.0012, -25.5368, 0.0865988, 0.28024}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[model1, x1, x2]\)], "Input",
  CellLabel->"In[41]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Two inputs model ", "SubsubsectionIcon"],

Cell[TextData[{
  "Below it is  shown a compartmental model with two inputs in compartment 1. \
One input represents a continuous flow  ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_1\)(t)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`b\_1\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < T\)]],
  " and the other one consist in a single input  (bolus) ",
  Cell[BoxData[
      \(TraditionalForm\`b\_2\)]],
  "(t) =",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  " that it is equivalent to take as initial condition ",
  Cell[BoxData[
      \(x\_1\)]],
  "(0) = ",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  ". "
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .62222 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.12963 0.21164 0.332275 0.21164 [
[ 0 0 0 0 ]
[ 1 .62222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .62222 L
0 .62222 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125  moveto 0 0 lineto 
-0.05 -0.0125  lineto stroke
} ifelse
grestore
} def
/MAarrowhead2 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .60741 m
.06614 .41693 L
s
% Start of user PostScript
-0.5 1.3 -0.3 0.4 MAarrowhead1
% End of user PostScript
gsave
.10847 .50159 -80.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
75.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.875 12.750 moveto
(H) show
85.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.875 12.750 moveto
(L) show
97.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.12963 .33228 .10582 0 365.73 arc
s
gsave
.12963 .33228 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.12963 .22646 m
.12963 .01481 L
s
% Start of user PostScript
0 -0.5 0 -1.5 MAarrowhead2
% End of user PostScript
gsave
.06614 .12063 -70.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23545 .3746 m
.76455 .3746 L
s
% Start of user PostScript
0.5 0.2 3. 0.2 MAarrowhead2
% End of user PostScript
gsave
.5 .41693 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.76455 .28995 m
.23545 .28995 L
s
% Start of user PostScript
3. -0.2 0.5 -0.2 MAarrowhead2
% End of user PostScript
gsave
.5 .24762 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.87037 .33228 .10582 0 365.73 arc
s
gsave
.87037 .33228 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23545 .60741 m
.19312 .41693 L
s
% Start of user PostScript
0.5 1.3 0.3 0.4 MAarrowhead1
% End of user PostScript
gsave
.29894 .50159 -77.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.875 12.750 moveto
(H) show
79.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
85.875 12.750 moveto
(L) show
91.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{288, 179.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000ga000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol002ioo`03001oogoo0?moocQoo`00;Woo00<007ooOol0
ogoo>7oo000^Ool2003oOoliOol002eoo`<00?moocUoo`00;Goo0`00ogoo>Goo000]Ool3003oOoli
Ool002eoo`@00?moocQoo`00;7oo1@00ogoo>7oo000/Ool5003oOolhOol002aoo`H00?moocMoo`00
;7oo1P00ogoo=goo000/Ool6003oOolgOol002]oo`L00?moocMoo`00:goo2000ogoo=Woo000[Ool8
003oOolfOol002]oo`P00?moocIoo`00:Woo2@00ogoo=Woo000ZOol:003oOoleOol002Yoo`X00?mo
ocEoo`00;Woo00<007ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?mo
ocQoo`00;Woo00<007ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?mo
ocQoo`00;Woo00<007ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?mo
ocQoo`00;Woo00<007ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?mo
ocQoo`00;Woo00<007ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?mo
ocQoo`00;Woo00<007ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?mo
ocQoo`00;Woo00<007ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?mo
ocQoo`00;Woo00<007ooOol0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol001Ioo`D0009oo`03001o
ogoo00ioo`03001oogoo0?moocQoo`003goo0P000Woo0`000Woo00L007ooOomoo`00Ool0000?Ool0
0`00Oomoo`3oOolhOol0011oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000moo`03001oogoo
0?moocQoo`0047oo00<007oo00001Goo00L007ooOomoo`00Ool0000?Ool00`00Oomoo`3oOolhOol0
011oo`<000Eoo`07001oogooOol007oo00003goo00<007ooOol0ogoo>7oo000@Ool01000Oomoo`00
0goo0P0017oo00<007ooOol03Woo00<007ooOol0ogoo>7oo000@Ool00`00Ool00003000HOol00`00
Oomoo`3oOolhOol0011oo`03001oogoo01]oo`03001oogoo0?moocQoo`003goo0P007Goo00<007oo
Ool0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo00<007oo
Ool0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo00<007oo
Ool0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo00<007oo
Ool0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo00<007oo
Ool0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo00<007oo
Ool0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo00<007oo
Ool0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo00<007oo
Ool0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002ioo`03001oogoo0?moocQoo`00;Woo00<007oo
Ool0ogoo>7oo000^Ool00`00Oomoo`3oOolhOol002Qoo`h00?]oo`h002Uoo`0097oo10003Woo1000
lgoo10003Woo10009Goo000POol4000FOol3003]Ool3000FOol4000QOol001moo`03001oogoo01]o
o`8007=oo`<00003Ool0000000<006eoo`8001eoo`03001oogoo01ioo`007Goo0P0087oo0P00LGoo
00<007ooOol00goo00<007ooOol0Jgoo0P0087oo0P007Woo000KOol2000TOol00`00Oomoo`1VOol2
0002Ool30002Ool00`00Oomoo`02Ool00`00Oomoo`1ZOol00`00Oomoo`0ROol2000LOol001Yoo`03
001oogoo02Eoo`8006Moo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`1XOol2000WOol0
0`00Oomoo`0IOol001Qoo`8002Yoo`03001oogoo06Aoo`03001oo`0000Aoo`03001oo`0000=oo`03
001oogoo06Moo`03001oogoo02Qoo`8001Uoo`005Woo0P00;Goo0P00I7oo0`001Goo00@007ooOomo
o`8006Moo`8002eoo`03001oogoo01Ioo`005Goo00<007ooOol0;goo0P00HWoo00@007ooOol0071o
o`03001oogoo02ioo`8001Ioo`0057oo00<007ooOol0<Woo00<007ooOol0Ggoo00<007oo00000`00
KGoo00<007ooOol0<Goo00<007ooOol04goo000DOol00`00Oomoo`0cOol00`00Oomoo`1NOol00`00
Oomoo`1_Ool00`00Oomoo`0cOol00`00Oomoo`0BOol001=oo`03001oogoo03Aoo`03001oogoo05eo
o`80071oo`03001oogoo03Eoo`03001oogoo015oo`004Woo00<007ooOol0=Woo00<007ooOol0cGoo
00<007ooOol0=goo00<007ooOol047oo000AOol00`00Oomoo`0hOol00`00Oomoo`3;Ool00`00Oomo
o`0iOol00`00Oomoo`0?Ool0011oo`03001oogoo03Yoo`03001oogoo0<Uoo`03001oogoo03Yoo`03
001oogoo00moo`003goo00<007ooOol0?7oo00<007ooOol0agoo00<007ooOol0?7oo00<007ooOol0
3Woo000>Ool00`00Oomoo`0nOol00`00Oomoo`35Ool00`00Oomoo`0nOol00`00Oomoo`0=Ool000io
o`03001oogoo03ioo`03001oogoo019oo`<00;1oo`03001oogoo03ioo`03001oogoo00eoo`003Goo
00<007ooOol0@7oo00<007ooOol03Goo1`00[goo00<007ooOol0@7oo00<007ooOol037oo000<Ool0
0`00Oomoo`11Ool00`00Oomoo`08Ool<002_Ool00`00Oomoo`11Ool00`00Oomoo`0;Ool000aoo`03
001oogoo045oo`03001oogoo00Aooa000:moo`03001oogoo045oo`03001oogoo00]oo`002goo00<0
07ooOol0@goo00<007ooOol0_`000Woo00<007ooOol0@goo00<007ooOol02Woo000;Ool00`00Oomo
o`13Ool00`00Oomoo`02OolA002^Ool00`00Oomoo`13Ool00`00Oomoo`0:Ool000]oo`03001oogoo
04Aoo`03001oogoo00Eoo`d00:eoo`03001oogoo04Aoo`03001oogoo00Yoo`002goo00<007ooOol0
A7oo00<007ooOol027oo2P00[Goo00<007ooOol0A7oo00<007ooOol02Woo000:Ool00`00Oomoo`16
Ool00`00Oomoo`0;Ool6002/Ool00`00Oomoo`16Ool00`00Oomoo`09Ool000Yoo`03001oogoo04Io
o`03001oogoo00moo`800:aoo`03001oogoo04Ioo`03001oogoo00Uoo`002Woo00<007ooOol0AWoo
00<007ooOol0_Goo00<007ooOol0AWoo00<007ooOol02Goo0009Ool00`00Oomoo`17Ool00`00Oomo
o`2mOol00`00Oomoo`17Ool00`00Oomoo`08Ool000Uoo`03001oogoo04Moo`03001oogoo0;eoo`03
001oogoo04Moo`03001oogoo00Qoo`002Goo00<007ooOol0B7oo00<007ooOol0^goo00<007ooOol0
B7oo00<007ooOol027oo0009Ool00`00Oomoo`18Ool00`00Oomoo`2kOol00`00Oomoo`18Ool00`00
Oomoo`08Ool000Uoo`03001oogoo04Qoo`03001oogoo0;]oo`03001oogoo04Qoo`03001oogoo00Qo
o`002Goo00<007ooOol0B7oo00<007ooOol0^goo00<007ooOol0B7oo00<007ooOol027oo0008Ool0
0`00Oomoo`0ROol5000ROol00`00Oomoo`2kOol00`00Oomoo`0POol5000TOol00`00Oomoo`07Ool0
00Qoo`03001oogoo02Aoo`03001oogoo029oo`03001oogoo0;]oo`03001oogoo021oo`05001oogoo
Ool0000TOol00`00Oomoo`07Ool000Qoo`03001oogoo02Aoo`03001oogoo029oo`03001oogoo0;]o
o`03001oogoo025oo`03001oogoo02Eoo`03001oogoo00Moo`0027oo00<007ooOol097oo00<007oo
Ool08Woo00<007ooOol0^goo00<007ooOol08Woo00<007ooOol097oo00<007ooOol01goo0008Ool0
0`00Oomoo`0TOol00`00Oomoo`0ROol00`00Oomoo`2kOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`07Ool000Uoo`03001oogoo02=oo`03001oogoo029oo`03001oogoo0;]oo`03001oogoo
02Aoo`03001oogoo029oo`03001oogoo00Moo`002Goo00<007ooOol08Goo0`0097oo00<007ooOol0
^goo00<007ooOol087oo00D007ooOomoo`0002=oo`03001oogoo00Qoo`002Goo00<007ooOol08goo
00<007ooOol08Woo00<007ooOol0^goo00<007ooOol08Goo0`0097oo00<007ooOol027oo0009Ool0
0`00Oomoo`18Ool00`00Oomoo`2kOol00`00Oomoo`18Ool00`00Oomoo`08Ool000Uoo`03001oogoo
04Moo`03001oogoo0;eoo`03001oogoo04Moo`03001oogoo00Qoo`002Goo00<007ooOol0Agoo00<0
07ooOol0_Goo00<007ooOol0Agoo00<007ooOol027oo000:Ool00`00Oomoo`16Ool00`00Oomoo`2m
Ool00`00Oomoo`16Ool00`00Oomoo`09Ool000Yoo`03001oogoo04Ioo`03001oogoo0;eoo`03001o
ogoo04Ioo`03001oogoo00Uoo`002Woo00<007ooOol0AWoo00<007ooOol0ZWoo0P004Goo00<007oo
Ool0AWoo00<007ooOol02Goo000:Ool00`00Oomoo`16Ool00`00Oomoo`2ZOol6000=Ool00`00Oomo
o`16Ool00`00Oomoo`09Ool000]oo`03001oogoo04Aoo`03001oogoo0:]oo`T000]oo`03001oogoo
04Aoo`03001oogoo00Yoo`002goo00<007ooOol0A7oo00<007ooOol0Zgoo3@001goo00<007ooOol0
A7oo00<007ooOol02Woo000;Ool00`00Oomoo`13Ool00`00Oomoo`2/OolA0004Ool00`00Oomoo`13
Ool00`00Oomoo`0:Ool000aoo`03001oogoo045oo`04001oogooOono0003Ool00`00Oomoo`11Ool0
0`00Oomoo`0;Ool000aoo`03001oogoo045oo`03001oogoo0:eooa0000Ioo`03001oogoo045oo`03
001oogoo00]oo`003Goo00<007ooOol0@7oo00<007ooOol0[Goo30002Woo00<007ooOol0@7oo00<0
07ooOol037oo000=Ool00`00Oomoo`10Ool00`00Oomoo`2]Ool7000?Ool00`00Oomoo`10Ool00`00
Oomoo`0<Ool000ioo`03001oogoo03ioo`03001oogoo0:ioo`<001Aoo`03001oogoo03ioo`03001o
ogoo00eoo`003goo00<007ooOol0?7oo00<007ooOol0agoo00<007ooOol0?7oo00<007ooOol03Woo
000?Ool00`00Oomoo`0lOol00`00Oomoo`37Ool00`00Oomoo`0lOol00`00Oomoo`0>Ool0011oo`03
001oogoo03Yoo`03001oogoo0<Uoo`03001oogoo03Yoo`03001oogoo00moo`0047oo00<007ooOol0
>Goo00<007ooOol0bWoo00<007ooOol0>Woo00<007ooOol03goo000AOol2000hOol00`00Oomoo`3<
Ool2000iOol00`00Oomoo`0@Ool001=oo`03001oogoo03Aoo`03001oogoo0<moo`03001oogoo03Eo
o`03001oogoo015oo`0057oo00<007ooOol0<goo00<007ooOol0I7oo1@0000Aoo`00000006=oo`03
001oogoo03=oo`03001oogoo019oo`0057oo00<007ooOol0<Woo00<007ooOol0Igoo00D007ooOomo
o`0006Ioo`03001oogoo035oo`03001oogoo01=oo`005Goo00<007ooOol0;goo0P00HGoo0P000Woo
0`000Woo00<007ooOol00Woo00<007ooOol0I7oo00<007ooOol0;Woo0P005Woo000FOol2000^Ool0
0`00Oomoo`1ROol01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol0IGoo0P00;Goo00<007oo
Ool05Woo000HOol00`00Oomoo`0YOol2001UOol00`00Ool00005Ool01`00Oomoogoo001oo`0006Qo
o`03001oogoo02Uoo`03001oogoo01Moo`005goo1000:7oo00<007oo0000IGoo0`0017oo0P0017oo
00<007ooOol0J7oo00<007ooOol09Woo0P006Woo000GOol20002Ool00`00Oomoo`0SOol20002Ool2
001TOol01000Oomoo`00MGoo0P009Goo00<007ooOol06Woo000FOol30003Ool2000ROol00`00Oomo
o`02Ool2001TOol00`00Ool00003001eOol00`00Oomoo`0POol2000MOol001Ioo`<000Eoo`8001io
o`8000Eoo`<006=oo`03001oogoo07Uoo`8001ioo`8001moo`005Goo00@007oo000000Moo`03001o
ogoo01Uoo`8000Moo`<0069oo`8007eoo`8001]oo`03001oogoo01moo`005Goo00@007oo000000Qo
o`@001Aoo`<000Uoo`800003Ool007oo0>5oo`<001Aoo`@0029oo`0057oo00D007oo001oo`0000ao
o`L000Eoo`P000aoo`04001oo`00003UOol80005Ool7000VOol001Aoo`05001oo`00Ool0000COol5
000DOol01@00Ool007oo0000k7oo1@00;Goo000COol01P00Oomoo`00Ool002aoo`05001oo`00Ool0
003oOolOOol001=oo`06001oogoo001oo`00;7oo00<007oo00000Woo00<007ooOol0ogoo77oo000B
Ool01000Oomoo`000Woo00<007ooOol0:Woo00<007oo00000Woo00<007ooOol0ogoo77oo000BOol0
1000Oomoo`000Woo00<007ooOol0:Woo00@007ooOol0009oo`03001oogoo0?mooa]oo`004Goo00D0
07ooOomoo`00009oo`03001oogoo02Yoo`04001oogoo0002Ool00`00Oomoo`3oOolKOol0015oo`05
001oogooOol00002Ool00`00Oomoo`0ZOol01000Oomoo`000goo00<007ooOol0ogoo6Woo000@Ool0
1@00Oomoogoo00000goo00<007ooOol0:Woo00@007ooOol000=oo`03001oogoo0?mooaYoo`0047oo
00D007ooOomoo`0000=oo`03001oogoo02Yoo`05001oogooOol00003Ool00`00Oomoo`3oOolIOol0
00moo`03001oogoo009oo`05001oogooOol0000/Ool01@00Oomoogoo00000goo00<007ooOol0ogoo
6Goo000DOol01@00Oomoogoo0000;7oo00D007ooOomoo`000?mooamoo`0057oo00<007ooOol0<Woo
00<007ooOol0ogoo7Goo000COol00`00Oomoo`0cOol00`00Oomoo`3oOolMOol001=oo`03001oogoo
03Aoo`03001oogoo0?mooaaoo`004goo00<007ooOol0=7oo00<007ooOol0ogoo77oo000COol00`00
Oomoo`0dOol00`00Oomoo`3oOolLOol0019oo`03001oogoo03Eoo`03001oogoo0?mooaaoo`004Woo
00<007ooOol0=Woo00<007ooOol0ogoo6goo000BOol00`00Oomoo`0fOol00`00Oomoo`3oOolKOol0
019oo`03001oogoo03Ioo`03001oogoo0?mooa]oo`004Goo00<007ooOol0=goo00<007ooOol0ogoo
6goo000AOol00`00Oomoo`0gOol00`00Oomoo`3oOolKOol0015oo`03001oogoo03Qoo`03001oogoo
0?mooaYoo`004Goo00<007ooOol0>7oo00<007ooOol0ogoo6Woo000@Ool00`00Oomoo`0iOol00`00
Oomoo`3oOolJOol0011oo`03001oogoo03Uoo`03001oogoo0?mooaYoo`0047oo00<007ooOol03Goo
1@001goo00<007ooOol01goo00<007ooOol057oo00<007ooOol04Goo0`0027oo00<007ooOol01goo
00<007ooOol0kgoo000@Ool00`00Oomoo`0?Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomo
o`0COol00`00Oomoo`0AOol00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`3^Ool0011oo`03
001oogoo00Eoo`800004Ool000000004Ool00`00Oomoo`05Ool00`00Oomoo`04Ool30004Ool00`00
Oomoo`0BOol00`00Oomoo`09Ool2000017oo000000000goo00<007ooOol01Goo00<007ooOol017oo
0`0017oo00<007ooOol0kGoo000?Ool00`00Oomoo`07Ool20003Ool01@00Oomoogoo00001goo00<0
07ooOol00goo00D007ooOomoo`0000=oo`03001oogoo019oo`03001oogoo00Yoo`8000=oo`04001o
ogoo0007Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00<007ooOol0kGoo000?Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool01@00Oomoogoo00001goo00<007ooOol00goo00<007ooOol01Goo00<0
07ooOol04Woo00<007ooOol02Woo00<007ooOol00Woo00D007oo001oo`0000Ioo`03001oogoo00=o
o`03001oogoo00Eoo`03001oogoo0>eoo`003goo00<007ooOol01goo00<007ooOol00Woo00<007oo
Ool00P001goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol04goo00<007ooOol02Goo00<0
07ooOol00Woo00@007ooOol000Moo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo0>eoo`00
3goo00<007ooOol01goo0P000goo00<007ooOol02Goo00<007ooOol00goo00<007ooOol01Goo00<0
07ooOol04goo00<007ooOol02Goo0P000goo00<007ooOol027oo00<007ooOol00goo00<007ooOol0
1Goo00<007ooOol0kGoo000>Ool00`00Oomoo`08Ool00`00Ool00002000<Ool00`00Oomoo`02Ool5
0004Ool00`00Oomoo`0COol00`00Oomoo`09Ool00`00Ool00002000;Ool00`00Oomoo`02Ool50004
Ool00`00Oomoo`3]Ool000ioo`03001oogoo00Qoo`03001oogoo00moo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo01Aoo`03001oogoo00Uoo`03001oogoo00ioo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo0>ioo`003Woo00<007ooOol01goo0P004Woo00<007ooOol01goo00<007oo
Ool05Goo00<007ooOol027oo0P004Goo00<007ooOol01goo00<007ooOol0kgoo000>Ool00`00Oomo
o`0nOol00`00Oomoo`3oOolGOol000eoo`03001oogoo03moo`03001oogoo0?mooaMoo`003Goo00<0
07ooOol0?goo00<007ooOol0ogoo5goo000=Ool00`00Oomoo`0oOol00`00Oomoo`3oOolGOol000eo
o`03001oogoo041oo`03001oogoo0?mooaIoo`0037oo00<007ooOol0@Goo00<007ooOol0ogoo5Woo
000<Ool00`00Oomoo`11Ool00`00Oomoo`3oOolFOol000aoo`03001oogoo045oo`03001oogoo0?mo
oaIoo`0037oo00<007ooOol0@Goo00<007ooOol0ogoo5Woo000<Ool00`00Oomoo`12Ool00`00Oomo
o`3oOolEOol000]oo`03001oogoo04=oo`03001oogoo0?mooaEoo`002goo00<007ooOol0@goo00<0
07ooOol0ogoo5Goo000;Ool00`00Oomoo`13Ool00`00Oomoo`3oOolEOol000]oo`03001oogoo04Ao
o`03001oogoo0?mooaAoo`002Woo00<007ooOol0AGoo00<007ooOol0ogoo57oo000:Ool00`00Oomo
o`15Ool00`00Oomoo`3oOolDOol000Yoo`03001oogoo04Eoo`03001oogoo0?mooaAoo`002Woo00<0
07ooOol0AGoo00<007ooOol0ogoo57oo0009Ool00`00Oomoo`17Ool00`00Oomoo`3oOolCOol000Uo
o`03001oogoo04Moo`03001oogoo0?mooa=oo`002Goo00<007ooOol0Agoo00<007ooOol0ogoo4goo
0009Ool00`00Oomoo`17Ool00`00Oomoo`3oOolCOol000Qoo`03001oogoo04Uoo`03001oogoo0?mo
oa9oo`0027oo00<007ooOol0BGoo00<007ooOol0ogoo4Woo0008Ool00`00Oomoo`19Ool00`00Oomo
o`3oOolBOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{127.625, 414.625}, {437.375, 259.188}} -> {-2.72345, \
2.70647, 0.0164996, 0.0164996}}],

Cell["This process can be mathematically represented by", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\_1' \((t)\)\)\(\ \)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(b\_1\)(
          t)\  - \ \((k\_10 + \ k\_12)\)\ \(\(x\_1\)(t)\)\ \  + \ 
        k\_21\ \(\(x\_2\)(t)\)\)\)\)]],
  "  \n",
  Cell[BoxData[
      \(TraditionalForm\`x\_2' \((t)\)\  = \ 
        k\_12\ \(\(x\_1\)(t)\)\ \  - \ \ \(\(k\_21\)\(\ \)\(\(x\_2\)(
              t)\)\(\ \)\)\)]],
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(x\_1\)(0)\), " ", "=", " ", 
          FormBox[\(b\_0\),
            "TraditionalForm"], " "}], TraditionalForm]]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`b\_1\)]],
  "(t) = ",
  Cell[BoxData[
      \(TraditionalForm\`b\_1\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < T\)]],
  " and  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(b\_1\),
              "TraditionalForm"], "(", "t", ")"}], " ", "=", " ", "0"}], 
        TraditionalForm]]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`t\  \[GreaterEqual] T\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "Coefficients: ",
  Cell[BoxData[
      \(TraditionalForm\`k\_12\)]],
  "=2 ",
  Cell[BoxData[
      \(TraditionalForm\`h\^\(-1\)\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`k\_21\)]],
  "=1 ",
  Cell[BoxData[
      \(TraditionalForm\`h\^\(-1\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`k\_10\)]],
  " =0,5 ",
  Cell[BoxData[
      \(TraditionalForm\`h\^\(-1\)\)]],
  ", \nSingle input: ",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  " = 100 mg\nConstant input: ",
  Cell[BoxData[
      \(TraditionalForm\`b\_1\)]],
  "=10 mg/h until ",
  Cell[BoxData[
      \(TraditionalForm\`T = 10\)]],
  " h)"
}], "Text"],

Cell["The first step is build the compartmental matrix", "Text"],

Cell[BoxData[
    \(model2\  = 
      CompartMatrix[2, {{1, 2, 2}, \ {2, 1, 1}, \ {1, 0, 0.5}}]; \)], "Input",\

  CellLabel->"In[42]:="],

Cell[TextData[{
  "Here is the retention for ",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < T\)]],
  " "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ShowODE[model2, \ {0, 0}, {10, 0}, \ t, \ x1] // TableForm\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                SuperscriptBox[\(x1\_1\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(10 - 2.5`\ x1\_1[t] + x1\_2[t]\)}]},
          {
            RowBox[{
              RowBox[{
                SuperscriptBox[\(x1\_2\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(2\ x1\_1[t] - x1\_2[t]\)}]},
          {\(x1\_1[0] \[Equal] 0\)},
          {\(x1\_2[0] \[Equal] 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Derivative[ 1][ 
            Subscript[ x1, 1]][ t], 
          Plus[ 10, 
            Times[ -2.5, 
              Subscript[ x1, 1][ t]], 
            Subscript[ x1, 2][ t]]], 
        Equal[ 
          Derivative[ 1][ 
            Subscript[ x1, 2]][ t], 
          Plus[ 
            Times[ 2, 
              Subscript[ x1, 1][ t]], 
            Times[ -1, 
              Subscript[ x1, 2][ t]]]], 
        Equal[ 
          Subscript[ x1, 1][ 0], 0], 
        Equal[ 
          Subscript[ x1, 2][ 0], 0]}]]], "Output",
  CellLabel->"Out[43]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol1[t1_] = 
      SystemDSolve[model2, \ {100, \ 0}, {10, \ 0}, \ t, \ t1, \ 
        x1]\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \({x1\_1[t1] \[Rule] \(\(20.000000000000004`\)\(\[InvisibleSpace]\)\) + 
          71.23475237772121`\ \[ExponentialE]\^\(\(-3.350781059358212`\)\ \
t1\) + 8.765247622278785`\ \[ExponentialE]\^\(\(-0.1492189406417878`\)\ t1\), 
      x1\_2[t1] \[Rule] \(\(40.00000000000001`\)\(\[InvisibleSpace]\)\) - 
          60.60517809103758`\ \[ExponentialE]\^\(\(-3.350781059358212`\)\ \
t1\) + 20.605178091037573`\ \[ExponentialE]\^\(\(-0.1492189406417878`\)\ \
t1\)}\)], "Output",
  CellLabel->"Out[44]="]
}, Open  ]],

Cell[TextData[{
  "Here is the retention for ",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`t\  \[GreaterEqual] T\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ShowODE[
        model2, \ {\*"\"\<\!\(x1\_1\)(T)\>\"", \*"\"\<\!\(x1\_2\)(T)\>\""}, \
{0, 0}, \ t, \ \ x2] // TableForm\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                SuperscriptBox[\(x2\_1\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-2.5`\)\ x2\_1[t] + x2\_2[t]\)}]},
          {
            RowBox[{
              RowBox[{
                SuperscriptBox[\(x2\_2\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(2\ x2\_1[t] - x2\_2[t]\)}]},
          {\(x2\_1[0] \[Equal] "\!\(x1\_1\)(T)"\)},
          {\(x2\_2[0] \[Equal] "\!\(x1\_2\)(T)"\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Derivative[ 1][ 
            Subscript[ x2, 1]][ t], 
          Plus[ 
            Times[ -2.5, 
              Subscript[ x2, 1][ t]], 
            Subscript[ x2, 2][ t]]], 
        Equal[ 
          Derivative[ 1][ 
            Subscript[ x2, 2]][ t], 
          Plus[ 
            Times[ 2, 
              Subscript[ x2, 1][ t]], 
            Times[ -1, 
              Subscript[ x2, 2][ t]]]], 
        Equal[ 
          Subscript[ x2, 1][ 0], "\!\(x1\_1\)(T)"], 
        Equal[ 
          Subscript[ x2, 2][ 0], "\!\(x1\_2\)(T)"]}]]], "Output",
  CellLabel->"Out[45]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol2[t_] = 
      AcuteInput[model2, \ Map[Last, sol1[10]], \ t, \ x2]\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \({x2\_1[t] \[Rule] 
        21.97112680766245`\ \((0.734260642832909`\ \
\[ExponentialE]\^\(\(-3.350781059358212`\)\ t\) + 
                0.2657393571670909`\ \
\[ExponentialE]\^\(\(-0.1492189406417878`\)\ t\))\) + 
          44.63368756504547`\ \((\(-0.3123475237772121`\)\ \
\[ExponentialE]\^\(\(-3.350781059358212`\)\ t\) + 
                0.3123475237772121`\ \
\[ExponentialE]\^\(\(-0.1492189406417878`\)\ t\))\), 
      x2\_2[t] \[Rule] 
        21.97112680766245`\ \((\(-0.6246950475544243`\)\ \
\[ExponentialE]\^\(\(-3.350781059358212`\)\ t\) + 
                0.6246950475544243`\ \
\[ExponentialE]\^\(\(-0.1492189406417878`\)\ t\))\) + 
          44.63368756504547`\ \((0.2657393571670909`\ \
\[ExponentialE]\^\(\(-3.350781059358212`\)\ t\) + 
                0.734260642832909`\ \[ExponentialE]\^\(\(-0.1492189406417878`\
\)\ t\))\)}\)], "Output",
  CellLabel->"Out[46]="]
}, Open  ]],

Cell[TextData[{
  "We build a compound function that represents the retention divided in two \
intervals: one of them  when ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < T\)]],
  " and the other one ",
  Cell[BoxData[
      \(TraditionalForm\`t\  \[GreaterEqual] T\)]],
  ". "
}], "Text"],

Cell[BoxData[
    \(x[t_, T_] := Map[Last, If[t < T, \ sol1[t], sol2[t - T]]]; \)], "Input",\

  CellLabel->"In[47]:="],

Cell["Here is the retention in compartment 1 and 2 f", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[{t, {x[t, 10]}}, {t, \ 0, 20}] // Chop\) // 
      TableForm\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"0", GridBox[{
                {"100.`", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"30.047487401802904`", "55.62426525409728`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"2", GridBox[{
                {"26.591153461188703`", "55.21407207202561`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"3", GridBox[{
                {"25.605149069937774`", "53.166652270311886`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"4", GridBox[{
                {"24.82563003431588`", "51.343655214496785`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"5", GridBox[{
                {"24.156614718849134`", "49.77127907606097`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"6", GridBox[{
                {"23.580423760684027`", "48.41679193774217`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"7", GridBox[{
                {"23.084107110851214`", "47.25006056637965`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"8", GridBox[{
                {"22.656589730781175`", "46.24506082108562`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"9", GridBox[{
                {"22.28833459856918`", "45.37937363177227`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"10", GridBox[{
                {"21.97112680766245`", "44.63368756504547`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"11", GridBox[{
                {"17.114767648488627`", "39.98712525916505`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"12", GridBox[{
                {"14.678848382540343`", "34.4981366185625`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"13", GridBox[{
                {"12.641848430665974`", "29.71791558032377`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"14", GridBox[{
                {"10.889363745888796`", "25.59849944577805`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"15", GridBox[{
                {"9.379882886388717`", "22.050050656839062`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"16", GridBox[{
                {"8.079648143368283`", "18.993483808685887`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"17", GridBox[{
                {"6.9596513788577035`", "16.360616640698407`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"18", GridBox[{
                {"5.994908005670206`", "14.09271619230843`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"19", GridBox[{
                {"5.163896873671436`", "12.139190963105339`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"20", GridBox[{
                {"4.448080086752384`", "10.45646241844592`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{0, {{.1*^3, 0}}}, {1, {{30.047487401802904, 
        55.624265254097281}}}, {2, {{26.591153461188703, 
        55.214072072025608}}}, {3, {{25.605149069937774, 
        53.166652270311886}}}, {4, {{24.825630034315878, 
        51.343655214496785}}}, {5, {{24.156614718849134, 
        49.771279076060971}}}, {6, {{23.580423760684027, 
        48.416791937742168}}}, {7, {{23.084107110851214, 
        47.250060566379652}}}, {8, {{22.656589730781175, 
        46.245060821085623}}}, {9, {{22.288334598569179, 
        45.379373631772268}}}, {10, {{21.971126807662451, 
        44.63368756504547}}}, {11, {{17.114767648488627, 
        39.987125259165047}}}, {12, {{14.678848382540343, 
        34.498136618562498}}}, {13, {{12.641848430665974, 
        29.717915580323769}}}, {14, {{10.889363745888796, 
        25.598499445778049}}}, {15, {{9.3798828863887174, 
        22.050050656839062}}}, {16, {{8.0796481433682832, 
        18.993483808685887}}}, {17, {{6.9596513788577035, 
        16.360616640698407}}}, {18, {{5.9949080056702062, 
        14.09271619230843}}}, {19, {{5.1638968736714359, 
        12.139190963105339}}}, {20, {{4.448080086752384, 
        10.45646241844592}}}}]]], "Output",
  CellLabel->"Out[48]//TableForm="]
}, Open  ]],

Cell["Here is the retention in compartment 2", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\(x[t, 10]\)[\([\)\(2\)\(]\)], \ {t, 0, 12}]\)], "Input",
  CellLabel->"In[49]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0793651 -0.525463 0.020087 [
[.18254 .06465 -3 -9 ]
[.18254 .06465 3 0 ]
[.34127 .06465 -3 -9 ]
[.34127 .06465 3 0 ]
[.5 .06465 -3 -9 ]
[.5 .06465 3 0 ]
[.65873 .06465 -3 -9 ]
[.65873 .06465 3 0 ]
[.81746 .06465 -6 -9 ]
[.81746 .06465 6 0 ]
[.97619 .06465 -6 -9 ]
[.97619 .06465 6 0 ]
[.01131 .17758 -12 -4.5 ]
[.01131 .17758 0 4.5 ]
[.01131 .27802 -12 -4.5 ]
[.01131 .27802 0 4.5 ]
[.01131 .37845 -12 -4.5 ]
[.01131 .37845 0 4.5 ]
[.01131 .47889 -12 -4.5 ]
[.01131 .47889 0 4.5 ]
[.01131 .57932 -12 -4.5 ]
[.01131 .57932 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .07715 m
.18254 .0834 L
s
[(2)] .18254 .06465 0 1 Mshowa
.34127 .07715 m
.34127 .0834 L
s
[(4)] .34127 .06465 0 1 Mshowa
.5 .07715 m
.5 .0834 L
s
[(6)] .5 .06465 0 1 Mshowa
.65873 .07715 m
.65873 .0834 L
s
[(8)] .65873 .06465 0 1 Mshowa
.81746 .07715 m
.81746 .0834 L
s
[(10)] .81746 .06465 0 1 Mshowa
.97619 .07715 m
.97619 .0834 L
s
[(12)] .97619 .06465 0 1 Mshowa
.125 Mabswid
.06349 .07715 m
.06349 .0809 L
s
.10317 .07715 m
.10317 .0809 L
s
.14286 .07715 m
.14286 .0809 L
s
.22222 .07715 m
.22222 .0809 L
s
.2619 .07715 m
.2619 .0809 L
s
.30159 .07715 m
.30159 .0809 L
s
.38095 .07715 m
.38095 .0809 L
s
.42063 .07715 m
.42063 .0809 L
s
.46032 .07715 m
.46032 .0809 L
s
.53968 .07715 m
.53968 .0809 L
s
.57937 .07715 m
.57937 .0809 L
s
.61905 .07715 m
.61905 .0809 L
s
.69841 .07715 m
.69841 .0809 L
s
.7381 .07715 m
.7381 .0809 L
s
.77778 .07715 m
.77778 .0809 L
s
.85714 .07715 m
.85714 .0809 L
s
.89683 .07715 m
.89683 .0809 L
s
.93651 .07715 m
.93651 .0809 L
s
.25 Mabswid
0 .07715 m
1 .07715 L
s
.02381 .17758 m
.03006 .17758 L
s
[(35)] .01131 .17758 1 0 Mshowa
.02381 .27802 m
.03006 .27802 L
s
[(40)] .01131 .27802 1 0 Mshowa
.02381 .37845 m
.03006 .37845 L
s
[(45)] .01131 .37845 1 0 Mshowa
.02381 .47889 m
.03006 .47889 L
s
[(50)] .01131 .47889 1 0 Mshowa
.02381 .57932 m
.03006 .57932 L
s
[(55)] .01131 .57932 1 0 Mshowa
.125 Mabswid
.02381 .09723 m
.02756 .09723 L
s
.02381 .11732 m
.02756 .11732 L
s
.02381 .13741 m
.02756 .13741 L
s
.02381 .1575 m
.02756 .1575 L
s
.02381 .19767 m
.02756 .19767 L
s
.02381 .21776 m
.02756 .21776 L
s
.02381 .23784 m
.02756 .23784 L
s
.02381 .25793 m
.02756 .25793 L
s
.02381 .2981 m
.02756 .2981 L
s
.02381 .31819 m
.02756 .31819 L
s
.02381 .33828 m
.02756 .33828 L
s
.02381 .35837 m
.02756 .35837 L
s
.02381 .39854 m
.02756 .39854 L
s
.02381 .41863 m
.02756 .41863 L
s
.02381 .43871 m
.02756 .43871 L
s
.02381 .4588 m
.02756 .4588 L
s
.02381 .49897 m
.02756 .49897 L
s
.02381 .51906 m
.02756 .51906 L
s
.02381 .53915 m
.02756 .53915 L
s
.02381 .55924 m
.02756 .55924 L
s
.02381 .05706 m
.02756 .05706 L
s
.02381 .03697 m
.02756 .03697 L
s
.02381 .01689 m
.02756 .01689 L
s
.02381 .59941 m
.02756 .59941 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03759 0 m
.03793 .01049 L
.04262 .12727 L
.0522 .30319 L
.05746 .37255 L
.06244 .42467 L
.06754 .46715 L
.07295 .50249 L
.07757 .5263 L
.08265 .54705 L
.0881 .56415 L
.09397 .57782 L
.09951 .58719 L
.10458 .59338 L
.10935 .59754 L
.11201 .59928 L
.11442 .60054 L
.11669 .60147 L
.11913 .60224 L
.12025 .60252 L
.12144 .60277 L
.12253 .60295 L
.12357 .60309 L
.12485 .60321 L
.12603 .60328 L
.1273 .60332 L
.12801 .60332 L
.12867 .60331 L
.12977 .60327 L
.13099 .60319 L
.13225 .60307 L
.13344 .60293 L
.13617 .6025 L
.13866 .60199 L
.14429 .6005 L
.15409 .59702 L
.16321 .5931 L
.18391 .58292 L
.22296 .56237 L
.26446 .54124 L
.30444 .52221 L
.3429 .50518 L
.38382 .48836 L
.42323 .47334 L
.46111 .45991 L
.50145 .44662 L
.54028 .43476 L
.58155 .42305 L
.62131 .4126 L
.65956 .40327 L
Mistroke
.70026 .39404 L
.73944 .3858 L
.78107 .37769 L
.80198 .37384 L
.81115 .37221 L
.816 .37135 L
.81739 .37111 L
.81872 .37083 L
.8199 .37048 L
.82119 .37002 L
.82364 .3689 L
.82624 .3674 L
.83091 .36399 L
.83998 .35535 L
.85979 .33081 L
.8976 .27663 L
.93785 .21911 L
.97619 .1675 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[49]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`003`3oool01@000000oooo0?ooo`3oool000000?l0oooo3@3oool000l0
oooo00D000000?ooo`3oool0oooo0000003o0?ooo`d0oooo000?0?ooo`050000003oool0oooo0?oo
o`000000o`3oool=0?ooo`003`3oool01@000000oooo0?ooo`3oool000000?l0oooo3@3oool000l0
oooo00D000000?ooo`3oool0oooo0000003o0?ooo`d0oooo000?0?ooo`8000000P3oool00`000000
oooo0?ooo`3o0?ooo`/0oooo000?0?ooo`050000003oool0oooo0?ooo`000000o`3oool=0?ooo`00
3`3oool01@000000oooo0?ooo`3oool000000?l0oooo3@3oool000l0oooo00D000000?ooo`3oool0
oooo0000003o0?ooo`d0oooo000?0?ooo`050000003oool0oooo0?ooo`000000o`3oool=0?ooo`00
3`3oool200000080oooo00<000000?ooo`3oool08`3oool4000002X0oooo0`00000W0?ooo`<00000
:`3oool2000002H0oooo1@0000020?ooo`8000008`3oool5000000030?ooo`000000000000800000
0`3oool000l0oooo00D000000?ooo`3oool0oooo0000000U0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool09P3oool010000000oooo0?ooo`00000Y0?ooo`040000003oool0oooo0000
02L0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0280oooo00D00000
0?ooo`3oool0oooo000000060?ooo`003`3oool01@000000oooo0?ooo`3oool0000002H0oooo00<0
00000?ooo`3oool0:03oool5000002L0oooo00@000000?ooo`3oool00000:@3oool010000000oooo
0?ooo`00000W0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool000l0oooo00D000000?ooo`3o
ool0oooo0000000W0?ooo`030000003oool0oooo02L0oooo00@000000?ooo`3oool00000:03oool3
000002/0oooo0P00000X0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool000l0oooo00D00000
0?ooo`3oool0oooo0000000U0?ooo`040000003oool0oooo000002T0oooo00<000000?ooo`000000
:@3oool00`000000oooo0?ooo`0Y0?ooo`040000003oool0oooo000002L0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0280oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0040oooo000?0?ooo`050000003oool0oooo0?ooo`0000009P3oool2
000002/0oooo0P00000Y0?ooo`<00000:P3oool2000002L0oooo0P0000040?ooo`800000903oool2
000000@0oooo0P0000040?ooo`003`3oool200000080oooo00<000000?ooo`3oool0o`3oool;0?oo
o`003`3oool01@000000oooo0?ooo`3oool000000?l0oooo3@3oool000l0oooo00D000000?ooo`3o
ool0oooo0000003o0?ooo`d0oooo000?0?ooo`050000003oool0oooo0?ooo`000000o`3oool=0?oo
o`003`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo2P3oool000l0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00080?ooool000006@00
000000l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`003`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo2P3oool000l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`3o0?ooo`X0oooo000?0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0o`3oool:0?ooo`003`3oool2000000<0oooo00<000000?ooo`3oool0o`3o
ool:0?ooo`003`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo2P3oool0
00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`X0oooo000?0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool:0?ooo`003`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0?l0oooo2P3oool000l0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`3o0?ooo`X0oooo000?0?ooo`8000000`3oool00`000000oooo0?ooo`3o
0?ooo`X0oooo000?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool:0?oo
o`003`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo2P3oool000l0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`X0oooo000?0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0o`3oool:0?ooo`003`3oool2000000<0oooo00<00000
0?ooo`3oool0o`3oool:0?ooo`003`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0?l0oooo2P3oool000l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`X0
oooo000?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool:0?ooo`003`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo2P3oool000l0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`X0oooo000?0?ooo`800000103oool00`00
0000oooo0?ooo`3o0?ooo`T0oooo000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0o`3oool90?ooo`003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo
2@3oool00080oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0?l0oooo0@3oool00`000000oooo0?ooo`050?ooo`0000D0oooo0000003oool0oooo0000
00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`3o0?ooo`030000003oool0oooo00H0oooo00030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool3000000<0oooo00<000000?ooo`3oool0oP3oool00`000000oooo0?oo
o`070?ooo`00103oool010000000oooo0?ooo`3oool2000000D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`3n0?ooo`030000003oool0oooo00L0oooo00001@3oool000000?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0?d0oooo00<000000?ooo`3oool0203oool00080oooo0P0000040?ooo`<00000103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0?`0oooo00<000000?ooo`3oool02@3oool0
00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3k0?ooo`030000003oool0oooo
00X0oooo000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0nP3oool00`000000
oooo0?ooo`0;0?ooo`003`3oool2000000@0oooo00<000000?ooo`3oool0nP3oool00`000000oooo
0?ooo`0;0?ooo`003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?T0oooo00<0
00000?ooo`3oool0303oool000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3h
0?ooo`030000003oool0oooo00d0oooo000?0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0m`3oool00`000000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0?L0oooo00<000000?ooo`3oool03P3oool000l0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`3e0?ooo`030000003oool0oooo00l0oooo000?0?ooo`8000001@3o
ool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo0100oooo000?0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0l`3oool00`000000oooo0?ooo`0A0?ooo`003`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0?<0oooo00<000000?ooo`3oool04@3oool000l0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo0180
oooo000?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0l@3oool00`000000oooo
0?ooo`0C0?ooo`003`3oool2000000D0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?oo
o`0C0?ooo`003`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?00oooo00<00000
0?ooo`3oool0503oool000l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3_0?oo
o`030000003oool0oooo01D0oooo000?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0kP3oool00`000000oooo0?ooo`0F0?ooo`003`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0>h0oooo00<000000?ooo`3oool05P3oool000l0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`3]0?ooo`030000003oool0oooo01L0oooo000?0?ooo`8000001@3oool0
0`000000oooo0?ooo`3/0?ooo`030000003oool0oooo01P0oooo000?0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`0H0?ooo`003`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0>/0oooo00<000000?ooo`3oool06@3oool000<0oooo
0`0000020?ooo`8000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0>X0oooo
00<000000?ooo`3oool06P3oool000@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0j@3oool00`000000oooo
0?ooo`0J0?ooo`0000<0oooo0000000000000`0000001@3oool000000?ooo`3oool0000000@0oooo
0`0000050?ooo`030000003oool0oooo0>P0oooo00<000000?ooo`3oool06`3oool000050?ooo`00
0000oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0i`3oool00`000000oooo0?ooo`0L0?ooo`000P3oool00`000000oooo
000000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`3W0?ooo`030000003oool0oooo01`0oooo00030?ooo`8000000`3oool2000000D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3V0?ooo`030000003oool0oooo01d0oooo
000?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0i@3oool00`000000oooo0?oo
o`0N0?ooo`003`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0>D0oooo00<00000
0?ooo`3oool07P3oool000l0oooo0P0000060?ooo`030000003oool0oooo0>@0oooo00<000000?oo
o`3oool07`3oool000l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3S0?ooo`03
0000003oool0oooo0200oooo000?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
h`3oool00`000000oooo0?ooo`0P0?ooo`003`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0>80oooo00<000000?ooo`3oool08@3oool000l0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`3Q0?ooo`030000003oool0oooo0280oooo000?0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0h@3oool00`000000oooo0?ooo`0R0?ooo`003`3oool2000000H0
oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`0S0?ooo`003`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0=l0oooo00<000000?ooo`3oool0903oool000l0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`3O0?ooo`030000003oool0oooo02@0oooo000?
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0gP3oool00`000000oooo0?ooo`0U
0?ooo`003`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=d0oooo00<000000?oo
o`3oool09P3oool000l0oooo0P0000060?ooo`030000003oool0oooo0=`0oooo00<000000?ooo`3o
ool09`3oool000l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3J0?ooo`030000
003oool0oooo02P0oooo000?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0fP3o
ool00`000000oooo0?ooo`0X0?ooo`003`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0=T0oooo00<000000?ooo`3oool0:@3oool000l0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`3H0?ooo`030000003oool0oooo02X0oooo000?0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`0[0?ooo`003`3oool2000000L0oooo
00<000000?ooo`3oool0e@3oool2000002h0oooo000?0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0e03oool00`000000oooo0?ooo`0^0?ooo`003`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0;`3oool000<0oooo0`0000020?oo
o`8000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0=00oooo0`00000b0?oo
o`00103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`3:0?ooo`H00000=@3oool000030?ooo`000000000000<0
0000103oool00`000000oooo0?ooo`020?ooo`<000001P3oool00`000000oooo0?ooo`350?ooo`D0
0000>`3oool000050?ooo`000000oooo0?ooo`0000000`3oool2000000D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`2o0?ooo`H00000@03oool00080oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
^P3oool5000004H0oooo00030?ooo`8000000`3oool3000000@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`2e0?ooo`@00000B`3oool000l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`2a0?ooo`@00000C`3oool000l0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`2]0?ooo`@00000D`3oool000l0oooo0P0000080?ooo`030000003oool0oooo0:L0
oooo1P00001G0?ooo`003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0:<0oooo
1000001M0?ooo`003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo09l0oooo1000
001Q0?ooo`003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo09/0oooo1000001U
0?ooo`003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09L0oooo0`00001Y0?oo
o`003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo1000001/0?ooo`00
3`3oool2000000T0oooo00<000000?ooo`3oool0S`3oool400000700oooo000?0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0S03oool3000007@0oooo000?0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0R03oool4000007L0oooo000?0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0Q03oool4000007/0oooo000?0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0P@3oool3000007l0oooo000?0?ooo`8000002@3oool00`000000oooo
0?ooo`1m0?ooo`@00000PP3oool000l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`1i0?ooo`@00000QP3oool000l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1f
0?ooo`<00000RP3oool000l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1b0?oo
o`<00000S@3oool000l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1`0?ooo`80
0000T03oool000l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`<00000
TP3oool000l0oooo0P00000:0?ooo`030000003oool0oooo06X0oooo0`00002E0?ooo`003`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo06L0oooo0`00002H0?ooo`003`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo06D0oooo0P00002K0?ooo`000P3oool2000000@0
oooo0P0000050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0HP3oool3000009d0
oooo00001@3oool000000?ooo`3oool000000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo05l0oooo0`00002P0?ooo`00103oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo0`00000:0?ooo`030000003oool0oooo
05/0oooo0`00002S0?ooo`000P3oool2000000<0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo05T0oooo0P00002V0?ooo`000P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`1F0?ooo`<00000Z03oool00080oooo0`0000030?ooo`8000001@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo05<0oooo0`00002[0?ooo`003`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0540oooo0P00002^0?ooo`003`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo04h0oooo0P00002`0?ooo`003`3oool2000000`0oooo00<00000
0?ooo`3oool0C03oool200000;80oooo000?0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0BP3oool200000;@0oooo000?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0A`3oool300000;H0oooo000?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
A03oool300000;T0oooo000?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0@P3o
ool200000;`0oooo000?0?ooo`8000003@3oool00`000000oooo0?ooo`0n0?ooo`<00000_P3oool0
00l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0l0?ooo`800000`@3oool000l0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0j0?ooo`800000``3oool000l0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0h0?ooo`800000a@3oool000l0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0f0?ooo`800000a`3oool000l0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0d0?ooo`800000b@3oool000l0oooo0P00000>0?oo
o`030000003oool0oooo0340oooo0P00003;0?ooo`003`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo02l0oooo0P00003=0?ooo`003`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo02d0oooo0P00003?0?ooo`003`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo02/0oooo0P00003A0?ooo`003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo02L0oooo0`00003C0?ooo`003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
02D0oooo0P00003F0?ooo`003`3oool200000100oooo00<000000?ooo`3oool08P3oool200000=P0
oooo000?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0803oool200000=X0oooo
000?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool07P3oool200000=`0oooo0002
0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo0=`0oooo00001@3oool000000?ooo`3oool000000080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01X0oooo0P00
003O0?ooo`00103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0`00000@
0?ooo`030000003oool0oooo01P0oooo0P00003Q0?ooo`000P3oool2000000@0oooo0P0000050?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3Q0?oo
o`000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0C0?ooo`800000i03oool00080oooo0`0000030?ooo`<00000
103oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo0P00003V0?ooo`003`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00d0oooo0`00003X0?ooo`003`3oool0
0`000000oooo0?ooo`0D0?ooo`8000002P3oool300000>/0oooo000?0?ooo`8000005`3oool20000
00H0oooo0P00003^0?ooo`003`3oool00`000000oooo0?ooo`0G0?ooo`L00000l03oool000l0oooo
00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?
0?ooo`030000003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.701161, 25.7086, \
0.0453004, 0.178985}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[49]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[model2, \ sol1, \ sol2, x1, x2, \ x]\)], "Input",
  CellLabel->"In[50]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["The General Two-compartmental System ", "SubsubsectionIcon"],

Cell["The figure shows a general two compartmental model.", "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .66667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.12963 0.21164 0.333333 0.21164 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125  moveto 0 0 lineto 
-0.05 -0.0125  lineto stroke
} ifelse
grestore
} def
/MAarrowhead2 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.12963 .65079 m
.12963 .43915 L
s
% Start of user PostScript
0 1.5 0 0.5 MAarrowhead1
% End of user PostScript
gsave
.04497 .54497 -80.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
75.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.875 12.750 moveto
(H) show
85.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.875 12.750 moveto
(L) show
97.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.12963 .33333 .10582 0 365.73 arc
s
gsave
.12963 .33333 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.12963 .22751 m
.12963 .01587 L
s
% Start of user PostScript
0 -0.5 0 -1.5 MAarrowhead2
% End of user PostScript
gsave
.06614 .12169 -71.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
73.375 14.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
75.125 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(o) show
80.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23545 .37566 m
.76455 .37566 L
s
% Start of user PostScript
0.5 0.2 3. 0.2 MAarrowhead2
% End of user PostScript
gsave
.5 .41799 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.76455 .29101 m
.23545 .29101 L
s
% Start of user PostScript
3. -0.2 0.5 -0.2 MAarrowhead2
% End of user PostScript
gsave
.5 .24868 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.87037 .33333 .10582 0 365.73 arc
s
gsave
.87037 .33333 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.87037 .65079 m
.87037 .43915 L
s
% Start of user PostScript
3.5 1.5 3.5 0.5 MAarrowhead1
% End of user PostScript
gsave
.78571 .54497 -77.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.875 12.750 moveto
(H) show
79.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
85.875 12.750 moveto
(L) show
91.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.87037 .22751 m
.87037 .01587 L
s
% Start of user PostScript
3.5 -0.5 3.5 -1.5 MAarrowhead2
% End of user PostScript
gsave
.80688 .12169 -71.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
73.375 14.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
75.125 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(o) show
80.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{288, 192},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000l1000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00;Woo00<007ooOol0ogoo27oo00<007oo
Ool0;Goo000^Ool00`00Oomoo`3oOol8Ool00`00Oomoo`0]Ool002ioo`800?moo`Qoo`8002moo`00
;Goo0`00ogoo27oo0`00;Woo000]Ool3003oOol8Ool3000^Ool002eoo`<00?moo`Qoo`<002ioo`00
;Goo1000ogoo1Woo1000;Woo000/Ool5003oOol6Ool5000]Ool002aoo`D00?moo`Ioo`D002eoo`00
;7oo1P00ogoo17oo1P00;Goo000/Ool6003oOol4Ool6000]Ool002aoo`H00?moo`Aoo`H002eoo`00
:goo1`00ogoo17oo1`00;7oo000[Ool8003oOol2Ool8000/Ool002]oo`P00?moo`9oo`P002aoo`00
:goo2000ogoo0Woo2000;7oo000ZOol9003oOol2Ool9000[Ool002Yoo`X00?moo`X002]oo`00:Woo
2P00ogoo2P00:goo000^Ool00`00Oomoo`3oOol8Ool00`00Oomoo`0]Ool002ioo`03001oogoo0?mo
o`Qoo`03001oogoo02eoo`00;Woo00<007ooOol0ogoo27oo00<007ooOol0;Goo000^Ool00`00Oomo
o`3oOol8Ool00`00Oomoo`0]Ool002ioo`03001oogoo0?moo`Qoo`03001oogoo02eoo`00;Woo00<0
07ooOol0ogoo27oo00<007ooOol0;Goo000^Ool00`00Oomoo`3oOol8Ool00`00Oomoo`0]Ool002io
o`03001oogoo0?moo`Qoo`03001oogoo02eoo`00;Woo00<007ooOol0ogoo27oo00<007ooOol0;Goo
000^Ool00`00Oomoo`3oOol8Ool00`00Oomoo`0]Ool002ioo`03001oogoo0?moo`Qoo`03001oogoo
02eoo`00;Woo00<007ooOol0ogoo27oo00<007ooOol0;Goo000^Ool00`00Oomoo`3oOol8Ool00`00
Oomoo`0]Ool002ioo`03001oogoo0?moo`Qoo`03001oogoo02eoo`00;Woo00<007ooOol0ogoo27oo
00<007ooOol0;Goo000^Ool00`00Oomoo`3oOol8Ool00`00Oomoo`0]Ool002ioo`03001oogoo0?mo
o`Qoo`03001oogoo02eoo`00;Woo00<007ooOol0ogoo27oo00<007ooOol0;Goo000^Ool00`00Oomo
o`3oOol8Ool00`00Oomoo`0]Ool002ioo`03001oogoo0?moo`Qoo`03001oogoo02eoo`00;Woo00<0
07ooOol0ogoo27oo00<007ooOol0;Goo000^Ool00`00Oomoo`3oOol8Ool00`00Oomoo`0]Ool002io
o`03001oogoo0?moo`Qoo`03001oogoo02eoo`0057oo1@001Goo0P003Woo00<007ooOol0kWoo0`00
1Woo0P003Woo00<007ooOol0;Goo000FOol00`00Oomoo`04Ool01000Oomoo`003Goo00<007ooOol0
kWoo00<007ooOol01Goo00@007ooOol000eoo`03001oogoo02eoo`003Woo0P000Woo0`0000=oo`00
Ool01Goo00@007ooOol000eoo`03001oogoo0>Ioo`80009oo`<0009oo`03001oogoo00Aoo`04001o
ogoo000=Ool00`00Oomoo`0]Ool000moo`04001oogoo0003Ool00`00Oomoo`05Ool2000>Ool00`00
Oomoo`3WOol01000Oomoo`0017oo00<007ooOol01Goo0P003Woo00<007ooOol0;Goo000?Ool00`00
Ool00004Ool00`00Oomoo`0EOol00`00Oomoo`3WOol00`00Ool00004Ool00`00Ool0000FOol00`00
Oomoo`0]Ool000moo`<000=oo`8001Moo`03001oogoo0>Moo`<000Eoo`03001oogoo01Eoo`03001o
ogoo02eoo`003goo00@007ooOol001]oo`03001oogoo0>Moo`04001oogoo000LOol00`00Oomoo`0]
Ool000moo`03001oo`0000<001Uoo`03001oogoo0>Moo`03001oo`0000<001Yoo`03001oogoo02eo
o`003goo00<007ooOol077oo00<007ooOol0igoo00<007ooOol07Goo00<007ooOol0;Goo000>Ool2
000NOol00`00Oomoo`3VOol2000OOol00`00Oomoo`0]Ool002ioo`03001oogoo0?moo`Qoo`03001o
ogoo02eoo`00;Woo00<007ooOol0ogoo27oo00<007ooOol0;Goo000^Ool00`00Oomoo`3oOol8Ool0
0`00Oomoo`0]Ool002ioo`03001oogoo0?moo`Qoo`03001oogoo02eoo`00;Woo00<007ooOol0ogoo
27oo00<007ooOol0;Goo000^Ool00`00Oomoo`3oOol8Ool00`00Oomoo`0]Ool002ioo`03001oogoo
0?moo`Qoo`03001oogoo02eoo`00;Woo00<007ooOol0ogoo27oo00<007ooOol0;Goo000^Ool00`00
Oomoo`3oOol8Ool00`00Oomoo`0]Ool002ioo`03001oogoo0?moo`Qoo`03001oogoo02eoo`00;Woo
00<007ooOol0ogoo27oo00<007ooOol0;Goo000^Ool00`00Oomoo`3oOol8Ool00`00Oomoo`0]Ool0
02ioo`03001oogoo0?moo`Qoo`03001oogoo02eoo`00;Woo00<007ooOol0ogoo27oo00<007ooOol0
;Goo000^Ool00`00Oomoo`3oOol8Ool00`00Oomoo`0]Ool002ioo`03001oogoo0?moo`Qoo`03001o
ogoo02eoo`00;Woo00<007ooOol0ogoo27oo00<007ooOol0;Goo000^Ool00`00Oomoo`3oOol8Ool0
0`00Oomoo`0]Ool002ioo`03001oogoo0?moo`Qoo`03001oogoo02eoo`00;Woo00<007ooOol0ogoo
27oo00<007ooOol0;Goo000^Ool00`00Oomoo`3oOol8Ool00`00Oomoo`0]Ool002ioo`03001oogoo
0?moo`Qoo`03001oogoo02eoo`00;Woo00<007ooOol0ogoo27oo00<007ooOol0;Goo000^Ool00`00
Oomoo`3oOol8Ool00`00Oomoo`0]Ool002Yoo`X00?moo`/002Yoo`0097oo1P002Woo1P00m7oo1@00
2goo1@009Goo000ROol2000FOol00`00Oomoo`3_Ool2000EOol2000SOol001moo`<001Uoo`@00>Uo
o`@001Uoo`<0021oo`007Goo0P0087oo0P00LGoo0`0000=oo`0000000`00Jgoo0P0087oo0P007Woo
000KOol2000TOol00`00Oomoo`1^Ool00`00Oomoo`03Ool00`00Oomoo`1ZOol00`00Oomoo`0ROol2
000LOol001Yoo`03001oogoo02Eoo`8006Ioo`80009oo`<0009oo`03001oogoo009oo`03001oogoo
06Qoo`8002Moo`03001oogoo01Uoo`0067oo0P00:Woo00<007ooOol0I7oo00@007ooOol000Aoo`03
001oogoo009oo`03001oogoo06Moo`03001oogoo02Qoo`8001Uoo`005goo00<007ooOol0:goo0P00
I7oo00<007oo000017oo00<007oo00000goo00<007ooOol0IWoo00<007ooOol0:goo00<007ooOol0
5Woo000FOol00`00Oomoo`0^Ool00`00Oomoo`1QOol30005Ool01000Oomoogoo0P00Igoo00<007oo
Ool0;Goo00<007ooOol05Goo000EOol00`00Oomoo`0`Ool00`00Oomoo`1POol01000Oomoo`00L7oo
00<007ooOol0;goo00<007ooOol057oo000COol2000dOol00`00Oomoo`1OOol00`00Ool00003001/
Ool2000cOol00`00Oomoo`0COol0019oo`03001oogoo03Eoo`03001oogoo05ioo`03001oogoo06io
o`03001oogoo03Aoo`03001oogoo019oo`004Goo00<007ooOol0=Woo00<007ooOol0GGoo0P00Kgoo
00<007ooOol0=Woo00<007ooOol04Goo000AOol00`00Oomoo`0gOol00`00Oomoo`3=Ool00`00Oomo
o`0gOol00`00Oomoo`0@Ool0011oo`03001oogoo03Uoo`03001oogoo0<]oo`03001oogoo03Uoo`03
001oogoo00moo`003goo00<007ooOol0>goo00<007ooOol0bGoo00<007ooOol0>goo00<007ooOol0
3Woo000?Ool00`00Oomoo`0lOol00`00Oomoo`37Ool00`00Oomoo`0lOol00`00Oomoo`0>Ool000io
o`03001oogoo03ioo`03001oogoo01=oo`800;1oo`03001oogoo03ioo`03001oogoo00eoo`003Goo
00<007ooOol0@7oo00<007ooOol03Woo1P00[goo00<007ooOol0@7oo00<007ooOol037oo000=Ool0
0`00Oomoo`10Ool00`00Oomoo`0;Ool9002_Ool00`00Oomoo`10Ool00`00Oomoo`0<Ool000aoo`03
001oogoo045oo`03001oogoo00Moo`d00:moo`03001oogoo045oo`03001oogoo00]oo`0037oo00<0
07ooOol0@Goo00<007ooOol00goo4@00[goo00<007ooOol0@Goo00<007ooOol02goo000;Ool00`00
Oomoo`13Ool00`00Oomoo`2o0002Ool00`00Oomoo`13Ool00`00Oomoo`0:Ool000]oo`03001oogoo
04Aoo`03001oogoo009ooa000:eoo`03001oogoo04Aoo`03001oogoo00Yoo`002goo00<007ooOol0
A7oo00<007ooOol01Woo3000[Goo00<007ooOol0A7oo00<007ooOol02Woo000:Ool00`00Oomoo`15
Ool00`00Oomoo`0;Ool7002]Ool00`00Oomoo`15Ool00`00Oomoo`09Ool000Yoo`03001oogoo04Eo
o`03001oogoo00moo`<00:eoo`03001oogoo04Eoo`03001oogoo00Uoo`002Goo00<007ooOol0Agoo
00<007ooOol0_Goo00<007ooOol0Agoo00<007ooOol027oo0009Ool00`00Oomoo`17Ool00`00Oomo
o`2mOol00`00Oomoo`17Ool00`00Oomoo`08Ool000Uoo`03001oogoo04Moo`03001oogoo0;eoo`03
001oogoo04Moo`03001oogoo00Qoo`002Goo00<007ooOol0B7oo00<007ooOol0^goo00<007ooOol0
B7oo00<007ooOol027oo0009Ool00`00Oomoo`18Ool00`00Oomoo`2kOol00`00Oomoo`18Ool00`00
Oomoo`08Ool000Qoo`03001oogoo04Uoo`03001oogoo0;]oo`03001oogoo04Uoo`03001oogoo00Mo
o`0027oo00<007ooOol0BGoo00<007ooOol0^goo00<007ooOol0BGoo00<007ooOol01goo0008Ool0
0`00Oomoo`19Ool00`00Oomoo`2kOol00`00Oomoo`19Ool00`00Oomoo`07Ool000Qoo`03001oogoo
029oo`D0029oo`03001oogoo0;]oo`03001oogoo021oo`D002Aoo`03001oogoo00Moo`0027oo00<0
07ooOol097oo00<007ooOol08Woo00<007ooOol0^goo00<007ooOol087oo00D007ooOomoo`0002Ao
o`03001oogoo00Moo`0027oo00<007ooOol097oo00<007ooOol08Woo00<007ooOol0^goo00<007oo
Ool08Goo00<007ooOol09Goo00<007ooOol01goo0008Ool00`00Oomoo`0TOol00`00Oomoo`0ROol0
0`00Oomoo`2kOol00`00Oomoo`0ROol00`00Oomoo`0TOol00`00Oomoo`07Ool000Qoo`03001oogoo
02Aoo`03001oogoo029oo`03001oogoo0;]oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo
00Moo`0027oo00<007ooOol097oo00<007ooOol08Woo00<007ooOol0^goo00<007ooOol097oo00<0
07ooOol08Woo00<007ooOol01goo0008Ool00`00Oomoo`0ROol3000TOol00`00Oomoo`2kOol00`00
Oomoo`0POol01@00Oomoogoo000097oo00<007ooOol01goo0009Ool00`00Oomoo`0SOol00`00Oomo
o`0ROol00`00Oomoo`2kOol00`00Oomoo`0QOol3000TOol00`00Oomoo`08Ool000Uoo`03001oogoo
04Qoo`03001oogoo0;]oo`03001oogoo04Qoo`03001oogoo00Qoo`002Goo00<007ooOol0Agoo00<0
07ooOol0_Goo00<007ooOol0Agoo00<007ooOol027oo0009Ool00`00Oomoo`17Ool00`00Oomoo`2m
Ool00`00Oomoo`17Ool00`00Oomoo`08Ool000Uoo`03001oogoo04Moo`03001oogoo0;eoo`03001o
ogoo04Moo`03001oogoo00Qoo`002Woo00<007ooOol0AGoo00<007ooOol0_goo00<007ooOol0AGoo
00<007ooOol02Goo000:Ool00`00Oomoo`15Ool00`00Oomoo`2[Ool3000AOol00`00Oomoo`15Ool0
0`00Oomoo`09Ool000]oo`03001oogoo04Aoo`03001oogoo0:]oo`L000eoo`03001oogoo04Aoo`03
001oogoo00Yoo`002goo00<007ooOol0A7oo00<007ooOol0Zgoo300027oo00<007ooOol0A7oo00<0
07ooOol02Woo000;Ool00`00Oomoo`13Ool00`00Oomoo`2/Ool@0005Ool00`00Oomoo`13Ool00`00
Oomoo`0:Ool000]oo`03001oogoo04=oo`03001oogoo0;l0009oo`03001oogoo04=oo`03001oogoo
00Yoo`0037oo00<007ooOol0@Goo00<007ooOol0[Goo4@001Goo00<007ooOol0@Goo00<007ooOol0
2goo000=Ool00`00Oomoo`10Ool00`00Oomoo`2]Ool=0009Ool00`00Oomoo`10Ool00`00Oomoo`0<
Ool000eoo`03001oogoo041oo`03001oogoo0:eoo`X000aoo`03001oogoo041oo`03001oogoo00ao
o`003Woo00<007ooOol0?Woo00<007ooOol0[Woo1P004Goo00<007ooOol0?Woo00<007ooOol03Goo
000>Ool00`00Oomoo`0nOol00`00Oomoo`2^Ool2000EOol00`00Oomoo`0nOol00`00Oomoo`0=Ool0
00moo`03001oogoo03aoo`03001oogoo0<Moo`03001oogoo03aoo`03001oogoo00ioo`0047oo00<0
07ooOol0>Woo00<007ooOol0bGoo00<007ooOol0>Woo00<007ooOol03goo000@Ool00`00Oomoo`0i
Ool00`00Oomoo`3;Ool00`00Oomoo`0iOol00`00Oomoo`0?Ool0015oo`03001oogoo03Moo`03001o
ogoo0<eoo`03001oogoo03Moo`03001oogoo011oo`004Goo00<007ooOol0=Woo00<007ooOol0cWoo
00<007ooOol0=Woo00<007ooOol04Goo000BOol00`00Oomoo`0eOol00`00Oomoo`1TOol5000017oo
00000000HWoo00<007ooOol0=7oo00<007ooOol04Woo000COol2000dOol00`00Oomoo`1WOol01@00
Oomoogoo0000IGoo0P00<goo00<007ooOol04goo000EOol00`00Oomoo`0`Ool00`00Oomoo`1OOol2
0002Ool30002Ool00`00Oomoo`02Ool00`00Oomoo`1TOol00`00Oomoo`0_Ool00`00Oomoo`0DOol0
01Ioo`03001oogoo02ioo`03001oogoo065oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomo
o`1UOol00`00Oomoo`0]Ool00`00Oomoo`0EOol001Moo`03001oogoo02aoo`03001oogoo069oo`03
001oo`0000Eoo`07001oogooOol007oo0000Igoo00<007ooOol0:goo00<007ooOol05Woo000HOol0
0`00Oomoo`0YOol2001UOol30004Ool20004Ool00`00Oomoo`1WOol00`00Oomoo`0YOol00`00Oomo
o`0GOol001Uoo`8002Qoo`03001oogoo06Eoo`04001oogoo001dOol00`00Oomoo`0VOol2000JOol0
01]oo`03001oogoo02=oo`8006Qoo`03001oo`0000<007=oo`8002Eoo`03001oogoo01Yoo`0077oo
0P008Woo00<007ooOol0J7oo00<007ooOol0N7oo00<007ooOol087oo0P007Goo000NOol3000KOol4
001ZOol2001kOol4000KOol3000OOol0025oo`8001Moo`800>moo`8001Moo`80029oo`008goo1P00
37oo1@00lgoo1@0037oo1P0097oo000YOol<003mOol<000ZOol002ioo`03001oogoo0?moo`Qoo`03
001oogoo02eoo`00;Woo0P00ogoo27oo0P00;goo000]Ool3003oOol8Ool3000^Ool002eoo`<00?mo
o`Qoo`<002ioo`00;Goo0`00ogoo27oo0`00;Woo000]Ool200000goo001oo`3oOol5Ool01000Ool0
0000;Woo000/Ool01@00Ool007oo0000ogoo1Woo00D007oo001oo`0002eoo`00;7oo00D007oo001o
o`000?moo`Ioo`05001oo`00Ool0000]Ool002aoo`03001oo`00009oo`03001oogoo0?moo`9oo`06
001oogoo001oo`00;Goo000/Ool00`00Ool00002Ool00`00Oomoo`3oOol2Ool01P00Oomoo`00Ool0
02eoo`00;7oo00<007oo00000Woo00<007ooOol0ogoo0Woo00H007ooOol007oo000]Ool002]oo`04
001oogoo0002Ool00`00Oomoo`3oOol2Ool01000Oomoo`000Woo00<007ooOol0:Woo000[Ool01000
Oomoo`000goo00<007ooOol0ogoo00D007ooOomoo`00009oo`03001oogoo02Yoo`00:goo00@007oo
Ool000=oo`03001oogoo0?moo`05001oogooOol00002Ool00`00Oomoo`0ZOol002]oo`04001oogoo
0003Ool00`00Oomoo`3oOol01@00Oomoogoo00000Woo00<007ooOol0:Woo000ZOol01@00Oomoogoo
00000goo00<007ooOol0ogoo00D007ooOomoo`0000=oo`03001oogoo02Uoo`00:Woo00D007ooOomo
o`0000Aoo`03001oogoo0?eoo`03001oogoo009oo`05001oogooOol0000[Ool002Yoo`05001oogoo
Ool00004Ool00`00Oomoo`3mOol00`00Oomoo`02Ool01@00Oomoogoo0000:goo000^Ool00`00Oomo
o`3oOol8Ool00`00Oomoo`0]Ool002ioo`03001oogoo0?moo`Qoo`03001oogoo02eoo`00;Woo00<0
07ooOol0ogoo27oo00<007ooOol0;Goo000^Ool00`00Oomoo`3oOol8Ool00`00Oomoo`0]Ool002io
o`03001oogoo0?moo`Qoo`03001oogoo02eoo`00;Woo00<007ooOol0ogoo27oo00<007ooOol0;Goo
000^Ool00`00Oomoo`3oOol8Ool00`00Oomoo`0]Ool002ioo`03001oogoo0?moo`Qoo`03001oogoo
02eoo`00;Woo00<007ooOol0ogoo27oo00<007ooOol0;Goo000^Ool00`00Oomoo`3oOol8Ool00`00
Oomoo`0]Ool002ioo`03001oogoo0?moo`Qoo`03001oogoo02eoo`00;Woo00<007ooOol0ogoo27oo
00<007ooOol0;Goo000^Ool00`00Oomoo`3oOol8Ool00`00Oomoo`0]Ool002ioo`03001oogoo0?mo
o`Qoo`03001oogoo02eoo`00;Woo00<007ooOol0ogoo27oo00<007ooOol0;Goo000^Ool00`00Oomo
o`3oOol8Ool00`00Oomoo`0]Ool002ioo`03001oogoo0?moo`Qoo`03001oogoo02eoo`00;Woo00<0
07ooOol0ogoo27oo00<007ooOol0;Goo000^Ool00`00Oomoo`3oOol8Ool00`00Oomoo`0]Ool002io
o`03001oogoo0?moo`Qoo`03001oogoo02eoo`00;Woo00<007ooOol0ogoo27oo00<007ooOol0;Goo
000^Ool00`00Oomoo`3oOol8Ool00`00Oomoo`0]Ool002ioo`03001oogoo0?moo`Qoo`03001oogoo
02eoo`002Goo1@001goo00<007ooOol01goo00<007ooOol037oo00<007ooOol0ggoo0`0027oo00<0
07ooOol01goo00<007ooOol047oo00<007ooOol0;Goo000;Ool00`00Oomoo`06Ool00`00Oomoo`09
Ool00`00Oomoo`0;Ool00`00Oomoo`3OOol00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`0?
Ool00`00Oomoo`0]Ool0009oo`800004Ool000000003Ool00`00Oomoo`05Ool00`00Oomoo`04Ool3
0004Ool00`00Oomoo`0:Ool00`00Oomoo`3FOol2000017oo0000000017oo00<007ooOol01Goo00<0
07ooOol00goo0`001Goo00<007ooOol03Woo00<007ooOol0;Goo0003Ool20003Ool01000Oomoo`00
1goo00<007ooOol00goo00D007ooOomoo`0000=oo`03001oogoo00Yoo`03001oogoo0=Moo`8000=o
o`05001oogooOol00007Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol03Woo00<0
07ooOol0;Goo0003Ool00`00Oomoo`02Ool01000Oomoo`001goo00<007ooOol00goo00<007ooOol0
1Goo00<007ooOol02Woo00<007ooOol0egoo00<007ooOol00Woo00H007ooOol007oo0006Ool00`00
Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0>Ool00`00Oomoo`0]Ool000=oo`03001oogoo009o
o`04001oo`000007Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`3G
Ool00`00Oomoo`02Ool01@00Oomoogoo00001goo00<007ooOol00Woo00<007ooOol01Woo00<007oo
Ool03Woo00<007ooOol0;Goo0003Ool20003Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomo
o`05Ool00`00Oomoo`0:Ool00`00Oomoo`3GOol20003Ool00`00Oomoo`09Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`0>Ool00`00Oomoo`0]Ool000=oo`03001oo`00008000]oo`03001o
ogoo009oo`D000Aoo`03001oogoo00Yoo`03001oogoo0=Moo`03001oo`00008000aoo`04001oogoo
Ool50005Ool00`00Oomoo`0>Ool00`00Oomoo`0]Ool000=oo`03001oogoo00ioo`03001oogoo009o
o`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo0=Moo`03001oogoo00moo`05001oogooOol0
0007Ool00`00Oomoo`0?Ool00`00Oomoo`0]Ool0009oo`80015oo`03001oogoo00Moo`03001oogoo
00aoo`03001oogoo0=Ioo`80019oo`03001oogoo00Moo`03001oogoo011oo`03001oogoo02eoo`00
;Woo00<007ooOol0ogoo27oo00<007ooOol0;Goo000^Ool00`00Oomoo`3oOol8Ool00`00Oomoo`0]
Ool002ioo`03001oogoo0?moo`Qoo`03001oogoo02eoo`00;Woo00<007ooOol0ogoo27oo00<007oo
Ool0;Goo000^Ool00`00Oomoo`3oOol8Ool00`00Oomoo`0]Ool002ioo`03001oogoo0?moo`Qoo`03
001oogoo02eoo`00;Woo00<007ooOol0ogoo27oo00<007ooOol0;Goo000^Ool00`00Oomoo`3oOol8
Ool00`00Oomoo`0]Ool002ioo`03001oogoo0?moo`Qoo`03001oogoo02eoo`00;Woo00<007ooOol0
ogoo27oo00<007ooOol0;Goo000^Ool00`00Oomoo`3oOol8Ool00`00Oomoo`0]Ool002ioo`03001o
ogoo0?moo`Qoo`03001oogoo02eoo`00;Woo00<007ooOol0ogoo27oo00<007ooOol0;Goo000^Ool0
0`00Oomoo`3oOol8Ool00`00Oomoo`0]Ool002ioo`03001oogoo0?moo`Qoo`03001oogoo02eoo`00
;Woo00<007ooOol0ogoo27oo00<007ooOol0;Goo000^Ool00`00Oomoo`3oOol8Ool00`00Oomoo`0]
Ool002ioo`03001oogoo0?moo`Qoo`03001oogoo02eoo`00;Woo00<007ooOol0ogoo27oo00<007oo
Ool0;Goo000^Ool00`00Oomoo`3oOol8Ool00`00Oomoo`0]Ool002ioo`03001oogoo0?moo`Qoo`03
001oogoo02eoo`00;Woo00<007ooOol0ogoo27oo00<007ooOol0;Goo000^Ool00`00Oomoo`3oOol8
Ool00`00Oomoo`0]Ool002ioo`03001oogoo0?moo`Qoo`03001oogoo02eoo`00;Woo00<007ooOol0
ogoo27oo00<007ooOol0;Goo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
\
\>"],
  ImageRangeCache->{{{127.625, 414.625}, {612.25, 421.25}} -> {-2.7215, \
5.37241, 0.0164924, 0.0164924}}],

Cell["Here is de compartmental matrix", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(model3\)\(\ \)\(=\)\(CompartMatrix[
        2, {{1, 2, \ k12}, \ {2, 1, \ k21}, \ {1, 0, \ k10}, \ {2, 0, \ 
            k20}}]\)\(\ \)\)\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \({{\(-k10\) - k12, k21}, {k12, \(-k20\) - k21}}\)], "Output",
  CellLabel->"Out[51]="]
}, Open  ]],

Cell["And here the SODE ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ShowODE[model3, \ {0, 0}, {b1, b2}, \ t, \ x] // TableForm\)], "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                SuperscriptBox[\(x\_1\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b1 + \((\(-k10\) - k12)\)\ x\_1[t] + 
                k21\ x\_2[t]\)}]},
          {
            RowBox[{
              RowBox[{
                SuperscriptBox[\(x\_2\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b2 + 
                k12\ x\_1[t] + \((\(-k20\) - k21)\)\ x\_2[t]\)}]},
          {\(x\_1[0] \[Equal] 0\)},
          {\(x\_2[0] \[Equal] 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Derivative[ 1][ 
            Subscript[ x, 1]][ t], 
          Plus[ b1, 
            Times[ 
              Plus[ 
                Times[ -1, k10], 
                Times[ -1, k12]], 
              Subscript[ x, 1][ t]], 
            Times[ k21, 
              Subscript[ x, 2][ t]]]], 
        Equal[ 
          Derivative[ 1][ 
            Subscript[ x, 2]][ t], 
          Plus[ b2, 
            Times[ k12, 
              Subscript[ x, 1][ t]], 
            Times[ 
              Plus[ 
                Times[ -1, k20], 
                Times[ -1, k21]], 
              Subscript[ x, 2][ t]]]], 
        Equal[ 
          Subscript[ x, 1][ 0], 0], 
        Equal[ 
          Subscript[ x, 2][ 0], 0]}]]], "Output",
  CellLabel->"Out[52]//TableForm="]
}, Open  ]],

Cell["In matrix notation can be represented as", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{
                StyleBox["x",
                  FontWeight->"Bold"], 
                StyleBox["'",
                  FontWeight->"Plain"]}],
              FontSlant->"Plain"], \((t)\)}], " ", "=", 
          RowBox[{
            StyleBox[
              RowBox[{
                StyleBox["A",
                  FontSlant->"Plain"], " ", 
                StyleBox["x",
                  FontSlant->"Plain"]}],
              FontWeight->"Bold"], 
            StyleBox[" ",
              FontWeight->"Bold"], "+", " ", 
            RowBox[{
              StyleBox["b",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", "t", ")"}]}]}], ",", 
        " ", \(t \[GreaterEqual] 0\)}], TraditionalForm]], "EquationNumber"],

Cell["where", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["x",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "'"}], \((t)\)}], " ", "=", 
            RowBox[{"(", GridBox[{
                  {\(\(x\& . \)\_1\)},
                  {\(\(x\& . \)\_2\)}
                  }], ")"}]}], " ", ";", " ", 
          RowBox[{
            StyleBox["A",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[" ",
              FontWeight->"Bold"], "=", "  ", 
            RowBox[{"(", GridBox[{
                  {\(a\_11\), \(a\_12\)},
                  {\(a\_21\), \(a\_22\)}
                  }], ")"}]}], ";", 
          RowBox[{
            StyleBox["x",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[" ",
              FontWeight->"Bold"], "=", 
            RowBox[{"(", GridBox[{
                  {\(x\_1\)},
                  {\(x\_2\)}
                  }], ")"}]}], 
          StyleBox[" ",
            FontWeight->"Bold"], ";", "  ", 
          RowBox[{
            RowBox[{
              StyleBox["b",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", "t", ")"}], " ", "=", 
            RowBox[{"(", GridBox[{
                  {\(b\_1\)},
                  {\(b\_2\)}
                  }], ")"}]}]}], " ", ",", " ", \(t \[GreaterEqual] 0\)}], 
      TraditionalForm]], "Text"],

Cell[TextData[{
  "with  ",
  Cell[BoxData[
      \(TraditionalForm\`a\_11\  = \(\(-\((k\_10 + k\_12)\)\)\(\ \)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(\(12\)\(\ \)\) = \ k\_21\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(\(21\)\(\ \)\) = \ k\_12\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`a\_22 = \(\(-\((k\_20 + k\_21)\)\)\(\ \)\)\)]]
}], "Text"],

Cell[TextData[{
  "The previous equation can be applied to a particular case substituting ",
  Cell[BoxData[
      \(TraditionalForm\`k\_ij\)]],
  " and the initial conditions ",
  Cell[BoxData[
      \(X1\_0\)]],
  " and ",
  Cell[BoxData[
      \(X2\_0\)]],
  " for their respective values, i.e.: Let's take ",
  Cell[BoxData[
      \(TraditionalForm\`k\_\(\(10\)\(\ \)\) = \ 0.05\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`k\_20 = 0.3\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(k\_12\  = \ 0.4\)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`k\_21 = \ 0.3\)]],
  ",  ",
  Cell[BoxData[
      \(X1\_0 = 1\)]],
  ", ",
  Cell[BoxData[
      \(X2\_0 = 1\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\({x1[t1_], \ x2[t1_]} = \ {x\_1[t1], x\_2[t1]} /. 
        SystemDSolve[
          model3 /. {k10 \[Rule] 0.05, \ k20 \[Rule] 0.03, k12 \[Rule] 0.04, 
              k21 \[Rule] 0.02\ }, \ {0, \ 0}, {1, \ 1}, \ t, \ t1, \ 
          x]\)\)\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    \({\(\(18.91891891891892`\)\(\[InvisibleSpace]\)\) - 
        4.778241060624656`\ \[ExponentialE]\^\(\(-0.10464101615137755`\)\ \
t1\) - 14.140677858294262`\ \[ExponentialE]\^\(\(-0.035358983848622454`\)\ t1\
\), \(\(35.13513513513514`\)\(\[InvisibleSpace]\)\) + 
        3.497915227189049`\ \[ExponentialE]\^\(\(-0.10464101615137755`\)\ \
t1\) - 38.633050362324184`\ \[ExponentialE]\^\(\(-0.035358983848622454`\)\ t1\
\)}\)], "Output",
  CellLabel->"Out[53]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{x1[t], x2[t]}, \ {t, \ 0, 100}]\)], "Input",
  CellLabel->"In[54]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0147151 0.0173069 [
[.21429 .00222 -6 -9 ]
[.21429 .00222 6 0 ]
[.40476 .00222 -6 -9 ]
[.40476 .00222 6 0 ]
[.59524 .00222 -6 -9 ]
[.59524 .00222 6 0 ]
[.78571 .00222 -6 -9 ]
[.78571 .00222 6 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .10125 -6 -4.5 ]
[.01131 .10125 0 4.5 ]
[.01131 .18778 -12 -4.5 ]
[.01131 .18778 0 4.5 ]
[.01131 .27432 -12 -4.5 ]
[.01131 .27432 0 4.5 ]
[.01131 .36085 -12 -4.5 ]
[.01131 .36085 0 4.5 ]
[.01131 .44739 -12 -4.5 ]
[.01131 .44739 0 4.5 ]
[.01131 .53392 -12 -4.5 ]
[.01131 .53392 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(20)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(40)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(60)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(80)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(100)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10125 m
.03006 .10125 L
s
[(5)] .01131 .10125 1 0 Mshowa
.02381 .18778 m
.03006 .18778 L
s
[(10)] .01131 .18778 1 0 Mshowa
.02381 .27432 m
.03006 .27432 L
s
[(15)] .01131 .27432 1 0 Mshowa
.02381 .36085 m
.03006 .36085 L
s
[(20)] .01131 .36085 1 0 Mshowa
.02381 .44739 m
.03006 .44739 L
s
[(25)] .01131 .44739 1 0 Mshowa
.02381 .53392 m
.03006 .53392 L
s
[(30)] .01131 .53392 1 0 Mshowa
.125 Mabswid
.02381 .03202 m
.02756 .03202 L
s
.02381 .04933 m
.02756 .04933 L
s
.02381 .06664 m
.02756 .06664 L
s
.02381 .08394 m
.02756 .08394 L
s
.02381 .11856 m
.02756 .11856 L
s
.02381 .13586 m
.02756 .13586 L
s
.02381 .15317 m
.02756 .15317 L
s
.02381 .17048 m
.02756 .17048 L
s
.02381 .20509 m
.02756 .20509 L
s
.02381 .2224 m
.02756 .2224 L
s
.02381 .2397 m
.02756 .2397 L
s
.02381 .25701 m
.02756 .25701 L
s
.02381 .29163 m
.02756 .29163 L
s
.02381 .30893 m
.02756 .30893 L
s
.02381 .32624 m
.02756 .32624 L
s
.02381 .34355 m
.02756 .34355 L
s
.02381 .37816 m
.02756 .37816 L
s
.02381 .39547 m
.02756 .39547 L
s
.02381 .41277 m
.02756 .41277 L
s
.02381 .43008 m
.02756 .43008 L
s
.02381 .46469 m
.02756 .46469 L
s
.02381 .482 m
.02756 .482 L
s
.02381 .49931 m
.02756 .49931 L
s
.02381 .51662 m
.02756 .51662 L
s
.02381 .55123 m
.02756 .55123 L
s
.02381 .56854 m
.02756 .56854 L
s
.02381 .58584 m
.02756 .58584 L
s
.02381 .60315 m
.02756 .60315 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .07602 L
.10458 .12677 L
.14415 .16355 L
.18221 .19171 L
.22272 .2159 L
.26171 .2349 L
.30316 .25155 L
.34309 .26487 L
.3815 .27566 L
.42237 .28538 L
.46172 .29332 L
.49955 .29986 L
.53984 .30583 L
.57861 .31076 L
.61984 .31525 L
.65954 .31897 L
.69774 .32205 L
.73838 .32487 L
.77751 .32721 L
.81909 .32935 L
.85916 .33113 L
.89771 .3326 L
.93871 .33395 L
.97619 .33501 L
s
.02381 .01472 m
.06244 .08312 L
.10458 .15233 L
.14415 .21123 L
.18221 .26207 L
.22272 .31011 L
.26171 .3508 L
.30316 .3886 L
.34309 .42026 L
.3815 .44679 L
.42237 .47131 L
.46172 .49174 L
.49955 .50881 L
.53984 .52457 L
.57861 .5377 L
.61984 .54974 L
.65954 .55974 L
.69774 .56806 L
.73838 .57572 L
.77751 .58208 L
.81909 .5879 L
.85916 .59272 L
.89771 .59673 L
.93871 .60041 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[54]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00?`3oool4000000<0oooo0P00000]0?ooo`<000000P3oool2000002/0oooo0`0000040?oo
o`800000;03oool2000000@0oooo0P00000X0?ooo`D000000P3oool2000000@0oooo0P0000050?oo
o`00?`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000002d0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0X0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000:P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
02T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool00P3oool00400oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
000Z0?ooo`D0000000D0oooo0000003oool0oooo0000000Z0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000:P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000002T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool00P3oool00440oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000Z
0?ooo`<000000`3oool010000000oooo0?ooo`00000[0?ooo`8000000`3oool010000000oooo0?oo
o`00000Y0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0080oooo000o0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000:`3oool00`000000oooo000000020?ooo`040000003oool0oooo000002/0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000Z0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000:@3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`00@03oool2000000@0oooo0P00000]
0?ooo`8000000`3oool2000002`0oooo0`0000030?ooo`800000;03oool2000000@0oooo0P00000Y
0?ooo`800000103oool2000000@0oooo0P0000050?ooo`00o`3ooolQ0?ooo`00403oool00`000000
oooo0?ooo`3o0?ooo`h0oooo000@0?ooo`030000003oool0oooo0?l0oooo3P3oool00100oooo00<0
00000?ooo`3oool0o`3oool>0?ooo`00403oool00`000000oooo0?ooo`3o0?ooo`h0oooo000:0?oo
ool000004`0000040?ooo`00403oool2000000/0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`00403oool200000380oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`090?ooo`00403oool00`000000oooo0000003o0?ooo`h0oooo000@0?ooo`040000003oool0
000000000?l0oooo3@3oool00100oooo0P0000000`3oool000000?ooo`3o0?ooo``0oooo000@0?oo
o`030000003oool0oooo00800000o`3oool<0?ooo`00403oool010000000oooo0?ooo`3oool20000
0?l0oooo2`3oool00100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`T0
oooo000@0?ooo`8000000`3oool200000?l0oooo2P3oool00100oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`3o0?ooo`P0oooo000@0?ooo`030000003oool0oooo00<0oooo0P00003o
0?ooo`T0oooo000@0?ooo`030000003oool0oooo00@0oooo0P00003o0?ooo`P0oooo000@0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3oool60?ooo`00403oool2000000H0oooo
0P00003o0?ooo`L0oooo000@0?ooo`030000003oool0oooo00H0oooo0P00003o0?ooo`H0oooo000@
0?ooo`030000003oool0oooo00H0oooo0P00003o0?ooo`H0oooo000@0?ooo`030000003oool0oooo
00L0oooo0P00003o0?ooo`D0oooo000@0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`00
0000o`3oool40?ooo`00403oool2000000T0oooo00<000000?ooo`000000o`3oool30?ooo`00403o
ool00`000000oooo0?ooo`090?ooo`800000o`3oool30?ooo`00403oool00`000000oooo0?ooo`09
0?ooo`030000003oool000000?l0oooo0P3oool000T0oooo0P0000050?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`000000o`3oool10?ooo`00203oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000o`3oool000/0oooo00<000000?oo
o`3oool00P3oool3000000/0oooo00<000000?ooo`000000o`3oool000T0oooo0P0000050?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`000000oP3oool000T0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo00000?d0oooo00090?ooo`<00000
103oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo00000?`0oooo000@0?ooo`800000
3P3oool01@000000oooo0?ooo`3oool000000?/0oooo000@0?ooo`030000003oool0oooo00h0oooo
00@000000?ooo`3oool00000n`3oool00100oooo00<000000?ooo`3oool03`3oool010000000oooo
0?ooo`00003j0?ooo`00403oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`00
0000n@3oool00100oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000?P0
oooo000@0?ooo`8000004P3oool01@000000oooo0?ooo`3oool000000?L0oooo000@0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3d0?ooo`00403o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0l`3o
ool00100oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`800000l`3oool0
0100oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0?00oooo000@0?ooo`8000005@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0>l0
oooo000@0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`3^0?ooo`00403oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0k@3oool00100oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0>`0oooo000@0?ooo`8000005`3oool00`000000oooo0?ooo`060?oo
o`800000k03oool00100oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0>T0oooo000@0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
1`3oool200000>T0oooo00020?ooo`D000000P3oool2000000D0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`090?ooo`800000i`3oool000@0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0>@0oooo00040?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`020?ooo`<000006@3oool00`000000oooo0?ooo`0;0?ooo`800000i03o
ool000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0>40oooo0004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0303oool200000>40oooo00030?ooo`800000103oool2
000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0=h0oooo000@0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool03P3oool20000
0=h0oooo000@0?ooo`8000007P3oool00`000000oooo0?ooo`0?0?ooo`800000g03oool00100oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0=T0oooo
000@0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04@3oool200000=T0oooo000@
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3F
0?ooo`00403oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0180oooo0P00003F0?oo
o`00403oool200000280oooo00<000000?ooo`3oool04`3oool200000=@0oooo000@0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool05@3oool200000=80oooo000@0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool05P3oool200000=00oooo000@0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool05`3oool300000<d0oooo000@0?ooo`8000009@3oool00`00
0000oooo0?ooo`0I0?ooo`800000b`3oool00100oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0J0?ooo`800000b@3oool00100oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0K0?ooo`<00000aP3oool00100oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0N0?ooo`800000a03oool00100oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0O
0?ooo`<00000`@3oool00100oooo0P00000Y0?ooo`030000003oool0oooo0240oooo0`00002n0?oo
o`00403oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02<0oooo1000002j0?ooo`00
403oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02H0oooo0`00002g0?ooo`000P3o
ool500000080oooo0P0000050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0:03o
ool400000;<0oooo00040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0;03oool400000:l0oooo0004
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool3000002`0oooo00<00000
0?ooo`3oool0;`3oool300000:`0oooo00040?ooo`030000003oool0oooo0080oooo0P0000050?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool0<@3oool400000:P0oooo00040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo03@0oooo1000002T0?ooo`000`3oool2000000@0oooo0`0000040?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool0>03oool400000:00oooo000@0?ooo`800000<03o
ool00`000000oooo0?ooo`0k0?ooo`H00000VP3oool00100oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`100?ooo`D00000U@3oool00100oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`140?ooo`D00000T03oool00100oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`180?ooo`P00000R03oool00100oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`1@0?ooo`P00000P03oool00100oooo0P00000d0?ooo`030000003oool0oooo05L0oooo1P00
001j0?ooo`00403oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo05`0oooo2000001b
0?ooo`00403oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo06<0oooo2`00001W0?oo
o`00403oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo06d0oooo2P00001M0?ooo`00
403oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo07H0oooo2`00001B0?ooo`00403o
ool2000003T0oooo00<000000?ooo`3oool0P03ooolF000003`0oooo000@0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0U@3ooolF000002H0oooo000@0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool0Z`3ooolK000000/0oooo000@0?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool0d03oool00100oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`3?0?ooo`00403oool2000003d0oooo00<000000?ooo`3oool0cP3oool00100oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`3=0?ooo`000P3oool4000000<0oooo0P0000050?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0c03oool00080oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool0b`3oool000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`<00000@03oool00`000000oooo0?ooo`3:0?ooo`00103oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`800000bP3oool00080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool0a`3oool000<0oooo0P0000040?ooo`8000001@3oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo0<H0oooo000@0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool0a@3oool00100oooo0P0000170?ooo`030000003oool0oooo0<@0oooo
000@0?ooo`030000003oool0oooo04L0oooo0P0000340?ooo`00403oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo0<40oooo000@0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool0`03oool00100oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`2o0?ooo`00
403oool2000004d0oooo00<000000?ooo`3oool0_P3oool00100oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`2m0?ooo`00403oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo0;`0oooo000@0?ooo`030000003oool0oooo04l0oooo0P00002l0?ooo`00403oool00`000000
oooo0?ooo`1A0?ooo`030000003oool0oooo0;T0oooo000@0?ooo`800000D`3oool00`000000oooo
0?ooo`2h0?ooo`00403oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0;L0oooo000@
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0]P3oool00100oooo00<000000?oo
o`3oool0E@3oool200000;H0oooo000@0?ooo`800000F03oool00`000000oooo0?ooo`2c0?ooo`00
403oool00`000000oooo0?ooo`1H0?ooo`800000/`3oool00100oooo00<000000?ooo`3oool0FP3o
ool200000;40oooo00020?ooo`@000000`3oool2000000D0oooo00<000000?ooo`3oool0G03oool0
0`000000oooo0?ooo`2^0?ooo`000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0G@3oool200000:h0oooo00030?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool3000005l0oooo00<000000?ooo`3oool0Z`3oool000@0
oooo00<000000?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool0H03oool200000:/0
oooo00020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1R0?ooo`800000Z@3oool000<0oooo0P0000040?ooo`<00000103oool00`000000oooo
0?ooo`1T0?ooo`800000Y`3oool00100oooo00<000000?ooo`3oool0IP3oool200000:D0oooo000@
0?ooo`800000J@3oool200000:<0oooo000@0?ooo`030000003oool0oooo06X0oooo00<000000?oo
o`3oool0X03oool00100oooo00<000000?ooo`3oool0J`3oool200000:00oooo000@0?ooo`030000
003oool0oooo06d0oooo0P00002N0?ooo`00403oool200000700oooo0P00002L0?ooo`00403oool0
0`000000oooo0?ooo`1a0?ooo`800000VP3oool00100oooo00<000000?ooo`3oool0L`3oool20000
09P0oooo000@0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0U@3oool00100oooo
00<000000?ooo`3oool0MP3oool2000009D0oooo000@0?ooo`800000N@3oool2000009<0oooo000@
0?ooo`030000003oool0oooo07X0oooo0P00002A0?ooo`00403oool00`000000oooo0?ooo`1l0?oo
o`800000S`3oool00100oooo00<000000?ooo`3oool0OP3oool3000008`0oooo000@0?ooo`030000
003oool0oooo0840oooo0`0000290?ooo`00403oool2000008D0oooo0P0000270?ooo`00403oool0
0`000000oooo0?ooo`260?ooo`<00000Q03oool00100oooo00<000000?ooo`3oool0R@3oool30000
0840oooo00030?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0S03oool3000007h0
oooo00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`2?0?ooo`800000O03oool000@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0080oooo0`00002A0?ooo`<00000N@3oool000D0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo09@0oooo0`00001f0?oo
o`000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0U`3oool400000780oooo00030?ooo`800000103oool2000000D0oooo00<000000?oo
o`3oool0V`3oool4000006h0oooo000@0?ooo`800000X03oool3000006/0oooo000@0?ooo`030000
003oool0oooo0:80oooo1000001W0?ooo`00403oool00`000000oooo0?ooo`2V0?ooo`@00000H`3o
ool00100oooo00<000000?ooo`3oool0ZP3oool4000005l0oooo000@0?ooo`030000003oool0oooo
0:h0oooo1@00001J0?ooo`00403oool200000;@0oooo1@00001E0?ooo`00403oool00`000000oooo
0?ooo`2h0?ooo`H00000C`3oool00100oooo00<000000?ooo`3oool0_P3oool5000004X0oooo000@
0?ooo`030000003oool0oooo0<<0oooo1P0000140?ooo`00403oool00`000000oooo0?ooo`390?oo
o`P00000?03oool00100oooo0P00003B0?ooo`P00000=03oool00100oooo00<000000?ooo`3oool0
f@3oool6000002h0oooo000@0?ooo`030000003oool0oooo0=l0oooo2000000V0?ooo`00403oool0
0`000000oooo0?ooo`3W0?ooo`/000006`3oool00100oooo0P00003c0?oooa0000002`3oool00100
oooo00<000000?ooo`3oool0o`3oool>0?ooo`00403oool00`000000oooo0?ooo`3o0?ooo`h0oooo
000@0?ooo`030000003oool0oooo0?l0oooo3P3oool00100oooo00<000000?ooo`3oool0o`3oool>
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-6.48536, -2.62904, \
0.385028, 0.211877}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[54]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[model3, x1, x2]; \)], "Input",
  CellLabel->"In[55]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Tricompartmental Systems", "SubsectionIcon"],

Cell["\<\
The analysis of model given above in the two variable cases can be \
inmediately generalizes to a system of with 3 or more compartments. In this \
section we show two models applied to represent drug administration process.  \
Other one is applied for people that intake lead in pollution enviromment. \
Finally it is presented the general tricompartmental model.          \
\>", "Text"],

Cell[CellGroupData[{

Cell["One input and first order abortion ", "SubsubsectionIcon"],

Cell[TextData[{
  "This figure show a tricompartmental model. In ",
  Cell[BoxData[
      \(TraditionalForm\`t\  = \ 0\)]],
  " is assumed that one amount ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  " is present in compartment 1 and 0 in the other compartments. A continuous \
liberation from a to 1 happen until that the initial amount ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  " is completelly removed from a.\n"
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0833333 0.119048 0.184524 0.119048 [
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.08333 .18452 .05952 0 365.73 arc
s
gsave
.08333 .18452 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.29167 .23214 -68.4375 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
73.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.14286 .18452 m
.44048 .18452 L
s
% Start of user PostScript
0.5 0 3. 0 MAarrowhead1
% End of user PostScript
newpath
.5 .18452 .05952 0 365.73 arc
s
gsave
.5 .18452 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .125 m
.5 .00595 L
s
% Start of user PostScript
3.5 -0.5 3.5 -1.5 MAarrowhead1
% End of user PostScript
gsave
.46429 .06548 -70.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.91667 .18452 .05952 0 365.73 arc
s
gsave
.91667 .18452 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 .20833 m
.85714 .20833 L
s
% Start of user PostScript
4. 0.2 6.5 0.2 MAarrowhead1
% End of user PostScript
gsave
.70833 .23214 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.85714 .16071 m
.55952 .16071 L
s
% Start of user PostScript
6.5 -0.2 4. -0.2 MAarrowhead1
% End of user PostScript
gsave
.70833 .1369 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  TextAlignment->Center,
  TextJustification->0,
  ImageSize->{288, 72},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000FQ000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00/goo00<007ooOol0/Woo002cOol00`00Oomoo`2bOol00;=oo`03001oogoo0;9o
o`00/Woo0`00/goo002bOol3002cOol00;9oo`<00;=oo`00/Woo0`00/goo002aOol5002bOol00;5o
o`D00;9oo`00/Goo1@00/Woo002aOol5002bOol00;1oo`L00;5oo`00/7oo1`00/Goo002`Ool7002a
Ool00;1oo`L00;5oo`00[goo2@00/7oo002_Ool9002`Ool00:moo`T00;1oo`00/goo00<007ooOol0
/Woo002cOol00`00Oomoo`2bOol00;=oo`03001oogoo0;9oo`00/goo00<007ooOol0/Woo002cOol0
0`00Oomoo`2bOol00;=oo`03001oogoo0;9oo`00/goo00<007ooOol0/Woo002TOol50002Ool00`00
Oomoo`05Ool00`00Oomoo`2bOol009ioo`80009oo`<00003Ool007oo009oo`03001oo`0000Ioo`03
001oogoo0;9oo`00Wgoo00@007ooOol000=oo`07001oogooOol007oo00001Woo00<007ooOol0/Woo
002OOol00`00Ool00004Ool01`00Oomoogoo001oo`0000Ioo`03001oogoo0;9oo`00Wgoo0`0017oo
00L007ooOomoo`00Ool00006Ool00`00Oomoo`2bOol009moo`04001oogoo0002Ool20004Ool00`00
Oomoo`05Ool00`00Oomoo`2bOol009moo`03001oo`0000<000ioo`03001oogoo0;9oo`00Wgoo00<0
07ooOol04Goo00<007ooOol0/Woo002NOol2000COol00`00Oomoo`2bOol00;=oo`03001oogoo0;9o
o`00/goo00<007ooOol0/Woo002cOol00`00Oomoo`2bOol00;=oo`03001oogoo0;9oo`00/goo00<0
07ooOol0/Woo002cOol00`00Oomoo`2bOol00;=oo`03001oogoo0;9oo`00/goo00<007ooOol0/Woo
000LOol7002=Ool80014Ool300000goo000000030010Ool7000LOol001Qoo`@000Moo`@008Eoo`@0
00Qoo`@0041oo`03001oogoo00=oo`03001oogoo03aoo`@000Moo`@001Qoo`005Woo0P003goo0P00
PGoo0P0047oo0P00=goo0P000Woo0`0000=oo`00Ool00goo00<007ooOol0>Woo0P003goo0P005Woo
000DOol2000COol2001mOol2000DOol2000fOol01000Oomoo`000goo00<007ooOol00Woo00<007oo
Ool0>7oo0P004goo0P0057oo000BOol2000GOol00`00Oomoo`1iOol00`00Oomoo`0EOol00`00Oomo
o`0dOol00`00Ool00003Ool00`00Ool00003Ool00`00Oomoo`0fOol2000GOol00`00Oomoo`0AOol0
015oo`03001oogoo01Qoo`03001oogoo07Ioo`8001Uoo`03001oogoo03=oo`<000Aoo`04001oogoo
Ool2000fOol2000JOol00`00Oomoo`0@Ool0011oo`03001oogoo01Yoo`03001oogoo07Aoo`03001o
ogoo01Yoo`03001oogoo039oo`04001oogoo000nOol00`00Oomoo`0KOol00`00Oomoo`0?Ool000mo
o`03001oogoo01aoo`03001oogoo079oo`03001oogoo01aoo`03001oogoo035oo`03001oo`0000<0
03aoo`03001oogoo01aoo`03001oogoo00ioo`003Woo00<007ooOol07Woo00<007ooOol0L7oo00<0
07ooOol07Woo00<007ooOol04goo0P006goo00<007ooOol0?Goo0P0087oo00<007ooOol03Goo000=
Ool00`00Oomoo`0POol00`00Oomoo`1^Ool00`00Oomoo`0POol2000?Ool6000JOol2000nOol00`00
Oomoo`0QOol00`00Oomoo`0<Ool000eoo`03001oogoo021oo`03001oogoo06ioo`03001oogoo025o
o`03001oogoo00Yoo`T005Yoo`03001oogoo025oo`03001oogoo00aoo`0037oo00<007ooOol08Woo
00<007ooOol0K7oo00<007ooOol08goo00<007ooOol01Goo3@00FGoo00<007ooOol08goo00<007oo
Ool02goo000<Ool00`00Oomoo`0ROol00`00Oomoo`1/Ool00`00Oomoo`0SOol01000Oomoogoo4@00
FGoo00<007ooOol08goo00<007ooOol02goo000;Ool00`00Oomoo`0TOol00`00Oomoo`1ZOol00`00
Oomoo`0UOom]000WOol00`00Oomoo`0:Ool000]oo`03001oogoo02Aoo`03001oogoo06Yoo`03001o
ogoo02Eoo`04001oogooOol@001HOol00`00Oomoo`0UOol00`00Oomoo`0:Ool000Yoo`03001oogoo
02Ioo`03001oogoo06Qoo`03001oogoo02Ioo`03001oogoo00Eoo``005Qoo`03001oogoo02Ioo`03
001oogoo00Uoo`002Woo00<007ooOol09Woo00<007ooOol0J7oo00<007ooOol09Woo00<007ooOol0
2Woo1`00F7oo00<007ooOol09Woo00<007ooOol02Goo000:Ool00`00Oomoo`0VOol00`00Oomoo`1F
Ool3000?Ool00`00Oomoo`0WOol00`00Oomoo`0=Ool3001GOol00`00Oomoo`0WOol00`00Oomoo`09
Ool000Yoo`03001oogoo02Ioo`03001oogoo05Ioo`L000]oo`03001oogoo02Moo`03001oogoo06Mo
o`03001oogoo02Moo`03001oogoo00Uoo`002Woo00<007ooOol047oo0`0000=oo`0000004Goo00<0
07ooOol0EGoo30001Woo00<007ooOol047oo1@004Woo00<007ooOol0Igoo00<007ooOol047oo1@00
4Woo00<007ooOol02Goo000:Ool00`00Oomoo`0?Ool01000Oomoogoo0P004Woo00<007ooOol0EGoo
40000Woo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol0Igoo00<007ooOol047oo00D007oo
Oomoo`00019oo`03001oogoo00Uoo`002Woo00<007ooOol03goo00<007ooOol00Woo00<007ooOol0
47ooJ`0057oo00<007ooOol04Woo00<007ooOol0Igoo00<007ooOol04Goo00<007ooOol057oo00<0
07ooOol027oo000:Ool00`00Oomoo`0@Ool5000BOol00`00Oomoo`1EOolA00000goo001oo`0COol0
0`00Oomoo`0BOol00`00Oomoo`1WOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`09Ool0
00Yoo`03001oogoo00moo`03001oogoo009oo`03001oogoo011oo`03001oogoo05Eoo`d000Eoo`03
001oogoo019oo`03001oogoo019oo`03001oogoo06Moo`03001oogoo01=oo`03001oogoo015oo`03
001oogoo00Uoo`002Woo00<007ooOol047oo10004Woo00<007ooOol0EWoo2P0027oo00<007ooOol0
4Woo00<007ooOol04Woo00<007ooOol0Igoo00<007ooOol057oo00<007ooOol047oo00<007ooOol0
2Goo000:Ool00`00Oomoo`0VOol00`00Oomoo`1FOol6000<Ool00`00Oomoo`0@Ool3000DOol00`00
Oomoo`1EOol2000@Ool00`00Oomoo`0@Ool01@00Oomoogoo00004Woo00<007ooOol02Goo000:Ool0
0`00Oomoo`0VOol00`00Oomoo`1FOol2000@Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomo
o`1FOol6000=Ool00`00Oomoo`0@Ool3000COol00`00Oomoo`09Ool000Yoo`03001oogoo02Ioo`03
001oogoo06Qoo`03001oogoo02Ioo`03001oogoo05Ioo`T000Yoo`03001oogoo02Ioo`03001oogoo
00Uoo`002goo00<007ooOol097oo00<007ooOol0JWoo00<007ooOol09Goo00<007ooOol0EWoo3@00
1Woo00<007ooOol09Goo00<007ooOol02Woo000;Ool00`00Oomoo`0TOol00`00Oomoo`1ZOol00`00
Oomoo`0UOol00`00Oomoo`1FOolA0002Ool00`00Oomoo`0UOol00`00Oomoo`0:Ool000aoo`03001o
ogoo029oo`03001oogoo06aoo`03001oogoo02=oo`03001oo`0006X00003Ool007oo02Aoo`03001o
ogoo00]oo`0037oo00<007ooOol08Woo00<007ooOol0K7oo00<007ooOol08goo00<007ooOol0Egoo
400017oo00<007ooOol08goo00<007ooOol02goo000=Ool00`00Oomoo`0POol00`00Oomoo`1^Ool0
0`00Oomoo`0QOol00`00Oomoo`1HOol<0009Ool00`00Oomoo`0QOol00`00Oomoo`0<Ool000eoo`03
001oogoo021oo`03001oogoo06ioo`03001oogoo025oo`03001oogoo05Qoo`L000ioo`03001oogoo
025oo`03001oogoo00aoo`003Woo00<007ooOol07Woo00<007ooOol0>Goo1000<goo00<007ooOol0
7goo00<007ooOol0=7oo1@0000Aoo`00000001aoo`<001=oo`03001oogoo01moo`03001oogoo00eo
o`003Woo00<007ooOol07Woo00<007ooOol0>Goo0`00=7oo00<007ooOol07Woo00<007ooOol0=goo
00D007ooOomoo`0003Eoo`03001oogoo01ioo`03001oogoo00eoo`003goo00<007ooOol06goo0P00
=7oo0P000Woo0`000goo00<007ooOol0<goo00<007ooOol077oo00<007ooOol0<7oo0P000Woo0`00
00=oo`00Ool00goo00<007ooOol0<goo00<007ooOol06goo0P0047oo000@Ool2000JOol00`00Oomo
o`0eOol01000Oomoo`0017oo0P00=Woo0P006goo00<007ooOol0<Woo00@007ooOol000=oo`03001o
ogoo009oo`03001oogoo03Aoo`03001oogoo01Uoo`03001oogoo011oo`004Woo00<007ooOol05goo
00<007ooOol0=Goo00<007oo0000?goo0P0067oo00<007ooOol0<goo00<007oo000017oo00L007oo
Oomoo`00Ool0000fOol2000IOol00`00Oomoo`0@Ool001=oo`03001oogoo01Aoo`8003Qoo`<0041o
o`03001oogoo01Aoo`8003Ioo`<000=oo`8000Aoo`03001oogoo03Moo`03001oogoo01Aoo`8001=o
o`0057oo00<007ooOol04Goo0P00>Woo00@007ooOol0041oo`03001oogoo019oo`03001oogoo03Io
o`04001oogoo0013Ool00`00Oomoo`0AOol2000EOol001Eoo`@000eoo`8003aoo`03001oo`0000<0
03moo`@000ioo`8003Uoo`03001oo`0000<0049oo`@000eoo`8001Moo`006Goo3@00?Woo00<007oo
Ool0AWoo3P00>goo00<007ooOol0BGoo3@006Goo001SOol2002@Ool2001aOol00?moofUoo`00\
\>"],
  ImageRangeCache->{{{90.625, 377.625}, {132.625, 61.625}} -> {-3.42488, \
0.272717, 0.0295777, 0.0295777}}],

Cell[TextData[{
  "The kinetics of amount",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[\(x\_i\),
              "TraditionalForm"], "(", "t", ")"}]}], TraditionalForm]]],
  " will be given by the differential equations"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(\(x\& . \)\_a\)]],
  "(t) = - ",
  Cell[BoxData[
      \(k\_a\)]],
  " ",
  Cell[BoxData[
      \(x\_a\)]],
  "(t)\n",
  Cell[BoxData[
      \(\(x\& . \)\_1\)]],
  "(t) = ",
  Cell[BoxData[
      \(k\_a\)]],
  " ",
  Cell[BoxData[
      \(x\_a\)]],
  "(t) - (",
  Cell[BoxData[
      \(k\_10\)]],
  "+ ",
  Cell[BoxData[
      \(k\_12\)]],
  ") ",
  Cell[BoxData[
      \(x\_1\)]],
  "(t)  + ",
  Cell[BoxData[
      \(k\_21\)]],
  " ",
  Cell[BoxData[
      \(x\_2\)]],
  "(t)  \n",
  Cell[BoxData[
      \(\(x\& . \)\_2\)]],
  "(t) = ",
  Cell[BoxData[
      \(k\_12\)]],
  " ",
  Cell[BoxData[
      \(x\_1\)]],
  "(t)  -  ",
  Cell[BoxData[
      \(k\_21\)]],
  " ",
  Cell[BoxData[
      \(x\_2\)]],
  "(t) \n"
}], "NumberedEquation"],

Cell[TextData[{
  "We will add the initial conditions: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(x\_a\)(0)\),
            "TraditionalForm"], " ", "=", " ", "d"}], TraditionalForm]]],
  " corresponds to an instantaneous \"release\"  ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ". In the rest of the compartments we suppose that the concentration is \
null in ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ", that is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(x\_1\)(0)\),
            "TraditionalForm"], " ", "=", " ", "0"}], TraditionalForm]]],
  "; ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(x\_2\)(0)\),
            "TraditionalForm"], " ", "=", " ", "0"}], TraditionalForm]]],
  ";  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(model1 = \ 
      CompartMatrix[
        3, {{3, 1, \ ka}, \ {1, 2, k12}, \ {2, 1, \ k21}, \ {1, 0, 
            k10}}]\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \({{\(-k10\) - k12, k21, ka}, {k12, \(-k21\), 0}, {0, 
        0, \(-ka\)}}\)], "Output",
  CellLabel->"Out[56]="]
}, Open  ]],

Cell["Thes equations are written as", "Text"],

Cell[BoxData[
    \(eq1 = ShowODE[model1, \ {d, 0, 0}, {0, 0, 0}, \ t, \ x]; \)], "Input",
  CellLabel->"In[57]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(eq1 // TableForm\) // TraditionalForm\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              RowBox[{
                RowBox[{
                  SuperscriptBox[\(x\_1\), "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], 
                "\[LongEqual]", \(\((\(-k10\) - k12)\)\ \(\(x\_1\)(t)\) + 
                  k21\ \(\(x\_2\)(t)\) + ka\ \(\(x\_3\)(t)\)\)}]},
            {
              RowBox[{
                RowBox[{
                  SuperscriptBox[\(x\_2\), "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], 
                "\[LongEqual]", \(k12\ \(\(x\_1\)(t)\) - 
                  k21\ \(\(x\_2\)(t)\)\)}]},
            {
              RowBox[{
                RowBox[{
                  SuperscriptBox[\(x\_3\), "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], 
                "\[LongEqual]", \(\(-ka\)\ \(\(x\_3\)(t)\)\)}]},
            {\(\(x\_1\)(0) \[LongEqual] d\)},
            {\(\(x\_2\)(0) \[LongEqual] 0\)},
            {\(\(x\_3\)(0) \[LongEqual] 0\)}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {
          Equal[ 
            Derivative[ 1][ 
              Subscript[ x, 1]][ t], 
            Plus[ 
              Times[ 
                Plus[ 
                  Times[ -1, k10], 
                  Times[ -1, k12]], 
                Subscript[ x, 1][ t]], 
              Times[ k21, 
                Subscript[ x, 2][ t]], 
              Times[ ka, 
                Subscript[ x, 3][ t]]]], 
          Equal[ 
            Derivative[ 1][ 
              Subscript[ x, 2]][ t], 
            Plus[ 
              Times[ k12, 
                Subscript[ x, 1][ t]], 
              Times[ -1, k21, 
                Subscript[ x, 2][ t]]]], 
          Equal[ 
            Derivative[ 1][ 
              Subscript[ x, 3]][ t], 
            Times[ -1, ka, 
              Subscript[ x, 3][ t]]], 
          Equal[ 
            Subscript[ x, 1][ 0], d], 
          Equal[ 
            Subscript[ x, 2][ 0], 0], 
          Equal[ 
            Subscript[ x, 3][ 0], 0]}]], TraditionalForm]], "Output",
  CellLabel->"Out[58]//TraditionalForm="]
}, Open  ]],

Cell["And here the solution is ", "Text"],

Cell[BoxData[
    \({{x1[t_], x2[t_], xa[t_]}} = {x\_1[t], x\_2[t], x\_3[t]} /. 
        DSolve[eq1, {x\_1[t], x\_2[t], x\_3[t]}, t]; \)], "Input",
  CellLabel->"In[59]:="],

Cell[TextData[{
  "The solution is valid for any value of transfer coefficients. We apply for \
 the following values ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(k\_a\),
            "TraditionalForm"], "=", "2"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(k\_12\),
            "TraditionalForm"], " ", "=", " ", "2"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(k\_21\),
            "TraditionalForm"], "=", "1"}], TraditionalForm]]],
  ",",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[\(k\_10\),
              "TraditionalForm"], " ", "=", " ", "0.5"}]}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`d\  = \ 100\)]]
}], "Text"],

Cell[TextData[{
  "Here is plot the concentration xa[t],  x1[t] and x2[t] for ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] t \[LessEqual] 50\)]]
}], "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[
      Evaluate[{xa[t], x1[t], x2[t]} /. {d \[Rule] \ 100, ka \[Rule] 2, 
            k10 \[Rule] 0.5, k12 \[Rule] 2, \ k21 \[Rule] 1}], \ {t, 0, 
        30}, \[IndentingNewLine]\ 
      PlotStyle \[Rule] {\[IndentingNewLine]{AbsoluteThickness[
              0.5]}, {AbsoluteThickness[1]}, {AbsoluteThickness[1.5], \ 
            AbsoluteDashing[{0.5, 1}]}}, \ 
      AxesLabel \[Rule] {"\<days\>", \ "\<r\>"}, 
      PlotLegend \[Rule] {"\<xa\>", "\<x1\>", "\<x2\>"}, 
      LegendPosition \[Rule] {0.2, \ \(-0.2\)}, \ 
      LegendSize \[Rule] {0.3, \ 0.3}]\)], "Input",
  CellLabel->"In[60]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0147151 0.00588606 [
[.18254 .00222 -3 -9 ]
[.18254 .00222 3 0 ]
[.34127 .00222 -6 -9 ]
[.34127 .00222 6 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.65873 .00222 -6 -9 ]
[.65873 .00222 6 0 ]
[.81746 .00222 -6 -9 ]
[.81746 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[1.025 .01472 0 -6.25 ]
[1.025 .01472 28 6.25 ]
[.01131 .13244 -12 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -12 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -12 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -12 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -18 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(10)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(15)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(20)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(25)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(30)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .13244 m
.03006 .13244 L
s
[(20)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(40)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(60)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(80)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(100)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03638 .01472 L
.03746 .01472 L
.03873 .01472 L
.03944 .01472 L
.04011 .01472 L
.04132 .01472 L
.04262 .01472 L
.04327 .01472 L
.04396 .01472 L
.04519 .01472 L
.04588 .01472 L
.04652 .01472 L
.04722 .01472 L
.04797 .01472 L
.04862 .01472 L
.04933 .01472 L
.05061 .01472 L
.05186 .01472 L
.05302 .01472 L
.05414 .01472 L
.05519 .01472 L
.05634 .01472 L
.05759 .01472 L
.05882 .01472 L
.06012 .01472 L
.06123 .01472 L
.06244 .01472 L
.06315 .01472 L
.06381 .01472 L
.06453 .01472 L
.06529 .01472 L
.06657 .01472 L
.06729 .01472 L
.06797 .01472 L
.06924 .01472 L
.0704 .01472 L
.07103 .01472 L
.07173 .01472 L
.073 .01472 L
Mistroke
.07376 .01472 L
.07448 .01472 L
.07513 .01472 L
.07583 .01472 L
.0766 .01472 L
.0774 .01472 L
.07809 .01472 L
.07885 .01472 L
.07956 .01472 L
.0802 .01472 L
.08095 .01472 L
.08166 .01472 L
.08291 .01472 L
.08362 .01472 L
.08427 .01472 L
.08544 .01472 L
.08669 .01472 L
.08787 .01472 L
.08896 .01472 L
.09016 .01472 L
.09148 .01472 L
.09214 .01472 L
.09285 .01472 L
.09413 .01472 L
.09483 .01472 L
.09548 .01472 L
.09619 .01472 L
.09695 .01472 L
.09821 .01472 L
.09893 .01472 L
.09961 .01472 L
.10086 .01472 L
.10201 .01472 L
.10333 .01472 L
.10458 .01472 L
.10572 .01472 L
.10694 .01472 L
.1081 .01472 L
.10916 .01472 L
.11033 .01472 L
.11162 .01472 L
.11227 .01472 L
.11297 .01472 L
.11422 .01472 L
.11491 .01472 L
.11554 .01472 L
.11624 .01472 L
.11698 .01472 L
.11822 .01472 L
.11892 .01472 L
Mistroke
.11958 .01472 L
.12081 .01472 L
.12194 .01472 L
.12323 .01472 L
.12446 .01472 L
.12562 .01472 L
.12668 .01472 L
.12789 .01472 L
.12903 .01472 L
.13009 .01472 L
.13107 .01472 L
.13214 .01472 L
.13327 .01472 L
.13441 .01472 L
.13564 .01472 L
.1368 .01472 L
.13785 .01472 L
.13909 .01472 L
.13979 .01472 L
.14043 .01472 L
.14162 .01472 L
.14288 .01472 L
.14402 .01472 L
.14526 .01472 L
.14656 .01472 L
.14777 .01472 L
.14891 .01472 L
.14994 .01472 L
.15113 .01472 L
.15226 .01472 L
.15348 .01472 L
.15478 .01472 L
.15589 .01472 L
.15711 .01472 L
.15842 .01472 L
.15915 .01472 L
.15982 .01472 L
.16113 .01472 L
.16236 .01472 L
.16352 .01472 L
.16456 .01472 L
.16577 .01472 L
.1669 .01472 L
.16796 .01472 L
.16893 .01472 L
.16999 .01472 L
.17111 .01472 L
.17225 .01472 L
.17347 .01472 L
.17462 .01472 L
Mistroke
.17566 .01472 L
.17689 .01472 L
.17758 .01472 L
.17823 .01472 L
.1794 .01472 L
.18065 .01472 L
.18185 .01472 L
.18316 .01472 L
.18441 .01472 L
.18556 .01472 L
.1867 .01472 L
.18773 .01472 L
.18893 .01472 L
.19005 .01472 L
.19128 .01472 L
.19258 .01472 L
.19369 .01472 L
.19491 .01472 L
.19623 .01472 L
.19696 .01472 L
.19763 .01472 L
.19894 .01472 L
.20017 .01472 L
.20122 .01472 L
.20238 .01472 L
.20359 .01472 L
.20472 .01472 L
.20578 .01472 L
.20675 .01472 L
.20781 .01472 L
.20894 .01472 L
.21008 .01472 L
.21129 .01472 L
.21244 .01472 L
.21349 .01472 L
.21472 .01472 L
.21541 .01472 L
.21605 .01472 L
.21723 .01472 L
.21847 .01472 L
.21968 .01472 L
.221 .01472 L
.22224 .01472 L
.2234 .01472 L
.22454 .01472 L
.22558 .01472 L
.22677 .01472 L
.2279 .01472 L
.22914 .01472 L
.23044 .01472 L
Mistroke
.23155 .01472 L
.23277 .01472 L
.23409 .01472 L
.23482 .01472 L
.2355 .01472 L
.2368 .01472 L
.23804 .01472 L
.23909 .01472 L
.24025 .01472 L
.24146 .01472 L
.2426 .01472 L
.24365 .01472 L
.24462 .01472 L
.24569 .01472 L
.24681 .01472 L
.24795 .01472 L
.24917 .01472 L
.25032 .01472 L
.25137 .01472 L
.2526 .01472 L
.25329 .01472 L
.25393 .01472 L
.2551 .01472 L
.25635 .01472 L
.25756 .01472 L
.25888 .01472 L
.26013 .01472 L
.26129 .01472 L
.26233 .01472 L
.26348 .01472 L
.26467 .01472 L
.2658 .01472 L
.26704 .01472 L
.26835 .01472 L
.26946 .01472 L
.27068 .01472 L
.272 .01472 L
.27274 .01472 L
.27341 .01472 L
.27472 .01472 L
.27595 .01472 L
.27701 .01472 L
.27817 .01472 L
.27938 .01472 L
.28052 .01472 L
.28158 .01472 L
.28255 .01472 L
.28367 .01472 L
.28474 .01472 L
.28588 .01472 L
Mistroke
.2871 .01472 L
.28825 .01472 L
.2893 .01472 L
.29053 .01472 L
.29122 .01472 L
.29186 .01472 L
.29303 .01472 L
.29427 .01472 L
.29549 .01472 L
.29618 .01472 L
.29682 .01472 L
.29799 .01472 L
.29923 .01472 L
.30034 .01472 L
.30138 .01472 L
.30252 .01472 L
.30375 .01472 L
.30499 .01472 L
.30569 .01472 L
.30634 .01472 L
.30765 .01472 L
.30839 .01472 L
.30906 .01472 L
.31026 .01472 L
.31156 .01472 L
.31278 .01472 L
.31392 .01472 L
.31497 .01472 L
.31611 .01472 L
.31718 .01472 L
.31816 .01472 L
.3193 .01472 L
.32055 .01472 L
.32173 .01472 L
.32282 .01472 L
.32406 .01472 L
.32522 .01472 L
.32626 .01472 L
.32739 .01472 L
.32862 .01472 L
.32992 .01472 L
.33103 .01472 L
.33225 .01472 L
.33356 .01472 L
.33477 .01472 L
.33541 .01472 L
.3361 .01472 L
.33683 .01472 L
.33751 .01472 L
.33876 .01472 L
Mistroke
.33991 .01472 L
.34123 .01472 L
.34249 .01472 L
.3436 .01472 L
.3448 .01472 L
.34592 .01472 L
.34694 .01472 L
.34814 .01472 L
.34945 .01472 L
.35067 .01472 L
.35181 .01472 L
.35302 .01472 L
.35431 .01472 L
.35554 .01472 L
.35665 .01472 L
.35796 .01472 L
.3587 .01472 L
.35939 .01472 L
.36064 .01472 L
.36128 .01472 L
.36198 .01472 L
.36266 .01472 L
.36337 .01472 L
.36465 .01472 L
.36536 .01472 L
.36602 .01472 L
.36675 .01472 L
.36753 .01472 L
.3682 .01472 L
.36893 .01472 L
.36962 .01472 L
.37026 .01472 L
.37146 .01472 L
.37274 .01472 L
.37394 .01472 L
.37526 .01472 L
.37651 .01472 L
.37766 .01472 L
.3788 .01472 L
.37984 .01472 L
.38103 .01472 L
.38216 .01472 L
.38339 .01472 L
.3847 .01472 L
.38581 .01472 L
.38703 .01472 L
.38834 .01472 L
.38908 .01472 L
.38975 .01472 L
.39106 .01472 L
Mistroke
.39229 .01472 L
.39334 .01472 L
.3945 .01472 L
.39571 .01472 L
.39685 .01472 L
.39791 .01472 L
.39888 .01472 L
.39994 .01472 L
.40106 .01472 L
.40221 .01472 L
.40342 .01472 L
.40457 .01472 L
.40562 .01472 L
.40685 .01472 L
.40754 .01472 L
.40818 .01472 L
.40936 .01472 L
.4106 .01472 L
.41181 .01472 L
.41313 .01472 L
.41438 .01472 L
.41554 .01472 L
.41669 .01472 L
.41772 .01472 L
.41892 .01472 L
.42005 .01472 L
.42129 .01472 L
.42259 .01472 L
.42371 .01472 L
.42493 .01472 L
.42624 .01472 L
.42698 .01472 L
.42765 .01472 L
.42896 .01472 L
.43019 .01472 L
.43125 .01472 L
.43241 .01472 L
.43362 .01472 L
.43476 .01472 L
.43582 .01472 L
.43679 .01472 L
.43791 .01472 L
.43898 .01472 L
.44012 .01472 L
.44134 .01472 L
.44249 .01472 L
.44354 .01472 L
.44477 .01472 L
.44546 .01472 L
.4461 .01472 L
Mistroke
.44727 .01472 L
.44851 .01472 L
.44973 .01472 L
.45042 .01472 L
.45106 .01472 L
.45223 .01472 L
.45347 .01472 L
.45458 .01472 L
.45562 .01472 L
.45676 .01472 L
.45799 .01472 L
.45922 .01472 L
.45992 .01472 L
.46057 .01472 L
.46188 .01472 L
.46262 .01472 L
.46329 .01472 L
.46449 .01472 L
.46579 .01472 L
.46702 .01472 L
.46815 .01472 L
.4692 .01472 L
.47034 .01472 L
.47141 .01472 L
.47239 .01472 L
.47353 .01472 L
.47478 .01472 L
.47596 .01472 L
.47705 .01472 L
.47829 .01472 L
.47945 .01472 L
.48049 .01472 L
.48162 .01472 L
.48285 .01472 L
.48415 .01472 L
.48526 .01472 L
.48648 .01472 L
.48779 .01472 L
.489 .01472 L
.48963 .01472 L
.49033 .01472 L
.49105 .01472 L
.49174 .01472 L
.49299 .01472 L
.49413 .01472 L
.49539 .01472 L
.49671 .01472 L
.49783 .01472 L
.49902 .01472 L
.50014 .01472 L
Mistroke
.50116 .01472 L
.50236 .01472 L
.50366 .01472 L
.50489 .01472 L
.50603 .01472 L
.50723 .01472 L
.50853 .01472 L
.50975 .01472 L
.51087 .01472 L
.51218 .01472 L
.51292 .01472 L
.51361 .01472 L
.51486 .01472 L
.5155 .01472 L
.5162 .01472 L
.51687 .01472 L
.51759 .01472 L
.51886 .01472 L
.51958 .01472 L
.52024 .01472 L
.52096 .01472 L
.52174 .01472 L
.52241 .01472 L
.52314 .01472 L
.52383 .01472 L
.52447 .01472 L
.52568 .01472 L
.52695 .01472 L
.52816 .01472 L
.52947 .01472 L
.53072 .01472 L
.53187 .01472 L
.53301 .01472 L
.53405 .01472 L
.53525 .01472 L
.53637 .01472 L
.5376 .01472 L
.53891 .01472 L
.54002 .01472 L
.54124 .01472 L
.54255 .01472 L
.54329 .01472 L
.54396 .01472 L
.54526 .01472 L
.5465 .01472 L
.54755 .01472 L
.54871 .01472 L
.54992 .01472 L
.55105 .01472 L
.55211 .01472 L
Mistroke
.55308 .01472 L
.55415 .01472 L
.55527 .01472 L
.55641 .01472 L
.55763 .01472 L
.55878 .01472 L
.55982 .01472 L
.56105 .01472 L
.56175 .01472 L
.56238 .01472 L
.56356 .01472 L
.5648 .01472 L
.56601 .01472 L
.56734 .01472 L
.56858 .01472 L
.56974 .01472 L
.57088 .01472 L
.57192 .01472 L
.57312 .01472 L
.57425 .01472 L
.57548 .01472 L
.57679 .01472 L
.5779 .01472 L
.57912 .01472 L
.58044 .01472 L
.58118 .01472 L
.58185 .01472 L
.58315 .01472 L
.58439 .01472 L
.58544 .01472 L
.5866 .01472 L
.58782 .01472 L
.58895 .01472 L
.59001 .01472 L
.59098 .01472 L
.5921 .01472 L
.59317 .01472 L
.59431 .01472 L
.59553 .01472 L
.59668 .01472 L
.59773 .01472 L
.59896 .01472 L
.59965 .01472 L
.60029 .01472 L
.60146 .01472 L
.60271 .01472 L
.60392 .01472 L
.60461 .01472 L
.60525 .01472 L
.60642 .01472 L
Mistroke
.60766 .01472 L
.60876 .01472 L
.6098 .01472 L
.61094 .01472 L
.61217 .01472 L
.61341 .01472 L
.6141 .01472 L
.61475 .01472 L
.61607 .01472 L
.6168 .01472 L
.61747 .01472 L
.61867 .01472 L
.61997 .01472 L
.6212 .01472 L
.62233 .01472 L
.62339 .01472 L
.62452 .01472 L
.62559 .01472 L
.62657 .01472 L
.62771 .01472 L
.62896 .01472 L
.63014 .01472 L
.63123 .01472 L
.63247 .01472 L
.63363 .01472 L
.63467 .01472 L
.6358 .01472 L
.63703 .01472 L
.63833 .01472 L
.63944 .01472 L
.64066 .01472 L
.64197 .01472 L
.64318 .01472 L
.64381 .01472 L
.6445 .01472 L
.64523 .01472 L
.64591 .01472 L
.64716 .01472 L
.64831 .01472 L
.64956 .01472 L
.65088 .01472 L
.652 .01472 L
.65319 .01472 L
.65431 .01472 L
.65533 .01472 L
.65653 .01472 L
.65784 .01472 L
.65906 .01472 L
.6602 .01472 L
.6614 .01472 L
Mistroke
.6627 .01472 L
.66392 .01472 L
.66504 .01472 L
.66635 .01472 L
.66709 .01472 L
.66777 .01472 L
.66903 .01472 L
.66966 .01472 L
.67036 .01472 L
.67104 .01472 L
.67175 .01472 L
.67303 .01472 L
.67374 .01472 L
.6744 .01472 L
.67513 .01472 L
.67591 .01472 L
.67658 .01472 L
.67731 .01472 L
.678 .01472 L
.67864 .01472 L
.67984 .01472 L
.68112 .01472 L
.68232 .01472 L
.68364 .01472 L
.68488 .01472 L
.68603 .01472 L
.68718 .01472 L
.68821 .01472 L
.68941 .01472 L
.69053 .01472 L
.69176 .01472 L
.69307 .01472 L
.69418 .01472 L
.6954 .01472 L
.69671 .01472 L
.69745 .01472 L
.69812 .01472 L
.69942 .01472 L
.70066 .01472 L
.70171 .01472 L
.70286 .01472 L
.70407 .01472 L
.70521 .01472 L
.70627 .01472 L
.70724 .01472 L
.7083 .01472 L
.70942 .01472 L
.71056 .01472 L
.71178 .01472 L
.71293 .01472 L
Mistroke
.71398 .01472 L
.71521 .01472 L
.7159 .01472 L
.71654 .01472 L
.71771 .01472 L
.71896 .01472 L
.72017 .01472 L
.72149 .01472 L
.72273 .01472 L
.72389 .01472 L
.72503 .01472 L
.72607 .01472 L
.72727 .01472 L
.7284 .01472 L
.72963 .01472 L
.73094 .01472 L
.73205 .01472 L
.73327 .01472 L
.73458 .01472 L
.73532 .01472 L
.73599 .01472 L
.7373 .01472 L
.73853 .01472 L
.73959 .01472 L
.74075 .01472 L
.74196 .01472 L
.7431 .01472 L
.74416 .01472 L
.74513 .01472 L
.74619 .01472 L
.74731 .01472 L
.74846 .01472 L
.74967 .01472 L
.75083 .01472 L
.75187 .01472 L
.7531 .01472 L
.75379 .01472 L
.75443 .01472 L
.75561 .01472 L
.75685 .01472 L
.75806 .01472 L
.75875 .01472 L
.75939 .01472 L
.76056 .01472 L
.7618 .01472 L
.7629 .01472 L
.76394 .01472 L
.76508 .01472 L
.76631 .01472 L
.76754 .01472 L
Mistroke
.76824 .01472 L
.76889 .01472 L
.7702 .01472 L
.77094 .01472 L
.77161 .01472 L
.7728 .01472 L
.7741 .01472 L
.77533 .01472 L
.77646 .01472 L
.77752 .01472 L
.77865 .01472 L
.77972 .01472 L
.7807 .01472 L
.78184 .01472 L
.78309 .01472 L
.78427 .01472 L
.78536 .01472 L
.7866 .01472 L
.78776 .01472 L
.7888 .01472 L
.78993 .01472 L
.79116 .01472 L
.79246 .01472 L
.79357 .01472 L
.79479 .01472 L
.7961 .01472 L
.7973 .01472 L
.79793 .01472 L
.79863 .01472 L
.79936 .01472 L
.80004 .01472 L
.80129 .01472 L
.80243 .01472 L
.80369 .01472 L
.80501 .01472 L
.80612 .01472 L
.80731 .01472 L
.80843 .01472 L
.80945 .01472 L
.81066 .01472 L
.81196 .01472 L
.81318 .01472 L
.81432 .01472 L
.81552 .01472 L
.81682 .01472 L
.81804 .01472 L
.81916 .01472 L
.82047 .01472 L
.8212 .01472 L
.82189 .01472 L
Mistroke
.82315 .01472 L
.82385 .01472 L
.82448 .01472 L
.82516 .01472 L
.82587 .01472 L
.82715 .01472 L
.82786 .01472 L
.82852 .01472 L
.82925 .01472 L
.83002 .01472 L
.8307 .01472 L
.83143 .01472 L
.83212 .01472 L
.83275 .01472 L
.83396 .01472 L
.83524 .01472 L
.83644 .01472 L
.83775 .01472 L
.839 .01472 L
.84015 .01472 L
.84129 .01472 L
.84232 .01472 L
.84352 .01472 L
.84464 .01472 L
.84587 .01472 L
.84718 .01472 L
.84829 .01472 L
.8495 .01472 L
.85082 .01472 L
.85155 .01472 L
.85222 .01472 L
.85353 .01472 L
.85476 .01472 L
.85581 .01472 L
.85697 .01472 L
.85818 .01472 L
.85932 .01472 L
.86037 .01472 L
.86134 .01472 L
.86241 .01472 L
.86353 .01472 L
.86467 .01472 L
.86589 .01472 L
.86704 .01472 L
.86808 .01472 L
.86931 .01472 L
.87 .01472 L
.87064 .01472 L
.87182 .01472 L
.87306 .01472 L
Mistroke
.87427 .01472 L
.87559 .01472 L
.87684 .01472 L
.87799 .01472 L
.87914 .01472 L
.88017 .01472 L
.88137 .01472 L
.88249 .01472 L
.88373 .01472 L
.88503 .01472 L
.88615 .01472 L
.88737 .01472 L
.88868 .01472 L
.88942 .01472 L
.89009 .01472 L
.89139 .01472 L
.89263 .01472 L
.89368 .01472 L
.89484 .01472 L
.89605 .01472 L
.89719 .01472 L
.89825 .01472 L
.89922 .01472 L
.90029 .01472 L
.90141 .01472 L
.90255 .01472 L
.90377 .01472 L
.90492 .01472 L
.90596 .01472 L
.90719 .01472 L
.90789 .01472 L
.90852 .01472 L
.9097 .01472 L
.91094 .01472 L
.91216 .01472 L
.91284 .01472 L
.91348 .01472 L
.91464 .01472 L
.91589 .01472 L
.91699 .01472 L
.91803 .01472 L
.91917 .01472 L
.9204 .01472 L
.92163 .01472 L
.92233 .01472 L
.92297 .01472 L
.92429 .01472 L
.92502 .01472 L
.92569 .01472 L
.92689 .01472 L
Mistroke
.92819 .01472 L
.92941 .01472 L
.93055 .01472 L
.9316 .01472 L
.93273 .01472 L
.9338 .01472 L
.93478 .01472 L
.93592 .01472 L
.93717 .01472 L
.93835 .01472 L
.93944 .01472 L
.94068 .01472 L
.94184 .01472 L
.94288 .01472 L
.94401 .01472 L
.94524 .01472 L
.94654 .01472 L
.94765 .01472 L
.94887 .01472 L
.94975 .01472 L
.95057 .01472 L
.95146 .01472 L
.95241 .01472 L
.95324 .01472 L
.95401 .01472 L
.95486 .01472 L
.95577 .01472 L
.95653 .01472 L
.95737 .01472 L
.95824 .01472 L
.95905 .01472 L
.95981 .01472 L
.9605 .01472 L
.9613 .01472 L
.96206 .01472 L
.96287 .01472 L
.96377 .01472 L
.96471 .01472 L
.96559 .01472 L
.96641 .01472 L
.96716 .01472 L
.96802 .01472 L
.96884 .01472 L
.96972 .01472 L
.97067 .01472 L
.97155 .01472 L
.97236 .01472 L
.97331 .01472 L
.97433 .01472 L
.9753 .01472 L
Mistroke
.97619 .01472 L
Mfstroke
1 Mabswid
.02381 .60332 m
.02605 .51049 L
.02846 .43239 L
.03053 .37884 L
.03279 .33225 L
.03543 .28955 L
.03793 .25841 L
.04262 .21726 L
.045 .20247 L
.04762 .18957 L
.05018 .17963 L
.05293 .17112 L
.05784 .15991 L
.06244 .15248 L
.06784 .14603 L
.07373 .14065 L
.08445 .13306 L
.10458 .1218 L
.14523 .10311 L
.18435 .08826 L
.22594 .0752 L
.266 .06482 L
.30455 .05652 L
.34556 .04919 L
.38505 .04335 L
.42302 .03867 L
.46344 .03452 L
.50235 .03121 L
.54371 .0283 L
.58356 .02598 L
.62189 .02412 L
.66267 .02248 L
.70193 .02117 L
.73968 .02012 L
.77989 .01919 L
.81858 .01845 L
.85972 .01779 L
.89934 .01727 L
.93745 .01685 L
.97619 .01649 L
s
1.5 Mabswid
[ .5 1 ] 0 Mabsdash
.02381 .01472 m
.02605 .08844 L
.02846 .14932 L
.03072 .19341 L
.03279 .22465 L
.03521 .25284 L
.03784 .27532 L
.04032 .29061 L
.04262 .3008 L
.04376 .30472 L
.04498 .30823 L
.0472 .31299 L
.04855 .31504 L
.04983 .3165 L
.05098 .31744 L
.05224 .31813 L
.05293 .31837 L
.05358 .31852 L
.0548 .31861 L
.05611 .31846 L
.05685 .31828 L
.05753 .31805 L
.05867 .31756 L
.05992 .31688 L
.06244 .31512 L
.06795 .31004 L
.07296 .30451 L
.08424 .29087 L
.10458 .26618 L
.14443 .22329 L
.18275 .18891 L
.22354 .15852 L
.2628 .13428 L
.30055 .11484 L
.34076 .0976 L
.37944 .08382 L
.42058 .07167 L
.46021 .06199 L
.49832 .05424 L
.53888 .04738 L
.57792 .0419 L
.61942 .03708 L
.6594 .03325 L
.69787 .03019 L
.73879 .02748 L
.77819 .02532 L
.81608 .02359 L
.85642 .02206 L
.89524 .02083 L
.93652 .01975 L
Mistroke
.97619 .0189 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.61905 .18997 m
.61905 .33283 L
.7619 .33283 L
.7619 .18997 L
F
1 g
.59524 .21378 m
.59524 .35664 L
.7381 .35664 L
.7381 .21378 L
F
0 g
.001 w
[ ] 0 setdash
.59524 .21378 m
.7381 .21378 L
.7381 .35664 L
.59524 .35664 L
.59524 .21378 L
s
% Start of sub-graphic
p
0.595238 0.213779 0.738095 0.356636 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0271739 0.271739 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.048913 0.35119 0.320652 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
1.5 Mabswid
[ .5 1 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .18478 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x2) show
75.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.36413 0.35119 0.63587 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
1 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .5 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x1) show
75.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.679348 0.35119 0.951087 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .81522 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(xa) show
75.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[60]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00?P3oool2000001d0oooo1@0000020?ooo`8000006`3oool500000080
oooo0P00000J0?ooo`@000000`3oool2000001/0oooo100000030?ooo`8000006`3oool2000000@0
oooo0P00000/0?ooo`00?@3oool010000000oooo0?ooo`00000N0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0J0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000006P3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000001T0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`00000[0?ooo`00@03oool00`000000oooo0?ooo`0L0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000001/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0Y0?ooo`00?P3oool2000001l0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3o
ool2000001`0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool00P3oool2000001d0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0Y0?ooo`00?P3oool00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool06@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000001X0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0I0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000:`3oool003h0oooo0`00000M0?ooo`800000103oool2000001`0oooo
0P0000040?ooo`<000006P3oool2000000@0oooo0P00000L0?ooo`800000103oool3000001X0oooo
0P0000040?ooo`800000;03oool00?l0oooo8@3oool001/0oooo00<000000?ooo`3oool0k03oool2
000001@0oooo000K0?ooo`030000003oool0oooo0>d0oooo00<000000?ooo`3oool04P3oool001/0
oooo00<000000?ooo`3oool0h@3oool4000000030?ooo`000000000000<000000`3oool010000000
oooo0?ooo`3oool3000000d0oooo000F0?ooon4000001`3oool010000000oooo0?ooo`0000020?oo
o`@000000`3oool00`000000oooo000000050?ooo`030000003oool0oooo00X0oooo000K0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000_000000d0
oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00<000003@3oool001/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool07@3ooolK000000`0oooo8@0000020?oo
o`030000003oool0oooo00`0oooo0`0000030?ooo`<0000000D0oooo00000000000000000?ooo`02
000000030?ooo`000000000000800000303oool001/0oooo00<000000?ooo`3oool0KP3ooolJ0000
01<0oooo5000000d0?ooo`030000003oool0oooo01`0oooo000K0?ooo`030000003oool0oooo06D0
oooo2@00000O0?ooo`h00000A`3oool2000001h0oooo000K0?ooo`800000G@3oool9000001d0oooo
3000001d0?ooo`006`3oool2000005@0oooo2@00000O0?ooo`P00000O`3oool001/0oooo0P00001;
0?ooo`T00000803oool8000008L0oooo000K0?ooo`800000A03oool7000002<0oooo1P00002?0?oo
o`006`3oool200000400oooo1000000T0?ooo`H00000U@3oool001/0oooo0P00000l0?ooo`@00000
803oool00`000000oooo0?ooo`05000009/0oooo000K0?ooo`800000>03oool4000002<0oooo1@00
002O0?ooo`006`3oool2000003<0oooo1@00000R0?ooo`D00000Y03oool001/0oooo0P00000_0?oo
o`@00000903oool400000:P0oooo000K0?ooo`800000:`3oool4000002@0oooo1000002/0?ooo`00
6`3oool2000002P0oooo0`00000U0?ooo`@00000[`3oool001/0oooo0P00000T0?ooo`@000009@3o
ool300000;<0oooo000K0?ooo`8000008@3oool3000002H0oooo0`00002f0?ooo`006`3oool20000
01l0oooo0P00000V0?ooo`<00000^@3oool001/0oooo0P00000L0?ooo`<000009@3oool300000;`0
oooo000K0?ooo`8000006@3oool3000002H0oooo0P00002o0?ooo`006`3oool2000001L0oooo0P00
000W0?ooo`<00000`03oool001/0oooo0P00000D0?ooo`<000009P3oool300000<<0oooo000K0?oo
o`8000004P3oool2000002L0oooo0`0000350?ooo`006`3oool200000100oooo0P00000W0?ooo`<0
0000a`3oool000h0oooo100000030?ooo`800000103oool2000000l0oooo00<000000?ooo`3oool0
9P3oool200000<T0oooo000>0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0`3oool2000000d0oooo0P00000V0?ooo`<00000b`3oool000l0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000030?ooo`<000002`3oool00`000000oooo0?ooo`0U0?ooo`800000
c@3oool00100oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0?ooo`80
00002`3oool00`000000oooo0?ooo`0T0?ooo`800000c`3oool000h0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000030?ooo`8000002P3oool00`000000oooo0?ooo`0S0?oo
o`800000d@3oool000l0oooo0P0000040?ooo`800000103oool2000000P0oooo0P00000U0?ooo`03
0000003oool0oooo0=40oooo000K0?ooo`8000001`3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo0=80oooo000K0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool08`3o
ool200000=D0oooo000K0?ooo`<000001@3oool00`000000oooo0?ooo`0Q0?ooo`800000e`3oool0
01/0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
0=L0oooo000K0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`3H0?ooo`006`3oool00`000000oooo000000030?ooo`030000003oool0oooo01l0oooo
0P00003K0?ooo`006`3oool00`000000oooo000000030?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0f`3oool001/0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo06d0oooo:@0000160?ooo`006`3oool00`000000oooo000000030?oo
o`030000003oool0oooo01/0oooo0P00001`0?ooobT00000AP3oool001/0oooo0`0000030?ooo`03
0000003oool0oooo01X0oooo0P00001a0?ooobT00000AP3oool001/0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0740oooo:@0000160?ooo`006`3o
ool00`000000oooo000000020?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0LP3o
oolY000004H0oooo000K0?ooo`030000003oool000000080oooo00<000000?ooo`3oool05`3oool2
000007D0oooo:@0000160?ooo`006`3oool00`000000oooo000000020?ooo`030000003oool0oooo
01H0oooo0P00001_0?oooc000000AP3oool001/0oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`0E0?ooo`800000L03oool00`000000oooo0?ooo`0V0?ooo`L00000AP3oool001/0oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0D0?ooo`800000L@3oool00`000000oooo
0?ooo`0V0?ooo`L00000AP3oool001/0oooo0`0000020?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0L03oool00`000000oooo0?ooo`0V0?ooo`L00000AP3oool001/0oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0740oooo00<00000
0?ooo`3oool09P3oool7000004H0oooo000K0?ooo`060000003oool000000000003oool00000503o
ool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo02H0oooo1`0000160?ooo`006`3oool0
1P000000oooo0?ooo`000000oooo000001<0oooo00<000000?ooo`3oool0L`3oool00`000000oooo
0?ooo`0?0?ooo`80000000<0oooo0000000000000P3oool4000000`0oooo1`0000160?ooo`00403o
ool300000080oooo0P0000040?ooo`030000003oool0oooo008000004`3oool00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo00`00000103oool00`000000oooo000000030?ooo`030000003o
ool0oooo00d0oooo1`0000160?ooo`004@3oool010000000oooo0?ooo`0000020?ooo`050000003o
ool0oooo0?ooo`0000000P3oool200000180oooo00<000000?ooo`3oool0M@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool7000004H0oooo
000>0?ooo`D0000000D0oooo0000003oool0oooo000000030?ooo`D000004@3oool00`000000oooo
0?ooo`1f0?ooo`030000003oool0oooo00l0oooo0P0000000`3oool00000000000040?ooo`030000
003oool0oooo00/0oooo1`0000160?ooo`003P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool00P00000@0?ooo`030000003oool0oooo07L0
oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`00000<0?ooo`L00000AP3oool000l0
oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
008000003`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo01L0oooo0P00000=0?oo
o`L00000AP3oool00100oooo0P0000030?ooo`800000103oool00`000000oooo0?ooo`02000000h0
oooo0P00001j0?ooo`030000003oool0oooo02H0oooo1`0000160?ooo`006`3oool00`000000oooo
0?ooo`02000000d0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0V0?ooo`L00000
AP3oool001/0oooo00<000000?ooo`3oool00P00000=0?ooo`030000003oool0oooo07X0oooo00<0
00000?ooo`3oool09P3oool7000004H0oooo000K0?ooo`030000003oool0oooo00800000303oool0
0`000000oooo0?ooo`1k0?ooo`030000003oool0oooo02H0oooo1`0000160?ooo`006`3oool20000
00030?ooo`000000000000/0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0V0?oo
o`L00000AP3oool001/0oooo00<000000?ooo`3oool00P00000:0?ooo`030000003oool0oooo07d0
oooo00<000000?ooo`3oool09P3oool7000004H0oooo000K0?ooo`030000003oool0oooo00800000
2@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02H0oooo1`0000160?ooo`006`3o
ool00`000000oooo0?ooo`02000000P0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?oo
o`0?0?ooo`80000000<0oooo0000000000000P3oool5000000/0oooo1`0000160?ooo`006`3oool0
0`000000oooo0?ooo`03000000H0oooo0P0000210?ooo`030000003oool0oooo00`00000103oool0
0`000000oooo000000050?ooo`030000003oool0oooo00/0oooo1`0000160?ooo`006`3oool01P00
0000oooo0?ooo`000000oooo000000H0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool7000004H0oooo000K
0?ooo`80000000@0oooo0000003oool000001@3oool00`000000oooo0?ooo`210?ooo`030000003o
ool0oooo00l0oooo0P0000000`3oool00000000000040?ooo`030000003oool0oooo00/0oooo1`00
00160?ooo`006`3oool00`000000oooo000000020?ooo`040000003oool0oooo0?ooo`800000Q03o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00/0oooo1`0000160?ooo`006`3oool0
0`000000oooo000000030?ooo`@00000Q@3oool00`000000oooo0?ooo`0G0?ooo`8000003@3oool7
000004H0oooo000K0?ooo`030000003oool0000008`0oooo00<000000?ooo`3oool09P3oool70000
04H0oooo000K0?ooo`030000003oool0000008`0oooo00<000000?ooo`3oool09P3oool7000004H0
oooo000K0?ooo`030000003oool0000008`0oooo00<000000?ooo`3oool09P3oool7000004H0oooo
000K0?ooo`030000003oool0000008`0oooo00<000000?ooo`3oool09P3oool7000004H0oooo000K
0?ooo`<00000S03oool00`000000oooo0?ooo`0V0?ooo`L00000AP3oool001/0oooo00<000000?oo
o`000000S03oool00`000000oooo0?ooo`0V0?ooo`L00000AP3oool001/0oooo00<000000?ooo`00
0000S03oool00`000000oooo0?ooo`0V0?ooo`L00000AP3oool001/0oooo00<000000?ooo`000000
S03oool00`000000oooo0?ooo`0?0?ooo`80000000<0oooo0000000000000P3oool5000000/0oooo
1`0000160?ooo`003P3oool3000000@0oooo0P0000040?ooo`030000003oool0000008`0oooo00<0
00000?ooo`3oool0300000040?ooo`030000003oool0000000<0oooo1000000<0?ooo`L00000AP3o
ool000h0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0000008`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00X0oooo1`0000160?ooo`003P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000<0oooo0`00002<0?ooo`030000003oool0oooo00l0oooo0P0000000`3oool0
0000000000030?ooo`<00000303oool00`000000oooo0?ooo`1:0?ooo`003P3oool3000000<0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0000002<0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0BP3oool000l0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0000008`0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`1:0?ooo`003`3oool3000000<0oooo0P0000040?ooo`030000003oool0000008`0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1:0?ooo`006`3oool00`000000oooo0000
002<0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0BP3oool001/0oooo00<00000
0?ooo`000000S03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo04X0oooo000K0?oo
o`030000003oool0000008`0oooo:P00001<0?ooo`006`3oool300000?l0oooo0`3oool001/0oooo
00<000000?ooo`000000o`3oool30?ooo`006`3oool200000?l0oooo103oool001/0oooo0P00003o
0?ooo`@0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool200000?l0oooo103oool001/0oooo
0P00003o0?ooo`@0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool200000?l0oooo103oool0
01/0oooo0P00003o0?ooo`@0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool200000?l0oooo
103oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool20000
0?l0oooo103oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`800000o`3oool40?ooo`006`3o
ool200000?l0oooo103oool000l0oooo0P0000040?ooo`800000103oool200000?l0oooo103oool0
00h0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000o`3o
ool40?ooo`003P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo
0`00003o0?ooo`<0oooo000?0?ooo`8000000`3oool010000000oooo0?ooo`0000030?ooo`800000
o`3oool40?ooo`003P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0
oooo0P00003o0?ooo`@0oooo000?0?ooo`800000103oool2000000@0oooo0P00003o0?ooo`@0oooo
000K0?ooo`800000o`3oool40?ooo`006`3oool200000?l0oooo103oool001/0oooo0P00003o0?oo
o`@0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool200000?l0oooo103oool001/0oooo0P00
003o0?ooo`@0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool200000?l0oooo103oool001/0
oooo0P00003o0?ooo`@0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool200000?l0oooo103o
ool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0
oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo
000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00080?ooo`D000000P3oool2000000@0oooo0P00
00040?ooo`030000003oool0oooo0?l0oooo0`3oool000X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo0000003o0?ooo`D0
oooo000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo0?ooo`<00000o`3oool30?ooo`002P3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool000000?l0oooo
1@3oool000X0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00D000000?ooo`3oool0oooo0000003o0?ooo`D0oooo00090?ooo`800000103oool2000000@0
oooo0P0000040?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool001T0oooo1000003o0?ooo`@0oooo
000J0?ooo`030000003oool0oooo0?l0oooo103oool001X0oooo00<000000?ooo`3oool0o`3oool4
0?ooo`006@3oool400000?l0oooo103oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.05261, -0.648943, \
0.00733523, 0.00733523}, {{7.125, 279.813}, {172.688, 4.1875}} -> {-3.93304, \
-13.5946, 0.140862, 0.759726}, {{170.75, 211.625}, {115.688, 74.8125}} -> \
{-14.1361, -5.61445, 0.0822027, 0.0900315}, {{172.938, 185.063}, {113.688, \
102.563}} -> {-15.0012, -19.284, 0.0865988, 0.28024}, {{172.938, 185.063}, \
{100.75, 89.6875}} -> {-15.0012, -22.9008, 0.0865988, 0.28024}, {{172.938, \
185.063}, {87.875, 76.8125}} -> {-15.0012, -26.5089, 0.0865988, 0.28024}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[60]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[xa, x1, x2, model1, eq1\ ]; \)], "Input",
  CellLabel->"In[61]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Order-zero input and first-order abortion ", "SubsubsectionIcon"],

Cell[TextData[{
  "Other usual model in drug administration consist in a order-cero input to \
a constant rate and an absorption through a first order process. This process \
can be represented by a tricompartmental system as above section with we add \
and input  ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_a\)(t)\)]],
  "  to the compartment as it show in the figure 8"
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .375 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0833333 0.119048 0.1875 0.119048 [
[ 0 0 0 0 ]
[ 1 .375 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .375 L
0 .375 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125  moveto 0 0 lineto 
-0.05 -0.0125  lineto stroke
} ifelse
grestore
} def
/MAarrowhead2 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.08333 .36607 m
.08333 .24702 L
s
% Start of user PostScript
0 1.5 0 0.5 MAarrowhead1
% End of user PostScript
gsave
.04762 .30655 -68.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
73.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.14286 .30655 -77.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.875 12.750 moveto
(H) show
79.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
85.875 12.750 moveto
(L) show
91.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.08333 .1875 .05952 0 365.73 arc
s
gsave
.08333 .1875 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.29167 .22321 -68.4375 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
73.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.14286 .1875 m
.44048 .1875 L
s
% Start of user PostScript
0.5 0 3. 0 MAarrowhead2
% End of user PostScript
newpath
.5 .1875 .05952 0 365.73 arc
s
gsave
.5 .1875 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12798 m
.5 .00893 L
s
% Start of user PostScript
3.5 -0.5 3.5 -1.5 MAarrowhead2
% End of user PostScript
gsave
.46429 .06845 -70.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.91667 .1875 .05952 0 365.73 arc
s
gsave
.91667 .1875 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 .21131 m
.85714 .21131 L
s
% Start of user PostScript
4. 0.2 6.5 0.2 MAarrowhead2
% End of user PostScript
gsave
.70833 .23512 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.85714 .16369 m
.55952 .16369 L
s
% Start of user PostScript
6.5 -0.2 4. -0.2 MAarrowhead2
% End of user PostScript
gsave
.70833 .13988 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{288, 108},
  ImageMargins->{{0, 0}, {0, 0.5}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000Qa000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo002cOol00`00Oomoo`2bOol00;=oo`03001oogoo0;9oo`00/goo00<0
07ooOol0/Woo002bOol3002cOol00;9oo`<00;=oo`00/Woo0`00/goo002bOol3002cOol00;5oo`D0
0;9oo`00/Goo1@00/Woo002aOol5002bOol00;5oo`D00;9oo`00/Goo1@00/Woo002`Ool7002aOol0
0;1oo`L00;5oo`00/7oo1`00/Goo002`Ool7002aOol00:moo`T00;1oo`00[goo2@00/7oo002_Ool9
002`Ool00;=oo`03001oogoo0;9oo`00/goo00<007ooOol0/Woo002cOol00`00Oomoo`2bOol00;=o
o`03001oogoo0;9oo`00/goo00<007ooOol0/Woo002cOol00`00Oomoo`2bOol00:Aoo`D0009oo`03
001oogoo00Eoo`03001oogoo0;9oo`00YWoo00L007ooOomoo`00Ool00006Ool00`00Oomoo`2bOol0
09ioo`80009oo`<00003Ool007oo009oo`03001oo`0000Ioo`03001oogoo0;9oo`00Wgoo00@007oo
Ool000=oo`07001oogooOol007oo00001Woo00<007ooOol0/Woo002OOol00`00Ool00004Ool01`00
Oomoogoo001oo`0000Ioo`03001oogoo0;9oo`00Wgoo0`000goo0P0017oo00<007ooOol01Goo00<0
07ooOol0/Woo002OOol01000Oomoo`0047oo00<007ooOol0/Woo002OOol00`00Ool00003000>Ool0
0`00Oomoo`2bOol009moo`03001oogoo015oo`03001oogoo0;9oo`00WWoo0P004goo00<007ooOol0
/Woo002cOol00`00Oomoo`2bOol00;=oo`03001oogoo0;9oo`00/goo00<007ooOol0/Woo002cOol0
0`00Oomoo`2bOol00;=oo`03001oogoo0;9oo`00/goo00<007ooOol0/Woo002cOol00`00Oomoo`2b
Ool001]oo`H008moo`H004Ioo`<00003Ool0000000<0041oo`H001eoo`005goo10001Woo1000Qgoo
10001Woo1000@Woo00<007ooOol00goo00<007ooOol0?7oo10001Woo10006Goo000EOol2000>Ool2
0023Ool2000>Ool2000iOol20002Ool300000goo001oo`03Ool00`00Oomoo`0jOol2000>Ool2000G
Ool001=oo`80019oo`8007moo`80019oo`8003Qoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00
Oomoo`0hOol2000BOol2000EOol0019oo`03001oogoo01Aoo`8007aoo`03001oogoo01Aoo`8003Io
o`03001oo`0000=oo`03001oo`0000=oo`03001oogoo03Ioo`8001Ioo`03001oogoo019oo`004Goo
00<007ooOol05goo00<007ooOol0N7oo00<007ooOol05goo00<007ooOol0<goo0`0017oo00@007oo
Oomoo`8003Moo`03001oogoo01Moo`80019oo`0047oo00<007ooOol06Goo0P00Mgoo00<007ooOol0
6Goo0P00<goo00@007ooOol0041oo`03001oogoo01Uoo`80011oo`003goo00<007ooOol06goo00<0
07ooOol0Lgoo0P007Goo00<007ooOol0<Goo00<007oo00000`00?7oo0P007Goo00<007ooOol03Woo
000>Ool00`00Oomoo`0MOol00`00Oomoo`1aOol00`00Oomoo`0NOol00`00Oomoo`0`Ool00`00Oomo
o`0nOol00`00Oomoo`0NOol00`00Oomoo`0=Ool000eoo`03001oogoo01moo`03001oogoo071oo`03
001oogoo01moo`03001oogoo015oo`<001Yoo`80041oo`03001oogoo01ioo`03001oogoo00eoo`00
37oo00<007ooOol08Goo00<007ooOol0KWoo00<007ooOol08Goo00<007ooOol037oo1`00Fgoo00<0
07ooOol087oo00<007ooOol037oo000;Ool00`00Oomoo`0SOol00`00Oomoo`1/Ool00`00Oomoo`0S
Ool00`00Oomoo`06Ool<001JOol00`00Oomoo`0ROol2000<Ool000]oo`03001oogoo02=oo`03001o
ogoo06aoo`03001oogoo02=oo`03001oogoo009ooa0005Yoo`03001oogoo02=oo`03001oogoo00Yo
o`002Woo00<007ooOol09Goo00<007ooOol0JWoo00<007ooOol09GooKP009Woo00<007ooOol02Woo
000:Ool00`00Oomoo`0UOol00`00Oomoo`1ZOol00`00Oomoo`0UOol01000Oomoogoo4000FGoo00<0
07ooOol097oo00<007ooOol02Woo000:Ool00`00Oomoo`0UOol00`00Oomoo`1YOol00`00Oomoo`0V
Ool00`00Oomoo`05Ool<001HOol00`00Oomoo`0VOol00`00Oomoo`09Ool000Yoo`03001oogoo02Eo
o`03001oogoo06Uoo`03001oogoo02Ioo`03001oogoo00Yoo`L005Qoo`03001oogoo02Ioo`03001o
ogoo00Uoo`002Goo00<007ooOol09goo00<007ooOol0EWoo0`003goo00<007ooOol09goo00<007oo
Ool03Goo0`00F7oo00<007ooOol09goo00<007ooOol027oo0009Ool00`00Oomoo`0WOol00`00Oomo
o`1FOol7000;Ool00`00Oomoo`0WOol00`00Oomoo`1XOol00`00Oomoo`0WOol00`00Oomoo`08Ool0
00Uoo`03001oogoo011oo`<00003Ool00000015oo`03001oogoo05Ioo``000Ioo`03001oogoo011o
o`D0019oo`03001oogoo06Qoo`03001oogoo00moo`D001=oo`03001oogoo00Qoo`002Goo00<007oo
Ool03goo00@007ooOomoo`80019oo`03001oogoo05Iooa00009oo`03001oogoo019oo`03001oogoo
019oo`03001oogoo06Qoo`03001oogoo00moo`05001oogooOol0000COol00`00Oomoo`08Ool000Uo
o`03001oogoo00moo`03001oogoo009oo`03001oogoo011oof`001Aoo`03001oogoo019oo`03001o
ogoo06Qoo`03001oogoo011oo`03001oogoo01Aoo`03001oogoo00Qoo`002Goo00<007ooOol047oo
1@004Woo00<007ooOol0EWoo4@0000=oo`00Ool04goo00<007ooOol04Woo00<007ooOol0J7oo00<0
07ooOol04Goo00<007ooOol04goo00<007ooOol027oo0009Ool00`00Oomoo`0?Ool00`00Oomoo`02
Ool00`00Oomoo`0@Ool00`00Oomoo`1FOol=0005Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00
Oomoo`1XOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`08Ool000Uoo`03001oogoo011o
o`@001=oo`03001oogoo05Ioo`X000Qoo`03001oogoo019oo`03001oogoo019oo`03001oogoo06Qo
o`03001oogoo01=oo`03001oogoo015oo`03001oogoo00Qoo`002Goo00<007ooOol09goo00<007oo
Ool0EWoo1P0037oo00<007ooOol047oo0`0057oo00<007ooOol0J7oo00<007ooOol03goo00D007oo
Oomoo`0001=oo`03001oogoo00Qoo`002Goo00<007ooOol09goo00<007ooOol0EWoo0P0047oo00<0
07ooOol04Woo00<007ooOol04Woo00<007ooOol0EWoo0`003goo00<007ooOol047oo0`0057oo00<0
07ooOol027oo000:Ool00`00Oomoo`0UOol00`00Oomoo`1YOol00`00Oomoo`0VOol00`00Oomoo`1G
Ool7000;Ool00`00Oomoo`0VOol00`00Oomoo`09Ool000Yoo`03001oogoo02Eoo`03001oogoo06Uo
o`03001oogoo02Ioo`03001oogoo05Moo``000Ioo`03001oogoo02Ioo`03001oogoo00Uoo`002Woo
00<007ooOol09Goo00<007ooOol0JWoo00<007ooOol09Goo00<007ooOol0Egoo40000goo00<007oo
Ool097oo00<007ooOol02Woo000:Ool00`00Oomoo`0UOol00`00Oomoo`0eOol4000aOol00`00Oomo
o`0UOom^000VOol00`00Oomoo`0:Ool000]oo`03001oogoo02=oo`03001oogoo03Ioo`<003=oo`03
001oogoo02=oo`03001oogoo05Qooa4000=oo`03001oogoo02=oo`03001oogoo00Yoo`002goo00<0
07ooOol08goo00<007ooOol0;goo0P000Woo0`000Woo00<007ooOol0<Goo00<007ooOol08goo00<0
07ooOol0F7oo3@001goo00<007ooOol08goo00<007ooOol02Woo000<Ool00`00Oomoo`0QOol00`00
Oomoo`0aOol01000Oomoo`000goo0P00=7oo00<007ooOol08Goo00<007ooOol0FGoo2P002goo00<0
07ooOol087oo0P003Goo000=Ool00`00Oomoo`0OOol00`00Oomoo`0bOol00`00Ool0000kOol00`00
Oomoo`0OOol00`00Oomoo`1JOol6000@Ool00`00Oomoo`0NOol00`00Oomoo`0=Ool000ioo`03001o
ogoo01eoo`03001oogoo03=oo`<003]oo`03001oogoo01ioo`03001oogoo03Eoo`D00004Ool00000
000MOol2000DOol00`00Oomoo`0NOol00`00Oomoo`0=Ool000moo`03001oogoo01]oo`03001oogoo
03Aoo`04001oogoo000kOol00`00Oomoo`0LOol00`00Oomoo`0`Ool20002Ool300000goo001oo`02
Ool00`00Oomoo`0dOol00`00Oomoo`0LOol00`00Oomoo`0>Ool0011oo`03001oogoo01Yoo`03001o
ogoo03Aoo`03001oo`0000<003Yoo`8001aoo`03001oogoo035oo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`0dOol2000LOol00`00Oomoo`0>Ool0015oo`03001oogoo01Moo`8003Moo`03
001oogoo03moo`03001oogoo01Moo`8003Aoo`03001oo`0000Aoo`03001oogoo009oo`03001oogoo
03Eoo`03001oogoo01Qoo`80015oo`004Woo00<007ooOol05Goo00<007ooOol0=Woo0P00@Woo00<0
07ooOol05Goo00<007ooOol0=7oo0`0017oo00L007ooOomoo`00Ool0000gOol00`00Oomoo`0EOol2
000COol001=oo`03001oogoo019oo`8007ioo`03001oogoo019oo`8003Moo`04001oogoo0002Ool2
0004Ool00`00Oomoo`0gOol2000DOol00`00Oomoo`0COol001Aoo`80011oo`80085oo`80011oo`80
03Uoo`03001oo`0000<0049oo`80011oo`8001Ioo`005Woo100027oo1000QGoo100027oo1000>goo
00<007ooOol0Agoo10001goo1@0067oo000JOol8002=Ool8000nOol2001=Ool7000MOol001ioo`03
001oogoo0?moodQoo`007Woo0P00ogooBGoo000MOol3003oOom9Ool001eoo`<00?moodUoo`007Goo
0`00ogooBGoo000MOol200000goo001oo`3oOom7Ool001aoo`05001oo`00Ool0003oOom8Ool001ao
o`05001oo`00Ool0003oOom8Ool001aoo`05001oo`00Ool0003oOom8Ool001aoo`03001oo`00009o
o`03001oogoo0?moodEoo`0077oo00<007oo00000Woo00<007ooOol0ogooAGoo000KOol01000Oomo
o`000Woo00<007ooOol0ogooAGoo000KOol01000Oomoo`000goo00<007ooOol0ogooA7oo000KOol0
1000Oomoo`000goo00<007ooOol0ogooA7oo000KOol01000Oomoo`000goo00<007ooOol0ogooA7oo
000JOol01@00Oomoogoo00000goo00<007ooOol0ogooA7oo000JOol01@00Oomoogoo000017oo00<0
07ooOol0ogoo@goo000JOol01@00Oomoogoo000017oo00<007ooOol0ogoo@goo000NOol00`00Oomo
o`3oOom8Ool001ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0ogooB7oo000NOol00`00Oomo
o`3oOom8Ool001ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0ogooB7oo000BOol30009Ool0
0`00Oomoo`09Ool40007Ool00`00Oomoo`07Ool00`00Oomoo`3oOolWOol001=oo`03001oogoo00Qo
o`03001oogoo00Uoo`<000Moo`03001oogoo00Uoo`03001oogoo0?moobIoo`0037oo0P000Woo1000
2Woo00<007ooOol00P0000Aoo`00000000Eoo`03001oogoo00Aoo`03001oogoo00=oo`<000Eoo`03
001oogoo0?moobEoo`003Goo00@007ooOol0009oo`8000Uoo`04001oogooOol20003Ool01000Oomo
ogoo0P001Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo0?moobEoo`003Goo00<0
07oo00000goo00@007ooOol000Moo`05001oogooOol00004Ool00`00Oomoo`09Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool00`00Oomoo`3oOolUOol000eoo`<0009oo`D000Moo`05001oogooOol00004
Ool00`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`3oOolUOol000eoo`04
001oogoo000=Ool01000Oomoogoo0P000goo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol0
1Woo00<007ooOol0ogoo9Goo000=Ool00`00Ool00003000;Ool01P00Oomoogoo001oo`<000aoo`04
001oogooOol50005Ool00`00Oomoo`3oOolUOol000eoo`03001oogoo00ioo`05001oogooOol0000A
Ool01@00Oomoogoo00001goo00<007ooOol0ogoo9Woo000<Ool2000@Ool00`00Oomoo`02000BOol0
0`00Oomoo`07Ool00`00Oomoo`3oOolWOol001ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0
ogooB7oo000NOol00`00Oomoo`3oOom8Ool001ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0
ogooB7oo000NOol00`00Oomoo`3oOom8Ool001ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0
ogooB7oo003oOomYOol00?moofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{127.625, 414.625}, {408.875, 301.875}} -> {-4.48178, \
7.31202, 0.0294395, 0.0294395}}],

Cell["We can represent the above model as ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`b\_a' \((t)\)\  = \ \(-\ k\_F\)\)]],
  " \n",
  Cell[BoxData[
      \(TraditionalForm\`x\_a' \((t)\)\  = 
        k\_F\  - \ k\_a\ \(\(x\_a\)(t)\)\)]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`x\_1' \((t)\)\  = \ 
        k\_a\ \(\(x\_a\)(t)\)\  - \ \((k\_10 + \ k\_12)\)\ \(\(x\_1\)(
              t)\)\ \  + \ \(\(k\_21\)\(\ \)\(\(x\_21\)(t)\)\(\ \)\)\)]],
  " \n",
  Cell[BoxData[
      \(TraditionalForm\`x\_2' \((t)\)\  = \ 
        k\_21\ \(\(x\_1\)(t)\)\ \  - \ \ \(\(k\_12\)\(\ \)\(\(x\_2\)(
              t)\)\(\ \)\)\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "Zero-order mean that the input is given by a constant rate ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(b\_a\)(t)\)'\)]],
  " = -",
  Cell[BoxData[
      \(TraditionalForm\`k\_F\)]],
  ", and therefore a constant input ",
  Cell[BoxData[
      \(TraditionalForm\`k\_F\)]],
  " to compartment a.   The total release amount is called ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  " that is equivalent to taken as initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_a\)(0)\  = \ d\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(b\_a[
        t_]\  = \(\(b\_a[
          t]\)\(/.\)\(\(DSolve[{\(b\_a'\)[t] + k\_F\  == 0, 
              b\_a[0] \[Equal] d}, b\_a[t], \ 
            t]\)[\([\)\(1\)\(]\)]\)\(\ \)\)\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \(d - t\ k\_F\)], "Output",
  CellLabel->"Out[62]="],

Cell[BoxData[
    \(d - t\ k\_F\)], "Output",
  CellLabel->"Out[58]=",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[TextData[{
  "We suppose that ",
  Cell[BoxData[
      \(TraditionalForm\`d = 100\)]],
  " and  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(k\_F\)\(=\)\(0.1\)\(\ \)\)\)]],
  " and plot ",
  Cell[BoxData[
      \(b\_a[t]\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Plot[
      Evaluate[b\_a[t] /. {d \[Rule] \ 100, k\_F -> 0.1}\ ], \ {t, \ 0, 
        1200}]\)\(\ \)\)\)], "Input",
  CellLabel->"In[63]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000793651 0.112816 0.00490503 [
[.18254 .10032 -9 -9 ]
[.18254 .10032 9 0 ]
[.34127 .10032 -9 -9 ]
[.34127 .10032 9 0 ]
[.5 .10032 -9 -9 ]
[.5 .10032 9 0 ]
[.65873 .10032 -9 -9 ]
[.65873 .10032 9 0 ]
[.81746 .10032 -12 -9 ]
[.81746 .10032 12 0 ]
[.97619 .10032 -12 -9 ]
[.97619 .10032 12 0 ]
[.01131 .01472 -18 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .21092 -12 -4.5 ]
[.01131 .21092 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .40712 -12 -4.5 ]
[.01131 .40712 0 4.5 ]
[.01131 .50522 -12 -4.5 ]
[.01131 .50522 0 4.5 ]
[.01131 .60332 -18 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .11282 m
.18254 .11907 L
s
[(200)] .18254 .10032 0 1 Mshowa
.34127 .11282 m
.34127 .11907 L
s
[(400)] .34127 .10032 0 1 Mshowa
.5 .11282 m
.5 .11907 L
s
[(600)] .5 .10032 0 1 Mshowa
.65873 .11282 m
.65873 .11907 L
s
[(800)] .65873 .10032 0 1 Mshowa
.81746 .11282 m
.81746 .11907 L
s
[(1000)] .81746 .10032 0 1 Mshowa
.97619 .11282 m
.97619 .11907 L
s
[(1200)] .97619 .10032 0 1 Mshowa
.125 Mabswid
.06349 .11282 m
.06349 .11657 L
s
.10317 .11282 m
.10317 .11657 L
s
.14286 .11282 m
.14286 .11657 L
s
.22222 .11282 m
.22222 .11657 L
s
.2619 .11282 m
.2619 .11657 L
s
.30159 .11282 m
.30159 .11657 L
s
.38095 .11282 m
.38095 .11657 L
s
.42063 .11282 m
.42063 .11657 L
s
.46032 .11282 m
.46032 .11657 L
s
.53968 .11282 m
.53968 .11657 L
s
.57937 .11282 m
.57937 .11657 L
s
.61905 .11282 m
.61905 .11657 L
s
.69841 .11282 m
.69841 .11657 L
s
.7381 .11282 m
.7381 .11657 L
s
.77778 .11282 m
.77778 .11657 L
s
.85714 .11282 m
.85714 .11657 L
s
.89683 .11282 m
.89683 .11657 L
s
.93651 .11282 m
.93651 .11657 L
s
.25 Mabswid
0 .11282 m
1 .11282 L
s
.02381 .01472 m
.03006 .01472 L
s
[(-20)] .01131 .01472 1 0 Mshowa
.02381 .21092 m
.03006 .21092 L
s
[(20)] .01131 .21092 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(40)] .01131 .30902 1 0 Mshowa
.02381 .40712 m
.03006 .40712 L
s
[(60)] .01131 .40712 1 0 Mshowa
.02381 .50522 m
.03006 .50522 L
s
[(80)] .01131 .50522 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(100)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .03924 m
.02756 .03924 L
s
.02381 .06377 m
.02756 .06377 L
s
.02381 .08829 m
.02756 .08829 L
s
.02381 .13734 m
.02756 .13734 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .18639 m
.02756 .18639 L
s
.02381 .23544 m
.02756 .23544 L
s
.02381 .25997 m
.02756 .25997 L
s
.02381 .28449 m
.02756 .28449 L
s
.02381 .33354 m
.02756 .33354 L
s
.02381 .35807 m
.02756 .35807 L
s
.02381 .38259 m
.02756 .38259 L
s
.02381 .43164 m
.02756 .43164 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .48069 m
.02756 .48069 L
s
.02381 .52974 m
.02756 .52974 L
s
.02381 .55427 m
.02756 .55427 L
s
.02381 .57879 m
.02756 .57879 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.06244 .57944 L
.10458 .5534 L
.14415 .52894 L
.18221 .50542 L
.22272 .48039 L
.26171 .45629 L
.30316 .43067 L
.34309 .406 L
.3815 .38225 L
.42237 .357 L
.46172 .33268 L
.49955 .30929 L
.53984 .2844 L
.57861 .26043 L
.61984 .23495 L
.65954 .21041 L
.69774 .18681 L
.73838 .16169 L
.77751 .13751 L
.81909 .11181 L
.85916 .08704 L
.89771 .06322 L
.93871 .03788 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[63]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0
oooo2@3oool000L0oooo100000030?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo
00070?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`3o0?ooo`T0oooo00080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
103oool200000?`0oooo00<000000?ooo`3oool02P3oool000030?ooo`000000000000800000103o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`3i0?ooo`8000003@3oool000L0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0?L0oooo0P00000?0?ooo`00203oool2000000@0oooo
0P0000050?ooo`030000003oool0oooo0?H0oooo00<000000?ooo`3oool03`3oool001D0oooo00<0
00000?ooo`3oool0m03oool200000180oooo000E0?ooo`030000003oool0oooo0?80oooo0P00000D
0?ooo`005@3oool200000?80oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3o
ool0k`3oool2000001L0oooo000E0?ooo`030000003oool0oooo0>h0oooo00<000000?ooo`3oool0
5`3oool001D0oooo00<000000?ooo`3oool0k03oool2000001X0oooo000E0?ooo`030000003oool0
oooo0>X0oooo0P00000L0?ooo`005@3oool00`000000oooo0?ooo`3Y0?ooo`030000003oool0oooo
01`0oooo000E0?ooo`030000003oool0oooo0>L0oooo0P00000O0?ooo`005@3oool200000>L0oooo
00<000000?ooo`3oool07`3oool001D0oooo00<000000?ooo`3oool07`3oool4000000<0oooo0P00
00040?ooo`8000007@3oool300000080oooo0P0000040?ooo`800000703oool3000000@0oooo0P00
00040?ooo`800000703oool2000000@0oooo0P0000040?ooo`800000603oool500000080oooo0P00
00040?ooo`800000103oool2000000X0oooo0P00000:0?ooo`D0000000<0oooo0000000000000P00
00030?ooo`800000103oool2000000<0oooo000E0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000001d0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
01T0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000001X0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000001T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`80
00003P3oool01@000000oooo0?ooo`3oool0000000D0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`005@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000J0?ooo`D00000
00D0oooo0000003oool0oooo000000020?ooo`040000003oool0oooo000001/0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000001X0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000001T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`800000403oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`005@3oool00`000000oooo0?ooo`0Q0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01P0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
01/0oooo0`0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000006`3o
ool2000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000I0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool0oooo0P00000B0?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo0@0000010?oo
o`40oooo000E0?ooo`030000003oool0oooo01l0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000001/0oooo00<000000?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000001`0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000001X0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000001T0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo00000000000D0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo0@000001
0?ooo`40oooo000E0?ooo`8000008@3oool2000000@0oooo0P0000040?ooo`8000007@3oool20000
00<0oooo0P0000040?ooo`8000007@3oool3000000<0oooo0P0000040?ooo`800000703oool20000
00@0oooo0P0000040?ooo`8000006@3oool2000000@0oooo0P0000040?ooo`800000103oool20000
00030?ooo`000000oooo01@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000030?oo
o`005@3oool00`000000oooo0?ooo`3I0?ooo`800000;@3oool001D0oooo00<000000?ooo`3oool0
f03oool00`000000oooo0?ooo`0]0?ooo`005@3oool00`000000oooo0?ooo`3G0?ooo`030000003o
ool0oooo02h0oooo000E0?ooo`030000003oool0oooo0=D0oooo0P00000a0?ooo`005@3oool00`00
0000oooo0?ooo`3D0?ooo`030000003oool0oooo0340oooo000E0?ooo`030000003oool0oooo0=80
oooo0P00000d0?ooo`003P3ooooo000000d000001P3oool001D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`060?ooo`8000002P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`005@3oool0
0`000000oooo0?ooo`3=0?ooo`800000>@3oool001D0oooo00<000000?ooo`3oool0b`3oool20000
03/0oooo000E0?ooo`030000003oool0oooo0<T0oooo0P00000m0?ooo`005@3oool00`000000oooo
0?ooo`370?ooo`800000?`3oool001D0oooo0P0000370?ooo`030000003oool0oooo03l0oooo000E
0?ooo`030000003oool0oooo0<@0oooo0P0000120?ooo`005@3oool00`000000oooo0?ooo`330?oo
o`030000003oool0oooo0480oooo000E0?ooo`030000003oool0oooo0<40oooo0P0000150?ooo`00
5@3oool00`000000oooo0?ooo`2o0?ooo`800000A`3oool001D0oooo00<000000?ooo`3oool0_P3o
ool00`000000oooo0?ooo`170?ooo`005@3oool00`000000oooo0?ooo`2l0?ooo`800000BP3oool0
01D0oooo0P00002l0?ooo`030000003oool0oooo04X0oooo000E0?ooo`030000003oool0oooo0;T0
oooo0P00001=0?ooo`005@3oool00`000000oooo0?ooo`2g0?ooo`800000C`3oool001D0oooo00<0
00000?ooo`3oool0]@3oool200000540oooo000E0?ooo`030000003oool0oooo0;<0oooo0P00001C
0?ooo`005@3oool00`000000oooo0?ooo`2a0?ooo`800000E@3oool001D0oooo0P00002a0?ooo`03
0000003oool0oooo05D0oooo000E0?ooo`030000003oool0oooo0:h0oooo0P00001H0?ooo`005@3o
ool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo05P0oooo000E0?ooo`030000003oool0
oooo0:`0oooo00<000000?ooo`3oool0F@3oool001D0oooo00<000000?ooo`3oool0ZP3oool20000
05`0oooo00070?ooo`@000000`3oool2000000D0oooo00<000000?ooo`3oool0Z@3oool00`000000
oooo0?ooo`1L0?ooo`001`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0Y`3oool2000005l0oooo00080?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000103oool200000:L0oooo00<000000?ooo`3oool0G`3oool000T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0Y03oool200000680oooo00070?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`2R0?ooo`800000I03oool000P0oooo0P0000040?ooo`80
00001@3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo06@0oooo000E0?ooo`030000
003oool0oooo09l0oooo0P00001W0?ooo`005@3oool00`000000oooo0?ooo`2M0?ooo`800000J@3o
ool001D0oooo0P00002M0?ooo`030000003oool0oooo06T0oooo000E0?ooo`030000003oool0oooo
09X0oooo0P00001/0?ooo`005@3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo06`0
oooo000E0?ooo`030000003oool0oooo09L0oooo0P00001_0?ooo`005@3oool00`000000oooo0?oo
o`2E0?ooo`800000L@3oool001D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1a
0?ooo`005@3oool00`000000oooo0?ooo`2B0?ooo`800000M03oool001D0oooo0P00002B0?ooo`03
0000003oool0oooo07@0oooo000E0?ooo`030000003oool0oooo08l0oooo0P00001g0?ooo`005@3o
ool00`000000oooo0?ooo`2=0?ooo`800000N@3oool001D0oooo00<000000?ooo`3oool0R`3oool2
000007/0oooo000E0?ooo`030000003oool0oooo08T0oooo0P00001m0?ooo`005@3oool00`000000
oooo0?ooo`270?ooo`800000O`3oool001D0oooo0P0000270?ooo`030000003oool0oooo07l0oooo
000E0?ooo`030000003oool0oooo08@0oooo0P0000220?ooo`005@3oool00`000000oooo0?ooo`23
0?ooo`030000003oool0oooo0880oooo000E0?ooo`030000003oool0oooo0880oooo00<000000?oo
o`3oool0P`3oool001D0oooo00<000000?ooo`3oool0P03oool2000008H0oooo00090?ooo`<00000
0P3oool2000000D0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`260?ooo`002P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
O@3oool2000008T0oooo00070?ooo`D0000000D0oooo0000003oool0oooo000000040?ooo`800000
O@3oool00`000000oooo0?ooo`290?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0NP3oool2000008`0oooo00080?ooo`030000
003oool000000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1h0?ooo`80
0000SP3oool000T0oooo0P0000030?ooo`8000001@3oool00`000000oooo0?ooo`1f0?ooo`800000
T03oool001D0oooo00<000000?ooo`3oool0M03oool200000980oooo000E0?ooo`030000003oool0
oooo0780oooo0P00002D0?ooo`005@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo
09@0oooo000E0?ooo`800000L03oool2000009L0oooo000E0?ooo`030000003oool0oooo06h0oooo
00<000000?ooo`3oool0U`3oool001D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?oo
o`2H0?ooo`005@3oool00`000000oooo0?ooo`1[0?ooo`800000V`3oool001D0oooo00<000000?oo
o`3oool0JP3oool00`000000oooo0?ooo`2K0?ooo`005@3oool00`000000oooo0?ooo`1X0?ooo`80
0000WP3oool001D0oooo0P00001X0?ooo`030000003oool0oooo09h0oooo000E0?ooo`030000003o
ool0oooo06D0oooo0P00002Q0?ooo`005@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo0:40oooo000E0?ooo`030000003oool0oooo0680oooo0P00002T0?ooo`005@3oool00`000000
oooo0?ooo`1P0?ooo`800000YP3oool001D0oooo00<000000?ooo`3oool0G`3oool00`000000oooo
0?ooo`2V0?ooo`005@3oool00`000000oooo0?ooo`1M0?ooo`800000Z@3oool001D0oooo0P00001M
0?ooo`030000003oool0oooo0:T0oooo000E0?ooo`030000003oool0oooo05X0oooo0P00002/0?oo
o`005@3oool00`000000oooo0?ooo`1H0?ooo`800000[P3oool001D0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`2^0?ooo`001`3oool3000000@0oooo0P0000050?ooo`030000003o
ool0oooo05D0oooo0P00002a0?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0D`3oool200000;<0oooo00070?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool2000005<0oooo00<000000?ooo`3o
ool0/`3oool000L0oooo0`0000030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0D03oool200000;H0oooo00080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`1>0?ooo`800000^03oool000P0oooo0`0000030?ooo`800000
1@3oool00`000000oooo0?ooo`1<0?ooo`800000^P3oool001D0oooo00<000000?ooo`3oool0BP3o
ool200000;`0oooo000E0?ooo`030000003oool0oooo04P0oooo0P00002n0?ooo`005@3oool00`00
0000oooo0?ooo`170?ooo`030000003oool0oooo0;h0oooo000E0?ooo`800000AP3oool200000<40
oooo000E0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0`@3oool001D0oooo00<0
00000?ooo`3oool0@P3oool200000<@0oooo000E0?ooo`030000003oool0oooo0400oooo0P000036
0?ooo`005@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0<H0oooo000E0?ooo`03
0000003oool0oooo03d0oooo0P0000390?ooo`005@3oool2000003d0oooo00<000000?ooo`3oool0
b@3oool001D0oooo00<000000?ooo`3oool0>P3oool200000<`0oooo000E0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0c03oool001D0oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`3=0?ooo`005@3oool00`000000oooo0?ooo`0f0?ooo`800000d03oool001D0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3@0?ooo`005@3oool00`000000oooo0?oo
o`0c0?ooo`800000d`3oool001D0oooo0P00000c0?ooo`030000003oool0oooo0=<0oooo000E0?oo
o`030000003oool0oooo0300oooo0P00003F0?ooo`005@3oool00`000000oooo0?ooo`0^0?ooo`80
0000f03oool001D0oooo00<000000?ooo`3oool0;03oool200000=X0oooo00080?ooo`800000103o
ool2000000D0oooo00<000000?ooo`3oool0:P3oool200000=`0oooo00070?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0X0?ooo`800000
gP3oool000L0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`80
0000:03oool00`000000oooo0?ooo`3N0?ooo`00203oool2000000<0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0U0?ooo`800000h@3oool000L0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0h@3oool000P0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0>80oooo000E0?ooo`030000003oool0oooo0240oooo0P00003U0?ooo`005@3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0>D0oooo000E0?ooo`030000003oool0
oooo01h0oooo0P00003X0?ooo`005@3oool2000001h0oooo00<000000?ooo`3oool0j03oool001D0
oooo00<000000?ooo`3oool06`3oool200000>/0oooo000E0?ooo`030000003oool0oooo01T0oooo
0P00003]0?ooo`005@3oool00`000000oooo0?ooo`0G0?ooo`800000k`3oool001D0oooo00<00000
0?ooo`3oool05@3oool200000?40oooo000E0?ooo`030000003oool0oooo01<0oooo0P00003c0?oo
o`005@3oool2000001<0oooo00<000000?ooo`3oool0l`3oool001D0oooo00<000000?ooo`3oool0
403oool200000?H0oooo000E0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0mP3o
ool001D0oooo00<000000?ooo`3oool03@3oool200000?T0oooo000E0?ooo`030000003oool0oooo
00/0oooo0P00003k0?ooo`005@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?/0
oooo000E0?ooo`030000003oool0oooo00P0oooo0P00003n0?ooo`005@3oool2000000P0oooo00<0
00000?ooo`3oool0oP3oool001D0oooo00<000000?ooo`3oool01@3oool200000?l0oooo0P3oool0
01D0oooo00<000000?ooo`3oool00`3oool200000?l0oooo103oool001D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo00000`3oool000000000000300000080oooo
0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0200000?l0oooo1`3oool000<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00P3oool300000?l0oooo2@3oool000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool200000?l0oooo2P3oool000<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00030?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0o`3oool90?ooo`000P3oool2000000@0oooo0P0000040?ooo`8000001@3oool0
0`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-100.906, -27.7157, 4.73059, \
0.765425}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[63]="]
}, Open  ]],

Cell[TextData[{
  "We will observe that from a certain value of t  ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_a\)(t)\)]],
  " takes negative values.  This means the all ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  " amount has been already transferred to ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " when  ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_a\)(t)\)]],
  " = 0.  We solve this equation to find ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " that we will call ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "We used Solve to find ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ".  "
}], "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[d - T\ k\_F == \ 0, \ T]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \({{T \[Rule] d\/k\_F}}\)], "Output",
  CellLabel->"Out[64]="]
}, Open  ]],

Cell["Therefore we should be consider two period:  ", "Text"],

Cell[TextData[{
  "First period:  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(0\)\(<\)\(t\)\(\[LessEqual]\)\(T\)\(\ \)\)\)]],
  "with ",
  Cell[BoxData[
      \(TraditionalForm\`T\  = \ d/k\_F\)]]
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x\_a' \((t)\)\  = \ \ k\_F - \ 
          k\_a\ \(\(x\_a\)(t)\)\)]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`x\_1' \((t)\)\  = \ 
        k\_a\ \(\(x\_a\)(t)\)\  - \ \((k\_10 + \ k\_12)\)\ \(\(x\_1\)(
              t)\)\ \  + \ \(\(k\_21\)\(\ \)\(\(x\_2\)(t)\)\(\ \)\)\)]],
  " \n",
  Cell[BoxData[
      \(TraditionalForm\`x\_2' \((t)\)\  = \ 
        k\_12\ \(\(x\_1\)(t)\)\ \  - \ \ \(\(k\_21\)\(\ \)\(\(x\_2\)(
              t)\)\(\ \)\)\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "\tInitial condition: ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_a\)(0)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\)(0)\)]],
  " =",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_2\)(0)\)]],
  " = 0"
}], "Text"],

Cell[TextData[{
  "Second period: ",
  Cell[BoxData[
      \(TraditionalForm\`t > T\)]],
  ". We call ",
  Cell[BoxData[
      \(TraditionalForm\`t'\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`t - T\)]],
  " "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x\_a' \((t')\)\  = \(-\ k\_a\)\ \(\(x\_a\)(
            t')\)\)]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`x\_1' \((t')\)\  = \ 
        k\_a\ \(\(x\_a\)(t')\)\  - \ \((k\_10 + \ k\_12)\)\ \(\(x\_1\)(
              t')\)\ \  + \ \(\(k\_21\)\(\ \)\(\(x\_2\)(t')\)\(\ \)\)\)]],
  " \n",
  Cell[BoxData[
      \(TraditionalForm\`x\_2' \((t')\)\  = \ 
        k\_12\ \(\(x\_1\)(t')\)\ \  - \ \ \(\(k\_21\)\(\ \)\(\(x\_2\)(
              t')\)\(\ \)\)\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "Initial condition: ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_a\)(0)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_a\)(T)\)]],
  ";  ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\)(0)\)]],
  " =",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\)(T)\)]],
  "; ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_2\)(0)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_2\)(T)\)]],
  ", where  ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_a\)(T)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\)(T)\)]],
  ", y ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_2\)(T)\)]],
  " is given by eq. 13 when ",
  Cell[BoxData[
      \(TraditionalForm\`t = T\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "Now, we give the values of transfer coefficients. In our example they are  \
",
  Cell[BoxData[
      \(TraditionalForm\`k\_F\)]],
  "=0.1, ",
  Cell[BoxData[
      \(TraditionalForm\`k\_a\)]],
  "= 2, ",
  Cell[BoxData[
      \(TraditionalForm\`k\_10\)]],
  "=0.5, ",
  Cell[BoxData[
      \(TraditionalForm\`k\_12\)]],
  "= 2, ",
  Cell[BoxData[
      \(TraditionalForm\`k\_21\)]],
  "= 1"
}], "Text"],

Cell[TextData[{
  "We use k with /: (TagSet) to  make easier clear all coefficient values \
later. We will can delete its writing ",
  StyleBox["Clear[k]", "DisplayMath"],
  " in place of write every ",
  Cell[BoxData[
      \(TraditionalForm\`k\_i\)]],
  " . Also we write ",
  Cell[BoxData[
      \(k\_F = 1/10\)]],
  " and ",
  Cell[BoxData[
      \(k\_10 = 1/2\)]],
  " using rational coefficients better than ",
  Cell[BoxData[
      \(k\_F = 0.1\)]],
  " and ",
  Cell[BoxData[
      \(k\_10 = 0.5\)]],
  " because with rational coefficients the computation is made using infinite \
precision. "
}], "Caption"],

Cell[BoxData[
    \(\(\(k /: k\_F = 1/10\)\(;\)\(k /: k\_a = 2\)\(;\)\(\(k /: k\_10 = 
      1/2\)\(\ \)\)\(;\)\(k /: k\_21 = 1\)\(;\)\(\ \)\(k /: k\_12 = 
      2\)\(;\)\(\ \)\)\)], "Input",
  CellLabel->"In[65]:="],

Cell["Here is the solution to eq13  ", "MathCaption"],

Cell[BoxData[
    \(eq1\  = \ {\(x\_a'\)[t] == \ \ k\_F - \ k\_a\ x\_a[t], \(x1'\)[
            t] \[Equal] 
          k\_a\ x\_a[t] - \ \((k\_10 + k\_12)\)\ x1[t] + 
            k\_21\ x2[t], \(x2'\)[t] == 
          k\_12\ x1[t] - k\_21\ x2[t]}; \)], "Input",
  CellLabel->"In[66]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \({x1a[t_], x11[t_], 
        x12[t_]} = {x\_a[t], x1[t], 
            x2[t]} /. \(DSolve[
              Join[eq1, {x\_a[0] \[Equal] 0, x1[0] \[Equal] 0, 
                  x2[0] \[Equal] 0}], {x\_a[t], x1[t], x2[t]}\ , \ 
              t]\)[\([\)\(1\)\(]\)] // FullSimplify\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \({1\/10\ \[ExponentialE]\^\(-t\)\ Sinh[
          t], \(205 - 41\ \[ExponentialE]\^\(\(-2\)\ t\) - 2\ \((41 + 9\ \
\@41)\)\ \[ExponentialE]\^\(1\/4\ \((\(-7\) + \@41)\)\ t\) + 2\ \((\(-41\) + \
9\ \@41)\)\ \[ExponentialE]\^\(\(-\(1\/4\)\)\ \((7 + \@41)\)\ t\)\)\/1025, 
      2\/5 + \(2\ \[ExponentialE]\^\(\(-\(1\/4\)\)\ \((7 + \@41)\)\ t\)\ \
\((\(-123\) + 17\ \@41 - \((123 + 17\ \@41)\)\ \[ExponentialE]\^\(\(\@41\ t\)\
\/2\) + 41\ \[ExponentialE]\^\(1\/4\ \((\(-1\) + \@41)\)\ t\))\)\)\/1025}\)], \
"Output",
  CellLabel->"Out[67]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{x1a[t], x11[t], x12[t]}, \ {t, 0, 50}, 
      PlotRange \[Rule] All]\)], "Input",
  CellLabel->"In[68]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.0147151 1.47247 [
[.21429 .00222 -6 -9 ]
[.21429 .00222 6 0 ]
[.40476 .00222 -6 -9 ]
[.40476 .00222 6 0 ]
[.59524 .00222 -6 -9 ]
[.59524 .00222 6 0 ]
[.78571 .00222 -6 -9 ]
[.78571 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .16196 -18 -4.5 ]
[.01131 .16196 0 4.5 ]
[.01131 .30921 -18 -4.5 ]
[.01131 .30921 0 4.5 ]
[.01131 .45646 -18 -4.5 ]
[.01131 .45646 0 4.5 ]
[.01131 .6037 -18 -4.5 ]
[.01131 .6037 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(10)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(20)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(30)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(40)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(50)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16196 m
.03006 .16196 L
s
[(0.1)] .01131 .16196 1 0 Mshowa
.02381 .30921 m
.03006 .30921 L
s
[(0.2)] .01131 .30921 1 0 Mshowa
.02381 .45646 m
.03006 .45646 L
s
[(0.3)] .01131 .45646 1 0 Mshowa
.02381 .6037 m
.03006 .6037 L
s
[(0.4)] .01131 .6037 1 0 Mshowa
.125 Mabswid
.02381 .04416 m
.02756 .04416 L
s
.02381 .07361 m
.02756 .07361 L
s
.02381 .10306 m
.02756 .10306 L
s
.02381 .13251 m
.02756 .13251 L
s
.02381 .19141 m
.02756 .19141 L
s
.02381 .22086 m
.02756 .22086 L
s
.02381 .25031 m
.02756 .25031 L
s
.02381 .27976 m
.02756 .27976 L
s
.02381 .33866 m
.02756 .33866 L
s
.02381 .36811 m
.02756 .36811 L
s
.02381 .39756 m
.02756 .39756 L
s
.02381 .42701 m
.02756 .42701 L
s
.02381 .4859 m
.02756 .4859 L
s
.02381 .51535 m
.02756 .51535 L
s
.02381 .5448 m
.02756 .5448 L
s
.02381 .57425 m
.02756 .57425 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02605 .03018 L
.02846 .04314 L
.03053 .05199 L
.03279 .05965 L
.03543 .06661 L
.03793 .07163 L
.04037 .0754 L
.04262 .07812 L
.04482 .08023 L
.0472 .08202 L
.0498 .08353 L
.05224 .08462 L
.05497 .08555 L
.05757 .08621 L
.0599 .08667 L
.06244 .08706 L
.0653 .08739 L
.06799 .08763 L
.07041 .08779 L
.07302 .08792 L
.07588 .08803 L
.07889 .08811 L
.08147 .08817 L
.08429 .08821 L
.08694 .08824 L
.08936 .08826 L
.09215 .08828 L
.09479 .0883 L
.09722 .08831 L
.09948 .08831 L
.10195 .08832 L
.10458 .08832 L
.10696 .08833 L
.10947 .08833 L
.11161 .08833 L
.11395 .08833 L
.11648 .08833 L
.11918 .08834 L
.12173 .08834 L
.12405 .08834 L
.1264 .08834 L
.12856 .08834 L
.13094 .08834 L
.13345 .08834 L
.13549 .08834 L
.13768 .08834 L
.14008 .08834 L
.14233 .08834 L
.14488 .08834 L
Mistroke
.14759 .08834 L
.15015 .08834 L
.15246 .08834 L
.1552 .08834 L
.15815 .08834 L
.16094 .08834 L
.16351 .08834 L
.16592 .08834 L
.16817 .08834 L
.17064 .08834 L
.17329 .08834 L
.17606 .08834 L
.17869 .08834 L
.18105 .08834 L
.18361 .08834 L
.18595 .08834 L
.18847 .08834 L
.19085 .08834 L
.19303 .08834 L
.19545 .08834 L
.1981 .08834 L
.20086 .08834 L
.20342 .08834 L
.20616 .08834 L
.20875 .08834 L
.21108 .08834 L
.21359 .08834 L
.21634 .08834 L
.21924 .08834 L
.22172 .08834 L
.22444 .08834 L
.22695 .08834 L
.22967 .08834 L
.23225 .08834 L
.23463 .08834 L
.23677 .08834 L
.23914 .08834 L
.24161 .08834 L
.24393 .08834 L
.24648 .08834 L
.24917 .08834 L
.25147 .08834 L
.25398 .08834 L
.2567 .08834 L
.2596 .08834 L
.26234 .08834 L
.26483 .08834 L
.26714 .08834 L
.26967 .08834 L
.27232 .08834 L
Mistroke
.2748 .08834 L
.27711 .08834 L
.27923 .08834 L
.28167 .08834 L
.28399 .08834 L
.28649 .08834 L
.28915 .08834 L
.29166 .08834 L
.29394 .08834 L
.29662 .08834 L
.29952 .08834 L
.30226 .08834 L
.30478 .08834 L
.30724 .08834 L
.30949 .08834 L
.31208 .08834 L
.31453 .08834 L
.31679 .08834 L
.31889 .08834 L
.32117 .08834 L
.32362 .08834 L
.32608 .08834 L
.32839 .08834 L
.33113 .08834 L
.33365 .08834 L
.33612 .08834 L
.3368 .08834 L
.33753 .08834 L
.33883 .08834 L
.34148 .08834 L
.34218 .08834 L
.34293 .08834 L
.34364 .08834 L
.34429 .08834 L
.34559 .08834 L
.34683 .08834 L
.34753 .08834 L
.34817 .08834 L
.34887 .08834 L
.34963 .08834 L
.35027 .08834 L
.35096 .08834 L
.35221 .08834 L
.35342 .08834 L
.35454 .08834 L
.35519 .08834 L
.35588 .08834 L
.35712 .08834 L
.35995 .08834 L
.36294 .08834 L
Mistroke
.36565 .08834 L
.36691 .08834 L
.36823 .08834 L
.36937 .08834 L
.37062 .08834 L
.37601 .08834 L
.38581 .08834 L
.42608 .08834 L
.46484 .08834 L
.50606 .08834 L
.54575 .08834 L
.58393 .08834 L
.60524 .08834 L
.6153 .08834 L
.62457 .08834 L
.627 .08834 L
.62927 .08834 L
.63041 .08834 L
.63164 .08834 L
.63424 .08834 L
.6447 .08834 L
.66368 .08834 L
.70503 .08834 L
.74486 .08834 L
.78318 .08834 L
.82395 .08834 L
.86321 .08834 L
.90094 .08834 L
.94113 .08834 L
.97619 .08834 L
Mfstroke
.02381 .01472 m
.04262 .05823 L
.06244 .09888 L
.08255 .13024 L
.10458 .15869 L
.14509 .19963 L
.18408 .22847 L
.22553 .25086 L
.26546 .26653 L
.30387 .27762 L
.34474 .28627 L
.38409 .29236 L
.42192 .29668 L
.46221 .30007 L
.50098 .30247 L
.54221 .30433 L
.58192 .30563 L
.62011 .30656 L
.66075 .30728 L
.69988 .30779 L
.74147 .30818 L
.78153 .30846 L
.82008 .30865 L
.86109 .30881 L
.90057 .30891 L
.93855 .30899 L
.97619 .30905 L
s
.02381 .01472 m
.06244 .11352 L
.10458 .24992 L
.14415 .34421 L
.18221 .4111 L
.22272 .46348 L
.26171 .50039 L
.30316 .52903 L
.34309 .54909 L
.3815 .56328 L
.42237 .57435 L
.46172 .58214 L
.49955 .58767 L
.53984 .59201 L
.57861 .59507 L
.61984 .59745 L
.65954 .59912 L
.69774 .60031 L
.73838 .60123 L
.77751 .60189 L
.81909 .60239 L
.85916 .60274 L
.89771 .60299 L
.93871 .60319 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00A03oool500000080oooo0P00000[0?ooo`@000000`3oool2000002/0oooo0P0000040?oo
o`800000;@3oool300000080oooo0P00000/0?ooo`800000103oool2000000@0oooo00160?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool00000:@3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002d0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0X0?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool004H0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0X0?ooo`D0000000D0oooo0000003oool0oooo0000000]0?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00@3oool004H0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo02X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo02X0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0X0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000:`3oool2000000<0oooo00@000000?ooo`3o
ool000000`3oool004H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
02P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000Y0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000:`3oool00`000000oooo000000020?ooo`04
0000003oool0oooo000002/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000003
0?ooo`00A@3oool2000000@0oooo0P00000/0?ooo`800000103oool2000002/0oooo0P0000040?oo
o`800000;@3oool2000000<0oooo0P00000/0?ooo`<000000`3oool2000000@0oooo003o0?ooob40
oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3o
ool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo
0?l0oooo2@3oool000l0ooooo`00000A00000040oooo000E0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01@3oool001D0oooo0P00000b0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool01@3oool001D0oooo0P00003o0?ooo`X0oooo000E0?ooo`<00000o`3oool90?oo
o`005@3oool300000?l0oooo2@3oool001D0oooo0`00003o0?ooo`T0oooo000E0?ooo`80000000<0
oooo0000003oool0o`3oool70?ooo`005@3oool2000000030?ooo`000000oooo0?l0oooo1`3oool0
01D0oooo0P0000020?ooo`030000003oool0oooo0?l0oooo1@3oool001D0oooo00D000000?ooo`00
0000oooo0000003o0?ooo`L0oooo000E0?ooo`040000003oool000000?ooo`800000o`3oool60?oo
o`005@3oool01P000000oooo0?ooo`000000oooo00000?l0oooo1P3oool001D0oooo00D000000?oo
o`3oool000000?ooo`0200000?l0oooo1@3oool001D0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo000E0?ooo`060000003oool0oooo0?ooo`000000oooo0P00
003o0?ooo`@0oooo000E0?ooo`8000000`3oool00`000000oooo0000003o0?ooo`@0oooo000E0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`0000000000o`3oool30?ooo`005@3oool00`00
0000oooo0?ooo`030?ooo`<00000o`3oool30?ooo`005@3oool00`000000oooo0?ooo`040?ooo`<0
0000o`3oool20?ooo`005@3oool00`000000oooo0?ooo`050?oooo`000001`3oool001D0oooo00<0
00000?ooo`3oool01P3oool200000?l0oooo0@3oool001D0oooo00<000000?ooo`3oool01P3oool2
00000?l0oooo0@3oool001D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000003o0?oo
o`005@3oool2000000P0oooo00<000000?ooo`000000oP3oool001D0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0000003n0?ooo`005@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool000000?d0oooo000E0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`000000o@3oool0
01D0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`00003l0?ooo`005@3oool00`00
0000oooo0?ooo`090?ooo`040000003oool0oooo00000?/0oooo000E0?ooo`030000003oool0oooo
00T0oooo00@000000?ooo`3oool00000n`3oool001D0oooo00<000000?ooo`3oool02@3oool01@00
0000oooo0?ooo`3oool000000?X0oooo000E0?ooo`8000002P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0?L0oooo000E0?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3o
ool0oooo0000003i0?ooo`005@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0mP3oool001D0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0?D0oooo000E0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`3d0?ooo`005@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0m03oool00080oooo0P0000040?oo
o`8000000`3oool5000000<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0?<0oooo00001@3oool000000?ooo`3oool0000000X0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0lP3oool000050?ooo`000000oooo0?ooo`0000002P3oool00`000000oooo0?ooo`030?oo
o`<00000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?40oooo00001@3oool0
00000?ooo`3oool0000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0l03oool000050?ooo`000000oooo0?oo
o`0000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`3_0?ooo`000P3oool2000000X0oooo0P0000050?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3^0?ooo`00
5@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
k@3oool001D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0>`0oooo000E0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`3[0?ooo`005@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0jP3oool001D0oooo0P00000?0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0j@3oool001D0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0>P0oooo000E0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`3W0?ooo`005@3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00d0oooo0P00003W0?ooo`005@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0i03oool001D0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0><0oooo000E0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0403oool200000><0oooo000E0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3P0?ooo`005@3oool2
00000180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3O0?ooo`005@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo01<0oooo0P00003O0?ooo`005@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0g03oool001D0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0E0?ooo`800000g03oool001D0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`800000fP3oool001D0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0I0?ooo`800000f03oool001D0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0K0?ooo`800000eP3oool001D0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0L0?ooo`800000e03oool001D0oooo0P00000D0?ooo`030000
003oool0oooo01h0oooo0P00003B0?ooo`005@3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo0200oooo0`00003?0?ooo`005@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0280oooo0P00003=0?ooo`005@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
02@0oooo0`00003:0?ooo`005@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02H0
oooo0`0000370?ooo`005@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02T0oooo
0`0000340?ooo`005@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02/0oooo1000
00300?ooo`005@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02l0oooo0`00002m
0?ooo`005@3oool2000001P0oooo00<000000?ooo`3oool0<@3oool400000;T0oooo000E0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0=@3oool400000;D0oooo000E0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0>@3oool700000:h0oooo000E0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0?`3oool800000:H0oooo000E0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0A`3oool500000:40oooo000E0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0B`3ooolC000008h0oooo00020?ooo`800000103oool2000000<0
oooo100000040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0GP3oool;000008<0
oooo00001@3oool000000?ooo`3oool0000000P0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo06P0oooo:`00001H0?ooo`0000D0oooo0000003oool0
oooo000000090?ooo`030000003oool0oooo00@0oooo0`00000J0?ooo`030000003oool0oooo09<0
ooooD@0000070?ooo`0000D0oooo0000003oool0oooo0000000:0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`3[0?ooo`0000D0oooo0000003oool0
oooo000000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`3Z0?ooo`000P3oool2000000X0oooo0P0000050?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0jP3oool001D0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`3Y0?ooo`005@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0>T0oooo000E
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0j03oool001D0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`3X0?ooo`005@3oool2000001l0oooo00<000000?ooo`3o
ool0i`3oool001D0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3W0?ooo`005@3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0>H0oooo000E0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0iP3oool001D0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`3U0?ooo`005@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0>D0
oooo000E0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0i03oool001D0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`3T0?ooo`005@3oool2000002<0oooo00<00000
0?ooo`3oool0h`3oool001D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3S0?oo
o`005@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0>80oooo000E0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0hP3oool001D0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`3Q0?ooo`005@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo0>40oooo000E0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0h03oool001D0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3P0?ooo`005@3oool2000002L0oooo
00<000000?ooo`3oool0g`3oool001D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`3O0?ooo`005@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0=h0oooo000E0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool0gP3oool001D0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`3M0?ooo`005@3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo0=`0oooo000E0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0f`3o
ool001D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3K0?ooo`005@3oool20000
02`0oooo00<000000?ooo`3oool0fP3oool001D0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`3I0?ooo`005@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0=P0oooo
000E0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0f03oool001D0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`3G0?ooo`005@3oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo0=H0oooo00020?ooo`800000103oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool0e@3oool000050?ooo`000000oooo0?ooo`00
0000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool0e03oool000050?ooo`000000oooo0?ooo`0000002P3oool00`000000oooo0?ooo`030?oo
o`<00000<@3oool00`000000oooo0?ooo`3D0?ooo`0000D0oooo0000003oool0oooo0000000;0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`3C0?oo
o`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`3B0?ooo`000P3oool2000000X0oooo0P0000050?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0d@3oool001D0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`3@0?ooo`005@3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo0<l0oooo000E0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0cP3o
ool001D0oooo00<000000?ooo`3oool0>03oool200000<h0oooo000E0?ooo`800000>`3oool00`00
0000oooo0?ooo`3;0?ooo`005@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0<X0
oooo000E0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0b@3oool001D0oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`380?ooo`005@3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo0<L0oooo000E0?ooo`030000003oool0oooo03l0oooo0P0000370?oo
o`005@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0<@0oooo000E0?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool0``3oool001D0oooo0P0000140?ooo`800000``3o
ool001D0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`300?ooo`005@3oool00`00
0000oooo0?ooo`160?ooo`030000003oool0oooo0;l0oooo000E0?ooo`030000003oool0oooo04L0
oooo0P00002o0?ooo`005@3oool00`000000oooo0?ooo`190?ooo`800000_@3oool001D0oooo00<0
00000?ooo`3oool0B`3oool200000;/0oooo000E0?ooo`030000003oool0oooo04d0oooo0P00002i
0?ooo`005@3oool00`000000oooo0?ooo`1?0?ooo`800000]`3oool001D0oooo0P00001B0?ooo`80
0000]@3oool001D0oooo00<000000?ooo`3oool0D`3oool300000;80oooo000E0?ooo`030000003o
ool0oooo05H0oooo0P00002`0?ooo`005@3oool00`000000oooo0?ooo`1H0?ooo`<00000[@3oool0
01D0oooo00<000000?ooo`3oool0F`3oool200000:/0oooo000E0?ooo`030000003oool0oooo05d0
oooo0`00002X0?ooo`005@3oool00`000000oooo0?ooo`1P0?ooo`@00000Y03oool001D0oooo00<0
00000?ooo`3oool0I03oool400000:00oooo000E0?ooo`800000J@3oool4000009`0oooo000E0?oo
o`030000003oool0oooo06`0oooo1P00002F0?ooo`005@3oool00`000000oooo0?ooo`1b0?ooo`D0
0000T@3oool001D0oooo00<000000?ooo`3oool0M`3oool5000008`0oooo000E0?ooo`030000003o
ool0oooo07`0oooo200000240?ooo`005@3oool00`000000oooo0?ooo`240?ooo`/00000N@3oool0
0080oooo0P0000040?ooo`8000001@3oool3000000<0oooo00<000000?ooo`3oool0S`3ooolF0000
06<0oooo00001@3oool000000?ooo`3oool0000000/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`2U0?ooob000000@`3oool000050?ooo`000000oooo0?ooo`000000203oool50000
00<0oooo0`0000350?oooc`000001`3oool000050?ooo`000000oooo0?ooo`000000203oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo2@3oool000050?ooo`000000oooo
0?ooo`0000002@3oool00`000000oooo000000040?ooo`030000003oool0oooo0?l0oooo2@3oool0
0080oooo0P00000;0?ooo`800000103oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`03
0000003oool0oooo0?l0oooo2@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.16788, -0.030982, \
0.193212, 0.00249935}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[68]="]
}, Open  ]],

Cell[TextData[{
  "Here is the solution to eq14. We have to bear in mind that ",
  Cell[BoxData[
      \(xa[0] = \ x\_a\)]],
  ", ",
  Cell[BoxData[
      \(x1[0] = \ x\_1\)]],
  " and ",
  Cell[BoxData[
      \(x2[0] = \ x\_2\)]],
  " correspond to the retention in the compartment a, 1 and 2  estimated with \
eq13 for ",
  Cell[BoxData[
      \(TraditionalForm\`t\  = \ T\)]],
  ", that is ",
  Cell[BoxData[
      \(\(\(\ \)\(x\_a\)\)\)]],
  " =  ",
  StyleBox["x1a[T]", "DisplayMath"],
  ", ",
  Cell[BoxData[
      \(\(\(\ \)\(x\_1\)\)\)]],
  " =  ",
  StyleBox["x11[T]", "DisplayMath"],
  "and",
  Cell[BoxData[
      \(\(\(\ \)\(x\_2\)\)\)]],
  " =  ",
  StyleBox["x12[T]", "DisplayMath"],
  ". Also, we know that ",
  Cell[BoxData[
      \(T = d\/k\_F\)]],
  "for this reason we make the replacement ",
  Cell[BoxData[
      \(T \[Rule] d\/k\_F\)]]
}], "Caption"],

Cell[BoxData[
    \(eq2 = 
      DSolve[{\(x\_a'\)[t] == \ \(-\ k\_a\)\ x\_a[t], \(x1'\)[t] \[Equal] 
            k\_a\ x\_a[t] - \ \((k\_10 + k\_12)\)\ x1[t] + 
              k\_21\ x2[t], \(x2'\)[t] == k\_12\ x1[t] - k\_21\ x2[t], 
          x\_a[0] \[Equal] X\_a, x1[0] \[Equal] X1, 
          x2[0] \[Equal] X2}, {x\_a[t], x1[t], x2[t]}\ , \ t]; \)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \({x2a[t_, d_], x21[t_, d_], 
        x22[t_, d_]}\  = \(\({x\_a[t], x1[t], x2[t]} /. 
            eq2[\([\)\(1\)\(]\)]\)\  /. {X\_a \[Rule] \ x1a[T], 
            X1 \[Rule] \ x11[T], X2 \[Rule] \ x12[T]}\) /. 
        T \[Rule] \ d\/k\_F\ ; \)], "Input",
  CellLabel->"In[70]:="],

Cell[TextData[{
  "Now we will build a compound function that represent the retention for \
both intervals: one for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(0 < t \[LessEqual] T\)\)\)]],
  " where the input is constant and the other for ",
  Cell[BoxData[
      \(TraditionalForm\`t\  > T\)]],
  " when there isn't any input. We apply ",
  StyleBox["If", "DisplayMath"],
  " whose syntax is ",
  StyleBox["If[", "MR"],
  StyleBox["condition", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["A", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["B", "TI"],
  StyleBox["]", "MR"],
  " gives ",
  StyleBox["A", "TI"],
  " if ",
  StyleBox["condition", "TI"],
  " evaluates to ",
  StyleBox["True", "MR"],
  ", and ",
  StyleBox["B", "TI"],
  " if it evaluates to ",
  StyleBox["False", "MR"],
  ". In our case A correspond to the solutions for the first interval given \
by eq13 (",
  StyleBox["condition", "TI"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`t \[LessEqual] T\)]],
  "), and B the solutions for the second interval given by eq14 (",
  StyleBox["condition", "TI"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`t > T\)]],
  ")."
}], "Text"],

Cell[TextData[{
  StyleBox["xa[t, d], x1[t,d]", "DisplayMath"],
  "  and ",
  StyleBox["x2[t,d]", "DisplayMath"],
  ", represent the retentions in compartment a, 1 and 2. We live d as \
function variable better than T because T is a function of d.  "
}], "Caption"],

Cell[BoxData[
    \(xa[t_, d_] := \ 
      If[\ t \[LessEqual] d\/k\_F, x1a[t], \ x2a[t - d\/k\_F, d]]\)], "Input",\

  CellLabel->"In[71]:="],

Cell[BoxData[
    \(x1[t_, d_] := \ 
      If[\ t \[LessEqual] d\/k\_F, x11[t], \ x21[t - d\/k\_F, d]]\)], "Input",\

  CellLabel->"In[72]:="],

Cell[BoxData[
    \(x2[t_, d_] := \ 
      If[\ t \[LessEqual] d\/k\_F, x12[t], \ x22[t - d\/k\_F, d]]\)], "Input",\

  CellLabel->"In[73]:="],

Cell["Here is plot the retention. We have suppose d = 10", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{xa[t, 10], x1[t, 10], x2[t, 10]}, {t, 0, 200}, 
      PlotRange \[Rule] \ All]\)], "Input",
  CellLabel->"In[74]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00476191 0.0147151 1.47151 [
[.2619 .00222 -6 -9 ]
[.2619 .00222 6 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .16187 -18 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -18 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(50)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(100)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(150)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(200)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16187 m
.03006 .16187 L
s
[(0.1)] .01131 .16187 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.3)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(0.4)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02499 .04339 L
.02605 .05964 L
.02729 .07123 L
.02846 .07784 L
.02954 .08165 L
.03053 .08392 L
.03163 .08553 L
.03279 .08659 L
.03395 .08725 L
.0352 .08768 L
.03638 .08792 L
.03746 .08805 L
.03873 .08815 L
.03944 .08819 L
.04011 .08821 L
.04132 .08824 L
.04262 .08826 L
.04327 .08827 L
.04396 .08828 L
.04519 .08828 L
.04588 .08828 L
.04652 .08829 L
.04722 .08829 L
.04797 .08829 L
.04862 .08829 L
.04933 .08829 L
.05061 .08829 L
.05186 .08829 L
.05302 .08829 L
.05414 .08829 L
.05519 .08829 L
.05634 .08829 L
.05759 .08829 L
.05882 .08829 L
.06012 .08829 L
.06123 .08829 L
.06244 .08829 L
.06315 .08829 L
.06381 .08829 L
.06453 .08829 L
.06529 .08829 L
.06657 .08829 L
.06729 .08829 L
.06797 .08829 L
.06924 .08829 L
.0704 .08829 L
.07103 .08829 L
.07173 .08829 L
.073 .08829 L
Mistroke
.07376 .08829 L
.07448 .08829 L
.07513 .08829 L
.07583 .08829 L
.0766 .08829 L
.0774 .08829 L
.07809 .08829 L
.07885 .08829 L
.07956 .08829 L
.0802 .08829 L
.08095 .08829 L
.08166 .08829 L
.08291 .08829 L
.08362 .08829 L
.08427 .08829 L
.08544 .08829 L
.08669 .08829 L
.08787 .08829 L
.08896 .08829 L
.09016 .08829 L
.09148 .08829 L
.09214 .08829 L
.09285 .08829 L
.09413 .08829 L
.09483 .08829 L
.09548 .08829 L
.09619 .08829 L
.09695 .08829 L
.09821 .08829 L
.09893 .08829 L
.09961 .08829 L
.10086 .08829 L
.10201 .08829 L
.10333 .08829 L
.10458 .08829 L
.10572 .08829 L
.10694 .08829 L
.108 .08829 L
.10916 .08829 L
.11044 .08829 L
.11114 .08829 L
.1118 .08829 L
.11422 .08829 L
.12446 .08829 L
.14288 .08829 L
.15338 .08829 L
.16331 .08829 L
.17222 .08829 L
.17466 .08829 L
.17725 .08829 L
Mistroke
.17946 .08829 L
.18071 .08829 L
.18189 .08829 L
.18314 .08829 L
.18384 .08829 L
.18447 .08829 L
.1857 .08829 L
.18686 .08829 L
.18822 .08829 L
.18946 .08829 L
.19228 .08829 L
.20215 .08829 L
.21117 .08829 L
.21336 .08829 L
.2157 .08829 L
.21705 .08829 L
.21828 .08829 L
.22068 .08829 L
.26055 .08829 L
.2989 .08829 L
.3397 .08829 L
.37898 .08829 L
.41676 .08829 L
.43612 .08829 L
.45698 .08829 L
.47664 .08829 L
.48704 .08829 L
.49275 .08829 L
.49555 .08829 L
.49678 .08829 L
.49814 .08829 L
.49944 .08829 L
.50065 .07074 L
.5013 .05731 L
.50201 .04632 L
.50331 .03307 L
.50404 .02821 L
.50472 .02486 L
.50601 .02062 L
.50674 .01905 L
.50741 .01799 L
.50818 .01709 L
.5089 .01646 L
.5101 .01577 L
.51135 .01534 L
.51243 .01511 L
.5136 .01496 L
.51487 .01486 L
.51558 .01482 L
.51623 .0148 L
Mistroke
.51749 .01476 L
.51868 .01474 L
.51978 .01473 L
.52099 .01473 L
.52226 .01472 L
.52344 .01472 L
.52455 .01472 L
.52556 .01472 L
.52673 .01472 L
.52784 .01472 L
.52903 .01472 L
.5303 .01472 L
.5315 .01472 L
.53259 .01472 L
.53388 .01472 L
.5346 .01472 L
.53526 .01472 L
.53649 .01472 L
.53778 .01472 L
.539 .01472 L
.53969 .01472 L
.54033 .01472 L
.54149 .01472 L
.54274 .01472 L
.54384 .01472 L
.54488 .01472 L
.54602 .01472 L
.54725 .01472 L
.54849 .01472 L
.54918 .01472 L
.54983 .01472 L
.55115 .01472 L
.55188 .01472 L
.55255 .01472 L
.55375 .01472 L
.55505 .01472 L
.55628 .01472 L
.55741 .01472 L
.55847 .01472 L
.5596 .01472 L
.56067 .01472 L
.56165 .01472 L
.56279 .01472 L
.56404 .01472 L
.56522 .01472 L
.56631 .01472 L
.56755 .01472 L
.56871 .01472 L
.56975 .01472 L
.57088 .01472 L
Mistroke
.57211 .01472 L
.57341 .01472 L
.57452 .01472 L
.57574 .01472 L
.57705 .01472 L
.57826 .01472 L
.57889 .01472 L
.57959 .01472 L
.58031 .01472 L
.581 .01472 L
.58224 .01472 L
.58339 .01472 L
.58465 .01472 L
.58597 .01472 L
.58708 .01472 L
.58827 .01472 L
.5894 .01472 L
.59042 .01472 L
.59162 .01472 L
.59292 .01472 L
.59415 .01472 L
.59528 .01472 L
.59649 .01472 L
.59779 .01472 L
.59901 .01472 L
.60013 .01472 L
.60143 .01472 L
.60217 .01472 L
.60286 .01472 L
.60411 .01472 L
.60475 .01472 L
.60545 .01472 L
.60613 .01472 L
.60684 .01472 L
.60812 .01472 L
.60883 .01472 L
.60949 .01472 L
.61022 .01472 L
.611 .01472 L
.61167 .01472 L
.6124 .01472 L
.61309 .01472 L
.61372 .01472 L
.61493 .01472 L
.61621 .01472 L
.61741 .01472 L
.61873 .01472 L
.61997 .01472 L
.62112 .01472 L
.62227 .01472 L
Mistroke
.6233 .01472 L
.6245 .01472 L
.62562 .01472 L
.62685 .01472 L
.62815 .01472 L
.62927 .01472 L
.63049 .01472 L
.6318 .01472 L
.63254 .01472 L
.63321 .01472 L
.63451 .01472 L
.63575 .01472 L
.6368 .01472 L
.63796 .01472 L
.63917 .01472 L
.6403 .01472 L
.64136 .01472 L
.64233 .01472 L
.64339 .01472 L
.64451 .01472 L
.64565 .01472 L
.64687 .01472 L
.64802 .01472 L
.64907 .01472 L
.6503 .01472 L
.65099 .01472 L
.65163 .01472 L
.65281 .01472 L
.65405 .01472 L
.65526 .01472 L
.65658 .01472 L
.65783 .01472 L
.65898 .01472 L
.66013 .01472 L
.66117 .01472 L
.66236 .01472 L
.66349 .01472 L
.66473 .01472 L
.66603 .01472 L
.66714 .01472 L
.66836 .01472 L
.66968 .01472 L
.67042 .01472 L
.67109 .01472 L
.67239 .01472 L
.67363 .01472 L
.67468 .01472 L
.67584 .01472 L
.67706 .01472 L
.67819 .01472 L
Mistroke
.67925 .01472 L
.68022 .01472 L
.68134 .01472 L
.68241 .01472 L
.68355 .01472 L
.68477 .01472 L
.68592 .01472 L
.68697 .01472 L
.6882 .01472 L
.68889 .01472 L
.68953 .01472 L
.6907 .01472 L
.69194 .01472 L
.69316 .01472 L
.69385 .01472 L
.69448 .01472 L
.69565 .01472 L
.69689 .01472 L
.698 .01472 L
.69904 .01472 L
.70018 .01472 L
.70141 .01472 L
.70264 .01472 L
.70334 .01472 L
.70399 .01472 L
.7053 .01472 L
.70604 .01472 L
.7067 .01472 L
.7079 .01472 L
.7092 .01472 L
.71043 .01472 L
.71156 .01472 L
.71262 .01472 L
.71375 .01472 L
.71482 .01472 L
.7158 .01472 L
.71694 .01472 L
.71819 .01472 L
.71937 .01472 L
.72046 .01472 L
.7217 .01472 L
.72286 .01472 L
.7239 .01472 L
.72503 .01472 L
.72626 .01472 L
.72756 .01472 L
.72867 .01472 L
.72989 .01472 L
.7312 .01472 L
.73241 .01472 L
Mistroke
.73304 .01472 L
.73373 .01472 L
.73446 .01472 L
.73514 .01472 L
.73639 .01472 L
.73753 .01472 L
.73879 .01472 L
.74011 .01472 L
.74122 .01472 L
.74242 .01472 L
.74354 .01472 L
.74456 .01472 L
.74576 .01472 L
.74706 .01472 L
.74829 .01472 L
.74942 .01472 L
.75063 .01472 L
.75192 .01472 L
.75315 .01472 L
.75426 .01472 L
.75557 .01472 L
.75631 .01472 L
.757 .01472 L
.75825 .01472 L
.75895 .01472 L
.75959 .01472 L
.76026 .01472 L
.76098 .01472 L
.76225 .01472 L
.76296 .01472 L
.76363 .01472 L
.76435 .01472 L
.76513 .01472 L
.7658 .01472 L
.76653 .01472 L
.76722 .01472 L
.76786 .01472 L
.76906 .01472 L
.77034 .01472 L
.77155 .01472 L
.77286 .01472 L
.7741 .01472 L
.77526 .01472 L
.7764 .01472 L
.77743 .01472 L
.77863 .01472 L
.77975 .01472 L
.78098 .01472 L
.78228 .01472 L
.78339 .01472 L
Mistroke
.78461 .01472 L
.78593 .01472 L
.78666 .01472 L
.78733 .01472 L
.78864 .01472 L
.78987 .01472 L
.79092 .01472 L
.79208 .01472 L
.79329 .01472 L
.79443 .01472 L
.79548 .01472 L
.79645 .01472 L
.79752 .01472 L
.79864 .01472 L
.79978 .01472 L
.801 .01472 L
.80215 .01472 L
.80319 .01472 L
.80442 .01472 L
.80511 .01472 L
.80575 .01472 L
.80693 .01472 L
.80817 .01472 L
.80938 .01472 L
.8107 .01472 L
.81195 .01472 L
.8131 .01472 L
.81425 .01472 L
.81528 .01472 L
.81648 .01472 L
.81761 .01472 L
.81884 .01472 L
.82015 .01472 L
.82126 .01472 L
.82248 .01472 L
.8238 .01472 L
.82453 .01472 L
.8252 .01472 L
.82651 .01472 L
.82774 .01472 L
.8288 .01472 L
.82996 .01472 L
.83117 .01472 L
.83231 .01472 L
.83336 .01472 L
.83433 .01472 L
.8354 .01472 L
.83652 .01472 L
.83766 .01472 L
.83888 .01472 L
Mistroke
.84003 .01472 L
.84108 .01472 L
.84231 .01472 L
.843 .01472 L
.84364 .01472 L
.84481 .01472 L
.84606 .01472 L
.84727 .01472 L
.84796 .01472 L
.84859 .01472 L
.84976 .01472 L
.851 .01472 L
.85211 .01472 L
.85315 .01472 L
.85429 .01472 L
.85552 .01472 L
.85675 .01472 L
.85744 .01472 L
.85809 .01472 L
.8594 .01472 L
.86014 .01472 L
.86081 .01472 L
.86201 .01472 L
.86331 .01472 L
.86453 .01472 L
.86567 .01472 L
.86672 .01472 L
.86785 .01472 L
.86892 .01472 L
.8699 .01472 L
.87104 .01472 L
.87229 .01472 L
.87347 .01472 L
.87456 .01472 L
.8758 .01472 L
.87696 .01472 L
.878 .01472 L
.87913 .01472 L
.88036 .01472 L
.88166 .01472 L
.88277 .01472 L
.88399 .01472 L
.8853 .01472 L
.8865 .01472 L
.88713 .01472 L
.88783 .01472 L
.88855 .01472 L
.88924 .01472 L
.89048 .01472 L
.89163 .01472 L
Mistroke
.89288 .01472 L
.8942 .01472 L
.89532 .01472 L
.89651 .01472 L
.89763 .01472 L
.89865 .01472 L
.89985 .01472 L
.90115 .01472 L
.90238 .01472 L
.90351 .01472 L
.90472 .01472 L
.90601 .01472 L
.90724 .01472 L
.90835 .01472 L
.90966 .01472 L
.9104 .01472 L
.91108 .01472 L
.91234 .01472 L
.91304 .01472 L
.91367 .01472 L
.91435 .01472 L
.91506 .01472 L
.91634 .01472 L
.91705 .01472 L
.91771 .01472 L
.91844 .01472 L
.91922 .01472 L
.91989 .01472 L
.92062 .01472 L
.92131 .01472 L
.92195 .01472 L
.92315 .01472 L
.92443 .01472 L
.92563 .01472 L
.92695 .01472 L
.92819 .01472 L
.92934 .01472 L
.93048 .01472 L
.93151 .01472 L
.93271 .01472 L
.93383 .01472 L
.93506 .01472 L
.93636 .01472 L
.93747 .01472 L
.93869 .01472 L
.94 .01472 L
.94074 .01472 L
.94141 .01472 L
.94272 .01472 L
.94395 .01472 L
Mistroke
.945 .01472 L
.94616 .01472 L
.94737 .01472 L
.9485 .01472 L
.94956 .01472 L
.95053 .01472 L
.95159 .01472 L
.95271 .01472 L
.95385 .01472 L
.95507 .01472 L
.95622 .01472 L
.95727 .01472 L
.9585 .01472 L
.95919 .01472 L
.95983 .01472 L
.961 .01472 L
.96225 .01472 L
.96318 .01472 L
.96406 .01472 L
.96485 .01472 L
.96572 .01472 L
.96666 .01472 L
.96765 .01472 L
.9686 .01472 L
.96945 .01472 L
.97032 .01472 L
.97112 .01472 L
.972 .01472 L
.97292 .01472 L
.97373 .01472 L
.97448 .01472 L
.97531 .01472 L
.97619 .01472 L
Mfstroke
.02381 .01472 m
.02846 .05766 L
.03279 .09399 L
.03754 .12464 L
.04262 .15192 L
.053 .19556 L
.06244 .22463 L
.07283 .24807 L
.0841 .26621 L
.09475 .27835 L
.10458 .28648 L
.11425 .29237 L
.12331 .29648 L
.13324 .29984 L
.14393 .30245 L
.15404 .30423 L
.16506 .30563 L
.17548 .30657 L
.18515 .30721 L
.19572 .30772 L
.20568 .30807 L
.21462 .3083 L
.22428 .30849 L
.23379 .30862 L
.24422 .30873 L
.25512 .30882 L
.26529 .30887 L
.27574 .30891 L
.28564 .30894 L
.29453 .30896 L
.3042 .30897 L
.3136 .30898 L
.32397 .30899 L
.33481 .309 L
.34498 .30901 L
.35481 .30901 L
.36516 .30901 L
.374 .30901 L
.38367 .30901 L
.39394 .30901 L
.40328 .30902 L
.41405 .30902 L
.42423 .30902 L
.43395 .30902 L
.44424 .30902 L
.45303 .30902 L
.46269 .30902 L
.47286 .30902 L
.48214 .30902 L
.48727 .30902 L
Mistroke
.49286 .30902 L
.49542 .30902 L
.49682 .30902 L
.49814 .30902 L
.49937 .30902 L
.50007 .30899 L
.50071 .3064 L
.50184 .29614 L
.50303 .28304 L
.50792 .23762 L
.51254 .2062 L
.51786 .17655 L
.52271 .15372 L
.53144 .12046 L
.54106 .09294 L
.55074 .07247 L
.56101 .05658 L
.57052 .04579 L
.57944 .03821 L
.5893 .03197 L
.59966 .02718 L
.60851 .02416 L
.61818 .02169 L
.62848 .01977 L
.63783 .01849 L
.64862 .0174 L
.65879 .01667 L
.66854 .01616 L
.67884 .01576 L
.68764 .01551 L
.69731 .0153 L
.7075 .01514 L
.7168 .01503 L
.72753 .01494 L
.7377 .01488 L
.74734 .01484 L
.75759 .0148 L
.76634 .01478 L
.776 .01476 L
.78608 .01475 L
.79532 .01474 L
.80547 .01473 L
.81617 .01473 L
.8257 .01473 L
.83589 .01472 L
.8455 .01472 L
.85425 .01472 L
.86421 .01472 L
.87341 .01472 L
.8835 .01472 L
Mistroke
.8942 .01472 L
.90362 .01472 L
.91375 .01472 L
.92331 .01472 L
.93205 .01472 L
.94191 .01472 L
.95105 .01472 L
.96109 .01472 L
.97178 .01472 L
.97619 .01472 L
Mfstroke
.02381 .01472 m
.04262 .23411 L
.0522 .32982 L
.06244 .40494 L
.07286 .46016 L
.08255 .49768 L
.09409 .52972 L
.10458 .55034 L
.11454 .56454 L
.12373 .57424 L
.13381 .58212 L
.14451 .58816 L
.15392 .59203 L
.16404 .5951 L
.1736 .59723 L
.18234 .59869 L
.19219 .59992 L
.20133 .60076 L
.21136 .60145 L
.22205 .60198 L
.23234 .60235 L
.24346 .60264 L
.25397 .60283 L
.26364 .60296 L
.27337 .60305 L
.28246 .60312 L
.29243 .60317 L
.30312 .60321 L
.3133 .60324 L
.32436 .60327 L
.33481 .60328 L
.34448 .60329 L
.35411 .6033 L
.36315 .6033 L
.37306 .60331 L
.38375 .60331 L
.39332 .60331 L
.40379 .60331 L
.41472 .60332 L
.42489 .60332 L
.43541 .60332 L
.44535 .60332 L
.45427 .60332 L
.46394 .60332 L
.4734 .60332 L
.48381 .60332 L
.48905 .60332 L
.49468 .60332 L
.49741 .60332 L
.49875 .60332 L
Mistroke
.5 .60332 L
.50112 .60238 L
.50232 .59724 L
.50301 .59216 L
.50365 .58617 L
.50485 .57249 L
.51375 .44705 L
.52327 .33578 L
.53372 .24615 L
.54346 .18527 L
.55391 .13762 L
.56343 .10592 L
.57427 .07967 L
.58451 .06183 L
.59419 .0495 L
.60446 .03993 L
.61323 .03387 L
.62289 .02887 L
.63301 .02502 L
.64228 .02242 L
.65245 .02032 L
.66315 .01872 L
.67272 .01768 L
.68293 .01687 L
.69257 .01631 L
.70131 .01593 L
.71132 .0156 L
.72053 .01538 L
.73065 .0152 L
.74134 .01506 L
.75081 .01497 L
.76096 .0149 L
.77054 .01485 L
.77928 .01482 L
.78918 .01479 L
.79835 .01477 L
.8084 .01476 L
.8191 .01475 L
.82845 .01474 L
.83854 .01473 L
.84807 .01473 L
.85682 .01472 L
.8666 .01472 L
.87572 .01472 L
.88572 .01472 L
.89641 .01472 L
.90663 .01472 L
.91773 .01472 L
.92821 .01472 L
.93787 .01472 L
Mistroke
.94729 .01472 L
.95611 .01472 L
.96579 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[74]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00D@3oool2000000@0oooo0P00000d0?ooo`D000000P3oool2000000@0oooo0P00000a0?oo
o`D000000P3oool2000000@0oooo0P00000b0?ooo`@000000`3oool2000000@0oooo0P0000030?oo
o`00D03oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
<03oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`00D`3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo03<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool00540oooo0P0000030?ooo`040000003oool0
oooo000003D0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`020?ooo`8000000`3oool010000000
oooo0?ooo`00000c0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`4000000@3oool10?ooo`00D@3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000003D0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000<@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool00540oooo0`0000030?ooo`800000=@3o
ool2000000@0oooo0P0000040?ooo`800000<P3oool2000000@0oooo0`0000030?ooo`800000<`3o
ool2000000@0oooo0P0000040?ooo`8000000`3oool00?l0oooo8@3oool00?l0oooo8@3oool001D0
oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo
000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`003P3ooooo0000010000000`3oool001D0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0000000:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool600000003
0?ooo`000000000000<000001P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`005@3oool00`000000oooo
0?ooo`1n0?ooo`030000003oool0oooo01T0oooo1@0000000`3oool000000000000400000680oooo
000E0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool05P3oool3000000@0oooo0P00
001X0?ooo`005@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo01@0oooo0P000006
0?ooo`030000003oool0oooo06P0oooo000E0?ooo`030000003oool0oooo07h0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`040?ooo`800000J`3oool001D0oooo0P00001o0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool00`3oool2000006d0oooo000E0?ooo`800000
O`3oool00`000000oooo0?ooo`0@0?ooo`8000001@3oool00`000000oooo0?ooo`1]0?ooo`005@3o
ool2000007l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo06d0oooo000E0?ooo`800000O`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0KP3oool001D0oooo0P00001o0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1_0?ooo`005@3oool2000007l0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0700
oooo000E0?ooo`800000O`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0L@3oool001D0oooo0P00001n0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`1b0?ooo`005@3oool2000007h0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0780oooo000E0?oo
o`800000OP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0L`3oool001D0oooo0P00001n0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1c0?ooo`005@3oool3000007d0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07@0oooo000E0?ooo`<00000O@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0M03o
ool001D0oooo00<000000?ooo`000000OP00000;0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0M@3oool001D0oooo00<000000?ooo`000000R03oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo07D0oooo000E0?ooo`030000003oool0000008P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`1f0?ooo`005@3oool00`000000oooo000000280?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0MP3oool001D0oooo0`0000270?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0M`3oool001D0oooo00@000000?ooo`0000000000QP3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07L0oooo000E0?ooo`040000003oool0
0000000008H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1g0?ooo`005@3oool0
10000000oooo0000000000260?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0M`3o
ool001D0oooo00@000000?ooo`0000000000Q@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo07P0oooo000E0?ooo`050000003oool000000?ooo`000000Q03oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo07P0oooo000E0?ooo`050000003oool000000?ooo`000000Q03o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07P0oooo000E0?ooo`030000003oool0
oooo00800000P`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07P0oooo000E0?oo
o`80000000<0oooo000000000000P`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
07T0oooo000E0?ooo`030000003oool0oooo00800000P`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo07T0oooo000E0?ooo`030000003oool0oooo00800000PP3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo07T0oooo000E0?ooo`060000003oool0oooo0000003oool0
0000P@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07T0oooo000E0?ooo`060000
003oool0oooo0000003oool00000P@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
07T0oooo000E0?ooo`060000003oool0oooo0000003oool00000P03oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo07X0oooo00020?ooo`800000103oool2000000<0oooo1@0000030?oo
o`060000003oool0oooo0000003oool00000P03oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo07X0oooo00001@3oool000000?ooo`3oool0000000X0oooo00<000000?ooo`3oool00`3o
ool01P000000oooo0?ooo`000000oooo00000800oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1j0?ooo`0000D0oooo0000003oool0oooo0000000:0?ooo`030000003oool0oooo00<0
oooo100000020?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1j0?ooo`0000D0oooo0000003oool0oooo0000000:0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0N`3oool000050?ooo`000000oooo0?ooo`0000002P3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0O03oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo07/0oooo00020?ooo`8000002P3oool20000
00D0oooo00L000000?ooo`3oool0oooo0000003oool0000007h0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`1k0?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0N`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07/0oooo000E
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`1k0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0O03oool001D0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`1l0?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0N`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07`0oooo000E0?ooo`8000000P3oool0
1@000000oooo0?ooo`3oool0000007/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1l0?ooo`005@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0N@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07`0oooo000E0?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0O@3oool001D0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1m0?ooo`005@3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo07d0oooo000E0?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0O@3o
ool001D0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`1m0?ooo`005@3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`000000N@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo07h0oooo000E0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo07H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1n0?ooo`005@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0MP3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo07h0oooo000E0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0OP3oool001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1n0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07h0oooo000E
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1c
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0O`3oool001D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1o0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo07l0oooo000E0?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0780oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1o0?ooo`005@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0L@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07l0oooo000E0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0O`3oool001D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`200?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0800
oooo000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`1]0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0P03oool001D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06d0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`200?ooo`005@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0800oooo000E0?ooo`800000103oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo06/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`200?oo
o`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo0P00001[0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0P03oool001D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`200?ooo`005@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00d0oooo0P00001X0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0P@3o
ool001D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`800000IP3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0840oooo000E0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool04@3oool400000680oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`210?ooo`000P3oool2000000@0oooo0P0000030?ooo`@00000103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo0`00001N0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0P@3oool000050?ooo`000000oooo0?ooo`000000203oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0603oool;000005<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`210?ooo`0000D0oooo0000003oool0
oooo000000090?ooo`030000003oool0oooo00@0oooo0`0000040?ooo`030000003oool0oooo02<0
ooooE00000060?ooo`030000003oool0oooo0840oooo00001@3oool000000?ooo`3oool0000000X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07d0
oooo00<000000?ooo`3oool0P@3oool000050?ooo`000000oooo0?ooo`000000203oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0O03oool00`00
0000oooo0?ooo`210?ooo`000P3oool2000000X0oooo0P0000050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`220?ooo`005@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0PP3oool001D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0880oooo000E
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`22
0?ooo`005@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07/0oooo00<000000?oo
o`3oool0PP3oool001D0oooo0P0000060?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3o
ool0PP3oool001D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1k0?ooo`030000
003oool0oooo0880oooo000E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0N`3o
ool00`000000oooo0?ooo`220?ooo`005@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo07/0oooo00<000000?ooo`3oool0PP3oool001D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`1j0?ooo`030000003oool0oooo0880oooo000E0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`220?ooo`005@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0PP3oool001D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo08<0oooo000E
0?ooo`8000001`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo08<0oooo000E0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`230?oo
o`005@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool0P`3oool001D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo08<0oooo000E0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0N@3o
ool00`000000oooo0?ooo`230?ooo`005@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool0P`3oool001D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo08<0oooo000E0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`230?ooo`005@3oool2000000P0oooo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`230?ooo`005@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0P`3oool001D0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo08<0oooo000E0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`230?oo
o`005@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool0P`3oool001D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1g0?ooo`030000
003oool0oooo08<0oooo000E0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0MP3o
ool00`000000oooo0?ooo`240?ooo`005@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo07H0oooo00<000000?ooo`3oool0Q03oool001D0oooo0P0000090?ooo`030000003oool0oooo
07H0oooo00<000000?ooo`3oool0Q03oool001D0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`1f0?ooo`030000003oool0oooo08@0oooo000E0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`240?ooo`005@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0Q03oool001D0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo08@0oooo000E0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`240?oo
o`000P3oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo07D0oooo00<000000?ooo`3oool0Q03oool000050?ooo`000000oooo0?ooo`00
0000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`240?ooo`0000D0oooo0000003oool0oooo0000000:0?oo
o`030000003oool0oooo00<0oooo0`00000:0?ooo`030000003oool0oooo07@0oooo00<000000?oo
o`3oool0Q03oool000050?ooo`000000oooo0?ooo`0000002`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`240?oo
o`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo08@0oooo00020?oo
o`8000002P3oool2000000D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1b0?oo
o`030000003oool0oooo08D0oooo000E0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`250?ooo`005@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0780oooo00<000000?ooo`3oool0Q@3oool001D0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo08D0oooo000E0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`250?ooo`005@3oool20000
00d0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`250?ooo`005@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0Q@3oool001D0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo08D0oooo
000E0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?oo
o`250?ooo`005@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0700oooo00<00000
0?ooo`3oool0Q@3oool001D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1_0?oo
o`030000003oool0oooo08D0oooo000E0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0KP3oool00`000000oooo0?ooo`260?ooo`005@3oool2000000l0oooo00<000000?ooo`3oool0
KP3oool00`000000oooo0?ooo`260?ooo`005@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool0QP3oool001D0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`1]0?ooo`030000003oool0oooo08H0oooo000E0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`260?ooo`005@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0QP3oool001D0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo08H0oooo
000E0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?oo
o`260?ooo`005@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo06/0oooo00<00000
0?ooo`3oool0QP3oool001D0oooo0P00000C0?ooo`030000003oool0oooo06X0oooo00<000000?oo
o`3oool0QP3oool001D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1Z0?ooo`03
0000003oool0oooo08H0oooo000E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
J@3oool00`000000oooo0?ooo`260?ooo`005@3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo06P0oooo00<000000?ooo`3oool0Q`3oool001D0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`1W0?ooo`030000003oool0oooo08L0oooo000E0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`270?ooo`005@3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0Q`3oool001D0oooo
00<000000?ooo`3oool05P3oool2000006H0oooo00<000000?ooo`3oool0Q`3oool001D0oooo0P00
000I0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0Q`3oool001D0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo08L0oooo000E0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`270?oo
o`005@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool0Q`3oool001D0oooo00<000000?ooo`3oool0703oool3000005l0oooo00<000000?ooo`3oool0
Q`3oool001D0oooo00<000000?ooo`3oool07`3oool3000005`0oooo00<000000?ooo`3oool0Q`3o
ool00080oooo0P0000040?ooo`8000001@3oool3000000<0oooo00<000000?ooo`3oool08P3oool2
000005X0oooo00<000000?ooo`3oool0Q`3oool000050?ooo`000000oooo0?ooo`0000002`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo02@0oooo2000001B0?ooo`030000003oool0
oooo08L0oooo00001@3oool000000?ooo`3oool0000000P0oooo1@0000030?ooo`<00000;03ooomB
000008X0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`3o0?ooo`T0oooo00001@3oool000000?ooo`3oool0000000T0oooo00<0
00000?ooo`000000103oool00`000000oooo0?ooo`3o0?ooo`T0oooo00020?ooo`8000002`3oool2
000000@0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?oo
o`T0oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-16.6539, -0.0330359, \
0.779333, 0.00252198}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[74]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[xa, x1, x2, model1, eq1, \ eq2\ ]; \)], "Input",
  CellLabel->"In[75]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["One input and two outputs ", "SubsubsectionIcon"],

Cell["\<\
The lead is one of typical pollutant in some industrial environment. It can \
be intaken to the human body specially through inhalation. The intaken lead \
goes to blood, to the tissues and to the bone. Part of it is eliminated by \
urine excretion. We can represente the temporal evolution in the human body \
using a system of tree compartment: (1) blood, (2) tissues, (3) bones. The \
flow diagram is shown in the figure\
\>", "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .375 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0833333 0.119048 0.1875 0.119048 [
[ 0 0 0 0 ]
[ 1 .375 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .375 L
0 .375 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
/MAarrowhead2 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125  moveto 0 0 lineto 
-0.05 -0.0125  lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.08333 .1875 .05952 0 365.73 arc
s
gsave
.08333 .1875 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.14286 .21131 m
.44048 .21131 L
s
% Start of user PostScript
0.5 0.2 3. 0.2 MAarrowhead1
% End of user PostScript
gsave
.29167 .23512 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.44048 .16369 m
.14286 .16369 L
s
% Start of user PostScript
3. -0.2 0.5 -0.2 MAarrowhead1
% End of user PostScript
gsave
.29167 .13988 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.5 .1875 .05952 0 365.73 arc
s
gsave
.5 .1875 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .36607 m
.5 .24702 L
s
% Start of user PostScript
3.5 1.5 3.5 0.5 MAarrowhead2
% End of user PostScript
gsave
.45238 .30655 -77.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.875 12.750 moveto
(H) show
79.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
85.875 12.750 moveto
(L) show
91.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12798 m
.5 .00893 L
s
% Start of user PostScript
3.5 -0.5 3.5 -1.5 MAarrowhead1
% End of user PostScript
gsave
.46429 .06845 -70.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.91667 .1875 .05952 0 365.73 arc
s
gsave
.91667 .1875 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.55952 .21131 m
.85714 .21131 L
s
% Start of user PostScript
4. 0.2 6.5 0.2 MAarrowhead1
% End of user PostScript
gsave
.70833 .23512 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.85714 .16369 m
.55952 .16369 L
s
% Start of user PostScript
6.5 -0.2 4. -0.2 MAarrowhead1
% End of user PostScript
gsave
.70833 .13988 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(31) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .12798 m
.08333 .00893 L
s
% Start of user PostScript
0 -0.5 0 -1.5 MAarrowhead1
% End of user PostScript
gsave
.04762 .06845 -70.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 108},
  ImageMargins->{{191.75, 0}, {0, 6}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000Qa000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo000NOol00`00Oomoo`2BOol00`00Oomoo`2bOol001ioo`03001oogoo
099oo`03001oogoo0;9oo`007Woo0P00Tgoo00<007ooOol0/Woo000MOol3002BOol3002cOol001eo
o`<0099oo`<00;=oo`007Goo0`00TWoo0`00/goo000MOol4002AOol3002cOol001aoo`D0091oo`D0
0;9oo`0077oo1@00T7oo1@00/Woo000LOol6002?Ool5002bOol001aoo`H008moo`D00;9oo`0077oo
1P00Sgoo1@00/Woo000KOol7002>Ool7002aOol001]oo`P008eoo`L00;5oo`006goo2000SGoo1`00
/Goo000KOol8002=Ool7002aOol001Yoo`T008aoo`T00;1oo`006Woo2P00Rgoo2@00/7oo000JOol:
002;Ool9002`Ool001ioo`03001oogoo099oo`03001oogoo0;9oo`007Woo00<007ooOol0TWoo00<0
07ooOol0/Woo000NOol00`00Oomoo`2BOol00`00Oomoo`2bOol001ioo`03001oogoo099oo`03001o
ogoo0;9oo`007Woo00<007ooOol0TWoo00<007ooOol0/Woo000NOol00`00Oomoo`2BOol00`00Oomo
o`2bOol0011oo`<000=oo`03001oogoo00Eoo`03001oogoo08=oo`D0009oo`03001oogoo00Eoo`03
001oogoo0;9oo`0047oo00<007ooOol00Woo00<007oo00001Woo00<007ooOol0QGoo00L007ooOomo
o`00Ool00006Ool00`00Oomoo`2bOol000Uoo`80009oo`<00003Ool007oo009oo`03001oo`0000Io
o`03001oogoo07eoo`80009oo`<00003Ool007oo009oo`03001oo`0000Ioo`03001oogoo0;9oo`00
2Woo00@007ooOol000=oo`07001oogooOol007oo00001Woo00<007ooOol0OWoo00@007ooOol000=o
o`07001oogooOol007oo00001Woo00<007ooOol0/Woo000:Ool00`00Ool00003Ool00`00Ool00002
Ool00`00Ool00006Ool00`00Oomoo`1nOol00`00Ool00004Ool01`00Oomoogoo001oo`0000Ioo`03
001oogoo0;9oo`002Woo0`0017oo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0OWoo0`00
0goo0P0017oo00<007ooOol01Goo00<007ooOol0/Woo000:Ool01000Oomoo`0047oo00<007ooOol0
OWoo00@007ooOol0011oo`03001oogoo0;9oo`002Woo00<007oo00000`003Woo00<007ooOol0OWoo
00<007oo00000`003Woo00<007ooOol0/Woo000:Ool00`00Oomoo`0AOol00`00Oomoo`1nOol00`00
Oomoo`0AOol00`00Oomoo`2bOol000Uoo`8001=oo`03001oogoo07eoo`8001=oo`03001oogoo0;9o
o`007Woo00<007ooOol0TWoo00<007ooOol0/Woo000NOol00`00Oomoo`2BOol00`00Oomoo`2bOol0
01ioo`03001oogoo099oo`03001oogoo0;9oo`007Woo00<007ooOol0TWoo00<007ooOol0/Woo000N
Ool00`00Oomoo`2BOol00`00Oomoo`2bOol001ioo`03001oogoo099oo`03001oogoo0;9oo`007Woo
00<007ooOol0TWoo00<007ooOol0/Woo000KOol60016Ool5000017oo00000000@7oo1P00AWoo0P00
0Woo1@00@7oo1P007Goo000GOol40006Ool40014Ool01@00Oomoogoo0000?Woo10001Woo1000A7oo
00D007ooOomoo`0003ioo`@000Ioo`@001Uoo`005Goo0P003Woo0P00>Goo0P000Woo0`000Woo00<0
07ooOol00Woo00<007ooOol0>Goo0P003Woo0P00>Goo0P000Woo0`0000=oo`00Ool00goo00<007oo
Ool0>Woo0P003Woo0P005goo000COol2000BOol2000hOol01000Oomoo`0017oo00<007ooOol00Woo
00<007ooOol0=goo0P004Woo0P00>7oo00@007ooOol000Aoo`05001oogooOol0000jOol2000BOol2
000EOol0019oo`03001oogoo01Aoo`8003Ioo`03001oo`0000Eoo`07001oogooOol007oo0000=goo
00<007ooOol057oo0P00=Woo00<007oo00000goo00<007oo00000goo00<007ooOol0=Woo0P005Woo
00<007ooOol04Woo000AOol00`00Oomoo`0GOol00`00Oomoo`0cOol30004Ool20004Ool00`00Oomo
o`0eOol00`00Oomoo`0GOol00`00Oomoo`0cOol30004Ool01000Oomoogoo0P00=goo00<007ooOol0
5goo0P004Woo000@Ool00`00Oomoo`0IOol2000cOol01000Oomoo`00@7oo00<007ooOol06Goo0P00
<goo00@007ooOol0041oo`03001oogoo01Uoo`80011oo`003goo00<007ooOol077oo00<007ooOol0
<7oo00<007oo00000`00?7oo0P007Woo00<007ooOol0<7oo00<007oo00000`00?7oo0P007Woo00<0
07ooOol03Goo000>Ool00`00Oomoo`0MOol00`00Oomoo`0`Ool00`00Oomoo`0nOol00`00Oomoo`0N
Ool00`00Oomoo`0`Ool00`00Oomoo`0nOol00`00Oomoo`0NOol00`00Oomoo`0=Ool000eoo`03001o
ogoo01moo`03001oogoo015oo`<001Yoo`80041oo`03001oogoo01moo`03001oogoo015oo`<001Yo
o`80041oo`03001oogoo01moo`03001oogoo00aoo`0037oo00<007ooOol08Goo00<007ooOol037oo
1`00Fgoo00<007ooOol08Goo00<007ooOol037oo1`00Fgoo00<007ooOol087oo00<007ooOol037oo
000;Ool00`00Oomoo`0SOol00`00Oomoo`06Ool<001JOol00`00Oomoo`0SOol00`00Oomoo`06Ool<
001JOol00`00Oomoo`0ROol2000<Ool000]oo`03001oogoo02Aoo`04001oogooOol@001JOol00`00
Oomoo`0TOol01000Oomoogoo4000FWoo00<007ooOol08goo00<007ooOol02Woo000:Ool00`00Oomo
o`0UOom^000WOom^000VOol00`00Oomoo`0:Ool000Yoo`03001oogoo02Eoo`04001oogooOol@001I
Ool00`00Oomoo`0UOol01000Oomoogoo4000FGoo00<007ooOol09Goo00<007ooOol02Goo000:Ool0
0`00Oomoo`0UOol00`00Oomoo`05Ool<001HOol00`00Oomoo`0VOol00`00Oomoo`05Ool<001HOol0
0`00Oomoo`0VOol00`00Oomoo`09Ool000Yoo`03001oogoo02Ioo`03001oogoo00Uoo`L005Qoo`03
001oogoo02Moo`03001oogoo00Uoo`L005Qoo`03001oogoo02Moo`03001oogoo00Qoo`002Goo00<0
07ooOol09goo00<007ooOol03Goo0`00F7oo00<007ooOol09goo00<007ooOol03Goo0`00F7oo00<0
07ooOol09goo00<007ooOol027oo0009Ool00`00Oomoo`0WOol00`00Oomoo`1XOol00`00Oomoo`0W
Ool00`00Oomoo`1XOol00`00Oomoo`0WOol00`00Oomoo`08Ool000Uoo`03001oogoo00moo`D001=o
o`03001oogoo06Qoo`03001oogoo011oo`D0019oo`03001oogoo06Qoo`03001oogoo011oo`<001Ao
o`03001oogoo00Qoo`002Goo00<007ooOol03goo00D007ooOomoo`0001=oo`03001oogoo06Qoo`03
001oogoo019oo`03001oogoo019oo`03001oogoo06Qoo`03001oogoo00moo`05001oogooOol0000C
Ool00`00Oomoo`08Ool000Uoo`03001oogoo011oo`03001oogoo01Aoo`03001oogoo06Qoo`03001o
ogoo019oo`03001oogoo019oo`03001oogoo06Qoo`03001oogoo01=oo`03001oogoo015oo`03001o
ogoo00Qoo`002Goo00<007ooOol04Goo00<007ooOol04goo00<007ooOol0J7oo00<007ooOol04Woo
00<007ooOol04Woo00<007ooOol0J7oo00<007ooOol04goo00<007ooOol04Goo00<007ooOol027oo
0009Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`1XOol00`00Oomoo`0BOol00`00Oomo
o`0BOol00`00Oomoo`1XOol00`00Oomoo`0AOol2000DOol00`00Oomoo`08Ool000Uoo`03001oogoo
01=oo`03001oogoo015oo`03001oogoo06Qoo`03001oogoo019oo`03001oogoo019oo`03001oogoo
06Qoo`03001oogoo01=oo`03001oogoo015oo`03001oogoo00Qoo`002Goo00<007ooOol03goo00D0
07ooOomoo`0001=oo`03001oogoo06Qoo`03001oogoo011oo`<001Aoo`03001oogoo06Qoo`03001o
ogoo00moo`05001oogooOol0000COol00`00Oomoo`08Ool000Yoo`03001oogoo00moo`<001Aoo`03
001oogoo05Ioo`<000moo`03001oogoo019oo`03001oogoo019oo`03001oogoo05Ioo`<000moo`03
001oogoo011oo`<001Aoo`03001oogoo00Qoo`002Woo00<007ooOol09Goo00<007ooOol0Egoo1`00
2goo00<007ooOol09Woo00<007ooOol0Egoo1`002goo00<007ooOol09Woo00<007ooOol02Goo000:
Ool00`00Oomoo`0UOol00`00Oomoo`1GOol<0007Ool00`00Oomoo`0UOol00`00Oomoo`1GOol<0007
Ool00`00Oomoo`0UOol00`00Oomoo`09Ool000Yoo`03001oogoo02Eoo`03001oogoo05Mooa0000=o
o`03001oogoo02Eoo`03001oogoo05Mooa0000=oo`03001oogoo02Aoo`03001oogoo00Yoo`002goo
00<007ooOol097ooK@0000=oo`00Ool09GooK@0000=oo`00Ool097oo00<007ooOol02Woo000;Ool0
0`00Oomoo`0SOol00`00Oomoo`1HOolA0003Ool00`00Oomoo`0SOol00`00Oomoo`1HOolA0003Ool0
0`00Oomoo`0SOol00`00Oomoo`0:Ool000aoo`03001oogoo029oo`03001oogoo05Qoo`d000Qoo`03
001oogoo029oo`03001oogoo05Qoo`d000Qoo`03001oogoo029oo`03001oogoo00Yoo`0037oo00<0
07ooOol08Goo00<007ooOol0FGoo2P002goo00<007ooOol08Goo00<007ooOol0FGoo2P002goo00<0
07ooOol087oo0P003Goo000=Ool00`00Oomoo`0OOol00`00Oomoo`1JOol6000@Ool00`00Oomoo`0O
Ool00`00Oomoo`1JOol6000@Ool00`00Oomoo`0NOol00`00Oomoo`0=Ool000ioo`03001oogoo01eo
o`03001oogoo03Moo`<00003Ool0000000<001]oo`8001Eoo`03001oogoo01eoo`03001oogoo03Eo
o`D00003Ool0000001ioo`8001Eoo`03001oogoo01eoo`03001oogoo00eoo`003goo00<007ooOol0
6goo00<007ooOol0<7oo0P000Woo0`0000=oo`00Ool017oo00<007ooOol0<Woo00<007ooOol077oo
00<007ooOol0<7oo0P000Woo0`0000=oo`00Ool017oo00<007ooOol0<Woo00<007ooOol077oo00<0
07ooOol03Woo000@Ool00`00Oomoo`0JOol00`00Oomoo`0aOol01000Oomoo`0017oo00<007ooOol0
0Woo00<007ooOol0<goo0P0077oo00<007ooOol0<Goo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo03Aoo`8001aoo`03001oogoo00ioo`004Goo00<007ooOol05goo0P00=7oo00<007oo0000
1Goo00<007ooOol00Woo00<007ooOol0=Goo00<007ooOol05goo0P00=7oo00<007oo000017oo00<0
07ooOol00goo00<007ooOol0=Goo00<007ooOol05goo0P004Goo000BOol00`00Oomoo`0EOol00`00
Oomoo`0dOol30004Ool00`00Ool00003Ool00`00Oomoo`0fOol00`00Oomoo`0EOol00`00Oomoo`0d
Ool30004Ool01`00Oomoogoo001oo`0003Moo`03001oogoo01Eoo`8001=oo`004goo00<007ooOol0
4Woo0P00=goo00@007ooOol000Aoo`04001oogooOol2000iOol00`00Oomoo`0BOol2000gOol01000
Oomoo`000Woo0P0017oo00<007ooOol0=goo0P0057oo00<007ooOol04goo000DOol2000@Ool2000i
Ool00`00Ool000030012Ool2000@Ool2000iOol00`00Ool000030012Ool2000@Ool2000FOol001Io
o`@000Qoo`@003]oo`03001oogoo04Moo`@000Qoo`@003]oo`03001oogoo04Moo`@000Moo`D001Qo
o`006Woo2000?Woo0P00CGoo2000?Woo0P00CGoo1`007Goo002cOol00`00Oomoo`2bOol00;=oo`03
001oogoo0;9oo`00/Woo0`00/goo002bOol3002cOol00;9oo`<00;=oo`00/Woo0`00/goo002aOol0
1@00Ool007oo0000/Woo002aOol01@00Ool007oo0000/Woo002aOol01@00Ool007oo0000/Woo002a
Ool01@00Ool007oo0000/Woo002aOol01@00Ool007oo0000/Woo002`Ool01000Oomoo`000Woo00<0
07ooOol0[goo002`Ool01000Oomoo`000Woo00<007ooOol0[goo002`Ool01000Oomoo`000Woo00<0
07ooOol0[goo002`Ool01000Oomoo`000Woo00<007ooOol0[goo002_Ool01@00Oomoogoo00000goo
00<007ooOol0[Woo002_Ool01@00Oomoogoo00000goo00<007ooOol0[Woo002_Ool01@00Oomoogoo
00000goo00<007ooOol0[Woo002cOol00`00Oomoo`2bOol00;=oo`03001oogoo0;9oo`00/goo00<0
07ooOol0/Woo002cOol00`00Oomoo`2bOol00;=oo`03001oogoo0;9oo`00/goo00<007ooOol0/Woo
002GOol50008Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`2bOol009Uoo`03001oogoo
00Moo`03001oogoo00Uoo`05001oogooOol0002dOol0091oo`800004Ool000000003Ool00`00Oomo
o`06Ool00`00Oomoo`03Ool30005Ool01000Oomoo`00]7oo002AOol20003Ool01000Oomoo`0027oo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`04001oogoo002dOol0095oo`03001oogoo009oo`04
001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01000Oomoo`00]7oo002AOol00`00Oomo
o`02Ool01000Ool0000027oo00<007ooOol00Woo00<007ooOol01Woo00@007ooOol00;Aoo`00TGoo
0P000goo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol01Woo00@007ooOol00;Aoo`00TGoo
00<007oo00000P0037oo00@007ooOomoo`D000Eoo`04001oogoo002dOol0095oo`03001oogoo00mo
o`05001oogooOol00007Ool01@00Oomoogoo0000]7oo002@Ool2000BOol00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`2bOol00;=oo`03001oogoo0;9oo`00/goo00<007ooOol0/Woo002cOol0
0`00Oomoo`2bOol00;=oo`03001oogoo0;9oo`00/goo00<007ooOol0/Woo002cOol00`00Oomoo`2b
Ool00;=oo`03001oogoo0;9oo`00/goo00<007ooOol0/Woo003oOomYOol00?moofUoo`00ogooJGoo
0000\
\>"],
  ImageRangeCache->{{{203.375, 490.375}, {243, 136}} -> {-6.71182, 2.42875, \
0.0294395, 0.0294395}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(model\  = 
      CompartMatrix[
        3, \ {{1, 2, k12}, {2, 1, k21}, {1, 3, k13}, {3, 1, k31}, {1, 0, \ 
            k10}, {2, 0, k20}}]\)], "Input",
  CellLabel->"In[76]:="],

Cell[BoxData[
    \({{\(-k10\) - k12 - k13, k21, k31}, {k12, \(-k20\) - k21, 0}, {k13, 
        0, \(-k31\)}}\)], "Output",
  CellLabel->"Out[76]="],

Cell[BoxData[
    \({{\(-k10\) - k12 - k13, k21, k31}, {k12, \(-k20\) - k21, 0}, {k13, 
        0, \(-k31\)}}\)], "Output",
  CellLabel->"Out[72]=",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell["It can be represented by the system of diferential equation", "Text"],

Cell[BoxData[
    \(eq1 = ShowODE[model, \ {0, 0, 0}, {b[t], 0, 0}, \ t, \ x]; \)], "Input",\

  CellLabel->"In[77]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(eq1 // TableForm\) // TraditionalForm\)], "Input",
  CellLabel->"In[78]:="],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              RowBox[{
                RowBox[{
                  SuperscriptBox[\(x\_1\), "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], 
                "\[LongEqual]", \(b(
                    t) + \((\(-k10\) - k12 - k13)\)\ \(\(x\_1\)(t)\) + 
                  k21\ \(\(x\_2\)(t)\) + k31\ \(\(x\_3\)(t)\)\)}]},
            {
              RowBox[{
                RowBox[{
                  SuperscriptBox[\(x\_2\), "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], 
                "\[LongEqual]", \(k12\ \(\(x\_1\)(
                      t)\) + \((\(-k20\) - k21)\)\ \(\(x\_2\)(t)\)\)}]},
            {
              RowBox[{
                RowBox[{
                  SuperscriptBox[\(x\_3\), "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], 
                "\[LongEqual]", \(k13\ \(\(x\_1\)(t)\) - 
                  k31\ \(\(x\_3\)(t)\)\)}]},
            {\(\(x\_1\)(0) \[LongEqual] 0\)},
            {\(\(x\_2\)(0) \[LongEqual] 0\)},
            {\(\(x\_3\)(0) \[LongEqual] 0\)}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {
          Equal[ 
            Derivative[ 1][ 
              Subscript[ x, 1]][ t], 
            Plus[ 
              b[ t], 
              Times[ 
                Plus[ 
                  Times[ -1, k10], 
                  Times[ -1, k12], 
                  Times[ -1, k13]], 
                Subscript[ x, 1][ t]], 
              Times[ k21, 
                Subscript[ x, 2][ t]], 
              Times[ k31, 
                Subscript[ x, 3][ t]]]], 
          Equal[ 
            Derivative[ 1][ 
              Subscript[ x, 2]][ t], 
            Plus[ 
              Times[ k12, 
                Subscript[ x, 1][ t]], 
              Times[ 
                Plus[ 
                  Times[ -1, k20], 
                  Times[ -1, k21]], 
                Subscript[ x, 2][ t]]]], 
          Equal[ 
            Derivative[ 1][ 
              Subscript[ x, 3]][ t], 
            Plus[ 
              Times[ k13, 
                Subscript[ x, 1][ t]], 
              Times[ -1, k31, 
                Subscript[ x, 3][ t]]]], 
          Equal[ 
            Subscript[ x, 1][ 0], 0], 
          Equal[ 
            Subscript[ x, 2][ 0], 0], 
          Equal[ 
            Subscript[ x, 3][ 0], 0]}]], TraditionalForm]], "Output",
  CellLabel->"Out[78]//TraditionalForm="]
}, Open  ]],

Cell[TextData[{
  "We will use the habitual agreement calling the lead amount in compartment \
1, 2, y 3,  in the time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ",  by  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(x\_1\)(t)\)\(,\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_2\)(t)\)]],
  " and",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(x\_3\)(t)\)\)\)]],
  ".  We call ",
  Cell[BoxData[
      \(TraditionalForm\`b\_1\)]],
  "the lead intake from outside of system in compartment 1. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["In matrix notation  the previous equation is transformed in ", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{
                StyleBox["x",
                  FontWeight->"Bold"], 
                StyleBox["'",
                  FontWeight->"Plain"]}],
              FontSlant->"Plain"], \((t)\)}], " ", "=", 
          RowBox[{
            StyleBox[
              RowBox[{
                StyleBox["A",
                  FontSlant->"Plain"], " ", 
                StyleBox["x",
                  FontSlant->"Plain"]}],
              FontWeight->"Bold"], 
            StyleBox[" ",
              FontWeight->"Bold"], "+", " ", 
            RowBox[{
              StyleBox["b",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", "t", ")"}]}]}], ",", 
        " ", \(t \[GreaterEqual] 0\)}], TraditionalForm]], "DisplayFormula"],

Cell["with", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{
                StyleBox["x",
                  FontWeight->"Bold"], 
                StyleBox["'",
                  FontWeight->"Plain"]}],
              FontSlant->"Plain"], \((t)\)}], " ", "=", 
          RowBox[{"(", GridBox[{
                {\(x\_1'\)},
                {\(x\_2'\)},
                {\(x\_3'\)}
                }], ")"}]}], ";", " ", 
        RowBox[{
          StyleBox["A",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", 
          RowBox[{"(", GridBox[{
                {\(a\_11\), \(a\_12\), \(a\_13\)},
                {\(a\_21\), \(a\_22\), "0"},
                {\(a\_31\), "0", \(a\_33\)}
                }], ")"}]}], ";", 
        StyleBox[" ",
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["x",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", 
          RowBox[{"(", GridBox[{
                {\(x\_1\)},
                {\(x\_2\)},
                {\(x\_3\)}
                }], ")"}]}], ";", 
        RowBox[{
          RowBox[{
            StyleBox["b",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", "t", ")"}], "=", " ", 
          RowBox[{"(", GridBox[{
                {\(\(b\_1\)(t)\)},
                {"0"},
                {"0"}
                }], ")"}]}]}], TraditionalForm]], "DisplayFormula"],

Cell[TextData[{
  "where the coefficiente ",
  Cell[BoxData[
      \(TraditionalForm\`a\_ij\)]],
  " of matrix ",
  StyleBox["A",
    FontWeight->"Bold"],
  " are:"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`a\_11 = \ \(-\((k\_10 + k\_12 + k\_13)\)\), \ 
    a\_12 = k\_21, \ a\_13 = k\_31, \ \ a\_21 = k\_12, \ 
    a\_22 = \ \(-\((k\_20 + k\_21)\)\), \ a\_31 = k\_13, \ 
    a\_33 = \(-k\_31\)\)], "DisplayFormula"],

Cell[TextData[{
  "To resolve the previous system we must know the form of input ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["b",
            FontWeight->"Bold",
            FontSlant->"Plain"], "(", "t", ")"}], TraditionalForm]]],
  ", also of the inital conditions ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              FormBox["x",
                "TraditionalForm"],
              FontWeight->"Bold"], 
            StyleBox[" ",
              FontWeight->"Bold"], \((0)\)}], "=", " ", 
          SubscriptBox[
            StyleBox["x",
              FontWeight->"Bold"], "0"]}], TraditionalForm]]],
  " "
}], "Text"],

Cell[TextData[{
  "In the model of figure we consider a single intake ",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`t\  = \ 0\)]],
  " , so ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(b(t)\), " ", "=", " ", 
          FormBox[\(b\_0\),
            "TraditionalForm"]}], TraditionalForm]]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`t\  = \ 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b(t)\  = \ 0\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`t > 0\)]],
  ". This is equivalent to assume as initial",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            RowBox[{
              FormBox[\(x\_1\),
                "TraditionalForm"], "(", "0", ")"}], " ", "=", " ", 
            FormBox[\(b\_0\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  ",  and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(\(\(x\)\(\ \)\)\_2\),
              "TraditionalForm"], \((0)\)}], " ", "=", " ", "0"}], 
        TraditionalForm]]],
  ". If we try to use DSolve without giving values to ",
  Cell[BoxData[
      \(TraditionalForm\`a\_ij\)]],
  " we will see that no solution is obtain. In real problems the most usual \
thing is that transfer coefficient values are known. "
}], "Text"],

Cell[TextData[{
  "In this example we will use the values given by 1992 (Bo92), in ",
  Cell[BoxData[
      \(TraditionalForm\`days\^\(-1\)\)]],
  ", obtained empirically from a person exposure to an environment highlly \
contaminated intaken 49.3 \[Mu]g of lead every day  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(k\_21\  = \ 0.0124; k\_12 = 0.0111; k\_13 = 0.0039; 
    k\_31\  = \ 0.000035; k\_10\  = \ 0.0211; 
    k\_20 = \ 0.0162; \ \), "\[IndentingNewLine]", 
    \(Initial\ \(conditions : \ b1\) = 49.3\  (*\[Mu]g/day*) , \ b2\  = 0; \ 
    b3 = 0; \)}], "Text"],

Cell[BoxData[
    \(model1 = 
      model /. {k21\  -> \ 0.0124, k12 -> 0.0111, 
          k13 -> 0.0039, \ \ k31\  -> \ 0.000035, \ k10\  -> \ 0.0211, \ 
          k20 \[Rule] \ \ 0.0162}; \)], "Input",
  CellLabel->"In[79]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \({x1[t1_], x2[t1_], x3[t1_]} = {x\_1[t1], x\_2[t1], x\_3[t1]} /. 
        SystemDSolve[model1, {0, 0, 0}, {49.3, 0, 0}, \ t, \ t1, \ 
          x]\)], "Input",
  CellLabel->"In[80]:="],

Cell[BoxData[
    \({\(\(1800.0970278827497`\)\(\[InvisibleSpace]\)\) - 
        719.884875401231`\ \[ExponentialE]\^\(\(-0.0446687516347288`\)\ t1\) \
- 855.3144589765811`\ \[ExponentialE]\^\(\(-0.020035616138806757`\)\ t1\) - 
        224.89769350493742`\ \[ExponentialE]\^\(\(-0.00003063222646443142`\)\ \
t1\), \(\(698.6390562761717`\)\(\[InvisibleSpace]\)\) + 
        497.28331724809317`\ \[ExponentialE]\^\(\(-0.0446687516347288`\)\ \
t1\) - 1108.5433171274608`\ \[ExponentialE]\^\(\(-0.020035616138806757`\)\ t1\
\) - 87.379056396804`\ \[ExponentialE]\^\(\(-0.00003063222646443142`\)\ t1\), \
\(\(200582.240249792`\)\(\[InvisibleSpace]\)\) + 
        62.90197241408429`\ \[ExponentialE]\^\(\(-0.0446687516347288`\)\ t1\) \
+ 166.78118148252585`\ \[ExponentialE]\^\(\(-0.020035616138806757`\)\ t1\) - 
        200811.92340368862`\ \[ExponentialE]\^\(\(-0.00003063222646443142`\)\ \
t1\)}\)], "Output",
  CellLabel->"Out[80]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{\ x1[t], x2[t], x3[t]}, \ {t, \ 0, \ 400}, \[IndentingNewLine]\ 
      PlotStyle \[Rule] {\[IndentingNewLine]{AbsoluteThickness[0.5], \ 
            AbsoluteDashing[{4, 4}]}, {AbsoluteThickness[
              1]}, {AbsoluteThickness[1.5]}}, \ 
      AxesLabel \[Rule] {"\<days\>", \ "\<r\>"}, 
      PlotLegend \[Rule] {"\<blood\>", "\<tissues\>", "\<bones\>"}, 
      LegendPosition \[Rule] {1, \ 0}, 
      LegendSize \[Rule] {0.6, \ 
          0.5}, \[IndentingNewLine]PlotLabel \[Rule] "\<Lead model:input = \
49.3 \[Mu]g/day\>"]\)], "Input",
  CellLabel->"In[81]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .46644 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.383199 0.359389 0.23322 0.359389 [
[ 0 0 0 0 ]
[ 1 .46644 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0111057 0.742588 0.455335 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00238095 0.0147151 0.000265629 [
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[1.025 .01472 0 -6.25 ]
[1.025 .01472 28 6.25 ]
[.01131 .14753 -18 -4.5 ]
[.01131 .14753 0 4.5 ]
[.01131 .28034 -24 -4.5 ]
[.01131 .28034 0 4.5 ]
[.01131 .41316 -24 -4.5 ]
[.01131 .41316 0 4.5 ]
[.01131 .54597 -24 -4.5 ]
[.01131 .54597 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12.5 ]
[.5 .63053 -92 0 ]
[.5 .63053 92 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(100)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(200)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(300)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(400)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .14753 m
.03006 .14753 L
s
[(500)] .01131 .14753 1 0 Mshowa
.02381 .28034 m
.03006 .28034 L
s
[(1000)] .01131 .28034 1 0 Mshowa
.02381 .41316 m
.03006 .41316 L
s
[(1500)] .01131 .41316 1 0 Mshowa
.02381 .54597 m
.03006 .54597 L
s
[(2000)] .01131 .54597 1 0 Mshowa
.125 Mabswid
.02381 .04128 m
.02756 .04128 L
s
.02381 .06784 m
.02756 .06784 L
s
.02381 .0944 m
.02756 .0944 L
s
.02381 .12097 m
.02756 .12097 L
s
.02381 .17409 m
.02756 .17409 L
s
.02381 .20066 m
.02756 .20066 L
s
.02381 .22722 m
.02756 .22722 L
s
.02381 .25378 m
.02756 .25378 L
s
.02381 .30691 m
.02756 .30691 L
s
.02381 .33347 m
.02756 .33347 L
s
.02381 .36003 m
.02756 .36003 L
s
.02381 .3866 m
.02756 .3866 L
s
.02381 .43972 m
.02756 .43972 L
s
.02381 .46628 m
.02756 .46628 L
s
.02381 .49285 m
.02756 .49285 L
s
.02381 .51941 m
.02756 .51941 L
s
.02381 .57254 m
.02756 .57254 L
s
.02381 .5991 m
.02756 .5991 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -153 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Lead) show
93.000 12.750 moveto
(model) show
123.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
129.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(input) show
165.000 12.750 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
177.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(49.3) show
207.000 12.750 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(g) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
219.000 12.750 moveto
(\\220) show
225.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(day) show
243.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .01472 m
.04262 .10484 L
.06244 .1764 L
.08255 .23107 L
.10458 .27604 L
.12415 .30645 L
.14509 .3317 L
.16639 .35163 L
.18653 .36646 L
.22495 .38708 L
.24479 .39489 L
.26581 .40163 L
.30365 .41078 L
.32306 .41435 L
.34394 .41755 L
.36365 .42005 L
.38516 .42233 L
.42487 .42556 L
.46552 .4279 L
.50465 .42951 L
.54623 .43072 L
.58629 .43156 L
.62484 .43215 L
.66585 .4326 L
.70534 .43292 L
.74331 .43315 L
.78373 .43334 L
.82264 .43347 L
.864 .43358 L
.90385 .43367 L
.94218 .43374 L
.97619 .43379 L
s
1 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02499 .01473 L
.02605 .01478 L
.02729 .01487 L
.02846 .01498 L
.03053 .01526 L
.03279 .01567 L
.0379 .01696 L
.04262 .01855 L
.05224 .02277 L
.06244 .02835 L
.10458 .05691 L
.14241 .08286 L
.1827 .1065 L
.22147 .12458 L
.2627 .1392 L
.30241 .14964 L
.3406 .15705 L
.38125 .16281 L
.42038 .16681 L
.46196 .16987 L
.50202 .17198 L
.54057 .17344 L
.58158 .17456 L
.62107 .17533 L
.65904 .17587 L
.69946 .17629 L
.73837 .17658 L
.77973 .1768 L
.81958 .17696 L
.85791 .17707 L
.89869 .17716 L
.93795 .17722 L
.97571 .17727 L
.97619 .17727 L
s
1.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01474 L
.02729 .01477 L
.02846 .01481 L
.03053 .01491 L
.03279 .01506 L
.03527 .01527 L
.0379 .01555 L
.04262 .01617 L
.05205 .01785 L
.06244 .02031 L
.0842 .02717 L
.10458 .03523 L
.14335 .05365 L
.18458 .07619 L
.22428 .09969 L
.26248 .12338 L
.30312 .14936 L
.34225 .17488 L
.38383 .20237 L
.4239 .22911 L
.46245 .25499 L
.50346 .28264 L
.54294 .30934 L
.58091 .33507 L
.62134 .36249 L
.66025 .3889 L
.70161 .41698 L
.74145 .44404 L
.77978 .47007 L
.82057 .49775 L
.85983 .5244 L
.89758 .55002 L
.93779 .57728 L
.97619 .60332 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.76056 .21525 m
.76056 .39495 L
.97619 .39495 L
.97619 .21525 L
F
1 g
.74259 .23322 m
.74259 .41291 L
.95822 .41291 L
.95822 .23322 L
F
0 g
.001 w
[ ] 0 setdash
.74259 .23322 m
.95822 .23322 L
.95822 .41291 L
.74259 .41291 L
.74259 .23322 L
s
% Start of sub-graphic
p
0.742588 0.23322 0.958221 0.412915 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0226449 0.226449 [
[ 0 0 0 0 ]
[ 1 .83333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .83333 L
0 .83333 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0407609 0.35119 0.26721 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
1.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .15399 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(bones) show
93.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.303442 0.35119 0.529891 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
1 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .41667 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(tissues) show
105.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.566123 0.35119 0.792572 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ 4 4 ] 0 Mabsdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .67935 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(blood) show
93.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .46644 L
0 .46644 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[81]:=",
  ImageSize->{288, 134.313},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000QR000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00?@3oool500000080oooo0P00
00040?ooo`8000005@3oool4000000<0oooo0P0000040?ooo`8000005P3oool2000000@0oooo0P00
00040?ooo`8000005`3oool300000080oooo0P0000040?ooo`800000J03oool003l0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000503oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000005`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0I@3oool003l0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000005P3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0B0?oo
o`D0000000D0oooo0000003oool0oooo000000020?ooo`040000003oool0oooo000006L0oooo000o
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool05@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool04P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000I`3oool003l0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool04P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000503oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000005@3oool00`000000oooo000000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000I`3oool003h0oooo0P0000040?ooo`800000103oool2000001H0oooo
0P0000040?ooo`800000103oool2000001H0oooo0P0000040?ooo`800000103oool2000001L0oooo
0P0000030?ooo`800000103oool2000006P0oooo00370?ooo`800000E`3oool00240oooo00<00000
0?ooo`3oool0Y03oool00`000000oooo0?ooo`1E0?ooo`008@3oool00`000000oooo0?ooo`2H0?oo
o`@0000000<0oooo0000000000000`0000030?ooo`040000003oool0oooo0?ooo`<00000D03oool0
0240oooo00<000000?ooo`3oool0U`3oool010000000oooo0?ooo`0000020?ooo`@000000`3oool0
0`000000oooo000000050?ooo`030000003oool0oooo04d0oooo000M0?oooiT000001@3oool01000
0000oooo0?ooo`0000050?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`00
001@0?ooo`008@3oool01@000000oooo0?ooo`3oool0000000<0oooo0P00002A0?ooo`<000000`3o
ool3000000050?ooo`00000000000000003oool00P0000000`3oool0000000000002000004l0oooo
000Q0?ooo`8000000`3oool2000000<0oooo0P00002A0?ooo`030000003oool0oooo05l0oooo000Q
0?ooo`8000001@3oool2000000<0oooo0P00002>0?ooo`800000H@3oool00240oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`<00000kP3oool00240oooo00<000000?ooo`3o
ool01`3oool2000000D0oooo0P00003/0?ooo`008@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00@0oooo0P00003Z0?ooo`008@3oool2000000/0oooo0P0000060?ooo`030000003o
ool0oooo0>L0oooo000Q0?ooo`8000003@3oool00`000000oooo0?ooo`040?ooo`800000i`3oool0
0240oooo0P00000>0?ooo`8000001P3oool00`000000oooo0?ooo`3T0?ooo`008@3oool00`000000
oooo0000000?0?ooo`030000003oool0oooo00@0oooo0P00003T0?ooo`008@3oool00`000000oooo
0000000@0?ooo`8000001P3oool200000>80oooo000Q0?ooo`030000003oool0oooo0180oooo0P00
00060?ooo`800000h03oool00240oooo00<000000?ooo`3oool0503oool2000000H0oooo0P00003N
0?ooo`008@3oool00`000000oooo0?ooo`0F0?ooo`8000001P3oool00`000000oooo0?ooo`3K0?oo
o`008@3oool010000000oooo0?ooo`00000G0?ooo`8000001@3oool200000=/0oooo000Q0?ooo`04
0000003oool0oooo000001T0oooo0`0000040?ooo`030000003oool0oooo0=P0oooo000Q0?ooo`04
0000003oool0oooo000001`0oooo0`0000020?ooo`800000f03oool000l0oooo0P0000040?ooo`80
0000103oool2000000@0oooo00D000000?ooo`3oool0oooo0000000N0?ooo`<0000000<0oooo0000
003oool0eP3oool000h0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo0000000Q0?ooo`@00000
e@3oool00140oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo0?ooo`8000009`3oool400000=80oooo000?0?ooo`8000000`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0:03oool8
00000<`0oooo000?0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool00`3o
ool600000<H0oooo000?0?ooo`<000000`3oool2000000@0oooo0P0000040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool09P3oool2000000T0oooo4P00002d0?ooo`008@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0603ooom60000
06h0oooo000Q0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool200000<`0
oooo000Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`390?ooo`008@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02X0oooo0P00
00390?ooo`008@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0<H0oooo000Q0?oo
o`030000003oool0oooo03@0oooo0P0000360?ooo`008@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0``3oool00240oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0_0?ooo`800000``3oool00240oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0<00oooo000Q0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0<@3oool200000<00oooo000Q0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`2m0?ooo`008@3oool00`000000
oooo0?ooo`0m0?ooo`800000_@3oool00240oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`2j0?ooo`008@3oool00`000000oooo0?ooo`100?ooo`800000^P3oool000P0oooo1@000002
0?ooo`800000103oool2000000@0oooo0P0000040?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`2g0?ooo`002P3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`050000
003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`0g0?ooo`800000]`3oool000X0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`3oool2000000X0oooo00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`2d0?ooo`002P3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?oo
o`000000303oool00`000000oooo0?ooo`0i0?ooo`800000]03oool000X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool01@000000oooo0?ooo`3oool0000004X0oooo00<000000?ooo`3oool0/@3oool000T0oooo0P00
00040?ooo`800000103oool2000000@0oooo0P0000040?ooo`030000003oool0oooo04T0oooo0P00
002a0?ooo`008@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0I`3oooln000000T0oooo000Q0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0>`3oool2000006L0oooo?P0000090?ooo`008@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool0I03oooln000000T0oooo000Q0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0?@3oool2000006@0oooo?P0000090?ooo`008@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0G03o
oom3000000T0oooo000Q0?ooo`030000003oool0oooo0580oooo0P00001L0?ooo`030000003oool0
oooo03/0oooo1@0000090?ooo`008@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0k0?ooo`D000002@3oool00240
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`100?ooo`800000F@3oool00`000000
oooo0?ooo`0k0?ooo`D000002@3oool00240oooo00<000000?ooo`3oool04`3oool200000480oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0k0?ooo`D000002@3oool00240oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`100?ooo`800000EP3oool00`000000oooo0?oo
o`0k0?ooo`D000002@3oool00240oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo03/0oooo1@0000090?ooo`008@3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo03l0oooo0P00001C0?ooo`030000003oool0oooo03/0oooo1@0000090?oo
o`008@3oool00`000000oooo0?ooo`0J0?ooo`<00000@03oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo01L0oooo100000040?ooo`8000000P3oool200000080oooo0P0000020?ooo`<0
00000P3oool3000000P0oooo1@0000090?ooo`008@3oool00`000000oooo0?ooo`1N0?ooo`800000
D03oool010000000oooo0?ooo`3ooolC000000@0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`D000002@3oool000P0oooo1@0000020?ooo`800000103oool2
000000@0oooo0P0000040?ooo`030000003oool0oooo0200oooo0`00000m0?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool0603oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool400000080oooo0`0000080?ooo`D0
00002@3oool000X0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000002D0oooo0P00
000l0?ooo`800000C@3oool00`000000oooo0?ooo`0H0?ooo`<00000103oool200000080oooo1000
00040?ooo`8000000`3oool4000000L0oooo1@0000090?ooo`002P3oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`3oool2000002T0oooo1@00000f0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0P0?ooo`D000002@3oool000X0oooo00<000000?ooo`3oool0
0P3oool2000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo0300oooo1@00000_0?ooo`030000003oool0oooo04T0oooo00<000000?oo
o`3oool05`3oool200000280oooo1@0000090?ooo`002P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo03P0oooo1@0000030?ooo`D000000`3oool5000001P0oooo00<00000
0?ooo`3oool0B03oool00`000000oooo0?ooo`0k0?ooo`D000002@3oool000T0oooo0P0000040?oo
o`<000000`3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo0500oooo1@0000030?oo
o`D000000`3oool5000000030?ooo`000000000000D000000`3oool5000000<0oooo1@0000030?oo
o`D000000`3oool5000002<0oooo00<000000?ooo`3oool0>`3oool5000000T0oooo000Q0?ooo`03
0000003oool0oooo06P0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0k0?ooo`D0
00002@3oool00240oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo03/0oooo1@0000090?ooo`008@3oool00`000000oooo0?ooo`1Z0?ooo`800000A03o
ool00`000000oooo0?ooo`0k0?ooo`D000002@3oool00240oooo00<000000?ooo`3oool0K03oool2
00000480oooo00<000000?ooo`3oool0>`3oool5000000T0oooo000Q0?ooo`030000003oool0oooo
06h0oooo0P0000100?ooo`030000003oool0oooo03/0oooo1@0000090?ooo`008@3oool00`000000
oooo0?ooo`1`0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0>`3oool5000000T0
oooo000Q0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`0k0?ooo`D000002@3oool00240oooo00<000000?ooo`3oool0LP3oool2000003`0oooo00<0
00000?ooo`3oool0>`3oool5000000T0oooo000Q0?ooo`030000003oool0oooo07@0oooo00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`0I0?ooo`800000103oool300000080oooo0`000003
0?ooo`<00000103oool400000080oooo0`0000000`3oool0000000000003000000T0oooo000Q0?oo
o`030000003oool0oooo07D0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0H0?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool5000000T0oooo
000Q0?ooo`030000003oool0oooo07H0oooo0P00000h0?ooo`040000003oool0oooo0?oooa<00000
103oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`<000000`3oool3000000<0
oooo00@000000?ooo`3oool000000P3oool4000000030?ooo`000000000000<000002@3oool00240
oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01L0
oooo1@0000030?ooo`8000000`3oool400000080oooo10000000103oool000000000003oool20000
00<0oooo0P0000020?ooo`D000002@3oool00240oooo00<000000?ooo`3oool0N@3oool2000003D0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0P0?ooo`D000002@3oool00240oooo
00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0603oool5000000T0oooo00080?ooo`@000000`3oool2000000@0oooo0P00
00040?ooo`800000103oool00`000000oooo0?ooo`1l0?ooo`800000<P3oool00`000000oooo0?oo
o`0k0?ooo`D000002@3oool000P0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`1n0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0>`3oool5000000T0
oooo00090?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo0P0000200?ooo`800000;`3oool0
0`000000oooo0?ooo`0k0?ooo`D000002@3oool000X0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01@000000oooo
0?ooo`3oool0000008<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0k0?ooo`D0
00002@3oool000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`220?ooo`800000;03oool00`000000oooo0?ooo`0k0?ooo`D000002@3oool000T0oooo0P000004
0?ooo`800000103oool2000000@0oooo0P0000040?ooo`030000003oool0oooo08@0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0k0?ooo`D000002@3oool00240oooo00<000000?oo
o`3oool0Q@3oool2000002T0oooo00<000000?ooo`3oool0>`3oool5000000T0oooo000Q0?ooo`03
0000003oool0oooo08L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0k0?ooo`D0
00002@3oool00240oooo00<000000?ooo`3oool0R03oool2000002H0oooo00<000000?ooo`3oool0
>`3oool5000000T0oooo000Q0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0k0?ooo`D000002@3oool00240oooo00<000000?ooo`3oool0R`3oool2
000002<0oooo00<000000?ooo`3oool05`3oool4000000<0oooo0`0000040?ooo`800000103oool2
000000@0oooo100000060?ooo`D000002@3oool00240oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo01P0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000070?ooo`D000002@3oool00240oooo00<000000?ooo`3oool0
/03oool010000000oooo0?ooo`3oool5000000<0oooo1@0000030?ooo`<00000103oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000L0oooo1@0000090?ooo`008@3o
ool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01P0oooo0`0000040?ooo`030000003o
ool0oooo00<0oooo0P0000040?ooo`800000103oool3000000L0oooo1@0000090?ooo`00e03oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`050?ooo`D000002@3oool00=@0oooo00<000000?ooo`3oool05`3oool20000
00D0oooo0P00000B0?ooo`8000001`3oool5000000T0oooo003D0?ooo`030000003oool0oooo03/0
oooo1@0000090?ooo`00G@3oool3000003l0oooo00<000000?ooo`3oool0103oool3000001D0oooo
0P00000D0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool02`3oool005h0oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo00000180oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00/0oooo
000?0?ooo`D000000`3oool300000080oooo1@0000020?ooo`@000001P3oool2000000040?ooo`00
0000oooo00000080oooo0P0000040?ooo`@000000P3oool300000080oooo0`0000040?ooo`030000
003oool0oooo00<0oooo0`0000000`3oool00000000000020?ooo`80000000@0oooo000000000000
0000103oool400000080oooo0P0000090?ooo`@000002P3oool3000000040?ooo`00000000000000
00@0oooo0P0000040?ooo`800000203oool600000080oooo0`0000030?ooo`030000003oool0oooo
00<0oooo100000000`3oool0000000000003000000<0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00/0oooo000@0?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00`3oool400000080oooo00@000000?ooo`3oool00000203oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo00000080oooo100000030?ooo`030000003oool000000180oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0;0?ooo`00403oool00`000000oooo0?ooo`030?ooo`@000001@3o
ool400000080oooo00<000000?ooo`3oool01P3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@000000`3oool00`00
0000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000002`3oool4000000P0
oooo1@0000020?ooo`<000002P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0@0?ooocl00000
3@3oool00100oooo00<000000?ooo`3oool0103oool2000000@0oooo100000020?ooo`<000001`3o
ool3000000030?ooo`000000oooo0080oooo0P0000040?ooo`<000000`3oool2000000@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`8000000P3oool400000080oooo1000
00020?ooo`80000000@0oooo000000000000oooo1@00000D0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo
0?ooo`0000000P3oool4000000<0oooo00<000000?ooo`3oool00P3oool3000000<0oooo0`000000
1@3oool00000000000000000oooo00800000G@3oool00100oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`0000000P3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000P0oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J03oool000l0oooo
0`00000=0?ooo`@0000000<0oooo0000000000005P3oool2000000P0oooo0P00000<0?ooo`030000
003oool0oooo02d0oooo0P0000030?ooo`<000002@3oool2000001P0oooo00<000000?ooo`3oool0
0P3oool2000006X0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {133.313, 0}} -> {-1.07207, -0.648941, \
0.00973564, 0.00973564}, {{7.375, 212.813}, {130.125, 3.125}} -> {-92.3105, \
-455.922, 2.77477, 24.8715}, {{212.813, 274.438}, {66.625, 15.25}} -> \
{-11.7034, -4.8796, 0.0545239, 0.07166}, {{216.063, 234.438}, {64.0625, \
50.125}} -> {-12.3716, -14.0944, 0.0571434, 0.18492}, {{216.063, 234.438}, \
{47.875, 33.9375}} -> {-12.3716, -17.0878, 0.0571434, 0.18492}, {{216.063, \
234.438}, {31.6875, 17.75}} -> {-12.3716, -20.0812, 0.0571434, 0.18492}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[81]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[b1, k, a, x1, x2, x3, \ eq1, \ model]; \)], "Input",
  CellLabel->"In[82]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["General tricompartimental model ", "SubsectionIcon"],

Cell["\<\
The figure represent the general tricompartmental model with one input in \
each compartment \
\>", "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.12963 0.21164 0.349206 0.21164 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125  moveto 0 0 lineto 
-0.05 -0.0125  lineto stroke
} ifelse
grestore
} def
/MAarrowhead2 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.12963 .66667 m
.12963 .45503 L
s
% Start of user PostScript
0 1.5 0 0.5 MAarrowhead1
% End of user PostScript
gsave
.04497 .56085 -80.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
75.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.875 12.750 moveto
(H) show
85.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.875 12.750 moveto
(L) show
97.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.12963 .34921 .10582 0 365.73 arc
s
gsave
.12963 .34921 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.12963 .24339 m
.12963 .03175 L
s
% Start of user PostScript
0 -0.5 0 -1.5 MAarrowhead2
% End of user PostScript
gsave
.06614 .13757 -70.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23545 .39153 m
.76455 .39153 L
s
% Start of user PostScript
0.5 0.2 3. 0.2 MAarrowhead2
% End of user PostScript
gsave
.5 .43386 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.76455 .30688 m
.23545 .30688 L
s
% Start of user PostScript
3. -0.2 0.5 -0.2 MAarrowhead2
% End of user PostScript
gsave
.5 .26455 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.87037 .34921 .10582 0 365.73 arc
s
gsave
.87037 .34921 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.87037 .66667 m
.87037 .45503 L
s
% Start of user PostScript
3.5 1.5 3.5 0.5 MAarrowhead1
% End of user PostScript
gsave
.95503 .56085 -77.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.875 12.750 moveto
(H) show
79.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
85.875 12.750 moveto
(L) show
91.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.87037 .24339 m
.87037 .03175 L
s
% Start of user PostScript
3.5 -0.5 3.5 -1.5 MAarrowhead2
% End of user PostScript
gsave
.80688 .13757 -70.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 1.30159 m
.5 1.08995 L
s
% Start of user PostScript
1.75 4.5 1.75 3.5 MAarrowhead1
% End of user PostScript
gsave
.40476 1.19577 -80.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
75.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.875 12.750 moveto
(H) show
85.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.875 12.750 moveto
(L) show
97.875 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.5 .98413 .10582 0 365.73 arc
s
gsave
.5 .98413 -66 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15079 .45503 m
.41534 .92063 L
s
% Start of user PostScript
0.1 0.5 1.35 2.7 MAarrowhead2
% End of user PostScript
gsave
.23545 .70899 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.47884 .87831 m
.21429 .42328 L
s
% Start of user PostScript
1.65 2.5 0.4 0.35 MAarrowhead2
% End of user PostScript
gsave
.39418 .62434 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(31) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.58466 .92063 m
.84921 .45503 L
s
% Start of user PostScript
2.15 2.7 3.4 0.5 MAarrowhead2
% End of user PostScript
gsave
.60582 .62434 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.78571 .42328 m
.52116 .87831 L
s
% Start of user PostScript
3.1 0.35 1.85 2.5 MAarrowhead2
% End of user PostScript
gsave
.76455 .70899 -70.625 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(32) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .87831 m
.5 .66667 L
s
% Start of user PostScript
1.75 2.5 1.75 1.5 MAarrowhead2
% End of user PostScript
gsave
.46825 .73016 -70.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5 translate 1 -1 scale
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
78.250 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{236.375, 315.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0001RA000`40O003h00Oogoo:7oo003oOolX
Ool00?moobQoo`00ogoo:7oo003oOolXOol00?moobQoo`00ogoo:7oo003oOolXOol00?moobQoo`00
9Woo00<007ooOol0egoo00<007ooOol097oo000VOol00`00Oomoo`3GOol00`00Oomoo`0TOol002Eo
o`800=Qoo`8002Ioo`009Goo0`00egoo0`009Goo000UOol3003GOol3000UOol002Eoo`<00=Moo`<0
02Eoo`0097oo1000eWoo10009Goo000TOol4003FOol4000UOol002Aoo`D00=Eoo`D002Aoo`0097oo
1@00eGoo1@0097oo000SOol6003DOol6000TOol002=oo`H00=Aoo`H002Aoo`008goo1P00e7oo1P00
97oo000SOol7003COol7000SOol0029oo`P00=9oo`P002=oo`008Woo2000dWoo20008goo000VOol0
0`00Oomoo`3GOol00`00Oomoo`0TOol002Ioo`03001oogoo0=Moo`03001oogoo02Aoo`009Woo00<0
07ooOol0egoo00<007ooOol097oo000VOol00`00Oomoo`3GOol00`00Oomoo`0TOol002Ioo`03001o
ogoo0=Moo`03001oogoo02Aoo`009Woo00<007ooOol0egoo00<007ooOol097oo000VOol00`00Oomo
o`3GOol00`00Oomoo`0TOol002Ioo`03001oogoo0=Moo`03001oogoo02Aoo`009Woo00<007ooOol0
egoo00<007ooOol097oo000VOol00`00Oomoo`3GOol00`00Oomoo`0TOol002Ioo`03001oogoo0=Mo
o`03001oogoo02Aoo`009Woo00<007ooOol0egoo00<007ooOol097oo000VOol00`00Oomoo`3GOol0
0`00Oomoo`0TOol002Ioo`03001oogoo0=Moo`03001oogoo02Aoo`009Woo00<007ooOol0egoo00<0
07ooOol097oo000VOol00`00Oomoo`3GOol00`00Oomoo`0TOol002Ioo`03001oogoo0=Moo`03001o
ogoo02Aoo`009Woo00<007ooOol0egoo00<007ooOol097oo000VOol00`00Oomoo`3GOol00`00Oomo
o`0TOol0015oo`D0009oo`03001oogoo00]oo`03001oogoo0<=oo`<000=oo`03001oogoo00]oo`03
001oogoo02Aoo`004goo00L007ooOomoo`00Ool0000<Ool00`00Oomoo`33Ool00`00Oomoo`02Ool0
0`00Ool0000<Ool00`00Oomoo`0TOol000]oo`80009oo`<00003Ool007oo009oo`03001oo`0000ao
o`03001oogoo0;aoo`80009oo`<00003Ool007oo009oo`03001oo`0000aoo`03001oogoo02Aoo`00
37oo00@007ooOol000=oo`07001oogooOol007oo000037oo00<007ooOol0_Goo00@007ooOol000=o
o`07001oogooOol007oo000037oo00<007ooOol097oo000<Ool00`00Ool00004Ool01`00Oomoogoo
001oo`0000aoo`03001oogoo0;eoo`03001oo`0000=oo`03001oo`00009oo`03001oo`0000aoo`03
001oogoo02Aoo`0037oo0`000goo0P0017oo00<007ooOol02goo00<007ooOol0_Goo0`0017oo00<0
07ooOol00Woo00<007ooOol02goo00<007ooOol097oo000<Ool01000Oomoo`005Woo00<007ooOol0
_Goo00@007ooOol001Ioo`03001oogoo02Aoo`0037oo00<007oo00000`0057oo00<007ooOol0_Goo
00<007oo00000`0057oo00<007ooOol097oo000<Ool00`00Oomoo`0GOol00`00Oomoo`2mOol00`00
Oomoo`0GOol00`00Oomoo`0TOol000]oo`8001Uoo`03001oogoo0;aoo`8001Uoo`03001oogoo02Ao
o`009Woo00<007ooOol0egoo00<007ooOol097oo000VOol00`00Oomoo`3GOol00`00Oomoo`0TOol0
02Ioo`03001oogoo0=Moo`03001oogoo02Aoo`009Woo00<007ooOol0egoo00<007ooOol097oo000V
Ool00`00Oomoo`3GOol00`00Oomoo`0TOol002Ioo`03001oogoo0=Moo`03001oogoo02Aoo`009Woo
00<007ooOol0egoo00<007ooOol097oo000VOol00`00Oomoo`3GOol00`00Oomoo`0TOol002Ioo`03
001oogoo0=Moo`03001oogoo02Aoo`009Woo00<007ooOol0egoo00<007ooOol097oo000VOol00`00
Oomoo`3GOol00`00Oomoo`0TOol002Ioo`03001oogoo0=Moo`03001oogoo02Aoo`009Woo00<007oo
Ool0egoo00<007ooOol097oo000VOol00`00Oomoo`3GOol00`00Oomoo`0TOol002Ioo`03001oogoo
0=Moo`03001oogoo02Aoo`009Woo00<007ooOol0egoo00<007ooOol097oo000VOol00`00Oomoo`3G
Ool00`00Oomoo`0TOol002Eoo`800=Qoo`<002Eoo`007Woo1`000Woo1`00bWoo1`000goo1P007goo
000KOol3000@Ool20035Ool3000@Ool2000MOol001Uoo`8001Eoo`<005moo`<00003Ool0000000<0
05Qoo`8001Eoo`<001Yoo`005goo0P006Woo0`00G7oo00<007ooOol00goo00<007ooOol0EWoo0P00
6Woo0`005goo000EOol2000OOol2001BOol20002Ool30002Ool00`00Oomoo`02Ool00`00Oomoo`1E
Ool00`00Oomoo`0MOol2000EOol001=oo`8002=oo`03001oogoo051oo`04001oogoo0004Ool00`00
Oomoo`02Ool00`00Oomoo`1COol2000ROol00`00Oomoo`0BOol0019oo`03001oogoo02Aoo`03001o
ogoo04moo`03001oo`0000Aoo`03001oo`0000=oo`03001oogoo055oo`8002Eoo`03001oogoo015o
o`004Goo00<007ooOol09Woo00<007ooOol0CWoo0`001Goo00@007ooOomoo`80059oo`03001oogoo
02Ioo`80015oo`0047oo00<007ooOol0:7oo00<007ooOol0CGoo00@007ooOol005]oo`03001oogoo
02Uoo`03001oogoo00ioo`003goo00<007ooOol0:Woo00<007ooOol0C7oo00<007oo00000`00F7oo
00<007ooOol0:goo00<007ooOol03Goo000>Ool00`00Oomoo`0/Ool00`00Oomoo`1;Ool00`00Oomo
o`1JOol00`00Oomoo`0/Ool00`00Oomoo`0=Ool000ioo`03001oogoo02eoo`03001oogoo04Uoo`80
05aoo`03001oogoo02eoo`03001oogoo00aoo`003Goo00<007ooOol0;Woo00<007ooOol0YWoo00<0
07ooOol0;goo00<007ooOol02goo000<Ool00`00Oomoo`0`Ool00`00Oomoo`2TOol00`00Oomoo`0a
Ool00`00Oomoo`0:Ool000]oo`03001oogoo039oo`03001oogoo0:9oo`03001oogoo039oo`03001o
ogoo00Yoo`002goo00<007ooOol0<Woo00<007ooOol03goo0`00T7oo00<007ooOol0<goo00<007oo
Ool02Goo000:Ool00`00Oomoo`0dOol00`00Oomoo`09Ool8002?Ool00`00Oomoo`0dOol00`00Oomo
o`09Ool000Yoo`03001oogoo03Aoo`03001oogoo00Aoo`d008moo`03001oogoo03Aoo`03001oogoo
00Uoo`002Goo00<007ooOol0=Woo00<007ooOol0W@0000=oo`00Ool0=goo00<007ooOol027oo0009
Ool00`00Oomoo`0fOol00`00Oomoo`02Ool>002>Ool00`00Oomoo`0gOol00`00Oomoo`07Ool000Qo
o`03001oogoo03Qoo`03001oogoo00Eoo`X008eoo`03001oogoo03Qoo`03001oogoo00Moo`0027oo
00<007ooOol0>7oo00<007ooOol02Goo1P00SGoo00<007ooOol0>Goo00<007ooOol01Woo0007Ool0
0`00Oomoo`0iOol00`00Oomoo`0=Ool2002=Ool00`00Oomoo`0iOol00`00Oomoo`06Ool000Moo`03
001oogoo03Yoo`03001oogoo09]oo`03001oogoo03Uoo`03001oogoo00Ioo`001goo00<007ooOol0
>Woo00<007ooOol0Vgoo00<007ooOol0>Goo00<007ooOol01Woo0007Ool00`00Oomoo`0jOol00`00
Oomoo`2JOol00`00Oomoo`0jOol00`00Oomoo`06Ool000Moo`03001oogoo03Yoo`03001oogoo09Yo
o`03001oogoo03]oo`03001oogoo00Eoo`001goo00<007ooOol0>goo00<007ooOol0VGoo00<007oo
Ool0>goo00<007ooOol01Goo0007Ool00`00Oomoo`0JOol5000LOol00`00Oomoo`2IOol00`00Oomo
o`0IOol5000MOol00`00Oomoo`05Ool000Moo`03001oogoo01aoo`03001oogoo01aoo`03001oogoo
09Uoo`03001oogoo01Uoo`05001oogooOol0000MOol00`00Oomoo`05Ool000Moo`03001oogoo01ao
o`03001oogoo01aoo`03001oogoo09Uoo`03001oogoo01Yoo`03001oogoo01ioo`03001oogoo00Eo
o`001goo00<007ooOol077oo00<007ooOol077oo00<007ooOol0VGoo00<007ooOol06goo00<007oo
Ool07Goo00<007ooOol01Goo0007Ool00`00Oomoo`0LOol00`00Oomoo`0LOol00`00Oomoo`2IOol0
0`00Oomoo`0LOol00`00Oomoo`0LOol00`00Oomoo`05Ool000Moo`03001oogoo01aoo`03001oogoo
01aoo`03001oogoo09Uoo`03001oogoo01eoo`03001oogoo01]oo`03001oogoo00Eoo`001goo00<0
07ooOol06Woo0`007Woo00<007ooOol0VGoo00<007ooOol06Goo00D007ooOomoo`0001eoo`03001o
ogoo00Eoo`001goo00<007ooOol077oo00<007ooOol06goo00<007ooOol0VWoo00<007ooOol06Woo
0`007Woo00<007ooOol01Goo0007Ool00`00Oomoo`0jOol00`00Oomoo`2JOol00`00Oomoo`0jOol0
0`00Oomoo`06Ool000Moo`03001oogoo03Yoo`03001oogoo09Yoo`03001oogoo03Yoo`03001oogoo
00Ioo`001goo00<007ooOol0>Woo00<007ooOol0Vgoo00<007ooOol0>Goo00<007ooOol01Woo0007
Ool00`00Oomoo`0iOol00`00Oomoo`2<Ool2000>Ool00`00Oomoo`0iOol00`00Oomoo`06Ool000Qo
o`03001oogoo03Qoo`03001oogoo08aoo`H000Yoo`03001oogoo03Uoo`03001oogoo00Ioo`0027oo
00<007ooOol0>7oo00<007ooOol0S7oo2P001Woo00<007ooOol0>7oo00<007ooOol01goo0009Ool0
0`00Oomoo`0fOol00`00Oomoo`2=Ool>0003Ool00`00Oomoo`0gOol00`00Oomoo`07Ool000Uoo`03
001oogoo03Ioo`03001oogoo09d00003Ool007oo03Moo`03001oogoo00Qoo`002Woo00<007ooOol0
=7oo00<007ooOol0SWoo3P0017oo00<007ooOol0=7oo00<007ooOol02Goo000:Ool00`00Oomoo`0d
Ool00`00Oomoo`2>Ool:0008Ool00`00Oomoo`0dOol00`00Oomoo`09Ool000]oo`03001oogoo039o
o`03001oogoo08moo`H000eoo`03001oogoo03=oo`03001oogoo00Uoo`002goo00<007ooOol0<Woo
00<007ooOol0Sgoo0P004Goo00<007ooOol0<Woo00<007ooOol02Woo000<Ool00`00Oomoo`0`Ool0
0`00Oomoo`2TOol00`00Oomoo`0aOol00`00Oomoo`0:Ool000eoo`03001oogoo02moo`03001oogoo
0:Eoo`03001oogoo02moo`03001oogoo00]oo`003Woo00<007ooOol0;Goo00<007ooOol0Ygoo00<0
07ooOol0;Woo00<007ooOol02goo000>Ool00`00Oomoo`0]Ool00`00Oomoo`2WOol00`00Oomoo`0]
Ool00`00Oomoo`0<Ool000moo`03001oogoo02Yoo`800003Ool007oo051oo`D00004Ool00000001=
Ool00`00Ool0000]Ool00`00Oomoo`0=Ool0011oo`03001oogoo02Qoo`04001oogooOol20019Ool2
0002Ool30002Ool01@00Oomoogoo0000CWoo00D007ooOomoo`0002]oo`03001oogoo00ioo`004Goo
00<007ooOol09Woo00<007ooOol00goo0P00BGoo00@007ooOol000Aoo`03001oogoo009oo`03001o
ogoo04]oo`03001oogoo009oo`03001oogoo02Ioo`80015oo`004Woo00<007ooOol097oo00<007oo
Ool017oo0`00B7oo00<007oo00001Goo00<007ooOol00Woo00<007ooOol0BWoo00<007ooOol017oo
0P009Goo00<007ooOol04Goo000COol00`00Oomoo`0ROol00`00Oomoo`05Ool40017Ool30005Ool0
1`00Oomoogoo001oo`0004]oo`03001oogoo00Ioo`03001oogoo025oo`03001oogoo019oo`0057oo
0P0087oo0P0027oo1@00AWoo00@007ooOol000=oo`8000Aoo`03001oogoo04Uoo`03001oogoo00Qo
o`03001oogoo01ioo`8001Eoo`005Woo0P0077oo0P002goo1000AWoo00<007oo00000`00Dgoo00<0
07ooOol02Goo0P0077oo0P005goo000HOol3000GOol2000=Ool50015Ool00`00Oomoo`1EOol00`00
Oomoo`0<Ool3000GOol2000IOol001]oo`<0019oo`8000moo`H004=oo`8005Ioo`03001oogoo011o
o`<0019oo`8001]oo`007Woo0`002Woo1@004Goo1`00VWoo00<007ooOol04goo0`002Woo1@007Goo
000QOol:00000goo001oo`0DOol7002HOol00`00Oomoo`0FOol;000ROol002Ioo`03001oogoo00Ao
o`03001oogoo019oo`P009Moo`03001oogoo01Eoo`8000Eoo`03001oogoo02Aoo`009Goo0P001Woo
00<007ooOol04Woo1`00Ugoo00<007ooOol05Goo0P001Goo0P009Woo000UOol30006Ool00`00Oomo
o`0AOol5002HOol00`00Oomoo`0EOol30005Ool3000UOol002Eoo`<000Ioo`03001oogoo019oo`<0
0003Ool007oo09Ioo`03001oogoo01Aoo`@000Eoo`<002Eoo`009Goo0`001goo00<007ooOol04Goo
00<007ooOol00Woo00<007ooOol0Tgoo00<007ooOol057oo10001Woo0`009Goo000TOol01000Ool0
00001goo00<007ooOol05Woo00<007ooOol0Tgoo00<007ooOol04goo1@001Goo00@007oo000002Eo
o`0097oo00@007oo000000Qoo`03001oogoo01Ioo`03001oogoo095oo`03001oogoo01=oo`D000Io
o`04001oo`00000UOol002Aoo`05001oo`00Ool00008Ool00`00Oomoo`0EOol00`00Oomoo`2AOol0
0`00Oomoo`0BOol60006Ool01@00Ool007oo000097oo000SOol01P00Oomoo`00Ool000Qoo`03001o
ogoo01Ioo`03001oogoo08moo`03001oogoo019oo`L000Eoo`06001oogoo001oo`0097oo000SOol0
1P00Oomoo`00Ool000Uoo`03001oogoo01Eoo`03001oogoo08ioo`03001oogoo019oo`L000Ioo`06
001oogoo001oo`0097oo000SOol01P00Oomoo`00Ool000Uoo`03001oogoo01Ioo`03001oogoo08eo
o`03001oogoo015oo`P000Ioo`06001oogoo001oo`0097oo000SOol01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol05Woo00<007ooOol0Rgoo00<007ooOol04goo1`001Woo00@007ooOol0009o
o`03001oogoo025oo`008Woo00D007ooOomoo`00009oo`03001oogoo00Moo`03001oogoo01Ioo`03
001oogoo08]oo`03001oogoo01Eoo`@000Ioo`05001oogooOol00002Ool00`00Oomoo`0QOol0029o
o`05001oogooOol00002Ool00`00Oomoo`08Ool00`00Oomoo`0FOol00`00Oomoo`29Ool00`00Oomo
o`0FOol01000Ool000001Woo00D007ooOomoo`00009oo`03001oogoo025oo`009Woo00<007ooOol0
37oo00<007ooOol05Goo00<007ooOol0R7oo00<007ooOol05Woo00<007ooOol037oo00<007ooOol0
97oo000VOol00`00Oomoo`0<Ool00`00Oomoo`0FOol00`00Oomoo`27Ool00`00Oomoo`0FOol00`00
Oomoo`0<Ool00`00Oomoo`0TOol002Ioo`03001oogoo00eoo`03001oogoo01Ioo`03001oogoo08Eo
o`03001oogoo01Ioo`03001oogoo00eoo`03001oogoo02Aoo`009Woo00<007ooOol03Goo00<007oo
Ool05Woo00<007ooOol0QGoo00<007ooOol05Woo00<007ooOol03Goo00<007ooOol097oo000VOol0
0`00Oomoo`0>Ool00`00Oomoo`0FOol00`00Oomoo`23Ool00`00Oomoo`0FOol00`00Oomoo`0>Ool0
0`00Oomoo`0TOol002Ioo`03001oogoo00ioo`03001oogoo01Ioo`03001oogoo08=oo`03001oogoo
01Ioo`03001oogoo00ioo`03001oogoo02Aoo`009Woo00<007ooOol03goo00<007ooOol05Woo00<0
07ooOol0PGoo00<007ooOol05Woo00<007ooOol03goo00<007ooOol097oo000VOol00`00Oomoo`0@
Ool00`00Oomoo`0EOol00`00Oomoo`20Ool00`00Oomoo`0FOol00`00Oomoo`0@Ool00`00Oomoo`0T
Ool002Ioo`03001oogoo011oo`03001oogoo01Ioo`03001oogoo07moo`03001oogoo01Ioo`03001o
ogoo011oo`03001oogoo02Aoo`009Woo00<007ooOol04Goo00<007ooOol05Woo00<007ooOol0OGoo
00<007ooOol05Woo00<007ooOol04Goo00<007ooOol097oo000VOol00`00Oomoo`0AOol00`00Oomo
o`0FOol00`00Oomoo`1mOol00`00Oomoo`0FOol00`00Oomoo`0AOol00`00Oomoo`0TOol002Ioo`03
001oogoo019oo`03001oogoo01Ioo`03001oogoo07]oo`03001oogoo01Ioo`03001oogoo019oo`03
001oogoo02Aoo`009Woo00<007ooOol04Woo00<007ooOol05Woo00<007ooOol0NWoo00<007ooOol0
5goo00<007ooOol04Woo00<007ooOol097oo000VOol00`00Oomoo`0COol00`00Oomoo`0FOol00`00
Oomoo`1iOol00`00Oomoo`0FOol00`00Oomoo`0COol00`00Oomoo`0TOol002Ioo`03001oogoo01Ao
o`03001oogoo01Eoo`03001oogoo07Qoo`03001oogoo01Ioo`03001oogoo01Aoo`03001oogoo02Ao
o`009Woo00<007ooOol057oo00<007ooOol05Woo00<007ooOol0Mgoo00<007ooOol05Woo00<007oo
Ool057oo00<007ooOol097oo000VOol00`00Oomoo`0EOol00`00Oomoo`0FOol00`00Oomoo`1eOol0
0`00Oomoo`0FOol00`00Oomoo`0EOol00`00Oomoo`0TOol002Ioo`03001oogoo01Eoo`03001oogoo
01Ioo`03001oogoo07Eoo`03001oogoo01Ioo`03001oogoo01Eoo`03001oogoo02Aoo`009Woo00<0
07ooOol05Woo00<007ooOol05Woo00<007ooOol0Lgoo00<007ooOol05Woo00<007ooOol05Woo00<0
07ooOol097oo000VOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`1bOol00`00Oomoo`0G
Ool00`00Oomoo`0FOol00`00Oomoo`0TOol000Ioo`D000Moo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo01Moo`03001oogoo01Ioo`03001oogoo075oo`03001oogoo01Ioo`03001oogoo01Mo
o`03001oogoo00aoo`<000Qoo`03001oogoo00Moo`40005oo`5oo`0027oo00<007ooOol01Woo00<0
07ooOol02Goo00<007ooOol01Woo00<007ooOol05goo00<007ooOol05Woo00<007ooOol0L7oo00<0
07ooOol05goo00<007ooOol05goo00<007ooOol037oo00<007ooOol01goo00<007ooOol02Goo0@00
0Goo00000`00Ool000020003Ool00`00Oomoo`05Ool00`00Oomoo`04Ool30004Ool00`00Oomoo`05
Ool00`00Oomoo`0HOol00`00Oomoo`0FOol00`00Oomoo`1_Ool00`00Oomoo`0FOol00`00Oomoo`0H
Ool00`00Oomoo`04Ool2000017oo000000000goo00<007ooOol01Goo00<007ooOol017oo0`0017oo
0@0000020003Ool01000Oomoo`001goo00<007ooOol00goo00D007ooOomoo`0000=oo`03001oogoo
00Eoo`03001oogoo01Uoo`03001oogoo01Ioo`03001oogoo06eoo`03001oogoo01Ioo`03001oogoo
01Uoo`03001oogoo00Eoo`8000=oo`04001oogoo0007Ool00`00Oomoo`03Ool01@00Oomoogoo0000
0goo0@0000000`00Oomoo`02Ool01000Oomoo`001goo00<007ooOol00goo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol06Goo00<007ooOol05Woo00<007ooOol0K7oo00<007ooOol05goo00<0
07ooOol06Goo00<007ooOol01Goo00<007ooOol00Woo00D007oo001oo`0000Ioo`03001oogoo00=o
o`03001oogoo00Eoo`40000000<007ooOol00Woo00@007oo000000Moo`03001oogoo00=oo`03001o
ogoo00Eoo`03001oogoo00Eoo`03001oogoo01Yoo`03001oogoo01Ioo`03001oogoo06]oo`03001o
ogoo01Ioo`03001oogoo01Yoo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0007Ool00`00
Oomoo`03Ool00`00Oomoo`05Ool10000008000=oo`03001oogoo00Qoo`03001oogoo00=oo`03001o
ogoo00Eoo`03001oogoo00Eoo`03001oogoo01Yoo`03001oogoo01Ioo`03001oogoo06Yoo`03001o
ogoo01Moo`03001oogoo01Yoo`03001oogoo00Eoo`8000=oo`03001oogoo00Qoo`03001oogoo00=o
o`03001oogoo00Eoo`40000000<007oo00000P002goo00<007ooOol00Woo1@0017oo00<007ooOol0
1Goo00<007ooOol06goo00<007ooOol05Woo00<007ooOol0JGoo00<007ooOol05Woo00<007ooOol0
6goo00<007ooOol01Goo00<007oo00000P002goo00<007ooOol00Woo1@0017oo0@0000000`00Oomo
o`0>Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`0KOol00`00Oomo
o`0FOol00`00Oomoo`1XOol00`00Oomoo`0GOol00`00Oomoo`0KOol00`00Oomoo`05Ool00`00Oomo
o`0>Ool00`00Oomoo`02Ool00`00Oomoo`04Ool10001Ool00003001oogoo00moo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo01aoo`03001oogoo01Ioo`03001oogoo06Moo`03001oogoo01Io
o`03001oogoo01aoo`03001oogoo00Aoo`80015oo`03001oogoo00Moo`40005oo`5oo`009Woo00<0
07ooOol07Goo00<007ooOol05Woo00<007ooOol0IGoo00<007ooOol05Woo00<007ooOol07Goo00<0
07ooOol097oo000VOol00`00Oomoo`0MOol00`00Oomoo`0FOol00`00Oomoo`0AOol20002Ool5000e
Ool30002Ool2000>Ool00`00Oomoo`0GOol00`00Oomoo`0MOol00`00Oomoo`0TOol002Ioo`03001o
ogoo01ioo`03001oogoo01Ioo`03001oogoo00Qoo`80009oo`<000=oo`05001oogooOol0000_Ool2
0002Ool300000goo001oo`05Ool00`00Oomoo`0;Ool00`00Oomoo`0FOol00`00Oomoo`0NOol00`00
Oomoo`0TOol002Ioo`03001oogoo01ioo`03001oogoo01Ioo`03001oogoo00Uoo`04001oogoo0004
Ool00`00Oomoo`02Ool00`00Oomoo`0^Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol0
2goo00<007ooOol05goo00<007ooOol07Woo00<007ooOol097oo000VOol00`00Oomoo`0OOol00`00
Oomoo`0FOol00`00Oomoo`08Ool00`00Ool00006Ool01@00Oomoogoo0000<7oo00<007oo00001Goo
00<007ooOol00goo00<007ooOol02Woo00<007ooOol05Woo00<007ooOol07goo00<007ooOol097oo
000VOol00`00Oomoo`0OOol00`00Oomoo`0FOol00`00Oomoo`08Ool30004Ool00`00Ool00003Ool0
0`00Oomoo`0^Ool30004Ool00`00Ool00002Ool00`00Ool0000;Ool00`00Oomoo`0GOol00`00Oomo
o`0OOol00`00Oomoo`0TOol002Ioo`03001oogoo021oo`03001oogoo01Ioo`03001oogoo00Moo`04
001oogoo0004Ool01000Oomoogoo0P00<7oo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo
00Uoo`03001oogoo01Moo`03001oogoo021oo`03001oogoo02Aoo`009Woo00<007ooOol08Goo00<0
07ooOol05Woo00<007ooOol01Woo00<007oo00000`00>7oo00<007oo00000`004goo00<007ooOol0
5Woo00<007ooOol08Goo00<007ooOol097oo000VOol00`00Oomoo`0QOol00`00Oomoo`0FOol00`00
Oomoo`06Ool00`00Oomoo`0kOol00`00Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0QOol00`00
Oomoo`0TOol002Ioo`03001oogoo029oo`03001oogoo01Ioo`03001oogoo00Aoo`8003aoo`8001Mo
o`03001oogoo01Ioo`03001oogoo029oo`03001oogoo02Aoo`009Woo00<007ooOol08Woo00<007oo
Ool05Woo00<007ooOol0FWoo00<007ooOol05goo00<007ooOol08Woo00<007ooOol097oo000VOol0
0`00Oomoo`0SOol00`00Oomoo`0FOol00`00Oomoo`1IOol00`00Oomoo`0FOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol002Ioo`03001oogoo02=oo`03001oogoo01Ioo`03001oogoo05Qoo`03001oogoo
01Moo`03001oogoo02=oo`03001oogoo02Aoo`009Woo00<007ooOol097oo00<007ooOol05Woo00<0
07ooOol0EWoo00<007ooOol05goo00<007ooOol097oo00<007ooOol097oo000VOol00`00Oomoo`0U
Ool00`00Oomoo`0FOol00`00Oomoo`1EOol00`00Oomoo`0FOol00`00Oomoo`0UOol00`00Oomoo`0T
Ool002Ioo`03001oogoo02Eoo`03001oogoo01Ioo`03001oogoo05Aoo`03001oogoo01Moo`03001o
ogoo02Eoo`03001oogoo02Aoo`009Woo00<007ooOol09Woo00<007ooOol05Woo00<007ooOol0Dgoo
00<007ooOol05Woo00<007ooOol09Woo00<007ooOol097oo000VOol00`00Oomoo`0VOol00`00Oomo
o`0FOol00`00Oomoo`0XOol00`00Oomoo`0WOol00`00Oomoo`0GOol00`00Oomoo`0VOol00`00Oomo
o`0TOol0051oo`03001oogoo01Ioo`03001oogoo02Moo`03001oogoo02Moo`03001oogoo01Ioo`03
001oogoo04ioo`00D7oo00<007ooOol05goo00<007ooOol09Goo0P00:7oo00<007ooOol05goo00<0
07ooOol0CWoo001AOol00`00Oomoo`0FOol00`00Oomoo`0UOol3000VOol00`00Oomoo`0GOol00`00
Oomoo`1?Ool0059oo`03001oogoo01Ioo`03001oogoo02Aoo`<002Ioo`03001oogoo01Ioo`03001o
ogoo051oo`00DWoo00<007ooOol05Woo00<007ooOol097oo0`009Goo00<007ooOol05goo00<007oo
Ool0D7oo001COol00`00Oomoo`0FOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0FOol00`00Oomo
o`1AOol005=oo`03001oogoo01Ioo`03001oogoo029oo`@002Aoo`03001oogoo01Moo`03001oogoo
055oo`00E7oo00<007ooOol05Woo00<007ooOol08Goo1@008Woo00<007ooOol05goo00<007ooOol0
DWoo0013Ool500000goo00000009Ool00`00Oomoo`0GOol00`00Oomoo`0POol5000ROol00`00Oomo
o`0GOol00`00Oomoo`0;Ool20003Ool3000oOol003aoo`80009oo`<0009oo`03001oogoo00=oo`03
001oogoo00Moo`03001oogoo01Ioo`03001oogoo01moo`H0025oo`03001oogoo01Moo`03001oogoo
00Aoo`80009oo`<000=oo`04001oogoo0011Ool003eoo`04001oogoo0004Ool00`00Oomoo`02Ool0
0`00Oomoo`09Ool00`00Oomoo`0FOol00`00Oomoo`0NOol6000QOol00`00Oomoo`0FOol00`00Oomo
o`06Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol0?Woo000mOol00`00Ool00005Ool0
0`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`0FOol00`00Oomoo`0NOol6000POol00`00Oomo
o`0GOol00`00Oomoo`06Ool00`00Ool00006Ool01@00Oomoogoo0000@7oo000mOol30005Ool01`00
Oomoogoo001oo`0000]oo`03001oogoo01Ioo`03001oogoo01eoo`L001moo`03001oogoo01Ioo`03
001oogoo00Moo`<000Aoo`03001oo`00009oo`03001oo`0003moo`00?Goo00@007ooOol000=oo`80
00Aoo`03001oogoo00Yoo`03001oogoo01Ioo`03001oogoo01aoo`P001ioo`03001oogoo01Moo`03
001oogoo00Moo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`0nOol003eoo`03001oo`00
00<001Eoo`03001oogoo01Ioo`03001oogoo01]oo`P001eoo`03001oogoo01Moo`03001oogoo00Qo
o`03001oo`0000<004Qoo`00?Goo00<007ooOol067oo00<007ooOol05goo00<007ooOol07Woo00<0
07ooOol07Woo00<007ooOol05goo00<007ooOol027oo00<007ooOol0Bgoo000lOol2000KOol00`00
Oomoo`0FOol00`00Oomoo`0NOol00`00Oomoo`0MOol00`00Oomoo`0GOol00`00Oomoo`08Ool2001=
Ool005Yoo`03001oogoo01Ioo`03001oogoo01eoo`03001oogoo01eoo`03001oogoo01Ioo`03001o
ogoo05Qoo`00FWoo00<007ooOol05Woo00<007ooOol07Goo00<007ooOol077oo00<007ooOol05goo
00<007ooOol0F7oo001KOol00`00Oomoo`0FOol00`00Oomoo`0LOol00`00Oomoo`0KOol00`00Oomo
o`0GOol00`00Oomoo`1IOol005]oo`03001oogoo01Ioo`03001oogoo01aoo`03001oogoo01]oo`03
001oogoo01Moo`03001oogoo05Uoo`00G7oo00<007ooOol05Woo00<007ooOol06goo00<007ooOol0
6Woo00<007ooOol05goo00<007ooOol0FWoo001LOol00`00Oomoo`0GOol00`00Oomoo`0?Ool20004
Ool00`00Oomoo`02Ool00`00Oomoo`0JOol00`00Oomoo`0GOol00`00Oomoo`1JOol005eoo`03001o
ogoo01Ioo`03001oogoo00Qoo`80009oo`<0009oo`06001oogoo001oo`000goo00<007ooOol06Goo
00<007ooOol05goo00<007ooOol0Fgoo001NOol00`00Oomoo`0FOol00`00Oomoo`08Ool01000Oomo
o`000goo00L007ooOomoo`00Ool00003Ool00`00Oomoo`0IOol00`00Oomoo`0FOol00`00Oomoo`1L
Ool005ioo`03001oogoo01Ioo`03001oogoo00Qoo`03001oo`0000Eoo`06001oogoo001oo`000goo
00<007ooOol067oo00<007ooOol05goo00<007ooOol0G7oo001OOol00`00Oomoo`0FOol00`00Oomo
o`07Ool30003Ool00`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`0GOol00`00Oomoo`0GOol0
0`00Oomoo`1MOol005moo`03001oogoo01Ioo`03001oogoo00Moo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`1MOol0061oo`03
001oogoo01Ioo`03001oogoo00Ioo`03001oo`0000<000]oo`03001oogoo01Ioo`03001oogoo01Mo
o`03001oogoo05ioo`00H7oo00<007ooOol05goo00<007ooOol01Goo00<007ooOol03Woo00<007oo
Ool05Woo00<007ooOol05goo00<007ooOol0GWoo001QOol00`00Oomoo`0FOol00`00Oomoo`04Ool2
000@Ool00`00Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`1OOol0069oo`03001oogoo01Ioo`03
001oogoo01Eoo`03001oogoo01Aoo`03001oogoo01Moo`03001oogoo061oo`00HWoo00<007ooOol0
5Woo00<007ooOol05Goo00<007ooOol057oo00<007ooOol05goo00<007ooOol0H7oo001SOol00`00
Oomoo`0FOol00`00Oomoo`0DOol00`00Oomoo`0COol00`00Oomoo`0GOol00`00Oomoo`1QOol006=o
o`03001oogoo01Ioo`03001oogoo01Aoo`03001oogoo01=oo`03001oogoo01Moo`03001oogoo065o
o`00I7oo00<007ooOol05Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol05goo00<007oo
Ool0HWoo001TOol00`00Oomoo`0GOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0GOol0
0`00Oomoo`1ROol006Eoo`03001oogoo01Ioo`03001oogoo019oo`03001oogoo015oo`03001oogoo
01Moo`03001oogoo06=oo`00IWoo00<007ooOol05Woo00<007ooOol04Goo00<007ooOol047oo00<0
07ooOol05goo00<007ooOol0I7oo001VOol00`00Oomoo`0FOol00`00Oomoo`0AOol00`00Oomoo`0@
Ool00`00Oomoo`0GOol00`00Oomoo`1TOol006Moo`03001oogoo01Ioo`03001oogoo011oo`03001o
ogoo00moo`03001oogoo01Moo`03001oogoo06Eoo`00Igoo00<007ooOol05goo00<007ooOol03goo
00<007ooOol03goo00<007ooOol05goo00<007ooOol0IGoo001XOol00`00Oomoo`0FOol00`00Oomo
o`0?Ool00`00Oomoo`0>Ool00`00Oomoo`0GOol00`00Oomoo`1VOol006Qoo`03001oogoo01Moo`03
001oogoo00ioo`03001oogoo00eoo`03001oogoo01Qoo`03001oogoo06Ioo`00JGoo00<007ooOol0
5Woo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol05goo00<007ooOol0Igoo001YOol00`00
Oomoo`0GOol00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0HOol00`00Oomoo`1WOol006Yo
o`03001oogoo01Ioo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo01Moo`03001oogoo06Qo
o`00Jgoo00<007ooOol05Woo00<007ooOol037oo00<007ooOol01goo0P000Woo00<007ooOol05goo
00<007ooOol0JGoo001[Ool00`00Oomoo`0GOol00`00Oomoo`0;Ool00`00Oomoo`07Ool5000IOol0
0`00Oomoo`1YOol006aoo`03001oogoo01Ioo`03001oogoo00]oo`03001oogoo00Ioo`L001Moo`03
001oogoo06Yoo`00K7oo00<007ooOol05goo00<007ooOol02Woo00<007ooOol01Woo2@005Goo00<0
07ooOol0JWoo001]Ool00`00Oomoo`0FOol00`00Oomoo`0:Ool00`00Oomoo`06Ool8000EOol00`00
Oomoo`1[Ool006eoo`03001oogoo01Moo`03001oogoo00Uoo`03001oogoo00Ioo`L001Ioo`03001o
ogoo06]oo`00KWoo00<007ooOol05Woo00<007ooOol02Goo00<007ooOol01Goo1`005Woo00<007oo
Ool0K7oo001_Ool00`00Oomoo`0FOol00`00Oomoo`08Ool00`00Oomoo`05Ool6000FOol00`00Oomo
o`1]Ool006moo`03001oogoo01Moo`03001oogoo00Moo`03001oogoo00Eoo`D001Moo`03001oogoo
06eoo`00L7oo00<007ooOol05Woo00<007ooOol01goo00<007ooOol017oo1@005goo00<007ooOol0
KWoo001`Ool00`00Oomoo`0GOol00`00Oomoo`06Ool00`00Oomoo`04Ool4000HOol00`00Oomoo`1^
Ool0075oo`03001oogoo01Ioo`03001oogoo00Ioo`03001oogoo00Aoo`<001Qoo`03001oogoo06mo
o`00LGoo00<007ooOol00Woo00<007ooOol04Woo00<007ooOol01Goo00<007ooOol017oo0P006Goo
00<007ooOol0Kgoo001bOol00`00Ool00002000DOol00`00Oomoo`05Ool00`00Oomoo`03Ool2000I
Ool00`00Oomoo`1`Ool0079oo`H001Aoo`04001oogooOol60003Ool00`00Oomoo`0GOol00`00Oomo
o`1aOol0071oo`P001=oo`D000Ioo`D001Qoo`03001oogoo075oo`00Kgoo2@0047oo0`0047oo0P00
5Goo00<007ooOol0LWoo001`Ool8000>Ool2000EOol3000BOol00`00Oomoo`1bOol0075oo`P000]o
o`8001Yoo`<000ioo`03001oogoo07=oo`00LWoo1`002Woo00<007ooOol07Goo0P0037oo00<007oo
Ool0Lgoo001cOol60008Ool2000ROol00`00Oomoo`08Ool00`00Oomoo`1dOol007Aoo`D000Ioo`80
02Eoo`03001oogoo00Ioo`03001oogoo07Eoo`00MGoo1@0017oo00<007ooOol09Woo00<007ooOol0
1Goo00<007ooOol0MGoo001fOol40003Ool00`00Oomoo`0XOol00`00Oomoo`03Ool00`00Oomoo`1f
Ool007Moo`<0009oo`03001oogoo02Yoo`03001oogoo009oo`03001oogoo07Ioo`00N7oo0P0000=o
o`00Ool0;Goo00@007ooOol007Uoo`00NGoo0`00;goo00<007oo0000NGoo001jOol00`00Oomoo`0^
Ool2001jOol007Uoo`03001oogoo031oo`03001oogoo07Qoo`00N7oo00<007ooOol0<Woo00<007oo
Ool0Mgoo001hOol00`00Oomoo`0bOol00`00Oomoo`1gOol007Moo`03001oogoo03Aoo`03001oogoo
07Ioo`00Mgoo00<007ooOol0=7oo00<007ooOol0MWoo001fOol00`00Oomoo`0fOol00`00Oomoo`1e
Ool007Ioo`03001oogoo03Ioo`03001oogoo07Eoo`00MGoo00<007ooOol0>7oo00<007ooOol0M7oo
001eOol00`00Oomoo`0hOol00`00Oomoo`1dOol007Eoo`03001oogoo03Qoo`03001oogoo07Aoo`00
MGoo00<007ooOol0>Goo00<007ooOol0Lgoo001eOol00`00Oomoo`0iOol00`00Oomoo`1cOol007Ao
o`03001oogoo03Yoo`03001oogoo07=oo`00M7oo00<007ooOol0>goo00<007ooOol0LWoo001dOol0
0`00Oomoo`0kOol00`00Oomoo`1bOol007Aoo`03001oogoo01Yoo`<001ioo`03001oogoo079oo`00
M7oo00<007ooOol06Goo00D007ooOomoo`0001eoo`03001oogoo079oo`00M7oo00<007ooOol07Goo
00<007ooOol06goo00<007ooOol0LWoo001dOol00`00Oomoo`0MOol00`00Oomoo`0KOol00`00Oomo
o`1bOol007Aoo`03001oogoo01]oo`8001ioo`03001oogoo079oo`00M7oo00<007ooOol07Goo00<0
07ooOol06goo00<007ooOol0LWoo001dOol00`00Oomoo`0IOol01@00Oomoogoo00007Goo00<007oo
Ool0LWoo001dOol00`00Oomoo`0JOol3000NOol00`00Oomoo`1bOol007Aoo`03001oogoo03Yoo`03
001oogoo07=oo`00M7oo00<007ooOol0>Woo00<007ooOol0Lgoo001eOol00`00Oomoo`0iOol00`00
Oomoo`1cOol007Eoo`03001oogoo03Qoo`03001oogoo07Aoo`00MGoo00<007ooOol0>7oo00<007oo
Ool0M7oo001eOol00`00Oomoo`0hOol00`00Oomoo`1dOol007Ioo`03001oogoo03Ioo`03001oogoo
07Eoo`00MWoo00<007ooOol0=Woo00<007ooOol0MGoo001gOol00`00Oomoo`0dOol00`00Oomoo`1f
Ool007Moo`03001oogoo03Aoo`03001oogoo07Ioo`00N7oo00<007ooOol0<Woo00<007ooOol0Mgoo
001hOol00`00Oomoo`0bOol00`00Oomoo`1gOol007Uoo`03001oogoo031oo`03001oogoo07Qoo`00
NWoo00<007ooOol0;goo00<007ooOol0N7oo001kOol00`00Oomoo`0]Ool00`00Oomoo`1iOol007]o
o`03001oogoo02eoo`03001oogoo07Uoo`00O7oo00<007ooOol0:Woo0P00O7oo001mOol00`00Oomo
o`0XOol00`00Oomoo`1lOol007ioo`03001oogoo02Ioo`03001oogoo07eoo`00Ogoo0P009Goo00<0
07ooOol0OWoo0021Ool00`00Oomoo`0QOol00`00Oomoo`1oOol0089oo`03001oogoo01ioo`80089o
o`00Pgoo0P0077oo0P00Q7oo0025Ool3000GOol20026Ool008Qoo`<0019oo`8008Qoo`00Rgoo1@00
1goo1P00RWoo002@Ool7002@Ool009=oo`03001oogoo095oo`00TWoo0P00Tgoo002BOol3002BOol0
099oo`<0099oo`00TWoo0`00TWoo002AOol01000Ool00000TWoo002AOol01000Ool00000TWoo002A
Ool01@00Ool007oo0000TGoo002@Ool01P00Oomoo`00Ool0095oo`00T7oo00H007ooOol007oo002A
Ool0091oo`06001oogoo001oo`00TGoo002@Ool01000Oomoo`000Woo00<007ooOol0SWoo002?Ool0
1@00Oomoogoo00000Woo00<007ooOol0SWoo002?Ool01@00Oomoogoo00000Woo00<007ooOol0SWoo
002COol00`00Oomoo`2AOol009=oo`03001oogoo095oo`00Tgoo00<007ooOol0TGoo002COol00`00
Oomoo`2AOol009=oo`03001oogoo095oo`00Tgoo00<007ooOol0TGoo002COol00`00Oomoo`2AOol0
09=oo`03001oogoo095oo`00Tgoo00<007ooOol0TGoo002COol00`00Oomoo`2AOol009=oo`03001o
ogoo095oo`00Tgoo00<007ooOol0TGoo002COol00`00Oomoo`2AOol009=oo`03001oogoo095oo`00
Tgoo00<007ooOol0TGoo002COol00`00Oomoo`2AOol009=oo`03001oogoo095oo`00Tgoo00<007oo
Ool0TGoo002COol00`00Oomoo`2AOol009=oo`03001oogoo095oo`00LGoo0P002Goo00<007ooOol0
1goo00<007ooOol02Woo00<007ooOol0TGoo001cOol00`00Oomoo`05Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`2AOol006Qoo`800004Ool000000004Ool00`00Oomoo`05Ool00`00Oomo
o`03Ool30005Ool00`00Oomoo`08Ool00`00Oomoo`2AOol006Uoo`8000=oo`03001oogoo009oo`03
001oogoo00Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`08Ool00`00Oomoo`2A
Ool006Uoo`03001oogoo009oo`06001oogoo001oo`001Woo00<007ooOol00Woo00<007ooOol01Woo
00<007ooOol027oo00<007ooOol0TGoo001YOol00`00Oomoo`02Ool01@00Oomoogoo00001goo00<0
07ooOol00Woo00<007ooOol01Woo00<007ooOol027oo00<007ooOol0TGoo001YOol20003Ool00`00
Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`2AOol006Uo
o`03001oo`00008000aoo`04001oogooOol50005Ool00`00Oomoo`08Ool00`00Oomoo`2AOol006Uo
o`03001oogoo00moo`05001oogooOol00007Ool00`00Oomoo`09Ool00`00Oomoo`2AOol006Qoo`80
019oo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo095oo`00Tgoo00<007ooOol0TGoo002C
Ool00`00Oomoo`2AOol009=oo`03001oogoo095oo`00Tgoo00<007ooOol0TGoo002COol00`00Oomo
o`2AOol009=oo`03001oogoo095oo`00Tgoo00<007ooOol0TGoo002COol00`00Oomoo`2AOol009=o
o`03001oogoo095oo`00Tgoo00<007ooOol0TGoo002COol00`00Oomoo`2AOol009=oo`03001oogoo
095oo`00Tgoo00<007ooOol0TGoo002COol00`00Oomoo`2AOol009=oo`03001oogoo095oo`00Tgoo
00<007ooOol0TGoo002COol00`00Oomoo`2AOol009=oo`03001oogoo095oo`00ogoo:7oo003oOolX
Ool00?moobQoo`00ogoo:7oo003oOolXOol00?moobQoo`00ogoo:7oo003oOolXOol00?moobQoo`00
\
\>"],
  ImageRangeCache->{{{127.625, 363}, {373.75, 59.625}} -> {-3.17454, \
-0.456021, 0.0200746, 0.0200746}}],

Cell["This model is represented by the follow ODE System ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\_1' \((t)\)\)\(\ \)\(=\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_1\)(
          t)\  - \ \((k\_10\  + \ k\_12\  + \ k\_13)\)\ \(\(x\_1\)(
            t)\)\ \  + \ 
        k\_21\ \(\(x\_2\)(t)\)\  + \ \(\(k\_31\)\(\ \)\(\(x\_3\)(
            t)\)\(\ \)\)\)]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\_2' \((t)\)\)\(\ \)\(=\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_2\)(t)\  + \ 
        k\_12\ \(\(x\_1\)(
            t)\)\ \  - \ \((k\_20\  + \ k\_21\  + \ k\_23)\)\ \(\(x\_2\)(
            t)\)\  + \ k\_32\ \(\(x\_3\)(t)\)\)]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\_3' \((t)\)\)\(\ \)\(=\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`b\_3\ \((t)\)\  + \ k\_13\ \(\(x\_1\)(t)\)\ \  + \ 
        k\_23\ \(\(x\_2\)(
            t)\)\  - \ \(\((k\_30\  + \ k\_31\  + \ k\_32)\)\(\ \)\(\(x\_3\)(
            t)\)\(\ \)\)\)]]
}], "NumberedEquation"],

Cell["in matrix notation ", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{
                StyleBox["x",
                  FontWeight->"Bold"], 
                StyleBox["'",
                  FontWeight->"Plain"]}],
              FontSlant->"Plain"], \((t)\)}], " ", "=", 
          RowBox[{
            StyleBox[
              RowBox[{
                StyleBox["A",
                  FontSlant->"Plain"], " ", 
                StyleBox["x",
                  FontSlant->"Plain"]}],
              FontWeight->"Bold"], 
            StyleBox[" ",
              FontWeight->"Bold"], "+", " ", 
            RowBox[{
              StyleBox["b",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", "t", ")"}]}]}], ",", 
        " ", \(t \[GreaterEqual] 0\)}], TraditionalForm]], "DisplayFormula",
  TextAlignment->Left,
  TextJustification->0],

Cell["with", "Text"],

Cell[TextData[{
  StyleBox["x",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\((t)\) = \ {\(x\_1\)(t), \ \(x\_2\)(t), \ \
\(x\_1\)(t)}\^T\)]],
  " \n\n",
  StyleBox["B",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\(\((t)\)\(\ \)\(=\)\(\ \)\({\(b\_1\)(t), \ \(b\_2\)(
                t), \(b\_3\)(t)}\^T\)\(\ \)\)\)]],
  "\n\nwhere  ",
  StyleBox["A",
    FontWeight->"Bold"],
  " is "
}], "DisplayFormula",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    \(model\  = 
      CompartMatrix[
        3, \ {{1, 2, k\_12}, {2, 1, k\_21}, {1, 3, k\_13}, {3, 1, k\_31}, {3, 
            2, k\_32}, {2, 3, k\_23}, {3, 3, k\_33}, {1, 0, \ k\_10}, {2, 0, 
            k\_20}, {3, 0, k\_30}}]; \)], "Input",
  CellLabel->"In[83]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(model // MatrixForm\)], "Input",
  CellLabel->"In[84]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(-k\_10\) - k\_12 - k\_13\), \(k\_21\), \(k\_31\)},
            {\(k\_12\), \(\(-k\_20\) - k\_21 - k\_23\), \(k\_32\)},
            {\(k\_13\), \(k\_23\), \(\(-k\_30\) - k\_31 - k\_32\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[84]//MatrixForm="]
}, Open  ]],

Cell["It assumed as initial condition:", "Text"],

Cell[BoxData[
    \(ic\  = {x\_10, \ x\_20, \ x\_30}; \)], "Input",
  CellLabel->"In[85]:="],

Cell["and as input", "Text"],

Cell[BoxData[
    \(input = {b\_1, \ b\_2, \ b\_3}; \)], "Input",
  CellLabel->"In[86]:="],

Cell["It can be represented by the system of diferential equation", "Text"],

Cell[BoxData[
    \(eq1 = ShowODE[model, \ ic, input, \ t, \ x]; \)], "Input",
  CellLabel->"In[87]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(eq1 // TableForm\) // TraditionalForm\)], "Input",
  CellLabel->"In[88]:="],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              RowBox[{
                RowBox[{
                  SuperscriptBox[\(x\_1\), "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], 
                "\[LongEqual]", \(b\_1 + \((\(-k\_10\) - k\_12 - 
                        k\_13)\)\ \(\(x\_1\)(t)\) + k\_21\ \(\(x\_2\)(t)\) + 
                  k\_31\ \(\(x\_3\)(t)\)\)}]},
            {
              RowBox[{
                RowBox[{
                  SuperscriptBox[\(x\_2\), "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], 
                "\[LongEqual]", \(b\_2 + 
                  k\_12\ \(\(x\_1\)(
                      t)\) + \((\(-k\_20\) - k\_21 - k\_23)\)\ \(\(x\_2\)(
                      t)\) + k\_32\ \(\(x\_3\)(t)\)\)}]},
            {
              RowBox[{
                RowBox[{
                  SuperscriptBox[\(x\_3\), "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], 
                "\[LongEqual]", \(b\_3 + k\_13\ \(\(x\_1\)(t)\) + 
                  k\_23\ \(\(x\_2\)(
                      t)\) + \((\(-k\_30\) - k\_31 - k\_32)\)\ \(\(x\_3\)(
                      t)\)\)}]},
            {\(\(x\_1\)(0) \[LongEqual] x\_10\)},
            {\(\(x\_2\)(0) \[LongEqual] x\_20\)},
            {\(\(x\_3\)(0) \[LongEqual] x\_30\)}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {
          Equal[ 
            Derivative[ 1][ 
              Subscript[ x, 1]][ t], 
            Plus[ 
              Subscript[ b, 1], 
              Times[ 
                Plus[ 
                  Times[ -1, 
                    Subscript[ k, 10]], 
                  Times[ -1, 
                    Subscript[ k, 12]], 
                  Times[ -1, 
                    Subscript[ k, 13]]], 
                Subscript[ x, 1][ t]], 
              Times[ 
                Subscript[ k, 21], 
                Subscript[ x, 2][ t]], 
              Times[ 
                Subscript[ k, 31], 
                Subscript[ x, 3][ t]]]], 
          Equal[ 
            Derivative[ 1][ 
              Subscript[ x, 2]][ t], 
            Plus[ 
              Subscript[ b, 2], 
              Times[ 
                Subscript[ k, 12], 
                Subscript[ x, 1][ t]], 
              Times[ 
                Plus[ 
                  Times[ -1, 
                    Subscript[ k, 20]], 
                  Times[ -1, 
                    Subscript[ k, 21]], 
                  Times[ -1, 
                    Subscript[ k, 23]]], 
                Subscript[ x, 2][ t]], 
              Times[ 
                Subscript[ k, 32], 
                Subscript[ x, 3][ t]]]], 
          Equal[ 
            Derivative[ 1][ 
              Subscript[ x, 3]][ t], 
            Plus[ 
              Subscript[ b, 3], 
              Times[ 
                Subscript[ k, 13], 
                Subscript[ x, 1][ t]], 
              Times[ 
                Subscript[ k, 23], 
                Subscript[ x, 2][ t]], 
              Times[ 
                Plus[ 
                  Times[ -1, 
                    Subscript[ k, 30]], 
                  Times[ -1, 
                    Subscript[ k, 31]], 
                  Times[ -1, 
                    Subscript[ k, 32]]], 
                Subscript[ x, 3][ t]]]], 
          Equal[ 
            Subscript[ x, 1][ 0], 
            Subscript[ x, 10]], 
          Equal[ 
            Subscript[ x, 2][ 0], 
            Subscript[ x, 20]], 
          Equal[ 
            Subscript[ x, 3][ 0], 
            Subscript[ x, 30]]}]], TraditionalForm]], "Output",
  CellLabel->"Out[88]//TraditionalForm="]
}, Open  ]],

Cell[TextData[{
  "We consider ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_1\)(t)\  = \ 2\ Exp[\(-0.1\)\ t]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_2\)(t) = 2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(b\_3\)(t)\  = 0.2  Cos[2\ t]\)\)\)]],
  " that is equivalent to take as initial conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(x\_1\)(0)\  = 1\)\(,\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(x\_2\)(0) = 2\)\(\ \)\(,\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_3\)(0)\  = \ 3\)]],
  ". Also we give values for constant coefficients.  "
}], "Text"],

Cell[BoxData[
    \(k /: k\_10 = 0.1; k /: k\_20 = 0.2; k /: k\_30 = 0.5; k /: k\_12 = 1; \ 
    k /: k\_13 = 2; \ k /: k\_21 = 1.4; k /: k\_23 = 1.1; ; \ 
    k /: k\_31 = 1.1; k /: k\_32 = 0.8; \)], "Input",
  CellLabel->"In[89]:="],

Cell["Here is the solution", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({x1[t1_], x2[t1_], x3[t1_]} = {x\_1[t1], x\_2[t1], x\_3[t1]} /. 
        SystemDSolve[
          model, {1, 2, 3}, {2\ Exp[\(-0.1\)\ t], 2, 0.2  Cos[2\ t]\ }, \ 
          t, \ t1, \ x]\)], "Input",
  CellLabel->"In[90]:="],

Cell[BoxData[
    \({\(\(1.9826464208242947`\)\(\[InvisibleSpace]\)\) - 
        0.9837287922772096`\ \[ExponentialE]\^\(\(-4.346311682563699`\)\ t1\) \
+ 0.004081989885034002`\ \[ExponentialE]\^\(\(-3.5553585022284833`\)\ t1\) - 
        3.5011517944290516`\ \[ExponentialE]\^\(\(-0.2983298152078162`\)\ \
t1\) + 3.5051546391752586`\ \[ExponentialE]\^\(\(-0.1`\)\ t1\) - 
        0.007002463178325058`\ Cos[2.`\ t1] + 
        0.022469245583020145`\ Sin[
            2.`\ t1], \(\(2.2733188720173545`\)\(\[InvisibleSpace]\)\) + 
        0.1465758309145742`\ \[ExponentialE]\^\(\(-4.346311682563699`\)\ t1\) \
+ 0.01676761104136903`\ \[ExponentialE]\^\(\(-3.5553585022284833`\)\ t1\) - 
        3.109790354459095`\ \[ExponentialE]\^\(\(-0.2983298152078162`\)\ t1\) \
+ 2.6804123711340218`\ \[ExponentialE]\^\(\(-0.1`\)\ t1\) - 
        0.007284330648223914`\ Cos[2.`\ t1] + 
        0.018488585048029253`\ Sin[
            2.`\ t1], \(\(2.6941431670281997`\)\(\[InvisibleSpace]\)\) + 
        0.9280241118263296`\ \[ExponentialE]\^\(\(-4.346311682563699`\)\ t1\) \
- 0.023030385689161253`\ \[ExponentialE]\^\(\(-3.5553585022284833`\)\ t1\) - 
        4.959423726037088`\ \[ExponentialE]\^\(\(-0.2983298152078162`\)\ t1\) \
+ 4.3298969072164954`\ \[ExponentialE]\^\(\(-0.1`\)\ t1\) + 
        0.030389925655223728`\ Cos[2.`\ t1] + 
        0.052523244178883294`\ Sin[2.`\ t1]}\)], "Output",
  CellLabel->"Out[90]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{x1[t], x2[t], x3[t]}, \ {t, 0, 100}, \[IndentingNewLine]\ 
      PlotStyle \[Rule] {{AbsoluteThickness[2]}, {AbsoluteThickness[
              0.5]}, {AbsoluteThickness[1.5]}}, \ 
      AxesLabel \[Rule] {"\<days\>", \ "\<r\>"}, 
      PlotLegend \[Rule] {"\<x1\>", "\<x2\>", "\<x3\>"}, 
      LegendPosition \[Rule] {0, \ 0.3}, \ 
      LegendSize \[Rule] {0.3, \ 0.3}]\)], "Input",
  CellLabel->"In[91]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 -0.163829 0.178541 [
[.21429 .00221 -6 -9 ]
[.21429 .00221 6 0 ]
[.40476 .00221 -6 -9 ]
[.40476 .00221 6 0 ]
[.59524 .00221 -6 -9 ]
[.59524 .00221 6 0 ]
[.78571 .00221 -6 -9 ]
[.78571 .00221 6 0 ]
[.97619 .00221 -9 -9 ]
[.97619 .00221 9 0 ]
[1.025 .01471 0 -6.25 ]
[1.025 .01471 28 6.25 ]
[.01131 .10398 -18 -4.5 ]
[.01131 .10398 0 4.5 ]
[.01131 .19325 -6 -4.5 ]
[.01131 .19325 0 4.5 ]
[.01131 .28252 -18 -4.5 ]
[.01131 .28252 0 4.5 ]
[.01131 .37179 -6 -4.5 ]
[.01131 .37179 0 4.5 ]
[.01131 .46106 -18 -4.5 ]
[.01131 .46106 0 4.5 ]
[.01131 .55033 -6 -4.5 ]
[.01131 .55033 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01471 m
.21429 .02096 L
s
[(20)] .21429 .00221 0 1 Mshowa
.40476 .01471 m
.40476 .02096 L
s
[(40)] .40476 .00221 0 1 Mshowa
.59524 .01471 m
.59524 .02096 L
s
[(60)] .59524 .00221 0 1 Mshowa
.78571 .01471 m
.78571 .02096 L
s
[(80)] .78571 .00221 0 1 Mshowa
.97619 .01471 m
.97619 .02096 L
s
[(100)] .97619 .00221 0 1 Mshowa
.125 Mabswid
.07143 .01471 m
.07143 .01846 L
s
.11905 .01471 m
.11905 .01846 L
s
.16667 .01471 m
.16667 .01846 L
s
.2619 .01471 m
.2619 .01846 L
s
.30952 .01471 m
.30952 .01846 L
s
.35714 .01471 m
.35714 .01846 L
s
.45238 .01471 m
.45238 .01846 L
s
.5 .01471 m
.5 .01846 L
s
.54762 .01471 m
.54762 .01846 L
s
.64286 .01471 m
.64286 .01846 L
s
.69048 .01471 m
.69048 .01846 L
s
.7381 .01471 m
.7381 .01846 L
s
.83333 .01471 m
.83333 .01846 L
s
.88095 .01471 m
.88095 .01846 L
s
.92857 .01471 m
.92857 .01846 L
s
.25 Mabswid
0 .01471 m
1 .01471 L
s
gsave
1.025 .01471 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10398 m
.03006 .10398 L
s
[(1.5)] .01131 .10398 1 0 Mshowa
.02381 .19325 m
.03006 .19325 L
s
[(2)] .01131 .19325 1 0 Mshowa
.02381 .28252 m
.03006 .28252 L
s
[(2.5)] .01131 .28252 1 0 Mshowa
.02381 .37179 m
.03006 .37179 L
s
[(3)] .01131 .37179 1 0 Mshowa
.02381 .46106 m
.03006 .46106 L
s
[(3.5)] .01131 .46106 1 0 Mshowa
.02381 .55033 m
.03006 .55033 L
s
[(4)] .01131 .55033 1 0 Mshowa
.125 Mabswid
.02381 .03257 m
.02756 .03257 L
s
.02381 .05042 m
.02756 .05042 L
s
.02381 .06827 m
.02756 .06827 L
s
.02381 .08613 m
.02756 .08613 L
s
.02381 .12184 m
.02756 .12184 L
s
.02381 .13969 m
.02756 .13969 L
s
.02381 .15754 m
.02756 .15754 L
s
.02381 .1754 m
.02756 .1754 L
s
.02381 .21111 m
.02756 .21111 L
s
.02381 .22896 m
.02756 .22896 L
s
.02381 .24681 m
.02756 .24681 L
s
.02381 .26467 m
.02756 .26467 L
s
.02381 .30038 m
.02756 .30038 L
s
.02381 .31823 m
.02756 .31823 L
s
.02381 .33608 m
.02756 .33608 L
s
.02381 .35394 m
.02756 .35394 L
s
.02381 .38965 m
.02756 .38965 L
s
.02381 .4075 m
.02756 .4075 L
s
.02381 .42536 m
.02756 .42536 L
s
.02381 .44321 m
.02756 .44321 L
s
.02381 .47892 m
.02756 .47892 L
s
.02381 .49677 m
.02756 .49677 L
s
.02381 .51463 m
.02756 .51463 L
s
.02381 .53248 m
.02756 .53248 L
s
.02381 .56819 m
.02756 .56819 L
s
.02381 .58604 m
.02756 .58604 L
s
.02381 .6039 m
.02756 .6039 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
2 Mabswid
.02381 .01472 m
.02499 .10332 L
.02605 .15673 L
.02729 .19903 L
.02846 .22743 L
.02954 .2475 L
.03053 .26257 L
.03279 .2891 L
.03506 .30946 L
.03756 .32737 L
.04262 .35494 L
.04755 .37653 L
.05285 .39784 L
.05526 .40665 L
.05783 .41487 L
.06025 .42106 L
.06139 .42336 L
.06244 .42512 L
.06378 .42683 L
.06448 .4275 L
.06522 .42806 L
.06647 .42865 L
.06718 .42881 L
.06784 .42886 L
.0686 .42882 L
.06932 .42868 L
.06997 .4285 L
.07068 .42825 L
.07373 .42692 L
.07512 .42637 L
.07643 .42598 L
.07708 .42585 L
.07779 .42577 L
.07857 .42574 L
.0793 .42577 L
.08049 .42593 L
.08181 .42626 L
.08445 .42712 L
.0851 .42733 L
.08581 .42753 L
.08709 .42777 L
.08834 .42782 L
.08949 .42763 L
.09074 .42715 L
.09144 .42673 L
.09211 .42624 L
.09344 .42495 L
.09488 .42313 L
.09995 .41403 L
.10458 .40494 L
Mistroke
.10704 .40103 L
.10936 .39827 L
.11064 .3971 L
.11203 .39609 L
.11445 .39472 L
.11677 .39348 L
.11804 .39266 L
.11922 .39174 L
.12131 .38956 L
.1236 .38627 L
.14434 .35183 L
.14678 .35054 L
.14936 .34874 L
.15071 .34746 L
.1522 .3457 L
.15482 .34164 L
.15959 .33193 L
.1621 .32656 L
.16473 .32152 L
.16712 .31791 L
.16848 .31635 L
.16974 .3152 L
.1709 .31439 L
.17195 .31382 L
.17317 .31332 L
.17432 .31294 L
.17641 .31232 L
.17756 .3119 L
.17863 .31141 L
.17979 .31072 L
.18106 .30972 L
.1833 .3073 L
.19232 .29151 L
.19451 .2879 L
.19688 .28488 L
.19823 .28363 L
.19948 .28278 L
.20066 .28223 L
.20191 .28187 L
.20316 .28168 L
.20434 .28161 L
.20499 .28158 L
.2057 .28156 L
.20694 .28147 L
.20766 .28138 L
.20842 .28122 L
.20907 .28103 L
.20978 .28076 L
.21044 .28043 L
.21115 .28 L
Mistroke
.21244 .27901 L
.21368 .27777 L
.21504 .27611 L
.21752 .27245 L
.22218 .26479 L
.2235 .26285 L
.22492 .26102 L
.22618 .2597 L
.22751 .25862 L
.22824 .25816 L
.22906 .25778 L
.22979 .25754 L
.23048 .25739 L
.23179 .2573 L
.23252 .25734 L
.23318 .25741 L
.23569 .25786 L
.23638 .25797 L
.23711 .25806 L
.23843 .2581 L
.23964 .25795 L
.24079 .2576 L
.24204 .25697 L
.24275 .25648 L
.24339 .25597 L
.24843 .24984 L
.2512 .24578 L
.25381 .24239 L
.255 .24115 L
.25625 .2401 L
.25691 .23967 L
.25763 .23929 L
.25889 .23886 L
.26004 .23872 L
.26128 .23879 L
.26244 .23903 L
.26351 .23936 L
.26576 .24017 L
.267 .24056 L
.26816 .24081 L
.26882 .24089 L
.26954 .2409 L
.27079 .24072 L
.27206 .24027 L
.27322 .2396 L
.27433 .23874 L
.27537 .23776 L
.27771 .23504 L
.28244 .22898 L
.28374 .22759 L
Mistroke
.28514 .22636 L
.28578 .22591 L
.28646 .22551 L
.28768 .22502 L
.28885 .22481 L
.28995 .22483 L
.29115 .22506 L
.29245 .22551 L
.29531 .22689 L
.29672 .22754 L
.29804 .22801 L
.29922 .22826 L
.30048 .22829 L
.3012 .22819 L
.30188 .22801 L
.30315 .22745 L
.3077 .22337 L
.31201 .21831 L
.31317 .21713 L
.3144 .21608 L
.31503 .21563 L
.31574 .21521 L
.31699 .2147 L
.31811 .21448 L
.31932 .21451 L
.32047 .21475 L
.32152 .21514 L
.32415 .21656 L
.3266 .21798 L
.32783 .21856 L
.32915 .21897 L
.32991 .21909 L
.33062 .21912 L
.33126 .21907 L
.33195 .21894 L
.33312 .21851 L
.33441 .21775 L
.33576 .21669 L
.33702 .21549 L
.34169 .21041 L
.34292 .20924 L
.34426 .20818 L
.34553 .20744 L
.34671 .20702 L
.34787 .20685 L
.34893 .20691 L
.35015 .20721 L
.3513 .2077 L
.35391 .20928 L
.35534 .21025 L
Mistroke
.35667 .21108 L
.35791 .21173 L
.35903 .21215 L
.36028 .2124 L
.36097 .21242 L
.36162 .21237 L
.36284 .21205 L
.36414 .21142 L
.36525 .21067 L
.36647 .20965 L
.37174 .20431 L
.37307 .20316 L
.37446 .2022 L
.37519 .20182 L
.37599 .20151 L
.37671 .20133 L
.37739 .20125 L
.37808 .20126 L
.37873 .20135 L
.37995 .2017 L
.38126 .20232 L
.38268 .20321 L
.38503 .2049 L
.38725 .20637 L
.38848 .20699 L
.38918 .20724 L
.38982 .20741 L
.39096 .20754 L
.39216 .20742 L
.39348 .20698 L
.39472 .2063 L
.39608 .2053 L
.39755 .20398 L
.40016 .20138 L
.40259 .19917 L
.40382 .19828 L
.40514 .1976 L
.40589 .19734 L
.4066 .19719 L
.40724 .19714 L
.40793 .19717 L
.40861 .19728 L
.40935 .19749 L
.41013 .19781 L
.41086 .19818 L
.41356 .20003 L
.41605 .20192 L
.41728 .20273 L
.41842 .20333 L
.41972 .2038 L
Mistroke
.42041 .20393 L
.42114 .20398 L
.42245 .20382 L
.42364 .20341 L
.44451 .19804 L
.44678 .19975 L
.4479 .20043 L
.44893 .20092 L
.45012 .20127 L
.45141 .20137 L
.4525 .20122 L
.45367 .20083 L
.45494 .20013 L
.45614 .19928 L
.45886 .19685 L
.46123 .19466 L
.46251 .19363 L
.46371 .19286 L
.4648 .19234 L
.46596 .19201 L
.46725 .19194 L
.46842 .19214 L
.46949 .19253 L
.47064 .19314 L
.47274 .19463 L
.4752 .19663 L
.47654 .19765 L
.4778 .19846 L
.47887 .19898 L
.48002 .19935 L
.4813 .19948 L
.48246 .19934 L
.48369 .19894 L
.48499 .19823 L
.48622 .19735 L
.48733 .19642 L
.48987 .19408 L
.49121 .1929 L
.49263 .19182 L
.49386 .19107 L
.49456 .19075 L
.49522 .19053 L
.49637 .19033 L
.4976 .19039 L
.49885 .19073 L
.50004 .19128 L
.50111 .19195 L
.50227 .19281 L
.5046 .19473 L
.50681 .19644 L
Mistroke
.50803 .1972 L
.50868 .19751 L
.50936 .19778 L
.51057 .19806 L
.5117 .19808 L
.51239 .19798 L
.51315 .19776 L
.51386 .19747 L
.51451 .19714 L
.51706 .19528 L
.51966 .19294 L
.52093 .19182 L
.52209 .19091 L
.52321 .19017 L
.52444 .18957 L
.52573 .18921 L
.52696 .18916 L
.5276 .18924 L
.52831 .18941 L
.52904 .18969 L
.52974 .19002 L
.53231 .19179 L
.53484 .19391 L
.53622 .19501 L
.53751 .19589 L
.53824 .1963 L
.5389 .19661 L
.53964 .19686 L
.54043 .19703 L
.54109 .19709 L
.54181 .19706 L
.54311 .19676 L
.54792 .19351 L
.5503 .19138 L
.55249 .18967 L
.55371 .18897 L
.55501 .18848 L
.55576 .18833 L
.55646 .18828 L
.55776 .18844 L
.55897 .18885 L
.56008 .18943 L
.56258 .19127 L
.56536 .19363 L
.56672 .19466 L
.56796 .19544 L
.56927 .19602 L
.56999 .19622 L
.57067 .19633 L
.57141 .19635 L
Mistroke
.5721 .19627 L
.57285 .19609 L
.57365 .1958 L
.57487 .19514 L
.57619 .19421 L
.57857 .19217 L
.58139 .18975 L
.58276 .1888 L
.58401 .18815 L
.5852 .18778 L
.58632 .18766 L
.58751 .18778 L
.58879 .1882 L
.59011 .1889 L
.59151 .18988 L
.59402 .19198 L
.59644 .19395 L
.5978 .19484 L
.59904 .19542 L
.59974 .19564 L
.6005 .19578 L
.60122 .19581 L
.60189 .19576 L
.60318 .19543 L
.6039 .19512 L
.60456 .19476 L
.60922 .19102 L
.61168 .18899 L
.61291 .18819 L
.61362 .18782 L
.61426 .18755 L
.61545 .18725 L
.61672 .18722 L
.6179 .18745 L
.61902 .18789 L
.62011 .1885 L
.62111 .1892 L
.62339 .19108 L
.62577 .19309 L
.62695 .19395 L
.62804 .1946 L
.62929 .19513 L
.62995 .19531 L
.63066 .1954 L
.63191 .19535 L
.63305 .19506 L
.63422 .19453 L
.63529 .19387 L
.63771 .19193 L
.63983 .19005 L
Mistroke
.64211 .18828 L
.6434 .18754 L
.64458 .18708 L
.64576 .18687 L
.64689 .18691 L
.64819 .18725 L
.6494 .18781 L
.65073 .18866 L
.65214 .18976 L
.65456 .19186 L
.65583 .1929 L
.65717 .19385 L
.65789 .19427 L
.65867 .19464 L
.65938 .19489 L
.66004 .19505 L
.66134 .19512 L
.66207 .19503 L
.66273 .19486 L
.68353 .19081 L
.68579 .19271 L
.6869 .19351 L
.68793 .19412 L
.68911 .19462 L
.6904 .1949 L
.6915 .19489 L
.69266 .19465 L
.69334 .1944 L
.69407 .19405 L
.69539 .19321 L
.69785 .1912 L
.70017 .18918 L
.7014 .18822 L
.70271 .18738 L
.70399 .18679 L
.70516 .1865 L
.70633 .18645 L
.70745 .18664 L
.70869 .18711 L
.70984 .18776 L
.71244 .18976 L
.71467 .1917 L
.71583 .19264 L
.71706 .1935 L
.71814 .1941 L
.71932 .19455 L
.72039 .19475 L
.72139 .19474 L
.72255 .19451 L
.7236 .1941 L
Mistroke
.72481 .19341 L
.72595 .19259 L
.72857 .19035 L
.73099 .18833 L
.73222 .18748 L
.73336 .18687 L
.73456 .18646 L
.73588 .18631 L
.73656 .18635 L
.73721 .18647 L
.73843 .1869 L
.73974 .18762 L
.74117 .18865 L
.74568 .19247 L
.74692 .19335 L
.74822 .19406 L
.74933 .19446 L
.75055 .19465 L
.75125 .19464 L
.75189 .19455 L
.75262 .19435 L
.75332 .19408 L
.75455 .19341 L
.7559 .19246 L
.76092 .18822 L
.76213 .18739 L
.76344 .18671 L
.76419 .18644 L
.76488 .18629 L
.76556 .18622 L
.76622 .18623 L
.76689 .18632 L
.76761 .18652 L
.76891 .18708 L
.7697 .18755 L
.77044 .18807 L
.77184 .18917 L
.77419 .19122 L
.77668 .19316 L
.77798 .1939 L
.77872 .19421 L
.77941 .19442 L
.78062 .19458 L
.78192 .19444 L
.78314 .19405 L
.78383 .19371 L
.78448 .19333 L
.7872 .19124 L
.78959 .18915 L
.79089 .18811 L
Mistroke
.7921 .18729 L
.79279 .1869 L
.79342 .18661 L
.79413 .18637 L
.79488 .1862 L
.79619 .18616 L
.79743 .18641 L
.79812 .18667 L
.79886 .18703 L
.80018 .18787 L
.80317 .19033 L
.80556 .19235 L
.80687 .19327 L
.80812 .19394 L
.80928 .19435 L
.81054 .19452 L
.81169 .19442 L
.81275 .19411 L
.81342 .19382 L
.81413 .19343 L
.81543 .19256 L
.81786 .19054 L
.82048 .1883 L
.82193 .18729 L
.82264 .18689 L
.82329 .18658 L
.82453 .1862 L
.82518 .18611 L
.82588 .1861 L
.827 .18627 L
.82823 .18671 L
.82937 .18733 L
.8306 .18819 L
.83283 .19006 L
.83563 .19241 L
.83701 .19336 L
.83829 .194 L
.83944 .19436 L
.84067 .19447 L
.84138 .19441 L
.84204 .19427 L
.84328 .19381 L
.8445 .19311 L
.84584 .19214 L
.84855 .18982 L
.84986 .1887 L
.85109 .18775 L
.85229 .18699 L
.85341 .18646 L
.85471 .18611 L
Mistroke
.85541 .18605 L
.85614 .18609 L
.85686 .18621 L
.85753 .18642 L
.85827 .18673 L
.85907 .18716 L
.86183 .18922 L
.86436 .19143 L
.86564 .19245 L
.86684 .19327 L
.86792 .19385 L
.8691 .19427 L
.87038 .19444 L
.87102 .19442 L
.87173 .1943 L
.87298 .19388 L
.87416 .19325 L
.87883 .18947 L
.87995 .18853 L
.88114 .18764 L
.88224 .18695 L
.88327 .18646 L
.88458 .1861 L
.88577 .18603 L
.88707 .18627 L
.88781 .18653 L
.88849 .18685 L
.88959 .18752 L
.8908 .18841 L
.89325 .19051 L
.89593 .1927 L
.8967 .19321 L
.89743 .19363 L
.89809 .19393 L
.8988 .19418 L
.90008 .19441 L
.90128 .19435 L
.90256 .194 L
.90329 .19367 L
.90397 .19329 L
.90907 .18917 L
.91035 .18813 L
.91156 .18728 L
.91264 .18667 L
.91382 .18623 L
.91507 .18601 L
.91621 .18607 L
.91746 .1864 L
.91877 .18703 L
.9201 .18791 L
Mistroke
.92135 .1889 L
.92418 .19136 L
.92533 .19229 L
.92657 .19317 L
.92775 .1938 L
.92885 .1942 L
.92983 .19438 L
.93091 .19437 L
.93204 .19413 L
.93311 .1937 L
.93428 .19303 L
.93551 .19214 L
.93772 .19027 L
.94027 .18811 L
.94153 .18723 L
.94269 .1866 L
.94371 .18622 L
.9448 .18601 L
.94588 .18602 L
.94708 .18629 L
.94807 .18669 L
.94914 .18729 L
.95107 .18873 L
.95327 .19063 L
.95567 .19259 L
.95676 .19332 L
.95793 .1939 L
.95904 .19425 L
.96004 .19439 L
.96112 .19432 L
.96212 .19407 L
.96322 .1936 L
.96438 .1929 L
.96847 .18953 L
.97025 .18806 L
.97123 .18737 L
.97215 .18682 L
.97324 .18633 L
.97424 .18607 L
.97517 .18598 L
.97619 .18607 L
Mfstroke
.5 Mabswid
.02381 .19325 m
.03279 .26251 L
.04262 .32533 L
.04758 .34768 L
.05288 .36952 L
.05785 .38733 L
.06004 .39359 L
.06244 .39902 L
.06381 .40138 L
.06508 .40313 L
.06643 .40452 L
.06719 .40512 L
.06788 .40556 L
.06858 .40592 L
.06933 .40621 L
.07015 .40645 L
.07091 .4066 L
.07169 .40672 L
.07242 .40679 L
.07379 .40691 L
.07509 .40705 L
.07575 .40715 L
.07647 .40729 L
.07774 .40764 L
.07894 .40809 L
.08162 .40953 L
.08451 .41145 L
.08576 .41226 L
.08709 .41302 L
.08778 .41335 L
.08855 .41364 L
.08925 .41384 L
.0899 .41396 L
.09118 .41397 L
.09236 .41372 L
.09365 .41314 L
.0943 .41272 L
.09501 .41218 L
.0974 .40974 L
.09997 .40638 L
.10458 .40003 L
.10717 .3972 L
.10847 .39611 L
.10991 .39518 L
.11113 .39459 L
.11245 .39414 L
.11369 .39383 L
.11482 .39361 L
.11614 .39335 L
.11755 .39301 L
Mistroke
.11836 .39275 L
.11909 .39246 L
.12052 .3917 L
.12186 .39072 L
.1233 .38934 L
.12593 .386 L
.14608 .36314 L
.18713 .32696 L
.20759 .31154 L
.20879 .31145 L
.21005 .31119 L
.21071 .31097 L
.21144 .31067 L
.21273 .30994 L
.21393 .30903 L
.21523 .30781 L
.21758 .30511 L
.22193 .29936 L
.22439 .29647 L
.22558 .29532 L
.22667 .29447 L
.22784 .29376 L
.22893 .29328 L
.23009 .29299 L
.23135 .29288 L
.23259 .29295 L
.2339 .29315 L
.23504 .2934 L
.23626 .29366 L
.23739 .29386 L
.23842 .29397 L
.23946 .29397 L
.24044 .29385 L
.24158 .29355 L
.24264 .2931 L
.2438 .29241 L
.24504 .29146 L
.2647 .27971 L
.26584 .28011 L
.26706 .28051 L
.26821 .28079 L
.26925 .28095 L
.27043 .28096 L
.27154 .2808 L
.27275 .28042 L
.27405 .27976 L
.27538 .27883 L
.27679 .27762 L
.27931 .27503 L
.28164 .27255 L
Mistroke
.28292 .27129 L
.28414 .27024 L
.28527 .26944 L
.28649 .26876 L
.2876 .26836 L
.28863 .26815 L
.2897 .26812 L
.29067 .26822 L
.29179 .26849 L
.29284 .26885 L
.29523 .26989 L
.29655 .27047 L
.29779 .27094 L
.29895 .27125 L
.30021 .27142 L
.30136 .27139 L
.30242 .27118 L
.30349 .2708 L
.30468 .27017 L
.30591 .26932 L
.30708 .26836 L
.30974 .26582 L
.31219 .26347 L
.31461 .26159 L
.31583 .26092 L
.31651 .26063 L
.31716 .26044 L
.31785 .2603 L
.31851 .26024 L
.31974 .2603 L
.32043 .26043 L
.32107 .26061 L
.32251 .26115 L
.32475 .26228 L
.32598 .26293 L
.32715 .26349 L
.32823 .26393 L
.32941 .26427 L
.33049 .26443 L
.33149 .26443 L
.33264 .26425 L
.33368 .2639 L
.33488 .26331 L
.33601 .26257 L
.34099 .25824 L
.34324 .25637 L
.34451 .25555 L
.34566 .25497 L
.34632 .25474 L
.34702 .25456 L
Mistroke
.34831 .25443 L
.3496 .25455 L
.35078 .25487 L
.35202 .25538 L
.35317 .25597 L
.3558 .25749 L
.35711 .2582 L
.35836 .25876 L
.35905 .259 L
.3598 .2592 L
.36112 .25935 L
.36237 .25926 L
.36355 .25895 L
.36461 .2585 L
.36576 .25784 L
.37071 .25381 L
.37296 .25202 L
.37419 .25124 L
.37534 .25069 L
.37632 .25036 L
.37738 .25018 L
.37854 .25019 L
.37961 .25037 L
.38079 .25075 L
.38189 .25125 L
.38441 .25273 L
.38571 .25354 L
.38707 .25434 L
.38834 .25495 L
.38952 .25536 L
.39053 .25558 L
.39162 .25564 L
.39283 .25549 L
.39393 .25516 L
.3951 .25462 L
.39637 .25384 L
.39868 .25206 L
.40139 .24982 L
.40272 .24884 L
.40393 .24809 L
.4052 .24749 L
.40591 .24727 L
.40657 .24712 L
.4073 .24704 L
.40796 .24704 L
.4087 .24711 L
.40948 .24728 L
.41078 .24775 L
.41217 .24846 L
.41471 .25006 L
Mistroke
.41719 .2516 L
.41827 .25215 L
.41944 .2526 L
.42066 .25287 L
.42182 .25292 L
.42246 .25286 L
.42315 .25273 L
.42437 .25231 L
.4255 .25175 L
.42656 .25109 L
.42897 .24926 L
.43142 .2473 L
.43275 .24635 L
.43399 .24563 L
.4347 .24531 L
.43535 .24507 L
.43606 .24488 L
.43682 .24476 L
.43746 .24474 L
.43815 .24478 L
.43941 .24504 L
.44072 .24554 L
.44195 .24619 L
.44474 .24801 L
.44625 .24901 L
.44769 .24985 L
.44898 .25044 L
.44971 .25068 L
.45038 .25083 L
.4515 .25095 L
.45274 .25085 L
.45404 .25049 L
.45525 .24994 L
.45657 .24915 L
.45777 .24829 L
.46048 .24616 L
.46165 .24528 L
.46291 .24444 L
.46411 .2438 L
.46521 .24337 L
.4665 .2431 L
.46714 .24306 L
.46786 .24309 L
.4691 .24333 L
.47027 .24375 L
.47144 .24434 L
.47256 .24502 L
.47466 .24645 L
.47713 .24808 L
.47821 .24865 L
Mistroke
.47938 .24912 L
.48065 .24943 L
.48186 .2495 L
.48253 .24944 L
.48324 .2493 L
.48451 .24886 L
.48568 .24827 L
.48678 .24758 L
.48927 .24572 L
.49194 .24372 L
.49326 .24292 L
.49448 .24235 L
.49516 .24211 L
.49588 .24194 L
.4966 .24185 L
.4974 .24184 L
.49806 .24191 L
.49877 .24206 L
.50006 .24251 L
.50132 .24314 L
.50246 .24385 L
.50502 .24564 L
.50619 .24643 L
.50743 .24719 L
.50857 .24776 L
.50964 .24815 L
.51087 .24841 L
.51152 .24845 L
.51222 .24842 L
.51298 .2483 L
.51369 .24811 L
.51433 .24788 L
.51503 .24757 L
.51766 .24591 L
.52011 .24404 L
.52144 .24307 L
.52287 .24215 L
.52353 .2418 L
.52423 .24149 L
.52548 .2411 L
.52667 .24094 L
.52779 .24099 L
.52902 .24127 L
.53033 .2418 L
.53308 .24347 L
.53599 .24554 L
.53718 .24629 L
.53847 .24696 L
.53921 .24726 L
.53989 .24746 L
Mistroke
.54057 .2476 L
.54121 .24767 L
.54244 .24762 L
.54374 .24732 L
.54497 .24681 L
.54609 .24619 L
.55142 .24234 L
.55275 .2415 L
.55416 .24081 L
.55489 .24056 L
.5557 .24037 L
.55643 .24029 L
.55712 .24029 L
.55782 .24036 L
.55848 .2405 L
.55971 .24092 L
.56041 .24125 L
.56105 .24159 L
.5625 .24251 L
.56492 .24425 L
.56619 .24513 L
.56753 .24595 L
.56871 .24652 L
.57 .24694 L
.57117 .24711 L
.57226 .24708 L
.57351 .24682 L
.57464 .24639 L
.57595 .24569 L
.57719 .24488 L
.58 .24279 L
.58138 .2418 L
.58263 .24102 L
.58377 .24045 L
.58486 .24006 L
.58601 .23984 L
.58725 .23983 L
.58853 .24007 L
.58925 .2403 L
.58989 .24057 L
.59234 .24201 L
.59475 .24374 L
.59728 .24543 L
.59861 .24609 L
.59937 .24637 L
.60007 .24655 L
.6013 .24671 L
.602 .24669 L
.60263 .24661 L
.60384 .24628 L
Mistroke
.60497 .2458 L
.6062 .2451 L
.60751 .24421 L
.60989 .24243 L
.61213 .2409 L
.61313 .24035 L
.61418 .23989 L
.61533 .23957 L
.61638 .23945 L
.61754 .23952 L
.61862 .23977 L
.61981 .24023 L
.62107 .24091 L
.62606 .2444 L
.62727 .24515 L
.62857 .24579 L
.62932 .24607 L
.63 .24625 L
.63068 .24637 L
.63133 .24641 L
.63203 .24638 L
.63277 .24627 L
.63347 .24609 L
.6341 .24586 L
.63565 .24509 L
.63711 .24415 L
.63971 .24224 L
.64112 .24122 L
.64244 .2404 L
.64361 .23982 L
.64485 .2394 L
.64556 .23926 L
.64624 .2392 L
.64749 .23928 L
.64865 .23956 L
.64972 .23998 L
.65089 .24061 L
.65213 .24141 L
.65453 .24315 L
.65711 .24488 L
.65787 .24529 L
.65859 .24561 L
.65924 .24585 L
.65995 .24604 L
.66061 .24615 L
.66132 .24619 L
.6626 .24607 L
.66384 .24572 L
.66455 .24542 L
.6652 .24509 L
Mistroke
.66795 .24329 L
.67049 .24141 L
.67173 .24058 L
.67288 .23993 L
.67352 .23963 L
.67423 .23937 L
.67494 .23917 L
.67569 .23905 L
.67701 .23904 L
.67825 .23928 L
.67896 .23951 L
.6797 .23983 L
.68102 .24056 L
.68401 .24265 L
.68642 .24434 L
.68775 .2451 L
.689 .24563 L
.69016 .24593 L
.69143 .24603 L
.69258 .2459 L
.69364 .24561 L
.6949 .24506 L
.69608 .24438 L
.69876 .24248 L
.70012 .24147 L
.70157 .24049 L
.70282 .23978 L
.70353 .23946 L
.70418 .23922 L
.70483 .23904 L
.70552 .23892 L
.70679 .23889 L
.70792 .23908 L
.70915 .23949 L
.70986 .23982 L
.71051 .24017 L
.71196 .2411 L
.71458 .243 L
.71701 .24462 L
.71768 .24498 L
.71839 .24531 L
.71966 .24573 L
.72084 .2459 L
.72194 .24587 L
.72315 .24562 L
.72446 .24512 L
.72563 .24449 L
.72671 .2438 L
.72918 .242 L
.73051 .24103 L
Mistroke
.73178 .24021 L
.733 .23955 L
.73414 .23911 L
.73514 .23886 L
.73619 .23877 L
.73726 .23886 L
.73842 .23915 L
.73956 .23961 L
.74079 .24029 L
.743 .2418 L
.74555 .24366 L
.74695 .24455 L
.74827 .2452 L
.74938 .24559 L
.75059 .24581 L
.75124 .24583 L
.75192 .24578 L
.75315 .24552 L
.75447 .245 L
.75588 .24421 L
.75843 .24242 L
.7612 .24044 L
.76196 .23998 L
.76276 .23955 L
.76346 .23924 L
.76421 .23898 L
.7649 .23882 L
.76554 .23873 L
.76679 .23873 L
.76748 .23884 L
.76824 .23904 L
.76896 .23931 L
.76962 .23961 L
.7721 .24114 L
.77474 .24308 L
.77598 .24393 L
.77733 .24473 L
.7786 .2453 L
.77977 .24564 L
.78082 .24576 L
.78198 .2457 L
.78319 .24542 L
.78432 .24497 L
.78558 .24428 L
.78692 .2434 L
.78933 .24163 L
.79068 .24067 L
.79214 .23977 L
.79281 .23943 L
.79352 .23913 L
Mistroke
.79478 .23877 L
.79595 .23865 L
.79703 .23872 L
.79822 .23901 L
.79949 .23953 L
.80089 .24033 L
.80221 .24123 L
.80468 .24304 L
.80694 .24451 L
.80807 .24508 L
.80932 .24551 L
.81038 .24569 L
.81153 .2457 L
.81261 .24552 L
.81359 .2452 L
.81482 .24463 L
.81596 .24395 L
.81854 .24211 L
.82083 .24048 L
.82208 .23972 L
.82324 .23917 L
.82451 .23877 L
.82518 .23866 L
.8259 .23861 L
.82718 .23872 L
.82834 .23904 L
.82905 .23933 L
.8297 .23964 L
.83117 .24053 L
.83385 .24245 L
.83505 .24333 L
.83635 .24418 L
.83755 .24484 L
.83869 .24531 L
.83996 .24562 L
.84113 .24568 L
.84241 .24551 L
.84314 .24531 L
.84382 .24505 L
.84499 .24446 L
.84625 .24368 L
.84854 .24202 L
.85059 .24056 L
.85167 .23988 L
.85283 .23928 L
.85409 .23883 L
.85526 .23861 L
.85595 .23858 L
.85661 .23862 L
.85783 .23887 L
Mistroke
.85898 .23931 L
.86004 .23985 L
.86244 .24145 L
.8647 .24311 L
.86707 .24461 L
.86831 .24518 L
.86902 .24541 L
.86967 .24556 L
.87083 .24566 L
.87206 .24555 L
.87323 .24522 L
.87449 .24467 L
.87679 .24323 L
.87901 .24159 L
.88109 .24015 L
.88239 .23943 L
.88357 .23894 L
.88488 .23862 L
.88561 .23856 L
.8863 .23858 L
.88696 .23866 L
.88766 .23883 L
.88893 .2393 L
.88971 .23969 L
.89044 .24012 L
.89181 .24103 L
.89412 .24273 L
.89656 .24436 L
.89783 .245 L
.89856 .24528 L
.89923 .24547 L
.90042 .24564 L
.90169 .24558 L
.90291 .24529 L
.90361 .24503 L
.90426 .24473 L
.90699 .24302 L
.90937 .24125 L
.91188 .23963 L
.91253 .23931 L
.91321 .23902 L
.91396 .23878 L
.91466 .23863 L
.91535 .23855 L
.916 .23855 L
.91721 .23872 L
.91791 .23891 L
.91865 .2392 L
.91997 .23987 L
.92296 .24191 L
Mistroke
.92535 .24364 L
.92667 .24445 L
.92791 .24506 L
.92907 .24544 L
.93034 .24562 L
.93148 .24558 L
.93255 .24536 L
.9338 .2449 L
.93497 .24428 L
.93765 .24246 L
.94047 .24043 L
.94184 .2396 L
.94309 .23903 L
.94408 .23872 L
.94502 .23856 L
.94602 .23854 L
.9471 .2387 L
.94821 .23904 L
.94938 .23957 L
.95149 .24089 L
.95369 .24251 L
.95606 .24414 L
.95721 .24477 L
.9583 .24522 L
.95928 .24549 L
.96035 .24562 L
.96134 .24558 L
.96224 .24541 L
.96328 .24508 L
.96426 .24463 L
.966 .24357 L
.96789 .24221 L
.96999 .24069 L
.97114 .23995 L
.97221 .23936 L
.97313 .23898 L
.97411 .23869 L
.9752 .23853 L
.97619 .23856 L
Mfstroke
1.5 Mabswid
.02381 .37179 m
.02499 .32911 L
.02605 .3137 L
.02729 .31153 L
.02846 .31788 L
.02954 .32744 L
.03053 .33773 L
.03279 .36214 L
.04262 .44996 L
.04755 .49119 L
.05285 .53418 L
.05542 .5513 L
.05669 .55829 L
.05786 .56379 L
.05901 .56823 L
.06005 .57145 L
.06121 .57417 L
.06244 .57615 L
.0637 .57732 L
.06485 .5778 L
.06612 .57784 L
.06676 .57774 L
.06746 .57757 L
.06863 .57726 L
.0699 .57705 L
.07109 .57711 L
.07218 .57748 L
.07284 .57789 L
.07355 .57849 L
.07481 .57999 L
.07618 .5822 L
.07768 .58527 L
.08022 .59136 L
.0829 .59766 L
.08424 .60022 L
.08495 .60132 L
.08571 .60226 L
.0864 .60289 L
.08704 .60324 L
.08828 .60332 L
.08902 .60296 L
.08971 .60236 L
.09047 .60142 L
.09126 .6001 L
.09261 .59724 L
.09408 .59331 L
.09666 .58532 L
.09947 .5767 L
.10075 .57334 L
.10212 .5704 L
Mistroke
.10341 .56834 L
.10458 .56711 L
.10589 .56642 L
.1071 .56639 L
.10773 .56657 L
.10842 .56689 L
.10914 .56735 L
.10982 .56784 L
.11114 .56893 L
.11239 .56991 L
.11352 .5706 L
.11474 .57098 L
.11587 .57087 L
.11707 .57017 L
.1181 .56903 L
.11923 .56719 L
.12042 .56458 L
.1217 .56105 L
.12403 .55317 L
.12934 .53303 L
.13064 .5289 L
.13201 .52521 L
.13281 .52347 L
.13353 .52215 L
.13421 .52112 L
.13493 .52028 L
.13622 .51935 L
.1374 .51909 L
.13867 .51931 L
.1394 .51961 L
.14007 .51996 L
.14128 .52069 L
.14242 .52134 L
.14361 .52182 L
.14492 .52195 L
.14617 .52153 L
.14687 .52101 L
.14751 .52034 L
.14868 .51864 L
.14992 .51614 L
.15251 .50877 L
.15535 .49841 L
.15781 .48905 L
.16014 .48121 L
.16142 .47768 L
.16281 .47468 L
.16408 .47276 L
.16525 .47167 L
.16639 .4712 L
.16747 .47123 L
Mistroke
.16864 .47169 L
.16991 .47253 L
.17112 .4735 L
.17244 .47454 L
.17369 .47529 L
.17485 .47564 L
.17604 .47553 L
.17711 .47493 L
.17836 .4736 L
.17952 .47168 L
.18059 .46939 L
.18158 .46686 L
.1838 .45996 L
.1885 .44357 L
.18986 .43948 L
.19114 .43622 L
.19229 .4339 L
.19354 .4321 L
.19463 .43114 L
.19583 .43073 L
.19709 .43096 L
.19827 .43167 L
.19936 .43265 L
.20037 .43371 L
.20263 .43616 L
.20384 .43719 L
.20513 .43785 L
.20634 .43792 L
.20745 .43744 L
.20874 .43616 L
.20948 .4351 L
.21015 .4339 L
.21271 .42771 L
.21782 .4115 L
.21929 .40726 L
.22068 .40388 L
.22194 .40153 L
.22265 .40053 L
.2233 .39981 L
.22458 .39902 L
.22577 .39896 L
.22684 .39943 L
.228 .40039 L
.22927 .40185 L
.23061 .40365 L
.23177 .40525 L
.23301 .40682 L
.23418 .40801 L
.23525 .40874 L
.23632 .40903 L
Mistroke
.23734 .40886 L
.23852 .40806 L
.23961 .40673 L
.24081 .40467 L
.24208 .40186 L
.24681 .38824 L
.24806 .38465 L
.24942 .38116 L
.25062 .3786 L
.2519 .37653 L
.2527 .37563 L
.25342 .37507 L
.25414 .37476 L
.25482 .3747 L
.2561 .37514 L
.25683 .37569 L
.25749 .37636 L
.26004 .37992 L
.26132 .38199 L
.26273 .38413 L
.26405 .38581 L
.26527 .38689 L
.26644 .38739 L
.26768 .38726 L
.26879 .38654 L
.26983 .38535 L
.27097 .38349 L
.2722 .38092 L
.27715 .36755 L
.27845 .36417 L
.27984 .36107 L
.28116 .35881 L
.28235 .35741 L
.28348 .35672 L
.2847 .35665 L
.28586 .35721 L
.28692 .3582 L
.28808 .35971 L
.28935 .36174 L
.29192 .36627 L
.29304 .36808 L
.2941 .36953 L
.29533 .37076 L
.29645 .37138 L
.2975 .37144 L
.29847 .37104 L
.29955 .37009 L
.30069 .36851 L
.30193 .36619 L
.3033 .36307 L
Mistroke
.30606 .35583 L
.30864 .34937 L
.30977 .34708 L
.31099 .34512 L
.31173 .34425 L
.31242 .34367 L
.31308 .34333 L
.31377 .34319 L
.31451 .34329 L
.31519 .34362 L
.31594 .3442 L
.31675 .34508 L
.31812 .34705 L
.31956 .34959 L
.32213 .35443 L
.32337 .35652 L
.32455 .35811 L
.32519 .35878 L
.3259 .35933 L
.32713 .35977 L
.3283 .35953 L
.32954 .35858 L
.3306 .35721 L
.33177 .3552 L
.33436 .34929 L
.33718 .34212 L
.33847 .33916 L
.33984 .33653 L
.34101 .33485 L
.34231 .33369 L
.34362 .33332 L
.34483 .33371 L
.34547 .33418 L
.34616 .33488 L
.34756 .33682 L
.34994 .34122 L
.35249 .34621 L
.35379 .34836 L
.35501 .34992 L
.35611 .35083 L
.3573 .35121 L
.35843 .35096 L
.35963 .35004 L
.36066 .34874 L
.36178 .34684 L
.36699 .33466 L
.36848 .33134 L
.36991 .32878 L
.37118 .32715 L
.37191 .32655 L
Mistroke
.37258 .32621 L
.3739 .32617 L
.37514 .32687 L
.37626 .32807 L
.37747 .32987 L
.37999 .33472 L
.38269 .34013 L
.38401 .34231 L
.38526 .34384 L
.38638 .34469 L
.38761 .34495 L
.38876 .34455 L
.38999 .34345 L
.39104 .342 L
.3922 .33992 L
.39485 .33394 L
.39764 .32734 L
.39879 .32502 L
.40002 .323 L
.40073 .32211 L
.40138 .32149 L
.40263 .32083 L
.40392 .32093 L
.40465 .32134 L
.40532 .32192 L
.40656 .32345 L
.40786 .32564 L
.41077 .33162 L
.4122 .33454 L
.4135 .33689 L
.4147 .33862 L
.41584 .33976 L
.41704 .34034 L
.41836 .3402 L
.41906 .33979 L
.4197 .33923 L
.42044 .33835 L
.42113 .33733 L
.4237 .33221 L
.42615 .32642 L
.42749 .32338 L
.42877 .32086 L
.42995 .31898 L
.43124 .31758 L
.43241 .31696 L
.43349 .31697 L
.43463 .31756 L
.43588 .31888 L
.43719 .32088 L
.43842 .32319 L
Mistroke
.44119 .3291 L
.44255 .33186 L
.44382 .33406 L
.4449 .33552 L
.44604 .33657 L
.44732 .33704 L
.44847 .33681 L
.44952 .33606 L
.45066 .3347 L
.45174 .33295 L
.45273 .33102 L
.4553 .32518 L
.45774 .3197 L
.4588 .3177 L
.45993 .31598 L
.46116 .31469 L
.46231 .31411 L
.46346 .31416 L
.46454 .31477 L
.46572 .31602 L
.467 .31797 L
.46945 .32287 L
.47203 .32843 L
.47313 .3305 L
.47429 .33235 L
.47558 .33379 L
.47677 .33451 L
.47794 .33456 L
.47905 .33401 L
.48004 .33304 L
.48112 .33153 L
.48633 .32036 L
.4876 .31763 L
.48896 .31513 L
.48974 .31398 L
.49046 .31314 L
.49118 .31251 L
.49186 .31214 L
.49305 .31201 L
.49432 .31262 L
.49552 .31384 L
.4966 .31544 L
.49907 .32027 L
.50177 .32617 L
.50299 .32854 L
.5043 .33062 L
.50553 .33201 L
.50665 .3327 L
.50792 .33277 L
.50864 .33247 L
Mistroke
.5093 .33198 L
.51052 .33059 L
.51181 .3285 L
.51625 .31874 L
.51858 .31405 L
.51976 .3123 L
.52104 .31101 L
.52171 .31064 L
.52242 .31047 L
.52371 .31077 L
.52499 .31183 L
.52615 .31338 L
.52861 .31804 L
.53094 .32319 L
.53227 .32596 L
.53367 .32847 L
.53487 .3301 L
.53619 .33121 L
.53693 .33149 L
.5376 .33152 L
.53838 .33128 L
.53912 .3308 L
.54043 .32934 L
.54118 .32821 L
.54187 .32701 L
.54697 .31583 L
.54837 .31313 L
.54913 .31191 L
.54984 .31096 L
.5511 .30979 L
.55176 .30947 L
.55248 .30935 L
.55376 .30976 L
.55449 .31033 L
.55516 .31105 L
.55639 .31284 L
.5577 .31525 L
.55999 .32022 L
.56245 .32547 L
.56367 .32762 L
.56484 .32918 L
.56588 .33012 L
.56703 .33057 L
.5681 .33043 L
.56925 .32969 L
.57033 .32845 L
.57131 .32694 L
.57597 .31697 L
.57724 .31425 L
.57861 .31175 L
Mistroke
.5799 .30996 L
.58108 .30894 L
.58227 .30855 L
.58358 .3089 L
.58481 .30995 L
.58595 .31147 L
.58844 .31622 L
.5911 .32212 L
.59321 .32626 L
.59439 .32803 L
.59548 .32917 L
.5967 .32983 L
.59798 .32976 L
.59909 .32907 L
.60032 .32769 L
.60099 .32668 L
.60172 .32541 L
.60305 .32274 L
.60553 .31713 L
.60824 .31161 L
.6096 .30961 L
.61038 .3088 L
.6111 .30828 L
.61242 .30796 L
.61362 .30839 L
.61428 .30891 L
.61501 .3097 L
.61632 .31165 L
.61882 .31667 L
.62114 .32184 L
.62243 .32448 L
.62379 .32679 L
.62495 .32825 L
.62623 .32918 L
.62695 .32938 L
.6276 .32934 L
.62836 .32905 L
.62907 .32852 L
.63035 .32705 L
.63107 .32594 L
.63173 .32477 L
.63647 .31443 L
.63777 .31185 L
.63845 .31068 L
.63917 .30962 L
.64049 .3082 L
.6417 .30758 L
.64278 .30761 L
.64393 .30825 L
.64502 .3094 L
Mistroke
.64601 .31085 L
.64844 .3156 L
.65073 .32073 L
.65297 .32521 L
.65409 .32695 L
.65533 .32829 L
.65598 .32873 L
.65667 .32898 L
.65793 .32885 L
.65917 .328 L
.66031 .32663 L
.66149 .32471 L
.66259 .32254 L
.66511 .31693 L
.6664 .31406 L
.66777 .31137 L
.66893 .3095 L
.67021 .30804 L
.67131 .30735 L
.67249 .30724 L
.6736 .30775 L
.67462 .3087 L
.67579 .31031 L
.67706 .31259 L
.67937 .31757 L
.68208 .32344 L
.6834 .32578 L
.68461 .3274 L
.68588 .32845 L
.68659 .32871 L
.68725 .32874 L
.68798 .32853 L
.68865 .32812 L
.68938 .32744 L
.69016 .32646 L
.69146 .32436 L
.69285 .32157 L
.69539 .31587 L
.69666 .31312 L
.69786 .31082 L
.69895 .30913 L
.70012 .30781 L
.70136 .30708 L
.7025 .30703 L
.70373 .30768 L
.70504 .30911 L
.70617 .31086 L
.70723 .31286 L
.70964 .31814 L
.71208 .3234 L
Mistroke
.71342 .32573 L
.71466 .32734 L
.71531 .32793 L
.71601 .32835 L
.71678 .32855 L
.71748 .32848 L
.71812 .32822 L
.71882 .32772 L
.72007 .32629 L
.72138 .32416 L
.72261 .32173 L
.7254 .31548 L
.72679 .31251 L
.72812 .31008 L
.72885 .30899 L
.72964 .30802 L
.73037 .30738 L
.73104 .30699 L
.73167 .30682 L
.73236 .30685 L
.73361 .30748 L
.73482 .30875 L
.73593 .31043 L
.73866 .31595 L
.74114 .32149 L
.7423 .32382 L
.74357 .32592 L
.74476 .32737 L
.74586 .32817 L
.74703 .3284 L
.74831 .32791 L
.74896 .32738 L
.74965 .3266 L
.75091 .32472 L
.75526 .31548 L
.75756 .31077 L
.75885 .30875 L
.76001 .30747 L
.76072 .30698 L
.76149 .30671 L
.76222 .30672 L
.76288 .30694 L
.76418 .30797 L
.76483 .30876 L
.76555 .30981 L
.76827 .31515 L
.77081 .32085 L
.77209 .32346 L
.77331 .32554 L
.7744 .32697 L
Mistroke
.77558 .32796 L
.77687 .3283 L
.77752 .32817 L
.77824 .3278 L
.77951 .32658 L
.7807 .32485 L
.78578 .31406 L
.78706 .31145 L
.78826 .30938 L
.78935 .30795 L
.79052 .30696 L
.79176 .30659 L
.79291 .30691 L
.79415 .30793 L
.79546 .30971 L
.79679 .3121 L
.79803 .31472 L
.80087 .32105 L
.80201 .32337 L
.80325 .32551 L
.80443 .32702 L
.80552 .3279 L
.80661 .32822 L
.80759 .32804 L
.80872 .32727 L
.80978 .32604 L
.81095 .3242 L
.81218 .32181 L
.81439 .31693 L
.81695 .31145 L
.8182 .30928 L
.81937 .30778 L
.82052 .30684 L
.82175 .30653 L
.82298 .30693 L
.82368 .30747 L
.82433 .30818 L
.82547 .3098 L
.82651 .31166 L
.82886 .31669 L
.83143 .32234 L
.83268 .32466 L
.83382 .32634 L
.83502 .32756 L
.83631 .32815 L
.83698 .32814 L
.83771 .32789 L
.83903 .32682 L
.8436 .31848 L
.84612 .31288 L
Mistroke
.84736 .31048 L
.84851 .30867 L
.84959 .30743 L
.85073 .30666 L
.85188 .3065 L
.85314 .30705 L
.85419 .30806 L
.85532 .30964 L
.85737 .31353 L
.85976 .31888 L
.86199 .32353 L
.86321 .32557 L
.86431 .32696 L
.86554 .32789 L
.86685 .32811 L
.86755 .32789 L
.86819 .32749 L
.8689 .32683 L
.86965 .32591 L
.8709 .3239 L
.87229 .32117 L
.87484 .31544 L
.87728 .31046 L
.87858 .30843 L
.87932 .30757 L
.88001 .30698 L
.88122 .30647 L
.88251 .30668 L
.88324 .30715 L
.88403 .30793 L
.88478 .3089 L
.88547 .30997 L
.88814 .31536 L
.89071 .32109 L
.89196 .32359 L
.8931 .3255 L
.8943 .327 L
.89559 .32792 L
.89626 .32809 L
.897 .32803 L
.89769 .32775 L
.89833 .32728 L
.9027 .32006 L
.90509 .31469 L
.90731 .31023 L
.90848 .30844 L
.90972 .30711 L
.91043 .30666 L
.91111 .30645 L
.91236 .30663 L
Mistroke
.91352 .30744 L
.91458 .30871 L
.91575 .31059 L
.91699 .31301 L
.91943 .31844 L
.92205 .32389 L
.92283 .32518 L
.92356 .32622 L
.92421 .32697 L
.92493 .32757 L
.92561 .32793 L
.92633 .32808 L
.92762 .32772 L
.92892 .32659 L
.92965 .32564 L
.93032 .32459 L
.93286 .31953 L
.93534 .31395 L
.9376 .3096 L
.93873 .308 L
.93996 .30686 L
.94112 .30641 L
.9422 .30657 L
.94334 .30733 L
.94459 .30881 L
.9459 .31098 L
.94713 .31344 L
.95146 .32291 L
.95251 .32479 L
.95363 .32639 L
.95486 .32757 L
.95601 .32804 L
.95667 .32803 L
.95738 .32779 L
.95867 .32676 L
.95993 .32509 L
.96108 .32306 L
.96573 .31294 L
.9669 .31065 L
.96815 .30863 L
.96887 .30773 L
.96953 .30711 L
.97081 .30644 L
.97214 .30657 L
.97288 .307 L
.97357 .30763 L
.97484 .3093 L
.97619 .31167 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.52381 .42806 m
.52381 .57092 L
.66667 .57092 L
.66667 .42806 L
F
1 g
.5 .45187 m
.5 .59473 L
.64286 .59473 L
.64286 .45187 L
F
0 g
.001 w
[ ] 0 setdash
.5 .45187 m
.64286 .45187 L
.64286 .59473 L
.5 .59473 L
.5 .45187 L
s
% Start of sub-graphic
p
0.5 0.451874 0.642857 0.594731 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0271739 0.271739 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.048913 0.35119 0.320652 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
1.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .18478 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x3) show
75.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.36413 0.35119 0.63587 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .5 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x2) show
75.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.679348 0.35119 0.951087 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
2 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .81522 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x1) show
75.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[91]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00@@3oool4000000<0oooo0P00000T0?ooo`<000000P3oool200000240
oooo0`0000040?ooo`8000008`3oool2000000@0oooo0P00000N0?ooo`D000000P3oool2000000@0
oooo0P00000Y0?ooo`00@@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000002@0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0N0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000008@3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000001l0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool09P3oool00480oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`00000Q0?ooo`D0000000D0oooo0000003oool0oooo0000000P0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000008@3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000001l0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool09P3oool004<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo01l0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`00000P0?ooo`<000000`3oool010000000oooo0?ooo`00000R0?ooo`8000000`3oool0
10000000oooo0?ooo`00000O0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo02H0oooo00110?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000008P3oool00`000000oooo000000020?ooo`040000003oool0oooo
00000240oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000Q0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000007`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0V0?ooo`00@P3oool20000
00@0oooo0P00000T0?ooo`8000000`3oool200000280oooo0`0000030?ooo`8000008`3oool20000
00@0oooo0P00000O0?ooo`800000103oool2000000@0oooo0P00000Y0?ooo`00o`3ooolQ0?ooo`00
6`3oool00`000000oooo0?ooo`3/0?ooo`800000503oool001/0oooo00<000000?ooo`3oool0k@3o
ool00`000000oooo0?ooo`0B0?ooo`006`3oool00`000000oooo0?ooo`3Q0?ooo`@0000000<0oooo
0000000000000`0000030?ooo`040000003oool0oooo0?ooo`<000003@3oool001H0ooooh@000007
0?ooo`040000003oool0oooo00000080oooo100000030?ooo`030000003oool0000000D0oooo00<0
00000?ooo`3oool02P3oool001/0oooo0P0000090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool02`3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool00`00000=0?ooo`006`3oool2000002T0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0<0?ooo`<000000`3oool3000000050?ooo`00000000000000003oool0
0P0000000`3oool0000000000002000000`0oooo000K0?ooo`800000i03oool00`000000oooo0?oo
o`0L0?ooo`006`3oool200000><0oooo0P00000N0?ooo`006`3oool200000?l0oooo103oool001/0
oooo0P00003o0?ooo`@0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool200000?l0oooo103o
ool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool200000?l0
oooo103oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool2
00000?l0oooo103oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`800000o`3oool40?ooo`00
6`3oool200000?l0oooo103oool000P0oooo1@0000020?ooo`800000103oool2000000@0oooo0P00
003o0?ooo`@0oooo000:0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3o
ool200000?l0oooo103oool000X0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`3o
ool300000?l0oooo0`3oool000X0oooo00<000000?ooo`3oool0203oool2000000@0oooo0P00003o
0?ooo`@0oooo000:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool20000
0?l0oooo103oool000T0oooo0P00000:0?ooo`<000000`3oool200000?l0oooo103oool001/0oooo
0P00003o0?ooo`@0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool200000?l0oooo103oool0
01/0oooo0P00003o0?ooo`@0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool200000?l0oooo
103oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool20000
0?l0oooo103oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`800000o`3oool40?ooo`006`3o
ool200000?l0oooo103oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`800000o`3oool40?oo
o`00503oool4000000<0oooo0P00001_0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0i0?ooo`00503oool00`000000oooo0?ooo`040?ooo`800000
KP3oool2000000@0oooo0`0000030?ooo`@000000`3oool500000080oooo100000090?ooo`@00000
0`3oool5000000030?ooo`000000000000<000000P3oool500000080oooo100000020?ooo`D00000
0P3oool5000000030?ooo`000000000000@0000000<0oooo0000000000000`0000020?ooo`<00000
;`3oool001D0oooo00<000000?ooo`3oool00`3oool3000005`0oooo00<000000?ooo`3oool01000
00020?ooo`D0000000<0oooo000000000000100000000`3oool000000000000:000000030?ooo`00
0000000000@0000000<0oooo000000000000B`00000_0?ooo`005P3oool00`000000oooo0?ooo`02
0?ooo`800000D`3oool4000000<0oooo100000000`3oool000000000000Q00000080oooo1@000000
0`3oool000000000000:000000030?ooo`000000000000@000000P3oool400000080oooo1@000003
0?ooo`@0000000<0oooo000000000000100000000`3oool000000000000400000080oooo0`000004
0?ooo`@0000000<0oooo0000000000001000000`0?ooo`00503oool010000000oooo0?ooo`000003
0?ooo`800000A`3oool00`000000oooo0?ooo`020?ooo`@000000P3oool5000000030?ooo`000000
000000L000000P3oool5000000030?ooo`000000000000<000000`3oool3000000<0oooo10000002
0?ooo`@000000`3oool4000000<0oooo0P0000050?ooo`<000001@3oool2000000<0oooo10000003
0?ooo`<00000103oool3000000D0oooo0P0000030?ooo`<00000103oool3000000D0oooo0P000003
0?ooo`<00000<P3oool001D0oooo0P0000040?ooo`800000AP3oool2000000<0oooo2@0000000`3o
ool0000000000004000000030?ooo`0000000000008000000`3oool3000009d0oooo000K0?ooo`80
0000A03oool:000000030?ooo`0000000000008000000P3oool400000:X0oooo000K0?ooo`800000
?P3oool>000000<0oooo0`00002a0?ooo`006`3oool2000003h0oooo1`0000030?ooo`<00000^03o
ool001/0oooo0P00000h0?ooo`<000000P3oool300000080oooo0`00002n0?ooo`006`3oool20000
03P0oooo1`0000340?ooo`006`3oool3000003H0oooo1`0000350?ooo`006`3oool3000003D0oooo
0P00003;0?ooo`006`3oool300000300oooo1`00000_0?ooo`<00000103oool3000000<0oooo1000
00030?ooo`@000000P3oool4000000<0oooo100000030?ooo`@000000P3oool4000000<0oooo1000
00030?ooo`@000000`3oool3000000<0oooo1@0000020?ooo`@000000`3oool400000080oooo1000
00030?ooo`@000000`3oool2000002l0oooo000K0?ooo`<00000;`3oool7000001d0oooo0P000004
0?ooo`<000000`3oool4000000<0oooo00<000000?ooo`0000000P000000103oool000000000003o
ool4000000<0oooo100000030?ooo`@000000`3oool400000080oooo100000040?ooo`<000000`3o
ool4000000<0oooo0`0000030?ooo`@000000`3oool4000000<0oooo0`0000030?ooo`@00000103o
ool3000000<0oooo0`0000040?ooo`<00000<@3oool001/0oooo0`00000_0?ooo`8000006`3oool2
000000@0oooo100000000`3oool00000000000030?ooo`<00000103oool3000000@0oooo0P000005
0?ooo`030000003oool0oooo08h0oooo000K0?ooo`<00000;P3oool3000001@0oooo0`0000030?oo
o`80000000<0oooo0000000000000P0000040?ooo`800000ZP3oool001/0oooo0`00000Z0?ooo`H0
00003`3oool2000000<0oooo00@000000?ooo`3oool0oooo0`00002g0?ooo`006`3oool3000002X0
oooo1@00000?0?ooo`H00000_P3oool001/0oooo0`00000Y0?ooo`8000003@3oool300000080oooo
00<000000?ooo`3oool0`P3oool000P0oooo100000030?ooo`800000103oool2000000@0oooo0`00
000X0?ooo`8000003@3oool2000000040?ooo`000000000000000<D0oooo00080?ooo`030000003o
ool0oooo00T0oooo00@000000?ooo`3oool000000`3oool4000002H0oooo0`00000<0?ooo`800000
bP3oool000T0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`3oool4000002<0oooo
1@00000:0?ooo`@00000b`3oool000X0oooo00<000000?ooo`3oool0203oool2000000@0oooo1000
000R0?ooo`H00000203oool200000<l0oooo00080?ooo`040000003oool0oooo000000T0oooo00<0
00000?ooo`3oool00`3oool400000280oooo0P00000:0?ooo`800000d@3oool000T0oooo0P00000:
0?ooo`<000000`3oool010000000oooo00000000000Q0?ooo`<000001@3oool600000=80oooo000K
0?ooo`D00000803oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo000K0?oo
o`030000003oool00000008000007`3oool2000000H0oooo00<000000?ooo`3oool0eP3oool001/0
oooo00<000000?ooo`0000000P00000N0?ooo`8000001P3oool00`000000oooo0?ooo`180?ooo`80
00001@3oool2000000@0oooo0`0000040?ooo`8000001@3oool2000000@0oooo0`0000040?ooo`80
00001@3oool2000000@0oooo0`0000040?ooo`<00000103oool2000000D0oooo0P0000040?ooo`<0
0000103oool2000000D0oooo0P00000_0?ooo`006`3oool5000001/0oooo1@0000050?ooo`030000
003oool0oooo03D0oooo0P0000050?ooo`800000103oool3000000@0oooo0`0000030?ooo`030000
003oool0000000@0oooo00<000000?ooo`0000000`3oool2000000030?ooo`000000oooo0080oooo
00@000000?ooo`00000000000`3oool00`000000oooo000000040?ooo`030000003oool0000000@0
oooo0P0000040?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool200000003
0?ooo`000000oooo0080oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`000000;`3oool001/0oooo100000000`3oool0
00000?ooo`0H0?ooo`D00000103oool200000340oooo0`0000040?ooo`<000000`3oool00`000000
oooo000000040?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000`3o
ool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo0000
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0<03oool001/0oooo100000000`3oool000000?ooo`0H0?ooo`<00000103oool2
000002d0oooo0P0000040?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000`3o
ool010000000oooo0?ooo`0000030?ooo`060000003oool0oooo0000003oool000000`3oool01000
0000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000103o
ool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo000000030?ooo`80000000<0oooo0000003oool00P3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool01000
0000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000<P3o
ool001/0oooo1P00000H0?ooo`<00000103oool00`000000oooo0?ooo`0V0?ooo`800000103oool0
0`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool01@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0
000000@0oooo00<000000?ooo`000000103oool3000000<0oooo0`0000040?ooo`030000003oool0
000000@0oooo0`0000040?ooo`800000103oool3000000@0oooo0`0000040?ooo`800000103oool3
000000@0oooo0`0000040?ooo`800000103oool3000000@0oooo0`00000b0?ooo`006`3oool60000
01P0oooo0P0000040?ooo`030000003oool0oooo02H0oooo100000020?ooo`050000003oool0oooo
0?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo
000000040?ooo`<000000`3oool3000000@0oooo0`0000040?ooo`8000001@3oool2000000D0oooo
0P0000040?ooo`8000001@3oool2000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0340oooo
000K0?ooo`H00000603oool2000000<0oooo00<000000?ooo`3oool08@3oool3000000<0oooo00@0
00000?ooo`3oool000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool30000
00@0oooo0P0000050?ooo`800000U`3oool001/0oooo1@0000000`3oool000000?ooo`0F0?ooo`80
00000P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0000000<0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000@0oooo0P0000050?ooo`030000003oool0oooo0:<0oooo000K0?oo
o`L000005@3oool6000001l0oooo0P0000040?ooo`030000003oool000000080oooo00<000000?oo
o`3oool00P3oool300000;40oooo000K0?ooo`<0000000@0oooo0000000000000000503oool50000
0200oooo00@000000?ooo`00000000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
^03oool001/0oooo0`000000103oool0000000000000000D0?ooo`@000008@3oool01P000000oooo
0?ooo`000000oooo000000D0oooo00<000000?ooo`3oool0]`3oool001/0oooo00@000000?ooo`00
0000oooo0`00000C0?ooo`@00000703oool2000000@0oooo00<000000?ooo`3oool00`00002o0?oo
o`005@3oool2000000@0oooo00<000000?ooo`0000000P3oool300000180oooo00<000000?ooo`00
00007@3oool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo0P00002o0?ooo`00
503oool010000000oooo0?ooo`0000030?ooo`030000003oool000000080oooo0`00000A0?ooo`<0
00007@3oool00`000000oooo0?ooo`02000000030?ooo`000000oooo0<@0oooo000F0?ooo`030000
003oool0oooo0080oooo0`0000020?ooo`<000004@3oool2000001h0oooo00@000000?ooo`3oool0
oooo0P0000360?ooo`005`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool30000
0100oooo0P00000I0?ooo`<000000P3oool00`000000oooo0?ooo`3:0?ooo`00503oool010000000
oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo0P00000@0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`3:0?ooo`005@3oool20000
00@0oooo00@000000?ooo`3oool000000P3oool3000000h0oooo0P00000J0?ooo`030000003oool0
oooo00<00000c03oool001/0oooo0P000000103oool000000?ooo`3oool3000000`0oooo0`00000J
0?ooo`040000003oool0oooo0?ooo`800000c@3oool001/0oooo00@000000?ooo`3oool000000P3o
ool2000000030?ooo`000000oooo00T0oooo1000000J0?ooo`030000003oool0oooo0=00oooo000K
0?ooo`040000003oool0oooo00000080oooo0P0000000`3oool000000?ooo`080?ooo`@000005P3o
ool200000080oooo00<000000?ooo`3oool0d@3oool001/0oooo00@000000?ooo`3oool000000P3o
ool2000000030?ooo`000000000000L0oooo0`00000G0?ooo`@0000000<0oooo0000003oool0dP3o
ool001/0oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo00@000000`3oool3
000001P0oooo00<000000?ooo`3oool00`00003C0?ooo`006`3oool01@000000oooo0?ooo`3oool0
00000080oooo0P0000040?ooo`80000000@0oooo00000000000000006@3oool01@000000oooo0?oo
o`3oool000000=@0oooo000K0?ooo`050000003oool0oooo0?ooo`0000000`3oool2000000D0oooo
0`00000J0?ooo`030000003oool0oooo0=H0oooo000K0?ooo`050000003oool0oooo0?ooo`000000
0`3oool2000000H0oooo0P00000I0?ooo`030000003oool0oooo0=L0oooo000K0?ooo`8000000P3o
ool010000000oooo0?ooo`3oool2000000030?ooo`00000000000080000000<0oooo0000003oool0
6@3oool00`000000oooo0?ooo`3G0?ooo`006`3oool01@000000oooo0?ooo`3oool0000000<0oooo
2@00000F0?ooo`050000003oool0oooo0?ooo`000000f@3oool001/0oooo00D000000?ooo`3oool0
oooo000000030?ooo`D0000000@0oooo00000000000000005@3oool3000000030?ooo`000000oooo
0=T0oooo000K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07P3oool00`000000
oooo0000000200000=X0oooo000K0?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0=d0oooo000K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`3M0?ooo`002@3oool2000000@0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0gP3oool0
00P0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3N0?ooo`002P3oool0
0`000000oooo0?ooo`0:0?ooo`040000003oool0oooo0?ooo`<000000P3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo0=h0oooo000;0?ooo`030000003oool0oooo00L0oooo0P000004
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3N
0?ooo`00203oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0K0?ooo`800000h03oool000T0oooo0P00000:0?oo
o`<000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo1000003Q0?oo
o`006`3oool2000000@0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`00003R0?oo
o`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0h`3oool001/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo05X0oooo:@00001Q0?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0FP3ooolY00000640oooo000K0?ooo`800000103oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05X0oooo:@00001Q0?ooo`006`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0FP3ooolY0000
0640oooo000K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`1K0?ooobT00000H@3oool001/0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo05/0oooo:@00001Q0?ooo`006`3oool2000000@0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`1D0?oooc000000H@3oool001/0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0@0?ooo`040000003oool00000000005H0oooo00<0
00000?ooo`3oool09P3oool700000640oooo000K0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03`3oool010000000oooo00000000001G0?ooo`030000003oool0oooo02H0oooo1`00
001Q0?ooo`006`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo0P00001J
0?ooo`030000003oool0oooo02H0oooo1`00001Q0?ooo`006`3oool2000000D0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02H0oooo1`00001Q0?oo
o`006`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0F@3oool00`000000oooo0?ooo`0V0?ooo`L00000H@3oool001H0oooo0`0000020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo00l0oooo0P0000000`3oool00000000000030?ooo`8000003@3oool700000640oooo
000G0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo05X0oooo00<000000?ooo`3oool0403oool00`000000oooo000000030?ooo`040000
003oool0oooo000000`0oooo1`00001Q0?ooo`00503oool500000080oooo0`0000040?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0000000<000000D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`L00000H@3oool001@0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0?0?ooo`80000000<0oooo000000000000
1@3oool00`000000oooo0?ooo`0:0?ooo`L00000H@3oool001D0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000000`0oooo1`00001Q0?ooo`005P3o
ool2000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo05/0oooo00<000000?ooo`3oool05`3oool2000000d0oooo1`00001Q0?ooo`006`3oool2
000000H0oooo00<000000?ooo`3oool01`3oool3000000030?ooo`000000oooo05`0oooo00<00000
0?ooo`3oool09P3oool700000640oooo000K0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool010000000oooo00000000001N0?ooo`030000003oool0oooo02H0oooo1`00001Q
0?ooo`006`3oool00`000000oooo0?ooo`060?ooo`<000001@3oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo02H0oooo1`00001Q0?ooo`006`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0V0?ooo`L0
0000H@3oool001/0oooo0P00000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
H03oool00`000000oooo0?ooo`0V0?ooo`L00000H@3oool001/0oooo00<000000?ooo`3oool02P3o
ool010000000oooo0?ooo`00001S0?ooo`030000003oool0oooo02H0oooo1`00001Q0?ooo`006`3o
ool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000006<0oooo00<000000?ooo`3oool0
9P3oool700000640oooo000K0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`000000H`3o
ool00`000000oooo0?ooo`0?0?ooo`80000000<0oooo0000000000000P3oool4000000`0oooo1`00
001Q0?ooo`006`3oool2000000`0oooo0P00001T0?ooo`030000003oool0000000`00000103oool0
0`000000oooo000000030?ooo`030000003oool0oooo00d0oooo1`00001Q0?ooo`006`3oool00`00
0000oooo0?ooo`1a0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0<0?ooo`L00000H@3oool001/0oooo00<000000?ooo`3oool0L@3oool00`000000
oooo0?ooo`0?0?ooo`80000000<0oooo000000000000103oool00`000000oooo0?ooo`0;0?ooo`L0
0000H@3oool001/0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0F0?ooo`040000
003oool0oooo000000`0oooo1`00001Q0?ooo`00S`3oool00`000000oooo0?ooo`0G0?ooo`800000
3@3oool700000640oooo002?0?ooo`030000003oool0oooo02H0oooo1`00001Q0?ooo`00S`3oool0
0`000000oooo0?ooo`0V0?ooo`L00000H@3oool008l0oooo00<000000?ooo`3oool09P3oool70000
0640oooo002?0?ooo`030000003oool0oooo02H0oooo1`00001Q0?ooo`00S`3oool00`000000oooo
0?ooo`0V0?ooo`L00000H@3oool008l0oooo00<000000?ooo`3oool09P3oool700000640oooo002?
0?ooo`030000003oool0oooo02H0oooo1`00001Q0?ooo`00S`3oool00`000000oooo0?ooo`0?0?oo
o`80000000<0oooo0000000000000P3oool5000000/0oooo1`00001Q0?ooo`00S`3oool00`000000
oooo0000000<000000@0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0;0?ooo`L0
0000H@3oool001T0oooo1000001b0?ooo`030000003oool0000000`000001@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00/0oooo1`00001Q0?ooo`006P3oool00`000000oooo0?oo
o`1b0?ooo`030000003oool0oooo00l0oooo0P0000000`3oool00000000000040?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0I@3oool001X0oooo00<000000?ooo`3oool0LP3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0I@3oool0
01T0oooo1000001b0?ooo`030000003oool0oooo01L0oooo0P00000=0?ooo`030000003oool0oooo
06D0oooo002?0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0I@3oool008l0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1U0?ooo`00S`3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo06D0oooo002?0?ooobX00000I`3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.05261, -0.648943, \
0.00733523, 0.00733523}, {{7.125, 279.813}, {172.688, 4.1875}} -> {-13.1101, \
0.55181, 0.469539, 0.0250463}, {{143.5, 184.375}, {47.5625, 6.625}} -> \
{-11.8961, -11.7507, 0.0822027, 0.0900315}, {{145.688, 157.813}, {45.5, \
34.375}} -> {-12.6414, -38.3928, 0.0865988, 0.28024}, {{145.688, 157.813}, \
{32.625, 21.5}} -> {-12.6414, -42.0009, 0.0865988, 0.28024}, {{145.688, \
157.813}, {19.75, 8.625}} -> {-12.6414, -45.609, 0.0865988, 0.28024}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[91]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[model, k, input, \ ic, x1, x2, x3, eq1]\)], "Input",
  CellLabel->"In[92]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Large compartimental models ", "SubsectionIcon"],

Cell["\<\
Here is show the metabolic uranium model as appeared in ICRP 78\
\>", "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74965 
%%ImageSize: 720 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.35272e-017 0.00139082 -0.00139082 0.00139082 [
[ 0 0 0 0 ]
[ 1 .74965 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .74965 L
0 .74965 L
closepath
clip
newpath
% Start of gray image
p
0 -0.00139 translate
1.00139 .75104 scale
720 string
720 540 8 [720 0 0 540 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFFFFF8FFF9FFFFF1FFFFFFF4FDFFFFFEFFFFFCFF
FFFDFFFDFFFAF7FFFEFFF9F0FFFBFFFFFFFAFFFFEDFFFEFFFFFFFFF6FFF8FFFBFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFCFFFFF9FFF5FFFFFFFBFBFEFFF4FFF8FFFFF1
FFFDFEFFFDFFF5FFF9FFFBFEF6FFECFFFAF5FFF7FFF7FBFFF6FFFFFAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFFF6FFF9FFFFF7FFE6F7FBFDFFEAFFFFFCFFFCEEF4FFFF
FAFFF4FFFFFFF1F7FFF8FFFFFFFEEBFAF1FFF6D9FFFFFAFFFEEEF5F8FAFFFFF5FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4FFF3F7FFFDF9F5FFFFFFF4FFFCFFF1FDFF
FFF9FFDDFAFAFFFCEEFBF4FFFFE3FFFFFEFFFDFFF7FFFFF1FFFFF3FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBF3FFFBFFFFF9FFFBFFFFFFFFFBFBEEF8FCFBFFFFFFFFF1
FFFFFFFFF4F7FFFFFCF8FFF7FFFDFFFFFFFCFFFFFFFCFFF3FFFDFFFFFBF9FBFDFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFAF3FFFBF7FFFFFFFBFFFCF6FFFBF6FFFCFF
F0FFFFFFF9FFFFFFFFFAFFF5F8FFFFF6FAF1FFFBFFF5FFFFFFFBF1FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFEDFCFFFFFCFCFFFFEDFAFFF8FFFFF9FFFDF9FEF6FBFF
FDFFFEFFFAFFFFF1FEFFF6FFF8FFFFE7FFF6FEFDEEFDF6FFFFF9ECEDFCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF09F9FEFFFFFCF7F30000FF01FBFFF00006
15E9FAF30900FFE8F6FF000006FFEBFFFF0B000AF1FFF5FFFFFFFCFCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCBF2FFF8B3FFFFFFBAC3D2C7F7FDF9C1FDFBFFB6C3D7ABFF
FBF9C5ECFFF7C5C5C6C1F9FFF4C9FAFFFFBAD3B6C5FFFFEBB9FFFFF5FFFFF6FAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFF00FFFFF0FCFFFF02FFFF0000FFEF0FFCFE
FB00FF00FDFF00FFF60AF8FFF100FFFF00FEFDEE02FFFDF8FEFFF6FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF3BCDFFFF42FFFFFF3F3B3D38FCFFFF3CFFFFFC5A25403FF6
FFF74CF7FFFD30443549F8FAFF00FFF5F84F314843E5FFFF49E9FFFFFFF2FCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F20CFFFFFFFFF5FF00FAFBFF0BFDFE00FDFF
FFFEFF00FEFFF3F7FF00F1FFFFFFFEF9F8FFFDFF00F7FFFFFBFFFBFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF3FD1FDEEFDF0FFF7FFFFFFFDFBFFFBFFF3FFEBF7FFFFFFFF
E1FFFAFFF2FDFFF9FFF5FEFFFFF605FFFFFFFFF7FFFFFCFAF4FFB7FFFFFFFFFCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FF00F2F5FFE8FFFBFF00050000FEFF000700
1004F10BFFFDFFFFEB0016000009FDFFFD000001FFFFF0FCFCFFFFF1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF44ABFFFFFFFF00FEFDF7FFFF00FC0CF8FBFF00070100FFFD
0DF1FFF50BFFEE090000FFFDF5FF00FFF4FFFF000B00F7FFFFC433FAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF500010C00FFF9FFFAF6FFFA09FBFA03FFFE
FF00FA02FAFFF7F8FF08EEFFFF00EBFF04FFFEFAFFF5FFF8FFF6F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF42C1F6FEFFED01FAFFF9FF09F6FD05F6FF00FFF8FF04F2FF
0CF6FAFF00FB00FFFCFF00FFFFFC00FFFFF705F5FFFF00FFFFD51DFBFEFFFFF9FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF60EF7FFFFF8FFFF00FFF1FF09F7FF00FFFB
FF00F40EFEFE00FEFE00FEFEFA0CFBF202FFEBFF0DF1FFFAFFF0FFF6FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF6FFFDFFFFF711FFF0FF00FFFFF600FFF305FCFFFF00FFEC
00FFFFFF00FF0FFAFFFEFFF7F008FD00FDFFF1FFF5FF0DF4FDE122FFF6EFFDFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FF00F9F0FEFFFDE9FF000000F2FFF2FF0000
08FFFFFF0500FFFBFBFF000502F3FFFFFF001300F1FFFBFFFFEFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFBFFF9DFFF0005FF00FFE7FFFF00FFFF00F9FCF700F1FF
00FEFFE910FF0004000508E5FF0EF103F7FFF20A0000FEFFFFE358F9FDFFFFF6FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFF05F4FFFFF2FFFFFFFFFFFFFBFFFFFFF7FF
FFF6FBF1F8F5FFFFFFFFF5F8FEFFFBF7FFF2FDFCFFF3FFFFFFFFFEF8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF4FFFBFDFFFF07FD00FEFFFFF7FB00FFEE00FFFFFF08F5FF
01FEFFFF00F215FFFFFF00FFF503FE02FEFA1BE5FFFFF0F7F8FFFFFFF4FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFF3000000000BFBFFF9F5FDFBFAFFFAFFF7FB
FBFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFFFFFF9F5FFFBEBFFFFFBFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF3DC1FEF5FFF800FFFF00FFF6FFF918FFFF00FFFB0003FEF8
0402FFE603FF00FBFFED07FF01F1FFF80BFD00FFFFFC00FFFFFAFFF5F8FFF2F2FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFF8F7FFF4FAFFFEFDFAFBFFEAFFFF
F0F2FCFBF7FFF9FFFFF9FFF7FFFCFFEDFFF1FFFCFFFFFBFDFFFCFCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFF1FA15FEFFED03FFFFF800F5F0FF0400FF00FFFD
00F60800FFFEEF050200FFE709FFF3FD00F6FF000000FBF4FFF2BCFFFFFCFDFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEF5FFFFF1FFFFF3FFFAEFF7FFFFFFFFFFFFF2
FFFFFEF8FFFCF8FFFFF8FCFFE9FFF6FFFFFFF8FFF0FFF2FFFFFAFBFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFBFFFC00FEFFFFFD00FFFFFCFFFFEAFFF6FF00FEF6
FFFCFFF3FFF9FFFAFFFFFFFFFDE1FFFFFFFFFEF6F4FFFFFFFDD86FF0FCFFF7EEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FEFFFFFFF7FFF9FFEFFFFFFFF1FFEFF6FFF2FF
FFFFEFFFFFFBFFEEEEFFFBFFFFEEFFF6F9FFFFFEFDFFFFFAF6F9FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEF4FFFFF6FF09FAF8FEFFF70EF300F7F7FFFBF8FF05FCFF
FDFAFFFDFFFFF8FFFBFEFBFFF3FFFFFBF9FFF8FDFFFDFFF8FEFFE2FFF7FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4FFFFF1FFFCFFFBF7FFFFFEFFFFFFFFFA
FEF9FFF1FDFEFDFFFFFDFEFDF8FCFFFFF5FFFAFFFFF3FFFFFBFFFFF4FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF41C0FFF6FDFFF9FFFFFFFFFFFFFFFFFFFFFFFEFBFCFDFEFF
FBFFFFFFFDF9FBFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFEFFEDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDF9FFFFFFFFFFFCFBFFFFFEFFFFFF
FFFFFEFDFEFFF8FFF3FFFFFDFEFBFFF6FFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF34C1FFFFFFFFF8FEFFFFFFFFFFFFFFFFEBFFFFFFFFFFFFFC
FFF9F1F7FFFFFFF3FFFCF8FEFDF4F3FCFFFFFFFFFFFFFFFFF9FFCCFAFDEFFFF6FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FDFFFCEFFFFFEEFBFFFFFBFEFFFFF4FEFEFEFF
FFFFFFFFF6F5FFF0FFF9F4FFFFFFFFFFFFFEF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4DBDF7EFFBFFFFFFFFFFFFFFFFFFFFFFFFFFF0F8FFFFF9FF
FDFFFFFFFEFBFFFFF1FFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFD11CFFFEFFF3FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFFFEF8FFFFFFFAF8FFFFFABE84725F4538
42638BA6FEFFFBFCF7FFFFF6FFF2F9F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF3EB4FFFFFFF8F6FFFFFFFFFFFFFFFFFFECFFFFF1FAFEF8FF
FDFBFBFEFFFFF9F3FFFEF8F9FFFFFBEDFFFFFFFFFFFFFFFFFFE016FFFBFCFFFDFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFCF6FFFFEEEFFFFFF7B44C123A84899DB8C7
BC9A70540C418EFFFFF6F7FFFFFFFFFDF8FFFFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFFFFF5FFFFFCFAFFFFFFFFFFFFFFFFFFFFFAFEFFFFF9FF
FFFFFFFDFEFFFFFFFFF7FBFFFFFBFBFFFFFFFFFFFFFFFFFFFAE62AFEF3FBFFF9FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFAF8FFFFFF984054A9EAFDFBFFFFFFFB
FBFEFFFFFCB46B0F8CFCFCFFF2FEFFFFFCFAFEF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFFFEF9FDFDFDFFFFFFFFFFFFFFFFFFF8F4FDFFECB7805F
3E42423E4871AFDFFFFFFFF3F1FFFFFCFFFFFFFFFFFFFFFFFFE04FFFF8FFF9FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFFF5FFFFCC206BC3F6FFFFFFFFF4F9FFFF
FFFFFBF7FFFFFFFA6615B8F7FFFFEDF7FFF9FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFFF5FFFFFFFFFFFFFFFFFFF1AB450F458C96
BEBFC2C4B4884D212C8BECFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFF8FFF5FFFDFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFF4FFFFAA3BDCF3FFFDFBFFFFFAFFFFFCF9
FAFDFFFFFBF9FBFBFFF05A70F1FFFFFAFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF49A8FDFFFBFBFFFEFFFFFFFFFFFFFFFF8D354CBFF8FCFFFF
FFFFFCFCFEFFFFFFD8662D7BE4FFFFFDFFFFFFFFFFFFFFFFFFEDFFFFFFFFF4FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFF4FFFE7552ECFEFFFFFFFFFCFDFFFFFFFFFF
FFFEFEFDFFFFFFF9FFFEEE8A53E2FFFAFFF9FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDF9FFFFFDFBFFFEFFFCFFF3FFFCFAFFF7FFFFFFFFF4FFFBFFF1FFF9
FFFAFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FFF9FFFEFFF9FF
FCFFF7FFFEF5FFF2FFFFFFFFF0FFFFF6FFFDFFF0FFFAFBFBF6FFFFFDFFFFF7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF5FBFFF5FDFFFEFFFFFFFEFFFFCF216CC9FFFFF6FBFFFD
FFFFFFFFFFFFFFFFFDFFE9753299FFFFFBFFFFF2FFF6FAFFFDFEB6FFFFF6FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FFFF7684FFFFFDFFFF00FFFFF1FFFC00F9FF
FFFFFE00FFFAFF07FFFCFFFEB451FEFBFFF8FFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFBFCFDFFF7FDFDF5FFFFFFFFF7FEFFFFEEFBFFFEFFFFFAFFFFFF
F6FCF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFAFFF3FFF8
FFFDFFFFFFFDDEFFF8FBFFF0FFFEF0FFEFFFFFFFECFFFFFDFFFFF8F9FAEEFDFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFCFCF9FFFCEFFFF69332F0F7FFFFFEFFFFFFF5
FFFFFFFFFFFFFFFFF7FFFFFFE56560F1FFFCF2FFFFFFFFF1FEE960FFFAFEF9F1FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEF7FF9468FFF9FDF8FFFC06FFEAFFFCFF00FFFF
F2FF00FFF1FFFDF8FDFFF1FFFD9963FFF4FFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF9FFFFFFFCFFE7FFFAFFF7FFFDEFFFF9FFEDFFFFECFFF9F9FFFFF6F2
FFFFF8FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFCFFFCFBFFFE
FCFFF6FFFDFBFFF5FCFFE9FFFCFFFCE5FFFFF3FDFFF5F9FFF0FFF7FFFCFFFFFDFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFEDFEFAF5FFFFFEFEF6FFFFFA7271F2F0FFFFF5F7FFFFFBFF
FFFFFFFFFFFFFFFFF9FFF5F0FFF59C4EEAFDFFFAEDFFFFF8FFFAF6FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFC342ECFFFFFFFFFBFF00F0FFFDFCFB00FFF5
FFF300FBFFF6FAFFFFFFFFFEFFF57486FFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFCFAF9FFFFFFFFF0FFF3FFFFFFFDEFFFF8FFFFFCFCFFFEFFFFFB
FFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2FFECFFFFEEFF
FFF8F6FFF8FDF2FFFEEBFFFFF8F8FFFFFFFFFDF9F6FFF5FCFFFFF8FDFFF9F8FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF51C0FFFFFFFBF6FFF0FFFF6287FFFFFFF6FEFFFFFFF3F3FF
FFFFFFFFFFFFFFFFFFEDFFFFF0FFFAB152F2FDFFFFFFE0FFFAFFFFEAFFF4FFE9FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFED2AE6F1FFFFFCF6FFFC00000002FFFF030005
000F0AF7FEF8FFFFFCF8F2FDF5FFF53ACBFAFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFCF9FFFFF4FFE2F3F8FFFFFEF4FFFDF9FBFEF1FFFBFCFFFFFBFDFF
F8FFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFEFFFF9FFFFFD
F5FFFFEEFDFEFFFEFFFFF2F9FFF4FFFBFFEFFFFFFAF7FFFFF0FCFFEAFCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF31BDFFFEFFFFF6FFFFF98F7DEFFFFAFFFFFFFFFBFFFFFDFF
FFFFFFFFFFFFFFFFFDFFFFF9FDFFFFFF9459F5FFFEF1FFFBFFE4D2FFF2FFE6FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC926EF5FFFFEAFFFFFFFD00FFF4FFFAF60BFBF1
FFFE00FFF9FFF5FDFAFDFFFFFFF4FFB14EFFFFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFCFCFFFFFFFEFFFFFFFFF7FFFFFFFAFFFFFEFFFFFFFFFFF4FFEDFFF6
FFF6FFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFCF2F2
FDFFF7F7FFFFF3F0FFECFFFFFEF5FFFEFFFBFDF8FFFFF8F5FFF9FFFFF4FFF7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF46C1FDF3FFFFFCFFFFBD39FFF2FDFFF3F6FEFAF5FEFFFFFF
FFFFFFFFFFFFFFFFF4FFFDFFFFF1E8FFFF857BF4FDFAF6FFFFE915FFFFFEFFECFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF38E3FFF7FFFFFCF5FCEB13EAFCFFFFFF00FFF2
FFFFF500FFFAFF0BF2FFF1F2FFF8FAFF4BB2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFAF9F3FFDBFFF2FCFFEDFFFEECFFF5FDECFFE7FCFFFFFEFFFFFA
FFFEEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6000B000000FFFF
FF05F8FEF70002FF00FEFF00001100FFFFFB050D0000FFFFFF060000FFEDFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF45B6FFFFFFF6F7FFFC0FEDFAFFFFFBFFFDFFFFFFFFFCF6FC
FFFFFFFFFFFFFFFFFFFFFCFBFFFFFFF3FFFF1CEFF0FFFFF6FADD28F6F9F6FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8179FFF7FFFAF9FFFDFFFF0005090004EC0A0009
0000FFFF040100F5FBFDF8FFF3FFFFF4B746FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFAFFFAFFFFFC060003FFF4FFF606FFFBFF02FFF806FFF8FF02F8FEFF
000208FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFAFF00FF
FD00FFFF00FEF90301FD00FCFFF409FFFB07F5FBFF00FFFC00FFFFFF03F1FF04FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFFFDF7FFFFFAFD778DFFFEFBF4FFFBFFFDF4FAFFFFFDFF
FFFFFFFFFFFFFFFFFFFBFFFFFCF9FFFFFFFFC72DFFF5FFFFFFD321FFFFFFFDFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3ABDFFFAFDFFFEFCFFFBFBFDFFFEFFFDFFFBF9FF
FFFFF5FFF4FFFFFFFFF8FFF7FFFFF5FFF423F3F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFEFFF6FFF900FFFEFF00FFFFF500FFF9FF00FFF900FFF1FF04F0FF03
EEFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07F6FFFBFF00FF
FF00EEFF01FFF9FC09F60CFFFEFF03FAFD00FFFFFF02FFFF07F5EFFFF6FBFF03F7FFFCF8
FFF3F8FFFFFFFFFFFFFFFFFFFFFBFAFFF4FFFEE22AFBFFFAFEFCFFFEFFFFFFFFFFFFFFFF
FBFFFFFDFCEFFFFFFFFFFFFFFFFFFFFFFFF5FF50B7F6FDFFFFEB52FFF9FFFFF9FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF8FFFFFFD031F1FFFBFFFFFEFFFFFFF6FFFAF3FFF3FCFFFEFF
EBF7FFF8FDFFF6FFFFFFFFFDFFFBFFF5FE738BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDF9FFFC03FAF9FFF9FF00F9FF07EFFFFF00F4FF08F7FFF000FFEB00
FFF7FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD00FFFFFFF204F9
FF11FCF1FF00000600F700FFF6FE03FEFF08FCF9FD00F6FF000F1B0002FFEC00FFFEFAFF
FFFEFFEEFFFFFFFFFFFFFFFFF9FFFFFEFFFBF58078FFFFFDFFFFFDFEFFFFFFFFFFFFFFFF
FFFFECFFFFFFFFF0FFFFFFFFFFFFFFFFF8FFFEB943FDFFFBF9FFFEFFFAF6FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFFFEFDF9F69D64FFFFFEFFFCFFFEF6FFFAF8FFFCF6FFFFEAFFF0
FFFFFCFFEEFFFCFFFFFFFCFFFEFBFFFBFF946AFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF5F1FF00FFFFF4FCFF00F8FF00FFF5FF00FFFF00FFFEFF0DF6FF00
00000009FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE010005000009F8
F600F7FFFFFFFAFF00FF00FDFFFF00FFF409E9FFFF00FFFF0FEAEFFF00F5FF00FFDFFFF8
F9FAFFFFFFFFFFFFFFFFFFFF41B6FAFEFFFFFA2BD2FFFCFEFFFFF9FFFFFFFFFFFFFFFFFF
FFF6FFEDFFF9FFFFFFFFFFFFFFFFFFFFF5FFFDFF13DDFFFAFFFCFFF1FDFFFBF3FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF9FFFFFEFFFA7889FFFEFDFCFDFFFEFFFFFFF3FFFFEFFFFBFFFFFF
DFFAFCF9FFFFFBEEFFFFF8FFFDFEFFFBFFC13BFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFFFBFF05FDFBFBFFDE05FFFC06FFFFF20BFFE60AFFF8FA00ECFF0C
FFFBF703FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF04FFEBFFFD00FF
FF00FCFF00FEFFF000FF0AE8FF0015FAFF00FFFF000CFFEC00FFFFFF00F4FF0600FFFCFC
FFFFFDEFFFFFFFFFFFFFFFFFFBFFFFEDFFFED21BFFFFFBFCFFFFFAFFFFFFFFFFFFFFFFFF
F3FFF5FFFFFFEFF9FFFFFFFFFFFFFFFFFFFFFFFD6393FFFFFDF7B5FFFBFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF8FEFFFBFFFF61A0F8F7FFFCFFFFFAFDFAFEFEFFFFFFF6FFFFF0FB
FFFFF4FFF3F0FFFFFFF9F4FFFFFFFEF5FFE815FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF4FFFFF600FFEEFFF7FF09FBFF0200F6FF00EFFF0303F9FF0BFEFF00
F1FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00F2FFFCFF00FF
F507FFFCFE000000FFFFFC0B04F700FBF9F80006FB00ECFFFA060000FFFFFF00FF00FBFF
FFF5FFFFFFFFFFFFFFFFFFFFFFF7FCFFFEEA9C80FFF7FFFCFBFFFEFFFFFFFFFFFFFFFFFF
FFF9FFFFFFF6FFFFFFFFFFFFFFFFFFFFFFF5FFF2B44FFFFFFFDF6AF5FAFFF7ECFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDFDFFF5FFFB42BFFFFFFFFDFFFFF8FDFFF3FFFFF3FEFFFBF2FFF9
F9FFFFF8FFFCFDFFFCFFFFFEFFFFFCF7FFFD01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF0FF0FEAFFFEFFFA04FFED04FF00FE11FFFC0DEE0900F9F9F1FF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF09FFFDFFFF00F9
FF02EBF5FFF6FFFFFFF2FFECFFFF00FFFDFFFEF8FF05F6F6F9FFEFFFFFFFFDF9FBF3FFF8
FCFBFFF9FFFFFFFFFFFFFFFFFAF7F9FFFDFF667EFFF9FFFFFCFCFFFDFFFFFFFFFFFFFFFF
FCF1FFF8FFFDFCFDFFFFFFFFFFFFFFFFFDF9FFFFC62DFFFAFCFFF7FFFFF9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFEFEFFFBFFFA3CC5FFFFFFF8FFFFFFFFFEFFFFDAFFFD0203000903
F50B0004E7FFF6FFF7FFFFFAFBFFFFFFFFFC03FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFEFDFFFF00FFFFEDF9FF00FFF6FFE9FFFCFAFFF4F5FFFAFFFFFFFFFF
FFFAFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7000F000000FCFF
F409FFFFF2FFF0FFFAFFFFFFF8F401FFFFFBFCF6FA0CF2FFFFFAFFE6FFFEFDFFFFFCFFFC
FDFFF2FFFFFFFFFFFFFFFFFF4CC1FEFDF8FF5FACFFFCFFFFFFF7FFFBFFFFFFFFFFFFFFFF
FF00060000FFFFFFFFFFFFFFFFFFFFFFF8FFFFFFDF14FFFAFFFAFFF2FFFFFFF9FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF6FFFCFFFFFFFF54ADF6FDFCF9FFFCFFF3FFF7FFFFFFFCFF00FFFBFF
00FDF1FF15E9FFFFF9F8F0FFFBFEFFFFFFEC15FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF9FFF204FFFCFFFEFF05FFFEFEFBFFFE00FFFAFFFFF8FFFAFFFBF8
FFFFFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFAFFFFF4
FFF5FFFFFDFFFFFFFEFCFCF3FFFFFBFDFCFFFEFFF4FFFAFFFCFFF9FEFEFCFFF6FCFCFAFF
F8FFFFFEFFFFFFFFFFFFFFFF3DBEF8FFFFED42BCFFFBFBFCFFF4FFFBFFFFFFFFFFFFFFFF
00FEFEFFFF00FFFCFFFFFFFFFFFFFFFFFFFFF9EDFF00FAFFFFEBCDFFFCFFF5FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFCFFF9FEF9FAFF649DF4FFFFFFFFF5FFFFF2FFFFF4FEFFFAF908FCFE
04FAFFF200FFFBF5FFFFF1FFFFFEFEFEF9DC27FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFF
FFFFFFFFFCFFFBFDFFFFF8FF46B5FFF8FAFF49B9FFFDFBF8FFF5FFF9FFFFFFFFFFFFFFFF
07F3FFF4FF00FFFFFFFFFFFFFFFFFFFFF7FFFDFBFF00FFFFFFDC17FFFFFFF4FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFEFFFF7FFFFFFFEF6FFF9FFFAFAFCFFF3FFFFFBFFFFF4FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFFFCFFFAFFF8827DFFFEF1FFFFFCFDFFFEFFFDF9FFFFFFFCFF00FE
09F6FEFF06F9FFFFF6FFFFFFFCFFFFFFF7BE40FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFEFEFFFFFCF1FDFFFDFB41B9F6FFFFFB4CAFFDFDFFFBFFF8FFF9FFFFFFFFFFFFFFFF
00FBFCFFFC00FFFCFFFFFFFFFFFFFFFFFEFDFDFFE316FFF6FBE02FF4FFF6FFFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEF3FFFFFFF9F4FFFFF1FFFFFAFFF6FFFDFFFFFAF6F9FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF5FFFBFEFFBD34FFF1FFFCF7F7FFFBFFFCFEFFFFFAFFFFFAFB00
00FFF8FF00FCFBFFFFF5FBFFFFFFFFF6FF7F7DFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FEFEFEFEFFE6FFFFF1EEFFFFFFFFFDD197F38690FEFAFFFCFAFDFFFCFFFFFFFFFFFFFFFF
00FFFFFFFE01EDFFFFFFFFFFFFFFFFFFFFF7FDFFCE31FFFBFFD619FEFFFFFBFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFAF2FFFFFFF0FFF2F4FFFFFFFFF0FFF2FFFFFAFBFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF2FFFFFAFFF52BCFFFF4FFFFF9FFFFFFF3FBFFFFFFF5F4FFFF00
07FFE5FF01FFFFF1FFFFFFF6FFF7FFF0FF24DAFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFFF8FFFFF6FFFFFAF4F9BC711F56FD9367FFF8FFFAF9FFFEFFFFFFFFFFFFFFFFFF
FF00020007FFFFFFFFFFFFFFFFFFFFFFFFFCFEFDB551EFFFFFE859FFFFFFF1FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF4FFFFFFF8FBF6F7FFFFFFF8FFF4FFF3FFFFFBFDFFFCFCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFFF7FFFFFAFFFF6598FFF8FEFCFFF3F5FEFFFFEBFFEF0FF7FCFF01
00FFFFFC00EEFFFFFCF6FFFDFFFDF7FFD41BFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDF6F9FFEFB02B198DE4FDFFBF38FFFFFBFCFFFFF9FFFFFFFFFFFFFFFFFF
00FFFFFFFA00FEF6FFFFFFFFFFFFFFFFFCFFFFFF6C8FF1FFFDFFEDFFFFFCFFFBFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF3F6F9FFF0FFFFFFDFFFFFF7FAFAFFF9F5FFFBEBFFFFFBFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFAFFFEFDFFFFFCFBC739FFF7FFF4FEFFF5FFEDFCFFEEF5FE0E0000FF
FF000B00FFFFF4FAFFFFFDFEFFFCFFFF6F7CFFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFF
FFFFFFFFF8F8F5FFF05A0C5326CBFFF8FFFDFB2AD6FFFCFFFFFFF7FFFFFFFFFFFFFFFFFF
00FCF5FFFF00FFFDFFFFFFFFFFFFFFFFF7FFFFFF26D9FFF6F7FFF2FFFCFFFEFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFDFFFFFFF7F6FFFDF7FFF3FCF9FFFCFFFFF3FFFFFFFFFEF8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFEFFFFF7FEFFFFFCFF47A3FFFFFDF6FFFFFCF5FFF5FFFFF9FDFFFEFA
EBFFF7FFFDEDFFFFFBFAF8FFFEFFF9D525FFEEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFF
FFFEFBF9FFFFB83F1674E3FFFFFFF1FEFFE9FF687EFFFFFFFFFCFBFFFFFFFFFFFFFFFFFF
00FFFEF9FF00FAFFFFFFFFFFFFFFFFFFFAFFFAC13CFFFFF8FBF195FFFAFFF1FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFEEFFFAFEFFF8FFFFF8FFFDFFFFFDF7F1FFFBFFFFEFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFBFBFFFFFFF9E621FEF5FFFFF5FEF6FFFFFFF3FAF7ECFFFEFC
FFF2FFFFFFFFFFF7F6FFFFFAFFEDFF4BB4F9FFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFF
FFFAF5F27A2732A8FBFFFDFCFFF8FFFBFFFEFFD231FDFFFDFFF9FFFFFFFFFFFFFFFFFFFF
FF00000700FFFEF9FFFFFFFFFFFFFFFFFFFFF57786FFF1FFFEF583FAFFF9FFFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000700FBFFFCF5FD00FFFBF5FFF9FF0DF1FFFAFFF0FFF6FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF6FFFFFCFCFBFFFFFF8C73FFFCFFFFFFFFFCEEFFFFF9FFFFFDFFFF
F1FFF8FFF8FFF7FCFFF7FFFCF7FFAF49FFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF9FFFFFEFCFFFFFAFFFBFAFFFFFFFDFDFFFFFDFFFFFFFFFCFFF8F8FF
FFF9FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEF7FEFFFC
FEFFFFF7FEFAFFFBFFFCFFFFFEFFFFFDFFFFF3F2FFFFFEFEFFFFF5FFFFC561FFF7FFFDFE
F7CB531574C5FFFFF1F6FFFFFEFFFDF7FFFFFAFD788BFEFBFFFFF3FFFEFFFFFFFEF8FAFF
FFFFFFFFFFFFFFFFFBFCFFFFFEFCFFFFFEFECC32FAF5FFF9FFF7FFFFFFFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDF9FFFFFFFEFFFCFF
F3FEF6FFFFFD05FFF1FFF1FC04FBFAF4FAFFFFFFFD00FFFFFFFBFFEEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF52A0FFE8FFFFFDF5F7FCFEFDFDFFFFFFFF
FDFBF8F7FFFFFAFFFFFFFAFFFFDA39F2EDFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF8F6FEFFFFFFF9FFFFF5F0FAFFFFFFFFFDFCFEFFFFFFEEFFFFF8
FFFFFDF2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAF2F4FFFFFFFFFD
FBFFFAFFF3FFE9FFFDFFFDF7FFFDF5FFFFF1FFFFEEF9FFFCFCFFFAFFD72A14D9FFF3F2B0
2230A1F8FDFFFFFFFFFFFFF845B6FFFFFFF6F7FFE535DCFFFFF7FFFCF7FFFDFCFFFFFEFA
FFFFFFFFFFFFFFFFFEFFFFF9FBFFFFF2FEFF33B7FFFFF7F9F4FFFCFFFFFFFCF8FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFCFEFFFFFAFFFFE4FEF6
FFFFF5FDFFF901FFFBEBFF01FDFFFFFFFFF2FFF9FDFF00F7F2FFFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFEEF74FB8FFFFF1FDFFFFFFFEFCFDFEFEFDFE
FFFFFFFFF5FFFFFBF9FAFFFFE824ECFFFFFFF5FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFBFFFFFFFFFAF5F5FEFFFFFFFFFFFBF8F9FCFFFFFEFBF9F9FFFFFBFF
FFF9FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFF9F7FF
FFFAF9FFFFFDFFFFBA8E73593D51777A86E6EFF6FFFFFFF8FFF0F8FF160000A1E95E0D5A
B3FFFFF2FFFBF4FBFFFEFEFF46C1FDF3FFFFFCFFFCA165FFF3FFFDFBFFFFFFF6FFFFFFFD
FFFFFFFFFFFFFFFFFFF1FBFFF9F0F9FFFF965D1500152F51727457DAF3FFFAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FBFFFFFFF50A000FFD
ECF5FFFBF8FF00FFFAFFFF02FFF10000FFFFFFF8FFF500FFF9F7FFEEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFF2309DEEFFFCF6F6FBFFFFFFFCFFFFFF
FFFDF5F0FFF9FFFFFAFFFFBA30E0FFE9F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFCFBFAF9FBFEFFFFFBFFFFFFFFFFFFFFFCF9FFFF
F5F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFFF3F8FFFFFF
FFFFFFF7ED9D670B41718CA6C5AF868478182770C2F9F3FFFAFFF8330E0600000B94EAFF
FFFDF7FFF8FAFFFFFFF2F6FF31BDFFFEFFFFF6FFFFFE6E92FFFBFFFAFCFFFFFBFDFCFCFF
FFFFFFFFFFFFFFFFFFF1FEFFF3FFFFFFC04AFABF000F0200000000E5FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FEFFFFEBFFEF0FF7F9FD0E
00FFFFFFFBFB00F5FFFB00FFFFFF00FF00FFF6FFF3FFFF00FFFDFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2FEFFFFE5607AF5FFFFFFFDF8FBFEFFFEFBF9
FCFFFFFFFAFFFCF9FFF19D3CDDE3FFFFF8FAFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFBF5F9FFFFFCF9FFFFFFFFDF9F73684745465372A2D6F7FFFAFEFF
FFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFCFAFFFFFFF7
F7FFFFA4285F90F2FFF6FFFFF0FCFFFFFFFFD18F4045C3FFFFFF4C0107000700C1FFFDFA
F4FFFFFCFFFFFFFEFEFFFFFF51C0FFFFFFFBF6FFFFF5FF4A9CFEFFFDF6F9FBFFFFFDF7FF
FFFFFFFFFFFFFFFFFAFFFFFFFFFFE8CC2FFAFFFD4500000F050A13FFF9FDFFFBFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFEDFCFFEEF5FE00FFFFED
0DF8F2FDFFFF06FFFFFF00FEF0FFFC00FFFAFFF0FFF4FF00FFFFE3FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFEFFAFFFFFF83319BF5FFFBFFFFFCFFFFFFFF
FFFDFAF9FFFFFEFAC24C5EFDFFFFFBF7FFF8FFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF6FEFFFFFFFFFFFFFEDB7C1915629794B7B9B6A6865C351D60E1FFEE
FFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFCF5FFFF
FFC51253ECFDFFFEF1FFFFFEFFFFEFFAF4F9FFFFFFBE4435DC7E00050000050058E9FFFF
FFFAF2FFF6FCFCF7FBFFFFFDEDFEFAF5FFFFFEFEF7FFFBF15E7FF8FEFFFFFAFDFFFFFAFF
FFFFFFFFFFFFFFFFFFFCFFFAFDFFB93BDEFFE9FFEF010000000617FFFFFBFCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF5FFF5FFFFF912E6FFFF
EB15FFFFFD0000FFFBEF00FFFFFCF502FFFCF7FFFFFCF600FFEFFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFDF9FDFFD962308CF1FFF4FCFFFDFCFB
FCFFFFFFFCFAB54236B3FFFAEAFFFCFFF8FBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFCFFFFFBFCFFFBEC554374DEFFFCEEFFFFFFFFFFFDF6EFEA942968EE
F8F6FFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8EFFFFFF3FEFFED
8D40D9FFFDFBFFFAFFFDFFFFF6FDFFFFFFFFFEFFEFFFFFC0272954310208000800EAFFF2
FEFFF6F8FDFFFFFFFFFDFBF9FFFFFFFFFEFCFCF9F7FFF0FFF58A41FFF0FFFFF8FBFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFD764CE7FFF0FFF0FF960008034438B9EEFFFFFCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEF6FFFFFFF3FAF700FFFAF7
FA01FFFEFFF7FFF9FDFF12EFFDFFFA0CF3FBFFEEFCFAFF04F9FCFFF7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFFFEF7FFF5FFFFD167203A8ECEE4F4FFFF
FFE2BBA2590949D7FFFCFFF6FFFFFFEBFFFFFFF2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFEFBF8FFFFEB821CAFE3FFFFF7FFFFFFFAFAFCFFFFFFFFFCFEFF8F2C
74F0FFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFF9FFE261
70F7FFFEF3FFFFFFFAFEFCFCFFFFFDFFFEFFFEFEFFFFF3FFF43B88FFF9F7FFBABBF5EDFF
FDF6FFFFFFFCF7FAFFFFFFFFFFF5FBFFF5FDFFFEFBFFFEFFFCFFA91E99DEFFFFFBFFFFFC
FFFFFFFFFFFFFFFFFFF4FFA92B79FFFFFFFFF5FFF5F430007BFF8C2B5EE4FFFAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCEEFFFFF9FFF90B00FF
FF00FFFFFFFFF6FFFFF800FFFFF8FFFF00FFE6FFFFF7FF00FFFFF1FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFEFFFFFFF9FFFDFFFFFFF0C074361A0C0000
001D425BA7F2FFF3FFFFF5FFFCEDFFFFFDFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF4FFFAF8FFFEFFFDFDFFFFEA3D8EF2FDFFFBFEFFECFFFAFEFFFCFFFEFEFBFEFDFDF6FF
8141E6FCFAFFF1FFFFF7FFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFBFDFFF64EB0
FFFFFFFFFFFFFFFFFA08F4FFFEFF00FF00FFFEFBFFF6FFFFFBFF5491FFFFF4FFF8FEFFFD
E3F7FFFFFEFEFEFEFEFDFCFC48B7FFFFFCFDFEFFFDFFFFFAFCFFFDF2703A7CF0FFF7FFFF
FEFFFFFCFFF9FFFBF6A0424BD6FFFDFFFFF3FCFFFCFFB425F9FEFFE85B299AFBFAFFFFFF
FFFFFFF9FDF9FAFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
07FBFFFFFAFFFFFFF9FA07F7FDF9FD000200FFFFFDFFF600FFFFF6FDFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFFFFF4F8FFFFFFFFFFF7FFFAFBFFF9
FBFDFFFCFFFAFFFAFFF8FFFFFFFFFFFFF6F8FFFFFEFFFBF8FFFFFEFFFFFFFFFAFEFFFFFF
FDFEFBFFF4FFFEFFFFFEF9FFFDFCFFF9FDFDFFFAFFF9FFFFFBFFFFFDFFFFF8FDFFF9F2FF
F8FBFFFFF8FFFFFFFFFFF7FFFAFBFFF9FBFDFFFCFFFAFFFAFFF8FFFFFFFFFFFFF6F8FFFF
FEFFFBF8FFFFFEFFFFF6FAFEFFF0FFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF4FFFFFFFDEFFFFFFFF8E323CBFAFFFFF6FFFFE9FFF4FCFCFFFEFFFBFFFFF8FFFFFFE1
FFBE25E0FFFAFFE2F8FFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2FFF7FF6497FC
FFFFFFFFFFFFFFFFFF00FFFFFFF506FE00EEF5FFFFFFFDF9FFFDFF54A8FFF5EDFFFF9F21
7FFFEAFFFFFFFFFFFFFFFFFFF3FFFFF7FCFFFFFCFFFFFFFDFFFFFFFAFFD072222A83C1BB
F3FEEDFAD0BF7A590C64C0FBFFFAEAFFFCF6FFFFF8FFFFDCEFFF81F7FFA23F48F2F0FFFD
F8FCF5FFFFFFFFFDF7F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF405FFFE
FBFFF8F6FFF1FDFFFFFFF10EFCFFF7FF00FEFEFFFFEB0EFFFEFCF9FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F4FBFFFFF6FFFFFFFFF5F3FFFFFFFFFDFFEFFF
FFFFE4FFFFFFFFF4FFFFFFF4FBF6FAFFFFFFFFF5FFEFFFFFF9FFFFEEF5FDFFFFFFF8F6F5
F8FFFDFFFFFFECFFEDFFFCF9FFFFF2FFFBFFFFF0FFFFFFF4FDF7FFFFF2FAFFFFF8C664F1
FFF9FFF5FFFFF5F3FFFFFFFFFDFFEFFFFFFFE4FFFFFFFFF4FFFFFFF4FBF6FAFFFFFFFFF5
FFEFFFFFF9FFFFEEFBFCFFFFFEF6FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFDFFFFF7FFF8FFDF16DEFFF8FFF9FF00F0FFF2FF0BFF00FFFAFF00F9FF00FFFFFF
F9FFE32EBDFBEAFFFFF7FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FF7D7EF4FF
FFFFFFFFFFFFFFFFFF00FEFEF4FD00F90DFFFFFBEFFFFFFBFFEAFFFC40C0FFFF811D0000
7EFFFFFFFEFDFCFCFCFEFFFFFFFBF7FCFFFDFAFCFFFFFDFFFFFCFBFCF5FFFFF5D383423E
13040D002C488CA2F8FEF5FCFFFFFCFFFFFEFFFFF5F8FFFFFFDF95FFF6FFF56A0E96F3FF
FFFFFFFEF2F9FBFBFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFEDFDFFFFFFFCFEE8EFFF00FFFFF9FB00FFFCFFFFFF07F5FFFDFAFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFFF1FFFFE9FFFFFFFFFEF9FAFCF7FDFFF8
FCFFFFFBFFFAFFFFFFF4FEFFFFFFFFFFFFFEFFFFFFFFFFF8F9FAFEFFFFFAF3FFFFFFFFFF
FFFEF5FAF0FEFFFFFFFFFFFBF5F9FFFFFFFDFEFEFFFFFFFFFFFBFEFFFFFFFFF4FD3008F5
F1FFFFFFFFFFFFFFFEF9FAFCF7FDFFF8FCFFFFFBFFFAFFFFFFF4FEFFFFFFFFFFFFFEFFFF
FFFFFFF8F9FAFEFFFAFFFFF7FAFFFAFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFEFFCFFFFFDF6F72BEFFBFCFFF4FFFF01FFFFFFF300FD05FAFFFE0FFFF801FFF6FF
FFFFFDED4AE7FFEFFFFFFEF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFF7C932FDFFF4
FFFFFFFFFFFFFFFFFE041000130000FE00FDFFFFFEFEFFF9FFFFFFFFC32C8110010A0008
87EAFFF2FDFEFFFFFFFFFFFFFFFFFFFFFCF4FFFFFDF6F6FFFFFFFFFFFFFFEFF4FFFCF4FF
EEFCFFFFF7FEFCFFFFFFFFFFEAF8FBFFFFFEFBFFFFFFF7F6FDFFFCF2FFFEFEFFD73D27C1
FFF3FFFBFFFFFCF8FDFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FF00F8
FFFFF3FFEFFFF8FFFFFFFFFF00FFFFFFFFF8FFF6FE00FBFBFFF9FFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFAF8FFFBEBFFFBF9F6FFFFFFFFF8FFEAFFFD
FFF8FFF0FFFAFCFFFFF9FCFFFAFEFCF8FBFBFEFFF7FFF6F4FFFFF4FFF7FFFFFEEEFAFDFF
FFF3FFFFF4FBFFF9FFEEFFFFFAFFFFF5F6FFFFF7F9FAFCFDFEFFFFF7FDECFEFFB500047A
FFFFE6FFFBF9F6FFFFFFFFF8FFEAFFFDFFF8FFF0FFFAFCFFFFF9FCFFFAFEFCF8FBFBFEFF
F7FFF6F4FFFFF4FFFFF7F7F7FDFFFCF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F8FFFFFDFFFFFEF7FF3DC2F7FFF8EEFFFFFF00FFF5FFFF02FF00FFFF00EDFFFF00FDF7FF
F0F6FFF0CD39FCFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFF44B1FFF9FF
FFFFFFFFFFFFFFFFFF00EBFFFFFC05FF04FFEEFFFFF3FDFFFBFAF5F8E01800000C000000
0D1E454A49433C3C475B717F285B8FADBEC3BCB3FFFFFFFFFFF7F7FEFFFFFFFFFBFFFFF3
FFFFFAFFFFFFFEFEFCFAF5FFF8FFFFFBF5FFFFFDFFFFFFFFFFFBFFFCFFFFF2FCF9FFAC19
71FFF1FFFCFCFFFFFDF9FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0013FF
F6F6FFF1FFFFF6F6FFEAFDFFFF00FFE4FFFFF8FF00FFFBFFEEF0FFEFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFEF8FDFFFFF3FFFFFEFFF3EDFFFDF3FFFFFC
F6FFFDFFFFFFFBFBFFFFFFF0FBFFFAFDFFFFFAFAFDFEFFFFF0EEFEFFFFFAF5FFFFFFF4FF
FCFFFFF7FFFEFBFFFFFFFFF5FEFFF8FFFFFEF8FFFFF9F5FFF3FFFEF2FFFEFFF92D000000
E7FFFFFAFFFFFEFFF3EDFFFDF3FFFFFCF6FFFDFFFFFFFBFBFFFFFFF0FBFFFAFDFFFFFAFA
FDFEFFFFF0EEFEFFFFF9FFFFFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFCFCFFFDF4FFFF8365FFFFEFFFFFFAF9FF01FFF7F8FF08FF1200020000FFF305FDFFFF
F4FFFFFFF89D6AF7FFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDB941FFF5FDFF
FFFFFFFFFFFFFFFFFF00FFFDFFFF00F500FFFEF8FFF4FFFFFFFFFFFBFCCE220600001500
7ED4BBBAAFB8C4C7BCA58A781A5A6C50484A424200000B213647586572719EC3BFD2FBFF
FFF6FFEFFFEFFFFFFDFFFFFFFBFFFFF9FBFFFFF7F5F8F9FEFFF18DF0FBFFFFFBFFFFF9ED
4818CCF2FFFEFEFFFFFFFDFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEDFFE5FF
FFFFFFFCFEFDFFF6FFFFFFEEFFF8F4FFFFF7F5F4FFF4F6FFFFFFF3FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4FFFFFEFFFFFFFAFEFBFFFFFBFFFBFFF6FFF3
FEF8FFF8F3F9FBFFF6F5F7FFF9FFFFF9FFFBF9FFF9FFFDFFFFFFFFFFFBFFF7FFF0FFFFFF
FFFAFFFFFFFCFFF5FCF4FFFFF2FFFBFCFFFFF8FFFFFFFAFFFFF1FFFFF9FBFFA20D000E0F
74FAE8FFFAFEFBFFFFFBFFFBFFF6FFF3FEF8FFF8F3F9FBFFF6F5F7FFF9FFFFF9FFFBF9FF
F9FFFDFFFFFFFFFFF5FFFFF3F8FFF0F2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFDFAFFF8FFFFD424FAFFFFF8EEFFF5FFFF00FFFFFFFF00EE00FFFEFDFF00FF03F5FEFF
FFFCEEFFFFFA19E6FFF9FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF844B7F9FFFFF3
FFFFFFFFFFFFFFFFFA0000000000FFFF0CE9FFFDF7FFFFF7F9FFF0F9FFFD67836C00000B
A2FFFFFBFFFFFFF8F7FBFFFF49C4FEF2F9FBF5FFFFFFF7E1CAB9ACA38E877B5634382B00
1A3A4F8685B0BEE1FFFFFCF9FFFFFFFFFEFEFEFFFFFFFFFDFFD520FFFCE3FFFFFFF2FFFF
FFB01B58E4FCFFFAF5FFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3
FFF4FEFFF9FFFFFCF3FFF2FFF9FFFFF9FFFBFFFDFFFFFFEAF6E8FFF2FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFF3FCFF8869FBFF9807000267EDFF916FF1FF
B400010062FFFF8E6FFCFF9B05000569F4FFA74EFFFF931000005FF2FF9774F9FF9C0A00
0A5FF7FD977BE2FFA20D000A6FF7F9AC5EF1FF9704002247FFFF855FFFFD8E0C00090001
009A6BF8FF9807000267EDFF916FF1FFB400010062FFFF8E6FFCFF9B05000569F4FFA74E
FFFF931000005FF2FF8C73FCFF940DE8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFAFFEE60A8FBFFF8FFFFFFFFFAFF00FFF6FFF60FFF09F4FFFBEE16F100FFFFF4
FBFFFFF8FFF7C047FFFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7EF18FEFFFBFBFF
FFFFFFFFFFFFFFFFFFFFF7FFFAFFFFF4F0FFFCFFF7FFF1FFFFF1FFF7FBFFC038F5EC5B00
A3F7F9FFF9FBFEFFFFFFFDFB3AC3FFF9FFFFF1FFF6FFFFFFFDFFFFFFF4FFF8C07B482000
030004071D1E323B000E354B7782A8C5FFFAFEFFFBF9FEFFF8EE1CFFFFFFFFF5FAFFFEF9
F8FFEF7B1691FDFFFBFEFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFF
FFFFFFFAFDFFF8F6FFF8FFFFFFEEFFFFFAFFF2FFF8FFF2FFFFFFF9FEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFFFFFFFFFFFBFEF9FFFEF3FFF4FFFBFFFE
FFF5FFFFFCFFF6FFF8FFF8FFF6FFFFF7FFFEF7FFFEFFFDFCFFFFFEFFFDFFF2FFF5FFF6FF
FDF7FFFFFFF8FFFFFFF5FFFDF7FFFBFCFDFFFAFFF9FFF8FFF8FFFFF7FFF1BD000500020A
007BFFFCFBFEF9FFFEF3FFF4FFFBFFFEFFF5FFFFFCFFF6FFF8FFF8FFF6FFFFF7FFFEF7FF
FEFFFDFCFFFFFEFFFBFFEEFDFFFC22DCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFDFFFEFBE91AFFFFFFFFFFFFFFFFFFFE00FFFEFFFF00F70D00000D01FEFF0DF1FFFA
FFF0FFF6FFFEFA2ADEFFFFFBF7FFFFF1FDFBFFF5FFFFFFFFFFFFFFFFFF8F78F8FFFAF4FF
FFFFFFFFFFFFFFFFFFF3FFFFFCFFFFF6FDFFF3FFFFFDF6FFFFFEFFFFFBFFF131DBFFF7D9
D1F6FAFFFFFFFFFFFFFFFFFFFBFFFFF8FFFFFEFEFFF9F9FFEFFFF2FFDF610F3A8AB6DCFF
FAFEFAE7C997521A5BB6DEBAA27E6342150E41666FADC0F2FFE011FFFEFFFFFEFFFFFFFF
FBFBFFFFC7323AD0FFF6FFFFFCF9FFFFFCFFFFF5FFFFFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7FCFFFFFFFFF7FBFFFFFFFFFAFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFF9FFFFFBFFFFFFFFFFFFFFFFFFFDFFFF
FDFFF9FDFAFDFFFFFDFBFBFCFFFDFCFFFFFCFBFDFFF5F6FFFFFFFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFDFCFFFFFFFFFBFFFBFFEE8A3A3D281941
4152F7FEFFFBFFFAF9FFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF8FFF8FFFF19DDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFBFF9C63FFFFFFFFFFFFFFFFFFFFF1FFFFE9FFFFFFFCEBFFF2FFFFFFF1FFFBFF
FFEFFFFFF4FFFD7878FFFFFFFFEAEDFFEEFFFFFEFEFEFEFEFEFEFEFEF852A6FAFFFFFFF2
FFFFFFFFFFFFFFFFF9FFFFFFF6F8FFFFFFFDFFEDFFFAFFF4FEFFFCFFFEFFFF6498F5FFFA
FBFFFDFBFFFFFFFFFFFFFFFFFCFFFFFFFFFFFDFFFCFFFFFCFFEEFF5E2699F7FFF5FFFFF3
FFFFFFFFFFFFFFF2A4373CCFFFFFF6FFF8FFB1B4886044190B2F3F8AA8DAF4FFFCF8F6F9
FFFFFBF5FFFF8E187AFEFDF8FFFFF5F8FFFEF9FFFCFEFFFFFFFEFCFCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFCFAF7F4FDFFFFFEFBFDFEFBFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEF4F3FF3BFCFFFFFFFFFFFFFFFFFFFEF8F9F7
FFF6FFFFFFFFFEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF7FEFFFAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFAF5FFF0F9FFFFFFF4FEFFA159FF
FFF3FFF8FFF4FEFFFFFCFBF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFCFBFAF9FD8DF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFFFFFEFAFF41C0FFFFFFFFFFFFFFFFFCFFF5FFFBFFFFF6FBFEFFF5FFFFFCFFFFF3FFFF
FFFFFEF8FCFFEFD339FFFFF6F1FFF06CFFF8FFF1FFFFFFFFFFFFFFFFFF21E7FFF9FBFFFF
FFFFFFFFFFFFFFFFFFFFEDFFF9FFEAFFFFEBFBFFE9FFF3FFFEFFFDFCFDFEFF8972FFFFFF
FFFFFFFAFFFFFFFFFFFFFFFFFFFFFDF4FDFFF9F2EBFFF3FFFDA01A9BFFFCFAFEFFFFFFFE
F6FBFAF2F2FDFFFFFFFFC03452FFFFF6FFEAFFFFF0FFF7FFFFB5B982682A083B5C83BAE8
FFFFFFFFF8F1FFE54F2CC0FFFFFFFFFFFFF8FBFFF9FBFCFBFAFCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7FFFFFFFDFFFBFFFCFBFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFDFF00F8FFFFFFFFFFFFFFFFFFFFF8FFFF
FAFFFDEDF8FEFFFFF4DCC3B2FFFFFCFAFEFFFDF4F7F8FDFFFFFFFFFCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEF8FBFFFFFFFFF3FFFFFBF4FFFFFAF7A95BFF
F7FFFFFFFDFFFCFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF8FFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFFFFFBFEF215F9FFFFFFFFFFFFFFFFFAF2FFEAF8FFF7FFFFF7FFFBFBFDFFFFF9F5FFFB
EBFFFFFBFFFFFFF41FDBFFFCE66A0D00FFEDF6FFFDFDFDFDFDFDFDFDF500F7FFFFF6FFFF
FFFFFFFFFFFFFFFFFFF9FFF6FFFCFDFFF7ECFFFFF8FFF8FFFAFFFFFCFFF7F8A060FFFFF6
FDF5FFFFFFFFFFFFFFFFFFFF4EB0FBFFFDFFFFFFFFF7FFFA7B58FBF9FCFEFFFFFCFAFFFF
FEFFFFFFFFFFFDF8FBF5F7FAA321ECFFEEFFFFF0FFFFFCFAEFFFFFFDFAFFF7D1AE8C531E
09235B88C1F4FFFAFFA1255CE5F7FEFFFCFFFFF2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFFFAF0FFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEFFFFEFB00F1FFFFFFFFFFFFFFFFFFFFECFFFF
E2FFF5FFD58D32000626404900001557A9E7FFFFFDFFFFF6FFFFFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFCFFFFFDFEFFFFF5F1F9FEFCFEFFE67E4BE1
FFFFFAF7FEFFFFF7FFFFEEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFBFFFAFFF9FFFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFBFFFAFFD824FFFFFFFFFFFFFFFFFFFFFFEEF6FFF6FBFFF2FFFFFFFFFFF9F6FFFFFBFD
FFFCFCFFF6FFFFFB42BECB800D000104FFFDFCF3FFFFFFFFFFFFFFFFF414F9FEFFFCFEFA
FFFFFFFFFFFFFFFFFFF2FFFFE9FFFFF2FFFFFFFCFFFFF9FFF8FFFFFDFFFFFFBF3DFFFCFA
FFF8FFFFFFFFFFFFFFFFFFFFF0FFFFFBFDFFF8EEF6FFF03E8AF9FFFFFFFFFFF9FAFFFFEF
FCFEFEFCFDFFFFFFFAFFFFFFF2D024DAFFFFF2F4FFFFFFF4FFEC91F8FBFFFFFFF7FBFFFF
FFDFAD873C18195A7EC0E1641EBAF7F7F8FFF0FFF6F6F8FEFFFFFFFCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE7B9BEC9BFC7C3F4FFFFFEFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FBFDFF0DFFFFFFFFFFFFFFFFFFFFFFFFFFF4
F6FF91133074C9FDFFF8F5FAFFF5E2B4500B4ABFFFEFF1FFFFFEFFFBFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FEFFFFFFF6F4F8FFFFFFF1AF510F0024221F22
00004D99D8F4FFEBF8FFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFBFFF9FFF7F6A5E2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8FDFDFFBB48FBFFFFFFFFFFFFFFFFFAF0FFFFE8FFFFF8FDFFF6FFFBF5FFFFF0FFF2FF
FFFAFBFFFFF8F8FF4C54250000000200BFBEC9C6C1C1C1C1C1C1C1C1B727FFFDFAFAFFFF
FFFFFFFFFFFFFFFFED09F6FFFFF9130000F8F2FAFFFFFFF8FFFFFFF8FFFFFFC53BFDFEFE
FFFCFFFCFFFFFFFFFFFFFFFFFEFFFDFFFFFFFFFFF2FF45AFFFFFF2F0F9F8FFFFFFF9FFFF
FFFFFEFBFDFFFFFFFFF9F6FFFFFEF32CD8FFFFFFF2FFF4FFFFE3A2F3FFFFFEF9FFFFF8F8
FEFFFEF9FFE8F0C273421B24470040F1FCFFFFFFFFFFFFFBFCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFE932F323E3D3D07D8FAFFF9FFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDA9FFFDFFFFFFFFFFFFFFFFFAFEEEFD
B7067CD6F6F9FEFFFFFFFFFFF3FFFFF9FFFFAE3C49C8FFFFF7FAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFBB471444A9FAFFEBFFFFFE
FEFFBC682B12A4FFFBFBFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFBFDFEFF98F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFEFFFFA55CFCFFFFFFFFFFFFFFFFFFFFFCFFFAF8FFFFFFFFFCF1FFFFF5F7FDFFFFFA
F6F9FFFFFFFFFEFD370B01000C02000D34433F313E3E3E3E3E3E3E3E7A00EDFFFFFDFFFC
FFFFFFFFFFFFFFFFFF00FFE9FB09E5FFFF00FFFFF2FFF8FFFFFCFFF9FCFDF6AD59FFFFFA
FFFCFFFCFFFFFFFFFFFFFFFFFFFFFBF5FFFFFAF9FB6494FFEAFFFFFFFFFFFFF4F8FFFFF4
FBFBFCFFFFFFFFFFFFF6FFFFFCFAF9D437F6FFF1FFFFEEFFF9FEFBFFF9F7FBFFF6FDFFFF
FFFDFFFFF5FFFDF7F9FFFFC8AB861A00167CB1ECF3FAFFFFFFFCFCFDFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF38683F1FFFFEC54C2F7FFF7FFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAF6FFFFF0FFFAF1FFFFFFFFFFFFFFFFFFFFEF4A
67E1F6FFFFFFFFF9F4F5FBFFFFF4F0FEFFFBFBFFAA4483FFFFFEFFEDFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAF8FFFFEAC62865AFFFFFF9FEFFFFFFF9F9
FFFFF3FFFFF25D1A8CFDFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFDFFFFFA9B5FFFFFFFFFFFFFFFFFFFF6FFF8FFFBFF00FDF2FFFB08FFF2FFFFFFF3FFFF
FBFFFFF4F7FFFFF58587782300040000FFFDF6FFFFFFFFFFFFFFFFFFFF23E2F6FFF9FEFF
FFFFFFFFFFFFFFFFFF00FFFFFA0BFFFCFA0DF3FCFFFBFBFFFFF5FFFFFFFFF49D66FFFFFC
FFFFFFFEFFFFFFFFFFFFFFFF44B2FFFFFBFFFFFE9D61FFFFFDFFFDFAFDFEFFFFFFFFFEFF
FFFFFFFFFFFDFDFFFFFFF9FEFFFFEBFFBC3CFFFFFAFFFCFFFFFFF7FFFDFFFFFBFFFFFAFA
FEFFFFFDFEFFFFFDFFFFF8FFFBFFFFD831242E193769B0E7FFFFFEFCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF7485FFF5FFFD40BBFBFFF8FFFFFAFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFBFFF0FFFFFFFFFFFFFFFFFFFFF9CF36B0
FFF8FFF9FEFEFFFFFFFFFFFCF8FFFFFDFBFFFFF5FBFE7450EDFFDEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFE68C34C9F6FEFFFCFDFFF3F9FEFFEE
FFFFFDFFFFFCF1EB6246ECFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFEFFFFFFF7F5FFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFCFFFEFFA849FFFFFFFFFFFFFEF7FFFAFFFEF5FFF707FFFFF0FF08FFF4FFF6FFFFFFFF
FFFFFFFFFDFFFDFF6995FFF292130001FFF5FFF3FFFFFFFFFFFFFFFFFE36CBFFFFEBFFF9
FFF2FFFFF4FEFFFAF010FDFAFF01F7FFFF00F7FFF2FFFFF9FFF5FFFBFFF7FF8182F8FFFA
FFFCFFFDFFFFFFFFFFFFFFFF43BEFFFEFFFEF3F028ECFFFFFDF5FFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC59ABFFFBFFF8FFFFE299F2FBFFFCFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF5FFF0F4FF8B2374CE8D4915256AABEAFCFEFAFCFFFEFBFF
FFFCFDFFFFFDFDFFFCFFFFFFFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF7E7FFFFDFFFF3EBFFFFDFFFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFF9F8FF43F9FFFFFAF8FFFDF2FFFFB332E9FE
F0FFF7FFFFFAFCFFFCFBFFFFFFF9FFFEF9FFFFFDF8FFFF993CF0F2FFFFF0FFFFF9FFF8FF
FFFFFFFFFFFFFFFFF6FFFFFFFFFFFFFFFAFFF9FBEF3E8FFFFFFFF1FFFFFFF2FFFDFFFBFE
FFECFFFAFBFCFFE7FFC32FCCFFFEF7FFFEFEFAFFFFFBF9FF0000FE00FFFFF2FF0000FE02
FFF6FF0000FFFF0000FFFCFBFFFF92E1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFEEFFFFF1CF3FFDFFFCFCF9FEFFFFFFFFF5F3FFF6FF04F3FEFFFF00FDF8FEFFFFFFFFFF
FFFFFFFFFCFFFFF642C4F3FFFCFD9325EEF6F5FFFFFFFFFFFFFFFFFFFF8280FEF4FFF1FF
F3FFF7FFFFFFFCFFFF00FFFFFF00110000FFFFFFFFF6FFFFFFF7FFF5FFFCFF39BDFFFEFB
FFF5FFFFFFFFFFFFFFFFFFFF37CBEEFFFFFFFF6490FFFAFFFFFFFFFCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD131F4FDFFFFF7FFD83BFBFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFAFFFFFFFFD25E0FC6FFFCE19150143875CFFFFFFFFFFB
FFFFFFFFFFFFFFFFFFFFFCFDFFFFFCF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF7E7FFFFDFFFF3EBFFFFDFFFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFF9FBFFAEFFFFEFFFFAFFFEFFF6BE3BFFFFFF
FFFFF1FF00FFFFF4FF08FB00FFFFF6FFFF00FFFBFFFFEFFFB44BFFF4FFFFFBEFFFFEFEFA
FFFFFFFFFFFFFFFFFFFFFEFAFAFDFDFBFEF7FFF324CAFEF4FDF2FFFFDFFCFFF4FFF6FFFF
E9FFF4FCFFF0FFFFEAFED443A5FFFBF7FAFFFFF8F9FFFFFF00FDFF04FFF3FF0CF6FF0000
FDFF00FFFF00FF00FFF6FDFFF9FF1BF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF3FFFFECEC1DF9FFFFFFFFFEFFFFFCFFF2FFFFF9FF00FFFFF9F1FF00FFF9F8FFFFFFFF
FFFFFFFFFFFEFFF227E0F7FFFCFFFFEDFFFFFFECFFFFFFFFFFFFFFFFFFC246ECFFFFF8FC
FFFEFFFFDAFFFD02FF00FFF8F406FAFFFFF5FFFAECFFF9FEF2FFF3FFF5FFEE14F5FFFAFF
FFF2FFFFFFFFFFFFFFFFFFFF46C6F7FFF6F3D541EDFFF8FEFFFFFCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5D8DFFFBFFFFFFDD06FFFEF1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFF5F9FFF9BB0B5EEFFBFFFFFFB7812F124FA9E6FF
FAF7FBFFFFFFFCFDF5FAFFFFFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF7E7FFFFDFFFF3EBFFFFDFFFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFFFFFFFFEFFFFFBE7DE53D3FFE3FF
FBFEFFFF00FFF0FFFE00FF01FEFFF9FCF101FFFFFFF8FFFDFF9E53FFF7FFFFF9FFF8FCFB
FFFFFFFFFFFFFFFFFFFEFBFDFFFFFFFFFEFFF12CD5FFFAFFFFFFECFF1AFEF9FFF9FF00F0
FFF2FF0BF9FFF0FFFFF5FFE346D2FFFFFFF5F1FFFFFFEBF909F8FF00FEFFF900FEFFFF00
F8FF00FFFBF4FF06F8FFF1F9FDFF10DBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFFFCFEFFFB1DE4FDFCFFFFFFF5FFFFECFFE8FDFDFF00F9F1FFFFF302F7FEFFFFFFFFFF
FFFFFFFFFFF5FAEE25F1FFF9FFFFF7FFFEFCF7FFFFFFFFFFFFFFFFFFFCF72AEAF9FDFFFC
FDFFF3FFFFF3FEFF0011FFFEFD0CFFF1FF00FFF8FFFFFFFFFBFEFFF5FFFFA656FFFFFAFF
FFF7FFFDFFFFFFFFFFFFFFFFFFEDF7FDFDFF7782FFFFFFFFFFFDF7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FCE527FFF7F8FFFFE32EFFFCF5FFFDFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF9FFFBF5FFFCF5FFFFFF6C1791FFFFF3FFFFFFEBA4502625
82DDFFFFE8FCFFFDFFFFFDFCFEFEF9F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF7E7FFFFDFFFF3EBFFFFDFFFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFFFFE2FFFDFFFBFAFBF5FC4AB5FFFCFFF9
F9FFF9FF00FDFCFFF700FF00FFFAFFFFF804FFFFFFF7FFF3F3FF668EFFF2FFFFF7FEF8FF
FFFFFFFFFFFFFFFFFFFCFEFFFFFFFEFFFBFA51C9F9FCFFFFFBFFF8FF00FFFAFFFFFF01FF
FFFFF300FCFFFBF7FFFFFFFFD541D8F4F2FFFFFFF3F7FFFF00FFF40AF5FFF5FF0A00000B
FEF810FCF6FFFF00FFF8FBFDFFFF19E7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F8FFFCFBFFFF6A91FFFCF2FFFFF3FFFFFFECFFFF00F707FFFFFFF6FFFC00FFF2FFFFFFFF
FFFFFFFFFFFAFFA053FFFFF7F3FFFCEFFFFFECFDFFFFFFFFFFFFFFFFFDFE7D85FDFBFFFE
FDFAFEFEFFFFFFF6FD00EEFFFFEC080600F6FFFFF0FFF7FFFFE7FFFDF6FF3BCAFBFCFFFF
FDFEFFFAFFFFFFFFFFFFFFFFFFF9FFFFFFF725DFFDF6FFFFFDFEFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFB38C8FFFFF9FFE895F2FFFFFFF5FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFEEDFFF4FFD63D38CDFFFFF0F9FEFBFFFAB5
691F167DE8FFFCFBF8FFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF7E7FFFFDFFFF3EBFFFFDFFFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFCFFFFFB5BFAFCF9FDF9F9FF9D64FFECFFFFEF
FFF6FFF900FDFCFFF700FF00FFFAFFFFF804FFFFFAFFF0FFFFFFF922E2FFF4FFF4FFFCFF
FFFFFFFFFFFFFFFFFFFFFFFFFEF9FAFFFE7F80FEFBFEFEFFFCFFFFFC0EFFFFFEFFFF00FF
F5FFFF02FFF8FFFEF8FFFCECFFCD36F4FFFFFEFFFFFFF9FA09F1FF00FFF8FFEEFFF4FF00
FFEF06F3FFFFF30CFAF0FFFFEEF799E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFBFFFEF8FFC52DFFFFF3FBFFFAFFFBFBF3FFFFFF0800FAFFE8FFF1FF04F8FFFFFFFFFF
FFFFFFFFFFF3FF25C0FFFFFFFFF1FFFCF6FEFFFEFFFFFFFFFFFFFFFFFFF3F620EDFCFFFF
FFFFFFF3FFFFEFFFFFFFFDFAFFF9F8FFFFFFFFF9FFFFF4F4FFFDFFFFFCA453FCFCFFFFFE
F7FFFFFEFFFFFFFFFFFFFFFFE9FFFFEFFBCD38FEFFFEFFF7FFFFFFFDFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF88473FFF9FFFFFFFEFDFBFFFEFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFFF8EEFDFFFBFFF8E8FE8C137EF4FFFFF9FFF8ECFF
FFFFD46D172183E1FFFEF8F7FBFEFDFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF7E7FFFFDFFFF3EBFFFFDFFFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFF00FFFFFFFFFFFFEF1CFEEDFFF8E8FF
FFF6FFFB00FFF0FFFE00FF01FEFFF9FCF101FFFFFCFFFFFAFFF5FF9660FFF2FFFFF9FDFF
FFFFFFFFFFFFFFFFFFFFFFFDFBFFFFFFCA33F9EBFFFFF8FDFFFFECFA00FFF0FFF9FF01FF
F7F8FF08FBFFF7FFFFEAFAFFF5FE6EACF7FFF0FFF8FFE8FF00FFF30A00FFF608FFFFFD00
E7FF00FFF401FB00FFFDFEF2FDFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF9FEFFF7FBF63BC3FFFFFBFFFEFFF7FFFFF1FFECF70CFDF8FF0009000008ECFFFFFFFF
FFFFFFFFFFF2D231FFFBFFFFFEF9FFFFFFF4F3F9FFFFFFFFFFFFFFFFFEFFFF7E7DFFEEFF
F6FFFAF8FFFCF6FFFDDBFFF8FFFFFFFCF6FFF5FCFFE6FFFFFBFFFFEAFD3DD6F6FFFFFFFB
FBFFFFFFFFFFFFFFFFFFFFFF43C5EEFFFF856DFFFFFFFFF4FFFFFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFC134FFF6FFFFFFF7FFFBF6FBFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8FFFCF6FFFFFFF7F5FFFFFFFBFFE94629B9FFF3F7FFFFFF
FDF5F7FFFFD06B183981D9FFFFFDFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF7E7FFFFDFFFF3EBFFFFDFFFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFF00FFFFF3FFFFF37892F2FFF1FFFFFF
FAFFF2FD00FFFFF4FF08FB00FFFFF6FFFF00FFFBFFF4FFFFF5F2FFFE31C0FFFFFFF6FFFF
FFFFFFFFFFFFFFFFFBFFFFFAFFFFFFF54CBEFCFFFFE6FFFFFBFFFAFF0BFFFCFBFFFF00FF
FFFFFF00FDFFFAFFFBF9FFE2FFFFD11FF7ECFFFFFFEDFF0A0009FF00FF00FFFF000001FB
FFF9FF0006FF000905F7FFFFFFFAFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFFF6FFFFF2FF9F60F1FFFBFFFAFFFFFAF9FDF8FFF9FFFFFEFFFFF1FFF9FEFFFFFFFFFF
FFFFFFFFFCFF4BB3FAFFFBFFFFFFFEF3FFFEFFFFFFFFFFFFFFFFFFFFFAFFFEFD36CEFEFC
FFFFF6FFFAF3FFF3FFF8FFFFF9FBFFFCFFFBFFFFF2FFFDF5FBFFF7FF956BFFFFFFFBFCFC
FFFFF6FFFFFFFFFFFFFFFFFFFDFFF7FFFB5EA0FFF9FFFDF7FFF5FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFAE919FDFFF2FFE398F8FFFFFFFBFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFBFEFFFCFAFFFFFFF2FCFFFDFDF6FFB31859FDFFF2FFF3
FFFFFFFCFBFFFFFFB866213CA3FAFFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF7E7FFFFDFFFF3EBFFFFDFFFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFDFCFF09FFF4FFF1FFFE10F5F6FFFFFDF5FF
FEF9FFFCFFFAFCFFFCFBFFFFFFF9FFFEF9FFFFFDF9FFFFF1FFFFFFFE8B74FFFBF3FFFFFA
FFFFFFFFFFFFFFFFFBFFFFFAFEFFEAC747FFF7FDF9FFFFF8FDFFFBFF00F5FFF9FAFF00FF
F6FFF60FFDFFFFF6FAFFFFFFFFF0FF8D6FFFFBFEFFFFF9F20AFFF7FFF6FFFFF6FFFFFEFE
F0FFFFF9FFF7FF00F8FFFDFFFFF792EEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF52B2FDFFF9FFF7FFFFFEFCFCFBFBFEFFFFFFFFFFFFFFFFFFF7FFFFF8
FFFBFFFAF9D43DF3FFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFF6DC41E0FA
FFF8FCFFFFFDFEFEFFFEFCFBFCFEFFFFFFFDFBFEFFFFFEFEFFDFFFA548FFFFFAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFBFF48BAF8FFFFFFFFFFFFFFFFFDFFFEFAFFF9FFFC
070005FFFFF2FFFBFFFFFFFFFFFFFFFFF9FFF4FF06ECFFFFFFF28CFFFCFCFFFDFFFFFBFA
FBFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEE621BA1FFF7FE
FDFFF9FFFDFBFFF8F4FFF59932227ADCFFF8FCFFFBFBFFFDFDFCFFFFF2FFFFFBFFFFFFFF
FFFFFFFFFF7E7FFFFDFFFF3EBFFFFDFFFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEF8FFFCC2FAFFFEFFFFBB45FEFFFCFFFFFFFF
FFFFFFFFFFFFFFFDFDFFF8FFFFFFF9FFFAFFFFFFFFFFFFFFFFFFFFFFDE2FF6F8FFFFF0FF
FFFFF2FAFAF9BDAAFFFEFDFDFFF9FE6CA9F0FFFAFFFFFAFCF4FFFFFBFFFFF3FFFFFFFFF7
FFEFFFFFFFFFFFFFFFFFFFFFFBFFFFDE22F8FFFFFFEEFFFF00FDFFFDFFFFFFFFFFFFFFFF
F6FFF0FFFAFFF10DFFFCFFFCFEFB9EE4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFD32DF7FFFAFEFDF8FFFFFFFFFFFFFAF5FFFFFFFFFFFFFFFFFFFBF6FF
FFFFEEFFF22CD0FFFCFFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2FFFFE21CF9
FFFFFFFFF9FAFFFBF4FDFFFFFFFDFFFFFAFEFFFFFFFEFFFFFFFFBB40FDF7FEFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFF3CB7FFFFFFFFFFFFFFFFFFFFFBFAFFF3FFFD00
F7FFFF00F4FFFFF0FFFFFFFFFFFFFFFFFAFFF7F026F2FEFAFFF8FCFFFFF5FAFCFFFDFFFF
FFFFFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2FFFFB83C51DCFF
FBF2FFFBFCFFEEFFFFFEFBFFFFCE661245B8FFF9F9FFFFF7FEFFF8F9FFFEECFFFFFFFFFF
FFFFFFFFFF7E7FFFFDFFFF3EBFFFFDFFFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FBFFFFF8FEFFFFFFFCF9778AFFFFFAFFFFFFFF
FFFFFFFFFFFEFFFFF1FFFFFFF3FFFDFFF3FFF6F9FFFFFFFFFFFFFFFFFF27D1FFF6F9FFFE
FCFFFFFFFFFA85012C83F3FFF9FFF10BE3FFFFFCFFFFF6FFFFFFF9F6FAFFFFFDFFF4F9FF
FFFFF3FEFFFFFFFFFFFFFFFFFDFFFFF048C5FEFFFFF8FFFDFAFFF2FFFFFFFFFFFFFFFFFF
FFFFEFFFFFFBFFF1FFF9FFFFFEFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFB73EFFFFFFFFFFF9FAFBFBFDFFFFFFFFFFFFFFFFFFFFFFEBFCFFFF
FEF8FFFF5AACFFF4FFFBFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1ECFFC43F
C8FFFFF0FFFFFFFFFFFFF6F3FAFFFDF9FFFFFBFBFDFDFAF7F69D3AF1FFFFFEFCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF3BC9FFF5EE44C7FCFFFFFFFFFFFFFFFFF7FFF6FFF9F1FFF3
FFFFE9FF08FFECFFFFFFFFFFFFFFFFFFFFF5FFFF0098DBFFF6F3FFFBF6FFF6FFFFFFFFFA
F5F5FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF871148A
FFFFF6FAFFFFFFF7F8FAFCFFFFFEFAF792331A92FFF9E5FFFAF8FDFFFDFFFFFDFFFFFFFF
FFFFFFFFFF7E7FFFFDFFFF3EBFFFFDFFFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFEFFFF2FFFFFEFD2BD7FEFFFDFFFFFFFF
FFFFFFFFFEF7FFFFFFF5FFF6FFF7F3F3FFF7FBFFFFFFFFFFFFFFFFFFFF5E9EFAFFFFFFF4
FDF9FFFFF2FFA50300011060DAFFB850FFFFFAF9FFFCF5FFFFFBFAFFFFF2FFF0FFFFFFF2
FAFEFFFFFFFFFFFFFFFFFFFFFFFEFDFF827CFBFFFFFFFAEAFFF8FFFFFFFFFFFFFFFFFFFF
F8FEFFFFFFFFF3FFFFFAFFFFF8FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFAFF8879F9E6FFF7FEFFFFFFFDFBFFFFFFFFFFFFFFFFFFFFFFF5FFF9
EFFFFF6D81FBFFFFF9FBFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFF6FFFFF9F8C8
3EA2F8FFF7F9FFFFF2FCFFFFFFFEFFFFFFFEFDFCFEFFFFFF8758F1FFF1FCF6FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF40C0F4FFFF56ACF6FFFFFFFFFFFFFFFFFBFFFDF6FFFFFBFF
FFE7FFFE00FFFFFFFFFFFFFFFFFFFFFFF9FFFFFB065C20248CC3A0FFFFF5FFF9FAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFF5FFFFFFCB3F
30CEFFFFFFECF7FFFFFFFEFEFEFFFFFEFFF5C5481099FFEFFFF9FFFFFDFFFFF2FFFFFFFF
FFFFFFFFFF7E7FFFFDFFFF3EBFFFFDFFFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEAFFFCF6FF43FFFCFAFFFF0BF9F5FAFFFFFFFFFF
FFFFFFFFFFFFE9FFEFFBFCFFEFFFFFFEFCFFFCFCFFFFFFFFFFFFFFFFEC8A79FCF2FFFFFF
FFFBF9EFC9B7750009040400014A6080FFFBF3FAFFFFF8FFFFFCFCFFFDFBFFFFF7F6FBF8
FFFFFFF4FFFFFFFFFFFFFFFFFFFFFBFFB93DFFFCF4FFFFFFEBFAFFF3FFFFFFFFFFFFFFFF
FBFFFFEBFBFFF5F9FFFBFFFEFCF69AE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFCFFFF6C4BFFFFFBF7FDFFFEFEFFFFFAFFFFFFFFFFFFFFFFEFFFFAFE
FFFB5D81FFF3FFFDFFFCFCFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFE2FFFFFF
EF5B56D2FFFFFFFFFFFFFDFBFAF9F9F9FAFFFFFCFFF7A13B77FFFFF7FFF7FFFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF44BCF2FFFF6E89FEFFFFFFFFFFFFFFFFFDFCFFFFFFFBEDF7
000515FF03F7F9FCFFFFFFFFFFFFFFFFFFF1F8EB1CFFFFBD751E0363C1FFF0FFFFFFFCFA
FFFFFCF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEFFF7EDFFFFFB
9C1671F4FCFFFFF3F0FAFFFFF9F5FCFFFFFFFFFFCE37189AE9FFFBF3FFFAF6FFFFFFFFFF
FFFFFFFFFF7E7FFFFDFFFF3EBFFFFDFFFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFBBF7FFFBFFFB0EF8FCFBFFFFFFFFFF
FFFFFFFFFFFCFFFFFFFEFFFBFFFAFDF5F9FFF7FFFFFFFFFFFFFFFFFFFEA76AF253382900
020702102F4A440000000000197D5EA2FEFFFFFFFFFFFBFAFBFFFFEBFBFFF5F9FFFFF0FF
F9F6F3FFFFFFFFFFFFFFFFFFFFFFFAFFDE18FFF8FFFDFFFFFFFFFAFDFFFFFFFFFFFFFFFF
FFFCFCFFFDFBFFFFFEFBFFFAFFFF23DFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFCF8FFF9C619CEFEFFFFFAF3F9FFFFFDFFFFFFFFFFFFFFFFFFF8F8FF
DC28A1FEFFFFFBEEFFF8FFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEF4FFEAFDEF
FEFFA7304AC2FFF8FFFEFEFFFFFFFFFFFFF2FCF8A1435EC0FFF4FBFBFFFFFAFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF43C1FFFEF09468FFFFFFFFFFFFFFFFFFFDFFFFFFEAFFFF03
FCFFE80005FFFFFFFFFFFFFFFFFFFFFFF5FFFFAB47FFFEFFFBE1257E300F6AA6F1FFFFFF
F8FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFF8FFFDEDFFFE
FFE15922A8FFFCFFFFFFFAFFFFFFFFFAF9F8FFFFFFFFC152199AFFFFFFFFFFF1FFFFFFFF
FFFFFFFFFF7E7FFFFDFFFF3EBFFFFDFFFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF6FFFDFEFFFFFAFFF8EC13F4FFFFFFFFFFFFFF
FFFFFFFFFFFAFFFEE3FFFFF7FFF3FFFFF9FFFEFFFFFFFFFFFFFFFFFFFFA740F6A2C2DCFD
F2FFFAF6FFFAA60807050569E6FF47A7FCFFFFFCFAFFFFFCF8FEFFFFFFFFF3FFFDFFF6F7
FFFFFFFDFFFFFFFFFFFFFFFFFFFFFCFCF109FFFAFFFBFBEFFFFFF1FFFFFFFFFFFFFFFFFF
FFFBFAFFFFF2FFF0FFFFFFF7FFFF00E7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEF9FFEBD73E6FDEF3FFFFFFFFFFFDFFFFFFFFFFFFFFFFFBFFE66B
2BDBEEFFFCE5FFFFEFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFECFCFFFFFFFFFAFF
F5FFFFF9C53A0B6CB1D3F9FFFFF3F4FBD498442059C0FEFFFFFFFFFFF4FCF9FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFCFFFFFFCB34F5FFFFFFFFFFFFFFFFFFFFE7F8FFF9F901
FFF5FFFF00FAFFFAFFFFFFFFFFFFFFFFFFF3F86E9AFCFFFFFDDE22FFFEEA98440349A1DF
FEFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFF1FF
ECFFF9B43E45D9FFFFFFFCF9F8F9FDFFFFF9FCFEF8FFFFFFD83A27B5FFF9F7FFFFFFFFFF
FFFFFFFFFF7E7FFFFDFFFF3EBFFFFDFFFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FEFFF6FFF9FDFFF6F20FFAFFFFFEFFFFFFFF
FFFFFFFFFFFFD6FE1DFFEFFFFD01000FF0F7FFE2FFFFFFFFFFFFFFFFFEA954FFFFFFE9FF
FBFFFCF5FFFFC608004FCAFFF0FC47C1FAFBFEFCF7FEFFFFFFFFEFFFFFFBFFF1FFF8FFFE
FAFFEEFFFFFFFFFFFFFFFFFFFFFFFFFCFA05FFFFF4FFFFFFF2FFFFFDFFFFFFFFFFFFFFFF
FFFFF9F6FAFFFFFDFFFFF9FEFCFD36E8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFBFFF9FEFFF5F2932677D2FEFFFCFEFFFFFFFFFFFFFFFFFFD95D2C8D
FEF8FFF9FFFFFFF3FFFDFCFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFF6FEFCFFF4
FFF5FEFFF2FFEB994F280305202B13002B6BB9EDFFFFFFFAFFFAFFFDFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFCFFF6FFFF29D2FFFFFFFFFFFFFFFFFFF2FFFFF7FAFF00
FFFFF9FA01FFF8FFFFFFFFFFFFFFFFFFFDFFFF20E2FFF9FFFFF284FFFFFCFFFFF7B25117
2F84D8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFCFBFDFFFD
FFFFF8F8F9741E9BFDFFFFFFFFFFFEFCFDFFFFFDFFFFFAFCF9FFA1305DE4FFF4FFFFFFFF
FFFFFFFFFF7E7FFFFDFFFF3EBFFFFDFFFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFBFAFF3CFFFFFFFAFF09FFEEFDFFFFFFFFFF
FFFFFFFFFBFFFFFF00F4FFF90DF2FFFA03FFF7FFFFFFFFFFFFFFFFFFFB9472FFF2FFFFFC
FFFBFFFFF7F8E22BBBFBFFFFFDFF2DC7FFFDFFFFFFFDFFFCF6FFF0FFFAFFF10DF5FCFFFB
000700FFFFFFFFFFFFFFFFFFFFFBFFFFFE03F3FFFFFFFFF2FFF3FFFBFFFFFFFFFFFFFFFF
F4FFFFFBFFFFF3FFF5FFF4FFF6FC8DEBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB8A2A2E6FACD9F8FFFFF8F2DEAC67332991F1FF
FAFBFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFDEEE1E3F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFF99074F5FFFFFCFFF7FEFFF6FFF0FFFAFFF10D
FFFDFFFF01FFF8FFFFFFEFFFFFF5FFFAFCFFB846F8FDFAC07F5931B0FFF8FEFBFCF8FFFC
C66E302073BAFBFFFCFCFFFFFBFCFCFEFFFFFFFFFFFFFEFBFEFFFFFDFFFCFAFCFEFEFFFF
FFFAFFFFF6FFC73C35D3FFFFFEF6FFFEFDFFFBF5FFFDF4FFFFFDFFF663179EFFFAFFFFFA
FCFAFDFFFA8973F7FFFFF442B7FFEFFBFDFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFA00FFFFFAFFFE1EDAFFEAFFFFFFFFFF
FFFFFFFFFEF5FFFF00FFF5FF01FFFBFF00F5FFFEFFFEFFFDF8FFFFFAFA8383F9FFFFFFF6
FFFFFFFFFFFFFFFFFDFFFFF2FFFF5A9CFDF7FFFFF5FFFFFFF9FFF4FFFEFFFD05F5FFFF02
F3FFF900FFFFFFFFFFFFFFFFFCFEFFF4E41EFFFFFAFFFCF0FFFB040002FFF4F8FF04FEFF
FFFFFFFFFFFFFFFFFEFFFFFFF7F5FFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F6DDA0541E0A0000030D26599ACAF7FFFFFA
FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAF9FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF43C6F4FFFFFFD33DEFF2EFFFFAF0FFFFFFFFEFFFFFFBFFF1
04000700F2FFF5FCF0FFFFF8FFFFFFF6FFFB4660441A00000C0008F7FFFFFFF6FFFFFEFC
FFFFEFDB8A381152B8F1FFFFFFFFFFFFFBF8FAFEFBFAFDFFFFFAF9FCFFFFFFFFFFFDFDFF
FEF3FFFFF8FFFFF0A50F86F0F5FFF3FFF1FBFFFFFFFFFFFBFEF7FFE9FFC42050E1FFFFFB
FFFFFFEDFF807EFFF5FAFF42C7FBFFFFFFF9F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFEC1CF2F7FFFDFF44B6FBFFFFFFFFFFFF
FFFFFFFFFFFCFFF700F8FFFC00FFF0FF00FFE8FCFEFEFFFFFFFFFEFCFF48B4FFFFF6FFFF
FFFFFFFFFFFFFFFFFFFBFFFFFFF37791FFFFF2F9FFF9F8FFF9F7FFFAFCFDF200FDFFF0FF
FFFEF80EFFFFFFFFFFFFFFFFFFF4FAFFBF34FFF6FFF4FFFFFD00F9FFF900FFFBFD00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9EFF1FEFFFFFFFFFFFFFBF6FBFFFFFFFAFF
FFFFFDFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFEFEFFFFFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFEEFFF5FDF5FEFF866BFFFFF3FEFFF6FFF8FEFFFFFFFFF3FF
FFFAFFFFF5F1FFFFFFF3FFFFEFF8F6FFF9BF429F00001B07000810FFFFF7FAFEEAFDFFFF
FFFFFFFFFAFFEC9F3F18478AE1EDFBFFFFFFFFFFFFFFFFFFFFFDFBFFFDFFFFFFFFFCFDFE
FFF9FCFFF5F1FFFFE9F33D25CEFFF9F5FFF7F9FFFCF8FEFFFFFFFAFFEEFFFF5A40C1FBFF
F6FDFCFFF8798AFFFEFFFF38B9FFEBFFFCF9FFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEDFFFFFBFF00FFFFFCF4FF9561FFFCFCFFFFFFFF
FFFFFFFFFFFADBFF08F0FFECFF000900FFFCFFFFFCFFFEFFFFFDF8FFF523E6FFFFF2FFFF
FFFFFFFFFFFFFFFFFFFBFDFFFFF4AA5CFEFFFFF5FFF7FEFFFFFFF4FAFFF0FF07FFF3FFFF
02060000FFFFFFFFFFFFFFFFFFFFFAFFA75FFAFEFDFFFFF800FFFEFCFFFF00FFFF07FFFF
FFFFFFFFFFFFFFFFFFFFFBFDFEFF98F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFFFF9FFF8F1F3FDFFFFFFFBF8FCFF
FCF4FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDFAFCFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFCF4FFF824DEFFFFFCFAFFF3FBFFFFEBFBFFF5F9
F6FFF8E7FFFFFFEFFFFBFFF8FFFFFDF8FF3AC2FFBA0000000E021DACE0FFFFFFFFFFF5F6
FBFCFCFEFEFFFFF8FFF8B463124087CAF4FFFEF7FEF7F2F3F9FEFFFFFBFEFFFDFDFFFFFC
FFFFFFFCFFFFFCF2FFFFFFB51753FBFBFFFFFFF9FFFFF8FFF8FFF9F9FEF8FFFF8E23D2F7
FFF9FFFFFF837AEEF6FEF845BBFFFFFCFCFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4FDFFBAFAFFFCFFFFEC1EFFF9FFFFFFFFFF
FFFFFFFFFFFF17FE00FFECFF00FFFFF900FBFFF3FDFFFAFEFFF7FBFFB44EFAFCFFFDFFFF
FFFFFFFFFFFFFFFFFFFFFCFEFFFFDD22FCF9FFFFEDFFFFFFFAFFF4FFF5FFFF00F7FFF500
FFFFFF07FFFFFFFFFFFFFFFFF5FFFBF65FABF3FFFEFAFFEE0AF4FFFEFFFF00FCFF00FFFA
FFFFFFFFFFFFFFFFFBFFF9FFF7F6A5E2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4FAFFFFFCFAFFFFFEFFFFFFFFFDF9F7FFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBF3FDEFFFFFF7FFBE41FFFEF7F6FFFFFFFCFCFFFDFBFFFF
FFFCFBFFF8FFFDFFF6FFFBFDFFFCF8FF886BFFFFF4C5100C0000905C172C8FC5FDFAFDFF
FFFFFFFFF9FDFFFFFFFFFDFBFFBF65282B6AC1FDFAFFFFFFFCFCFCF7FFFFFEFAFDFFFFFA
F2FFFFF9FFFFFFFFFFEEFAFFF4741BAFFEFFF9FFFFFFF6FFFFE6FFFFFFFFE1FFFFB31FD0
FDFFF1FFFA7685FFFFFFFE46B2EDFFF5FFFBEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FDFFF8FBFFFFF7FEFFEFFF3CB6FFFFFFFFFFFF
FFFFFFFFF7F0FC0010F8FFFF03FFF5F908FFFFFFFDFFF9FCFFFBFFFF53ABFBFDFFFFFFFE
FFFFFFFFFFFFFFFFFEFFFCFFFFFFFF36C9FCF2FFFCFFFAFCFFFAFFFFF900FF10FFEDFF09
FBF6FF00FFFFFFFFFFFFFFFFFDFFFDF80EF3FFFFFFFFF1FF02FFF5FF000D02FEFA13FFF8
FFFFFFFFFFFFFFFFFBFFFAFFF9FFFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFFCF8FEFFFEFAF6F8FFFFF3FBFFFF
FFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFFFFFFFFFDFCFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF40CBFFFFFFF9F8FFFFAA50FFFFFFEFFFFFFBFAFFFFF2FFF0
FFF7FFF7F8F4F2FFFFFFF9FFFCF9F9AD46FFFEE9FFEEDD000325EEFFFFD07C2F165BAEE3
FBFFFCF2FFFCF6FAFCFAFDFFFDFFFFFCD48E410D5D9CE1FFFFFFFFFFFFFFFFFDFEFFFFF9
FCFFFFFAFAF6F6FFFCFFFFFFFAF9C92C43DBFFF2F5FAF4FFF9FFFAFCF7FEFFF6FEFDB31A
D3FCE17C8B3A88FFF3FDF53E6C8D71FAFFF8F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF8F7FFFBFFF1FFB956F6FBFFFFFFFF
FFFFFFFFFFFFF9FF03FAFBFFFA040804F5FFF1FFFBFFF9FEFFFFFFD035F1FFFFFCFFFBFE
FFFFFFFFFFFFFFFFFFFDFCFFFEF4FF9658FFF9FFFFFFFFFAFFFFEAFFFFFA0B00F8FFF300
FFF7FF04FFFFFFFFFFFFFFFFFFFFFFA150FDFFFBF6FDFFFF00FFFAFAF9F1FFFAFF00EAFF
FFFFFFFFFFFFFFFFFFFFF8FFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FBFFFFFDF7FCFFFFFDFCFFFFFFFBF4FFFFFFFD
F7FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFBFDFFFFFFFDFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF3ACAF8FFFFFBFFFBFAFB9071FFFAF2FFFFFFF9F6FAFFFFFD
F9FFFFFBFFFFFFF5FEFBFEFBFDFFC743FFF8F8FFF1FFF8DB205F93FFFFF6EAFFE8A8521F
3380D5FFFEFFFFF7FDFFFFF3FCFDFFFFFFFFF6EEA051173998E4FBF5F0FEFFFFFDFFFFFC
FFF8F9FFFFFFFFFFFFFFF9F7FFFFF4F58A2273FFFFFFFFE7FFF0FFFFF4E9FCFFF0FFE89F
25EDEE03728BCDFFF2FFFFB97B472FFFF6FFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4FFF3F5FF45FFFFFFFFFFFBF651ACFCFFFFFFFF
FFFFFFFFF8FEFFF3FFFFFFFFF9FFEFFFFFFFF4FFFAFFFBFFFEFFEC7694FFFFFFFDFCFCFD
FFFFFFFFFFFFFFFFFFFEFFFFFCF3FFE83DD6FFFBF8FBFFFCF6FFFDF4FFFFEC01FFFFF9FF
030F00FCFFFFFFFFFFFFFFFFFBFFE945D9F1FCFFFCFFEEFF13FCFFFFFFFF06FFFC00FFF7
FFFFFFFFFFFFFFFFFFFCFBFAF9FD8DF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFAFF
FFFFFEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFDFCFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF3FC2FFFCF6FDFFFCFEFFFA6A5CEFFFF9F4FFFFFBFFFFF3FF
FEFFF3FFF2FFFDFFF7FFFDFEFF7D3EECF8FBFFFFF9FFFEFCDFAE21FFEEFFFFF9FFF9FEFE
CD742D135DA5EFFFFCF6FDFFFFFFFFFEFDFDFEFFFFFFF4BD5A173780DAF3FFFFFBFEFFFF
FEFFFFFFF6FBFFFBFCFDFFFFF9FCFEFFFFCB4E40C4FEEDFFFEFFFFFBFFFFFFFBFFEFFFFC
6D63FF9860F1FFF6FFFDFAFFFD3DCFFFFCFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFBFFFBBDFDFFFEF9F8C8B1683EF5FFFFFFFF
FFFFFFFFFFFEFBFFFFF2FFFEFFFFFFFFF9F3FFF4FBFFFCFFFCFFCF28FFF9FFF9FFFDFFFA
FFFFFFFFFFFFFFFFFCFFFFF7FBFFFFFF8E65FFFFFFFFFBFFFFE7FFFFEBFFFFFFFFF4FFFF
F5F4FFFFFFFFFFFFFFFFFFFFFDFFAD47FFFBFDFFFFEEFFFFF100FFF7FF00F9FFFC00FFFA
FFFFFFFFFFFFFFFFFFF8FFF8FFFF19DDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFCFFFFF9FCFFFFFAF8
FFFFFDFBFFFBFBFFFFFBFBFFFFFEFFFFFDFFFFFAFCF9FFFFFCFDFFFFFEFDFCFEFFFFFFFF
F8FFFFFFFFFCF9FFFDFFFEFBFFFDFDFFFFFDFDFFFBFEFFFDFFF9FCFFFFFFFFF8FFFFFFFF
FEFCFDFEFFFFFDFCFFFFF9FCFFFFFAF8FFFFFDFBFFFFFFFFFFFFFFFFFBFDFFFFF8FAFFFF
FCF9FFFFFCFDFFFFFEFDFCFEFFFFFFFFF8FFFFFFFFFCF9FFFDFFFEFBFFFDFDFFFFFDFDFF
FBFEFFFDFFF9FCFFFFFFFFF843B1FFFFF6FCFFFEF9FFFFFEB13BC1FFFFF7FFFFF6FFFFFB
FBFFFFFFFDFAFFF8FFF0FFEA4A73FFFEFFFDF8FFFFFFFFF8FFDA12FFF9FFF9FFFFFFFDFC
FFFFF4E3A247082E8AD3FAFFFAF8FEFFFFFAFAFFFFFFFEFFFFFBBA73233166B6F2FFFFFF
F9FFFFFFFFFFFFFBFFFFFFFAFAFFFFFDFBFFF0A70A7EFFF8FFFFF3F8FFFFFFFFFFF9FEFF
FC16CDFE5AACF7FDFFFFF5FF6D91FAFFF7FFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFF1FFFDC07D504500020000559763FFEBFFF7
FFFFFFFDFFF7FBFFFBFFFFFAFFFDF9FBFFFFFFF7FFFFFFFFF8EF34E0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD33D4FFF5FFFFF5FFFFFFFFFFFDFDFFFFFFFEFE
FFFFFFFEFFFFF4FCFFF9FCFFFFE624F3F7FAFFFFFAFFFAFFFFFC060003FFF4FFF606FFFB
FFFFFFFFFFFFFFFFFFF5FFFAFFFC1FE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFDFDFCFFFFF1FFFFFF
FDF8FBFFF6FFFFF6F6FFFFF6FAFBFFFFFAFCFFFFFFFFFCFDFDFFFFFBFFFDFFFFFFF6F7FF
FCFFFBF9FEFFFFFFFBFFFFFFFFFFF8FAFAF8FFFFFFFFFFFBFFFFFFFEF9FBFFFCFFF7F6FF
FFFFFDFFFBFFFFFDFDFCFFFFF1FFFFFFFDF8FBFFFFFFFFFFFFFFFFFFFFFBF8FDFFFFFFF1
FFFFFCFDFDFFFFFBFFFDFFFFFFF6F7FFFCFFFBF9FEFFFFFFFBFFFFFFFFFFF8FAFAF8FFFF
FFFFFFFBFFFFFFFEF9FBFFFCFFFFFAFDFFFFFCFFFFEFFFFAEFF92058C8FFE9F9FFF5FFFF
FFF9F9F5FFFFF4FFFBE0821DABFFFEFBFEFFFFFFF4EAFFFFFBDB2FFFF4FFFAFAF7FDFFFF
FDFDFEFEEFFFFFC767262B4EB9EEFFF5EEFFFFF5FFFFFEF4F8FFFFFBF5D18A3F2452A9EA
FFFFFCFFFFFDFCFFF0F7FFFFFFFFFDFFFFFFFFF0F74B1DB9FCFFFFFFFBFFF4FEFFFFF7FF
FF9552FFE82AF8F5FFF1FFC952EEFFF1FEEFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFFFFDE0E020004080013F4DD8389FFF9FF
F6FFFAF3FBF5FFFFFFF4F7FFFAFFFFFFF8F5FDFFFEEFFBF5FF3FB3FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFECA39F7FCFFEDFFF8FFFFF7F9FFFFFEFEFEFEFF
FFFFFFFFF4FFFFFBF0FFF1FFFC689FF4FFFBFFFFFFFFFAF9F3FFDBFFF2FCFFEDFFFEECFF
FFFFFFFFFFFFFFFFFFF8FFFFFFFE27DDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFEFDFAF9FFFFF7F8
FFFFFFFFFFFDFDFFFFFDFDFFFFFFFEFCFCFDFDFBF9FAFDFEFDFFFFFFFCFFFFF2F4FFFFFC
FFFEF7F9FFFFFAEFFFFFFFFFFCFBFFFFFFFFFBFCFFFFFFFFEFFAFFFFF9F7FEFFFCFFFFF4
F2FFFFFCFFFFFFFDFEFDFAF9FFFFF7F8FFFFFFFFFFFCFCFFFFFCFCFFFFFFFFFFF8F7FFFF
F9FAFDFEFDFFFFFFFCFFFFF2F4FFFFFCFFFEF7F9FFFFFAEFFFFFFFFFFCFBFFFFFFFFFBFC
FFFFFFFFEFFAFFFFF9F7FEFFEBFFFFFDFCFFFDFEF6FEF4FFFFF2FFAB2866BCF1FFFFF3F1
FBFFFDFFFDFFFC9F6F2880F3F9F8F7FFFFFDEEF8FFFFFFF9FFED88FEFAFBFFFFFFFFF5F7
FFFFFFFFFFFFF9F8FFFBD3A544203493E8FEFBFFF9FFFFFFFFFFFEFAFFFFFFF7E0AB5611
3391E7FDFCFFFFFDFFFFF0F6FFFFFFFFFBFFF4FFFFFFBD2665D5FFFFF7F6FFFAF6FFFFF6
FFFF17DDFFBC39FFFAFFEE26D7FFFDFAFFFFFFF2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFED4AA401000000007DF1FFFF47A8FDF9
FDFFFFFFFFFFFCF5FFFFFFFFFFFFFEEFF9FFFFF3FFFFFCF85CA1FFF4FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFB444FFF5FFF8FFFFFFFFFEF0F5FFFCFEFFFF
FFFFFEFEFCFFFFFEFFFFFFF57D90F3FFFFFFFEFEFCFCFFFFFFFEFFFFFFFFF7FFFFFFFAFF
FFFFFFFFFFFFFFFFFFFBFFFFFFFA90EAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F9FFFFFFFFFFFFFFFDFFFF
FFFBF9F4FFFEFEFFFFFEFEFFF9FDFFFFFFFFFDFCFFFFFFFFFFFFF9F8FFFBFDFFFFFCF8FD
FBFFFFFFFFFFFFFFFFF7F3F7FFFFFFFAFAFFFFFFF7F3F7FFFFFFFFFFFFFFFFFBFDF8FCFF
FFFDFBFFF8F9FFFFFFFFFFFFFFFDFFFFFFFBF9F4FBFFFFFBFBFFFFFBF4F9FBFFFFFFFDFF
FFFFFFFFFFFFF9F8FFFBFDFFFFFCF8FDFBFFFFFFFFFFFFFFFFF7F3F7FFFFFFFAFAFFFFFF
F7F3F7FFFFFFFFFFFFFFFFFBFFFFFFF9FFFFFFFCFCFFFFF6F1F8FFFEFCAF4900387C85C2
C7B2B1937D4B17549AE3F1FFFFFFFFFAF8FFFFFFFFFBFFFEF6FFF6FFFFEEFFFCF4F9FFFF
FFF8F8FFF2FFFFFCF8FFFFF9FFF1BE70251A62B5FBFDFFFFFFFEFFFFF7F3F9FFFFF8F7FF
C65E0E287BC0ECFFF5F7FEFFFFF8F8FDF9FFFCF6FFFFFEEC742C93FDFFFFF8FFFFF8FBFF
FEFE41A9FFFF7990FAFA67A0FFE5FFFFECFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBF4FFF1F81BF62700070013FFF8FFF9F6547BFB
FCF8EBFFEBFFFFFFFFFEF7FFFEF5FCFFFFF6F4FFF4FEE230ABFBFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAD4CF4FFFFFAFEF9F4FFFFFFF4FFFFFFFF
FEFDFDFFFFEDFFFFEFF1FC815BFFFFFFFCFFF7FFFFFCF9FFFFF4FFE2F3F8FFFFFEF4FFFD
FFFFFFFFFFFFFFFFFFFDFFFEFFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEEF3FFFFFFF6F9FF
FCFFFFFFFFFEFEFFFFFEFEFFFAFFFBF9FFF9F8FFFFFFF3EEFEFFFFFFFBFCFDFAF7F9FFFF
FFFBFAF8F4FFFFF9FFFFFFFFFCFDFFF2F2FFFDFCFFFFFFFFF9FFFFF4F8FAFBFFFFFFF9F7
FAFDFCFBFFFFFFFEEEF3FFFFFFF6F9FFFCFFFFFFFFF2F2FFFFF2F2FFFFFFFFFCFFF9F6FF
FFFFF3EEFEFFFFFFFBFCFDFAF7F9FFFFFFFBFAF8F4FFFFF9FFFFFFFFFCFDFFF2F2FFFDFC
FFFFFFFFF9FFFFF4F8FAFBFF56B0F8FFFFFFFFFEFFF9FDFFFFFCFFF7FDF8FFFFB77D843E
34444B727EAAFFF2FCFFFFF7FFEEFFFBFFFFF6F5FEF7FDFFFFFFFFFEFFFFFFF7FFFFFFFF
FEFCFEFFFFFFFFFEFDFFFFFCF6FFFFFFFBE69943023C93DBFAFCFDFFFFFFFFFFFFFBFAFF
F9FFFFDA77252F68B0F3FFFCF0FFFFFCF8E05BFFF0FFFFFFEDCB3941D3FFFFF9FDF6FFFF
F1FFA184FFFBF432E2A35EFEF3FFFFFBFAFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00225D0D030D9AFFF8FCFEF1FF8B36
E7FFFFF3FFFFF8FCFFFDF3FFFFFFFFF6F7FFFFFFFFA826E2E7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFBF9B150C2FFFFFFFFFFFFFEFCFEFFFFFFFF
FEFFFFFFEFFFF8FCFFFF5B75ECFFFFF6FDFFF9FFFFFFFCFAF9FFFFFFFFF0FFF3FFFFFFFD
FFFFFFFFFFFFFFFFFDFFFDFDFDFCFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDD5C0C0C7E5FBF2DEE7FFFF
DCBCBBB7E1FAFAE1E1FAFAE1C8C6BFD8FFFFE4DEF2FBE5C7C0C0D5FDFFE8E3FDFFE4BEAE
BCD9FFFFE2E3FEFFDEBEB4C3DCFFFFE7E7FFFFDCC3B4BEDEFFFEE3E2FFFFD9BCAEBEE4FF
FDE3E8FFFDD5C0C0C7E5FBF2DEE7FFFFDCBCBBB7E4FFFFE4E4FFFFE4B7BBBCDCFFFFE7DE
F2FBE5C7C0C0D5FDFFE8E3FDFFE4BEAEBCD9FFFFE2E3FEFFDEBEB4C3DCFFFFE7E7FFFFDC
C3B4BEDEFFFEE3E2FFFFD9BCB6C0C4BEB1ABCCFFF5BEB4ABCEC6AEC4ABCCF6FBC5A8BFC8
C3C7BC9DDBFFE5C6A4B9C1ABCCC1A1D4FFF3BFB2C5C3C0BDBF8A84F4FFECADC4B7CFEBFB
FFFFFFFFFCF7F8FFFFFFFFFFFFFCF9FBFBFAFFFFFBBD6627225BB3F5F8FFFBF1F5FFFFF9
FBFFF7F1FFFFD389401B3CABF9F8F0FFFF720076FFFAFFF8FFFAFF8A197DF2FFFFFFFFFF
F8FFB48DBBC6BD8F301FFAFFFFFFE7EFFFFCF3FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFA7D0EAAF7BC0023EDF9FFF6FFFFFFFBC6
1964DBFFF7FFFFF2FAFFFFFBF3FFFFFCFFFFE4AD2754EFFFFFFFF9F1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFDFDF7C149ABFDFAF7F5F5F8FFFFFFFEFCFD
FFFFFFFFFFFFFFFCD22AA8FFFFF2FCFFFFFDFDFFF9FFFFFFFCFFE7FFFAFFF7FFFDEFFFF9
FFFFFFFFFFFFFFFFFBFFFBFEFEFF89F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB9E4E324CA4F7FF83B2FBF9
994C3F40B4FFFFB4B4FFFFB4626D7CB5F9EEB295FFF7A44C324E9EFBED9EA2FFFF984649
509DF8F6AEA5E1FF994F2B54A5F0EAA7A7EAF0A5542B4F99FFE1A5AEF6F89D50494698FF
FFA29EEDFB9E4E324CA4F7FF83B2FBF9994C3F409AFFFF9A9AFFFF9A403F4C99F9FBB283
FFF7A44C324E9EFBED9EA2FFFF984649509DF8F6AEA5E1FF994F2B54A5F0EAA7A7EAF0A5
542B4F99FFE1A5AEF6F89D50464282DFD27B8CF8FF87314F2595CCD18095FFF48351363A
89D0C58B92EAFE924541478FC5D47E90FFF18B3F304489CBC88D8FFFF5A23C484A9FF6FF
FFF5FAFFFFFFFFFFFAF6FBFFFBFFFFFFFFFFFFF4FAFDFFF7D89845084C9DEEFFF9F4FCFF
FFFFFFFFFFF9FCFFFAF1AF440D3B9BDEFC37090051FFF8FFEBFFEDFDEF4D2EC6E79F4F3F
240B0041453E424F2D00001E3D6895E2FFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFC83E5AABF0FFF467BAFFF2FFFFFAFFF5FFFF
F3942951A1DBFFFFF1FDFFFEFFFAFFFFCD754B53D0FFF1F3FFEDFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFCFFE9EC5633A8FFFFFBFFFFF0FFFCFBFE
FFFFFDF7FDFAC3572DE3EDFFECFFF1FFFFFFFDFFFFFFFBFCFDFFF7FDFDF5FFFFFFFFF7FE
FFFFFFFFFFFFFFFFFFFDFFFBFFFF8EF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4FFFFF6FCFFF3FFF4FCFF
F8F8FFF8FFFEFEFFFFFEFEFFFFFFF3F7FFFFF4FFF3FFFCF6FFFFF4FFFFFDF6FDFFFFFEFF
FDF7FFFFF3FFFFF8FFF6FFFFF3FFFFF6F6FFFFF3FFFFF6FFF8FFFFF3FFFFF7FDFFFEFFFF
FDF6FDFFFFF4FFFFF6FCFFF3FFF4FCFFF8F8FFF8FFFEFEFFFFFEFEFFF8FFF8F8FFFCF4FF
F3FFFCF6FFFFF4FFFFFDF6FDFFFFFEFFFDF7FFFFF3FFFFF8FFF6FFFFF3FFFFF6F6FFFFF3
FFFFF6FFF8FFFFF3FFFFF7FDFFFFFAF8FFFFFFFFFFFAFFF9FFF3FFFBF8FFF9FFFFF1FFFF
FCFFFFFAFFFFFFFCF7FFF9F7FFF5FFF6F1FFFCFDFFFEF8FFFFFEFFFEFFF9FFFDF7FFFFF7
FAFFFFF2FDFFFDFAFFFFFFFAFFFCF9FFFFFCFDFFFEFFFFFFFFFFFDF4AE611B2574C7F4FF
FAFFFFFBFDFFFFFCFFFAFEFFF8B95D192C0100150044FBF7FFFCFBFFFFB84C1C1570A1BF
E1F4FFF8FDFAF8FFF1F5FFDCB99C6F1D1F7BC2FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE802992F6FFFFFFFFE5F7FFFEFEFFFCFCFFF9FB
FFFFF3AC5C222561838D9EAD8476491D2F80D3FBFCFBFFFFFFFFFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDEEFFFAFFFFFBC9592676DAFBFCFFFFFFFCFF
FFFFF4E8973F36A4FFF2FFFFFFFFFFFAFFFFFDFCFDF9FFFFFDFBFFFEFFFCFFF3FFFCFAFF
FFFFFFFFFFFFFFFFFFFAFFF6FEFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF71FFFFEFFFFEFFF5FFFFFFFF
FFFFFFFFFFFFFFF7F611FAFFFE05FFFBFFFCFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFCFFFFFFFFFFFFFFFFFFFCF8FFFFFDFC
FEFFFFFFFFFFFFFFFFFFFFFFFEFCFBFCFEFFFEFCFFFFFEFEFFFFFEFCFFFCFFFEFDFFFAFF
FBFFFFF5F8FFFFF2FEFFFAFAFFFFFBFBFCFEFFFFFFFEFDFCFFFFFFFFFFFEFFFFFFFFFEFF
FFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFDFDFEFFFFFFFF
FFFBF4FBFFFFFFFFFFFFFFFBFDFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8FF
FCFDFFFCFFFCFCFFFFFFFEFFF7FFFFFBF9FFFFFDFFF7FFFFF9F8FFFFFFFDFFD9913B124B
9AD7FFF7F8FFFAFFFFFAFBF9FFFCFFF980010008000649EFF9EBAD4D173A92D5FEFFFFFF
FFFDFBFBFFFDFEFFFFFFFFFDFEF8FFFFDB87391458A0FCFFF3FFFFFFFFFFFFF8FAFFF9FF
FFFFFFFFFFF9F8FFFBF5FEFFFFFFFED52D53ECF4FFFFF1FFFFFFFFFFFFFFFDFFFFFFFCF6
FFFFFDFFFFF3CCAA8075515C7E88BBE1FFF6FEFFFFFDFFFFFDFDFFFFFFFDFFFFFDFFFFFD
FEFEFFFFFFFDFFFFFFFFF8FFFFFFF9FFF9FFFCFFFFF9FDFFFDFFDE71341E507A7D9BAA89
8353341E64B4FFFDFFF7FFFFFFFFFCF6FFFFFDFFFFFFFCFDFFFFFAFFFFFBFFFAFFF6FFFF
FFFDFFFFFDFDFFFFFFFDFFF1FEFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FF0FFFFFFF0FFFFFFFFFFFF
FFFFFFFFFFEEFFFFFB00FFF5FF00F4FCFFFFFCFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAF9FAFFFFFFF7FFFFFFF8F8FFFFFFF4FFFFFD
FDFFFFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFF
FFF8F7FFFFFBF9FFFFF7FFFFFFFCFFFBFFFFFBF9FBFFFFFFFCFEFFFEFBFAFBFDFEFEFEFD
FCFBFCFDFAFBFCFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFDFFFFFFFDFCFC
F6FFFFFFFFFFFFFAFBFEFFFEFFFFFFFCFFFDF5F7FFFFFFF9FFFDF5F6FCFFFBF5E499FEF8
FFFBFCFEFFFFFFFAF9FFFFFCFFFBF6FFFFFFFCFEFFFFF8F7FFFFFFEBFFEEF7FFFAFFF3B6
5824226DCDF1FFF0FBFFFEFFE6F7FFFF47001000000000518A4543A7FBFFF7FFFFFFFEF4
F7FFFFFFFFFFFCF9F7F8FAFDFFFFFFFEFFFFF9EEAA591992FFF6FBFFFEF6F5FDFFFFFFE4
FFF6FFFFFAFFFFF1FFFFFFF6F9FB9018AEF4FFFAFF4DFFF5FFFEF8FCFFFFF8FCF8FFFFFF
FFFAFBF8FFFFFFFDFAFFFFFAFFFCFDFDFFFFFFFEFFFFFFFFFFFFFFFDFFFFFCFFFFFFFBF6
FCFFFFFFFEFFFFFEFBFFFEFFF8FDFFFFFFFFFDFBFDFFFFFFFFFCFCFDFFE1AE8A895E527D
7BA4D6FFFFFFFFFBFFF6F8FFF8FFFFFFFFFAFBF8FEFFFFF9FFFFFFF7FFFFFFFAFFFFFFF8
FFFFFFFFFFFFFFFDFFF9F9FFFFFF89F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F7FFFFFCFEF8FFFFFFFFFF
FFFFFFFFFFF9FFE0FF0DF3FFFE0DFFEFFFF3FFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEF8FBFFFFF3FFFFFFFCFFFFFFFFFEF5FC
FFFDFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFEFFFFFFFFFDFDFEFEFCFBFEF8FFFBFBFFF9FF
FCFFFFF6F6FFFFFCF6FFFEE7F6FFFCFFF2F8FFFFFFFCF9F8FFFFFEFFFFFFFFFFFFFFFFFF
FEFFFFFFFFFEE7D1C2BEC0C3BEBEBEBEBEBEBEBEBEBEBEBEBEBEBEBEBFC0BFBCB9BABFC4
C0BDB8B5B9BFC1BFC6C1BFC6D4E5F9FFFCFFFFFFFFFBFCFFF8FFFFFFFFFFFFFFE695FFF9
FFF7F4FFF2FCFEFAFFFFFFF5FFFAF7FFFFFDFAFEF5FFFFFFFFFBFEFFFFFFF0F8FFFFFFF1
FFFFCC823B0356A4DAFFF9FFFFFBFFDC0C00001535634B0A6DD1FFFFEAFDFFF5FFF9FEFF
FFF4F7FFFCFFFFFFFFFEFFFFF8FFFFF7FCFFFFF8F9FFE864309FFFFCFFFDFFFFF9FBFFFF
FFFFFBFBFFF1F2FFE5FFEFFFE43131E8F9F9FFFFFDB5F8FFF8FFFFF7FAFFFFFFFFFFF5FF
FDF9FFFDFFF0FFFFF9FAFFFFFFFCF7FFFEFDFBFFF8FFFEF7FDFAFAFFF8FFFFFAFFFCFCFF
FFFFF7FFF4F7F4FFFFF7FFFFFFFCFFF9FEF3FFFFF9FFFFF9FFFFFFFFFFFFF8FAF4FEFEFF
F7FFFFF7FCFFFBFDFFFFFFFCFFFFF5FFFDF9FFFDFFF8FFFFFEEFFFFFFFFAF7FFFFFCF8FF
F8FFFEF7FDFAFAFFFFFFFEF9FFF11BDCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FAFFFFF9FFFFFFFFFF
FFFFFFFFFCFFF6FFFD00FFF5EE06EEFFFFFFF9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFDFFFFFFFCF3FFFEF7F9FFFFFCF8EEFFFFFF
F8FEFFFDFFFFFFFFFFFFFFFFFFFFFFFFFEFCFDFEFEFDFDFFFFFFFFFFFFF9FFFDFFFFFDFF
FDF7FBFFFFFEFCFFFFF7FFFFFAFFFFF1FFEFCBBFC3BA9B7D7483886E452C3140443E3321
0D00000000071B2F3C403D3A414141414141414141414141414141413A3D424544403B37
463D3E4A4B403B403D3B3D3F3014000001010000000522393E403E393A4C6B838975778C
B8D2C8C6CEF1FFFFF5F1FDFFF5FFFFFFF7FCFFFFFFFFF1F9FFFAF1FFEEFFFFFFFFF1F6FF
F7FFFCF9FFF09123261D73A9FFFFE7EF83BBD9FF983066EDFCF8FCFFFFFEFFFFFFFFFFF5
F7FFFFF6FAFCFEFDFBFBFDFFFFF5F5FFFFFAF5FEFEEFFFFFCC633194FBFFFCFFF6FFE8F0
FEFDFFFFFFFFFFEBFFF5FF8C0B8DFFFEFFFDECFFFCFFC08C7D7AAFFFFFC1B8F8FFCE827D
82ABFFFAD2BEFBFFD185777EA0FDFFCBB3FFFFCA7F8281B1FFFFCDA8FFFFC98A7881B1F7
FFCDB1FFFFD8837584AFFFFACCB6F0FFD1847C7DAFFFF6D5A4F5FFD3817A8AAEFBFFD49F
F7FFCE887D7DA6FFFFCBB9F9FFCE827D82ABFFFAC7B8F7FEDA7F807CADFFFFCCB3FCFFD2
7F8281B1FFFFCDA8FEFBD5787D8420DDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF75FFFDFEFFFFF6FFFFFFFFFF
FFFFFFFFFDFFEDFFFF02F5FEFF10FEF0FFE8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFDFFFFFFFFFFFFFFFBFFFFFFF8FBFFFFFCF2FA
FFFFFEFEFFFFFFFFFFFFFFFFF8FAFDFFFFFFFFFFFFFFFFFEFEFCF9F7FFFFFFFEFDFFF7FA
FAFFFFD0B7B8A179916D3939512C00070013333E3C466380897A758EB8D1CCBDB9BFCADC
F0FFFFFFFBFAF8F9FCFFFFFFFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFFFFFBF9FDFFFFFF
F9FDFFFFF9F8FFFFFFFFFCFDFAF5FBFFFCFCFFFFFFF8DBC4BFBDBFC4C2B19279788A8776
3A2E353F310A0000122D383C4A62777E8AA3B7BFBBFFFFFFFAFFFFFEFFF2FFF8ECFFFFF4
F7FDFFFFF1FF7E0C9CDA8038154DA1E7FCFFC7106FD4F6FFFFFFFFF9FAFFFEF4F1FFFFFE
FEFFFFFFFFEAC7ABA1A7B4BEFFFFFFFAF7FFFFFFFBFFF9FFFFF7DB6829CFFDFFF5F3FFFF
FEFFFAF9FFFCF9FFFFEA3F3BDDFFF0FFFFFFFAFBFCF8CD797D7AAFFFFFC1B8F8FFCE827D
82ABFFFAC4B1EFFACD867D86B2FFFFC9AEFFFFD07F8281B1FFFFCDA8FFFFC98A7881B1F7
FFCDB1FFFFD8837584AFFFFACCB6F0FFD1847C7DAFFFF6D5C0FFFFC87B7A8DB1FFFAC8B1
FFFFB9858A89AFFFF9C0B5FFFFCE827D82ABFFFAC7B8F7FEDA7F807CADFFFFCCB3FCFFD2
7F8281B1FFFFCDA8F9FBD2837A8AA3F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FDFEFCFFFAFCFFFFFFFFFF
FFFFFFFFF9FFFFFFFE0002FFFF00FFFBFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFDEDD6C6BB927787ABC9E1F4FFFFFFFF
FFF9FCFFFFFFFFFFFFFFFFFFFFFFFFFEFDFBF7F4FDFDFDFFFFFFFFFFD4C0B3947A674941
1C00012B44455D85708ABCC9B2C7F5FFFFFFFFFFFFFFFDF9FDFFFFFFFBF9FBFFFFFEFDFF
FFFFFCF7FDFFFFFFFFFFF5EEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F9FCFFFFFFFCF7
FFFFFFF2F9FFFFF6F0F7FFFFFFFFFFFFFFFEF9FBFFFFFFFFFFFFFBFAFFFFFDF9EB8EFFFF
FAFFFFF9FFFDFFFFF7D3C0C1AC98877F7057464333000012373647728182B7CEE3FFF7FF
FFFFF2F2FFE60F0005CCFFFFE1AB7C0E22513AEAF6FFFFFDF4F8FDFFFEFEFFFFFEFFFFFC
FFF9B86C14223B54615E4D3F002E8AE2FFF9F7FFFEFFFBF8FFFFF6FCDB33A2F2FFF5E6FF
FFFFFAFEFFFAF6F9981F84FFF9FEFFFBFBF0FFF8F8FFFEFEF8FFFFF7FAFFFFFFFFFFF5FF
FDF9FFFDFFF6FFFFF9F8FEFFF9F8F5FDFAFFFFFFF8FFFEF7FDFAFAFFF8FFFFFAFFFCFCFF
FFFFF7FFF4F7F4FFFFF7FFFFFFFCFFF9FEF3FFFFF9FFFFF9F4FFFFFFFFFCF2FCFFFFF9FF
F4FFFFFFF1FCFAFFFFFFFCFFFFFFF5FFFDF9FFFDFFF8FFFFFEEFFFFFFFFAF7FFFFFCF8FF
F8FFFEF7FDFAFAFFFBFFF9FFF1EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFEF9FFFFFFFFFFFFFFFF
FFFFFFFFFFF8FDF9FD02F80003FDFFFFEEFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2FFFCCB7A3A2C394269897C4F2C2A3878C9FFFF
F1FDFFF6FFFFFFFFFFFFFFFFFFFBF9FEFFFFFFFFC6B69A77522F130344455D7291B1B9C6
FFFCF8FDFFFFFFF9BBC199728CBBCCCDF6FDFFFFFAFAFFFFFEFCFBFCFEFFFEFDFCFBFCFD
FEFEFDFDFFFCF7F3F5FCFFFFFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFBFFFFFFEFD6C1B6
7F8A9FBBD9EFFBFEFFFFFFF9F2F4F9FDF4FDFFFFFBF7FBFFF4FDFFFFFDFAFEFFC337FFFF
FAFEFDF8FFFFFCFDFCF7FBFFFFFEF9FFFFFFFDFFFAFFFFE5C9CCB78983784E2B21090C47
467EA1B5F09200100420E2FFFFF5E9FF4D3DF7FFFBF5FFFAFFFFFDF6F9FFFFFCFFF0FBFF
BA474290F0F3F7FCFFFFFFFEFFD1682766E3FFF1FFE2FFFFFBFFF9FFF8F06264FDFFFFF9
FFECFFFFF4FFDE563BC6FFFFF6F7FFFBFFFFF9FFF3FBFFFFFFFEF8FCFFFFF8FCF8FFFFFF
FFFAFBF8F8FAFFFEFCFFFEF7FFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFDFFFFFCFFFFFFFBF6
FCFFFFFFFEFFFFFEFBFFFEFFF8FDFFFFFFFFFDFBFDFFFFFFFFFDF8FCFFFFFFFFFDF8FAFF
F4FFFFF4FFFCF2F9FFFBF6FFF8FFFFFFFFFAFBF8FEFFFFF9FFFFFFF7FFFFFFFAFFFFFFF8
FFFFFFFFFFFFFFFDFFFFF7FFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF04FAFFFFFCFFFBFCFFFFFFFF
FFFFFFFFFDFFFFF9FFFFFDFFF5FFFFFCFFFFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA43E3783D5FBFFFFFFF9F2FFFFF3CD853736A7
FFFFF8FFFFFFFFFFFFFFFFFFFFF0C79A6F42190049566F92B9DCF5FFFFFAFFFCFFFFFCFE
FCFFFFFEDB9849123D436686774D3533245AA6E5FFFFFEF7FFFFFFFFFFFFFFFFFFFFFFFF
FDFDFFFFFFFFFFFFFFFFFDFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE5A45C29213A54
846B5D5129124A9FE2F4FFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFEFDFEFFFFFEBA47FFF5
FFFFF8FFF8FEFFFFFFFFFFFFF8FFFFFCFAFFFFFEFFF2FAFFFFFAFFFFFCFFF9FFFFFFFBBE
C085864723000A0000003DF2FFFFDC3BADF3FCFFFFFFF5FFFFF7F9FFFFFAF8FFF0FFDA57
43B5FFFAFCFFFFFFFFFCFDFFFFF3FFFF92236DFFF7FFFDFEFFF8FFF7F3FFF79040D2FFFD
F3FFF3F1FF8D2281FEFFFEF7FFFFF3FFFFFCFCFFFDFFFFF5FFFFFFFFFFFFFDFFFFFFFCF6
FFFFFDFFFFFFFCFFF9FFF4FFFFF9FFF8FFF5FFFFFFFDFFFFFDFDFFFFFFFDFFFFFDFFFFFD
FEFEFFFFFFFDFFFFFFFFF8FFFFFFF9FFF9FFFCFFFFF9FDFFF8FFFFF7FFF5FEFFFFFFFFF4
FFF2F8FFF8FFFFF2FFFAFFFEFFFFFCF6FFFFFDFFFFFFFCFDFFFFFAFFFFFBFFFAFFF6FFFF
FFFDFFFFFDFDFFFFFFFDFFE9FFFDF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7DFFFEFCFFFCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFEFFFFFDFFF8FFC22B6DC4FCFFFFFEFFFFFFFFFFFFFFFFFFFFFEC54B
49C1FDFFFDFBFFEEFFBF7E501425436C9AC6E8FBFFFFFFFFFFFFFFFFFEF9FFFDFFFDFFFD
FFFFD75F255FC0F4FFFFFFFFFFFFFFFFEDA1453080E7FFF4FAFFFFF9FFF9F1FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF6FFFCF2FFF0773C42A3F1F7F4FF
FDFFFFFEFFF0AD671771D9F7FFFCF8FEFFF4FFFFFBFFFCFFFFFFFFFFFFFFFFFFBE47F8FF
FFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F8FFF9FFA10B000A00100063FFAD40C5FFFFFFFFFFFFFFFFFFFAFBFFEEFFFEF5FED444A6
FDFFFFFEFFFFFFFFFFFFFFFFFAFFFFFEFFEB9C48E3FFFFFFF6FFF5FFFFF8FFFFCA2EB5FC
FFF0FFEB3B30D9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFFFCFFF6FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFCFFFBFFFDFF8845D4E9FFFFFFF7FAFFFFFFFFFFFFFFFFFFF7FFFEFF
B03999FFFFFF86610A287FB0ECEFF3F8FEFFFFFFFFFFFFFFFFFFFFFFFFEAF9FFF2FCFFF7
E8571E8FFFFFF3FCFFFFFFFFFFFFFFFFF8FFFFE7752979FFFFFFFEFFECFFFFF9FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2FFFFFBFFF37E2284D7FFFFF4FFFFF8
F8FEFDF9FFFFFFF7FF962469D8FFFFFFFFFFF1FFF2FFFFFBFFFFFFFFFFFFFFFFDB9CFDFF
FFFFF6FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFDFA45000000050008005D4DDCFFFFFFFFFFFFFFFFFFFEFFEBFAFFF8FFFFC11BDBF5
FFFBE8FFFFFFFFFFFFFFFFFFFBFFFEFCFFFFE0B251FBEEFDFFF6FDFFFEFFFFF4EBFF34A0
F9FFC7118FECFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFFFCFFF6FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF8F7F5F55D69F5FFFFFFFEFBFBFFFFFFFFFFFFFFFFFFFFFFE0FFF9
FFFF7D4A980056A9E6FFFFF2FFFFFFFFFFFDFAF7FFFFFFFFFFFFFFFFFBFFFFEDFFFFFFC1
2DA7FFFFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFCFDFFE58E37E7F6F7FFFFF8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFECFEED4D6CECFEFFFFFFFEF9FCFF
FFFFFFF9F5FAFFFFFDF8F6993FB6FAF5EBFFFDFDFBFFF9FEFFFFFFFFFFFFFFFFFFFEFFFD
FCFEFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEF8FFBCC6C6BDDCFFFEC556FAFFFCFFFFFFFFFFFFFFFFF3FFFFFFE9FDFFCD37F9F0FC
FFFFFFF7FFFFFFFFFFFFFFFFFFFFFEFAFFFFFFFDBE35FEFFE2FFFFFAFFF1F4FFFFF3F855
B5FEDED5EEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7DFFFEFCFFFCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF3FFF33BA9FFFFFAFBFEFFFFFFFDF8FFFFFFFFFFFFFFFFE9FFF9FA
FFFEF4910CDEFFFFFAFDF5FFF8FAFCFFFFFFFFFFFFFFFFFFFFFFFFFFFEFAF4FFFFFF9749
F1F5F5F2F9FFFFFFFFFFFFFFFFFFFFFFF8FFFDF4FFFFF4C528C5FFF9FFFFF8FCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFFBE28BAFFFFFFFFF8FBFFFFFDFC
FFFEFFFFFFFFF8F5F9FFFFFCE8408CFDFFFBFFF0FFFFF0FFFFFFFFFFFFFFFFFFFDFCFFFA
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F6FDFFF6FFF8F8FFFEFFD344E4FBFFFFFFFFFFFFFFFFFFFFFFF7F5F3FFFCF63DD3F3FFFF
EFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFEFBF9FDFFFFB554EAFFFFECFFFCFFFFEDFFF9FFE5
3FCEFFF2FFFDE9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7DFFFEFCFFFCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF8F45ABCF9F8F7FFFFFFFFFFFFFDFCFFFFFFFFFFFFFFFFFFFCFFFD
FAFFF7FF983DFCEFFFFFFDFDFFFFFFFDFCFCFCFDFFFFFFFFFFFFFFFFFFFFFFEAF1814BFA
F9FEFFFFFFFDFDFFFFFFFFFFFFFFFFFFFCFFFFFFFFF9FFFFF52F9CFFF6F6FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9B847E8F5FFEBF4FFFFFFFEFFFFF6
FFFCFAFFFFFFFFFFFFFFE4FFFAFC7382FFF7FAFFF7FCFEFFFFFFFFFFFFFFFFFFCBB6F7FB
FFFFFCF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFECFFFFFFF5FFFFFFDF34D6FFFFFFF3FFFFFFFFFFFFFFFFFAFAFFFFFFFD5A99FFFFFFEF
FFF5FFF1FFFFFFFFFFFFFFFFFEFDFFFFFFFAFAFFFFFF698FFFFFF8FFFDFFF4FFF2FCFFFF
E92CE9FEFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFFFCFFF6FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFF8371F4FFEFFFFCFCFCFBFAFDFFFFFFFFFFFFFFFFFFFFF6FAFFFD
FFFFFAF0FF8782FFFBFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFF4FFAC67FFF4
FFF9F8FFFFF9F6FFFFFFFFFFFFFFFFFFFFFFFDF2F4FFFFF6F8F353E5FFF8FEF6FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE225F9FFEEFFFFFFFAF2FAFEF9FBFF
FFFFFFFCF6F3F9FFF8FFFFFFF6FAFC6782FFFFFFF3FFFFFFFFFFFFFFFFFFFFFFDFB0FFFD
FFFFFDFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF1FCFFFDF5FFE54ECDFFF2FFF7FFFFFFFFFFFFFFFFFFFFFFF5FEFBD83AF6FFF6F9FF
FAFFEDFFFFFFFFFFFFFFFFFFFFFDFDFFFFFEFDFFF6FFDE3DE1F5FFFAFFF0FFFCFEFFF9F6
F8D94AE5F3FFFFEAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFFFCFFF6FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAF65FEFEFFFAFBFFFFFFFFFFFFFEFEFFFFFFFFFFFFFFFFFFFFF3FD
FFFDFFFFF7FF4BAEFFFFF6FEFEFEFDFBFAFAFAF9FFFFFFFFFFFFFFFFFDFFFFAB45E7FBFD
FAFFFFF5F9FFFFF7FFFFFFFFFFFFFFFFF6F4FFFFFFF9FBFFFFEEDC32D0FFFFFCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEB26FEF0F7FFF3FFF0FFFFFFFBFFFFFF
F5FEFFFFFFFFFFFFFFF9FDEAFFFFFAFB59BCFFFBFFFFF9FFFFFFFFFFFFFFFFFFFFE4FFFF
F3FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E4FFFFFFFFFFFFF749B7F6FFFFFFECFFFFFFFFFFFFFFFFFFF3FFFFF5FF23D3FFF5FFFFF8
FFFFFBFFFFFFFFFFFFFFFFFFFFFFFDFEFFFDFDFEFFFCFE9063FFFFFFFFFFFDFFF5FFFCFD
FFFABB38FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7DFFFEFCFFFCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFB2CCFFFFBFEFDFFFFFEFCFCFEFFFFFFFFFFFFFFFFFFFFFFFAFAFFFD
FCFFFCFFFFFFE522F9FAFFFCFFFFFFFFFFFFFFFDFFFFFFFFFFFFFFFFFFF4F727E6FFF5FF
FFFEFFFFFEF8FAFFFFFFFFFFFFFFFFFFFFFFFCF9FBFEFEFBFFF9FFA45EF7F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF51ACF0FFF7FFFBFFFFFFF5F8FFFFFFFC
FEFFFEFAFDFFFFF8F8FFFFFFFFF9F7FFE824E1FFFFF9FFFCFFFFFFFFFFFFFFFFFEFEFFFF
F5FFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF3FFFEFBF6FF688CFFFFF4F6FFFFFBFFFFFFFFFFFFFFFFFFEBFFFFE037E8FFFFFFFAFF
FFFCFFF6FFFFFFFFFFFFFFFFFFFFFEFDFFFFFFFFFEFFFDED20EFFFF9FCFFFCF5FFF4FBFF
F6FFFF8C6FFBF2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFF8FFF4FFFFF7FFFFFFFF
FFFFFFFFFFFDFEFCFFFF000A06FFF8FFF7FFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FFFFFBFFFEFBFF876DFFFCFFFDFFF9F4FFFFFBFFFFF3FFFAFFFFF6FFF2FFFFFFF3FFFF
FBFFFFF4FFFFFF6489FFFFF1F6FFFEF8FFF7FFF8FFFCFCFFFFFFFEFFFFF8639EF8FFF2FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFF858B3FAFEFFFFFDFD
FDFFFFFFFFF9FFFFFCF7FFFCFEFBF6FAFFFFF1B952F2FFFCFFF0FFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF09A75F3FFFFF7FCFEFEFEFEFEFEFEFED99BFFFF
FFFFFCFFFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEF4FFF6FFFFFFFE
F3FEFFFCFFF7CB40FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFCFF857DFDFFFFFFFFFF
FFFFFFFFFBFFFFF9FAFFFFFFFFFFFFFFFFFFFFFFFAFFFFFB52AEFFFBFFFFFFFFFFFFFFFF
FFF5FFFE2ED6FFFFFFFEFDFAFFF7FFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F5FFFFFFFCFFFFFFFEFFFFFFF9F4FFFFFFFFFFFFF5FBFFFBFFFAFFFBFFFFF9FFFFFDFFFC
FFFFF7FFFFF7FFF9FFFCFFFFFFF6FBFFFFFDFFFFFFF6FFFFFFEAFFFFFFF5FFFBFFFFF4FA
FCFFFAF9FFFFFFFAFCF5FFFCFFFFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF06FFF0F6FFFFF5FFFFFFFFFF
FFFFFFFFFFFFFFF8FB00FFF3FA00FFFAF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFCFCFFFAFFEF20F4FFF0FFFFF5FFFFFFF9F6FAFFFFFDF8FFFFFCFFFFF9F4FDFFFFFA
F6F9FFFFF3FFF1FF05FFFBFFFCFFFCFFFFFFF8FFFFFFFFFFFFFFFFFFF8DB3EF0F4FCFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFF7FCE620FFF9FFFFFFFF
FFFFFEFDFCFFFFF4FAFFEFFFF7FFF8FFFEFFFF3ABBFFFFFDFFF9FFF8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEA42D0FDE9FFFFFFFFFFFFFFFFFFFFC051F6F7
F3F9F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE4FFFDFFF8FF
FFFFFCFEF4FF41B0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFAFF45B9FFFCFFFFFFFF
FFFFFFFFFFFF000B04000000FFFFFFFFFFFFFFFFFFF3FFF98878FDFFFFFFFFFFFFFFFFFF
FFFFFCFDB54AFFF4FFFEFFF9FFFAFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAF0FDFFFAF9FFFFFAF6FFFFFFFFF2FAFCF0FFF9FFFFFCFFF6FFECFDF5FCFFF5FFF2FF
FFF2FFFFFBFFFFFEEBFFFFFDFFF9FFF7FFEFFFFFFFFFF4FFFCFFFFFBF6FFFBFFF9F1FFFF
FDFFFFF9FFF1FFFFFFFDFFFFE2FEFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00EDFFFFFFF9F4FFFFFFFFFF
FFFFFFFFEBFFFFFFFF0CEAFFFF07FDFFFFFFF4FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFDFDFFFFF6FFAA3DFFF5FFFBFDFEFFFFFBFAFFFFF2FFF0FFF9FBF6FFFFF8FFF0FFF2FF
FFFAFBFFFFF8FFF2569FFFF5FFEFFFFFF2FFFDF6F3FDFFFBFAFFFFFFFF628DFFFFFDFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFF5718DFFFFFEF9F6
F6FAFFFFFFEFFFFFFFE98BFFFFF7FFEDFDFFB243FFFFF7FCFFFEFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFEA855FFFEFEE9FCFCFCFCFCFCFCFCC431FFFF
FFFFFFFFFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCF0F8FFC0FFFAFFFA
FFF1F0FFFF9B58F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4FFFDFB13ECFFFCFFFFFFFF
FFFFFFFFEFFFF802FFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFCB846FCFFFFFFFFFFFFFFFFFF
FFF9FFFFFE51A5FFFFF9FFFBFBFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F3FFFFFFFFFCFAF8FFF8FFFFECF7FFFFFFFBFFFCFFF3FCFFEEFFFFFFFFFFECFFFAFFFFF4
FFFFECFFFBF9FFFFFFFCFEFFF6FFFFFFF8FFFDF8FFF8FBFFFFF5F4FCFFFFFFFFFFFFFAFA
FAFFF0F9FFFFEFFFF8ECF3FDFFFFF6FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCAFFFFF2F5FFFFF7FFFFFFFF
FFFFFFFFFFFEFFF5EA07FFEEFC00FFF0F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFFFFFFF8FF4FB8F2FAFFFBFBFFF8FFFCFCFFFDFBFFFFFCFBFFFDFFF3F8FDFFFFFBFD
FFFCFCFFF2FFF9FCBB5EEEFFFFFFF6F1FFFAFFFFFFFFFFFFFFFEFCFBF913F8F2FFFFF3FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAF3FFF0FBC14BFFF9FEFFFF
FFFFFFFBFFFDFCF8FFD90D1FAFFFFCFFF9FF5BA9FFF5FBFFFFFBFBFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE4FF11F5FFFFFFFFFFFFFFFFFFFFFFBF43FAFF
F8FFF5FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB0457C9F8FF
F3FFFFFBEE33E5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFF10DF9FFFFFFFFFFFF
FFFFFFFFFFFFFFEF00FBEFFFFFFFFFFFFFFFFFFFFCFFFCFFC931FDFEFFFFFFFFFFFFFFFF
FFF9FFFFFDCE40F4FFF6FFFEFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFEF1F8FFFFFAF5FFFDF0FFFFE9FFF8FFFFFCF4FFFEFDFFEBFFFFF0F4FFF8FFDCFFFF
EAFFFFF8F8FFF9FFEEFFF7F6FFF9FDFFFFFFFFFFF1FFFFFFEEFFFCFFF7FFEDFFFFFFFFF8
FFEEFFFFEAF7FFF0FCFFFFF3FFFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3FFFFEEFCFFFFFFFFFF
FFFFFFFFF5FEF7FFFF00FAFFFC01FEFFF6FFEDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFCFFFFFFFFF117EBFFFFF1FFFDFBFFFBFFFFEBFBFFF5F9EEFFFFF4FFFCFFF8F9F5FFFB
EBFFFFFBFCF9FFFDFF0AFEF7FFF4FFFFA432D6FFFFF8F6FFFFFEFCFFB04FFFFFFAFFFBFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFE722E4FFFDF9F6
F6F9FDFFF4FFFFFFF1B50700003FD6F5FFE904FFFFF4FFFFFCFDF9FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF56ADF5FFFEFCFCFCFCFCFCFCFCDE9FFEFF
FAFFFAFFFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCF7F6FF00000254D1
FFFFFBF38986E2FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE8FFEF0FFDFFFFFFFFFFFF
FFFFFFFFFFFAF6FFFE00FFF9FFFFFFFFFFFFFFFFFCFFF9FFD823FDFDFFFFFFFFFFFFFFFF
FBFFF6FBFFFB827FFFFFFCFDFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFDFFFFFFF4F3FEFFFAFFFCF7FEF7FFFFF4FFFCFFFEFEFFFEFFEEFFFAFFF9FEF7FFFFFF
FFFAFFFBFFFDF9FAFFF8FFFFFDFFF7F6E6FFF6FFFFFAFFECFFFFF8FCFFF9FFF7F1FEF6FF
FFFAF1FFF9FFEDFFFFF0F6FFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFFF7FFFFF8FFFFFFFFFF
FFFFFFFFFDFFFFF5FA08FAFFFF07EFFAFFFCF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFF9FEFFE21CFAFFF7FDFFFAFCFEF8FEFFFFFFFFF3FFFFFFF2FFFFFFFBFFFFF3FFFF
FFFFFEF8FFFFF2FFFA12F3F9F8EB870C0300EDFCFFFFFEFFFFFFFFFF649AFFFFF3FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE5FFFFEBE82600324745454A
576A7D898B7C83BCC68D0D0000000462D5B168F6FFF9FFFFFCFFFFF9FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEDFFF6A565F4FFFDFFFFFFFFFFFFFFFFFFF1FFFF
F6FFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEF040C000400
55B8FFEA1EFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FFF707FFFFFBFFFFFFFF
FFFFFFFFFFFFFBF7F7FB0AF2FFFFFFFFFFFFFFFFFFFAFBFFE11FFDFFFFFFFFFFFFFFFFFF
FFFFF6FFFFF8ED2DE2FFFAF9FFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFFFFFFEAFFFFFFFFFFFDF8FFFFEBF3FAFAFFFCFFFAFDFFF9FBFFF1FFFFFA
FFFFF0FFF8FDFFFFFFFCF7FDF8FFFCFFFFFFF7FFFFFFFFFCFFFFEBFFFFFFFFFFFFFFFFFB
FCFFFFECF9FFF4FFFDFFFFFFFFF4FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF48E6FFFAFAFBFFFFFFFFFFFF
FFFFFFFFFFFFF1FBFFEB0C0200F6FFFFF0F7FFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFCFDFEFEFCC83DFFFAEBFFFFF8FFF9FFFFEFFFFFFBFFF1F6EDFFEFFEFFF4FFF1FFFBFF
FFEFFFFFEEFFFFFFFE3DBBD8681000051100ECFFF9FFFFFCF6FBFDF939BEFFF5FEFFFBFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFFFF7F5BB7BBBFBD
AF9A83747E846C4642300000031C0003086178FFFDFDF6F8FFFFFFFCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFE014610000010101010101010105000900
00000000010101010101010101010101010101010101010101010101000302000D09000F
0507747C83FBF6FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFC0FF4FFFAFFFFFFFF
FFFFFFFFF8FDFFFFFAFFEA13FFFFFFFFFFFFFFFFFFFBFCFCC63DFEFFFFFFFFFFFFFFFFFF
FFFAFFFFF8FFFF6F86FFFEFAFFFCFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFFFBFBFFFAA547FDFFAC0C00003EFEFFB048FFF7D20200002EFFF6BE4CFBF6CA000000
45F7FFC640F7FDCB00140238FFE8CC42F7F8C30002002EFFF1C050F1F3D000000C30FAFF
B542FDFECC000C003BE7FFF2FFFFFFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFAFFF8FBFFF2FFFFFFFF
FFFFFFFFFFFBFFFEFCFFFFF8FDFFEFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7FBFFFFF2AE52FCFBFFF6FFFDFFFFF6FFF0FFFAFFF10DFFF0FF0A000003000DF1FFFA
FFF0FFF6FFF5FFFDFF5D450402000B000000947B85ADC3BCC6EAFFFD21E5F3FFFFFCFAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFF5F9A161FFFFFFFD
FCFDFEFEFFFCFFFBFF9B00070000206EDE639CFFFBFFF9FFFFF9FEFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF7E614FFF3FFFEFEFEFEFEFEFEFED4B9F6F6
FFFEFFFBFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFFFFF80900070400
2EAAFB21D9FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB25D8FFFFFFFFFFFF
FFFFFFFFFFF0FAFFF1FFFF00FFFFFFFFFFFFFFFFF6FFFAFF9C69FFFAFFFFFFFFFFFFFFFF
FEFCFFEEFFF7FCDD2FFBFFFFFFFEFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFFFFFFFFFFF1FFFFFCFFF5FFFBFFFDFCFFFBEEFFFFFFF2FEFFF4FFFFF8FFFFFB
FDFFFBFDFFFCFFFAFFF9FFFCF7FFFEF1FFFFFAFFFCFFFFEFFFFFEDFFFFF2FFFAFFFFF7FE
FFF5FFFAFEFFEDFFFFFFF3FBFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F8FFFFF8FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFFFBFFF8FF9364FFFFFDFFFFFBFFF9F5FFFFFCFFF7FD03FDFFFDFC00FBFFFDF8FFF7FC
FFF7FFFCFFFFFFFFFF6195A01B03000501137F81734332473B11113800FFFCFFFBFEFFF9
F4FFFFFBFFFFF3FFF900FFFFF7F3FE05FFFFFFFFFFFFFFFFFFFCFFFFEFFFB24CFDFEFFFF
FFFDF1FFFCFFFFF2FFA40002158AF9FFFF44AEFFFFFFFFFFFFFFFFFFFFFFF8F6FFF005FD
FFFDFF0C000011FAFFFFFFFFFFFFFFFFFFF3FFFA03EDFFFFF6FFFFF8FDFEFFF7D6B3F2FF
FEFFFFFFFDFFFFFFFFFFFDFBFFFEFCFDFFFFFEFAFEFEFEFEFEFEFEFEFFFDFF00080026B2
FFF3B84AFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFF7385FFFCFFF9FFFF
FDFFFFFBFFF6FFFDFFEFFF00FFFCF9FEFFFDFDFFF7FFFFFB679AFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF41B6FFFFFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F6FFF1FEFFCEF0F7FFFFFFFFFFFFFFFFFFFFFCFFFFFDF6FFFDFAFFFFFEFAFFFFFCFFFFFF
FFFFFFFFFFFDFCFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF88DBFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFF4FFFFFCF9FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFFF9FFA658FFFDFDFFFFFCFFFDFFECFEF9F1FFFF03FCF9FFF2FF00F7FDFFFFFFF7
F6FFFFFAFFFEFFFAFD53B8F1E57D0A00011CF8FFFFFFFCFEFCF8FBFF03FFF6FFFFFEFFFE
FFFFF9F6FAFFFFFDFF00F3FFFFF8FF00FFFFFFFFFFFFFFFFFFF5F2F9FFFFB43DFFFFFFF8
F6FFFFEBFFEFFCFFFD943C9AFFF6FFF6FC47B9FFFFFFFFFFFFFFFFFFF2FFFFFFF2FF04FE
FBFC00F5FFF9FF00FFFFFFFFFFFFFFFFFFF0FFFF1EEFF6F1FFFAFCFFF6FEFFFFFFEBFFFF
FAFEFCFFFEFDFBFAFCFFFFFFFFFFFDFBFCFFFFFFFFFFFFFFFFFFFFFFFFFCFB0020BCFFFB
FBFF5C9DFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFCF2D436E8FFF3FFFFF9
FBFFF2FFF9FB00F4FFFFFF03FFFBFCFFFFFFFFFFFFF9FFF022EEF7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF8677FFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFDFBFFF864A3F7FFFFFFFFFFFFFFFFF5FEFFFAE8FEFFFFFFFFF9F1FFFFFEF9FFFDF4F4
FBFFFEF9F5FFFFFEF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF2B7DFFEF8FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3CFFFFFFFCFAFFFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFCFFFAFEC23FFFF7FDFFFBFFFDFFF7FFFFF8FFF0FF03FFF8F6FFF5FD07FFFDEDFFFF
FBFAF8FFFCFAFFFFFF38C6FFFFFFE5570031FFFDF4FEFFF8FAFFFFFC0BF8F4FFFFFFFCFF
FFFBFAFFFFF2FFF0F800FFFFECFFF404FFFFFFFFFFFFFFFFF8FFFFF1FFF7BF52F3FFF8FF
FFBCCDFFF5FFFFF4FDFBE8FFFFEDFFFFFF48B1FAFFFFFFFFFFFFFFFFFFFFF3F3FFFF00FF
FAFF00FFFAFFFF00FFFFFFFFFFFFFFFFFFFFFFF711F2FFFFFFFCF3FFFFFFE0FFFFF3FFFF
FBFEFBFFFFFFFFFFFFFDF6F1FAFFFFFFFFFBFCFEFCFCFCFCFCFCFCFCF3FFFFB5FFFFEBF3
FAFC1DE8FFFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFF5FFF824EDF7FFF3EBFF
FDF4FFFFFFFFFF000B0300FAFDFCFFFFFFFEFEFFFFFAFFAB4BFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFD831FBF6FFFBFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF6FFFFFF57A4FFFFFFFFFFFFFFFFFFFFFCFFFFFFFFF9F5F2F6FFFFFBF9FFFFF8FFFFFF
FFFFFFFFFFFEFBFFFFFEFAFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF6FFFAFEFCFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFEFFEFFF6FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF9FFFFFAFEDC22FFF9FEFFF8FFFAFFFFEFFFFDEAFFFF00E8FFFFF7FFFFF100FFFFF4FA
FFFFFDFEFEFEFBFFFF22D4F5FFFFFAFFC668F6FDFFFFFFFFFFFEFBFE1BE4FBFFFEFFFBFF
FFFCFCFFFDFBFFFFFF00FFFDF2FFFB04FFFFFFFFFFFFFFFFFCFFFFF5FFFD9B50FFFFF8C5
3E0095FFFFFFF6FAFFFFFFFFFFFFFFFFF655A4FFFFFFFFFFFFFFFFFFFFFFF9FFFFFE00FE
FCFF00EAFFFFED00FFFFFFFFFFFFFFFFFFFFFBEB16FEFAF0FBFFFCB581FDFFFDDDA1FFFF
FFFFFFFFFDFBF8F7F9FFFFFFFDFFFFFFFFFDFCFCFFFFFFFFFFFFFFFFFFF5FFF6FFF3FFFF
FFC03AF8FFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFAFCFFFF9D41FFECFFFFFF
FFFEFCF9ECFFF4FEF7F8FFFDFEFFFFFFFDFAFBFDFBF7FF2ED5F5FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF21DBF8FFF6FFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF3FD68A1F5FFFFFFFFFFFFFFFFEDFFFBEEFDFCF7FFFFF9FEF4B66D3D1F00000000
0936719CDCFFFFFBFFFFFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFEFFFFF8FFFCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFBFFFFFAFFF022E9FFFEFFF8FFF9FFF7FFFFFFFDFFF609FCFFFFFBFCF5FFFF00EEFFFF
FCF6FFFDFFFFF6FFE427FAFFFFF0FFF8FEFFFDFFFFF6F6FFFFF6F5FF3DBCFFFFFAFFFEFD
FBFFFFEBFBFFF5F9FF00F9FFFFE3FF00FFFFFFFFFFFFFFFFFFFAFFFCFFFF8196FDBE4602
000399FFFFF8F6FFFFEBF5FCF9FFF9F2FF8985F9FFFFFFFFFFFFFFFFF2FFFAFFEBF715F4
FFFF02FFF4FFFF0FFFFFFFFFFFFFFFFFFFFCF8D72AFFFFFFFFBD4A0658FFF6FFB145F5F7
FFFFFEF9FFFFFFFFFFFEFCFAFFFDF8F6FAFFFFFFFCFCFCFCFCFCFCFCE9FFFFFAF7FBFFFB
FF8779F3FFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFA34B5FFF9FFFD
FEFFF9FFFFF8FFFDFFFFF5F8FFFFFFFDFBFDFFFFF8FF8371F6FFFFF3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF53A7FEFFF6FDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFDFCFFFF90B1FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F7FCE067134B9ABDDBFFFFFFFF
F4C78C611652B6F7FAF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE9FD9FEF7FFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01F8FFFFF4FFFFF4FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFDFFFFF9FFFC55A7FFFFFFF9FFFBFFFFFFE8FFFFEFF500FFFFEFFFFFFFF5F501FFFFF1
FFFFFFF6F8FFFEFF9C57FFFFFFFFF6FAFAFFF3FFFFFFFFFFFFFFFFFF7A82FFFFF8FFFFFD
F8FEFFFFFFFFF3FFF700FFFFFCFFFA01FFFFFFFFFFFFFFFFFCFFFFF8F7FF4F6B45020006
000084B6B2C6C9BDB5C7D7C1BBC7BFBCCC784CFFFFFFFFFFFFFFFFFFFFFFF2EEFFF505FF
FFEF10FFFBFFF300FFFFFFFFFFFFFFFFF9FFFF9660FFF2C9480000095BF8FFFFC148FFFC
FFFFFFFDFCFEFFFFFFFFFEFCFFFFFFFFFFFFFBF4FFFFFFFFFFFFFFFFFFF3F7FFD2B4D3E1
FA62A6FCF9FCFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF9FFF2FFE53DE6FFE7FA
FFEEFFFFF8FFFCFFF6F8F5FFFFFFFEFCFFFFFFFFFFDE39DAFFFFE7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFA9B6BFEFFFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFFF8FFFFEFFAFFFFFFFFFFFFFFFFFFFEF3FFFFE9FDFFE75B3487F2F3F3FFFFFFFFF8F7
FCFFFFFCFFA53F55CEFFFEF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFA48BEFCF8FFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC4F8F2FBFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFCFFFFFAFFFFAC53FCFEFFFAFFFEFFEDFFFFF6FF00FF00F8FCFFFAFAFFF4FF00FCFBFF
FFF5FBFFF8FFFFFF4DAEFEF9FAF7FFFFFFFFEDFFFDFFFFF9F8FDFDF8C444F5FFFCFDFFFF
FFFFEFFFFFFBFFF1FF03FFF7FFFAFF00FFFFFFFFFFFFFFFFFCFCFFFAFFEF1A2502000600
000031414A3D3B38373E3B35413F3B353C4B1FF8FFFFFFFFFFFFFFFFFFFDFFFFF9FF00FF
FFFF00ECFFF2FF02FFFFFFFFFFFFFFFFFEFFF946BFCF5E000009100251BC956D6010837D
807F817E8A7B624B3E3B4045373B4144423B312A0101010101010101000D00013633499F
FD30D0FFFAFDFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFEF2FFFFF5A648FFFFF4
FFF6FCFCFAFFF6F8FFFFFFF2FFFFFDFCFFFFFEF4F42EDCFFF2F3FFF8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFCCB34F1FEFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7FAFFFFEFFFFFFFFFFFFFFFFFFCFFFFF5FFFFA12796FEFFF8FFFFF0FFF2FCFFFF
FEF9FCFFFFF5FFBA3868F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF35C3FEFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFFFDFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFCFFFBFCFFF017F5FEFFFAFFFFFFFFF9FFFCFFFF0006FFFBFF00FFFBFCFE06F9FFFF
F6FFFFFFFFFCFBF813FDFDFFFFFDFFFEFCF2FFFDFFFDFDFFFFFEFEFFF71CE6FFFFF9FFFF
F6FFF0FFFAFFF10DEF0EFCF8FF01FA03FFFFFFFFFFFFFFFFFFF7FFFFFBA354FD9D220C00
020C94FFFCF8FFFFFFFFFFFFFFF7FFFFFBFF4AA3FFFFFFFFFFFFFFFFFFF3FEFF00FA04FF
FBFF00FFFBFFF901FFFFFFFFFFFFFFFFFFF1F320E05100000D00010014496B8E6E527F7E
7C81808077859AB0BEC3C1BEC5C3BFBABAC2CFD9FEFEFEFEFEFEFEFEFFF8FFFDFFFFFFFA
FF00F6FEFFFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F1FFFFA046E5FF
E3FFFFFFF9FFFFFDFFF6FEFFFFFFFDFCFFFFF3E233CDFFFFFFFCFFFBFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFDB12E2F6FFFCFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF4FFFFF2D7F2FEFFFFFFFFFFFFFFFFF9FFF5FFFC7455F3FFF0F6FFFCF9FFFFFFFFFFFE
FFFFFFFFF0FFF0F3FF8545E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFD3AC9F9FFFDFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFCFFFAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFBFBF8FF0000FFFFF6FFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF8C74FDFFFFFAFFF3FCFFFAFFFFFFEC09FDFFFEF50B030004FEFFFFF9
F9FFFFFFFFFFFF6A93F4FFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA728FFFFFF8EFFF
FFFCFAFCFEFEFFFF0003F8FFF9F40D00FAFFFFFFFEFFFFFFFFFFFFFFFA4AB2FFF9FEA227
0000B2F2FFFFFFFFFFFFFFFFFFFCF1FFFFF2C83FFFFEFFFFFBFFF4FFFFEEFFFEFF0001FD
FCFF00FFFFFEFE00FFFEFFFFFCFFF6FFFAFF8F6CFFFED2520400000D59FBFFFFFEFEFFFF
F5FFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFDF5FFFBFF
D624FEFFFFFEFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9AF41D5
FCFEFDFFFFFFFFFAFDFFFCFFF5FCFFFFFFFBAD3BE2F3FFFFFCFDFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFB9B0C22000801423D4B5F74889FB7C7C5EFFFFFF9FDFFFFFFFFFDFA
FAFDFFFFFFFEFBFBFFFFFFFAFFFFFFFBFAFCFCFBFAFFFEFEFFFFFBFFFBF8FAFFFFFFFEFF
FFF7FFFFFF8CA3FFFFFBFFEEFFFFFFF4F2FFE8FF3D8CFFFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFBFFFFFEFEB740DEF1FFFDF8FFFFF7FBFFFFF3F7FFF5FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE9FE3FFFDFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF43E3FEFFFFF3FFFEFFFFFFFF
FFFFFFFFFCFFF3FFFFFFF202FFECF8FFFCFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF929DFFFFFFAFFFFFFFFFAF7FAFAFFE5FFF6FAFFF2FFFFFCFFF6F6FF
FFFBF3F5FAFFD81BFFFFDAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4ED26F1FFF6FFF2
FFFFFFFFFFFDFDFFFC06FFF0FFFFF509FFFFFFFBFBFDFDFCF2FFF7F8D83AFFF6FFFFFFF3
9D2798FFFFFFFFFFFFFFFFFFF5FFFFF7FAFFE74CCBECF2FFFCFFFEFAF8F8FFF4FFFF00FF
FFFFFF00000600FFFBFFF9FFFFFBFFFBFFD922EEF5FFEEF9DB6E02015FFFFFF6FFE4FFFF
F3FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFF4FF
C834FDFFFDFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD034
66D7FFF0FFF2F5FFFFFFF6FFFFFFFDFFCC4B55E4F4FEFFFFFCFDFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF91FDAFFF4FFC0C1B19B877460493A371500001E414A43837787B0
C7C8D8F5FCFFFFFFFEFEFFFFFBFEFFFFFFFFFFFFFAFFFFF9F9FFFFFAFFFFFFFDF9F9FDFF
FFF5FFFFF5F6FFF2FBF2D7FFFFF0FFFFFFEBFF3FB6FAFCFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFCFFFFF9FFFFD847F3F5F2FFFAF2FFFDF6FFFFFFFFF1F3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFBFFF8FFFCFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBBFFFFF2FFFFFFF2FFFFFFFF
FFFFFFFFFBFFFFEFF6FFFC03FAFFFFEFF8FFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF6B84AFFF4FFF3FFFAFFFDFFFFECF9FFF9FFFFF5FFF1F9FFFBFFFFFF
FEFFFFFFFFF650B8FAF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEE8676FFFFFFFF
FDFFFFFFFFFCFDFEFFFBFFFFF7FFECFAFFFEFCFFFFFFFFFFFFF4F4FF34B3FFFBFEFFFAFF
FFF1F3EEFFFFFFFFFFFFFFFFF5FFFFFBF9FFFFBF35FBFFEAFCF5FFFFFFF5F7FFF0F8FFE7
FDFCFDFFF8FFF1FCFCFEFFF0FFFCFDFAFF926CFBFFFAFFFFEAFFDF7364F8FFFDDFB0FFFD
FFFFFDFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FAFFF7EBFFFFFF
B44BFDFFFAFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFF3
9E1F6DBDFFFFFFFFF1F6FFFFDAEEAC3834ABFFFFFFFFFFFFFCFEFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFAFF2DD4F5FDFFFCFFFCF8FDFFFFFFFBFFFFFFFFF0CCB8B97E8B7D57
413E2B0D000F25374960747F91B0C1BFD3FBFFF7FFF4F8FFF8F0F8FBF0FFFFFFFFFFFFFD
FAFFF8F8FFFFFFFFFFC9016FECFFF5F0F5FF698FFBFFFFFAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF9FFFFEFF4FFFFB534FBFFF7F5FFF9FFFFFCFFF4FAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFBFFF8FFFCFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7E8FFFEFDFFF7FFFFFFFFFF
FFFFFFFFF9FFECFFF9FEFF00FFF4FAFFFAF3FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDF38083FFFFF8FFFFFFFAF7FFFFF1FDF8FFFAFCFFFFFAFFFDFFFFFD
FFFFFFF7FC8870FCFFF9FFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFF435D8FAF7FF
FBFEFFFDFDFFFFFCFEFFF7F5FFFFFFFFFDFAFDFFFFFFFEFFFFF0FFA742FFF6FFF6FDFEFF
F6FFFFFFFFFFFFFFFFFFFFFFFFFFF6FFFFF1FFFF50ABFFF3FFFFFFF5F5FFFFF0FFFBFFFF
FFFFF6FFFFFFF9FFFDFFF7FFEDFFF2FFDE16FFF7FFF2F8FAFFFDFCFFFAFFEEFFCBB6F7FB
FFFFFCF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEAFEFFFFFFFCFA
A45DFEFFF8FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFF2
EDC762470731618487868161160A4FC7FFFCF4F9FFFFFDFBFDFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF94AB8E9FFEAFFFCFEFFFFFDFBFCFDFFFAF9FFFAF1FCFFFCFDFFFF
FFFFFFFFFFF5E2CDBCAB97857F52404D3907001A452D4A79818FAFBBC2D8EAF0F9FFFFFF
FFFFF8FFFFC7DDFFF4CF00002399FFFFFF925DFFFFEEF9FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFAF1FCFFFFFFFFFCFF8F62F9FFFFECFFFEFFF4FFFFFFD806FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE9FE3FFFDFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FDFFF2FFFFFFFFFF
FFFFFFFFFDFFFFF4F7F8FF00FCF8FFF9FFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFCFFFC6099FFFFF6FFFBFFFDF9FFFFFFFFFFF3FFF8FFFAF7FCFFFFFE
F8F8FFFF9263FFFFF8FEFFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFCB42F8F7FF
FFFFFEFAFDFFFFFAF5FCFEFFF1FBFBFAFFFFFFFFFFFAFAFDFFFFD235F7FFF8FFFFFDF0FF
F9FFF0FFFFFFFFFFFFFFFFFFF9FFFAFAFFFFFDF3FA3FC2FFFFFDFCFEF1FFF4FFFFF8F4FE
F9EFFFFFFFF5FFF3FFF8FFF7F9FFFFE73CD8FFEFFFFFFFFFF1FFFFFFFBFFFFFCFDFCFFFA
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF2F8FEFD
A060FFFFF9FFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5F4FF
EB290FD7FEC5847D7970899433BDF9ECFFFFFBFFFDFBFAFDFFFFFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF5F63BBBFFFFFDF6FEFFFFFFFCFCFEFFFEFDFFFFFFFFFBF5FFFFFFFF
FFFEFDFDFFFFFFFCFEFFF9F0FFFFFDF6F5FCFFFED0C8C3A277766E434038210A0C25383A
46858374B1507DE2FCC3070004003CC0DB35F2F8FFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFDFDFFFFFFFFFDFFFF4DB8F6FFFFFAEEFFFFFFF6FFFF0BFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE9FE3FFFDFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF30FFFFFFFFF4F4FFFFFFFFFF
FFFFFFFFF7FFF7FFFBFEFF0BFEFFEEFEFFFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFCFF3B9CFCFFFFF7FFFFF6FCF6F5F7F4FFFFF4F6FFFFF9FFFFFB
FFFFE6AE61FFFFFDFFF0FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFB34EF2FE
FFFFFFFDFEFFFFF9FFF4FFFDFFFFFFF5FFFFFFFAFBFFFFFFFCDA2EE9FFFFFFFBECFFFFFF
F0FFFFFFFFFFFFFFFFFFFFFFF7FFFFF7FFFFFFF6F9E24AD4FEFAFFFFFFFBFFE9FFFDF9FF
FFFFF9FFEDFFF6FFFFE9F2FFFFE6FF4FAFF7FDFFFAFCF0FFFFFFF5F4F8FFFFFBFFFEFFFD
FCFEFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFEDFDF9FDFFFF
A955FFFCFEFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFE8F6
62000543EAFFFAFFFFFFFFFF3EC4FFFFFEFFF6FDFFFEFEFFFFFFFCFDFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF43BBFEECFFFFFFFDFAFDFFFFFFFDFBFFFFFEF4F8FFFFF2FFFFF3
F4FFFFFCF0FAFFFEFCFFFFFFFFFBFCFFFFFCF9FFF6FAFFFFF7FFFFF8FBFFFFFEF8EBD1B8
D48E7F7A830A372F1200000C040007052E90FFFFF3FFFFFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F4F9FAF4F6FAE62BF4FDFEFFFFFFF3FEFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFBFFF8FFFCFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF05FFEFEAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF9FBF9FF000000FFFFFFFFF3F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF9FCEEFF635FFFFCFDF3FFF7FFFFFFFFFBFDFCFFFFFFF9FFFEF9FD
FFE49141EEFFF2F6FFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFCF2FF9261EA
F0FEFFFFFDFFFFFCF5FFFFEAFFFCEFFFFFFFFFFAFFFFFFECE230D3FFFDFFF3FFFFFFF9FF
FFF9F9FFFFFFFFFFFFFFFFFFFFFCFFFFFBF9FFFFFAFEC937DAFFF5FCFAFFFFFFFAFFFEFE
F0FFFFFFFFECFFFFFBFFFDF3F6FF48A0F7FFFFE8FFF7FFEFFEFFFFFFFFF4FBFFDB9CFDFF
FFFFF6FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE76AC8FFFFFBF8
B743FFF9FFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FCFF99
000C000072F6FFF6F0F1FFFC43B3FFFFEDFFFFFAFFFFFFFFFFFCFBFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF736C3FFFFFEFEFEFEFFFFFFFFFCF7FEFDFAFBFFFFFFFAFFFAF8FF
FFF1F1FFFFFFFFFFFCFBFCFDEEFFFFF6F6FFFFEFFFF9FAFFFFF9F9FFFFFFFCFBFEFFFFFF
F4FAFEFFFB60A6FFF48908000403110915D7FFFFFEF8FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF4FFFFFFFFFFFFFFFFFFFF6796F6FFFFFEFDFFFFF9F4F90BFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFBFFF8FFFCFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00F3FFFFEFFFF5FFFFFFFFFF
FFFFFFFFFFFCFFFCFFFCFD0DFFFFF0FFFEFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEF8FFF5F79F36C0FFFFFFFCFFFCFBFAFFF7FDFDFFF4FFFFF6FFFF
AC5084FFFFF9FFFFFBFAFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2FFFFFCFCB338
DAF3FFFFFBFEFFFFFFFFFFFDFFFFFDFCFCFFFFFCFFFFE4BA2CD8FFFFFBFEFFFBFFFFFAFF
FFFFFFF8FFFFFFFFFFFFFFFFFFF8FDFFFFFFFEF4FFFFFFD634A7FFF9FEFFFCFBF8FBFFFF
FFFFEFFCFDFFFFFBFFFEFFFFCA40A2FFFFFEFCFEFFFAFFFFFFFAF5FDFFFBFFFFBE47F8FF
FFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFF1E0034BBFFFF
C236FFF7FFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC505
0502060000B1F4FFFFFBFFFF3FC3FDF6FFFFF3FFFFFDFDFFFEF9FCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF9FF26D9FFF6FFFBD9EAFDFFFDF9FEFFFFFFFFFFFFFEFFFFFEFFFFFF
FFFFFFFFFEFCFAFAFFFFFFF9FFFCFBFFFFFCFDFFFFFFFEFAFFFEFCFFFCFBFFFFFFFEFBFD
F9FFF4FCFF89ABFFFF86000000408F719AFCFFFFF7FFFFF5FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF9FAFFFEF8FFFBFFF5E527FFFFF6FFFAFEFCFFFFFA00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE9FE3FFFDFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FEFFFBFDFFFCFDFFFFFFFF
FFFFFFFFF7FFF6FDFFF3FE05FFF3FFFFFBFFFFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFCFFFFF0D73357B7FFFFF3FEFFFFFAFFF9FBFFFCFFFFFFB442
48BFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFCFFFFF3E2
368EE7FFFFFDFFFFFFFEFFFDFEFFFFFFFEFBFFFFF2D8754DFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFE5675BE4FFFFFFFFFFFFF9FF
F8FFFFFFF1FFFDFFFFFFF57F28D2FFFEFEFAFFFFFFFFF9FCFEFFFFFCFFFFFBFFC543FDFF
FCFFF6FFFFFFFFFDFCFEFFFFFFFFFBFBFFFFFFFDFDFDFDFDFDFDFDFDFEFF2203000045B7
D42EF7FFFFFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFAFAFFF9FFF6FEFFEFAD84
794D3F7E8387FFEFFFFDFFFD3BC9FAFFFFF6FDFFFFFFFFFFFFFFFFFFFEF6FFF9FFFAFAFC
FFFFFFFFFFFFFFFFFCF926DAFFFF923C03DCFFFAF7FDFFFCFCFFFFFFFBF3F8FFFFFDFAFC
FFFFFEFBFDFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFFFF9FDFFFFFFFFFFFEF9
FCFFF5FFFFF9FFFFF6670A6CD5F5FF1EF2F5FAFFFFFFFFFEFFFFFFFFFFFFFFFFFFF6FFFC
F7FFFAFFFFFFFFFFFFFFFFFFFFFFFFF725DFF5FFFFF1FFFFF5FBFF0000FBFFFDF5FFFFFF
FFFFFFFFFFFFFFFFFD3AC9F9FFFDFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBEFFFFFFFBFCFFFAFFFFFFFF
FFFFFFFFFFFFFFF8FFFFFBFEFDFFFFFAF6F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFBFFFFFDFFFFFCEEFFB744237AD5F5FEFBFFE7FFFFEAFBC865293EB5
FFFCF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFCFFFFFEF4
FF6D2889F8FFFAFFF7FFF9FFFFF8FFF6F9FFEDDD8D27A0FCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FEFFFFF89F2369DDFFFBFCF6FEFB
FFFFE8FFFFF7FAFFF4871E87FFFFF8FFFFF9FFF8F9FFFEFFFFF7F8FFFFF9FAFFB83AFFF5
FAFFFFF6F7FCFFFFFFFFF6F1FFFDFDFFFFF9DCC4C1C1C1C1C1C1C1C18383030F08000000
1E0EFEFCFFF3FFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FFFAFFFFF1FFFFFBF5FF
F57B79FFFDFFFFF8FF766C812F4D8A7FA9FFF7FAFFFFFFFFFFFFFFFFFFF1FFFFFAFFF6FF
FFFFFFFFFFFFFFFFFFEC08E86317100300F6FFF4FFFFF7FEFCFEFAF8FFFFFFF5FFFFFFFF
FFFFFFFEFFFEFEFFFFFFFEFCF3FFFFF2F1FFFFEEFCF5F6FFFFFCFEFFFEFFFFFCF7F9FFFF
FDFFFFEEFFFFFFF3FFC5DEFFFFFFBA35F9FBFEFFFFFFFFFDFFFFFFFFFFFFFFFFFBFEFFFF
FFFFFFF9FFFFFFFFFFFFFFFFFFFAFEFF7C89FFF9FFF0F8F9FFFFE915FF00FFFFFFF3FFFB
FFFFFFFFFFFFFFFFFF35C3FEFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFCFFFFF4FEFFFFFFFFFF
FFFFFFFFFFFFF8FFFEFFFBFEF0FFF2FFFFFAFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFAFFFFFDFCFFFFFFFFFFF2CC8B2D09303F3E875C3232083D92DAFFFF
F9FFFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFCFFFFFFFF
F6FFDF722B4FACEDFFF9FFF8F7FFF5FFF07E591979F7F8FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFF8FBFFFBA0193799D3FFFFF9
FFF8FFFDFDFF99582172EFEAF7F7FFFFFFFFFFFEFCFFFCFFFFFFFFFFF5FFFFF4DF95FCCD
BFADA28987755B443A3E4B5419110400000723393E3E3E3E3E3E3E3E7A78080100060E00
3B22D4FFFFFDFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4F2FFF0FFFDFFFF
FF7D7CFFFFFFF0F9F686000D0000001DD3F7FFFCFFFFFFFFFFFFFFFFF0FFF2F4FFFFFFFF
FFFFFFFFFFFFFFFFFF8710000000000017E9FFFCFFF5F0FFFFFEFBFFFBE9EFFFFBFDFEFF
FEFFFFFFFFFFFFFFFFFFFFFEFFF7F7FFFFFBFCFFFFFFFFFEFDFFFFFFFFFEFDFFFFFFFFFA
FFFBFFFFFFC4E7FFFFF2FFFFF2FA9180FFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFBF4FF
EAFDFFFDFFFFFFFFFFFFFFFFFFF6FEFFC045FFFAFAFFFFF7FFF6FFE7FCF8FFEFFFFAFFF7
FFFFFFFFFFFFFFFFFA48BEFCF8FFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFBEBFFFFF7FFFFFFFFFF
FFFFFFFFEEFFFFFFF5FFFFF7FFFFFBFDFFFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFFFFFBF8FCFFFFFBF4FFFFFFFFF6D3C5BA7EA4C9D1FFF7FDF8F5FA
FFFFFDF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFBFDFFFF
FFFFFEFCE2A2521B123A4269684037100E7AABFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF9F4FFFFFBFCF1FFC26A1B053A3C
60724C3B140F6BA4DEFFFFE8FFFBFBF9EFF2FFFFF7E5C0B3857F7D603B403E1602101930
435365757C8AA0B5C0C1BAB4D7EAFDFFFBF6FBFFFFFFFFFFFFFFFFFFFFFF2700020021AE
F151ACFCFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFF4FFF8FFFFFFFDFEFCED
FC8587F8FFFAFFFFFFFF5A00001700A2FFFAFBFFFFFFFFFFFFFFFFFFFFFFFFF8FFF4FFF3
FFFFFFFFFFFFFFFFF176020005170000000349452E83878096B1C5CFEDFFFFF8FFFFFFFF
FEFCFDFFFCFBF9FAFCFFFFFFFCFCFBFAFAFCFEFFFEFBFAFBFCFBFDFFFFFEFFFFFFFFFBF9
FEF0FFFFF396B8F7FFFFF7F8FAFA6E91FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF4FFF8FFFFFFFFFFFFFFFFFDFCFFF9CE35FAFFFEFFFFFCFFFDFCFFFFFFFFFDFBFFF5FF
FFFFFFFFFFFFFFFFFE9FD9FEF7FFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3CEBFFFFFFFBEEFFFFFFFFFF
FFFFFFFFFFFAFFF3FFFFEAFFF9F5FFFBEBFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFCFCFEFEFCFFF3FAFEF6FFFFF6FEF1FFFFFFFFF2FFFFFFFFFF
FFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFDFAFBFD
FAFFFFF9FFFFFFF7EBC3BB9495BDC5EDFFF9FCFFF5FAE7FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFF2FFFFFAFFF4FEF6FFFEB9C9
968BBDCEE9FFF1FFFAFFFDCDB8A08283634328090A2A4767937A94BEC1C9E3ECFEF0FBFF
FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEF7FEFEFEFEFEFEFEFEFAF41C1327A3FFF3
FF748DF4FFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAF7FFFFDFFFFFFBFFFF
FF747BFFFFFFFCEFFFFBDD27000079FFFFFFF6FFFFFFFFFFFFFFFFFFFFDFFFFFF7FAFAFF
FFFFFFFFFFFFFFFFFF758D860005000337FFB9C6CC7180735F4B3C2E0C00042F3542586F
879FB4C1CBEAFFFFFCEEF3FFFFFFFFFFFFFFFFFFFFF7F9FFFFFCFBFFF5FAFFFFF9F6FFFF
FFFFFFFFFFF9FFFFF7FFFDFFFFFE4AA7FFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFD030000
00FFF3FFFFFFFFFFFFFFFFFFF8FFFFFADD1FFBFFFFF4F9FFFFFFF0F3F0F9FAF3FFF9FFF6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC5FFF5FFF2FFFFF8FFFFFFFF
FFFFFFFFFFF9F9F8FFFFFFFFFFF3FFFFFFFFFEF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFDFFFFFFFFFDFFFFFCFFFFF5E8FFFFFFFFFBF9FDFCFFFFF6F2FC
FFFCFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFCFFFFFFFEFEFF
FFF8F9FFFFF8F7FFF6FFF7FFFFFAFFFBFFFFFFEFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF4FFFFFFF4FFFFFFFAFFFFF8FFEC
FFFFE0B8A37C6F333C0025403C8C7689B6C3E8FBFFFFF8F5FFECF5FFFDF7FFFFEC9AFFFF
F3FFFDF7FBFCFEFEFEFDFBFAFCFAF9FCFFFFFFFDFEFEFEFEFEFEFEFEFEFF4489F2FFF8FF
F7B43EFFF1FFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFF9FCF3FFF7FFFAFFFF
F6858CF5FEFFFFF7FFFDFFC70D34FBF6FCFDFFFDFFFFFFFFFFFFFFFFF7FFF3FCF9FFFCFF
FFFFFFFFFFFFFFFFF439CAF7E93B100042F9FAF0FFFFFFFFFFFFFFF7FFFFF6CEC6BCAA8F
7258453C3B140000284D53487C7284AEC8CCDFFDF8FFFFFAF8FFFFF1FFFFFEFFFFFFF5F1
F6FFF3F4FDFFFFF7FFF7FFF0F5FF3BD2FEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFF00FFFCFF
F200FAFFFFFFFFFFFFFFFFFFF9FFF4FFFE00FFFAFFF8FFFFEEFBFFFFFFFFFDFFFBFCF3FF
FFFFFFFFFFFFFFFFF6FFFAFEFCFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FCF6FFF2FFFFFCFFFFFFFF
FFFFFFFFF2FFFFFFF9FFFFEFF1FFFBFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2FFFFE7FBFFFFFEEEFEF8FFFFFCFFF9F4FFFFFF
FBFFFCEDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFCFFFFFFFFFF
FFFFFFFFFCFAFFFFFFF7FFF5F5FFF8FFFCFFFFFFFFEEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFEDF8FFFFFFFFFFEBB5AD8C4D59
17032C447286A4D0EDFFFBFCFFFFFFFFFFFDFFFAFAFFFDFFFDFFFFFCFBFFFFFAD699FFF7
FCFFFFFFFFFFFFFFFFFFFEFEFFFFFFFFF7F6FFFFFFFFFFFFFFFFFFFFF4FFEEFFFFFDF5FF
FDFB12FFF3FFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FDFFFFFDFFF8FFFEFFFEF7
FFE4E7FFFDFEFFFFF8FFECFF8BECFFFFFCFFF8FDFFFFFFFFFFFFFFFFFFF8FFFDFFFFFDF7
FFFFFFFFFFFFFFFFFA00FFFFEFFFA7275CFEFFFFF9F9F3FBFDF6FBFFFFF7F5FFFBFBFCFF
FFFFFFFFF7FFFFF6D8BEB2B2808A784D332E1C00002234324B7A8B7CBBB3BCD9F5FFFFFF
FFFFFFFFFFCEE3FFFFFFFFFAFFFF3FB7FEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FDFFEF
FF0FEFFFFFFFFFFFFFFFFFFFFDFFF6FFFD00FFFBFFFCFFFFFFFCFFEEF8FFF9E5FFFFFFFD
FFFFFFFFFFFFFFFFF2B7DFFEF8FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFBFFFFEFFFFFFFFFFF
FFFFFFFFFFFFFFEFFFF208040DF1FFFAFFF0FFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFBFCFFFFF5FFFFF8F7FFFEFFFFFFFAF8FFFFFDFFFAF5FF
FFFCFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF9FEFFFDFDFF
F9FBFEFFFFFFFDFDFFFFFFFFFFFEFFFBFFFDFAFFFAFFF8FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFBCA28C42310A1B516181B2B3
F0FBFFF8FFF9FFFCFFFAFFFFFEFFFEFAFFFBFFFFFFFFF8FBFCFFFDFBFFFFFBFFFAFFFFFD
FFF7FDFFFFFFFEFEFFFFFFFFF9FAFEFFFFFFFEFAFFFFFFFFFFFFFFFFFFEDFFFEFCF8FFFF
FDFF3DAFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFF5FBFF00FDF9FFFFFF
FFFFF9FEFDFFF5FFFFF0FFF0F8FFECFFFFF9FFFFFFFFFFFFFFFFFFFFFD00FFFBF5FFF9FF
FFFFFFFFFFFFFFFF966AFCF6FFFFF0F4C7FAF1FFF9FFFFF5FEFFFFFCFAFEFFFFFFFFFEFE
FFFFFCF9FFFFFFFEFDFDFFFFFCFDFFFFFFFFFFFFFFDDCACAB183738349443A2303001236
4242687D853F77BCCCFFF1FFFFF25FA6FFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFF08F8FFFF
ED09FBFFFFFFFFFFFFFFFFFFFFFCFFFBDD28F3FFFDFFFFFFFFF6FFFDFFF6FFFFFAF3FEFF
FFFFFFFFFFFFFFFFFF88DBFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF42FDFFF9FEFFFDFBFFFFFFFF
FFFFFFFFF5FFFFFFFE00FFFFFF00FFF8FFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFEFFFDFFFFFEF9F9FEFFFAFBFCFD
FDFFFFFFFEFFFFFAFFFFFFFBFFFFFEFFF7D9A9835C371314376795B1E2F3FFFFFCFDFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFF3
FFFFFEF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFBFFFEF7FAFFFFF2FFFFFFFFF3FD
FFCE6C6BF7FFFFFFFFFFFFFFFFFFFFFFF9FFFEF7FFFFFAFFFFFDFFF3FF0BF5FBFEFAFFFF
FFFFFEFFFFFDFFFFF7FFF3FFFFFFF9F7F4FFFFF9FFFEFEFCFAFFFFFCFBF50BFFF3FFFDFF
FBFFFEFFFDFCFFFC52ACFFFDFFFFF3FFF9FDFFFFFEF8FAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFFFEE6CA
BECA7E81891A2244310000004143688EF7FFFBFAFFFFECFFFFFFFFFFFFFFFFFF0107F7FF
F903F9FCFFFFFFFFFFFFFFFFFDFFF4FFBF3EFDFFFCFFF7FFFCF7FFF8FAFFF4FDFFFFEEFF
FFFFFFFFFFFFFFFFF9FFFAFFFEF4FFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00F1F4FDFFFFFCFFFFFFFFFF
FFFFFFFFFFFFFCFEF424EDF8FDFFF2F8F2FFFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFAFCFFFFFFFDFFFFFAFCFFFFFFFAFFFFFFFF
FFFFFCF6FEF2FCFFF8F5F4E4A37D45180F2E6188AECBF4FFFFFAF7FDF4FEFFFFFCFDFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDDA0FDF9
FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFAFAFFFFFFFFFDEDFF692F45141701
01016015FFFDFCF9FFFFFFFFFFFFFFFFF7FFF7FD06F5FFFDFDFAFFFF00F6FFFF0AFFF4FF
FFFD00FEFB0600EE00FF030000F6FF00FFFE00FFF800FFFF0200E404FFFFF600FFFFFAFD
FFFFFAFFFFFEF9EE17FFF9FFEFFCFFF9FDFDFBF9FEFFFFFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFCFFFFFFF6
F4FFFFFFF85FA0FFFFFFFFFAC0AD9B67FFFBFFFDFAFFFAFFFFFFFFFFFFFFFFFF00FF0100
09FFEDFFFFFFFFFFFFFFFFFFFEFDFFF3BD48FCFFFAFFFFF6F7FFFFFFF8F0FFFFECFFFFFF
FFFFFFFFFFFFFFFFFFEFFAFFFFF9FEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF02FFFFFFF9FCFDFFFFFFFFFF
FFFFFFFFEFFFF3F7FF000E02000EFFF2FFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFAF7FEFFF7FEFFFFFCFBFFFFFFFBF5F7
FEFFFFFFFFFBC79A7B41151C5B86C2F1FFFFF8F3F8FBFEFDF7F6FFFFFFFFFFFFFCFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC941FEFF
FCFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF8FAFCFAF7FFCC00070A0001
0D0FFF5B8EFFFFFFFFFFFFFFFFFFFFFFFCF9FFFF00FFF9FCFBFFFFF208FFFEF700FFFFF0
FFF20AF900FFFF020C00FEFFF70FF200FFFC01FFFF01FF04ECFF1406F7FEFF08F2FFFFFB
FFFDFEFEFFFEFF9073F3FBFFFFFCFFFFFFFFFFFCFFFFFFF9FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFBFAFFFFFF
FFFAFFFBFE93B6F2FFEFF8FFEFFFE227FFF5FFFFFBFFFFFCFFFFFFFFFFFFFFFF03FFF7FF
ECFFFFE7FFFFFFFFFFFFFFFFF8FFFFFB6894FFFFFFF8FAFBFFFFEDFDFFFFFFEFFFFFF0FF
FFFFFFFFFFFFFFFFFEA6E1F7FFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00EAFEFFFFFFFDF3FFFFFFFF
FFFFFFFFFFFFF9FFFE00FFFFFF00FFFCEEFCFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAF5F8FFFFFFFFFFFEFCFFFFFFFEF4FEFFFFFF
E2B37E5C170D38708FC6FFFFFFFDF8F5F7FDFFFFFFFEF9FFFFFFFDF1FFFFFDFBFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBF29FEFF
FFFDFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FF5F07000000
00C6FBDB24F7F1FDFFFFFFFFFFFFFFFFFFF7FFF114FFEAFFFFF8FAFF00FEFFFF00FFF7FF
FFFF00FF06F5FFFF03FFFFF007F9FA09FCF700FDFF07F300FFF9FF00FFFFFE00FFFAF8FF
FCFFFFF6FFFDF126A3838B7D7E73789FF9FFFFFFFFFDFDFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFBFCFDFB
F2F9FDF7F9FFFEFFFFF9FFFAFDFFF827D3FFF6FFFFFFFDFFFFFFFFFFFFFFFFFF06FFF3FF
FFF2F9FFFFFFFFFFFFFFFFFFFFFBFDFF10EDFCFFFEFDFFFFFAF4FFFF000805FFF2FFFFEF
FFFFFFFFFFFFFFFFFB52C1F7FFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFF4FBF9FFFFFFFFFFFF
FFFFFFFFE9FBFFF9FA05FFF6FF01FFFFFFF7FFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFDFFFFFDF6F2F6FFFFB991572A
234880AAECFFFEF4FFFFF1FCFFFFFFFFFFFFFCF4FFFFFCF8F8FCFFFFFDFBFAFDFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBC58F6FB
FFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F4FFFFFFF9F7FFF2F38500060C00
5EF3FFF96AB8F3FFFFFFFFFFFFFFFFFFFDFDFFFB00FFFFFFFFF8FAFF00FEFFFF08000B00
F5FD00F2FF00040000FB000AFFF7FF00FFFF0CFAFF07FFFF00020009FFFFFE00FFFAF8FF
FEFFFFFAFFFB9445010D0000000C0C94FFF8F9FFFFF9FBFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFE
FFFFFFFDF9FFFEF8F1F9FFFFFFF5FF896BFFFBFDFFFFF6FFFFFFFFFFFFFFFFFF00FCFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFEFFFBF39FFF2FFFDFFF6FCFFFFEE00FCFDF800FFF7F6FF
FFFFFFFFFFFFFFFFFF30B5FFFFFFFDFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2F3F6FFFDFCFFFFFFFFFF
FFFFFFFFFFFCFCFFF9FF000803FBFCF1FEFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5F7FBFEFFFEFCFAF7FEFDE7B46F2E064A70A9DB
F8FFFFFFFAF7FFFFF4FFFFF4FBFFFFFFFDFDFFFFF3FCFFFFFFFFFCF9FFFEFEFFFFFFFCFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD8B2FAF9
FFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFCFCFAFAFFFFF6D83F2B7A000021
F7FFFFF2E31BF3F7FFFFFFFFFFFFFFFFF9FFFFFF00FFFFF2FBFFFFF208FFFEF700FFFFF9
00FF00FF03FEFFFF1200F6F9FF00FF0C00EC00FFFF00FF00FFFFFC00F7FEFF08F2FFFFFB
FFFDFBFFFFD746CE5D00001000001AF7FFFFFAFEFFFEFCFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFBFEFFFFFF
FFE8FEFFFFD2DFFFFEFFF4FFFFFFFEDD34E0FFFFFCFFF9FFFFFFFFFFFFFFFFFFFF020000
00FDFFF7FFFFFFFFFFFFFFFFFEF9FF4CAEFFFFFDF6FFFFFFF1FFFF01FFFFFFF6FFF2FFFF
FFFFFFFFFFFFFFFFFF4DBCFFFBFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFFFBFFF9FFFFFFFFFFFF
FFFFFFFFFDFCFFF4FEFFFAFAFEFBFFFFFFF4FAF2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FCFFFFEAD07D4C1A1A509AD2ECFFFFFFFF
FFFFFEFFFEFFFFF5FFFFFCFFFBFFFFFFFAF7FAFFFFFFFCF7FBFFFFFFFFFFFFFFFFFCFBFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAF5FFFF
FFFFFAFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFFFFFFFF9E26406A3FDF8300E9F
F7FFFBFCFF8C63FFFFFFFFFFFFFFFFFFFFFBF7EB0DF5FAFFFDFAFFFF00F6FFFF00FFDEFF
07FC00F4F6000002ECFF000500FFFC00FF14040000FFFFFD000500FFFFFFF600FFFFFAFD
FFF7FFFFEF8282FFFE310700030856FEF0FFFFFFFDFFFFF9FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFBFCFCFCFC
FFFEFFFFE799B4F7FEFFFFFFFAF6FFFF817FF7FFF9FFFFFEFFFFFFFFFFFFFFFFFFEFFFFF
FBFFEDFFFFFFFFFFFFFFFFFFF4FFB658F0FFFFF4FFFBF5FFFFFBFC000000090BF1FFFFF9
FFFFFFFFFFFFFFFFF7A2DAFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF43F0FFFFF9FFFFF4FFFFFFFF
FFFFFFFFFFFCFDF8FFFAFFFFFFFFF6FCFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFCE7D3D282D82B0E8FFFFFAFDFFFFFFFEFE
FFFFFFFFFEF7FEFFFFF9FCFFFFFEFDFFFFFFFFFFFAFFFFFDFAFEFFFFFFFDFDFFFEF9FCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFF
F5FFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFDF8FFF08A1976E9FFFFF9BD54FF
FFFCFFF8FCF13DCDFFFFFFFFFFFFFFFFFCFBFFFF00FFF9FFFFFDFFF3FF0BF5FB05F0FFFF
00F909FFFBFFFDF1FFFCFFF9FFFBFDFFFDE2FFF6FFF9F2FFEEFFFFF9FBF50BFFF3FFFDFF
FFF6FFF6D532FEF5F8E01D0000163924A5E1FFFFF4FFFFFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FBFFFFFFFFFFFF
FCFFE9FFFFFFF8FFFFF4FFF2FFFBFFF7F92BD7FFFFFCFFFEFFFFFFFFFFFFFFFFFAFFFFF1
FFF7FFFAFFFFFFFFFFFFFFFFFFF238CEF9FFF0FFFFFFFFF6FFFFF906FFFFFF00FFFFFCFF
FFFFFFFFFFFFFFFFFFFAFFFEFEFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC5F9FFFDFFFCFFFBFFFFFFFF
FFFFFFFFF4FFFFFBFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFEFEFEFB
FFFDFBFFFFF8F8FFFDFDFEFFFFF8EADF8C521C236AC0F7FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE490FFFE
FFFFFFFEFFFFFFFFFFFFFFFFFFFCFBFBFFFFFFFDFFF8FFFFAB2F53D2FFFDFFFFFFF7F8FF
FFFAFFF6FFFFA556FFFCFCFFF3FFF1FFFFF902FF00FEFFF9FFF9FFF5FBFF00FD05001200
F4FC00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF809FFF5FDFFF7FF
FEFFF8FB4AB8FFFCFFF7BC0A0077FFB63E3279E7FFFCFBFFFAFFFDFAFFFFF7FFFFFDFDFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFEFFFFFCFBFFFFFFFFFFFFFFFFFFFDBD45F9FFECFFFDFEFEFFFFF4FEFFFEFFFFFFF8
F9FFFFFCF7FFFFFDFFFAFDFEFF7C85FAFFF7FFFAF6FFF0FFFAFFF10DFEF6FF00F9FFFFFB
FFFFFFFFFFFFFFFFFFFBF9FCFFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEF8FFFFFFEFFAFFFFFFFFFF
FFFFFFFFFFFFF9F6FAFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF8FBFFFFFEF9
F1FDFFFBFBFFFFFFFFFFFCD89C5C2B1277A9E7FFFFFCF3F2FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD8BAF6F9
FEFFFDFDFFFFFFFFFFFFFFFFEBFFFFFFFFFCFFFFF7FFD64826A9FFFFFFFEF9F8FDFFFFFF
FFFDFFFFEAFFFF4C9AF8FFFFF7FDFFF2FEFFFF0008FFFBFFF7FDFFFFFDFFF8FFF4EFF8FC
FFFFFDFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFF1FCFFF8
F7FFFF9C5FFBF9FCFFF9FF991BE6E6FFF9CB571E75E0FFFFFFECFCFFFFFEFFFFFFFFFFFD
F5F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9FFF9F6FFDEEFF8FFFFFFFFFFFFFFFFF6FFAF55FFFFFFFFFEFBFEFFFFFFFFF8F6FBFFFF
FFFFFFFDFFFFFFFCF9FFF3FF9752FFFFDCFFEFFFFFFFEFFFFFFBFFF1040000FFFCEAFFFB
FFFFFFFFFFFFFFFFFE9DE6FFF7FFFAFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFDFFFFF8FFFFFFFF
FFFFFFFFFFFBFAFFFFF2FFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBF8FFFFF7FBFF
FFFFFFFFFAFFFFFAC37C2F1F56A8E6FFFFFDF9F9FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FBFEFF
FCFFFBFFFFFFFFFFFFFFFFFFFFEAFFFEF2FFFBEDF1861C77FDFFFFF9F5FFFFFFFFFBF7F2
FFF0FFFFFCFFC12D44E6F4F5FFFAFFF9EFFFFFF711FCF7FFFFFCFFF9FCF3FFF7FFFFFFFE
FEF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFAF8FF
FFEEE244D4FFF6FFFCFFFFF9A3FFFBFFFFFFFED25F155DD9FBFFFFF3F4FCFAF5EEF8FEFE
FFFFFFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF5FFFFFB5A9AFFFFFFFFFFFFFFFFFFFFFFF17E7FEAFFEFFFFFFEFFFFF8F2FDFFFFFFFF
FDF8F8FBFFEFFFFFFBF3FFAB56FFF3F5FFEDFFFFF8FEFFFFFFFFF3FFFFFFFCFCFFFFFFF9
FFFFFFFFFFFFFFFFFD99E6FFEFFFF7FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF49F1FFFFF7FFFFF7FFFFFFFF
FFFFFFFFFFFCFCFFFDFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFCFEFFFFF3
FFEDEAFEFDC05D143878C9FBFFFBFAFFFFFFFFFFFFFCF8F5FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFF
F8FFFCFFFFFFFFFFFFFFFFFFFEFFFAFFFFF8FEC20C4FE7FFF7FFF9FDFFFFFFFEFCFFFFFF
FDFFFEF8EC5808B3C63CF5F8FFFFF6FFFFF9FEFFF0FFECFFFFFAFAF7FFFFDFFFFFE9F8FA
FFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFBFDFEFFF8FFF5
FFED45CEF6FFF9FFFFFFECFFFFF6FFF4FBF1FFFFFFE589134FC5FFFFFFFFFEFFFFFFFEFC
FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFEFF56A2FBFFFFFFFFFFFFFFFFF6FFFFEE7562ECFFF9FFFBEAFBFFFFFFFFFDFDFF
FFFCFFFFF7FFFCFAFFFF7954E5FDFFF9EEFFFFF5FBFFFFEBFBFFF5F9F6FFFFFFFBFFE7FF
FFFFFFFFFFFFFFFFFDFFFAFCFCFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFF5FFFFFAFCFFFFFFFFFF
FFFFFFFFFBFFFFEBFBFFF5F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FCFFFEF6F3FCFF
FBF3B0420B3D9FE2F2F7FCFEFDFDFFFFF9FFFFFFFBF8FDFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE596FFFF
F4FDFCFFFFFFFFFFFFFFFFFFE8FFFFF2FFCE322AD4FFF5F9FFFBFFFFFFFAF3FCFFFFFBFB
EBFFF682146FFFF3FFAC4CFFF7E9FFF9FFFBFFE5FFFFFFF9F3FFF4FFF8FFFFFFFCFFFFFF
FBF6FFF2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFF9FFF7FF
E25CB5FAFFFEFBFFFFFFFBFFF7FFEDFFFFFFF4EAFFFFEDEB892534B5FFFFFBFDFAF9FEFF
FCF2F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFFFFF4FF64ADF4FFFFFFFFFFFFFFFFFFFFF5FFFFB127CEF8FFFFFFFFF8EEFBFFFFFFFF
FFFEFBFDFFFEF2FDE24780FBFFFFF7F8FFF9F4FFFFFCFCFFFDFBFFFFFFFEFFF5FFF5FFF3
FFFFFFFFFFFFFFFFFDFFF9F9FFF9FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFF4FFF8FFFFFFFFFFFFFF
FFFFFFFFF8FEFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFF9FFFFEC9F
401F45B7FFFBEFFFFFFFFFFFFFFDFAF9FFFAF4F8FFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBF43FCFF
FCFFFBFFFFFFFFFFFFFFFFFFFFFBF3EC6B1490FFFFE2FFFFF7FFFAFFFDFDFFFFFFFFFFFF
FFB12848E0FFEBFFFFFF9B5BF9FFFFFDEBFFF6FFFDE2FFFAFFFFFFFFF4F2FFF0ECFFF9F2
FFFDFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE5FFFAFFFFFAF5
6D9AF7FFFBF2FFFFFFFBFFFFF7FFECFFF3FFFFFFFFFFFFFFFFF7A32F2CA5FCF9FFFFFDFF
FFFFFAFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF7EB6FEFFFFFFFFFFFFFFFFFEFFFFF8FFF4E22E5CC1FFFFF5FFFFFFFDFDF9F6
F9FFFFFFFDFAEA8120ADFDFDFBFFF5FFFFF9FFFDFFFBFAFFFFF2FFF0FFF5F7F2FFFFE7FF
FFFFFFFFFFFFFFFFFCA1DBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00F2FFFFF6F8FFFFFFFFFFFF
FFFFFFFFFFFFEFFFFFFBFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F8FAB0422147
B7EEFFF5E8FCFFFFFFFFFCFAFAFDFFFFFBFFFFFFFDFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBB3CFFFF
FFFFFAFFFFFFFFFFFFFFFFFFFFFA8B186DF2FDF6FDFFFBF7FFF4FEFFFFFFFFFAFCFFFBE6
3F2AAEFEF5FFFFFCFFEFFF7582FFFDFDFFFBFDFEF4FFFFFAFFF6FFFAFFFFF1FFFFEFFFFE
FFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFF9FF71
7FF8FFFFF0FFF0FFFDFFFFF5FFF7FFF9FFEDF7FFF4F8FFF7FFFEF8F6B63D3097F0FCFFFB
FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFCF4FFFBFFFAFFFFFFFFFFFFFFFFFFFFEAFFECFEFFFA9B4641A9FBFEF2F8FFFFFFFD
FFFFFFF4C95B227FFFFFFFFFFFFEF6FFFBFBFFF1FFFFF9F6FAFFFFFDFFFFFFFFF9FBFFF1
FFFFFFFFFFFFFFFFFE42C5FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBEFEFCF5FFFFF6FFFFFFFFFF
FFFFFFFFF6FFF0FFFAFFF10DFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9D3751E309AEBFA
FDFBFEFFFFFFFBF8FEFEFFFFFFFFFFFFFDFDFEFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBE4CFAFD
F8FFF7FFFFFFFFFFFFFFFFFFB43041D0FFF7FFFFFFF7FDFBFFFFFFF7FDFFFDFAFFF0850F
83EBFFFFFFF7FFFFFFFFF7FF6981FAFFFFFFFCFFFFFAFAFFFCFAFAFFF9FFF6FEFAFCFFFE
FFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FFFCFCFE856C
FFFFFCF8FFFFFFF5FBFFFFFFFFF7FFFEFBFFFFFAFFFFFAFFFDFFFFFDF9F9B74F1C88EDFF
FAFBFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFBF6FFFFFDFBFFFFFFFFFFFFFFFFFFFFF3FFF7FFFFF8FFFFF5B94F0F3B7C89AFBEBFAB
967945133BA4F9FFF6FEFAFFFEFFFFF8FCFFF8FFF4FFFFFBFFFFF3FFFFF8FFFCFFF0FEFF
FFFFFFFFFFFFFFFFFF3CC3FEFFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FFF0FFFFFFFFFFFFFFFF
FFFFFFFFFFFEFFFFFDFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFCFFFFFDFDFFF5F7FBFFFFF2FFEE9D282764CFFFFDF6FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDCA2FEF6
FDFFFFF8FBFFF5FFFFFFDE51249FFFFFF9FFFFF7FFFFFFFEFFFFF3FEFFF7FFFFA52A54D8
FFFFFFFFFFFFFFFFFFF1FFFFEC7F4CF4FFFFFBFFFDFCFFF1F7FFFFFDFAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFFEAFFFEFF446FFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD05F1868
E7FFF3FFFCFFFFFFFEFAFDFFFFFFF9F9FFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFBFBFFC9EAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF6FFFFFCC47E7B35103D42
7F86A1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FDFFF7F6FFFCFFFFFFFBFFF7FAFF
FFFFFFFFFFFFFFFFFF42B5FFFFFCFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFF8FBFFFFFFFF
FFFFFFFFFFFEFFFFFDFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FEFFF5FFFFFFF2F6F479163BB8E9FFFFF8FEFFF7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFCFF
FFFDFDFFFFEEFFFDE67B0589F4FEFFFCFAFFFFFEEFFFF7F6FCF7FFFFFFFFD0482BADFFFF
FFFFFFFFFFFFFFFFF5FFFFFCFCFAB52BC9FFFFFBFFF5F6FFFFFFF6FEFFFFFEFCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2FFFEF5FFFFFCF6F9FFF4CB30BCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F7DD6A
0F67EBFEFFF7FAFFFFFFFFEEFEF0FFFFE9FCFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDF4FDFFEF95BAF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FDFFFDFD9775FBFE
F8FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFDF3FFFFFFFFFEEAFFF4FFFFFFF4
FFFFFFFFFFFFFFFFFF9AD9FFF8FDFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF46E3F8FFF6F8FFFFFFFFFFFF
FFFFFFFFFFFEFFFFFDFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFEFCFAFEF7CF5A0559E2FFF5FFFFFFF6FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFF
EDFAFFF0F9FFF7AA1F4EFDF5FFFCFAFFFFFCF8FCFFEDFFFFF4FFFFF1FD861779FFFFFFF8
FFFFFFFFFFFFFFFFFFFFF0FFFFF6FFE02D76F9FFEEFFFFFEF5FEFFFAFAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFEFFFFFFFFF9F8A935DEEDFFF9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FF
EE5D105CD0FCFFFAFFF8F6FFFFF0F0FFFFFBFDFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFCF9FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBF5FEFFFCFFFFA34EFFFF
FFEFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFFF9FFFEF2F912FEF9FFFFF3FAFF
FFFFFFFFFFFFFFFFFFF8FFFFF6FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBBFFFFFFF2FFFFF9FFFFFFFF
FFFFFFFFFFFEFFFFFDFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFEAFFFFE8FFFFC43F1B8DF5FFF6F4FFF2ECFAFFFFFDFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCDADFFF7
FFFFF5FFFFD74032C0FEF4FFF4FFFFFEF8FBFFFFF8FDF4FFFDF6FCAF0750EBFFF2FBF6FE
FFFFFFFFFFFFFFFFF2FFFEF6FFF89224022668FFFFE5FBFFFBFFFFFFFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFEF6F8FAFF5764E5FFFFFFFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFF
F9FFF0921A50BFFFFFFFFFF2F0FFFFF5FFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9FFFFF4F1FAFFF2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FFFFF9FDFA9A68FBFF
EEFFF9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFEFFF7FEFFFF00FFFAFFF6FFFFF5
FFFFFFFFFFFFFFFFFFF2FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAF7FFFFEFF7FFFFFFFFFF
FFFFFFFFFFFEFFFFFDFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFFFFF8FFFFC03714A2F1F2FFFFFAFFFEFFFFFFFEFFFFF9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEC9AF8FB
F9FDFDE767208BEFFFFFF6FFFFFFFFF7F9FFFFFAFFFFFFF4FFDE4124C6FFFDF3FFF9FFFF
FFFFFFFFFFFFFFFFFFFFFFD76819040305DD932398FFF9FFFFF9F4FFFFFDFAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4FCFFFFFFFFF3AC2801B8FFEFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFFEE
F8FFFAF9FF961E2AA9F7FCFFFFFAF4FAFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF1F7FFFFD7E9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFECFFFFF9FEFFFFF9A251F7FA
FFF9F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2FEFFFEFEFF00FF01FFFFFBF0FFFF
FFFFFFFFFFFFFFFFF4ABE0EEFFFCFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBF9FFFFFFFAFFFFFFFF
FFFFFFFFFFFEFFFFFDFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF6FFFFD2520BAAFFF6FFFFFFFCFFF6F4FFFFFAF8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEF7FFFF
FFFFAA1265DAFFFFFFF0FFFFF4F5FAFFFFFFFDF8FFF6F7EE62088BFFFCE4FFFFF5FFFFF8
FFFFFFFFFFFFFFFFFFD347070500060011FFFFE6591EA5F9F6FFFFFAF8FFFFF9FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF7FF932F4DDCDD0EB9FFFDF6FD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFAFF
FFFFFAFFFEFEFCB2392B9FFFFEFFFCFAFFFCEDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFE96198F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FBFDF5FFA75EFFF7
FFFDFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE4FFF3FFFFE818FB00FEF8F5FFFCFF
FFFFFFFFFFFFFFFFFFA6E3F5FFFBF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3DF4FFFFF8FFFFF7FFFFFFFF
FFFFFFFFFFFEFFFFFDFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF6F86D0A96FFF3F3FFFEF7FDFFFFFDFFFEF8FFFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FA
BC2C2EE1FFFFF9FCFFFFFFFFFFFFFFFFFBF5FDFFF7FFA1286FE8F6FFFFFFF7F8FFFBFFFE
FFFFFFFFFFFFFFFFFCED62000000000B68FFF5F6FFD86538BCE8FFFFFCFFFFF4FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F5FFB72452E5FFFFFCB215D0FBFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
EEFEFFF5FFFFFFFFF8B44D0E8CEDFFF5F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFFF1F5FF6CABF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBF3FFFFF48A000000030A00
0EEDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEAFFE0FFFF00FB02FFFDFEFFF9F5
FFFFFFFFFFFFFFFFFFE5FEFFFFFDFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFAFFF2FFFFFFFFFFFFFF
FFFFFFFFFFFEFFFFFDFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAE2564E5F8FFFDFFFFFFFFFEF9F9FFF9FFFFFDFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD3AAE15F
2BA2FFF2F9FCFFFFFCFFFFFCFAFDFDFBFDFFFFFCC63C35BDFFFBFFFFFFF3FDFFFFFFFAFF
FFFFFFFFFFFFFFFFFBFFFF700009000096FFFBFFF8FFF0D4444886E6FFF8F1FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF096304ED4FFFCFDF9FFFFB41EC3FFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFCFE
FFFFFCFFFDFFFFFCFEFFF9D64E1B70F4FFFAFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFFFAFDFF4EA3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFF5FFCC1A0102000100
9DFFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFCFFFFFFFF00FFFDFB00FFFFFFFFFF
FFFFFFFFFFFFFFFFF3FFFFFBF7FBFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFF6FEFCF5FFFBFFFFFFFF
FFFFFFFFFEFFFDFFFEFFFFFFFAF8FFFFF8FFFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF6FFFFFFFEFFFFFFFFFFFFF8FCFFFFF8FAFCFEFFFFFEFBFAFFF8FAFF
FFFBFAFFFBFCFFFFFBFFFFFF791AA9FFEAFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8FFFFF0FFFFFEFFFDFEFFFFFDFCFBFFFFFFFFFBFAFFFAFFFDF7FFFFFFFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFF6FCFFFFFFFEFEFFFFFFFDF9FCFF
FBFFFFF8F5FFFFF5FFF6FFFDF8FFFAFFFFFCFFFFFBF8FFFFFDFEFFFAFEFFFFFFB91C1280
EAFFFEFEFFF7FDFFFDF9FFFCFEFFF4FFFFFFE76E2191F5FFFBFFFFFDFFFFFFFFFFFFFFFF
FDFFFFF3FFFFEFFFFDFFF0B22102000ADFF4FFFFFAEFFFFE65565615298FC0FFFAFFFFFF
FBFBFBFFFCFFF3FFFCFFFFFAFDFFF7F7FFCA74330E1FB4FFF9FCF7FFFFF5FFFF9923E2F8
F8FFFEFFFFF9FFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFD9621964E2FFFAFDFFFFFBFFFEF9FFFFFFFEFFFFFFFFFF
FFF5FFFFF38FB8FAFFFFFFFFFFFFFFFFFFFBFFFFFCFFFFFFFFF2FCFFFDFF6C0201000011
FCFFFDFAFFF6FFFFF9FAFFFDFFFFFFFFFFFFFFFFFFF9FFF5FBFF00FDFFFA00FFFAFAFFEC
FFFFFFFFFFFFFFFFFD99DDFAFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00F4FFFEFFFFF7FDFFFFFFFF
FFFFFFFFFFFCF7FFFFF4F3FEFFFFFAF6FFECFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFBF8FAFCFCF3F2FCFFFFFAF7FFFFFFFFFDFCFEFFFFFFFFFFF1
F4FFFFF7FFFAFDFFFFF3E23248F0FFF6FFFFF4FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFBF5FFFFFFFDF7FFFDFFFFF6FDFFFFFFFFF6F1FAFFFFFFFFFFFFFFFFF6F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FFFEF6F8FFFFF9F9FFFFF7
FEFDF8FFFFFFF5FFEFFFFFFFFFF9FFF3FBFFFCF4FFFFFCF6FFFFFFFFFFFFF0A71C20D0FF
FFF8FFFFFFFDF3F6FFFFFFFFFEF7FFF1EDA01567EFFFFFFAF8FFFFFFFFFFFFFFFFFFFFFF
FAFEF7FFF9F8FFFFFFFCE21EC3CA0A1BFCFFF1F1F5FFF28D33DDFFFCD87A35146699D6F8
FFFFC5BAFDF6F8FFF7F9FFFFFFAEAF71152E9BC4F904003A99FFE9FFF3FBF9FFFF8B1DE9
FFFFF9FEE3FFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF6FAFFDE711855DBFFF1FDFFF5FFFFF8FDFFFFF6F7FFFDED
FBFFF4FBFFFFFFFFFFFFFFFFFFFFFFFFFBFFFCF5FFFFF9F3F9FFFFE8FFFFDE0C03100094
F6F8FFFFFFFEF9F7F9FFFFFEFFFFFFFFFFFFFFFFF7FDFFFFFDFFF8FFFBFFF8FFFAFCFFFF
FFFFFFFFFFFFFFFFFD55C6FCFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCBFFFAFEFFFFECFFFFFFFFFF
FFFFFFFFFCFFFFDBFFFFFFFDE7FCFFFFFCFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFCFDFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFEFEFEFDFDFDF9FFFF
FFF9F8FFFFFFFCF6FFD12485EDFFECFFFFEAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F4FDFDFFEFFFFFF9FFFBEEFFF7F0FFFFFAF7FFF8FFF6F6FAFAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFECFFECFFFDFFFFFFFEF9FAFFFAD7B3
B28285A6AEC3ECFFFFFFEEF0FFFFEEFFFFF5FFFFFFF4FDFFFFEFF5FFFFD5522E7E4DFAFF
FFF9FFF7EFFFFFF8FEFFF4F7FCFEFECE302EE0FFFFFEFDFFFFFFFCFCFFFFFFFFFFFFFFFF
FFFFFAFFF6FEFFF5FBEA0DA7FFECE87EFAFFF2FFFFFEBB21CBFFF8FFFFF6FFE39F643100
273D0F1B838390866E51322007005190EAFAE6FFF23800000B0683C7FFFFFEFFECFF8424
EBFFFFFFFFDFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF48F184DC2FFFEFFFFF6FDFAF9FFFFFFFAFFFF
F7FFFFFDF5F4FBFBFFFFFFFFFFFFFFFFFFF8FFFFFAECFCFFF9FFF2FFF5FFFF6D00001AFE
FBFFFFF5FFFBFFFFFFEEE7FFFFFFFFFFFFFFFFFFFFFCFFF9FCF3FFF7FFFAFFFCFFFFFAF5
FFFFFFFFFFFFFFFFFF2AB8FFFFFBFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFE5FFFFFAFFFFFFFF
FFFFFFFFF5FFFFFFFAF4FDFFFFFFECFFFFF2FCF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFCFAFDFFFFFFFFFFF3FFFFFEF5F9FFFEFFFFFFFFFFFFFFFFFFF9F8FE
FFFFFEFFFEFBFFF3D017B0F6FFFCFFFDF9FFFDFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEF5F8FFFFFDFFFFF6CBB59C7D92BCBED4FFF7E6FFFFFFFFFFFFFFFFF9FFFFF6FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFFF9F6FFFFFBE9B66221274F
517975594B3028478CEEF7FFF9FFFFFFFFFFFEF5FCFFFFF5F5FFFFFB701B89E6ED92F3FB
FFFAFFFFFFF9FEFFFDFFFFFFFFED5323A9FFFEF6FAFAFFFFFDF5FBFFFFFFFFFFFFFFFFFF
FFF9FFF4FEFFF3FFE92E87FFF1FFFFFFFFF5FFFFF3DE11B5FFF4FDFFFBFFFFFFFBFFF1FF
E2980702558B7A7088B4CEE0FF39C3FDF7FFFFF2FF8306050000000E6CFBFFFFFFFFEA7F
35E6FDF9FCFFECFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF6FFFFF8EEF6F68F2C37BBFFF3EFFFFFFFFCF3FBFFFFEB
FFF3F9FDFFD3EDFFFFFFFFFFFFFFFFFFF7FFFFFFFFFFFFEDFFE4FDFFFFFDFFDF100085FF
EFFFF9F4F4FFF9EDFEFFFFFFFFFFFFFFFFFFFFFFFFFAFAF7FFFFDFFFFFFFE2FFFFF7FFFF
FFFFFFFFFFFFFFFFFC4CBFFFFFFDFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE9FFFFFFFFFCFFFFFFFF
FFFFFFFFFFDFFFFFFCFBFFFDFBFCFFE9FFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFEFFFFFFFBFBFFFFFFFAFAFFFFE3BD91887F8297BCE3FCFFFFFFFF
FFFFFDFAFAFFFBDA1BAEFFFFEEFDFFF6FFFFECFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFFF6FAFFD7A04F0A354C64846E45422B2A5BABE3FBFCEEF2FFFFFFFDFBFCF8FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFEFFFFEFFFCEF822B45A3EBFFFB
FFF5FFFFFFFFF0A86C0E6BDFF3FFFBFEFDFFFAF4FFFAEEFFFFFDA11A53EBFFFFFFEFFFFF
FFFFFFFFFBF5F9FFFFFFFFF77E1971E2FFFFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFEEFFF4FFFAFFF84B66FFFFFFFBF2FFFBFFF5FFF41B97FFFFFEFFF9FFFFD9FFFDF9FFFF
F34107025DFFFFFDFEFFFCF7EC33DDFFFFFCEBF9FFBC02000A010A50FFFFFCFFFFF7FFFF
5B47ECFEF7FFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFCFFF8F5FFFFFAFFFBA92C29B3FFF2F8F9FFFFFFFBFFFF
FBF8FFFFEB8EB7F3FFFFFFFFFFFFFFFFF8FFFCEEFFFFF5FFFFFFFFFEB4C380933610A4CC
E6FFFFFFFAFFFFFFFFFEF9FFFFFFFFFFFFFFFFFFF3FFF4FFF8FFFFFFFFFBFFF3FFFEFFFF
FFFFFFFFFFFFFFFFF5A8DAFFF2FFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF44F5FFF6FFFFFFFCFFFFFFFF
FFFFFFFFF5FFEFFBFFFBFFF8FFF7F9FFECFDFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFEFFFFFDFEFFFFFFFEFFF6BF6725203A70777E7A6747250F60B4F5F8
F1FFFFFFFDFFE41BB7FCFFF9FFF5F2FFFFFEFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9FFFFE4661D6CADFFF3F9FFF2FDFFF9FFD2A05A2F80F0FFFFFFF4F9FFFCF8FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6EFFFF6F1FF801F7FE9FFFFF1F5FF
F4FFFFF4FFFCF6FFFFFBAD1870D5FFFFFFF0FFFFFFFFFFF2C14628C0FFF2F9F5FFFFFFF2
FBFFFFFCFFFFFFFCEFFFC02D55D1FFFFFCEAFFFFF2F8FEFFFFFFFFF5FFFFFFFFFFFFFFFF
FAFFFFF9FFFFFC5B51F6F8FFFDFFFFFDF8FDFFFB4173FFF8FFFFFAF0FBFFFFFEFFF3FFF5
CC090A0003C4FFFFFCFEF9FFFF23D8F7FEFFFFFFFBFF1001000061FFF3FFFEFFFDFFFFFA
FF6153F9FFFBF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFF8F8FDFBFFFCF9FBB42C249DFBF9FEFFFEF5FBFF
FFFFF1FEFFFFFFFFFFFFFFFFFFFFFFFFFFF6FFFFF2FFFFF3DC9A4C05484876726E4B582F
172978CDFEFFF7F4FDFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFF4F2FFF0FFF5FFEDFFFFFDF5
FFFFFFFFFFFFFFFFFFF7FEFFF0FFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB7FFFFF8FFF6FAFFFFFFFFFF
FFFFFFFFFFFEFFF8FBF2070800F8FFFEFFFBFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFCFFFFFBFFFFFFF0FD95373E91E0FFFFFDFEFFFFFFFDFAF79D4134A2
FFFFF0FCFFF05F73FFFFEAFFEDFFFFFBFFF7F8FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFE45D129DFFF3FFF8FFFFFEFFFFF9FFF6FFFDFFF0672274EDFFFFFAFFFFF7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFFFEBFF278CF9FDF7EEF7FFFFFF
FFF9FFFFFAFCFFFFFCFFE9FDA52DCAF9FFFFFFF8F6FFE0781298FFFFF8FFFEFFD3B4F6FB
FFFAF9FFF7FFF4FCF24E14B7FFFDF7F9FFFFFFF4FFFFFFFEF7F6FEFFFFFFFFFFFFFFFFFF
F9FFFFF8FFF49339F7FFFFFFF9F6FFFBFFF7FE534CFFF6FFFBFDFFFFF1F6FFF3F0FFF7FD
350000090065F5FFFFF9FEFFFF19EBFFF7F3FFFBFAFF4A0D006F29CAFAFFF2FFFFF4FFFE
F8F95346FEFFF2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF4FFFFFFFFFFFFFFFDFDFFFFFFFFCA421C89ECFFFFFFFFF5
FBFFFFFFFBF6FDFFFFFFFFFFFFFFFFFFF8F7FFFFFEFFD975246CA9F6FFE9FFFFFFF9F1FF
FFCE7B394AA9FFFFFDFFFFF8FFFFFFFFFFFFFFFFFFF6FFFAFFFFF1FFF8FFF6FFFFF1FFFF
FFFFFFFFFFFFFFFFFFEAFFFFF9FFF7FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFBFBFFF4FFFFFFFF
FFFFFFFFFEFEFFFFF807F9FDFF08F7FFFFF2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFCFFFFFBFFFFE8C11A70D2FFFFFFFFFFFDFEFFFFFFFEFCFBF8FFCE4F
38A3FDFFFFAA2DFFFCF5FFF7FFFDFAFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC20A0FFF2FFFFFAFFFDFFFFF8FAFFFFFFFEFFFAF9FFEC804BD4FFF9FEFFF8FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFEC530CAFBF8FEFFFFFFF9FAFF
FCFFFFFBFDFFFEFEF0FFFFFEFFE04796EDFFF5FAFF861868F0F7FCFFFEFCFFFEE19AFFF9
FFFFF9F9F9FFF980197AFDFCFFFFFFFFF9FDFEFFFFF8F9FFFFFFFFFFFFFFFFFFFFFFFFFF
FFF3FFFCFCBB1DD9F8FFF8FFFFFCFFFAFFF9943CF6FFFCFCFFFEF8FEFFFFFAFFFFF7FFAE
0C000D000002D5F5FFFCFDFFFA20E7FDFFFAFFFCFFF7A603BEFA9531F3F8FFF4FFF8F6FF
FFFFEC4E5EFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F8FFFAF3FFFDFFFAF8FFF9F9FFE159166FE1FFFDFF
FFF6FDF7FFD2EDFEFFFFFFFFFFFFFFFFF9FFEFF9FF6F1B95FAFAF9FFF2FFFFF5FAFFFFF9
FAFFFFF8BB4A45C1FFFFF3FFFFFFFFFFFFFFFFFFFCFAFAFFF9FFF6FEFFFEF2F8FFFEFFF6
FFFFFFFFFFFFFFFFF6A6E4F7FFFFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFDFFFFF6FEFFFFFFFFFF
FFFFFFFFFFF4F8FFF700FFF4F8FFFFF8FFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F9FEFF724FE8F4FFFFFFFCFFFFFFFFFFFFFFFFFFFFF9FFFFFF
D45D65FEFE4DA9FFFFEDFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2FFFFEFFF8E
4BD4FFF9FEFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC43DC7F2FFFFF6FFFFFFFFFF
FFFFFFFFFFF6FEFFFCFFFFFFF7FFF8FFF7FFFFF7FDFFFEBF32EDFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF9FFFAF5FFE76A8FF7FFC82A41D6F8FFFFF1FCF8FFF7FBFEFFFFFF
FFFEF5FFFF9F3250D5FFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFC
F3FFFFFFBD14D1FFFFF3FFF9F8FFFDFFFFB516D7FFFFF8FEFFFFFFFFFFFFFFFFF8FFFD2E
00040000000063E9FFF8FFFFFF00FFFEFFF7FFFFFCFDE3CDEFFFE48B39EEF8FFFFF4FFF7
FFECFFFE2D6BFFF7FFFCFFFFFDFBFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FBE4771A5CD8FF
F6FFE7FFFF639EFDFFF0FFF9F8FFEFFFFFFDFFD04C8AF3FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAB244A3FFFFF5FEFFF6FAFFFFF6FFF9FFF3FEFFFFF7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF6A6E4F7FFFFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FF3FFF4F9F9FFFCFFFFFFFF
FFFFFFFFEEFFFFFFF20A00041000FFFFF9FFFFEDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF8FFF8FFF04196F3F7FDFFFFFEFBFCFFFFFFFFFFFFFFFFFFFEFFF9F3
FFF29543E309F6F3FDFFFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2F3FF8068
EDFFFFFAFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD938D0F8F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFFFFFDEDFFFAF4F5FFFFFCD135FDE1FFF0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF5FFFFEFF9FFE94CAF5B23A8FCFFFFFAFEFDFFFFFCF5FFFFFFFDEC
FFFFFFEB5539A9FFF1ECFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFDFFFDFA
FFFFEEE726B6F7FAFFFFFCF9FFEBFFFFC309C8FFFAF7F6FFFFFFFFFFFFFFFFFFFFFFFFFF
FFF16C97FFF5FFFFFBFAFFF8FF00FFFEFFF8FFFFFFFFFFFFFFFFFFF86658FFF6FFFFF3FF
FFF4FFF1F43282FFFDFEFFFEF6FFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0EEF375185B
D2FFFFFFFF5A9AFFFCFEF8FFFFFFFEFFFEEEC64CB9FEFFF9FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFAFFFFE4567AFCFDF8F5FFFFFFF9FFFFFAFFFFFFEDF4FFE9FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFEAFFFFF9FFF7FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFF8FFF5FFFFFFFF
FFFFFFFFFFFAFAFFFF00FFFFF600FFFFFBF5FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF1FFFA28BAFFFFFFFFFFFFFDFCFEFFFFFFFFFFFFFFFFFFFBFFFFFD
F7FFFDB43748FCFFF9E7FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF1FFFFFFA157FF
FFFFF4F9FFFCF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEE536D9F8FFF0FFFFFFFF
FFFFFFFFFEFFFFFFFFFBF9FFFBFDFAFFFFFFF7FCFEF232D5FBFFF8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF6FFFFFDF8FFFFFD55B0F1FFFFE7FFFFFEFFF6FEF1FBF8EC85FFFF
FFF683007AECFFF4FFFFEDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFF7FBFFFFFF
FFFAEE3A86FCFFFDEDFFFFF3FEFFF7DF2E9AFFF1FFFBFFF4FFFFFFFFFFFFFFFFFCFFE6FF
FFFF57A7F4F7FFFBF5FFFFFAF806FFFFFFF9FFFEFFFAFBFFFFF8FEFFF34A57FFFBFFFFFB
FFFDFFFDFFF40E95FDFFF1FFF4FFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6E8FFFFECFFF982
1C46BEF7F65FA7F4FFF7F8FFF7FAFFFAFFC92DD6FFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF1FFFCFFF77768FFFFF4FFFFFFF6FFFBFFF1FBFFFFFFFA17FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7FEFFF0FFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFAFCFFFCFFFCFFFFFFFF
FFFFFFFFF5FFFBE8FF00F8FDFF03FEF2FFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEF942BEFFFFFAFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFF
F1EFFFFF8224F9FFFBFFFAFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FBBC49FCFF
F2FFFFFFFDFBFCF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFE149DDFFF5FFFFFFFF
FFFFFFFFF7FFF9FEFFFBFDFFF1FFFFF5F0FFFBFFFF43B1FFFFFCF4FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFCFFFFFBF2FED316F9FFF6FFFFFEFFFDFCFFFFFFFFC15BF1FF
AE0F5BF1FFFCFAFEF9FFFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5F8FFFEFCFE
F7FF4370FFFCFDFFFFF4FFFEF9FDEF3F7AFCFFFBFBFFFFFAFFFFFFFFFFFFFFFFFFFFFFF4
FBF761A0FFFFFFFFFFF9F7FFEF0EFFFFFFFBFFFEFFFFFDFAFFFFFEF2FFE94777FFFFEEFF
FEFFF6FFFFFCF31E92F5FFFFFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBF8FFFFF9FF
FF8E3638AE8FBCFFFBFFFFF9F2FFFFF3D13BE2FFFCF4FFF6FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE6FFFFFF6E7EF9FFF6F6FFFBFFFAFFF3FFFFFDFDFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF5A8DAFFF2FFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF18F0FFFEEFFFFFFEFFFFFFFF
FFFFFFFFFFFAFFFFF8FF000500FFEDFFF3FFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF9FE4FB8FCFDF4FFFFFDFDFEFFFFFFFFFFFFFFFFFFFFFFFFFFFCFEFF
FFFEFBF6FF9D60EEFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFEEA18F2FFE8
FFFFFFFFF9FFFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFFA566E4FFFFFFFFFF
FFFFFFFFFCFFFAFFFFFFFFFCFFFFFEFFFFFFF8FCA253FFF6FFFFFCF8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF8FFFFF5F8FFFEFEFFFF956EE7FFFFFAF8FFFDFCFFFDF6FFA146DC44
22B2FFF4FDF2FCFFFFFDFDFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFF6FFFFF8FCFA
FF7147F6FFFFF7FFFFFAFDF8FFE96456FFF3FFFDFFF7FDFFFFFFFFFFFFFFFFFFFEEAFFFF
FFFF6A97FFFAF2F9FFF9F9FFE617FEFFFFFDFFFDF8FFFFFFFDFFFFFCF0FFEB2A99FEFFF8
FBFFFFFEFFFFFFCE22B0EFFFFFF6F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE9FFFFF9FAFEFCFD
FFF9F7B0462092FFFDFDF8FFFFFBFFF83DD7FFFAF8FFF0FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF5FFF9F1F6FF5394FFFDF2FFFFFAFFFFFFFFFDFEF4FF0BFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC4CBFFFFFFDFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB5FFFFFFF8FFFAFFFFFFFFFF
FFFFFFFFF9F8FFF2FFFDFFF8F8FFFFFEFFF1FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF9462FFF6FFFDFFFEFEFFFFFFFFFEFCFFFFFFFFFFFFFFFFFBFFFFF8
FEFFFFFFFFE766A4EEFDF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDEFFF7895F9FFFF
FFF6F6FAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFF8FDFD4AC4F6FFFFFFFF
FFFFFFFFFFFFF9FFFFFEFFD8E6F9FFFDFAFAFFF53ADCEFFFFCF5FFF1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFAFFFFFEFFFDFCFFFFEEFC2FE6FCF8FBFFFFEB79F5FCFFE7D00E1C8A
FFFFFAFDFCFFFFFBF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFDF9FFFF
8228FFF2FFFCFFFFF5FFF1FCFF7F3EF3FBFFFAF7FFF1FFF9FFFFFFFFFFFFFFFFFFF7FFFF
F4FE629EF9FFFFFFFFFFFBFADD20FEFFFDFEFFFCFAFBFBFBFAF9FEFFFEFFEDE71DACFFF8
FFF1FFFFFBF3FFFFC312B5FAFEFEFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFAFFFFFAFBFF
F1FFFCF9FFC2581F8DF0FDF5F6FFF04AA3F7FFFFFBF6FFFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF5F7F9FFFAFFFFEC3FD7FFFBFDFFFBFFFFFFFBF8FFFFF600FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF2AB8FFFFFBFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEAFDFFFCF7FFFFFFFFFF
FFFFFFFFFFFFF8FFFFF5F3FCFFFCFFF6FAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF72CE9EDFFFEFFFBFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFCFAFF
FFFFFAF2F6FFDC31FAFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC432FBFFEBFB
FFFFFFFFFFF6F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFDFFFDFFD928F6FFFFFFFF
FFFFFFFFFEFFF8FFF8FCFFAD1686E6FFFFF7FF9565F5FFFFF7F8FDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF8F7FFFFFFFAF6F8FFFF9B55FFF0FFFFE67C01B1FFFCA90248EAFD
EDFEFFFFFFF7EBFBFFFFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FDF6FFFFAA
2ED5FFFFEFFFFFFEFFFEFFFFA21CEBFBFFE9FDFFF0FFF6FFFFFFFFFFFFFFFFFFF6FFFFFF
F6FF5AABFFFFFFF7F6FEFFFED726FDFFFCFFFFFCFFFFF9FFFFFFFFFFFFFFFFFCCF16BCFF
FAFFF2F7FFFFF0F4FFDA12B7FFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5F9FFFFFFFFFB
FFFFFCFFFEDBE0D6671280F3EBFCCF46FFFFFFFDFEFBFFF1FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF1FFF1FFFFF6FF836EFFFFF9FFFFFFFDFBFFF8FFFEFE10FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFD55C6FCFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FFFEFBFFFBFFFCFFFFFFFF
FFFFFFFFF8FFF9FFFFF1FFFFFCFFF2FFFFFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF7688FCFFF7FDFFFEFEFFFFFFFEFEFFFFFFFFFFFFFFFFFFFFFFF7FFFF
F6FBFFFDFDFEFF8175FDFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFC6098FFF9FFFF
FAFFFDF7FFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFBFF639FFFFFFFFF
FFFFFFFFFEFFFAFFF9FFFF970000137DE5FFFD50AFFFFFF3FFFFFFF9FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFCF7FFFFFFFFFFF3F21FEFFFEFFBDC000431C23932CEFBFCFF
FFFFFDFFF7FFFFFEF5FFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFAFFFFFFC718
C8FFF3FFFFFEFFFEFCF9FFC70DD8F7FFFFFFFFF9FFFFF9FEFFFFFFFFFFFFFFFFFEFDFFEE
FFF545B4FFF9FEFFFFFCFEFCD329FDFFFCFFFFFBF8FFFFFFFFFFFFFBFFFFF4FAFFB721CA
FFFBFFFDFFFBFDFFFFEEBE17CFFEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFFFFBFAFF
FCFFFFFFF78EB5FEF6E56E04EAFF1FCFFEFCFEFDFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF1FFF2FFFFF9FF1EDAFDFFFFFFFCFFF6FFFEF8FFF900FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFD99DDFAFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF41FDFFFFFFF4FFF8FFFFFFFF
FFFFFFFFFFF3FFFFF0FFF5FFFFF6FFFFFAF3FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFCFFFFFAFAFFEF13F2FEFFFDFFFFFFFDFFFFFFFFF6FFFDFFFDFFF2FFF3FFFEFFF3FFFF
FBFFFFF4FFF9FDF70FF7FCFFFFF6F9FFFDFCFAFFFEFFFFFFF9F7FDFFFFF40EF9FCFFF8FF
FFFFFFFFFFFFFFFFF8FFFDFCFFF7FEFFFCFDFAFFFFFFFFFAFFF9FFFFFFF9D22FFFEFFFFA
FEFFF6FFF8FFFFFFFDFFF1A1000208000F7EDD18FFFFFFFFFFFFFFFFFCFFF7FFFCF7FFF8
FCFEFFFFEFFFE7FFFFFFFAFDFFFFFFF9FFFCFFF73FC0FFF8FD18000900099CF8F5FFF5F9
FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFFFFFFFEFFFFF6FFFFDA20B0
FAFFF7FFFFF6FFFFFFF6F31AAAFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4FFFF
FAFC42C0FFFFFFFFFFFFFFFFC33DFFF7FFFCFCFFFFFFFFFFFFFFFFFFFFFBFFFCF6FFB81A
D9FFF9FFFFF9FDFEFDFFF5BD0BD6FFF6FCFFF7F9FFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFEFFFFFFFFBFDFFFFFAFFF5FFB94CFCFFFFFFFFFFFFFFFFFDFFFFFFFFF6FFFDFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFB24CF5FFF5F9FFFFF0FFFFF3FFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF3FFFFFBF7FBFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB0FBFFF6FFF9FFFFFFFFFFFF
FFFFFFFFFEFFFFFBFFE1FFFAF8FFF9E5FFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFAFFFFAA53FBFEFFFAFFFEFFFFFCFFFFFFFCFFEEF5FFFFFFFBFFFFF9FDFFFFFA
F6F9FFFFFDFFFFFF4DA6FBF7FEFFF2FFF8FFFFF8FBF7F4FAFFFFFFF7FEA954FEFFFFFCFF
FFFFFFFFFFFFFFFFFFF7FFFFF0FFFFFDFFFFF7FCFCFBF8FFFFFDFFFDFDFFE03BD8130011
000004000A00000000061600090400000E001F49FFFFFFFFFFFFFFFFFAFFFFF6F7FFFFFF
FFF7FFEAFFFFFFFFF5FFFFFFF8F9FFFFFCF8FFFFA156EEFF790A0600080FE6FFE99AFFFC
FFFCFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFDFAFFF7F7348DFE
FBFEFFFDFEFFE7FDFFFF188CFFF3FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FFFF
FBFF43BDFFFFFFFFFFFFFFFFBF40FFF8FFFCFDFFFFFFFFFFFFFFFFFFFCF9FFFFFBFFEF9E
31EBFDFEFEFFF7FFFFF1FFFF9827E0FFF9EBFFFFFCFFEFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFFFEF3FBFFFFF1FCFFFFFFFF4BA8FFFFFFFFFFFFFFFFFFFFFCFFFFFFFCFFEEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAF221F4F8FFFFFAFBF8FFECFFF3F7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE5FEFFFFFDFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4FFFFFFFEFFFFFFFF
FFFFFFFFFFF8FCFFF9FFF1FFFFFFFDFFFBFCF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFFFEFBFFFB51ABFFFEFFF6FFFCFFFFF8FFFFEEFBFFFFFFF2F4F8F7FFF7FFF0FFF2FF
FFFAFBFFFCFAF8FDAD52FFFFF5FFFFE9FFACF8FFFFFFFFFFFDFCFFFFFF4FACFDFFFFFFFD
FFFFFFFFFFFFFFFFEAFFF7FCFFFFE8FFFBE9FFFFFFFFFDF6FDFFFFF7FBFFF2579FFFFFF8
FFFFF7FFFEF9FFFFFBFCF2AB07000F01005E7672FFFFFFFFFFFFFFFFFFF8FAFBFFFFEDFD
FFFDFFFFF6EFFFF5FFFBF3F9FFFFFEF9FFFFFCEED631FFD10000010003025FF3ED88FFFE
FFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFEFFFFFFFFFEFEFFFFFFF24E67FFFF
F8FBFFF4FAF9FFF4FF4F69FFF9FFF4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFD
FDFF43BAFFFFFFFFFFFFFFFFB747FFF9FFFDFDFFFFFFFFFFFFFFFFFFFFFBFFFFFDFFFFFD
7E26FFF9FAFBFFFDF5FFF9FFFA9C24CDFFFFFFFFF5F2FFF7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFFFFCFE3FFFAFFFBFFEF11FFFDFFFFFFFFFFFFFFFFFFF8FFFFEEFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFF4DA9FFF4FFF3FFF8FCFFFAFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA6E3F5FFFBF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFBFFFFFCFAFFFFFFFF
FFFFFFFFF2FFFFFAFDEFF8FAF0F9FAF3FFF9FFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFCFFFEFCFFEF1DECFFFFFFF6FFF9FFFFF4F9FFFFFFF0F3FFFDFFF8FFFBFCFFFFFFFBFD
FFFCFCFFFFFFFFFFF916ECF8FFFCFFA31416FFFEF8FAFDFDFAF8FFFFFF1CE5F4FDFFFFFF
FFFFFFFFFFFFFFFFFFFFF1FFFFEAFFFFFFFCFFFEEAFFFFFCFCFFFFFAFDFFFD7E77FFFFF0
FCFFFFFBFFFFFFFFF8FFFC9500010952EAFF53ADFFFFFFFFFFFFFFFFFEFDFFFFFAF4FFFF
FFFEFFF1FFFFFFFDF5F9FBFFFDFAF3FFFBFFFBF7DE29F23F0A180000030000BCFFF2FFFF
F9FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFDFDFFFFF6FF6C3BFFFFF2
FFFEFCFBFFFFE5FF6447F1FFF1FFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFCFFFA
FEFF41B9FFFFFFFFFFFFFFFFAE50FFFAFFFDFDFFFFFFFFFFFFFFFFFFFFFFF9FDFFFCFBFF
FF6250FFF9FFFFF5FCFFEEFBFFFF7342E8FFFEE4FFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEF2FFFA6EA5FFFFFFFCFFAE46FFF8FFFFFFFFFFFFFFFFFFF4F9FFFFFFF0F3FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEB249FFEDFFFDFCF9FFFCFFF4F8F2FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF4ABE0EEFFFCFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF56F8F8FDFDFFFBFFFFFFFFFF
FFFFFFFFFFFFFAF9FFFFFFFCFFFFFFFDFBFFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF9FDFFFCFFDD1EFFFAFFFFF9FFF8FFFEFFFFFCFFFDFCFFEFFFFFFFE7F8FFF6F9F5FFFB
EBFFFFFBF6FAF9EFF81CE3FFFF8E1A060835F6FEFFFAFAFFFFFFFBF3FB13F6F3FFFFFAFF
FFFFFFFFFFFFFFFFFDF4FFEAFFFFFDF5FFEEFCFFFBFCF8FFFDFEFFFFFFFDFFA45EEDFDFF
FEF5FFF5FDFCF7F2EDFFFDA8126CD6F7FFFE40B3FFFFFFFFFFFFFFFFFDFFF6FCFFFFEE00
FFF4FFFB03070006FBFFFFF8FCFFFBFFFFFCFFFFF00ADF749EB5B8D8FFECFFFFFFFFFEFF
F8FFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFD8836F9EFFFFD
FDFFFFFFFFFEFF8236E4F6FFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFF8
FFFF3DBDFFFFFFFFFFFFFFFFA459FFFCFFFEFEFFFFFFFFFFFFFFFFFFFEFFFAFBFFFFFAFF
F6FF3E65FFFFFDFCFFF5FCFFFCEEFF7734F7F7FFFBFFF4FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFDF9FCFF549FF9FFFFFBFF7E85FBFCFFFFFFFFFFFFFFFFFEFFFFFCFFFDFCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFDE120FDFFF9FFFAFDFFF0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF2FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFBFFF8FFFBFFFFFFFFFF
FFFFFFFFFFF3F1FFF7F5FDFFFCF8FFEFFFFAFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFCFFC23CFFF7FFFFFEFFFBFFFAFFFFF7FFF6FFE7FFFFF1F5FFFFFAFFFFF3FFFF
FFFFFEF8FDFFFFF4FF5BB5A025111800001DFFFDFFFFFAFBFAF7FBFFEF17F8FCFFFFF6FC
FFFFFFFFFFFFFFFFFF01E5FFFEFCFFFFF210FFEEFFFFF6FFFEFEFFFFFFF7FFB946FFF6E7
FFFFFBFFFFFFFFFFFFFAF3CED7EEFFFFFFF53EC5FFFFFFFFFFFFFFFFF6FFFFFFF1FFFF01
EBFFFF00FFFEFFF500DAFFFFFDFFFCF7FFFFFFF9FF00F6FFFFFFFDF4FFFFFFF4E098FFFF
FDFFFDFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFCFDFFFFFFFFFFAC11ECF5FFF6FF
FDFDFFFFEEFFD01BD0FFFFFFF5FFF7F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFF9
FFFF38C5FFFFFFFFFFFFFFFF9A61FFFDFFFFFEFFFFFFFFFFFFFFFFFFF7FFFFFDFFFFFFFF
FAFDF73F81F2FFFFFCFCFFF6FEFFF0FF5B48FFFAFDF5FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFCFFFFFF55A3FFFFFFFBFF6D93F2FFFFFFFFFFFFFFFFFFFAFFFFF7FFF6FFE7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFEA0FFDFFFFF7FFFFF2FFFFF0FFEEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF8FFFFF6FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFCFCFEFFFFFFFF
FFFFFFFFF0FFFFFFF315FEF0FF00FFFFFFF3FFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFFF9FFA658FFFCFDFFFFFDFFFDFFF0F8F9FFFFE915FCF5FFF200070004F1FFFBFF
FFEFFFFFF4FFFEFFFA4A3C07000000150A0014000000020200001C3CEE11FBFFFFFFFCFB
FFFFFFFFFFFFFFFFFA00FFF8FFF2FFF6FF00F9FFFFFFF8FCFDFFFEFDFFFAFFBB38FAFFFF
FFF9F6FFFBFFF8FFFFF7FFFFFFFFFCF2FFFF51B8FFFFFFFFFFFFFFFFFFFBF5FFFFFBFC00
FFF8FFFCF3FCFCFF0EFFFFF3F6FFFFFFF4FFFFF2FF04F3FFF2FFFFFEFFFFDDFFC43CFFFF
FFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFBFEFFFFFDF7D41ACFF7F6FFFFF9
FFFBEBFFF4E015B6FFFFFEF4FFFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FFF933CEFFFFFFFFFFFFFFFF9368FFFFFEFFFFFFFFFFFFFFFFFFFFFFFCFFFFFEFAFDFFFE
FFF7FCFE1DA5F8FDFFFBFFFAFFFFFFFFFF5F34FFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F6FAFFFF82B7FFFEFCFFFF54A4FBFFFFFFFFFFFFFFFFFFFFF0F8F9FFFFE915FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFCFD08FAF8FFF5FAEBFFFFEDFFFCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF9AD9FFF8FDFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF08F2FFF9FFFEFFFBFFFFFFFF
FFFFFFFFFFFFF4FFF600FFFF00FBFFFDF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9FFFCFFF7FF9365FFFFFBFFFFFBFFFCFFF1FFFFF5FBFF00FFF8FF01FFFFFDFF0DF1FFFA
FFF0FFF6FFFFF1FFFA6E9BBD450012000022FDFFFFFBFCFFFFF8FBFFF508FFFFF6FFFFFF
FFFFFFFFFFFFFFFFFF00FBFFF3080003000206F4FBFFFFFEFCFFFEF6FFFFFFB548FFFFF9
F9FFFFFCFBFFFBF5FFFFFFFBFEFCFAFFFFFA639CFFFFFFFFFFFFFFFFFFFFFFF6FFFFF906
F8FFF8F8FFFFFBFF00FFF7FFFFF4FAFFFDFFF9FFE313FFFDFFFCFCF4FFF1FFF5BD3DFFFC
FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFF4E820A5FFFFFEF9FAFF
F8FFFCFBF52C8FFFFEFFFEFFEEFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB
FFF530D4FFFFFFFFFFFFFFFF8F6BFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFBFDFFFFFFFFFA
FBFFEDFFDD23BEFBFDFFF6FFF1FAF9FFFFFF4B60FFF3FFFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9FFFEF5FFF6FFFCFFF7FFFD32C9FFFBFFFFFFFFFFFFFFFFFFF1FFFFF5FBFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7FF1ADCFEF7FFFFFFF7FFFFFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF42B5FFFFFCFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBCFFF7FEFCF9FFFDFFFFFFFF
FFFFFFFFFBFAFEFFEF08FFF909F8FFFFF9FFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF9FDFFFFF2B258FDF7FFFFF2FFFFFFFFF7FAFDFFF9FF00FEFFEFFFFFF2FAFF08FFFFFF
F1FFFFFDFFF9FFF5FF5EA3FEFFBC4602011AFFFBFFFFFFFFFFFFFFFFFF22DAFFF9FFFEFB
FFFFFCEEFFFFF9FFFF00FFFCFFFC00FFFE0BF9FFFFFBFFFFFFF8FFFFF9F6FFA05CFFF7F9
FEFFFFFFFFFFFFFFFFFFFFFFFFFAFFFFFFF97E80FFF6FFFFF1FFFFFCFEFFFBFFF5FDFF00
FDFFF1FFFFFCEFFF02FDFFF4FFFBFEFEFFEDFCFFBC48F1FFFFFFFFFFFFFFFFFFBE47F8FF
FFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2FFFBFFFFF12F7DFFEFFFFFF6F8FF
FFFCFFF1436DF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFF7FF
FEFB20E2FFFFFFFFFFFFFFFF7F81FDFCFFFEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFCFEFFFFCE16C4F3FFF9FFFFFFF4FFF9FFF1406EFBFEFFFFFFFFEEFFFDFBFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFFFFFAFEFFF5FFFFFDFFFC6199FFFDFFFFFFFFFFFFFFFFF7FFF6FDFFF3FE05FFF5FFF5
FFFFF6FFFFFFFFFFFFFFFFFFFBFFFB00FFFFF3FFF9FFF3FEFFFFF7FFFCFEFFF6FFF7FEFF
FFFFFFFFFFFFFFFFFF3CC3FEFFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FAFEFFFFFFF3FFFFFFFFFF
FFFFFFFFFFFFFDF5FF00000EF0FFECF5FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFDFFFFFFFBC83EFFFFEEFDFFF5FFFFFFFFFDFFF7FFFD03F4FFFFF0FFFFFFFF00FFF4F6
FFFFF1FFFFEDFFFFFF37CDF5FBF9FAC04625FAFFFFFFFFFFFFFFFFFFFF1CE1F5FFFAFFFF
FEF6FFFFFFF3FAF7FF10FEFEF9FC01FFFF00FFFFEAFFFEFDF8FFF7FDFFFFFF817DEAFFFF
B4C9FFF2FFFFFFFFFFFFFFFFF9F2FFFBF4FFAC56F6FFEDFFFFF3FBFFFFF2FFF4FFFFFE0F
F8F7FFF3FF001600FEFFEEFFF3FFFFF9FEFFFFF88A71FFFFFFFFFFFFFFFFFFFFDB9CFDFF
FFFFF6FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4FFE8FFFFF74A7AFFE0FFFFF9FFFFF6
FFF1FF714AF8FFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFF9FF
FBFE23DEFFFFFFFFFFFFFFFF7B85FDFDFFFEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFFFFFDF0FFAE1FDCFEFFFFFBF9FAFFFFFFFFF52A7DFEF8FFEFFBFFFFFFF0F8FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEF9FFFBFADFE5FFFFFCFFFB738CFFFBFFFFFFFFFFFFFFFFFFFFFFF8FFFFFBFE00FFFEFC
F4FFFFFDFFFFFFFFFFFFFFFFFFFFE213FDFEFFFCFAFFFFFFEDF4FFE9FFF6FFFFF7FDFFF5
FFFFFFFFFFFFFFFFFE42C5FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F4FFFFF1FFFFFFFFFF
FFFFFFFFF3FFFDFAFF01FD00FFFDFFFFFFFFFEFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFBFEFFE11CFEFFFDF9FFF6FFFFF7F5FFF6FFF8FC00FFFFF911FDF0FFFD17FFFFFB
FAF8FFF6FFFAF8FFFB12E6FFFFFFF9FDECD0FFF4FFFFFFFFFFFFFFFFFA6998FAFFFFF3FF
FFFCF5FFF5FFFFF9F20EE6FFFFEFFF00FF0CFFF2FFF6FBF9FFFBFFEEFCFFEC4AADFFBB29
0099FFFFFFFFFFFFFFFFFFFFFFF7FFFFFFFFE415F4F6F9FFFCFFF7FFF3FAFBFFF6FFFC00
FFFFEFFFF8FFEBFF0BF3FFFFFEFFEEFFF8FFFFFD3DB9FFFDFFFFFFFFFFFFFFFFFFFEFFFD
FCFEFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFF2FF6A4DEAFCFDFFF5FFF5FCFF
FAFF8524FEF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFCFF
F8FF26D9FFFFFFFFFFFFFFFF748BFDFEFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFDFFFFFAFFAD33C3FAFFFFF7FFFAF9F5FFF7F43B76FFF2FFFFFFFFEBFFF9FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFEFFFFFEC94AFFBFFFCFFFA9768FFFDFFFFFFFFFFFFFFFFFFFFF8FFFEFFFBFE00FEFFFF
F8F7FFFEFFFFFFFFFFFFFFFFFFFDCC35FEF8FFFAFFF1FBFFFFFFFA1700000B00FFF3FFFF
FFFFFFFFFFFFFFFFFCA1DBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF42F0FFFFFFF6F5FFFFFFFFFF
FFFFFFFFFFF9FFFFF917F1FF0BFCF2F9F4FFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFBFFFFFFFFF31BEDFCFFFFF2FFFFFEFFFFFFFFF6FAFF00FDF5FF0000100A00ECFFF5FF
FFEFFFFEFDFFFEFAEC19F4FFF0FFFDFFFFFCF9FFFFFFFFFFFFFFFFFFFCBB42FCFFEEFFF9
F5FFEDFCFFEEF5FEFE04FFFFE6FFFF04FA00FFF0FFFFF7FFFBFFFAFFFFECFF219D370000
0DA1F8FCFEFEFEFEFEFEFEFEFBFFFFFFEBEDFF57BCEFFFFFF1FFFBFBFEFFFFFFF707FF0D
FBF7FFFFF5FFFFF400FFF5FEFFFDFFFFFFFDFFE921F9FEFAFFFFFFFFFFFFFFFFFDFCFFFA
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFD9230E4FFF7FFFBFFFEFCFFEE
FFB618E0FFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFF
F6FF25D8FFFFFFFFFFFFFFFF6A94FDFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFFFFEBFFFBF7FF873FECFFFAEDFFFCFFFAFFF6FFEF208DFFFFFAECFFFDF6FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFBF6FFFFFFF7FDFFFCFDC839FDFFFFFFFFFFFFFFFFFFEEFFFFFFF5FFFFF7F800FFFF
F9FFF5FEFFFFFFFFFFFFFFFFFFF7A16AFFF9F7FFFFF3FFFFFDFDFF00FEFFF3FFF2FFF6FE
FFFFFFFFFFFFFFFFFDFFF9F9FFF9FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB9FFFBF9FEFFFFFDFFFFFFFF
FFFFFFFFFEFFFFF9FA00FFF9F00DFFFFFAFFFFE8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFFFFFFF9FF5AA9FCF2FFFFFFF9FDFFEBFFF7FFFFEF01FFFCFE00F9FBECFFFFFFFDF6
FFFFF9FFFFFAFFEDAD5DFFF6FFF5F9FFF7FEFEF8FFFFFFFFFFFFFFFFFFED19F3FBFBFFF0
F5FEFFFFEBFFEF0FFE00FAFCFFF9FBFF070CFAFFF5FFFFFFFFEDFFFBF3FF710011000006
0077B6C2C0C0C0C0C0C0C0C0C2C1B5B8CEC9FFA34DFFF7F8FFF8FFFAF8FFF8F8FFFF0000
FFFFFD00FEFFF3FF07FFFFF5FCFAFFFFFFFBFF7F6FFFFBFEFFFFFFFFFFFFFFFFCBB6F7FB
FFFFFCF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFEB122DBF7FFFFF1FFFDF9FFFFFF
C513D8FAF9FFF0FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFF
F8FF1EDEFFFFFFFFFFFFFFFF609DFDFFFDFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7FFF6FEFFF6FAFF7E46FBFFFFEFFFFFFFFFFFFFF5D73794FFFBFFF8FDFFF1FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFFF8FFFFE5F0FFFCFFFBFFF425DDFFFFFFFFFFFFFFFFFFFFFAFFF3FFFFEAFFFF18F0FD
FAF6F1FFFFFFFFFFFFFFFFFFFEFF45B3FFFFF2FFFFFFFFFDFEF4FF0BFFFFFBF6FFFFF6FE
FFFFFFFFFFFFFFFFFDFFFAFCFCFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBFEFFF4FFFBFFFFFFFFFF
FFFFFFFFFFFFDFFFFF00FFF8FFE6FFFFFCFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFDFEFFF7FFB636FFFAFEFFFAFEFCF7FFFCFAFF06FD0AF4FCFFFF0AFFFFFFF7FDFFFF
F5FFFFFAFFFDFCFF38BDFCFEF8FCFFFFF8F9FCFFFFFFFFFFFFFFFFFFFFFF6388FFFFF2FF
FFFFF3FBFFFFFFF50015F0FFFAFFF8FF0000FFFFFFF3FFFAFCFFF7FDFBE00C04000A0000
003A32453D3D3D3D3D3D3D3D414940364D5CE7FF3EC3FFFFFFFAFFFFFFE7FFFFF5EFFF05
FFFFF3FF04000900FBF5F7FFFCF9FFFEFFFFF025E3FBFFFFFFFFFFFFFFFFFFFFDFB0FFFD
FFFFFDFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFC619BEFFFFF2F2FBFFF4FFFDFFDD
32ACF9F6FFEAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFF
FDFF12EAFFFFFFFFFFFFFFFF57A6FEFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF9FCFFFCF5FFFFFAF15F43FFFFFDFBFFF1F8FFFFFFFCD221B3FFF6FFEEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4FFF3FFFFE9F2FFFDFFFDFFFF54A1FFFFFFFFFFFFFFFFFFFFF9F9F8FFFFFFFFE8FF0EFF
FFFFFFF4FFFFFFFFFFFFFFFFFFFC0BF2FAFFFFFFFFFFFBF8FFFFF600FAF6FFFFF9F6FFFF
FFFFFFFFFFFFFFFFFD99E6FFEFFFF7FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FEF7FFF8FBFFFFFFFF
FFFFFFFFFFFFFFF1FB02FFFFF1FFFFFFFEF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFEFDFFFAFFF227E3FFF4FDF8FFFEFFFFFFFFFCFF0000FFFFF3FD02EAFFFAFFFFEFFF
FEF1FFFFF4FFFDE826F9F1FFFBFFFEEEFFFFF0FDFFFFFFFFFFFFFFFFFDF8EB26FFEEF7FF
FBFFFCFEFFFFFAFFF102FFFBFAFFECFFFF00F6FFF7FFFBFFFAF7FFFEFFB748A42A0B0011
0091FFFFFFFFFFFFFFFFFFFFFFFAFFFFFFF0FFFFAA51F9FFEDFFFCFFF5FFF6FFFFFFFFEB
F9FFFFFFFCFFFEFFFDFFFFE7FFFFFBF8FBFC8B6BFFF7FFFFFFFFFFFFFFFFFFFFFFE4FFFF
F3FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAE51EA7FFFCFFFFFFF7FEFFFAFCE545
78EFFFFFF3FFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFC
FFFF05F7FFFFFFFFFFFFFFFF50ACFEFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FFFAF5FFFFFBE3FFFFFF4D61F5FFFFFFFFF9FFF4FFFFFFC412AFFFF7FFFFFDFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFDFFF76390FEFFFEFFFBFFB659EAFFFFFFFFFFFFFFFFF2FFFFFFF9FFFFEFFFEF00FF
F4FBF4FFFFFFFFFFFFFFFFFFFBA453FFF8FFFFFDFDFBFFF8FFFEFE10FFF3FFFFF4FBFFFB
FFFFFFFFFFFFFFFFFE9DE6FFF7FFFAFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FF9FFFBFFFFFAFFFFFFFFFF
FFFFFFFFFCF9F7FFFFF3FDFFFFFFEBFFFFF6FFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F5FFFFFFFFFCF8FF877BFDFBFFFFFAFFFCFBFFF3FFFCFF03FFF5FFFF0006050000F7FFF7
FFFBFFFAFFF9FF6A89FFFDFBFEFAFFFEFDFBFFF5FFFFFFFFFFFFFFFFFFF8FF707CFFFFF4
FFFEFFFDF9FFFFFFFFFDFCFFFFFFFFF4F7FFF7FFFCFFFFF3FFFFFBFFFF37C3FFFFAF2D00
00A2FFFAFEFEFEFEFEFEFEFEFFF1FFFBFDFEFFFCFF3BBBF5FFFFF5FFFFFCFFF6FFFCF1FF
FFF8FFFFF5FFFEFEFFF9FFFFFDE6FFFDFEE91CFCFEFFFBFCFFFFFFFFFFFFFFFFFEFEFFFF
F5FFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2D8AFFFFFAF7FFFBF9FFFCFEFF5E55
FFFFF8FFF7FFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF9
FFFC00FFFFFFFFFFFFFFFFFF4CB0FEFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFEFFFFFFFF1FFFFF3FFFFF3407FFFFBF9FFFFFAFFFBF8FBFDDD11CBF9FFFFFBFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFFF3FF5B9BFFFFF9FFF7F8FF26D8FFFFFFFFFFFFFFFFFFFFFFEFFFF2080400050006
FDFFFFFFFFFFFFFFFFFFFFFFF33FCEFFFEFAFEFFFFF6FFFEF8FFF900FFFFFCFAFFFFFDFC
FFFFFFFFFFFFFFFFFFFBF9FCFFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFF8FFF4FFFFF7FFFFFFFF
FFFFFFFFFFFFFFF9FFFFF9FFFFF9FFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF33BCCFFFCF3FFFCFFFBFFFFF5FFFFFAFFFFFFFFFFFFFFFFFEFEF8FF
FFFFF5FFFFF9DD34ECFFECFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFF424E6FFF5
FBFFFBFFFFF7FFFAFEFFFFFFFEFEFFFFFFFFFAFDFFFFF9FFF4FFF7FFAB5CFFF7FEFFFF9F
4096FFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFC39C9FFF8FEFFF9FEFFFFFDFFFFFD
FCFFFFFBFFFFFAFFFFFEFFF5FFFFFAFFEF33D5FBFFFFFDFFFFFFFFFFFFFFFFFFD698FFFF
FFFEFAFFFFFFFFFFFFFFFFFFF4FFFEFFFFFFFFFF3C77F2FFFCFFF1FFFDF9FFFFFC842BFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFE
FBFF00FFFFFFFFFFFFFFFFFF3DC4FDFCFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFAFEEC2C9EFFFEFFF8FFFEF9FFFFFEFFBA11C5FFFCFFFFF4FBFF
FFFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F8FFF5FCFF5B9DFFFEFFFFFFFCFFD225FCF9FFFFFFF8FFFFFEFFFFFFFEFEFFFFFFFFFFFF
FFFFFFFFFFF1FFFAEEFFFCFF966AF7FFF8FFF6FFFFFAF4FFFFF7FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFFFEFEFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF06FFF0F6FFFFF5FFFFFFFFFF
FFFFFFFFF9EAFFFFF4FDFFFAFAFFFDF4FFFFEAF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFB142FFFFFBF6F7FFFEFFFFFFFAFDFFFFFFFFFFFFFFFFFFFFFEFFFB
FFEEFFFAFFEC48B5FFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFC847EDFF
FFFEFFEFFDFFF0FFFFFFFFFFFFFEFEFEF3FFFFFFF4FFFFFAFFF3FFBD43F3FAFFFFF8FFFF
F1F0FFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE63FE8EFFFF1FFFCFDFFFFFCFCFF
FFFFFBFDFFFFF7F1F2FFF6FFFBFCF8F760BEFFEFFFFFFBFFFFFFFFFFFFFFFFFFC758FCFE
FAFFFEFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFF66750E6FFFFFFF0FFFFFFFFF9FFAC25E7F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFE
FDFF00FFFFFFFFFFFFFFFFFF39C7FDFCFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFCFFFFFFF1F511A9FFFFF3EDFFFEFFFBFFF6FEB923DDF9F6FFFEFFFF
F6F7FFEEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF683ACFFFEFFF7FFFCFFF28695FFFFF3FAFFFFF9FFFFFFFFFFFEFEFEFFFFFFFF
FFFFFFFFFFFFEFFFFFEBFFE11AF4FFFCFFF5FFF7FFFFFFF6F3FFFF0EFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7A2DAFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00EDFFFFFFF9F4FFFFFFFFFF
FFFFFFFFFFFFFBF8FFFAFFFDFDFFFAFFF8FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FF8568FFFFFFFFF3FFFDF7FFFFFFFEFFFFFFFFFFFFFFFFEFFFFFFF
F4FFF2F8FF7586FFF5FFF8F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFF5FFBB42E9
FFF7FFFFFEFFFDF9FEFEFFFFFFFFFEFCFFF7EFFFFFFEFAFEF9FFF13FD5FFFFFAFFFFF8FF
FFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFDFFCD32DAFCFFFFFCF7FCFFFCFEFF
FBFCFFFEF4F9FFFFFFF0FFFAF6FFFF5287FFFFFFFBFEFFFBFFFFFFFFFFFFFFFFBE2CFEFF
FAFFFCFFFFFFFFFFFFFFFFFFFFF1FFFFF5F99F31E1FFFFF6FFFFF9F7F4FFFFBE1FCDF0FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFE
FFFF00FFFFFFFFFFFFFFFFFF32CEFDFEFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFDFAFFECF8E921B9FEFFFFFFF8F3FBF3FFFFF19F31CAFFF5FFFAFF
F4FFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F5F3FFFFFFF7FEFFF4FFFFFBFFE742B8FFFFF0FFF3FCFEFEFFFFFFFFFEFCFFFFFFFF
FFFFFFFFFCFAFAFFEBFFFF38C7FFEBFEFFFDF8FFF7FCFFFDFFFFDA00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF4DBCFFFBFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCAFFFFF2F5FFFFF7FFFFFFFF
FFFFFFFFF4FFFFFBFFFFEDF7F7EDFFFFFBFFFFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFF065A6F9F8F4FEFFFFFCFFFFFCFEFFFFFFFFFFFFFFFFFFFEFFF4
FFFFF6FF8E71EBFFFDFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFF5FFFFF2AA68
FAF8F1FFFBEAFFF8FFFDFDFEFFFFFFFFFFFFFEFEFFFFF8FFFFBD3DD4F4FFF1FFEDFFFFF5
FBFEFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBEFFFD43EABF0FFFFFFFFFFFFFFFB
FFFBFFFFFFFFFFEDFFFFFEFFFFC230A6FFF4F6FFEEFFFFFCFFFFFFFFFFFFFFFFC246FDFF
FBFFF7FFFFFFFFFFFFFFFFFFFBF4FFFDFFAF1BD2FFF1FFFFF7FEFFFFFEF8E024ADF8FFF7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFE
FFFE05FCFFFFFFFFFFFFFFFF29D6FDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFCEFFFFFF0B122DCF6FFFFFFFFFFFEF8FAFFF1A713EDFFFDFFE3
FFF9F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FFFFF7F8FBFDF2FDFFFAFFFFF5FFFFED34D0F9FFFDF4FFFFFDFDFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF6FFF250ADFFEAFFFFEBFFF9FFFFFBFFFCF8FFFFFBFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF30B5FFFFFFFDFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3FFFFEEFCFFFFFFFFFF
FFFFFFFFFFF0FFFFECFFF9FFFFF9FFECFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE9FFF54C8DFFFFFFFFF8FBFFF9F5FFFFFFFFFFFFFFFFFFFDFFFAFF
FDEDFF9463EFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFAFFFFA2
2AD1FFFBFEFAFFFFFFFFFFFEFFFFFFFFEDFFFFF5FCFEFFFFA840D2F6FFF2FDFFFFFDFDFF
FFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2FFFFDD508BDBF5FFFEF3F5FFFF
FFF8FEFFF6FBFFFCFBFFFEED9941D9FFFFF9FFFCF8FFF4FFFFFFFFFFFFFFFFFFDC9DFBFF
F7FFF8FFFFFFFFFFFFFFFFFFFDFFEEFFCE15B4FFFCF9FEFFF8F6FFF0FFE93692F8FEFFFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFE
FFF70DFCFFFFFFFFFFFFFFFF1FDFFEFFFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFAFFFAFFFFFAF8FF9728E2FFFFFFF9FFFFF8F6FFFFF58638E8F8FFFF
EEFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF2FFFFCFE5FFFEFFFDFFFFF9FAFFFAF537C9F6EFFFF6FFFFFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFBFFF65B9EFFF0F9FFFBFBFFFFFDFFF3FAFDFFFBF9F5FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFB52C1F7FFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFFF7FFFFF8FFFFFFFFFF
FFFFFFFFFFFFF4FDFFFC00080800FCFFFDF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF0FFF76E66F6F2FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFBFBF8
FFFF546BE0FFFFFDF4FFF0F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFF5FFFEFFF2FF
E4486DECFFFFF2F7FFFFFFFFFDFCFEFFFFF1FFFFEDFFDC5151F7FFFFFAF7FFFBFFF4F6FF
F6F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFE8FFFFFF773080DBFFFFFFFDFF
FFFEFFFFFEFFFFFFFFED7F3565F6FAFBEFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFF2FFFF
F7FFF9FFFFFFFFFFFFFFFFFFFFEAFFD315B0FFFEFFFFFFFAFFFFEFFFF55167FFF3FFFCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFEFE
FFEF14FDFFFFFFFFFFFFFFFF15E8FEFFFCFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF9FFFFE6FFFFFEFFFF8234F6FFFAF2FFFFFBFFFFF9FFFF6C2FFFEFFF
FFFAF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F1FFFFFCF18DB2F7FFFFFDF9FFFFFEFFFFF2CB4698FFF7F4FFFFFFFFFDFCFEFFFFFFFFFF
FFFFFFFFF9FFFFDB2C9FFFFAFFFFFAF7FFF6FEFFF9FEFFFFF9F3FBFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFEA6E1F7FFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF48E6FFFAFAFBFFFFFFFFFFFF
FFFFFFFFF5FFFFF7FB00FFEFEFFF00FBF7FFFFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF6FFFFF8FEFF9135C1E6FFFFFFFFFFEFFFFFFFFFFFFFFFFFFFF1FFFF
A325B4F8FFF6F1FFFCF9FFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBFFFFF7FFFFFC
F4ED8A237CFDFFFFF7FDFFFFFEFBFCFFEBFFF9FFEE5924A5FFFCFFEBFFFFF7FFEFFFFFFF
FDFFFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F5FFFAFFFFFFEB852B3891E2FDF9
FFFEF9FFFFFACEAF501C85DEF5F5FFFFFFFFF7FFFCFBFFFFFFFFFFFFFFFFFFFFFFF4FFFF
FEFDFDFCFFFFFFFFFFFFFFFFFAFCF13087FFFFF2F8EEFFFBF9FFEDFF7C47F2FFFFEDFFF2
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFE
FCE81AFFFFFFFFFFFFFFFFFF0EEFFEFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF4EEFFF9FCF5FFF3FF8231F9FFFFFFFDFEFFF5FFEEFFFF6D31FFFB
F7FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFDFFFFFFFFFFFEFFFEFDFFFFFFFFFAFFF6684EEEFCF7FDFFFFFEFBFCFFFFFFFFFF
FFFFFFFFFFEC8C3AD2FFFFF2ECF2FFFDFAFFFFFFFFFFF9F8FFFFFFF5FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFEFFAFFFFF9FEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFAFFF8FBFFF2FFFFFFFF
FFFFFFFFFFFFF9FEFF07F5FFFFF507FFFEF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFBFFFFFFFAFFD241499CFFFFF4F8FFFFFFFFFFFFFFFFFFFBFFAB30
47DBFFFFF3FFFFFFFBFFEAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF9FDFCFFFFFF
FFFDF9F37B104B9BE8F4FFFFFFFCFFFFFFCF852F1E92FFFFFCFFFCFFFFF2FFF9FFFFFCF4
FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFEF6FFFFFCFBFFFFEFC46C1B143B
3E636B4F301A2A54ACF1F6FFFFFFF5FFFDFEFEFFFBFFF3FFFFFFFFFFFFFFFFFFD4B9F6F5
FFFEFFFAFFFFFFFFFFFFFFFFFDFF3E6DFAFFFCFFFFFFF8FFF5FFFF951EE8FFFFF9FFEFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFE
FAE31DFFFFFFFFFFFFFFFFFF0AF2FEFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFAFFFFFFFBFEFFF3FBFFF86D4AFAFFF0FCFFFFFFFCFFF7FCF76B41FC
FFF4FFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFEFFFFFEBFFF9FFFFF9FFFFFEFCFBFFFFFEF7FFFFA02562E8F4FFFFFFFCFFFFFFFFFFFF
FFFFFFFF842F66F8FFF8F2FFFFFFECFEFFFFF7FFF9FFFFFFFDFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF9FFFAFFFEF4FFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F8FFFFF8FFFFFFFF
FFFFFFFFFFFEFFF3FFF5FFFCFCFF00FFFAFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB5512E5DAEEDFFFDFFFEF1FEFFE9B15B2D4EC5
FFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFCFDFFF5B0681117263A47463627002977C9FCFFFFFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFFFEE6CA
B7A69EAFCCE6F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFB3F1FE
FFFFFDFFFFFFF5FFFDFDF9F7FF8137ECFFFFFFFCFFEFFFF0FFFFA821E2F3FFFFFCFDFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FE
FEE51BFFFEFFF6FDFFFBFFFF00FFFFFAFFFFFBFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FEFF3F6AFFF8FFF6FBFFF7FFFFFCF9FE4D5D
FFFFFFFCFFFFFCFDFFF9F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF9FDFCDEFAF5FFFDFAFCFFFFFEFCFFFBFFFFF4FFF5AA262472CCFFFFFBFFFDFFF8FD
E39C520C66F1FFF2F9FBFDFFFFFEFDFAFFFDFCF7FCFFFCFCFFFFFCFFFBFFFFFAFFFFF5FF
FDFFFFFCFFFDFDFFFF9DE3F3FFFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFF4FFFFFCF9FFFFFFFFFF
FFFFFFFFFFFFFFFDFFFF00000003FFFFFBFEFFE4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFE0994F1B0346323F5637000F4C9FDEFFF8
F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFFFFFAFFFFFFF6FFF2D6C2BDC3CBD0FFFFFFFFFFFBFAFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFCFFFFFFF6
FFFAF4F7FCFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FBFF
F9F2FDFDFFFCF7FFFFECFFFF8812FCFFFEEAFFFEF1FFFCFFF6D129BFF4FEFFFFFCFDFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFF9FF
FEE31DFFFCFFF8FFFFFAFDF903FFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFF0FC2E7EFFF5FFFFEEFFFFFFFFFFFFF852
48FCFFFFEBFFFFFFFFFEFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF5FFFFFC548FFFF4FFFFFFF7FFFCFFFFF4FFFFFFF9FFF1FFDE902F002B3B3F4537290F
1859AEFAFFF4F4FFFFF9FFF4FCFFFFFFFAFFFFFFFFFFFAFAFFFFFCFFFFF8FFFFFFFFFEF8
F9FFFFF7F4FFFFF4FE9FD4FFFCFAFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3CFFFFFFFCFAFFFEFFFFFFFF
FFFFFFFFFFF6F7F8FF03FFFDF5FFF2FFF2F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF8F7F9FAF8F6B6BFBEBBCCEEFFFFFFFEFFFF
FFFBF7FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFFFFFBF2F5FFFFFFFFFEFBFCFDFDFDF3F3F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFBFAFFFFFF
FDFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFF
FFF8FFFFF7FFFFEFFFFFFCA514F9F1FCFFF6FDFFFFF4FFFFE6328BFFFFFFFFFFFCFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFBFF
FFDE22FDFBFFFAFFFFFAFAEC10FFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFF407A0FFFFEEFFFEF6FFF6FFF0FFE8
4681FFF7FFFFF1F2FFEFFCFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FFFFEBFF67A5FCF7FDFFFFFEFFFFFFF2FFFFF2F2FFFFFEFEF2FFFFF4DCBEC3BEBBE0EE
FFFFFDFFFCFCFFFFE8EEFFF8FCFBFAFEFDFCFBFFFFFFFEF8FEFDFBFFFFEEFCFCEFFFFFFF
FFFAF3FCFFF8F7FFFFFFFFFFFDFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFEFFEFFF6FFFFFFFFFFFF
FFFFFFFFFDFFFFFFF600FFFEFFED00FFFFFFFDF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEF9FFFFFFF2F5FFFFFEFFF9F8FE
FFFBFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFBFFFFFFFDF8F8F7FAFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFBFCFDFB
FCFDFEFDFAF9FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD59EF4FF
FFF9FFFBFBFFF2FEFFFDCD24C3F3FFFFF1FFF2FFFFF1FCFF4F6BFFF4FFFFFDFBFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFCFF
FFD729FDFDFFFBFFFFFCFCE41CFFFFFEFFFEFEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFFFDFFE823ACFCFCFFFFF7FFFBF7FFFCFF
EF2587FFF7FFFFFFF4FFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF4FF5BA3FFFFF9FEF8FFF2FCFFFFFFF0FFFFFFECFFFFFDFFF4FFFFFFFFFFFBFCF8
F8FDFBFFFEFCF3FFFFFFF9FFFFFDFFFAFFFBFFFCF5FEFCFBFFFFFDFEFAF7FFFFFFFFF9F8
F7FFFFF3FFFFFFF6F8FFFFF9FFFFF9FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFEFFFFF8FFFCFFFFFFFF
FFFFFFFFFBFCF6F7FF00FFFFF8FF00FFE5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FBFFFEFAFAFFFFFCF9FFFFFFF5F9FFF7FFFFFD
F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF9F6FEFFFFFFFFFFFFFFFCF8F7FAFCFCFCFAF8F9FDFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFE
FFFFFFFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD049FFF9
FBFFFAFEFFFFF9FFFFE91D9CFFF3FFF5FFFDFCFFFBFFFF7340FCFFFDFDFBFAFDFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFDFF
FFD030FDFFFFFCFFFDFFFFDF21FFFEFFFFFDFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFCFFF9FCFFF7C61AD7FFF6FFFFE1FFFFFCFFF5
F1F61599FFFBF4FFEFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEF8FFFD81B8F6FEFFFFFFF9FFFEFDEAFFFFF5FFFFFEFFFAF9FDFFFFFFE6FFF9FFFAFF
FFF2FFFBFFFFFFF0F7FDFFF6F4FEFFFFF8FBFDFFFAFFFFFBFFFFFFFFFDFFFAEDFFFFF0FF
FFFFF8FFFFFAF3FFFF97E0FDF8F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01F8FFFFF4FFFFF4FFFFFFFF
FFFFFFFFF8FFFFFCFEFF00010013F4FFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFCFFFFFFF6FFFFFEFAFFFFFDF0FFF7F1FF
FFFFFAF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFDFAF7F5F8FDFBFFFFFFFFFFFFFFF9FFFFFFFFFFFEF8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFBFEFFFFFF
F6F8FAFBFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC128FFFF
FFFFFCFFFEFBFFF6F22C83FFF4FFFFFFF5FFFFF5FFFD922FE7FDFFFFFFFEFEFFFFFFFCFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFEFF
FDC838FEFFFFFDFFFBFFFFD726FBFAFFFFFEFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE9FFFFFAFBFFFFB203DDFFF9FCFFF3FFFFF4FC
FFFFDC2D9EFFEBFFFDF7FFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFFF9FFFFFCFFD677EFFDD6363F4075FFF7D37CF2FFD33D434468FFEEC990FDFFCA452E
4B80F0FFC881EEFFDC3E3F4175FFFFBC79FFFFC146373D88F1FFBE69FFFFCD5D2F367DFF
FFB375FFFFD544334B26C5FFFFFFF7FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC4F8F2FBFFFDFFFFFFFFFFFF
FFFFFFFFFFF7FFF2FFF0FFFCFFF6FFE8FFFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFEFBFEFFFDF8FDFFFFF8FEFFF3FFFFFF
FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F8FFFFFFFFFFFFFFFFFFFCF7F6FAFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFBFCFCFCFC
FFFFFFFFFFFFFCF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB955F4FF
FBFFFBF6FFE1FFFF3866FFFEFFFAF8FFFFEBFFFFF9B727D3FFFEFAFEFFFFFFFFFFFCFBFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFEFF
FBC23EFFFFFFFFFFFAFFFFCA32FEFAFFFEFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFF5FFFFFFFEEFFFAF14E3FFFBFDFFF6FFFEF9
FFF7FFD118B4FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFBFFFFFFFEF8E7CBFFFFFBADD0BAC2FFEBEEC7FFF7F2BCB6C7CCFFFEF2BAFFFDF4BBB9
BFC8FDFFF4BCFFFBF3B3C6B8C7FFF5FFCAFFF5FFBCC1BFCCF0FFF2DFF9F8DEBBC4CCCBF5
FFF8CFFFE9F8C1CBB1CAFFF1FFFCF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFFFDFFFFFFFF
FFFFFFFFFEFAFFFFFFFFF9FFFFF3FFFFFBFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFDFFFFFFF9FDFFFFF4FFFFFDFE
FFFFFDFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFFFFFDFDFFFFFEFDFDFFFFFFFFFFFEFCFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FBFFFFFFFFFFFF
F9FEFEF9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5C4FCFF
F8FBFFFFF6FFFF6758EBFFF7FEFDFFFFF0FFFFFDDF11C0FFEFFFFFFFFFFDFDFFFEF9FCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
FABF41FFFEFEFFFFFAFFFBC041FFFDFFFBF8FFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFBFFFFFAF0FFFEFBFF942AE4FFE8FFFFF8FBFF
F5FFFFFFCE19B2FEFFFFF8FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8FFF3FFFFFAFFFFFCFBFCFFFFFFFFFFFFFFFFFCFDFEFFFCFFFFE9FFFFFAFFFBFFFEFF
FFFBFFFDFAFFFFF3F9FFF7FFFFFEFEFFFFFDFDFDFFFFFFF9FFFFFDF4FFFFFFFEF9FCF9FF
FFFFFEFBFFFFF9F8FFFFFFFFFFFFFDF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FCFFF2FFFFFDFFF6FDF6
FFF6FFFFFFFEFFF5FFFAFFF5FDFFF9FFF1FFFFF7F6FFFAFFFFF6FFFFFFFFFFF8FFFAFFF6
FDFFF6FFFFFFF3FDFDF9FFF9FFF8FFF8FFF9FDFFF7F9FFFCFEFEFEFFF2FFFFF5FFFFFFEB
FFF6FFFFFFFFF9F7FFFFFAFFFFF6FDF6FFF6FFFFFFFEFFF5FFFAFFF5FDFFF9FFF1FFFFF7
F6FFFAFFFFF6FFFFFFFFFFF8FFFAFFF6FDFFF6FFFFFFF3FDFDF9FFF9FFF8FFF8FFF9FDFF
F7F9FFFCFEFEFEFFF2FFFFF5FFF3FFFCF6FFFDFFFFFFEFFFFFF2FFF3FFFFFAF8FEF7F4FF
FFFFF4FFFFFCFDFFFDFFFBFFF7FFF7FFFFF4FFFDFFFFFAFFFDFFEAFFFFFFFFFEFFF1FFF4
FFFFF7FFFFFA9824EDFFF8FFFCFFF7FEFFFEF9EF1AAFFCFFF4FFFFFDFBFFFDFFFFFFFCFA
FDF8FFFFFFF7FFFFFFFFFAFFFCFFFBFFFFFEFFFFFFF8FFFBFFFAFFFAFBFFF9FFFDFEFFFF
F9BA41F5FFF3FFFFF9FFFFC33CFFFFF2FFFFFCFCFFFFF5FFFFFAFFFAFCF9FFFCFEFDFFFD
F7FCFFFFF8FFFFFFFBFFFDFFFFFFFCFAFDF8FFFFFFF7FFFFEEFFFF7548F1FEFFFEFEF4FF
FFF8FBFFFFC423D0F3FFF8FBFFF7FFFBFFFFF8FFFFFFFFF9FFFDFFFFFFFEFFFFFFF5F8FF
FFFFF5FFFFFAFFFAFCF9FFFCFEFDFFFDF7FCFFFFF8FFFFFFFFFFFBFFF7FFFCFCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFEFEFCFFF9FFFFFFFBFFFF
FFFFFFF4F3FDFFFFFBFFFFFFF1FFFFF2FAFFFEFFFFFFFFF8F6FDFEFFFFFCF3FDFFFBF2FF
FFF5F5FDFFF9FFFFFFFBF6FFFFFEFEFFF4FFF6FCFFFDFEFEFEFFF6EDFEFDFDFFF0FFFFFF
FCFFFFFCF6F3FFFFFDFFFFFFFFFBFFFFFFFFFFF4F3FDFFFFFBFFFFFFF1FFFFF2FAFFFEFF
FFFFFFF8F6FDFEFFFFFCF3FDFFFBF2FFFFF5F5FDFFF9FFFFFFFBF6FFFFFEFEFFF4FFF6FC
FFFDFEFEFEFFF6EDFEFDFDFFF8FEFFFFFDFCFCF6EBFFFFEFF1FFEFFFF3FFF6FFFFFFFBF4
FFFFFFFFF6FAFFFFF3FFFEFDF5EFFFF6FFFEFDFFFFF8FDFFF8FFFFFCF5FFF8FFF8FFFEFF
FFF6FFF6FABD14E9FAFCFFFDFFFBFFF6FEFFFF4481FBFFF6FFFFEEFEFFF7FFFFEBF4FFFD
FFFFFEFBEDFFFFFAF8FFFFFFF5FFFFFEEEFFFFEDFFFFFFFFFCF9FFFEFFFFFFFFFFF1EDFF
FFC642FFFEFFFFFFFBFFF1B646F7FFFFF6F1FFFFFCFFFFF1FFFFE6FFFFF5F7FBFFFBFFFF
FEFFF9F3FFFFF2FFFFF7FFFFEBF4FFFDFFFFFEFBEDFFFFFAFFE4FFF76057F7FFFFFAFFF0
FFFFFFE4FFF5A80FDCF3FFFFF9FFF9F1FAFFF2FFFFF6F5FAFFF6F6FFF6F8FFF4FFFFFFF5
FCFFFFF1FFFFE6FFFFF5F7FBFFFBFFFFFEFFF9F3FFFFF2FFFFFFFEF5FEFFFFFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFACFFFEFFFDF9FFF2FFFFFFFE
EFFDFFFEFFFFFFFDFFFEFDF8FFFFF8F6FFFFE6FFF8F9FFFFFFFFFAFAFFEEFFFFE8FFFFEC
FFFFFFFFEEFEFFF6F8FFFFF9F8F9FFFFFDFFFFEAFFFFE3FFF9FFFFFFFFFEE9FFFFF0F1FF
FFFFFFFFFFEDFFFFF0FFFFF3FFFFFFFEEFFDFFFEFFFFFFFDFFFEFDF8FFFFF8F6FFFFE6FF
F8F9FFFFFFFFFAFAFFEEFFFFE8FFFFECFFFFFFFFEEFEFFF6F8FFFFF9F8F9FFFFFDFFFFEA
FFFFE3FFF9FFFFFFFFFEE9FFFFEFFFF5FAFFFFFFFFFBFEFFFFFDFFFDFFFFFFFFF4FAFCFF
F4FFFFF6FAFFFFFCFFFFF6F4FFFFE1FFFFECFFF8FCFFFEE5FFE2FDFFF6FCFFFFE063FAFF
F7FFF2FFC80CCDF9FDFFE9FFFFF3FFFFFFF26448F0FFFFF9FFFAFFFFFDFFEDFFFFFFFFF3
FCF7FDFFFFFFFFFFFFF5F4FEFFFFFFFFFFF8F6FFFFFFFBF9FFFFFFFFFFFDFFFDFBFFFFFF
FABA3DF9F8FFFFE4FFFFFFBB60E9FFF4FFFCFFF6FFFCF7FCFFFFFFFEFFF8FFFFF8FFFFEC
FFF4FEFFFFFDFEFEFDFFEDFFFFFFFFF3FCF7FDFFFFFFFFFFF9FFF9FFF24669FCF5FFF2FD
FFE0FFFFFFFFFEBF19D6FFF0FFF8FFFEFFFFF6FEFFFFFFFFFDFFFFFDFFFFF5FFFCFDFBFF
FFFCF7FCFFFFFFFEFFF8FFFFF8FFFFECFFF4FEFFFFFDFEFEFCECFEFFFFF5FDFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F7F9FFFFF3FFF7FFFFFF
F7FFFFF9F6F8F3FFF8FDF8FFFFE3FFFCF1FCFFFDFFFCFFFCF6FFF3FFFFF7FEFFFDFFECFF
FDECFFFFFFFCFFF6FFFEF9FFFFFFF4FFFEF3FFFFF4FFFFEAFFE7FFFFFFF1FFFAFBFCFFFF
EEFBFFFAF0F8FFF3FFFFE8FFF7FFFFFFF7FFFFF9F6F8F3FFF8FDF8FFFFE3FFFCF1FCFFFD
FFFCFFFCF6FFF3FFFFF7FEFFFDFFECFFFDECFFFFFFFCFFF6FFFEF9FFFFFFF4FFFEF3FFFF
F4FFFFEAFFE7FFFFFFF1FFFAFEFFFFFFF6FFFBF6F5FFFFF2FFFDFFFCF4E8FFF8FFF5FFFA
FFFDF6F1FFFFEFFFFCFFFFF8FFF1FFFFFBFFF7FFF5FFFFFFFFFFFFF8F8FFF8F8F1CEFFFF
FFFFFDEB30A6F6FFF9FFF1FFFFFFF6FFF68741F7FFFFFBFFEBFFFFF6FFEBFFFEECFFF0FF
F8FFFBFFE6FFFAFFFFFFFDFFF5F9F1FFFBFDFFF0FFFFFFFFFFF6FFFBFAFFF5FFFAFFE6FF
FFC039FFFFFFFFFFFFFEE99E62F8FFFFFAF2F3FFFFFBFFF9FFFFEDFFFAFFF8E7FFF4F3FF
FFFFFFFFE0FFFFF9FFEBFFFEECFFF0FFF8FFFBFFE6FFFAFFFFFBFFFAFFFE427DFBFFFDFF
FFFFFFFBFFE7FFFF972AD1FFF9F8F0FDEFFFFFFFFFF2FFFDFFECFCFFF3F9FFF7FFFFFFF8
FFFBFFF9FFFFEDFFFAFFF8E7FFF4F3FFFFFFFFFFE0FFFFF9FFFFFFF5F9FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF93B120000B4F8FC3FB7FFE9
4D000012C7FFFF40BBFCFF35000A00CEFEFF49B3FFFA23080003DEF5EF39C9FCFF1F0204
00C6F2F53FCCE8FF3E041100CBFFFF3BC9FFF847000008C8FFF94AB9F1FF2E000100C9EA
FF4BB7FFFD4A0E0008A1FFFF3FB7FFE94D000012C7FFFF40BBFCFF35000A00CEFEFF49B3
FFFA23080003DEF5EF39C9FCFF1F020400C6F2F53FCCE8FF3E041100CBFFFF3BC9FFF847
000008C8FFF94AB9F1FF2E00000AAEF5FF3CB3FFFE46001100BFEFFF49C4FFF73F0A0008
BDFFFF36C6FFFC4C000000D0F2FF49B0FFFF48000309A3FFEE45C0FFFF33110000BEFFF2
F9FFEE2776FFF6FFFFF4FFF1E2FFFFE5BC1EDEFFFEFFF5FFFFF7F1FFF1FFFBF6FFFFF1FF
FFF8FFFFFFF8FDFFFBFEFFFBFFFFFFFFFFEBFFFFE6F9FFFFF8F6FFFCFCFFFFFFFFF5FFFB
F4A064F6FFFDF7F3F9FFFF975FFFFDFFF5FFFFFFFDFAFDFFF6F0FFF6F2FFFFFFF9FEFFF6
FFFEFDFFFFFEF8FFF1FFFBF6FFFFF1FFFFF8FFFFFFF8FDFFFDFFF4FFECFEDC23A7FDF2FF
E6FCFFF6F9FDFFFAFE903CE3FFFF48AEFFFFFFEEFEFAFEFFFEFFFFFFFFFFF5FFF9FFF7FF
FDFAFDFFF6F0FFF6F2FFFFFFF9FEFFF6FFFEFDFFFFFEF8FFF7FFF3F4FFFFEFF9FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFDFFF3FFFFFFFEFF
F9FFFFF3FFF1EFFFFFF8F7FFFFF3FFFAF7FFFAFFFFFFFFFFFEF6F9FDFFFFFFF2FFFFFAFF
FFFDFFFFFEFFFFF7F8FBFFFFFFFFFFFFFAFFFCFFFFFFFFECF9F4F8FFFFFEFFFFFFF5FFFF
FDF7FFFDFFF7FFF8FFFFFBFFFFFFFEFFF9FFFFF3FFF1EFFFFFF8F7FFFFF3FFFAF7FFFAFF
FFFFFFFFFEF6F9FDFFFFFFF2FFFFFAFFFFFDFFFFFEFFFFF7F8FBFFFFFFFFFFFFFAFFFCFF
FFFFFFECF9F4F8FFFFFEFFFFFCF2FFFFFFFFFFFFFFE0FFFEFFFAFFF4FDFBFFFFFFFFFFFF
FFECFFFEE7FBFFF1FFFFFFFFFDFBFCFFF9F9FFFFE9FFFFFCFFFEFCF8F5FFFFF9FFFFEDFF
FFFF5D56FFFFFEFFF6FFF4FCFFEFFFD006D3F7FCFEFFF2FEEAFFFFFFFFFFF4FFFFFDFFFF
FFFDF9FFFEFFFBFEFFFEF0FFF8FFF2F7FFECFFF5FFFFFDFFFFFCFFFFFFFFF5FFFFF2FFFF
F59F67FFF6FFFFFF7F2E402B094B6C7FFFEBFFF5FFFFFAF6FEFFFFFFFFFFFEFFFFF4FFF1
F9FFFAFFEFFFFFF5FFFFF4FFFFFDFFFFFFFDF9FFFEFFFBFEECFFFFFFFFFFFFE803C1FFE9
FFFFECFFFFFFEEF5FFFF792EE028036AFCFAFFFFFFFDFFFBFCFAFFE7FFFBF8FDFFFFFEF8
FFFFFAF6FEFFFFFFFFFFFEFFFFF4FFF1F9FFFAFFEFFFFFF5FFF2FFFFF7FDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDECFFF5F5FFFFF7F9FFFF
FDF8FFFFFFFFFFFFF8FFFFFFFCF8FFFFFFFAFFF2FBEEFFF9F8FFF3FFF9F8FCFFF2FFFEED
FEF8FFFBFEEBFDFFFFFFFCFFF7FCF7FFFFF7FFFEEDFCFCFFFFFDFFFFFEF3FFFFFAFFFBFF
F8FFFFFDFAFFFDF9FFFFF5FEF7F9FFFFFDF8FFFFFFFFFFFFF8FFFFFFFCF8FFFFFFFAFFF2
FBEEFFF9F8FFF3FFF9F8FCFFF2FFFEEDFEF8FFFBFEEBFDFFFFFFFCFFF7FCF7FFFFF7FFFE
EDFCFCFFFFFDFFFFFEF3FFFFFFF4FFEBFCF5FFF825E3FFFF0F031400DFF2FF1ED9FFFF12
000D00EEFFFE2BE7FCFE23000707DEFDFF1BD1F8FF1C000000EBFDFF1CE2F3FF14040600
E45E3B24D6FFFD2E000000EEFFFF1516B8EE44000200EFFFFF2ACCFFFF09130005D1FFF3
1FE7FFEF1028000DE1F4FF28D5FFFF1C001500EBFFF120DCFFFF0B000000EFF6F81CDFFF
FF07080002E0FBFB1B08000209000106DEFFF326DDFFFD27000B00E8FFEA23E4FFFE0D0C
0C00EEF4F72BC5FFFF09130005D1FFF31FE7FFEF1028000DEFFFF513E5F0FF14040902E3
F3FF0CE9FFF522060000D28000110032FF14000300E9FFEE1FE5F8FF29001C00DCFFF52E
DDFFFD27000B00E8FFEA23E4FFFE0D0C0C00EEF4F72BC5FFFF1E0056F3E6FFFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFEFFFFFFFBFBFFF7FFF9
FFF7FFFAFFFAFFFCFFFAFEFEFFFFF5FDFCFFFFFFFFFFFCFFFFFFFFFAFBFFFFF7FFF6FFFF
FFFFF9FFFFFFFBFFFEFCFFF7FFFFFFFCFCFFF6FFFFFAFFFCF9FFFAFEFDFFFDFCFFFFFFF5
FFFDFEFFFFFFFEFFFFFBFFFEFFF7FFF9FFF7FFFAFFFAFFFCFFFAFEFEFFFFF5FDFCFFFFFF
FFFFFCFFFFFFFFFAFBFFFFF7FFF6FFFFFFFFF9FFFFFFFBFFFEFCFFF7FFFFFFFCFCFFF6FF
FFFAFFFCF9FFFAFEFDFFFDFCF4FFF5FFFB21E9FDFBFFF7FFFFFFF8FFFFFFFDFCFFFBF7FF
FFF0FFEFFFFFFAFBFFFEFFFFF6FFFBFFF5FFFDFFFDFBFFF9FDFFFCFBFFF6FFF4FFF4FFFF
8F2AF7F9FFFFFFEAFFF7FBFCFEF63596F9FFEEFFFFFCFFFFFFF9FFF8FEFFFFFEFFFCFFFF
FFFDFFFFFFF5FCFCFFF9FFFAFFF7FEFDFFF5FFFFEEFFFEFEFBFFFFFFFFFAFFFFFFFDFFFC
FF995EFFFBFFFFFFF728000000001FF2FEFFFEFBF9FFF7FFFFF3FFFFFDFFF3FFFAF8FFFE
FDF4FFFFFFFCFFFDFEFFFFFEFFFCFFFFFFFDFFFFFFF5FCFCF6FFFDFFFFFBFFFFFBB118D9
FFFEFFF8FEFFFFEDFFFFE43105000000C8FFFBFEFFF6FEFFFAFCFFFFFBFDFFFEFFFFFFFD
F9FFF7FFFFF3FFFFFDFFF3FFFAF8FFFEFDF4FFFFFFFCFFFDFAFFBE43FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFEEFFFF17E5FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFDFCFFF9F7FFFFFCFFFEFBFFFFFBFFFFFFFCFCFFFFFFFFF6FFAF
1DE0F8FFFFF7FFFFFBFFF5FFFA4A69F2FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF7FFFFFFFCFFFCFF
FF985DFFFFFFF0FFFF8D0800000096FDFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5B21B
D9FFFEFEFCFCFFFFFFE90E0800000A0080FEFFF5FFFFFDFDFFFFFFFFFFFEFFFFFDFDFFFC
FFFFF5FFF6FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4F5D8FAF4FFFCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF6FFFFFBE72FCEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFCFFFBFBFFFFFFFCF9FFFFFFFFFBF5FFF1F4FDFFFFFAFBFFF3FFCE15
B4FFF9FFFFFFF4FBFCF1FFF56C57F3FFFFFAFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F7FFFFFFFAF6FFFBFBFB
F59E6EE3FFF4FFFAF0FC23000031EDFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFF18F
2CEDEFFFFFFEEFFDF2BE4B03001200003AFFECFFFFFFFFFFFFFFFCF8F7FFFCF8FFFFFAFF
F3FEFFF5FFFDFCFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF2FFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFEFF16DEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFCFFFFF7F3F9FBF8FFF5EEF8FFFAFEFFFFFBF3FFFFFFFAFBFFEA0FB2
FAF3FFFFFFFEF4DDFFF9FFB31DF2F2F7FBFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFFFEFFFDFCFFF3FFF8FB
FF9659FFFFFDFFFFFFFA751307A5FFFFF4FEF2EDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFEFFF
7F59FAF5F3FFFCFFFFFAFFE1921F110000F4FFF8F6FBFFFFFFFCFDFFFFF8FBFFF7FFFFF1
FFFCFFFFF5FFF2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5F8FFFCFFF8FFFAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF9FFFEFEF1FFFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFBFDFFFFFEFFFFFFFFFFFFFFFCFFFFECF7E5DBE5F5FDFFFFEF1F8DF5
FFFCFFFDFFFDE70099FFC802D6F7FFF6FFF6F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFF5F8FFFEFEFFFBFFFF
F7BAA5F6FAFFC6C7FFFFEA0228FFFBF9F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8FF
F16357FFFEFEFFFFFFF6FFFFF9FFB9672B85FFFFD1944514080A0500003065A1E8FCF7FF
FFECF2FCFFF4FFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC46AFEFCF6FCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7FBFFFFFFFFF2FEF8FFFFC27B4112001D2C16001147763F6AFFFF
FFFFFFFCFFF7960E00532FCEFFEDFFFFFEFFFEF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFBF2FFEFFFFF
DFA86126010638281000382D79F0F6F2FFFCFBF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF9FFF4
FBF34969FFF8F1FFFFFFFFFFF9FFFFFFF7E672192C69B8E9F5F3F8FFF9D0A4580E33A7F0
FFFFFAFFECFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAF9FED5FDFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF4F7F3FFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF9FFFFF1F8FFFFF8F270083E88B3F1FBFFFFFEFFF2BC84310383E4
F6F5FFFAFFFB6E020C002CE9EAFFF3FFEFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FFFFFDF8FFFFFFFFAE36
145AACD4F5EDFFFFF9FFD495510D52C4FFFFEDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F6FF
FFFFF23781FFFFF4FEF9F7FFFAEDFFE279137FE6FFFFFFFFFFFFFFFFFDFFFCFFFFCF6124
84FFF6FFFFF3F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0F9FFFFF5FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFF1BDBF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF8F8FFFFF6FFFFE574267DFFFBF2FFFFFCFFFFFDF8FAFCFAFFEF7B36
80F2FFFEFDFF240002060229F3DBFFFFFFEEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFFEFF9FFE9A0364DD2
FFFBFFFEFFFFEEFFFFF4FEFFFFFBB24B33C9FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFF1FC
FFF3FFF627A0FDFDFFFFFBFFFFFFC03188EBFFF9F9FAFBFAF9FAFEFFFFF6FCFFFBFCFAE6
7B1CFFE6FDFFFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FAFFFFFFFCFFFCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFDFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFCFFFDFDFEB2368CECFFF8FFFFF7FFFFFDFAFEFFFFFFFFFFF9FDEB
7A3CC0FFF8E20303000700092EFBF7EFFFFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFAF5FFE76A59D1FFF7
FFFFFDFFF0FFFFF2FFFFFFFEFBFFF8F6D0327FFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBF9FFFF
FFFAFFF2D81BBDFFEFFBFFF9FD9033E5FFF7FFFAFFFFFFFFFFFFFFFFFFFFFFFDFFFFFCFF
FBC330BDFFFFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFCD67FFFFFDFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFEFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF6FFFDF9FF9339F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFE2
FFD628AFFF95050005003CB0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFEFDD83DA0FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFEFCFFFFF49938EDFDFFFFFFFBFFFBFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFC81CCFFFFFFBFF4098EAFFFAFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFCEA41AAF9FFFBFFFEFDFCFFF2FFFFFFFFFFFFFFFFFFFFFFFCAD4EEDFFFFFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFFFFFFFFFDFAFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF6FFF84E89F8FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAF5F7FF
F9FFFF577958120C50D9FFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFCE35CAFDFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFFFFF8FCFFE8C533EBF3F8F8F5FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFCFFB018DFFFF479A9DCFFFFFAFBFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFFFAF847C5E0FFFDF9FFFDFFF9FFFBFFFFFFFFFFFFFFFFEDFFD041FFF3FFF5FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6FF1EE2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF6F9FF8A7AF7F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEFF
FFEFFFED6F1D81F4FFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4FFEDE535D3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFCF9FFFFFFDF25F9FFFAFFFFF5FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF4FFAB1BF0A167F4FFFFFFFBFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9FFFFFBF336D9FAFFF6FFFDFFFFFFF9FFFFFFFFFFFFFFFFFFFFB12CFFFFFAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFEFFFEFF20D7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8E63FFF0FFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFF9
FDFFF6FFF758CCDDFFFFFDFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFCEB40CEFFF9F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFCFFFFFFFDF8F6FABD55EAFFFEFCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF5FFA59753E9FFFCFBFDFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8F7F9FFE639E9FFFBFFFEFDFFFEFEFFFFFFFFFFFFFFFFFDE8F4E3FBFCFFF7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFEFFFEFF20D7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFD334F7F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FEFFFF
FCFFFFE5FDE530E5FFFFFEFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF166AAF7F0FFFBFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFFFFFDFEF9F98771FEFAFFF8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF5FEFFFF2ACBFFFFFAFAFFFFFDFBFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9FFFEFEF7FF9466FFFFFFFEFEFFF9FFFFFFFFFFFFFFFFFFFFFFF5FAF7FFF8FAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6FF1EE2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF138D2FCFFFFE8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFF4FF
FFE6FDFFFFFFA946FFF2FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBB64FF9FDFFFCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFDFCFFFFFDFFFFFFEEFF31E6FAFEFBFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF5FCFFFF856DF7FFFFFEFDFFFFFCFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFEFFF6EFFF3CC3FFFCFEFFFDFAFFFFFFFFFFFFFFFFFFF7FFFFFCFBFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFFFFFFFFFDFAFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFA555FFF4F8F7FFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFF
F7FFFFF1FFFFF553C7FBFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF732C5FFFFFFF8F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF9FBFFFFFEFAFBFFEDFFFFB137FFECFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFBFFE32EF4FBFEFEFCFDFEFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE8FFFEFDFFA362F8FCFEFFFEFFFFFFFFFFFFFFFFFFFFFFFFC183F4FFF6FDFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFEFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF1EF2F3F5FFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FF
FFF3FFFFFBFCFFC32CFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8E75FFEBFEFFF6FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFFFFFFFFFFFFFBFF50A6FFF3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF1FFF3B44EF9FFFFFDFEFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFECFFFFF7FF15EDFEFEFFFFFFFBFFFFFFFFFFFFFFFFFFFFE9CBFFFCF7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFDFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF5FEFFFFB54DF5FFFDFFF6FFF4FFFFFFFFFFFFFFFFFBFFFFFEFFFFF9FFFFFFFFFF
FFFFFFFFFFFBFFF830D2FFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFCF6FFFEFD27E4FBFFFFFCFDFDFFFFFFFF
FFFFFFFFFFF5FFFFFDFBFFFBFFFFFFFFFFFFFFFFF5FFFCFFAD49FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFCFF4FABFFF7FFFFFFFFFFFFFFFFFFFAFFFFF7FFEFFFF9FDF6FFFFF1FFF9FF
FFFFFFFFFFFFFFFF6D8CFFFFF9FDFFFAFFFFFFFFFFFFFFFFFFEFFAFFF9FDFFFBFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFF1BDBF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFFFFFFFEFEFE639AFFFFFBFFF7FFFCFFFFFFFFFFFFFFFFFFFFE5FEFFEDFFFDFFFFFFFF
FFFFFFFFFFF7FFFC7882FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFDFFFFFCFFFFDB3AE6F8FCFFFDFFFFFFFFFFFF
FFFFFFFFF7FFF2FFFFEFFFFFFFFFFFFFFFFFFFFFFFFEFFF5F719FBF8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF2F12AE8FFFFFCFFFFFFFFFFFFFFFFFFFFEEFFFCFFF8FFF6FFFFEAFFF1FFF9
FFFFFFFFFFFFFFFFBA47FBFDFFFFFBFFFFFFFFFFFFFFFFFFF8FEFFF4FFFCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF4F7F3FFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFFF6FFFCFBFA1BE8FFFCFEFFFBFFFFFFFFFFFFFFFFFFFFF6FFFFFAFFFFF3F9FFFFFFFF
FFFFFFFFFFF7FFFFD227FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFF9FFF89370FBFFFFFFFDFEFCFFFFFFFF
FFFFFFFFFEFAFFFFF6FFFEFDFFFFFFFFFFFFFFFFFFEAFFFDFF4BB0FEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFEC033FFFFF8FFFFFFFFFFFFFFFFFFFEF4FFF6EEFFF3FFFFEEF5FFF6FFF3F9
FFFFFFFFFFFFFFFFFA09FBF8FFFFF7FFFFFFFFFFFFFFFFFFFFFFC772FEFDFFF8FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFF3FFFAFEE71AFFF8FDFFFFFFFCFEFFFFFFFFFFFFFFFFF7FFFCFFF9FBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF03F4FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFF6FFF556A3FFFFFFFFFDFEFBFFFFFFFF
FFFFFFFFFFF3FFF2FFFCFEFCFFFFFFFFFFFFFFFFFFF6FFFFEA9870FEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF9FFA256FFFFF2FFFFFFFFFFFFFFFFFFFDFFF6FFFFFFF7FFFDFFFFF8F1FFFDFF
FFFFFFFFFFFFFFFFFF09F7FCFDFFFFFDFFFFFFFFFFFFFFFFF5FFC240FFFAFEFCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF9FFFEFEF1FFFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFDFFFFBF45FFF3FFFFFBFFFDFEFFFFFFFFFFFFFFFFFFE0FFFFFFF7FFF9FFFFFFFF
FFFFFFFFFAFFFFFDFF1BDCFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFCFFFFFAFFFF3DBEFFF9FFF9FFFFFFFFFFFFFF
FFFFFFFFECFFFDFFFFFAFFFFFFFFFFFFFFFFFFFFF6FFFFFCFFA168F3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF99B66FFF0FFFEFFFFFFFFFFFFFFFFFAFFFFF4F900070300FFEFFFFFFBFFFB
FFFFFFFFFFFFFFFFFC2ED5FFFFF6FFFBFFFFFFFFFFFFFFFFF8FFB934FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFEFF16DEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFFFCFFFF9865FFFBFFFEF6FEFFFFFFFFFFFFFFFFFFFFFC14000800FEFAFFFFFFFFFF
FFFFFFFFF8FFFFFBFA43C4FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFCFFFF24DDFFF9FFF8FEFFFFFFFFFFFF
FFFFFFFFFFFFF5F808F9F6FDFFFFFFFFFFFFFFFFFFF9FFFBFFBB41FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8827AFDFFFFF8FFFFFFFFFFFFFFFFFFF5FFFF02FFEDFFFF00FBFFFFFFF7FB
FFFFFFFFFFFFFFFFFF43B0FEFFF1FFFFFFFFFFFFFFFFFFFFFFFFAF50F7FFFFFBFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF6FFFFFBE72FCEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEF9FFFFFFFB8E70FFFFFDFDFEFEFFFFFFFFFFFFFFFFFFFF00F9F6FDFF05FFF6FFFFFFFF
FFFFFFFFFDFFFFFBFC52B3FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFBFEFFF8FB0DF6FFFFFFF9FEFEFDFFFFFFFF
FFFFFFFFF2F1FFFF00F8FFFCFFFFFFFFFFFFFFFFFFEEFFFFF9DE1BFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF7B80F1FFFFFCFFFFFFFFFFFFFFFFF5FFF0FCFFFFFFEEF50EF9FAFAF6FFFF
FFFFFFFFFFFFFFFFFF3BBBFBFFFAFBFFFFFFFFFFFFFFFFFFEDFFF4CFFFFBFAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFEEFFFF17E5FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7FDFFFEF99871FDFFF2FFFFFFFFF9FFFFFFFFFFFFFFFFFFFFFFEEFD00FDFFFFFFFFFF
FFFFFFFFFFF7FFFDFF4EABFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFF5FDFFFFFF0DF6FAF9FFF8FEFFFFFFFFFFFF
FFFFFFFF050300000A00F6FEFFFFFFFFFFFFFFFFFEFFFDFDFFCC32F9FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEFF9A65FFF1FFFFFFFFFFFFFFFFFFFFFFFCF8FFFEF6F9FFFF00FFFEFFFDFFF8
FFFFFFFFFFFFFFFFF52BE2FBFFFFF5FDFFFFFFFFFFFFFFFFFFFFFCFEFBFFFDFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFBFF1CDEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFDFFF3FFFF9B5DFFF9FFFFF5FFF3FFFFFFFFFFFFFFFFFFF9FFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFCFFFCFAFE3CC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFCFDFFFF2ADCF8FFFDFEFFFDFFFFFFFFFF
FFFFFFFFFE03FFFF00FFFDFFFFFFFFFFFFFFFFFFF6FFF9FFFFB34EFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEF2C550F7FFF7FFFFFFFFFFFFFFFFFFFFFFFAFB0FFFF8FFFF00FFFFFFFFF6FF
FFFFFBFFF0FFFFF4FF00FFF4FFF6FFFFFFFFFFFFFFFFFFFFFCFFFFF3FFFFF9FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFCF1FFF8FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFAFFFCFFFFC237F8FFF9FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFE6FFFA00FFF3FFFFFFFF
FFFFFFFFFFFFFCFFF820D9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFF9FFFEF93EC0FFF6FFFFFFFFFFFFFFFFFF
FFFFFFFFF900FAF70DFBFAFEFFFFFFFFFFFFFFFFFFFFFFF9FFA054FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC02EFFFCFFF6FFFFFFFFFFFFFFFFFCFFF8FF0007000004F4F7FFEBFFFFF7
FFF6FFFCFFFCEEFFEC0CF7FFFFF6FFF5FFFFFFFFFFFFFFFFFDF8C289F4FAF4F4FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFBFEFFFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF9FDFFFCFBED19F6FFF5FFFFF3FFFFFFFFFFFFFFFFFFFFFBFF0D0204F2FFF9FFFFFFFF
FFFFFFFFFFFFF9FFEF1BECFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF8FFFEFA7097F0FFF7FCFFFFF8FFFFFFFF
FFFFFFFFFFF800FF00EFFFEEFFFFFFFFFFFFFFFFFFF8FAFFFB6C92FCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFCF627DFFBFFFFFFFFFFFFFFFFFFFFFFF6FFFB18EFFFFFFBFFFFFFFFF3F7FF
FFFBFFFFFEF6FFF4AA5EF6FFFFF7FFFFFFFFFFFFFFFFFFFFFFFFEABCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDF5FFF7F9EFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF9FFFFFEF8FE35D7F7FBFFFDFCFBFFFFFFFFFFFFFFFFFFF6F9FAF9F50EF9FFFFFFFFFF
FFFFFFFFFDFFF7F3BD4FFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFCF9FFFFFFB547FBFFFCFEFCFFF9FFFFFFFF
FFFFFFFFF0FF00FF0EFFFEFFFFFFFFFFFFFFFFFFFAFFFAFFFF25DFF9FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF2FFFC7686F9FFFCFFFFFFFFFFFFFFFFF6FFF9EDFF00FFFBFCEEF7FEF5FFFBFB
FDFFF8FFF4FFFFF93FC0FFF1FFFFF4FFFFFFFFFFFFFFFFFFF1F5FFFFFEF5FBFAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF2FDCF2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7FFF9FFFCFC8771FFFFFEFEFFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFD00F6FBFFFFFFFF
FFFFFFFFFDFFFBFF56A2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFEFCFFFDFFEB10FFE2FFFFF7F9FFFFFFFFFF
FFFFFFFFFFFFFF0002FFF6FAFFFFFFFFFFFFFFFFF4FFFFE5ED22FEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF0FFB63EFFFFFCFFFFFFFFFFFFFFFFFFFDFFFFFF00F5FFFFFEFDFFF8FFF7FF
FFFEFFEFFFFFF7FA17E9FFF4FFFFF4FFFFFFFFFFFFFFFFFFFFFFFDEEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF9FFFBF9F3FAFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCF7FFF3FFFFF9D822FFFFF5FFFEFAFFFFFFFFFFFFFFFFFF00FFF8E3FF09F7FFFFFFFFFF
FFFFFFFFFFFBFFF91BE5FFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFEFEF7FFFF5C92FFFFF8FCFFFBFFFFFFFF
FFFFFFFFF8FAFF0A06FEFEFFFFFFFFFFFFFFFFFFFFF0FFFF6F86FFFCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF5FF30D1ECFFFFFFFFFFFFFFFFFFF3FFEDF2FF070900000EFAF5FFF4FFF8
FEFEFFFCFFF5FF6E81F5FFFFF8FFFFF7FFFFFFFFFFFFFFFFFDFFD36BFFFBFFF9FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFFFDFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFF8FFFFFDFC5BA9FBFAFFFDFFFFFFFFFFFFFFFFFFFFFF000F0000FFFFF6FFFFFFFF
FFFFFFFFFFF9FA9B6BFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFEFFFCFAFFFFD331FFFCF7FFFFF9FFFFFFFF
FFFFFFFFFCFFF9F700FFFFF5FFFFFFFFFFFFFFFFFFECFAF133E4FFF8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF2FFFFF4D52DFFF8FFFFFFFFFFFFFFFFFEFFFDFFFFE4FFF8FFF9FFF5FFF2FCFF
FCFFFBFFFFF1E82CF2FFFEFFF9F8FFFCFFFFFFFFFFFFFFFFF4FFC63AFFFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFAFDFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF9FFFFFDFFFCD12EF6FFF0FFFFFAFFFFFFFFFFFFFFFFF9FFEEFFFFF8FDFFFFFFFFFF
FFFFFFFFFDFEEF26EAFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFCFFFFFFFFFAF96799FEFFFFF1FFFFFFFFFF
FFFFFFFFFFF8FFFFF9FFF4FFFFFFFFFFFFFFFFFFF8FFFF807EF4FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8FCFFF4718BFFFFFFFFFFFFFFFFFFFFF3FFFDFEFFFFFFF8FFFFFCFFFFFEF9
FFFCFFFCFDFF53A8FFFFFDF9FFFFF6FFFFFFFFFFFFFFFFFFFFFFB446F8FAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFDF9F82EE0FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF6C8BFBFFF7FFFFFFFBFAFDFFFFFFFFFFFFFFFFFFFFFFFFFFF2F7FF
FFF7FDFFFBFF698FFFFCFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBEB25EEFFFFEFFFFFFBF9FF
FFFFFDFFFFFFFFFFFFFFFFFFFFFCFCFFFFFCF0FFF9F3E526F7FFF3FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEF7FFFFFCEF27E4FFF2FEFFFCFFFDFFFFFBFFFFF5FFFFFBF9FFFFF6FEFDFAFF
FFFFF9FFFFAB53FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEF9C042FFFBFFF5FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0DD7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFAEA53C7FBFFF1FFFFFFFFFDFDFFFFF3FFFFFFFFFFFFFFFFF4FFFFF9
FFFFF8F6FFBA45FFEBFFFDFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0A370F8FBFFFFFAFFFFF9
F4F9FFFFFFFFFFFFFFFFFFFFEDFFFFFFEEF8FFF8FFFA47BCFCF5FFFDFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF5FFFBF8FBFFD333F2FFFFFBFDF3FFF5FFFFFFFFFDFFFFFCFFFFFFFFFFFFF9F8
FCF0FFFFBB3AFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFAF0D8F7FAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8FAFEF9EC46DDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF4FFE132EEFBFFFCF5F7FFFFFFF5FCFFFFFFFFFFFFFFFFFFFFFFFAFD
FFFFFFFFC242F3F6FFFFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFF38C7BF6FFF5FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFF7F6F658A0FFFCF3FFF7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFCFFF6FFF5FFBC36EBF9F7FFFFF5FFF8FBFAFDFFFFFEFFFFF8FAFFFEF7FEFF
FFFEFFCB3DF4F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBF1FFF4FFFEF9FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF04E5F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF3FFC63EE5F4FFFFFFFFF3FAFFFFECFFFFFFFFFFFFFFFFF5FBFEF5
F3FFFDDC55E7EFFFFFF2FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4FFE55DA2FFFFFEFCFFFF
FFF4F4FDFFFFFFFFFFFFFFFFF2F7FFF9FFFFF6FF7689F8FFFFFFF6FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFDFFF1FFFFE4FFB23FD0FFFEF3F9FFFFFFFFFDFFFBF2FFFEFAFFFCF7FFFFF1
F0FCAB31D6F5FFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE5FFFFEBFFFFFDFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFDFFF7FBFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF3FFFFB243CBEBFCFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFAFF
FFFFA932D2E6FFFFF1F5FFF2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF8FFFF585AF2FFFFF9FB
FFFFFFFDFFFFFFFFFFFFFFFFFDFFFBFFF6FFEE498DFDFDF8FEFFFFFCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFDFFFBFFFFFFF8F6FFCE339FFDFFFFFFFEFFFEFCFFFFF9FFFFF9FFFFF9F9FFFB
F67457FFFEFFF8F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC72F4F4FFFDFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEF4FFFFFFF9FDF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFBFFF5DB4CA4FDFEFEFDF9F6FBFFFFFFFFFFFFFFFFFFF1FFFEFF
E96B5EEFFFFFFFF3FFFEF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFF3FAFCFF9940DCFFFFFB
EDFAFFFBFFFFFFFFFFFFFFFFFFECFFF6FFBC4AA7FFEEFFFFFFF3FFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7FBFFFFECFFFFF1FFFF512898FFEBF6FFFEFCFFFFFBFBF9FFFEECF9FFE18E
268CF6F7FDEBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF8FBD4FFF4FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFBFFF4FFFFFFE06B239AFDFFFEFFFFF9FFFFFFFFFFFFFFFFFFFAF998
2C86FFF3FCFBFFF8FFF5FFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE8FFFFF8FFFDD1176FD2FF
FFFFFFFFFFFFFFFFFFFFFFFFF1FFF9D9593CD3FBFEFFEDFFFFF2F1FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFBFFE4FFFFF5E6FFFBEDFFDD611EA0E6F3FFFFFFFFFFF4FFF7FEFFC0563B6D
E0FFFFFCFFFFEAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4F0F8FFFFFFFAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF2FCFF20E5F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFBF4FFF3FFFFDD65266FD3F6FAFFFFFFFFFFFFFFFFFFBD6D2764
E5FFF1FFFEFFF6FFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFF5FCFFFFFCF7FF8C334F
A8E6FCFFFFFFFFFFFFFFFFFFEE954439A0FEFDFFFFF6FFF8FBFFFFF4FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFFFFFEF6FFFFFDF9FFFFFFFFE06F1B335D798CB1C2AD79834E12379CE6FF
FFFFF8FFFDF7FFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFFFFDF8FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F7FFF9FFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDE87321E4C8181B4C39F88845511418DE0FF
FFFBFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFCAE
4B1F40747CA7BEAC998C65341D63BEF9FFFFFBFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD4A585654843507D8AB5ECFFFFF8FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6C87AF7FFFFF8FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8FDFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF9E0B1897D4A3D63787AA6EAF9FFFFFC
F6FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F5FF
FFF5B9847B53425567729BCDF4F9FEFFFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFBFFFFFFFDFFFFF8FBFFFFFCFAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FDC343FFF1FFFAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFFFDFDF3F7FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFCFEFDFAFEFEFFFFFFFFFFFFFFFFFFFD
FFFFFFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFA
FEFFFFFFFFFEF9FFFFF8F3FDFFFFFFFFFFFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F6F8FEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC529FFF8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFCFF23E5FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5F7FBFFFFFFFFF8FFFFFDF9F9FFFFFFF8FDFFFB
FBFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFBFFFF
FEF7FAFFF7FFFFF0F5FFFFFFF7F9FBFCFCFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAF9FDFFFEF5FBFFFFFFFFFEF9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFABC4AFFF2FBF9FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF9FAFFFEFF13D4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F8FFFFFFFFFFF7FCFFFFFCF6FFFFFFFFFF
F9FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F9
FFFFFFFDF9FFFFFFFFFEF9F6FFFFFFFFFDFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FCFFFFFFFFFFFFFFFFFFFDFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEAC6FFFFFFFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFAFFF2F638D6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2FDFFFFFEF4F7FFFDFFFFF2F3FFFFFFF3F8FEFF
FFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FCFFFF
FFFDFCFDFFFFFFFFFBFBFFFFF5F6FBFFFFFFFEF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFDFDFCFAFBFDFCF9FBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFFFF8FAFEF7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FEFF03E6FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF6FAFFFFFFFFFFFFFFFFFFFBF7FAFFFFFCFA
FCFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF8
FAFFFFFFF2FDFFFDFDFFFFF8FFFFF9F7FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFDFBFBFFFFFFFFFFFFFFFFFCFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEE6FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFFFBFFF7FFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFFFFFCF9FAFAFFFFF8F8FFFFFDF8FAFDFF
FFFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFCFEFF
FFFFFCFAFFFDF8FFFFFCFBFFFAFFFFFFFDFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFDFFFFFFFAF9FFFFFCFBFFFFFCFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAC883FFFAFAFDFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEF2FFFFFEFFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFF7FFF8FF06
FBFFFD00FEFF00FFFF00FFFEFD10EBFF07EFFFFC00FFFF00F9FAFFFFFFFC02F7FFF40BFF
FC02FDF7FA0EFF00FFFD00FDFCFFFEFA00FFFA00FEFF00FCFFFB00FFFF00FBFFFF00F9FB
00FFFBFF05FE00FFFDFA0DF9FF00FEFFFF00EDFFFFF8FAFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9E9DBF7FFFFF8FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFF7E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FAFF00FA
FBFBFFFB00FF04F0F811FDFDFC00FFFF00FFEBEFFFFFF900FFFFF6F8FFEEFFFFFFFA08F6
F901F6FFFF00F000FFFA03FDFFF6FFFF00E6FE03FFEFFFFFF6F70EF9FFFEF6FFF300FFFF
06FFFCFF00FF01FFFFFFF1FFFFFFFFFBEF0AFFF9FDFCFFFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFF8F4F8FEFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFFF2FDFF2FE3F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF4FFFFFFFD07FF
FFF6FFFF09F200FFFF00FFFAFF05E9FF0000030F03FEFF00FFF4FFFFF6FFFF000006F1FF
FE00FBFFFE05FF00FFFB00FFFCFFFCF800FFF900F6FFED050000FFF7EEFF0B000CFFF2FA
05EBFFF900FF0000000005FFE6FF000009FEEAF5FFF7F3FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFEF0FFFFFFFCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFBFEEEFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F0FF00FC
FCFFF4FC00FC0FFDE70AFFF2FF00FFF80BF8FFF500FFEA00FAFCFFF4FFF802FBF6FFFFFD
FC00FFFAFF00FF06EFFF00FCFFFCF9FF00FEF207FDF803F1FFFFFFFFFF06FFFAF8FFFFF8
00FFFFFF0BF400FFFFFF0EFFFF00FBFCFBFFFFF8FFFFFEF5FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEC785F5FEFEFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFCFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEDFFF6FFFE01FC
FFFEFCFF00FF01F1FF0000FFF005F0FF00FBFFFF00F2FF000FFFF3FFFFFB00FFFFFD03F8
FF02FFFDFF00FF00FFFB00FFFEFFFFFE05F6FF00FFF901FFFFF600FFFF00FFFFFF00FFFF
02FFEDF000FF05FBFFF400FAFA02FCFFFC00FDFFE9FBFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFBE47FBF9FCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF6FDF7F0F6FFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FCFFFAEF07FF
E7FFF1F70100000CF500FF0500FFFFFFFF000005FBFFF400F100FBFFE9F9FF000000FFFF
F1FA040000FF040008080000FFFBEF000000FF02F2FAFF010007FEFFFFFF000600F3FFE2
00F5FFFF00F7FF000004FFFFFFFF010003FFFDF6FFFEFFF2FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFB83CFFFFFFF9FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFEFF15E1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF7F0FFFFF600
FFEDFF00FFFF00FFFF07F4F8F9FFFFFCFFF0FFFBFFF5FFF8FFF9FFFBFFF9FFFFFAFFEDF7
FFFFF7F8FAFFFF00FFF900FFF4FDFFF70DFFE5FFFFFFEEFFF5FFFFFFFAFFFEF9FFFFF8FF
FFFFFCF5FEFFECFFFFF6FFEEFAFFFDFEFFF6FFFAFAFFEDFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7B452EDF8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF9FFF9FFF627DCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDEFFFFD
000300FFFFFF00FFFF00FFFFFFFFF0FFF2FFFFF8FFFDFFFFF9FFF9F8FFFBF2FFFFEFFFFF
FBF5FFFFFFFAF5FF000A00F9FFFFF8FF00FCFD0CFBFCFEF9FFF8FFF9FEFFFFF7FFF4FCFF
F4FFFDFFFFFEFBFFFDFEF8FFFFFAFFFFFFFFF7FFFFEBFFF2FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFAC5FFF7FFF6FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF9FFF9FFF627DCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FCFFF4FFFFFBFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFEFF15E1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFF5FFF9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF6FDF7F0F6FFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC177FFF7EFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFCFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEF6F3D3FFFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFBFEEEFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1EBFFFFF5FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFFF2FDFF2FE3F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4F4FFFFF0FCFFF4FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFF7E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBC74F9FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEF2FFFFFEFFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4FFC439FFF7FBFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFFF6FFFDFDFCFFF3FDFFFBFFFCFFF1FFFFFFFAFDFF
FEF9F7FFFFFFFFFFFBFDFFF8FFFFFFF7FFFFFFFFF6FBFFFAFFF5FFFFF6FFF7FEFAFDFFFF
FEF6FFFCF3FDFFFCFFFFF1FFF9FEFFFFF9FCFFFCFEFEFFF9FFFBFFFEFFF9FFFFF0FFFFFE
FCFFF3FDFFFBFFFCFFF1FFFFFFFAFDFFFEF9F7FFFFFFFFFFFBFDFFF8FFFFFFF7FFFFFFFF
F6FBFFFAFFF5FFFFF6FFF7FEFAFDFFFFFEF6FFFCF3FDFFFCFFFFF1FFF9FEFFFFF9FCFFFC
FEFEFFF9FFFBFFFEFFF9FFFFF0FFFFFEFCFFF3FDFFFBFFFCFFF1FFFFFFFAFDFFFEF9F7FF
FFFFFFFFFBFDFFF8FFFFFFF7FFFFFFFFF6FBFFFAFFF5FFFFF6FFF7FEFAFDFFFFFEF6FFFC
F3FDFFFCFFFFF1FFF9FEFFFFF9FCFFFCFEFEFFF9FFFBFFFEFFF6CB40F6FCFFFCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF5FFEFFAFB21E5FFFFFDFFFFFFFFF7FCFCFFFFFBF6FFFFFD
FFFFFFF5FAFFFFF8FFFFFCFFFBF9F9FFFCF9FDFDFFFFF9F3F7F4FFFBFFFFF8FFFFFAEDFE
FFFFFAFFFFFFFCF8F8FFFFFFFFFBFBF5FCFFFFFBFFFAF1FFFFFFF6FFFFF8F7FAFFFEF8FF
FFFDFFFFFFFFF7FCFCFFFFFBF6FFFFFDFFFFFFF5FAFFFFF8FFFFFCFFFBF9F9FFFCF9FDFD
FFFFF9F3F7F4FFFBFFFFF8FFFFFAEDFEFFFFFAFFFFFFFCF8F8FFFFFFFFFBFBF5FCFFFFFB
FFFAF1FFFFFFF6FFFFF8F7FAFFFEF8FFFFFDFFFFFFFFF7FCFCFFFFFBF6FFFFFDFFFFFFF5
FAFFFFF8FFFFFCFFFBF9F9FFFCF9FDFDFFFFF9F3F7F4FFFBFFFFF8FFFFFAEDFEFFFFFAFF
FFFFFCF8F8FFFFFFFFFBFBF5FCFFFFFBFFFAF1FFFFFFF6FFFFFEB33DFFFFF7FAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFFF1FFFF28CBFFFDFCFFFEFBFEFCFFFFFEF5FFFFF7F2FB
F9FFFFFFFFFAFEFFFFFAF5FEFFFFFFFFFEFFFFF5F7F8EEFFFFFFFFF1FFFFF5FFEEFFFFFF
FFFFFFFFF4F3FFFFFFFEFFF7F9FAFFFFFFF0FEFBF4FFFFFAF7FFFFFDEEFFFEFCFFFFFCFF
FDFCFFFEFBFEFCFFFFFEF5FFFFF7F2FBF9FFFFFFFFFAFEFFFFFAF5FEFFFFFFFFFEFFFFF5
F7F8EEFFFFFFFFF1FFFFF5FFEEFFFFFFFFFFFFFFF4F3FFFFFFFEFFF7F9FAFFFFFFF0FEFB
F4FFFFFAF7FFFFFDEEFFFEFCFFFFFCFFFDFCFFFEFBFEFCFFFFFEF5FFFFF7F2FBF9FFFFFF
FFFAFEFFFFFAF5FEFFFFFFFFFEFFFFF5F7F8EEFFFFFFFFF1FFFFF5FFEEFFFFFFFFFFFFFF
F4F3FFFFFFFEFFF7F9FAFFFFFFF0FEFBF4FFFFFAF7FFFFFDFFFFF5CBF4FBFDFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF9FFFFEEFF07E4FFFCFFF5FFFFF5FFFFFFFFFDECFFF7FFFF
FFFFEBFFFFFFEDF6FEFFFFFAFFF4FFF9FDFAF9FEFFFFFFFFF3FFFBFFF0FFF8FFFFFFFFE8
FFF8FFF7FFFFFEFFF9F4FFFEFFF3FEF6FFF9FFFFFFFAFFFCFFF6FFFFFFFFF9FFEDFEFFFF
FCFFF5FFFFF5FFFFFFFFFDECFFF7FFFFFFFFEBFFFFFFEDF6FEFFFFFAFFF4FFF9FDFAF9FE
FFFFFFFFF3FFFBFFF0FFF8FFFFFFFFE8FFF8FFF7FFFFFEFFF9F4FFFEFFF3FEF6FFF9FFFF
FFFAFFFCFFF6FFFFFFFFF9FFEDFEFFFFFCFFF5FFFFF5FFFFFFFFFDECFFF7FFFFFFFFEBFF
FFFFEDF6FEFFFFFAFFF4FFF9FDFAF9FEFFFFFFFFF3FFFBFFF0FFF8FFFFFFFFE8FFF8FFF7
FFFFFEFFF9F4FFFEFFF3FEF6FFF9FFFFFFFAFFFCFFF6FFFFF5FFF3FFFFFFE7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF4FFF5EC3ADDF9FDFFFFFFFFFFFDF6FEFFFFFFFFF9FAF6
F7FFFFFFFDFFFFFFFEF5F5F6FFFFFFFBFFFFFAFFFBF2FFF2FFFBFCFFFFFFFFEDFDFAFCF9
FFFBFFFFFBFFF9FAFFFFFCFFFFFAFFF9FEF5FFF6FFFEFBF5FFFEFCF0FDF1F5FFFFFFFFF7
FDFFFFFFFFFFFDF6FEFFFFFFFFF9FAF6F7FFFFFFFDFFFFFFFEF5F5F6FFFFFFFBFFFFFAFF
FBF2FFF2FFFBFCFFFFFFFFEDFDFAFCF9FFFBFFFFFBFFF9FAFFFFFCFFFFFAFFF9FEF5FFF6
FFFEFBF5FFFEFCF0FDF1F5FFFFFFFFF7FDFFFFFFFFFFFDF6FEFFFFFFFFF9FAF6F7FFFFFF
FDFFFFFFFEF5F5F6FFFFFFFBFFFFFAFFFBF2FFF2FFFBFCFFFFFFFFEDFDFAFCF9FFFBFFFF
FBFFF9FAFFFFFCFFFFFAFFF9FEF5FFF6FFFEFBF5FFFEFCF0FFFFFFFFF5F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF9FBFFFBF6FEFFFFF3FFF3F2FFF4FFF9F5FAFFECFFFFFF
FFEDFBFAFFEAFEFFFFFFFCFFF6F8F4FFFBFAFBFFFFFFFFF7FFF6FFFBFBEAFFFFFBFFFFFF
EDFFFFF4FBFFFFF8FDFFF2FFFEFBFDFFFEFFFFFFFEFFFDFFFCFFFFFFFFFBFFF7F4FAFFF8
FFF3FFF3F2FFF4FFF9F5FAFFECFFFFFFFFEDFBFAFFEAFEFFFFFFFCFFF6F8F4FFFBFAFBFF
FFFFFFF7FFF6FFFBFBEAFFFFFBFFFFFFEDFFFFF4FBFFFFF8FDFFF2FFFEFBFDFFFEFFFFFF
FEFFFDFFFCFFFFFFFFFBFFF7F4FAFFF8FFF3FFF3F2FFF4FFF9F5FAFFECFFFFFFFFEDFBFA
FFEAFEFFFFFFFCFFF6F8F4FFFBFAFBFFFFFFFFF7FFF6FFFBFBEAFFFFFBFFFFFFEDFFFFF4
FBFFFFF8FDFFF2FFFEFBFDFFFEFFFFFFFEFFFDFFFCFFFFFFF6FFBC6DFFFAFAFCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF1FFF2FAFFFAFFFFF5FFFFFFFFF6FCFBFFE9FFF7F5FFFFF7
FFFEFFFFF3FFFFF5EFFCFFF4FFFFFFFBFBFFFFEFFDFFEDFFFBFFF5FFFFFBF2FFFFECFFFF
FFF7FFFBFFE3FFFFFBFFFDF5F9FFFFFFECFFFBF5FFF8FDF5FFF8FDF7FFFAFFF6FEFFE8FF
F5FFFFFFFFF6FCFBFFE9FFF7F5FFFFF7FFFEFFFFF3FFFFF5EFFCFFF4FFFFFFFBFBFFFFEF
FDFFEDFFFBFFF5FFFFFBF2FFFFECFFFFFFF7FFFBFFE3FFFFFBFFFDF5F9FFFFFFECFFFBF5
FFF8FDF5FFF8FDF7FFFAFFF6FEFFE8FFF5FFFFFFFFF6FCFBFFE9FFF7F5FFFFF7FFFEFFFF
F3FFFFF5EFFCFFF4FFFFFFFBFBFFFFEFFDFFEDFFFBFFF5FFFFFBF2FFFFECFFFFFFF7FFFB
FFE3FFFFFBFFFDF5F9FFFFFFECFFFBF5FFF8FDF5FFF8FDF7FFFFE8D4FFF8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF2FC4BBBFFF53A070007CBFBF73FBEFFFF37000C
00B9FFF147C1F5FF43050400CBFFF243C5F5F94B00020BB7FFEB4AB5FAFF41000300C1FF
F250B2FFFA450E0012B3FBFF3EBCFFEE4B0A000FBFFAFF50B1FFFF4206000AC5FFFA4AB2
FFF53A070007CBFBF73FBEFFFF37000C00B9FFF147C1F5FF43050400CBFFF243C5F5F94B
00020BB7FFEB4AB5FAFF41000300C1FFF250B2FFFA450E0012B3FBFF3EBCFFEE4B0A000F
BFFAFF50B1FFFF4206000AC5FFFA4AB2FFF53A070007CBFBF73FBEFFFF37000C00B9FFF1
47C1F5FF43050400CBFFF243C5F5F94B00020BB7FFEB4AB5FAFF41000300C1FFF250B2FF
FA450E0012B3FBFF3EBCFFEE4B0A000FBFFAFF50B1FFFF42000011BEEDFFF9FEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Text",
  ImageSize->{720, 540},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;@000271000`40O003h00OogooogoodWoo003o
OoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoo
dWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00
ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomo
om9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol0
0?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOooo
OooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo
003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogoo
ogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9o
o`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mo
oomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooB
Ool00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003o
OoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoo
dWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00
ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomo
om9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol0
0?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOooo
OooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo
003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogoo
ogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9o
o`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mo
oomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooB
Ool00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003o
OoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoo
dWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00
ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomo
om9oo`00ogooogoodWoo003oOoooOooBOol00?mooaAoo`05NmioogooOomkgP0>Ool00g_NOomoo`02
Ool00g_NOomoo`06Ool00gNmOomoo`04Ool00g_NOomoo`3@Ool00g_NOomoo`05Ool00g_NOomoo`02
Ool00g_NOomoo`04Ool00g_NOomoo`03Ool00g_NOomg_@02Ool01G_NOomkgWooNmh00Woo00=kgWoo
Ool0VGoo003oOol;Ool00g_NOomoo`02Ool017_NOomcW7_N0goo00=g_GooOol00goo00=g_G_NOol0
0goo00AkgWooOomoo`9kgPIoo`06Mkeoog_NOomkgVmk1Goo00=g_G_NOol00goo00=kgWooOol0b7oo
00AkgWooNmikgP=oo`05NmioogooOomkgP03Ool00g_NOomoo`03Ool00fmkOomoo`02Ool00gNmOomk
gP02Ool00g>LOomoo`04Ool017_NOomoog_N0Woo00=kgWooOol0Ugoo003oOol:Ool00g_NOomoo`0;
Ool00gNmOomoo`05Ool00g_NOomoo`02Ool2Nmh5Ool00g_NOomoo`09Ool00g_NOomoo`3AOol017_N
Oomoog_N1Woo00AkgWooOomkgP=oo`03Nmioogoo00Qoo`07NmioogooOomkgWooNmh00goo00=kgWoo
Ool00Woo00=kgWooOol0Ugoo003oOol;Ool00gNmOomoo`05Ool00gNmOomoo`08Ool00g_NOomoo`07
Ool017_NOomoog_N17oo00=cW7ooNmh00Woo00=g_GooNmh00goo0WNmcgoo00<48GooOol00goo0W_N
0P0000Eoo`00Oomoog_N0080000:249g_GooNmh48@00Oomg_G_NOol300002WooMkeoogoo124000@Q
Nmioog_NWGoo003oOol9Ool01FLiNmioogooF]H00goo00ENmf<HJeYS67_N009oo`08HaQoogooOomJ
eV<HJeYF]@=oo`04HaQg_GooNmh4HaP2Ool00g_NIcUoo`02Ool015kgJeYJeV<H0Woo00Eg_EkgOomo
og_N009oo`03Nmioogoo0<Yoo`04001oogooNmh3Ool00`00Oomoo`0200000gooMkd48@03Ool00`00
Ool00002Ool01000OomkgP@Q0Woo00EkgP00Oomoo`00009oo`03Mkd007oo00Aoo`03Nmioogoo09Mo
o`00ogoo2Goo00DLifLiOomoob4800=oo`@Li`=oo`0=7>MoogooOol]Ja248@PLig_NOomkgRDYNmh0
0Woo00@HaR486<HU:@=oo`09001oog_NOolU:AS69BTQ27>L009oo`039BUg_Goo009oo`03Nmioogoo
0<Uoo`9kgP03125oogoo009oo`03Nmioo`0000=oo`04125oogoo0005Ool00`00Oomoo`02Nmh00goo
001kgP09Ool00`00Nmioo`2MOol00?moo`Uoo`087>M[FWooMkeoog_NOomkgPQoo`04NmioogNmNmh4
Ool01G>LOomoogooNmh017oo00IkgWooOomoog_N0004Ool00g_NOomoo`02Ool00g_NOomJeP3>Ool0
0g_NOol00002Nmh00gooMkeoo`02Ool40002Ool3000010Q2001kgP@Q17oo00=g_@0024800P0000@4
8GooOomoo`<0009oo`03Nmioogoo009oo`03Nmioogoo09Ioo`00ogoo2Goo00<Q25JeOol00goo00@0
07ooOomkgP9oo`03001oo`@Q00=oo`@0009oo`08125kgWooNmh48GooMkd48@80009oo`05Nmioo`00
OomkgP02Ool01000124007_N0Woo00=S61S6Ool0cWoo00EkgP0000048@0000Aoo`04Nmioogoo1242
Ool01`00Oomoogoo001oo`00009oo`05Nmioogoo125g_@02Ool01000Mkeoo`0017oo00EkgWooOomo
og_N09Yoo`00ogoo2Goo00<Q26<HNmh00Woo00=g_@00Ool00goo00L48G_NOol007_NOol00003Ool0
1@00Nmioo`@QNmh00Woo00<007oo00000goo00D007ooOomoo`00009oo`03Nmh007_N009oo`05001o
ogooJeX<H`3?Ool00g_N125kgP05Ool02000OomkgWoo125kgWoo0003Ool00`00Nmh48@02Ool01000
Oomoo`000goo00T48GooNmh007ooMkeoo`@QNmh00goo00=kgWooNmh0V7oo003oOol9Ool00g_NOomo
o`02Ool01W_N249oog_NOol0009oo`05Nmh007ooNmh00003Ool01000Oomg_@000goo00<007oo1240
17oo0W_N00<48Goo00000Woo00akgWooNmioo`@QNmioog>L48Aoog_NMkg;Ool01G_NOol007ooNmh0
0goo00=g_Goo00000P0000AkgWooNmioo`800004125oogooOol20004Ool3000027_NOomoogoo0008
@P00Nmh4Ool00gNmOomoo`2HOol00?moo`eoo`08Kg]oo`00001oo`00OomcW09oo`04001oogoo0002
Ool01G_N001kgWoo00000Woo00=g_@Q2Ool0100000X48G>LOol48G_N001kgWooNmh48@8000=oo`03
Li`]Jgoo00=oo`03Nmioogoo0<Uoo`05001kgWooOomkgP0:Ool027_NOomoog_NOomkgWooNmh4Ool0
0g_NOomoo`02Ool00g_NOomkgP03Ool00g_NOomoo`2LOol00?moo`Uoo`03Nmioogoo00=oo`03001o
o`0000=oo`06Nmioo`00Oomg_@000goo00@48G_NOol000=oo`03001kgPQ200=oo`06001oog_N001o
o`000Woo00@<Hg>LOomoo`9kgPAoo`03Nmioogoo0<Uoo`03Nmioog_N00@00005125oogooOomkgP06
Ool00g_NOomoo`0DOol017_NOomoogNmVgoo003oOol9Ool011cWHaQoog_N0Woo00H007ooOol007oo
Nmh2Ool010aSOomoo`000Woo0P000Woo0P0000Eoog>L001oo`00009oo`05Mkd007oo001kgP02Ool0
0`@QOol00003Ool00`00Oomoo`02Ool00g_NOomoo`02Nmk?Ool00g_NOomkgP07Ool00gNmOomoo`02
Nmh2Ool00g_NOomoo`04Ool01g_NOomoogooMkeoog_N0:9oo`00ogoo2Woo00IkgWooOomkgWoo2482
Ool00gNm001oo`02Ool01000NmikgWoo0P0000Qoo`00Oomoo`00Nmh48@000Woo00eg_@00000007oo
Li`48GooNmioo`00Nmioo`0300001GooNmioog_NG_L0cWoo00Eg_G_NOomoog_N009oo`05Nmioogoo
MkekgP06Ool00g_NOomoo`0:Ool00gNmOomkgP05Ool00g_NOomkgP2MOol00?moo`moo`03001oogoo
009oo`03001oogoo00=oo`07Mkeoog_NOol007ooNmh00goo00=kgWooOol01goo00=cW7ooOol00goo
0W_N17oo00=_NcF]Nmh00Woo00=kgWNmOol0agoo00=kgWooOol00Woo00EkgWooOomoogNm00=oo`06
NmioogNmNmioog_N0goo00=g_GooOol00Woo0WNm17oo00=g_GooNmh027oo00=kgWooOol0VGoo003o
Ool:Ool01W_NOomoog_NOol48@Aoo`04Nmh48G_N0002Nmh4Ool00`00Oomoo`0<Ool00g_NOomoo`0;
Ool00g>LOomkgP3>Ool017_NOomoog_N17oo00=kgWooOol02Goo00=kgWooOol02Woo00=kgWooOol0
0Woo00=kgWooOol00goo00=kgWooOol0UWoo003oOol9Ool01248HaQoog_N;Woo00=g_GooOol0igoo
00=kgWooOol017oo00=kgWooOol0XWoo003oOol9Ool00aS6HaQoo`0=Ool00gNmOomoo`07Ool2Nmh3
Ool00g_NOomoo`03Ool2Nmh;Ool01VLiOomoogNmOomkg/aoo`04MkeoogooMkd7Ool00g_NOomoo`06
Ool2Nmh01GooNmioogooNmh01goo00=kgWooOol0Wgoo003oOol9Ool012DYG_MkgWNm3Woo00=kgWoo
Ool02goo00=kgWooOol03Woo00=[FPaSOol00Woo00=kgWooOol0eGoo00YNmd8@>Lh]Jb487>LQ236<
AS5BU0Aoo`08NmioogooNmioog_NOomkgZAoo`00ogoo2Goo00<Lie[FOol00goo00=kgWooOol01goo
00Ag_GooOomkgP]oo`03Nmioogoo00Eoo`03Mkeoogoo00Moo`03Li`8@Woo0<moo`03Nmioogoo009g
_@9oo`0ANmiJeRDY248Lid8@AS5>LekgHaQNmdic>LhYBP@Q8@Q6<@02Ool2Nmh8Ool00g_NOomoo`2N
Ool00?moo`aoo`03Nmioogoo01]oo`03Nmioogoo00eoo`04Li`DYGooNmkDOol01Dic8@PYBUJeMkd0
2goo00AJeSF]1256<@=oo`03Nmioogoo00Aoo`03Nmioogoo09ioo`00ogoo6Woo00QkgWooOomg_E[F
@Q0]JacW0R4800DLibDY>LiF]Fmk00=oo`9kgPaoo`03Li`U:Goo0<eoo`04NmioogooNmh2Ool01FLi
48@e[F<HNmh017oo00=kgWooOol017oo00=kgWooOol00Woo00@aS0Q2G_MkgP9oo`03MkekgWoo0:=o
o`00ogoo47oo00=kgWooOol01goo00MkgUJe8@P48B48AS5:DP02G_L2HaP01e[FAS4U:A245:E6<GNm
019oo`03Nmioogoo0<]oo`07NmioogooE[DLifmkNmh04goo00AkgRe[>LikgZMoo`00ogoo2Goo00<U
:EJeOol03Goo00A6<AS69BUNm`aoo`05Kg/aS1BU?NmcW00<Ool00gNmOomoo`02Ool00g_NOomoo`39
Ool01W_NOomoocW>:DYg_AIoo`04Mke6<BU:LibVOol00:=oo`03Nmioogoo009oo`03Nmioogoo009o
o`05NmioogooOomkgP05Ool00g_NOomoo`0FOol00g_NOomoo`07Ool01W_NOomoog_NOomkgPAoo`04
NmioogooNmh3Ool00g_NOomoo`02Ool00g_NOomoo`03Ool00g_NOomoo`0@Ool017_NOomoog_N2Goo
00AW>A24=JeW>@9oo`03Nmioogoo00]oo`04MkdicQS6CW<5Ool00g_NOomkgP04Ool015[FOomoog_N
bgoo00EkgWooOolicT8@00Eoo`04001oogooNmh2Ool00`00Oomoo`03Ool01@00Oomoogoo000017oo
00=JeRU:Ool017oo00=kgWooOol0WWoo002NOol017_NOomoog_N17oo00EkgWooOomoogNm00Uoo`03
Nmioog_N01ioo`03Nmioogoo00Ioo`03Kg]oogoo009oo`06NmioogooNmioogNm0goo00=g_GooOol0
1Woo00=g_GooOol06Woo00Eg_GooNmi:DQS6009kgPIoo`03Nmioogoo00Ioo`05NmioogooOomcW002
<H`017_NOomoog_N17oo00AkgWooMkdaS0Aoo`03Nmioogoo0<Moo`04NmioodYB=Jd6Ool00`00Oomg
_@03Ool02000Oomoog_NOol007ooNmh5Ool02G_NOomoodic<Haoog_NOomkgP2QOol009ioo`05Liao
ogooOomkgP02Ool01GNmOomoogooMkd00Woo00=g_GooOol00goo0W_N9Woo00=kgWooOol00Woo00Ak
gWooOomg_@Aoo`04LiaoogooNmh2Ool01W_NOomoog_NOomkgQEoo`04MkeoogooNmh4Ool017_NOomo
ogoo0SW>0W_N0Woo0W_N3Woo0W_N00Eoog_NCW<U:GNm00=oo`03Mkeoogoo00=oo`03Nmioogoo0<eo
o`03HaPQ27Nm00Ioo`03001kgWoo00=oo`06001oog_NOomkgP000Woo00=kgWooOol01Goo00=kgSW>
@Q000Woo00=kgWooOol0Wgoo002QOol00g_NOomkgP04Ool00gNmOomoo`0VOol00g_NOomg_@02Ool0
1GNmOomoogooNmh00goo00AkgWooOomg_@Yoo`03Nmioog_N01Uoo`03:DYS67oo00=oo`03Nmioog_N
009oo`03<Ha247oo009oo`03Nmioogoo009oo`9kgPYoo`04MkeoogooNmh2Ool00e[F:DYkgP04Ool0
0g>LOomoo`02Ool01GNmOomkgWooMkd0bGoo00Ag_ABULiakgP=oo`03Nmioogoo00@0009oo`@00084
8@03Nmioogoo00Aoo`07Nmioog_NOomkgQcWIcT0Xgoo002MOol017_NOomcW7_N17oo00=kgWooOol0
0goo00=kgWooOol08Woo00=kgWooMkd01Goo00AkgWooOomg_@Ioo`04NmioogooNmh3Ool01GNmOomo
ogooNmh00Woo00AkgWooOomg_AAoo`036<INmgoo00=oo`07NmioogooOom6<Cg_Mkd06goo00=:DRe[
Nmh00Woo00YkgWooOomoog>LJeYoog_NOomcW<Yoo`03BU8e[G_N009oo`03Mkeoogoo009oo`03001o
og_N009oo`04Nmh48GooNmh2Ool01@00OomoogooNmh01Woo00AkgWooF]HU:@9oo`03Nmioogoo09io
o`00XWoo00=kgWooOol02Woo00MkgWooMkeoog_NOomkgP0POol2Nmh2Ool2Nmh2Ool2Nmh00gooMkeo
o`02Ool00g_NOomoo`07Ool00g_NOomoo`02Ool00g_NOomkgP0AOol01248HaQoog_N1Goo00ANmacW
OomkgP9oo`9kgP9oo`03Nmioogoo00Yoo`03Nmioogoo009oo`07Nmig_GooOom243g_Nmh00Woo00Ek
gWooOomg_@Q200Aoo`03Mkeoogoo0<Ioo`05Kg/Lig>LOomkgP03Ool01G_NOomg_@Q2Mkd017oo00<0
07ooNmh00Woo00=kgP00Ool00Woo00<48G_NOol00W_N17oo00<U:E[FOol0XGoo002LOol01G_NOom_
NgooNmh00Woo00Yg_GooOomg_GooNmioogNmOomcW0Uoo`03Mkeoogoo01Moo`03Nmh000@Q00<000=o
o`04001oogooNmh2000017oo001oogoo0P0000<8@P00Ool00Woo00@000@Q000000=oo`<00004Oomg
_Goo000@Ool00b48F]Ioo`02Ool2Nmh2Ool00`@QMkeoo`0:Ool00g_NOomoo`0>Ool01W_NOomoo`aS
MkekgP9oo`07Nmioofmk5:EkgWooNmh0bWoo00A243g_OomkgPMoo`80000712400000Mkd48@001240
0P000Woo0`0000=kgWooOol00Woo00IkgWooOomkgU[F8@RROol009ioo`<00005OomkgWooNmh00003
Ool01000Oomoo`000goo00@007ooOomoo`800003125oogoo01Qoo`03001oogoo009oo`04001oogoo
0002Ool00`00Oomoo`0200001Woo001oogooNmh48@9oo`05001kgWooOol00002Ool02000Oomoogoo
001kgWoo000COol00g_NOomoo`02Ool00cW>AS5oo`02Ool00g_NOomoo`02Ool00g_NOomoo`0EOol0
16<H5:Eoog_N0goo00=[FQ24Ool0c7oo00<LiekgOol04goo00=kgWooNmh01Woo00QkgWooOomkgWoo
Nmh@Q7_NXGoo002JOol017_NOomoo`000goo00D007ooOomkgP0000=oo`0<001oogoo001oog_NOol0
07_NOol007Nm0Woo00<007ooOol05goo00<007_NOol00Woo00L007ooOol007NmOol00003Ool00`@Q
Nmh48@03Ool01000Oomoo`000goo00P007ooOol007_NMkeoog_N0Woo00<007_NOol00goo00=kgWoo
Ool037oo00EkgWooOomcW1BU01Aoo`03Mkeoogoo00Uoo`05NmioobU:F]IkgP03Ool00gNm:DYoo`3;
Ool00f]J6<IkgP08Ool01W_NOomoog_NOomkgPAoo`03MkekgWoo00=oo`03Nmioogoo00Ioo`04Nmio
ocW>AS6QOol009aoo`03001oogoo00=oo`05001oogoo001g_@02Ool03@00Nmioo`@QNmioog_N001o
ogNm001oog_N01]oo`06001oogooOomkgP000Woo00@8@WooNmioo`@00006Nmh007ooNmioo`000Woo
00X48GooOomoo`00Nmioo`00124<H`800003Oomg_@0000Moo`03Mkeoogoo00aoo`03Nmi243g_015o
o`03Mkeoogoo009oo`03Nmioogoo00Uoo`03G_LQ27oo00Moo`03Nmioogoo0<Ioo`03Nmi>Lc6<00Mo
o`03Nmioogoo00=oo`06NmioogooMkeoog_N17oo00=g_GooOol02Woo00=:DSF]Ool0X7oo002IOol2
Nmh01Goo001oogooNmh00Woo00P007ooOol007ooNmioo`000Woo00L007ooOomoo`@QNmioo`040000
0`@QOomoo`0GOol500001@@QOomkgP00Nmh01Goo00<007oo00000goo00D007ooNmh48GNm009oo`04
001oogoo1242Mkd01goo001kgWoo001oofmk00ioo`038@QJeWoo00Aoo`035:E[FWoo00moo`03Nmio
ogNm00aoo`06NmioogooOol8@Vmk1Goo00EkgWooOomoog_N0<Moo`03?Nm6<Goo00Uoo`04Nmioogoo
Mkd5Ool00fmkOomoo`04Ool00gNmOomoo`07Ool00f<H7>Moo`2POol009aoo`03001oogoo009oo`05
Kg/007ooOol00002Ool01G_N125oog>L12400goo00@007NmOol48@9oo`03Nmh007oo01Qoo`03001o
ogNm009oo`04001oogoo0002Ool02`00Oomoog_N001oo`@QMkeoo`0024800Woo00P007ooOol000@Q
Oomg_@000goo00<007_NOol00P001Woo00=g_GooOol02Goo00Eg_GooOom[FPaS011oo`03Nmioog_N
00=oo`03Mkeoogoo00]oo`03<Ha:DWoo009oo`03NmiJeWoo0<]oo`04<HaBU7ooNmh<Ool017_NOomo
og_N0goo00AkgWooNmikgPAoo`03Nmioogoo009oo`04NmioogNm24:QOol009Qoo`0;NmioogooNmh0
07ooMkeoog_NOol48@02Ool200001G_NOol007NmOol00P000Woo00D48GooOol007_N009oo`03001o
ogoo01Moo`03001kgWoo009oo`04001oog_N0003Ool30003Ool010@Q001kgP000goo0P0000=oo`00
Mkd00Woo0`000goo00<007oo00000goo00=kgWooOol02Goo00UkgWooOomoogNmCW=247ooNmh04goo
00=kgWooOol02Goo00EkgWooNmiJeRDY00=oo`03Kg/e[G_N009oo`03Nmig_Goo0<=oo`05Nmioogoo
8@QNm`09Ool017_NOomoog_N0goo00=kgWooOol03goo00AkgWooOol00:5oo`00VWoo00AkgWoo125g
_@Aoo`08001oogNm001oo`00Ool8@P9oo`04125g_@@Q0002Ool00g_NOol00002000JOol00`@QOomo
o`02Ool02000Oomoo`00MkekgWooNmh3Ool00g_NOomg_@02Ool00`00Oomoo`04Ool00`00NmikgP02
Ool00gNmOomoo`04Ool00g_NOomoo`0=Ool00g_NOomoo`02Ool00c6<?Nmoo`0@Ool00g_NOomoo`0@
Ool00f<H5:Eoo`03Ool00g_NOomoo`3:Ool00acWHaQoo`0:Ool00fmkOomoo`03000010@Q001kgP@Q
0P0000EcW7ooNmioog_N00Uoo`03001oogoo09moo`00W7oo00@007ooOomg_@9oo`05001oog_NOomg
_@04Ool2NmhSOol00g_N00048@030002Ool01g_N125oogooNmioog_N00Ioo`03Nmh007oo00=oo`04
Nmioo`@QNmh4Ool00g>LOomoo`08Ool00g_NOomoo`07Ool00bDYHaQoo`03Ool00be[E[Eoo`04Ool0
0g_NOomoo`09Ool4000?Ool00fmk249oo`04Ool00g_NOomoo`32Ool00g_NOomoo`04Ool00bU:E[Ek
gP06Ool00g_NOomkgP05Ool02P00Oomoogoo001oog_NOol8@WNm17oo00=kgWooOol017oo00=g_@Q2
Ool0X7oo002KOol00g_N001oo`04Ool00`00Oomoo`04Ool00`00Oomoo`0VOol00g_NOomoo`02Ool0
0g_NOomkgP09Ool00g_NOomoo`06Ool00g_NOomoo`08Ool00g_NOomoo`0>Ool00acWG_Moo`02Ool0
0gNm8@QNm`05Ool00g_NOomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00gNmOol00003Ool0
0gNmIcUoo`02Ool00g_NOomoo`36Ool00c6<CW=kgP04Ool017_NOomoog_N0Woo00=kgWooOol00Woo
00@48GooOol0009oo`05Nmh007ooOomkgP02Ool00g_NOomoo`04Ool00fmk48Aoo`2POol00?moo`Uo
o`038@QJeWoo00=oo`039BUNmgoo00Aoo`03Nmioogoo00Qoo`06001kgWooNmioo`002Woo00=kgWoo
Ool00Woo00H007ooOomoofmk2483Ool00g_NOomoo`1AOol00gNmOomkgP04Ool00g_NOomoo`05Ool0
0g_NOomoo`03Ool00g_NOomoo`1MOol01D8@?NmoogooNmh03Woo00@007oo125kgP9oo`05001oogoo
OomkgP07Ool00g_NG_LQ202QOol00?moo`Aoo`03Nmioogoo009oo`038@QNmg_N00=oo`039BUF]Goo
00moo`03001oogoo009oo`03001oogoo00aoo`0:Li`8@WooNmioog>L5:EkgWooNmiCOol00g_NOomo
o`02Ool017_NOomoog_N17oo00=kgWooOol00goo00=kgWooOol0Fgoo00=kgWooOol00Woo00ANmaS6
OomkgP9oo`9kgPaoo`8000=oo`03001oogoo009oo`03Nmioogoo00=oo`04Nmioocg_?NnQOol00?mo
o`9oo`05LiaoogooNmig_@05Ool01F]JBU9kgT8@BU8047oo00<007ooOol00Woo00<007NmOol02Goo
00EkgWooOomW>AS600=oo`03JeX<Hgoo05Qoo`06NmioogooOomkgWoo0W_N17oo00=kgWooNmh0Ggoo
00=kgWooOol00Woo00EkgQBUIcUoog_N00Ioo`03Nmioogoo009oo`9kgP9oo`800004OomcW7oo0002
Ool037_NOomoogooNmioog_NOomkgWoo48A_Nj5oo`00ogoo17oo00ekgWooOomoog_NOomNmcW>36<Y
BWooBU8aS00AOol4000?Ool00e[F:DYg_@02Ool00gNm;F]oo`02Ool00g_NOomoo`1?Ool00g_NOomo
o`03Ool2Nmh5Ool00g_NOomkgP1ROol00g_NOomoo`03Ool00c6<CW=oo`04Ool2Nmh3Ool01GNmOomg
_@@QNmh00Woo0P000goo00<007NmOol00Woo00=kgWooOol00Woo00IkgWooJeX<HgooNmjPOol00?mo
o`Aoo`09NmioogooMkeJeQBU36=6<G>L009oo`03G_LLigoo00moo`03001oogoo009oo`03001oog_N
00aoo`03=Je6<G_N00=oo`03Mkeoogoo05Aoo`9kgP9oo`05NmioogooOom_N`02Ool00g_NOomoo`02
Ool017_NOomoogNmHgoo00IS61cWOomkgWooNmh2Ool00g_NOomg_@02Ool017NmNmioo`@Q0P000Woo
00<000@Q00000Woo00=kgWooOol01goo00@e[Cg_OomkgZ1oo`00ogoo0goo00QkgWooNmh]J`@Q:DX@
Q6Li1Goo00<DYF]JOol017oo00=kgWooOol01goo00<007ooNmh00Woo00<007ooOol027oo00MkgWoo
Oomooa24Kg]oo`02Nmh00gooNmioo`1HOol2Nmh2Ool00g_NOomkgP06Ool00g_NOomoo`1OOol00g_N
Oomoo`03Ool00b48DYAoo`02Ool01g_NOomoogooNmioog_N00Moo`03Mkeoog_N009oo`03Mkeoogoo
00Moo`04JeX@Q7ooMkfQOol00?moo`=oo`05G_LLi`Q2>LicW003Ool01g_NOomoogNmOole[Cg_00mo
o`03001oogoo009oo`03001oogoo00]oo`03HaPLigoo00=oo`03Nmi:DWoo009oo`03Nmioogoo051o
o`03Mkeoogoo00]oo`9kgPAoo`03Mkeoogoo065oo`04Li`@Q7ooNmh2Ool00g_NOomkgP03Ool017_N
OomkgWNm17oo00=kgWooOol00goo0W_N17oo00Ag_Goo9BUJeZ=oo`00oWoo0W_N00@mka246<IF]@]o
o`03JeXHaWoo00moo`@000eoo`05NmhicT8@OomkgP02Ool00g_N@Q1oo`1EOol30003Ool00g_NOol0
0002Ool01W_NOomoogoo125kgP=oo`03Nmioog_N05Uoo`03Nmioogoo00Ioo`03AS4icWoo00Ioo`03
Mkeoogoo00Ioo`03Nmioogoo00=oo`04NmioogooNmh2Ool017_NOomF]BDYY7oo003DOol00g_NOomo
o`04Ool00g_NOomoo`0<Ool2Nmh6Ool01g_NOomoof<H<Haoog_N00=oo`06NmiW>BU:248icV<H0Woo
0W_N1Goo00=kgWooOol00Woo00<mkdHaOol00goo00=kgWooOol06Goo00AW>AS6OomkgP=oo`03Nmio
ogoo051oo`03Nmioog_N00=oo`07001oog_NOomkgWoo00000Woo00=kgWooOol00goo00<007ooOol0
0goo00=g_GooOol0HGoo00@YBU:DOomg_@=oo`9kgP]oo`03Nmioogoo00Moo`04Kg/Lig_NMkfSOol0
09]oo`03Nmioogoo00Eoo`9kgP]oo`03Mkeoogoo00Aoo`03Nmioogoo01Moo`9kgPUoo`03NmioogNm
00Aoo`04NmioogooNmh2Ool017_NOomoogNm1goo00E[FQBU249_Ngoo009kgP04F]H@Q1S6DY@9Ool0
0b48F]Ioo`02Ool2Nmh017ooLi`HaVmk0Woo00AkgWooOomkgQIoo`05Nmioogoo6<IJeP02Ool00g_N
OomkgP1@Ool00g>LOomkgP02Ool01G_NOomoogoo00000Woo00=g_Goo00001Goo00=kgWooOol00Woo
00<007_NNmh0IGoo00Ag_G_N9BUNm`9oo`03Nmioogoo00eoo`03Nmioogoo00Eoo`03Mkd@Q7Nm00=o
o`03Nmioogoo09moo`00WWoo0W_N=Woo00=kgWooOol01goo00aNmdHa>Lh]JacW:DXicSg_@Q1cW7Nm
Nmh5Ool017_NOomoo`Q20P0000IBU7Nm;F/48Be[F]H2Ool017_NOomoog_N1Goo00@Q26<HOomkgPEo
o`04DY@aS7ooNmh6Ool00g_NOomoo`0;Ool01G_NOomoogooNmh00goo00M:DRe[248000Q25:DYBP02
>Lh00bU:Kg]kgP15Ool00g_NOomoo`02Ool01g_N124000@QOomg_G_N00Aoo`03001oogoo009oo`03
001oog_N008000Eoo`07Nmh007ooOomkgWooMkd0I7oo00AkgQS6CW=g_@9oo`9kgPYoo`9kgPMoo`06
G_LHaW>LOomg_G_NXgoo002dOol2NmhJOol017_NOomoog_N1goo00]kgWNmCW<aS0@Q8@PicTHaDYAS
65Je00924007?Nl<Ha24>LiS67ooNmh017oo00<HaP@Q00000P0000<48DYBMkd00goo00=kgWooOol0
17oo0W_N00=ooaS6G_L017oo00IkgWooOomoocF]BU8EOol017_NOomoog_N0goo00IS62DYOomNm`00
124500000g>LOomoo`12Ool02G_NOomoogooMkeoogNm125kgP02Ool00`@Q001oo`04Ool01@00Nmio
ogoo00000goo00L007oo001oog_NOomkgP02Ool00`00Oomoo`1SOol027_NOomoogooLi`aS3g_NmhD
Ool01G_NCW<LifmkLi`0YWoo002JOol00g_NOomoo`07Ool016mkCW<icSF]0b4800DYBSW>DYA[FW_N
00Moo`03Mkeoogoo01eoo`9kgP9oo`07DY@DYBe[BU9kgWooNmh00Woo00=kgWooOol00goo00E[FTHa
8@PQ26<H00=oo`039BT0000000<00005HaQoogooOomkgP0;Ool00bU:HaQoo`03Ool01g_NOomoog_N
OolU:Dic00=oo`03Nmioogoo00=oo`03Nmioogoo00eoo`03MkeW>ABU00=oo`078@P00000124000@Q
2480AGoo00=kgWooMkd00Woo00Ag_G_NOol0009oo`04Mkd48GooNmh3Ool01`00Oomoogoo001oog_N
009oo`09001oogooOomkgWooNmioo`00009oo`03Liaoogoo05moo`03NmioogNm00Aoo`04@Q0HaTic
NmhAOol00f<H9BT]J`04Ool01G_NOomoogooNmh0X7oo002HOol00g_NOomoo`06Ool01Fmk?Nl<H`Q2
<H`00TYB00aJeUkgF]IBU48@;F/HaPaS<HacW7ooMkd2Ool00gNmOomoo`0LOol027_NOomoogooHaP8
@RU:Mkd3Ool00g_NOomoo`03Ool00gNmOomkgP04Ool01Ekg8@PHaVmk?Nl01P0000<]JgNmOol00goo
00=kgWooNmh00Woo00=kgWooOol00Woo00Ag_GooOomkgPAoo`06NmioogooNmh]Jcg_67oo00MNmacW
Kg]oogNmOomg_@0500000`Q2Oomoo`15Ool00g_NOomkgP03Ool01PQ2LiaoogooMkd8@P=oo`80009o
o`03Mkd007oo009oo`05Nmh007ooOomkgP03Ool017_N001oogNmJWoo00M_Nc6<6<I6<G_NOomkgP0;
Ool015[F8@PHaU[F0Woo00=g_GooOol0YGoo002OOol01GNm:DXQ23W>Kg/00Woo00=g_GooOol017oo
00]kgWNmMke:DQBU=Jeg_GooNmioog_N01Uoo`04MkeoogooNmh2Ool017NmAS4Q26mk2Goo00=kgWoo
Ool01Goo011g_GooOomS61245:DYBQS600048@00124007NmOomkgP9oo`03Nmioogoo00moo`09Nmio
og_NOomkgTHa8@Qoog_N00moo`03Mkeoogoo009oo`0@>LhU:G>LOomkgWooNmioodYB00048@008@PL
iekgMke4Ool027_NOomoogooNmioog_N0002Ool00g_NOol00003Ool00g_NOomoo`02Ool00`Q2Mkeo
o`02Ool01@@QNmioogooMkd00goo00D007ooOomoog_N065oo`07NmioogooOomkgWooNmh00Woo00Q[
FS6<48@LidHaIcUcW7_N0goo00McW5kgDY@]J`@Q9BU[FP03Ool01G_NOomoogooMkd00goo00=kgWoo
Ool0WWoo002MOol01GNm@Q0<HeJeLi`00Woo00=kgWooOol02goo00A6<ABU>LikgR1oo`04Li`aS3W>
Nmh2Ool00g_NOomoo`0?Ool01G_NOomkgQcWAS400Woo00IkgWooG_MNmg_NMkd2Ool00g_NOomoo`02
Ool00g_NOomoo`04Ool017_NOomoog_N2Goo00AF]@aSCW=_N`moo`05NmiooeJe5:Dmk`04Ool037_N
OomkgW_N6<H003g_Oom6<ABU;F]cW4Eoo`03Mkeoogoo00=oo`05124007ooOol00004Ool01G_NOomo
ogoo00001Goo00<007ooLi`00Woo00=kgWoo00000Woo00=kgWooOol0Ggoo00=kgWooOol02Goo00Ik
gV<H>LhHaPaS124300001`aS8@P]Je:DNmioog_N009oo`04NmioogooMkfVOol0095oo`03Nmioogoo
00Qoo`04MkdLidHaNmh5Ool00gNmOomoo`0:Ool01G_NOom24248Li`00goo00IkgWooOomkgWooNmhE
Ool00g_N9BUJeP09Ool00`@QNmioo`02Ool00`00Ool00004Ool00g_NOomoo`02Ool01BU:BU9oogoo
Nmh01Goo00=cW7_NOol02Goo00<U:E[FOol037oo00MkgSW>7>Lmkg_NOomkgP0:Ool01G_NDY@Q22DY
JeX017oo00=kgWooOol00Woo00=JeQ24Ool00Woo00Ag_Be[5:E>LdYoo`04001oo`000009Ool00`00
Nmioo`02Ool30004Ool01G_N001oogooNmh087oo00=kgWooOol017oo00=kgWooOol04goo00=kgWoo
Ool05Goo00=kgWooOol06goo00=kgWooOol02Goo00=kgWooOol04goo00=kgWooOol02Woo00EkgWoo
Oomoog_N089oo`00TGoo00=kgWooOol00Woo00=g_GooOol00Woo00=cW124IcT00goo00IkgWooOomg
_GooNmh<Ool01G>LOomNma24Li`00goo00=cW7ooOol04goo00IkgWooNmiooc6<BU8:Ool02P00Oomo
ogooNmh007oo001g_G_N27oo00DYBUJeOomkgWNm009oo`05CW<@Q3g_Oomg_@09Ool017_NOomoog_N
3Goo019[FSW>48@DYD8@HaQNmg_NOomg_GooJeYNmcg_;F/48C6<HaP3Ool017NmOomoog_N1Goo00U_
NgNmOom247_NOomBU1cW9BT00W_N17oo00=kgWooOol00goo00=kgWooOol0>Goo00=kgP00Ool017oo
00=kgWooNmh017oo00MkgP@QOomoog_NOol00004Ool00gNm125oo`0MOol01G_NOomoogooNmh017oo
0W_N1Woo00Eg_GooOomoog>L00Aoo`07NmioogooOomkgWooNmh01Goo00=kgWooMkd01Goo00=g_G_N
Ool017oo0W_N1Woo00=g_GooMkd01Goo00=kgWooOol00Woo00MkgWooOomoog_NOomkgP02Ool00g_N
Oomoo`02Ool00f<H<HakgP03Ool00g_NOomoo`02Nmh6Ool01GNmOomoogooLi`017oo00MkgWooOomo
og_NOomkgP05Ool00g_NOomg_@05Ool00gNmOomoo`03Ool00g_NOomoo`20Ool009Ioo`07Nmioogoo
Oom_N`Q2Kg/01Goo00P007_NOomkgWoo125oo`000goo00@007ooOol000Eoo`05Li`DYEkgOomg_@02
Ool00g_NOomoo`0DOol2?Nl00g_NOomoo`08Ool02000Oomoog_NOol007oo1243Ool00gNmOomoo`02
Ool01GNmOomoob48HaP00Woo00E240aS000003g_00eoo`03Nmioogoo00]oo`0@NmioogooNmi[FT8@
8@PLi`Q200048@005:DU:DHaDY@2Ool00g_NOomoo`07Ool00g_NOomoo`02Ool02VmkBU9oog_NOomk
gSF]125:DW_N1Goo00=kgWooOol017oo00=kgWooOol0>7oo00@007ooOomg_@Ioo`9g_@03Ool007oo
00=oo`03001oogoo00=oo`03001kgWoo01moo`04NmioogooMkd8Ool00g_NOomoo`0:Ool00g_NOomo
o`0BOol00g_NOomoo`05Ool00g_NOomkgP07Ool00g_NOomoo`0@Ool017_NOolHaP@Q0W_N2goo00=k
gWooOol02Woo00=kgWooOol04goo00=kgWooOol0PWoo002COol00gNmOomoo`02Ool2Nmh00aBUMkeo
o`02Ool017_NOomoo`000goo00AkgP00Ool000=oo`06125oogoo001oog_N17oo00Eg_BDYLiaoogNm
00=oo`03Nmioogoo011oo`03NmiW>AS6009oo`03Nmioogoo00Moo`040008@P00248200000goo001o
o`0:Ool036<H5:E240Q200048@00125247NmOomkgPeoo`04NmioogooOol2Nmh7Ool01gNmNmioogoo
NmioogNm00=oo`03Nmioogoo00Eoo`03Mkeoogoo00Moo`9kgP=oo`03Nmioogoo009oo`06JeXLia24
HaQoog_N@Woo00=kgWoo00000goo00=kgWooMkd01goo00<007ooOol017oo00=kgWoo00007Woo00=k
gWooOol00goo00Eg_GooOomoog_N00Ioo`03Mkeoogoo00=oo`03Nmioogoo00ioo`04Nmioog_NNmh2
Ool00g_NOomkgP03Ool00gNmOomoo`02Ool017_NOomoog_N17oo00=g_GooOol00goo0W_N0Woo00=k
gWooOol01Goo00=kgWooMkd00Woo00AJeP00000mk`9oo`05LiaoogooOomkgP06Ool00gNmOomoo`03
Ool00g_NOomoo`0>Ool017_NOomkgW_N0Woo00=kgWooOol00g_NQ7oo002GOol01G_NOolLif<HNmh0
0Woo00Mg_GooOomoo`00OomkgP02Ool00`00Ool00002Ool02000Mkeoogoo001oog_NOol2Nmh017oo
NmiW>AcW0goo00=g_GooOol047oo00EkgWooOolQ25[F00aoo`03001g_Goo009oo`05001oo`00Oomg
_@02Ool00g_NOomoo`02Ool017_NOomcW0aS0P0000L48@00000000@Q36<Q20029BT03b487>LLib48
;F/icSg_5:D]JdHaE[ENmf<HG_MJeP05Ool2Nmh8Ool00g_NOomoo`08Ool00g_NOomoo`03Ool00g_N
Oomoo`0;Ool02G_NOomoogooE[D<HcW>OomkgP12Ool00`00249oo`02Nmh017ooNmioogoo0W_N00=o
ogNmOol00Woo00<007ooLi`017oo00P007ooOomoogNmNmioogNm7goo00=kgWooOol00Woo00EkgWNm
Oomoog_N00=oo`03Nmioogoo00Qoo`03Nmioogoo00Yoo`03Nmig_Goo00=oo`05NmioogooOomkgP04
Ool00g_NOomoo`05Ool00g_NOomoo`08Ool00g_NOomkgP02Ool00g_NOomoo`02Ool01ABU00000000
Li`01goo00EkgWNmOomoog_N00=oo`03Nmioogoo00Qoo`03Nmioogoo00Yoo`03Nmig_Goo00Ioo`03
Nmioogoo081oo`00UGoo00EkgWooOom2436<009oo`03Mkeoogoo00=oo`03001oog_N009oo`03125o
o`Q200@00003OomkgP0000=oo`03Nmioogoo009oo`03CW<e[G_N01Ioo`04G_LQ27ooNmh;Ool00`00
Oomoo`02Ool00`00Nmh00004Ool00g_NOomoo`05Ool00fLi48@00002000010Q2000mkf]J0Ukg00aF
]EkgHaQS65kgDYA6<Cg_36<]JcF]:DX29BT28@P200001P@Q48@HaR48;F/aS08icP04CW=S65kgJeX3
Ool01G_NOomg_GooMkd03Goo0W_N17oo00=kgTHaNmh01goo00Eg_BDY36=W>G_N041oo`03Mkeoog>L
00Qoo`05NmioogooOomg_@02Ool00g_NOomoo`03Nmh00gooNmikgP03Ool00g_NOomoo`0HOol00g_N
Oomoo`0=Ool00g_NOomkgP04Ool017_NOomoogoo0g_N4goo00=kgWooNmh02Woo00=kgWooNmh00Woo
00=kgWooOol02Woo00=kgWooOol00goo00=BU0@Q00000P@Q00<icWooMkd02Woo00=kgWooNmh017oo
00AkgWooOomoo`=kgQ5oo`04NmioogooNmh2Ool2Nmj0Ool009Moo`03JeX@Q7oo00=oo`03Mkeoog_N
009oo`03001oogoo009oo`03001g_@0000Aoo`04001oo`00Nmh4Ool01WNmOomoogoo36=cW1Ioo`03
8@QJeWoo009oo`03Nmioogoo00Moo`D0009oo`05125g_GooOomkgP02Ool017_NOomoog_N0goo00<a
S48@=Jd00P0000<48E:DOol01Woo00QkgWooOomoobDYHaQoog_N0Woo01EkgWooOomoog_NLiaW>Ekg
E[EBU4Ha@Q0mkbU:6<HLiaBU000<HacW9BT00T8@00=JeUkgLi`04Goo00E[FQ24Oomoog>L00=oo`08
NmioogooOomJePaS;F]cW0=oo`03Nmioogoo03aoo`03Nmioog_N00Ioo`03Nmioog_N00aoo`05Mkek
gWNmOomkgP0HOol00g_NOomkgP02Ool01DHa=JeoogooCW<00`0000PaS7NmOom:DSF]Nmiooe[F0`00
00DaS7ooOom6<CF]009oo`09CW<00000000e[G_NOomBU2DY009oo`09BU88@P00000]Jg_NOom:DSW>
009oo`0GCW<48@00124]Jg_NOom:DSg_Liaooe:D124000@Q=JekgWooE[D]Jg_NOom:DP0200001Q24
8@Qoogoo@Q0]J`9oo`04AS448@00124300001Dic=JeoogooCW<00`0000PaS7NmOom:DSF]Nmiooe[F
0`0000DaS7ooOom6<CF]009oo`09CW<00000000e[G_NOomBU2DY009oo`09BU88@P00000]Jg_NOom6
<CW>009oo`03BU848GNm081oo`00UWoo00=g_C6<E[D02Goo00T007ooNmioog_N125oo`@QNmh00Woo
00Ag_@Q2Nmh0009oo`03Nmioogoo00=oo`03NmiS624801Aoo`03Nmig_@aS00moo`03Nmioogoo009o
o`9kgP=oo`03Nmioog_N009oo`03Nmioog_N009oo`08HaPLig_NMkd]J`00DYAkgPYoo`037>MS67oo
00=oo`03Nmioog_N00Moo`07NmioogooHaPmkbDY48@01@000PaS00XHaQcW00048AS69BTicT8@E[ES
60Uoo`03Mkd<Hgoo00=oo`03Nmioogoo00Aoo`04Mkdmk`Q2BU8oOol00gNmOomoo`07Ool00g_NOomo
o`03Ool00gNmOomoo`02Ool01G_NOomoogooNmh0:Woo00=kgWooNmh01Goo00=kgWooOol00Woo00=k
gWooOol00goo00AkgWooOomkgP9oo`03Nmioogoo00Uoo`05Nmioog_NOomkgP02Ool00g_NOomoo`05
Ool017_NOomoog_N3Woo00AkgWooNmiNm`@00003124003g_00Moo`03Nmioog_N00Eoo`03Nmioogoo
009oo`03Nmioogoo00=oo`04NmioogooNmh2Ool00g_NOomoo`09Ool01WNmOomoogoo48A_Nh1oo`00
UWoo00=g_@aSOol02Goo00<007ooOol00Woo00<007_N12400P0000H48@00Oomoo`@QNmh3Ool00g_N
OomkgP03Ool00aBUKg]oo`02Ool017_NOomoog_N0goo00=kgWooOol01goo00=6<Cg_Ool00Woo00=k
gWooOol027oo00=kgWooOol00goo00AkgWooOomkgP=oo`03Nmioogoo00Eoo`08NmhHaVmkOomkgVmk
JeYkgQIoo`0;Mkeoog_NOom_Nc6<124LidHaF]I_N`04Ool067>LIcU:DRU:36<]Je[FKg]Nme:D?Nla
S24824848B48<H`e[EJeHaQkgWooLi`8@Peoo`06HaPHaQcWJeYoog_N2Goo00=kgWooOol0=Woo00=k
gWooOol00goo00=kgWooOol0D7oo0W_N:Woo00Ig_DHa7>LLiaBU36<28@P00bU:Nmioo`0^Ool00`aS
Kg]oo`1oOol009Ioo`03CW<aS7oo00Uoo`04NmioogooMkd4Ool00gNmOomkgP03Ool00g_NOomoo`02
Ool017NmOomoog_N0Woo0Sg_17oo0WNm00=oogNmOol02goo00<YBU:DOol00goo00=kgWooOol02Woo
00=kgWooOol017oo00Eg_GooOomoog_N00Moo`03<Ha>Lg_N01]oo`08Mkeoobe[48A>Lg_NOomkgP9o
o`03Nmioogoo00Eoo`05NmiBU1S67>MW>@02Ool017_NOomoogoo0U[F00]6<C6<8@P<H`@Q5:DLidHa
E[E_Ng_N00=oo`03Nmioogoo009oo`06NmioogooAS4<Hcg_1Goo00=kgWooOol0?Woo0W_N;Goo0W_N
00=ooacWOol037oo00=kgWooNmh05Woo00=kgWooOol087oo00=kgWooNmh017oo00EkgWooOomBU2e[
009oo`05NmioogooOomkgP0/Ool00dHaNmioo`1oOol009Ioo`038@QS67oo00Uoo`03Nmioogoo009o
o`05NmioogooOomkgP05Ool00g_NOomoo`06Ool00gNmJeXLi`02Ool2Nmh00gooNmhe[@03Ool00g_N
Oomoo`07Ool00a24Liaoo`0>Ool01GNmOomoogooMkd00Woo00Ig_GooOomg_GooNmh8Ool00dHa>Lio
o`0AOol027_NOomoogooNmig_GooNmh2Ool00e:D36=>L`08Ool00g_NOomoo`02Nmh5Ool00f<H6<HY
BP02Ool00g_NOomg_@02Ool00g_NOomkgP02Ool02e[FG_M243F]5:D48AcW;F]245kgMkd01Goo00Ik
gWooLi`U:ABUHaQ2Ool00g_NOomoo`0aOol00`00Oomoo`0?Ool00gNmOomoo`02Ool017_NKg]S65[F
1goo0W_N9goo00EkgWooOomoog_N00=oo`05NmiF]Be[OomkgP0_Ool00g_NOomoo`21Ool009Eoo`03
Nmh8@Woo00Uoo`03NmioogNm009oo`04NmioogooNmh7Ool017_NOomoogNm1Woo00=kgPaSKg/00Woo
00McW3F]124007ooMkekgP09Ool00g_N001kgP02Ool00g_NOomoo`0;Ool00g_NOomoo`02Ool00g_N
Mkeoo`0:Ool017_NOomBU36<0Woo00=kgWooNmh02Woo00<U:E[FOol01Woo00EkgWooOolmkbe[01=o
o`9kgP06OomBU124MkeoogNm0Woo00=kgWooOol00Woo00=g_GooOol00goo00akgV]JE[E6<BU:36<4
8A24;F]6<F<HNmh3Ool01E:D48@]Jg>LNmh01Goo00=kgWooOol0>goo00=kgWooOol0:Goo00Ig_Goo
Oomoo`00Nmh:Ool02WNmOomoog>LOomkgWooJeY6<AS60P0000<@Q2489BT00P0000@8@RU:E[EcW0Eo
o`03Nmioogoo02=oo`9kgPEoo`04Li`mkbDYLi`3Ool01G_NOomoogooNmh00Woo00=g_GooOol0Ygoo
002EOol00fmk48Aoo`0:Ool017NmNmioog_N0Woo00=kgWooOol017oo00=kgWooOol01Woo00UkgWoo
Oomoob48G_MW>D8@12400`000goo00=kgWooOol01Woo00=kgPQ2Ool03Woo00AkgWooOomg_@9oo`03
Nmioogoo00eoo`03G_LLigoo00ioo`03Nmioogoo00Aoo`06MkekgWooNmhLidHa2Woo00=g_GooOol0
2Woo00AkgV]J48A_N`9oo`9kgP=oo`04NmioogNmBU85Ool00g_NOomoo`02Ool016mkE[E241cW0PaS
00L]Jcg_HaQcW36<36=Nm`02Nmh2Ool017_NOomkgW_N=goo00EcW5kgG_MW>Ekg009S6003Nmioogoo
02Yoo`03125oogoo00]oo`9kgP06Oom:DPQ26<HicVLi0goo00ekgWooOomkgW>LF]HYBP@Q9BUNmgoo
MkekgP0ROol2Nmh4Ool01G_NE[DYBP@Q00000Q2400X<Ha24000002DYCW=_Ng_NOomg_@9oo`03Nmio
ogoo02=oo`9kgP03DYAcW7oo07moo`00UGoo00=NmbDYOol02Goo00AkgWooOomg_@Eoo`04Nmioogoo
Nmh2Ool00g_NOomkgP09Ool00bDY:DX@Q0050002G_L00fLiHaQS6007HaP00e[F48Aoo`0=Ool00gNm
125kgP03Ool01@Q2000007ooNmh037oo00=S61cWOol05Woo00AkgWoo8@QF]@9oo`9kgQ9oo`07Nmio
ogooOomkgQBUKg/00goo00=kgWooNmh00Woo00=cW5:DNmh03Goo00]g_G_NHaPicR4836<@Q248000Q
27_N03eoo`03BU8DYAS600<Li`03001_Ngoo02]oo`03E[Eoogoo00Yoo`07Mkeooe[F000mkf]JNmh0
1goo00=kgWooOol00goo00AF]AcW9BUW>@9oo`03Nmioogoo029oo`05G_LQ20Q28@QF]@02Ool00gNm
Oomoo`03Ool01Ekg=JdDY@Q2DY@0:goo00=>Lg_NOol0Ogoo002EOol00e:D;F]oo`0COol00g_NOomo
o`02Nmh4Ool00g_NOomoo`05Ool01AS61240000012400P0000D48AS68@PLiaS600PLi`03?Nl007Nm
00ioo`06001oogNmOol48G>L0Woo00@007ooOomkgPUoo`03NmiF]Be[019oo`03Nmioogoo00=oo`04
<Ha:DWooMkd6Ool01G_NOomoogooNmh02Goo00=kgWooOol00goo00E[FQS6Nmioog_N009oo`03Mkeo
ogoo00Aoo`04NmioogooNmh7Ool017_NOomoog_N0goo00YW>EJe@Q0<H`00248mke[FMkekgSMoo`04
Nmi2448@Nmh2Ool01WNm:DYS67_NOomkgREoo`04NmioogooNmh2Ool00g_NOomoo`08Ool01GNm9BTa
S7>LNmh01Goo0W_N0goo0W_N1Goo00=F]B48@Q0017oo00=g_GooOol077oo00Eg_F<H5:DaS5Je00]o
o`07NmioogooNmh]J`aSAS400Woo00=kgWooOol097oo00=cW7ooOol0Ogoo002EOol00dic;F]oo`08
Ool00g_NOomoo`03Ool00`00OomkgP02Ool00`@QOomkgP03Ool00g_NOomoo`03Ool2Nmh2Ool01G_N
@Q1243g_48@010000Woo00=kgWooOol027oo00<@Q7>LNmh03Goo00D007ooOomoo`@Q00=oo`03125k
gWoo00Eoo`03Nmioogoo009oo`03Nmi>Lc6<00moo`038@QJeWoo00Eoo`03CW<aS7oo01]oo`04Mkeo
oekg7>L8Ool00g_NOomoo`0FOol02Fmk6<H@Q1BU36<HaSF]F]IcW00eOol013W>@Q1oog_N0Woo00<Q
25kgOol0:goo00=kgWooOol02Goo00=W>AS6F]H04goo00QkgWooOolicRU:Mkeoofmk7Woo00EcW4Ha
6<IW>G_N00Eoo`05NmioogooOomg_@06Ool01G_NMkdaS248Mkd09Goo0W_N00=oog_NOol0Ogoo002E
Ool00eJe9BUoo`06Ool00g_NOomoo`02Ool017_NOomkgP000Woo00MkgWoo125oog_NOomkgP0<Ool0
1SF]BU9oog_NBU88@P800004OomkgWooNmh9Ool01AS6IcUoogooMkd00goo00AkgWooOomkgP=oo`03
Nmh8@Woo009oo`08001kgWooOol007_NOomkgPAoo`06NmioogooOomkgWoo0T8@3goo00<Q25kgOol0
0goo0W_N00<DYGNmOol00Woo00=kgWooOol06Goo00<]JeJeOol01Goo00=cW4icNmh057oo011kgWoo
NmikgWooAS4@Q3W>IcU6<BDY248@Q3F]E[Eg_C5oo`8mk`Aoo`037>MNmgoo02]oo`038@Qoogoo00Eo
o`0:NmioogooF]HHaWNmOomkgWooNmhDOol014ic7>MkgW_N0Woo00=kgWooOol037oo00=kgWooOol0
2Goo00=g_AcWAS400goo00EkgWooOomoog_N00Ioo`03Mkeoogoo00=oo`05Liaoof<H5:EW>@02Ool0
0g_NOomoo`07Ool200001Woo001oogooNmioo`800005Ool007ooNmioo`020002Ool20005Ool00dYB
Liaoo`1oOol0095oo`06MkeoogooNmiW>AcW2Woo0W_N00Eoog_NOol007_N00=oo`03001oogoo00eo
o`04NmhQ26<HNmh3Ool00dYB48Ag_@02Nmh:Ool2@Q0027ooNmioog_NOomkgWooNmh6Ool01P00Oomo
ogoo0008@P8000Aoo`07NmioogooOomkgWooNmh00goo00<LiekgOol00goo00=kgWooOol027oo00<H
aVLiMkd017oo00<aS4YBOol07goo00=[FQS6Nmh00goo00AkgWooKg/Lia]oo`04JeX]J`@QHaP2Ool0
1g>LBU8YBPQ27>LicVLi01Aoo`03Nmioogoo01Moo`8mk`Aoo`037>MNmgoo02]oo`04E[EoogooMkd5
Ool00g_NG_LLi`05Ool00g_NOol00002Ool01G_NOol48Goo00000Woo00AkgWooOol000Aoo`06Mkeo
oe[F9BUoog_N0goo00=g_GooOol04goo00UkgWooNmh@Q6LiOomkgWooNmh00Woo00I_NgooOomkgWoo
Nmh2Ool00gNmOomkgP02Ool027_NOomoogNmOom[FR48DY@2Ool00g_NOomoo`06Ool02P00Oomoo`00
OomkgWoo125kgWoo0P000Woo00P007ooOol007oo001oog_N17oo00<<HgooOol0Ogoo002AOol00g_N
Oomoo`02Mkd00`aSOomoo`08Ool00g_NOomoo`02Ool01`00OomoogooNmioo`0000ioo`04Nmh@Q7>L
Nmh4Ool01GNmOomoogooMkd02Goo00=S6248Mkd027oo00I_NgooOol007oo0002Ool00g_N001oo`02
Ool017_NOomoogNm0goo00UkgWooNmioog_NOomg_@Q2Nmh017oo00=kgWooOol027oo00@Q26<HNmio
o`9kgP03JeXQ27Nm025oo`03;F]6<Goo00Aoo`05Kg/007ooOomkgP0COol017_NOomoog_N0goo00AN
m`@Q;F]g_@Aoo`07F]I241BU248U:EJeLi`00Woo00=kgWooOol017oo00=kgWooOol07Woo0Sg_17oo
00<LiekgOol0<goo00IcW6mk:DY[FWooLi`5Ool00`00OomkgP02Ool00`00Ool00004Ool00g_N001o
o`06Ool014ic:DYoog_N6Goo00=kgQBUJeX01Goo00=g_Goo36<01Goo00H007_NOomkgWoo1242Ool0
27_NOomoog_NOomcW248JeX3Ool2Nmh3Ool00gNmOol48@02Ool01@00Oomoogoo00000goo00@007oo
Ool0009oo`03Nmioo`00009oo`06NmioogooOol8@VmkP7oo002FOol00`aSLiaoo`04Ool01W_NOomo
ogNmOomg_@=oo`03001oog_N009oo`03Nmh007_N00]oo`05NmioogNm48AkgP04Ool01G_NOomoogoo
Nmh02Woo00=kgQBUMkd01Woo00AkgWooOomkgP9oo`030008@Woo009oo`05125oog_NOol00009Ool0
1G_NOomooe:D:DX01Goo00=kgWooOol02Goo00=g_G_NOol00Woo00<icT8@Ool01Goo00=kgWooOol0
6Goo00AcW124OomkgP=oo`05Li`DYGooOomkgP0EOol017_NOomoog_N0goo00<e[@Q2BU800Woo00Mk
gWooOomoogNmDY@YBP0248@01D8@Kg]oogooMkd02Woo00=kgWooOol05goo0Sg_17oo00<LiekgOol0
:goo00=cW7ooOol017oo00AkgWoo9BUJePQoo`08001oogooOomkgP00Ool000Eoo`06001oogooOomk
gWoo0W_N00Eooc6<AS5oog_N009oo`03Nmioogoo01=oo`03:DYW>Goo00Moo`03001oogoo00=oo`06
001oogooOomkgP000goo00=kgWooOol00Woo00=[FR48Kg/00W_N0goo0W_N0Woo00T007ooNmh48G_N
OomkgWoo12400P0000H48GooOol8@WooNmh2Ool00`00Oomoo`04Ool00`aSLiaoo`1oOol009Ioo`05
=Je:DWooOomkgP02Ool01G_NOomoogooMkd00Woo00<007_N00000goo00IkgWooOol007ooNmh;Ool0
15:D:DYoogoo0W_N0Woo00Ag_GooOomg_@]oo`03?Nm247oo00Yoo`04Nmioo`00Mkd2Ool01GNm1240
0000Nmh00Woo00=kgWooNmh00Woo00McW7ooOomkgWoo7>MW>@0EOol01G_N48A_NgooNmh08Goo00<L
ifLiOol00goo00=g_DYBNmh00goo00=kgWooOol05Goo00Eg_GooNmioof]J008Li`04IcUoogooNmh5
Ool01U[F=Jd<H`Q2?Nmg_BAoo`8mk`Aoo`037>MNmgoo02]oo`03;F]oogoo00Eoo`04CW<aS7ooMkd2
Ool00gNmOomkgP02Ool02000OomoogooNmh007oo0005Ool00`00Oomoo`02Ool00g_NOomoo`02Ool0
1Q24Liaoog_NOomkgQAoo`03?Nm247oo00Qoo`03125oogoo00=oo`03001oog_N009oo`03001oogoo
00Eoo`05MkeoofLi6<IkgP08Ool010@QNmioo`000goo00Ug_GooNmioo`00Oomg_@00Nmh00Woo00Ak
gP@QOomkgP9oo`04MkekgTicLib0Ool009Ioo`05HaPDYGooOomkgP06Ool01W_NOomoogoo1240009o
o`05Mkeoog_NOol0000;Ool017_NOol@Q6<H17oo00AkgWooOomkgPaoo`9kgP0348Ag_Goo00Eoo`04
NmioogooMkd?Ool2Nmh5Ool00e:D:DYoo`04Ool00g_NOomoo`09Ool01gNmOomoogNmOomW>AcW00Ao
o`03Nmioogoo01eoo`03@Q0icWoo01moo`03Mkeoogoo00=oo`06MkeoodHa248mkg_N1Goo00Yg_Goo
Oomoof]J=Jd8@Q24@Q1cW0=oo`03Nmioogoo01]oo`8mk`Aoo`037>MNmgoo02]oo`03001oogoo00Ao
o`04Mkd<HgooMkd2Ool017NmOomoog_N0Woo00<007ooNmh00Woo00<007oo000017oo00=kgP00Ool0
1Woo00IkgWooBU8aS7ooNmhEOol016Li6<IoogNm1Woo00Eg_Goo001oog_N00=oo`03001oog_N009o
o`04125oogooNmh2Ool02WNmOomoog_NOole[EJeNmioog_N0goo00Yg_Goo001oog_N124007ooNmh4
8@=oo`09001cW7oo001oog_N001oo`0000=oo`04NmioogooLib1Ool009Aoo`05Nmioog_N7>MS6006
Ool027_NOomoog_NOomg_G_N1243Ool01P0012400000125g_@Uoo`03Nmi[FQS600Uoo`9kgPaoo`8m
k`04Oomg_GooNmh5Ool017_NOomoofmk1Woo00=kgWooNmh00Woo00=cW7ooOol00goo00Eg_Goo7>M[
FW_N011oo`038@QS67Nm009oo`03@Q0e[Goo00=oo`03Nmioogoo01]oo`06Mkeoof<H6<Ioog_N0goo
00AkgWooOomkgQEoo`04NmioogooOol2Nmh5Ool01GNm8@PDYEkgOol00W_N17oo0W_N0Woo00I[FSF]
36<Lid8@Kg/NOol2?Nl4Ool00acWG_Moo`0[Ool01000Oomoog_N0Woo00IkgSg_BU9kgWooNmh5Ool0
0g_NOol00002Ool01G_NOol48Goo00000Woo00AkgWooOol000=oo`03Nmioogoo009kgP9oo`036<IS
67oo009oo`03Nmioogoo00moo`03NmhU:Ekg00=oo`03Liaoogoo00Aoo`03125oogoo00=oo`03001o
ogoo009oo`03001oogoo00Eoo`07LiaoogooJeX<Hg_NMkd00goo00Ug_Goo124000@QOol007oo0000
0Woo0`0017oo0P0000Eoo`00124007_N08Ioo`00TWoo00QkgWooOomkgWooCW<aS7_N4Goo00=kgWoo
Ool037oo00<U:E[FOol01Woo00=kgWooOol03Woo00<HaVLiOol00goo00IkgWooOomkgWooNmh<Ool0
17_NOomoog_N0Woo00AkgWooBU8e[@Qoo`03Nmioogoo00Uoo`05Nmioogoo;F]BU004Ool00g_NOomk
gP0MOol027Nm36=oogooNmioog>LCW<NOol00g_NOomoo`02Ool01G_NOomJePaS;F/00Woo00=kgWoo
Nmh027oo00ENmc6<48@Lie:D009oo`03Nmioogoo01Moo`8mk`Aoo`037>MNmgoo02]oo`05125oog_N
OomkgP02Ool00`Q2NmikgP03Ool00g_NOomoo`0FOol00g_NOomoo`02Ool01DHa>LioogooNmh04Goo
00Eg_F<H8@Qoog_N00Uoo`03001kgWoo00=oo`06001oog_NOomkgP@Q0goo00=kgWooOol00goo00Ak
gWooAS4e[@Ioo`06Nmh48GooNmioog_N0Woo00=kgWooOol00Woo00=kgWooOol00Woo00=kgWoo0000
1Goo00=kgTYBMkd0P7oo002HOol00bU:F]Ioo`03Ool00g_NOomoo`0?Ool00g_NOomoo`06Ool00f]J
7>MkgP0GOol017_NKg/Q27>L6Woo00A_NgooDY@U:AQoo`039BUNmgoo011oo`<0009oo`03Nmioogoo
00Yoo`04Nmioo`00Mkd3Ool00g_NAS5oo`0UOol01WNm<H`<He:DOomkgPUoo`08Nmioog_NCW<HaQ24
?Nm_N`aoo`03Nmioogoo00Yoo`8mk`Aoo`037>MNmgoo02]oo`03HaQoogoo00=oo`03G_LQ27oo029o
o`03Kg/DYG_N00=oo`05NmioogooOomkgP03Ool00ekgE[Eoo`06Ool00cF]E[EkgP06Ool00g_NOomo
o`03Ool00g_NOomoo`02Ool00g_NOomg_@0=Ool00fmk48Aoo`03Ool017NmOomoo`002goo00=kgWoo
Nmh00goo00=kgP@QOol01Goo00=>Lg>LOol0Ogoo002HOol00f]J5:EkgP0<Ool00g_NOomoo`08Ool0
2G_NOomoogooMkeoog_N5:E[FP03Ool00g_NOomoo`0AOol01G_NOomoog>L36<02Goo00=kgWooOol0
3goo00ANmb48OomkgQMoo`037>MJeWoo00aoo`05Nmioogoo001kgP02Ool01@00NmioogooNmh02Woo
0W_N00<@Q7_NOol01Woo00=kgWooOol01goo00=kgWooOol05Woo00MkgWooOomNmacW:DY_N`02Ool0
0g_NOomoo`02Ool00gNmOomoo`04Ool01FLi<H`8@R48G_L01Goo00=kgWooOol017oo00=g_GooOol0
27oo0Sg_17oo00<LiekgOol0<Goo00<icTHaOol03Woo00EkgWooOomoog_N00=oo`03Nmioog_N00Yo
o`0448A[FWooNmh9Ool01D8@000DYD8@Nmh00goo00=kgP@QLi`01Goo00=kgWooOol00Woo00=kgWoo
Ool00goo00=kgWooOol00Woo00=kgWooOol02Woo00=kgRDYHaP027oo00=kgWooOol02Goo00=g_Goo
Ool00Woo00=kgWooOol017oo00=kgWooOol0Ogoo002IOol00e[F7>Moo`0DOol00gNmOomoo`05Ool0
12e[E[Eoog_N5goo00IkgWNmOomS61cWIcT2Ool00g_NOomoo`04Ool2Nmh;Ool2Nmh00dic7>MkgP0D
Ool01acWIcUoog_NMkdQ26<H00Uoo`03Nmioog_N009oo`03Nmioog_N009oo`05Mkeoo`@QOomg_@0:
Ool01g_NOomoo`00CW=_Ngoo009kgP9oo`03Nmioog_N00Eoo`9kgQmoo`03>Lh8@THa009oo`03Nmio
ogoo009oo`03Nmioogoo00Eoo`05Nmi:DQS636=:DP02Ool00g>LOomoo`0@Ool2?Nl4Ool00acWG_Mo
o`0ZOol00gNmOomkgP04Ool00aBUJeYoo`0;Ool027_NOomoogooNmioog_NOol3Nmh00gooNmioo`0:
Ool00be[CW=oo`03Ool00g_NOomoo`02Ool00g_NOomBU00300001PQ2<Ha_NgooG_LYBPIoo`03Nmio
ogoo00Aoo`03Nmioog_N00=oo`03Nmioogoo00ioo`03@Q0mkgoo00Aoo`03Mkeoogoo011oo`03Nmio
ogoo08Moo`00VWoo00I6<Cg_OomcW7ooNmhAOol017_NOomoogNm0Woo00<e[D8@Ool05Woo00=kgWoo
Nmh017oo00=W>AcWDY@00Woo00EkgWooOomoog_N00moo`07@Q0]Jg_NOomkgWooNmh04Goo00<Q26<H
Nmh00Woo00<YBUJeNmh02goo00=kgWooOol00goo00AcW7ooOol000moo`07000]Ja2448A6<F<HDY@0
0Woo00=kgWooOol08Woo00QkgWooOomoofLi7>LHaVLi0goo00=g_G_NOol02Goo00MkgV<H9BT8@Tic
Oomg_@07Ool00g_NOomoo`07Ool2?Nl4Ool00acWG_Moo`0VOol01WNmOomoog_NOolQ20Eoo`03125o
og_N00aoo`03MkeoogNm00=oo`03Mkeoogoo00eoo`05Mke6<Cg_OomkgP06Ool01WNmIcUJeSW>0004
8@@000039BTaS48@009oo`03Nmioogoo00]oo`9kgPEoo`03Nmioogoo00Yoo`05G_LLigooOomkgP03
Ool017NmOomoog_N2goo00Ag_GooOomkgPIoo`03Nmi>Lg>L081oo`00Vgoo00<e[BDYOol00Woo00=k
gWooOol03Goo00=g_GooOol00goo00@]Jd8@OomkgQYoo`08LiaoogooOomg_Be[:DY[FQ5oo`04NmiB
U1cW>Lh2Ool00g_NOomkgP0BOol00b48G_MkgP02Ool00cF]AS5oo`0>Ool027NmNmh00000249oo`00
Nmh;Ool017_NOomg_@aS0Woo00QNmcW>36<0036<HaQoog_N27oo00=kgWooOol05goo00Ag_GooNmig
_@=oo`04CW<8@SW>Nmh3Ool2Nmh4Ool00g_NOomoo`04Ool01FLi6<H<HdicMkd00Woo00AkgWooOomk
gPYoo`8mk`Aoo`037>MNmgoo02Qoo`05NmioogooG_MkgP04Ool00`@QOomoo`0EOol017_NOomoog_N
2Woo00IBU3F]NmhYBQcW5:D4000010Q25:DU:B481@0000@<Hcg_;F]BU0]oo`04MkeoogooNmh3Ool0
0g_NOomoo`02Nmh=Ool00fmk36=oo`0OOol00a24Kg]oo`1oOol009aoo`03HaP<HfLi00Aoo`03Nmio
ogoo00ioo`03Kg/DYE:D00Aoo`05MkeoogooOomkgP0BOol01WNmNmioogNmOomg_@9oo`04DY@HaRDY
HaP;Ool02G_NOomooe:D8@P]Jf<HOomkgP0FOol01b48HaQoogooNmi:DSF]00eoo`04Mkeoogoo0002
Ool00gNm0000000;Ool01G_NOomooeJe8@P017oo00QcW124?NlHaP@Q=JeBU7_N97oo00Qg_GooOomo
og>L;F/@Q5Je4Goo00AS62U:36=>L`Eoo`03Nmioogoo00Moo`8mk`Aoo`037>MNmgoo02Ioo`03Mkek
gWoo00Moo`03Mkd8@W_N00moo`06LiaoogooNmioog_N3goo00QBU248NmiBU6<HKg]oog_N0Woo00Ek
gWooOomBU0@Q00<00005=JecW7oo8@QBU00>Ool017_NOomoogoo0W_N47oo00=kgP@QOol017oo00Ag
_GooOomkgPioo`03Nmioog_N00=oo`05Nmioogoo001cW020Ool009aoo`06Mke[FQcW=Je_Ng_N47oo
00EcW3F]5:E_NgNm009oo`04LiaoogooMkdCOol00gNmOomoo`05Ool02W_NOomoogooHaPLi`@Q=JeJ
eV]J0goo0W_N00Moof]JCW<Q2124;F]S6006Ool00g_NOomoo`0FOol00fLi6<IkgP0:Ool00g>LOomo
o`02Ool00`00OomkgP02Ool00`00Oomoo`0:Ool017_NOole[Dic17oo00]_Na24OomoogNmCW<Q2000
9BUBU6mk00=oo`03Nmioogoo01aoo`03NmioogNm009oo`04F]HLib48Kg/AOol016mk7>L@Q5[F0Woo
00=kgWooOol027oo0Sg_17oo00<LiekgOol09goo00AkgWooOomkgPAoo`9kgP03125oogoo00aoo`05
JeYoo`aSOomg_@02Ool200001@@QNmikgWooLi`02Goo00=F]BU:Ool00Woo00=g_GooOol00Woo00ek
gWooOomS60@Q000U:FLiOomkgWoo8@QS6004Ool00g_NOomoo`03Ool00gNmOomoo`02Ool00g_NOomo
o`04Ool00gNmOomoo`0<Ool01000Oomoog_N0goo00=kgWooOol037oo00=kgWooOol027oo00<HaWNm
Ool0Ogoo002MOol2Nmh014YB48@icV]J3Goo00A_Nbe[5:E6<@Moo`03Nmioogoo01Eoo`07Nmioogoo
OomkgWooNmh00Woo00IkgWooMke>LbDY5:D2000021245:D8@P005:De[EkgMkdOOol01G_NOomooaBU
JeX02Goo00AkgWooOomkgP9oo`03001oogoo009oo`03001oogoo00aoo`0348AcW7oo00=oo`03Nmi2
47oo00Aoo`07NmiJeRU:248DYD8@Kg/09Woo00<icPaSCW<04Woo00IBU1S6;F]cW7ooNmh9Ool2?Nl4
Ool00acWG_Moo`0[Ool00acWOomoo`03Ool00`@QOomg_@0>Ool01P00Nmioogoo125kgP9oo`03001o
og_N00Yoo`04BU8icWooNmh7Ool01G_NOomcW1BUG_L01Goo00<DYF<HOol01goo00=kgWooNmh00goo
00=kgP@QNmh00goo0`003Woo00<007_NOol00goo00=kgWooNmh02Woo00=kgWooOol00goo00YkgWoo
Nmioog_NOomkgWooAS5g_H1oo`00XGoo00I6<ABU5:De[EJeKg/4Ool027_NKg]F]C6<6<HDYDYBNmh`
Ool017NmLiacW7_N97oo00IkgWooOom:DSW>Nmh4Ool01W_NOomoog_NOomkgP=oo`03Nmh48Goo00=o
o`03001oogoo00=oo`04MkeoogooNmh4Ool00ekg8@Qoo`02Ool01F<H?Nl]JaS6F]H027oo00IS63F]
6<H@Q3W>G_LROol01W_NOomS61cW6<I[FP=oo`03Nmioogoo00=oo`04NmioogooNmh4Ool017_N<H`8
@Tic2Woo00=6<CW>Nmh00Woo00EkgR48F]IoogNm02Yoo`03001oogoo00=oo`0436=_NgooMkd:Ool0
27_NOomoo`00OomkgWoo0003Ool00`00Nmioo`0:Ool2@Q04Ool00g_NOomoo`09Ool01g_NOomoobe[
CW=oog_N009oo`03Nmioogoo00=oo`03Nmioogoo009oo`06001kgWooOol007_N0Woo00<007ooOol0
2Goo00=kgW>L36<01Goo00=kgWooOol00`0000Eoog_NOomoo`0000ioo`9kgP03OomkgWoo07moo`00
XWoo00IkgVmkDY@YBPaS124300001P@Q48@]JdicIcUkgUMoo`038@QS67_N00=oo`05JeXLigNmNmig
_@02Ool00g_NOomoo`02Ool00gNmOomoo`02Ool00g_N0000000200001G_NOomkgWooNmh01Woo00Mk
gWooOolQ236<8@P<H`02000010@Q00048G_N0goo00=kgWooOol017oo00Qg_FmkAS4Li`Q2:DYNmg_N
6goo00=kgWooOol00goo00AkgU:D1252409kgP04OomkgWooNmh8Ool027_NOomg_GooHaP@Q2U:Li`6
Ool01WNmOom243g_OomkgP9oo`038@QS67oo00Aoo`03Nmioogoo02=oo`04Mkd<Hg_NNmh3Ool00b48
F]Ioo`0=Ool00g_N001oo`02Ool01`00OomkgWoo001oogNm00Yoo`059BUJeWooOomkgP0?Ool00g_N
>Li:DP02Ool00g_NOomoo`04Ool00g_NOomoo`02Ool01G_N001oogooNmh017oo00<48GooOol01goo
00UkgWooOomNmaS6OomkgWooNmh00goo00D007ooOomoo`0000=oo`03001oogoo00ioo`03Liaoogoo
07moo`00Xgoo00=g_G_NOol01goo00=kgWooOol0F7oo00Eg_GooNmioog_N009oo`05@Q0e[GooOomk
gP02Ool00g_NOomoo`05Ool00g_NOomoo`03Ool2Nmh3Ool01W_NOomoogNmOomkgP9oo`03G_LQ24ic
0080000536<000001248@P02Ool017_NOomoogNm2Goo00Qg_Dic7>L<Hb48AS5cW7Nm6Woo0W_N0Woo
00Eg_G_N7>L@Q6Li009oo`03Nmioog_N00Yoo`06Mkeoogoo;F/Q26<H0Woo00=kgWooOol00Woo00<m
kdHaOol00goo00@LiekgOomg_BEoo`03Mkeoogoo009oo`08001oogooOomkgWooBU8aS0eoo`0:Kg]o
o`@QNmioogNmOol000@Q000<Ool00g_N48AcW002Ool00g_NOomoo`0=Ool00g_NE[D]J`03Ool00g_N
OomkgP04Ool027_NOomoog_NOol007ooNmh2Ool4000<Ool00e:D;F]oo`05Ool00`00Oomoo`03Ool0
1000Oomoo`0047oo00=>Lg_NOol0Ogoo002ZOol2Nmh9Ool00g_NOomoo`1AOol01G_NOomoogooNmh0
0Woo00<@Q6mkOol017oo00EkgWooOomoogNm009oo`03Nmioog_N009oo`05LiaoogooOomg_@09Ool0
11cWHaQooekg0`0000D48@0036=F]G>L00Eoo`9kgPYoo`07F]HaS0Q28@Q246LiNmh00Woo00=kgWoo
Nmh00W_N4goo00MkgWooOomooe[F248YBP0BOol014Ha48A[FW_N1Goo00A243g_MkekgP9oo`038@QN
mgoo02Qoo`04NmioogooG_L5Ool00gNm36=oo`0<Ool01`Q2Ool007ooMkeoo`0000=oo`04001oogoo
Nmh5Ool01G_NOomooe[F9BT057oo00=_Na24Ool00goo00=g_GooOol00goo00=kgWooNmh00Woo00D0
07_NOomkgP0000=oo`03001oogoo00Ioo`07NmioogooNmh]JeJeNmh017oo00=g_@@QNmh017oo00@0
07ooOol000ioo`9kgP03DYAcW7oo07moo`00X7oo00=kgWooOol037oo00=kgWooOol0Egoo00=kgWoo
Mkd00Woo00AkgWooG_LQ209oo`9kgQ9oo`03Nmioogoo00Eoo`08AS4e[GooOomkgV<H24848@800006
BU8]J`Q25:E6<F<H4Goo00INmc6<5:DDYCF]HaP8Ool00g_NOomoo`06Ool00g_NOomoo`06Ool01gNm
Oomoog_N>Lh<HeJe00Ioo`04NmioogooLi`4Ool01W>LOomooe[F36=[FP9oo`05Nmioogoo>Li24004
Ool01B48F]Ig_GooNmh00Woo00=g_GooOol07goo00=cW7ooOol017oo00MkgWooOomg_Goo7>MJeP0:
Ool2Nmh00goo0008@P03Ool01@00OomkgWoo12402goo00<YBUJeOol057oo00@HaVLiOomkgPYoo`0;
001oo`Q2Oomg_Goo125oog_NOol0000<Ool00`@QNmioo`03Ool02G_NOol007ooNmioo`0012400002
Ool00`Q2Oomoo`2@Ool00:9oo`03Nmioogoo00Moo`05NmioogooOomkgP06Ool00g_NOomoo`1>Ool0
0b48IcUoo`06Ool00eJe:DYoo`02Ool00gNmOomoo`04Ool027_NOomkgWooNmioog_NOol2Nmh8Ool0
25Je8@QoogooMkeoogNmKg/200002a24MkeoogooJeXmkaBU248]JeJeLi`00goo00AkgWooOomkgPUo
o`07JeY6<B48124]JdicLi`04Woo0W_N1goo00EW>ABU8@Q_Ngoo009kgP03OomkgWoo00Aoo`04Nmio
ogooNmh2Ool04E[F36=[FWooLi`mkdHa7>M6<GooNmioog_N7>Le[DHa>Lh00goo00=kgWooOol09Goo
00UkgWooOomoog_NOomNmbU:Nmh03Goo00<007ooOol00Woo00H000@Q001kgWooNmh8Ool00f]J6<Ik
gP0COol017_NOom:DRe[2Goo00Ig_GooOomoo`@Q0002Ool01W_N001oog_NOol000]oo`03DY@YBWoo
009oo`05NmioogooOol00004Ool01W_NOomoogoo001g_@eoo`03Nmioogoo085oo`00YGoo00=kgWoo
Ool01goo00=kgWooOol00Woo00=kgWooOol0DGoo00<LifLiOol01goo00E:DSW>Oomoog_N00Aoo`03
Nmioogoo00Uoo`03Nmioogoo00Aoo`03HaPQ27oo00=oo`07NmioogooKg/@Q2e[BU800Woo00YkgWNm
Oomg_EJe:DX<HaS6@Q1[FPAoo`05NmioogooOomkgP06Ool02G_NMkeBU2U:248LidicLiaoo`02NmhB
Ool00g_NOomoo`02Nmh00dHa48@icP04Ool00g>LOomkgP02Ool02G_NMkeoogooNmioogNmCW<@Q002
Mkd01P00>Li6<FLiOomkgP9oo`06G_Lmkb485:Eoog_N8goo00IkgWooNmikgWoo8@P6Ool00g_N:DYF
]@0<Ool00g_NOomoo`04Ool01GNmOomoogooNmh01goo00=g_CW>BU8057oo00EkgWooMkdLif]J00Io
o`04NmioogooNmh2Ool00gNm001oo`03Ool00`001240000;Ool017Nm8@Q_Ng_N17oo00=g_Goo2480
1Goo00H007ooOol007ooNmh>Ool00dHaNmioo`1oOol00?moo`Uoo`057>MS67ooOomkgP06Ool00cF]
;F]g_@02Ool00g_NOomoo`03Ool01g_NOomoogooNmioog_N00=oo`03Nmioogoo009oo`03?NlLigNm
00Qoo`05Kg]F]A24Oomg_@07Ool01fLi>LhDY@Q2;F]BU7Nm009oo`03Nmioogoo00Yoo`08NmiNmbe[
248HaT8@Kg]kgPYoo`03Nmioogoo00Yoo`06IcTU:B48HaQoogNm2Woo00]g_GooOole[C6<Oom>Lc6<
Nmioog_N00Eoo`037>MW>Goo02Uoo`03G_Moogoo00=oo`05IcUJeSF]7>MkgP0=Ool00g_NOomoo`05
Ool00g_NOomkgP06Ool00fLi5:Eoo`0BOol00g_NOomoo`02Ool00dHa<Haoo`06Ool017>LOomoogNm
17oo00=kgWooOol00W_N37oo00=F]B48Ool017oo00Ug_GooOomkgP00OomkgWoo00000goo00<007oo
Ool03Woo00<<HfmkOol0Ogoo003oOol9Ool01B48F]IoogooNmh01goo00=JeQcWHaP00Woo00AkgWoo
OomkgPaoo`05NmioogNm9BTicP0;Ool00fmk249oo`0:Ool027_NLiaBU248124DYDHaJeX@Ool01ekg
>Lh@Q1S6<HaJeW_N01Eoo`04NmiBU0@Q?Nl4Ool00g_NOomoo`08Ool01PQ2IcUoobe[E[EkgP=oo`04
NmioocF]BU82Ool00g_NOomoo`0SOol01g_NOomoof<H?NlYBR4800@00007:DY:DS6<Oomg_GooNmh0
1Goo00=kgWooOol02goo00=kgWooOol00goo00=g_AS6Li`06Goo00@HaV]JOomkgP9oo`03Nmioogoo
011oo`03Nmioogoo00Aoo`04Li`@Q7_NNmh9Ool300001GooNmioog_N00002goo00=kgWooOol00Woo
00<<Hg>LOol0Ogoo001XOol00g_NOomoo`05Ool00g_NOomoo`02Nmh2Ool00g_NOomoo`0COol2NmhR
Ool2Nmh=Ool00g_NOomoo`0DOol00g_NOomoo`0;Ool2NmhZOol02WNmOomoogNmOol@Q2e[IcUoogNm
0Woo00=kgWooOol00goo00AkgWooOomkgP9oo`04Lia240aSE[D7Ool00g_NMkeoo`02Ool016mk5:Eo
og_N0goo00=kgWooOol01Goo00eg_GooOomS636<48@DYBDYG_Mg_GooNmig_@02Ool01G_NOomoogoo
Nmh017oo00QkgV]JAS4Lia24:DYF]GNm27oo0W_N2Goo0W_N00<U:@aSG_L01Woo00EkgWooOomoog_N
009oo`0BBU8YBWooMkdDYGooNmioog_NOomW>BU:Mkeoog_NOomg_G_N8Woo00IkgWooOomoofmk1243
00001`@Q0008@W_NKg]244Ha00=oo`06NmioogooNmioog_N0goo0W_N1Woo00YkgWooOomoogNmOomk
gWoo7>MJeQYoo`03IcTLig_N009oo`03Mkeoogoo009oo`03Nmioogoo00Yoo`07NmioogooOomkgWoo
Nmh00Woo00<e[DicNmh027oo00EkgWooKg]oog_N009oo`04MkeoogooMkd?Ool00a24Kg]oo`1oOol0
06Yoo`03Nmioogoo01ioo`9kgPEoo`03Nmioogoo009oo`03Mkeoogoo00ioo`03Mkeoogoo009oo`03
Nmioogoo00=oo`9kgPeoo`03Nmioogoo011oo`03Nmioogoo00]oo`9kgPEoo`03Nmioogoo009oo`03
Mkeoogoo00ioo`03Mkeoogoo009oo`04NmioogooMkd7Ool00g_NOomkgP02Ool01g_NOomF]ABU<HaN
mg_N009oo`9kgPMoo`05CW<e[ABU@Q1kgP02Ool01G_NOomoogooMkd01Woo00=g_DHaOol01Woo0W_N
2Woo00M[FU:D8@P@Q1S6BU9g_@0>Ool027_NLiaF]BU:248HaTYBLi`7Ool2Nmh6Ool027_NOomoogoo
G_L@Q36<JeX2Ool2Nmh2Ool017_NOomoog_N0Woo00D8@VmkOomNmacW00=oo`03Mkd@Q6]J00Ioo`03
Nmioogoo029oo`03MkdU:E:D00D00006?NmkgWooOolQ25Je2Goo00=kgWooOol01Goo00Eg_GooOomo
og_N00Aoo`04;F]BU7ooNmhJOol015[F8@Qoog_N1goo0W_N47oo00AkgSg_BU9kgPmoo`03Nmioogoo
015oo`03BU9g_Goo07moo`00Kgoo00=kgWooOol09goo0g_N27oo0g_N87oo00=kgWooOol01Woo00=k
gWooOol07Woo0g_N27oo0g_N57oo0W_N17oo00IF]BDY000Licg_@Q02HaP2F]H024YB?NlU:@Q2:DY>
Lg>LNmh=Ool00g_NOomkgP02Ool017NmOomoog_N1goo00=kgWooOol01Woo00MkgUkg>Lh@Q0aS<HaJ
eP08Ool2Nmh4Ool02W_NOomS62e[124DYCg_HaQg_Goo0W_N2Goo00QkgWooOomoogNm>LhDYDYB2goo
00HQ25JeOomoocg_BU82Ool0136<DYAoog>L0Woo00=g_GooOol08Woo00MkgWooNmioo`aSNmh@Q003
00000`Q2Oomoo`02Ool00g_N:DXmk`03Ool00gNmOomg_@05Ool017_NOomoog_N0goo0W_N00Ioog_N
OomcW1S6E[DNOol00eJe9BUkgP05Ool01G_NOomoogooNmh02Goo00Qg_GooOomg_G_NOom242e[1Goo
00=kgWooOol017oo00AkgWooLiakgPAoo`03Nmioogoo00eoo`03Nmioogoo081oo`00I7oo00=g_G_N
Ool00Woo00=kgWooOol05Woo00=kgWNmOol01goo00=kgWooOol01Goo00=kgWooOol027oo0W_N2Woo
00=kgWooOol01Goo00=kgWooOol01Woo00=g_G_NOol00Woo00=kgWooOol01Goo0W_N0Woo0W_N1goo
00IkgWooOomoog_NMkd8Ool00g_NOomoo`05Ool00g_NOomoo`08Ool2Nmh:Ool00g_NOomoo`02Ool0
0bU:F]Ioo`0<Ool00g_NOomoo`02Ool035[F?Nm241cW6<HQ22DY>LhmkeJeOomkgP=oo`03NmioogNm
00Aoo`9kgP03OomkgWoo00Qoo`03Nmioogoo00ioo`03Nmioogoo009oo`07Lia>Lb48000LidYBKg/0
3goo00M_NcW>48@DYCF]F]IkgP02Ool00g_NOomoo`02Ool017>L;F]oog_N0goo00Eg_FLi7>LQ26]J
00Aoo`07NmioogooNmiooe:D@Q000Woo00MkgQS6LiaBU2e[OomkgP05Ool00g_NOomoo`0TOol01`00
48@]J`@Q00048Dic00Aoo`05NmioodHa6<IcW002Ool00g_NOomoo`04Ool00g_NOomoo`02Ool2Nmh4
Ool015Je48AcW7>L7goo00=JeRU:HaP04Goo00=g_GooOol00goo00<]JcW>Mkd00Woo00=kgWooOol0
2goo00=kgWooNmh0U7oo001QOol02F]JHaQS66<HLiaoog_NKg]cW002Ool01FmkG_MNme[FLi`00Woo
0W>L0Woo00EcW6LiHaQNmfmk009oo`05Lia_Ng_NOomcW003HaP01F]JOomoogNmLi`00Woo00EcW5kg
E[ENmfmk009oo`9cW09oo`05Kg]Nme[FHaQ_N`02Ool2Li`2Ool01FmkHaQJeUkgKg/00Woo0W>L0Woo
00E_NekgE[ENmg>L009oo`05Liag_GooOom[FP03HaP01G>LOomkgVmkLi`00Woo00E_NekgG_MJeW>L
009oo`9cW09oo`05LiaJeUkgG_M_N`02Ool01G>LKg]kgWooLi`00f<H00E[FWooOomg_G>L009oo`05
LiaNmeJeG_M_N`02Ool2Li`2Ool01FmkG_MJeV<HKg/00Woo0W>L0Woo00E_Nf<HF]INmfmk009oo`9c
W09oo`03Kg]Nme[F009S600EG_MJeUJeIcUoog_NG_MJeUJeIcUS65JeHaQF]FLiNmioof<HE[ENmfLi
009S600BG_M>LfmkOomcW6<HDYANmf<HE[EW>F<HDYA[FWooNmiNme[F0f<H0Ukg00Y6<D8@NmioogNm
E[ES65[FIcUg_@Ioo`03Nmioogoo00eoo`07G_LaS12448@]Je[FNmh00goo0W_N1Goo0W_N0Woo00I[
FTHa8@P<HacWE[D2Ool01W_NOomoocW>000icPMoo`04AS4<Hcg_Nmh7Ool025[FAS5Nmf<HG_M6<AS6
36<4Ool01G>LMkeoogooNmh09Goo00Pmk`@QE[EkgUkg000@Q7Nm0Woo00=kgWooOol00Woo00IS60aS
<Ha_NgooNmh2Ool00g_NOomoo`02Ool00g_NOomoo`03Ool01G>LE[D@Q2U:Mkd017oo00=kgWooOol0
6Woo00AkgV<H9BUF]@9oo`=kgPmoo`03JeXDYEJe009oo`03Nmioogoo00Yoo`05LiaoogooOomkgP02
Ool00gNmOomoo`0>Ool00dHaNmioo`1oOol0065oo`09CW<U:AS69BUBU7_NOom245[F009oo`05CW<U
:AcW8@QJeP02Ool2F]H2Ool055[F<H`e[Cg_F]IoogNmF]I:DWooNmiBU2DY6<HU:DicOomg_DicDY@2
Ool04Tic8@PU:BU:CW=oog_NE[EBU7>LOom>LbDY5:DYBU:DNmig_@9BU00BMkekgU:D:DXDYBDYCW=o
og>LDYAF]G_NOom>LbU:9BTQ24ic0Woo00eBU4icMkeoodic9BTHaRDYDYAkgWoo@Q1JeP02Ool01Dic
9BTLib48CW<00Woo0Tic0Woo00E>Lb487>LU:Dic009oo`0=F]I247ooNmiBU2DY6<HU:DicOomg_Dic
DY@00Woo019>Lb489BTYBTicOomkgUJeDYAcW7ooCW<U:ABU:DYBU7_NMkd2DY@03gNmNmiBU2U:5:DU
:DicOomcW5:DE[EkgWooCW<YBP028@P01D8@Kg][FSg_AS400Woo01M241S69BT@Q4YBIcU[FT8@BU9o
og_N@Q0YBQS67>M6<F]JHaQ6<DYBMkeoodYB00<Q200<AS5S66]J?Nm:DWooNmi6<AcW6<HQ24Ha0VLi
0THa00Aoog_NDY@Li`8U:@05CW=kgWooOomkgP07Ool00g_NOomoo`07Ool037_NOomoogooNmi_Ndic
8@P48BDYCW=g_@9oo`03Nmioogoo00Uoo`0<NmiF]B48124LidicKg]ooaS6124002U:0goo00mg_Goo
MkeoogNm9BTDYF<HLia>LbDY7>L@Q0@Q00000R4800@Lib489BTDY@80000736<LicF]BU9cW7ooNmh0
97oo00]W>AcW;F]F]G_NOomkgS6<G_Moog_N00Aoo`09NmioogooNmi:DQBU:DYBU6mk009oo`03Nmio
ogoo00Eoo`06IcTicRDY:DY[FWoo0W_N00=oogNmOol07Woo0WNm00<YBQS6E[D01Goo00=kgWooOol0
1Goo00akgWooOomS62U:5:EcW7NmOomg_GooNmh;Ool017_NOomoog_N17oo00=kgWooOol03Goo00=6
<G_NOol0Ogoo001QOol017_NOomoog_N0Woo00=kgWooNmh047oo0W_N0Woo00=kgWooNmh00Woo00Ak
gWooOomkgP=oo`03Nmioogoo00Aoo`04NmioogooNmh4Ool017_NOomoog_N0Woo0W_N0Woo00AkgWoo
OomkgPAoo`04NmioogooNmh6Ool01G_NOomoogooNmh00Woo00IkgWooOomkgWooNmhDOol00g_NOomk
gP02Ool017_NOomoog_N0goo00=kgWooOol017oo00AkgWooOomkgPAoo`04NmioogooNmh2Ool2Nmh2
Ool017_NOomoog_N17oo00AkgWooOomkgPioo`03Nmioogoo00Eoo`03Nmioogoo00Qoo`07Nmioogoo
Nmioog_NOol00W_N3goo00AkgWooOomkgP=oo`03Nmioogoo01Eoo`08NmiF]C6<36<@Q3W>HaQkgPio
o`04G_L]J`aS5:D200001@Q2000Q27ooNmh01Goo00UNmbDY36<8@SW>DYANmg>LNmh01Woo0W_N00Eo
ofmkG_M>LcF]008<H`03?NmS67oo025oo`04@Q0DYDYBNmh4Ool00g>LNmioo`0:Ool00g_NE[D]J`02
48@0336<@Q16<DicE[E243W>9BT<HaBU@Q1[FR=oo`03Mkeoogoo00=oo`05IcT]Ja24>Li_N`09Ool0
27_NMke:DQcW6<IBU7ooNmhEOol00g_NOomoo`0=Ool017_NOomoog_NPGoo001POol013W>OomoogNm
0goo00=kgWooOol02Goo0W_N00D8@WooOomoo`00065oo`05NmioogooOomkgP12Ool00g_NOomoo`0[
Ool00g_NOomoo`06Ool00g_NOomoo`07Ool02FmkBU8Li`Q29BU>Lf]JOomkgP0<Ool0148@000000@Q
0P0000XU:GNmOomg_EJe9BT8@QcWBU9[FQAoo`06Kg]241cW248]Je:D0Woo00=kgWooOol04Woo00=k
gWooOol00goo00E[FQBU:DYg_G_N009oo`03Nmioogoo00Yoo`03Nmioogoo00=oo`0=NmiW>EJe@Q0i
cRU:;F/mkdHaG_McW7ooNmh0;7oo00E_NcW>6<H<HbU:008mk`09CW=F]DHa@Q0YBQS636<aS5[F00=o
o`03Nmioogoo00=oo`03Nmioogoo00moo`03Nmioogoo00]oo`03Nmioogoo089oo`00H7oo00=6<G_N
Ool00Woo00=kgWooOol02Goo00Yg_GooOomoo`00OomkgWoo001kgRaoo`03Nmioogoo00Ioo`03Nmio
ogoo00Aoo`03Nmioogoo021oo`03Nmioogoo00Aoo`03Nmioogoo03aoo`03Nmioogoo00moo`9kgPIo
o`9kgP=oo`03NmicW4ic011oo`03Nmioogoo00Ioo`08NmioogooOomg_GooMkekgP=oo`03NmiJeRe[
008@Q005=JeW>G_NOomkgP04Ool01g>LNmioogoo8@P000Q200@00005:DY6<B488@QBU002Ool00g_N
Oomoo`02Ool2Nmh7Ool00g_NOomoo`08Ool01gNmE[D]J`aSBU9oog_N00=oo`9kgPAoo`03Liaoog_N
00Eoo`05NmioogooOomkgP02Ool014YB36=F]G_N0goo00<U:GooNmh0;goo00=kgWooOol06goo00Ic
W5JeAS56<Be[:DX2?Nl00e:DJeYoo`05Ool00g_NOomoo`0?Ool00g_NOomoo`0DOol00dHaNmioo`1o
Ool0061oo`9kgQ5oo`04Liaoo`@QNmh2Ool01@@QOomg_GooNmh0:Woo00=kgWooOol01goo00=kgWoo
Ool09Woo0W_N0goo00EkgWooOomcW7_N00=oo`03Nmioogoo01Moo`04Lia[FV<HG_L2HaPAG_L00f<H
G_MNm`03G_L2HaP2G_L01E[FG_MNmf<HG_L00V<H00ANmf<HJeYcW19oo`03Lia:DWoo009oo`9kgP03
OomkgWoo00Eoo`04NmioogooNmh5Ool00g_NOomoo`07Ool00g_NOomoo`02Ool02W_NOomoofLi@Q0L
i`00:DYBU6mk1Woo00]_N`@Q000000Q26<HaS2DY124e[F]J009oo`04MkeoogooNmh5Ool2Nmh<Ool0
0g_NOomoo`04Ool017Nm<H`HaTic3goo0W_N00Ioog>LOomg_GooLi`26<H00gNmOomoo`03Ool00e[F
Oomoo`03Ool00g_NOomoo`04Ool00g_NOomoo`04Ool00g_NOomoo`06Ool00g_NOomoo`06Ool00g_N
Oomoo`0<Ool00g_NOomkgP02Nmh2Ool00g_NOomoo`05Ool00g_NOomoo`0<Ool01G_NOomoogooNmh0
0Woo00=kgWooOol027oo00=kgWooOol027oo00=g_GooOol00Woo00=kgWooOol01Woo00=kgWooOol0
1goo00=kgPaSKg/0P7oo001bOol02G_NOomoo`00OomkgWNm001g_@0/Ool017_NOomoog_N1Goo00=g
_GooOol09Woo00=kgWooOol01Goo00=kgWooOol00goo011kgWooMkeW>EkgHaQNmdic?NlicT8@AS4e
[B485:DHaP8Q20047>LHaQ241245000010aS5:DLib480QcW42480QcW124800<LiaS68@P00QcW0RDY
00<Q21cW8@P011cW00<HaPQ200001`0000@@Q1cW7>LQ20<Li`049BTe[D8@AS42>Lh01dHaG_M[FVLi
HaQW>G_N009oo`9kgP9oo`05NmioogooOomkgP05Ool01g_NOomoogooNmioogNm00Aoo`9kgP03Oomk
gWoo00=oo`07Nmi:DQ2448@<HcW>E[D00Woo00YcW7Nm@Q1NmfmkOom>LaS6<Hag_@]oo`9kgP9oo`03
Nmioogoo00Moo`9kgP=oo`04NmioogooMkd2Ool016Li<H`HaTYB17oo00AkgWooMkekgPMoo`07Mkeo
og_NOom6<@@QAS4017oo00Ig_GooOomoof<HAS42?Nl01EJeOomoof<HG_L00Woo00EW>D8@?Nm245Je
009oo`09JeYNmgooOom[FT8@>Lhmke:D009oo`06IcUJeWooOomW>Cg_0T8@00EJeWooOomW>EJe009o
o`09IcU6<Cg_@Q1JeW_NOomW>E[F009oo`05Kg]243W>@Q1F]@02Ool01VLiF]IkgWooJeY2408mk`0<
E[Eoog_NJeYBU7_NOom[FT8@?Nm6<EJe0Woo00I[FTicNmioofLiAS42?Nl01E:DOomoofLiG_L00Woo
00EW>D8@?Nm245Je009oo`09HaQNmg_NOom_Ncg_@Q0mkeJe009oo`06IcUJeWooOom[FSg_0T8@00EJ
eWooOomW>EJe009oo`06JeXmkcg_@Q0@Q6mkP7oo001POol00cW>Oomoo`03Ool00g_NOomoo`09Ool0
1GNmOomoo`00Nmh00Woo00D8@WooNmioogNm03Aoo`03Nmioogoo01Yoo`03Nmioogoo00Aoo`03Nmio
ogoo009oo`07JeYJeUkgDY@mkdYB=Jd00QcW00<YBQBU00000P0000h8@QS67>LLib48<Ha244Ha?Nli
cTHaG_M[FVLi0ekg00=W>FmkNmh0<7oo00=kgWooOol01Woo00=_Nf<HG_L00Ukg0V<H00eJeTYB?Nlm
kdHa@Q0icQcW5:DHaQcW6<H48@0200002`Q25:DLiacW9BTaS3W>?Nm6<E:DF]H00Ukg27oo00AkgWoo
Oomg_@9oo`9kgP=oo`0<Nmioocg_125>Lfmk@Q0Li`Q29BUBU7>L0Woo00ES60Q2=Je[FW_N00Qoo`9k
gPQoo`03MkeS65Je009BU003F]INmgoo00=oo`03Nmioogoo00Ioo`05Nmi_NcF]5:EW>@02Ool2Nmh;
Ool01WNm7>LLifmkOomkgPMoo`05IcTmkcg_?NmF]@02Ool02F<HG_MoogooIcU243g_@Q1F]@02Ool0
2F<HF]Ig_GooIcU243g_@Q1JeP02Ool01VLiE[EoogooJeXmk`924005F]IoogooIcUF]@02Ool02FLi
AS4mkd8@F]IkgWooIcUJeP02Ool01Fmk@Q0icT8@E[D00Woo00IW>E[FNmioof]J@Q02?Nl01EJeOomk
gV]JHaP00Woo00EW>Cg_?Nm6<E[F009oo`06IcUJeWooOomNmd8@0THa00EF]GooOomS65[F009oo`05
IcU243g_@Q1F]@02Ool02F<HG_MkgWooKg/mkd8@?NmF]@02Ool01VLiF]IoogooJeXmk`924005F]Io
ogooIcUF]@02Ool01F]J@Q0mkdHaDY@0PGoo001POol00`00Oomoo`0BOol20002Ool00`00Oomoo`0Y
Ool02gNmJeYS65kgBU8icT8@E[EW>G>LNmh05Woo0W_N27oo00U[FV<HF]I:DSg_<H`U:B4836<00P00
00`DYB488@P]Jd8@>Li6<EkgIcUJeV<HNmhHOol00g_NOomoo`04Ool00g_NMkeoo`0?Ool00g_NOomo
o`04Ool01G_NOomoogooNmh00goo0g_N5Woo00=g_DHaOol02Goo00YkgV]JHaQS65JeCW=243g_>LhY
BP8Q20046<H0000024826<H02B48>Li2448@F]IW>G>LOomkgP03Ool2Nmh00gooLi`48@02000036Li
Oomoog>LE[Dmk`@Q48@YBQcWMkekgP=oo`03Nmioogoo00]oo`0>G_Le[@Q248@LibU:<H`]JbDY7>L0
01BUAS5cW09oo`03Nmioogoo00Eoo`09Nmioofmk6<IBU7_NOomkgW>L00Moo`05Nmioodic36=24006
Ool00g_NOomoo`07Ool00g_NOomoo`04Ool00g_NOomoo`04Ool00g_NOomoo`06Ool00g_NOomoo`06
Ool00g_NOomoo`0<Ool00g_NOomkgP02Nmh2Ool00g_NOomoo`05Ool00g_NOomoo`04Ool00g_NOomo
o`03Ool00g_NOomoo`03Ool01G_NOomoogooNmh02Goo00=kgWooOol027oo00=g_GooOol00Woo00=k
gWooOol01Woo00=kgWooOol01Woo00=kgWNmOol0PGoo001POol00`00Oomoo`0BOol01000Ool00000
0goo00=g_GooOol08Goo00ekgWooOomW>Cg_7>LDYAcW8@Pe[DHa?NlU:@025:D00acW?NmW>@02Ool0
17_NOomoog_N47oo00QS65[FCW<icRU:5:D8@P000R4800H]JcW>BU9JeUkgHaP8Ool01UkgHaQ>LcW>
AS5Nm`9W>@03Nmioogoo01Moo`=kgQMoo`0:Mke[FV<HF]HmkdHaCW=NmfmkMkd6Ool2Nmh2Ool00g_N
Oomoo`02Ool017_NOomoog_N1goo00=S61S6Ool02Woo00=kgWooOol02goo00YcW6LiIcUJeTHa@Q0m
kbDY5:D@Q0848@8Q200:?NmBU5[FNmi:DP0024800124Li`2Ool01W_NMkeoobDY7>MkgP9oo`03Nmio
ogoo00=oo`03Nmioogoo00=oo`04NmioogooG_L28@P014YBNmikgW_N1Woo00U[FSF]48@aS7>LOomk
gWooLi`01goo00=kgS6<<H`01Goo00Ug_GooOomkgWooKg/YBQcWHaP00Woo0W_N1Woo00=kgWooOol0
67oo00=kgWooOol01Goo00=kgWooOol03Goo00=kgWooOol08Woo00AkgWooOomkgP9oo`05Nmioogoo
OomkgP0@Ool00g_NOomoo`0@Ool00g_NOomoo`23Ool0061oo`03001oogoo01Eoo`03Nmioogoo00=o
o`03Nmioogoo021oo`05DY@LiaS6@Q1[FP05Ool01W_NOomoog_NIcU2408HaP03DYAoogoo00]oo`0>
NmiS64ic=JdQ20aS000U:BU:=Je:DUkgKg]kgPeoo`0:Kg]>LbDY248Lib48<Ha243W>9BT26<H01124
;F]BU7>L0goo00=kgWooOol09goo015cW5:D;F/DYA247>LYBT8@=Jd]JbU:5:D8@RDYCW=cW7_N01Io
o`04G_LQ27ooNmhEOol00g_NOomoo`0;Ool025kgHaQ2448@8@P@Q0001243000021cWNmioogooKg/L
ieJeNmh4Ool017_NOomoog_N1Woo00IkgWooKg/YBR48F]H;Ool027_NOomoodYB48@e[GooNmh6Ool2
Nmh01GooNmi:DR48JeX00Woo00QkgWooNmikgWooAS4@Q48@0goo00AkgWooOomkgPQoo`03Nmioogoo
00Uoo`03Nmioogoo00Qoo`03Nmioogoo00Aoo`03Nmioogoo02]oo`03Nmioog_N00Eoo`03Nmioog_N
00Eoo`03Nmioogoo00Eoo`03Nmioogoo00moo`03Nmioogoo00]oo`04MkeoogooNmj1Ool0061oo`03
?Nmoogoo03aoo`04HaPDYCF]HaP?Ool016<H9BTU:F<H1Goo00ag_GooG_LmkbU:248@Q248=Je>Lf<H
MkdCOol01V]J;F/@Q2e[HaQkgPQoo`08MkeBU2486<I247>LOomkgPIoo`03Nmioogoo01Uoo`0:Nmio
ogooNmioog_N>LhLib48DY@3Nmh6Ool01g_NE[DaS0Q2>Li_Ng_N00Eoo`03Nmioogoo00aoo`03G_LQ
27oo02Uoo`0<DY@48@00124000Q2000aS7ooE[DQ26<H37oo00Qg_GooOomkgWooJeXQ25:D4Goo00Ag
_Dic9BUcW0=oo`03Nmioog_N00Eoo`03IcTDYE[F009oo`06NmioogNm7>LHaVmkogoo6Woo001VOol0
0g_NOomoo`0eOol014Ha8@Q[FWNm0goo00=kgWooOol027oo00MkgWooOomooe[F7>M>L`03Ool01T8@
<H`48ABU?NmJeP9g_@03Nmioogoo00aoo`04MkeoogooNmh2Ool01G_NMkdYBPaSAS400Woo00=kgWoo
Ool02Woo00AcW3W>5:Dmk`Eoo`03Mkeoogoo01Uoo`03Nmioogoo009oo`05Nmhmka24@Q1[FP02Ool0
0g_NOomoo`08Ool01W_NOom:DQ24=Je_N`Eoo`03Nmioog_N00]oo`03Kg]>Lgoo00=oo`03Nmioogoo
02=oo`038@P0000000<00005124002e[9BU_N`0;Ool00gNmOomoo`03Ool016<H36=_Ng_N0Woo00=g
_GooOol03Goo00EcW5[F:DYoogNm009oo`03Nmioogoo00=oo`05Nmig_Goo6<IBU002Ool016<H2496
<GNmogoo6goo001VOol00g_NOomoo`0aOol3Nmh00be[=JekgP0AOol00g>LOomoo`02Ool01cg_9BU>
L`00:DYF]G>L009oo`03Nmioogoo00Eoo`03Nmioogoo00Uoo`07MkeoogooOomS61BUDY@00Woo00=k
gWooOol03Woo00AcW4Ha6<IcW09kgQmoo`06MkeoogNm9BTe[GNm37oo00=kgWooOol00goo00MkgTic
7>MJeWooNmig_@0kOol01EkgHaQS65kgKg/00Woo00=S62U:Ool02Woo00EkgWooOomoogNm009oo`04
IcTHaWooNmh4Ool00g_NOomoo`0>Ool01Ekg6<IoogooLi`017oo0W_N0Woo00QkgWoo:DYJeWooKg][
FWNmogoo77oo001POol00cg_Oomoo`0fOol01G_NOomkgQcWE[D04Woo00=g_GooOol00goo00AkgTYB
125_N`Aoo`03Nmioogoo015oo`06NmioogooOom:DRDY17_N3goo00MkgWooOomkgV<H5:ES600NOol0
1W_NOomooekg5:ENma5oo`03Nmioogoo009oo`03MkdQ24Ha00Aoo`04NmioogooNmhaOol017_NOomo
og_N1Woo00=[FR48Li`037oo0g_N0Woo00AkgQcWJeYkgP9oo`03Mkeoogoo019oo`03F]HYBWNm009o
o`03Mkeoogoo009oo`09MkeoogooOomcW1cWIcUoog_N009oo`03Mkeoogoo0?mooaQoo`00H7oo00<m
kgooOol0=goo00=kgRe[G_L00Woo00=kgWooOol057oo00IkgWooCW<LigooMkdGOol017NmNmi242DY
6Goo00AkgQBUCW=oo`9kgQaoo`07G_LQ27NmNmioogNmNmh01Woo00=kgWooOol027oo00QcW7ooOomo
ocW>@Q1oog_N0Woo00=kgWooOol02Goo00=W>E[FNmh017oo00=kgWooOol07goo00Eg_GooOomoog_N
00=oo`03Kg/HaV]J00=oo`03Nmioogoo00aoo`03;F]>Lgoo009oo`05Mkeoog_NOomkgP0BOol00cF]
AS5oo`05Ool00g_NOomkgP03Ool00gNm5:Eg_@3oOolNOol006Ioo`03Nmioogoo02moo`07Mkeood8@
>LikgWooMkd04Goo00=kgWooOol017oo00AkgWoo@Q1241Eoo`08Nmioog_NOomF]C6<OomkgPIoo`03
Nmioogoo00Yoo`9kgP9oo`05Nmioog_N:DYcW003Ool00g_NOomoo`0GOol01G>L48AoogooMkd017oo
00=kgWooOol01goo0W_N1Woo00EkgWooOolaS48@00=oo`03Nmioogoo00Uoo`03Kg]JeWoo02Moo`0=
NmioogooOomkgWooLi`U:FLiOomkgWooNmh02goo00QkgWooOom_NacWNmioog_N17oo00=g_GooOol0
3goo00IkgWooKg/Lig>LNmh3Ool00g_NOomoo`03Ool01W_NOom_NbDYLiakgP9oo`03Mkeoogoo0?mo
oaMoo`00IWoo00=kgWooOol0<7oo00=F]C6<Ool05Woo00=kgWooOol00goo00AkgWoo9BUF]@9oo`03
Nmioogoo019oo`03E[DQ27>L00Eoo`05NmioogooOomkgP08Ool2Nmh7Ool017NmKg/HaV]J6goo00=g
_A24Ool00W_N00Aoog_NOomkgPMoo`03Nmioogoo00Qoo`03Mkeoogoo009oo`03;F]Nmgoo00ioo`04
LiaoogooNmhSOol00g>LOomoo`04Ool017_N9BUJeW_N0goo00=g_GooOol01goo00UkgWooOomkgWoo
48A[FWooNmh06Woo00=:DS6<Ool01Woo00=kgWooOol00goo00=NmacWOol0ogoo77oo001POol00cg_
Oomoo`0fOol00aBUIcUoo`0NOol00g>L48Aoo`0DOol2Nmh01124Liaoog_N77oo00ABU2e[NmikgQUo
o`05:DYF]G_NOomkgP05Ool00g_NOomoo`0AOol01G_NOomg_A24Li`04Goo00=kgWooNmh08Woo00Qk
gWooOomoog_NOole[DHa0Woo0W_N37oo00Ig_GooOomcW1S6Mkd8Ool00g_NOomoo`0AOol00gNm48Ag
_@05Ool00g_NOomkgP02Ool01g_NOomoodHa=Jeoog_N0?mooaYoo`00H7oo00D007ooOomoog_N009o
o`03Nmioogoo00aoo`0300048@0000=oo`03Nmioogoo015oo`03Nmioogoo00Eoo`03@Q0e[Goo00Eo
o`03Nmioogoo00=oo`03Nmioogoo009oo`03Nmioog_N00=oo`03Nmioogoo00=oo`06NmioogooOola
S4Ha0Woo0W_N17oo00=kgWooOol02Woo00DaS4icOomoog_N01eoo`03;F]JeWoo00ioo`03Nmioogoo
009oo`08NmioogooOomkgUkg:DYkgP=oo`03Nmioogoo01Qoo`04Nmi>LcW>Nmh2Ool00g_NOomoo`07
Ool00fmkCW=oo`0NOol00g_NOomkgP04Ool00g_NOomoo`02Ool00g_NIcTQ200DOol00d8@?Nmoo`0M
Ool00bU:E[Eoo`0:Ool01G_NOomooaBUJeX01goo00=kgWooNmh0>7oo00=kgWooOol02Woo00=kgWoo
Ool017oo00=kgWooOol03goo00AkgWooOomkgPMoo`03Nmioogoo00Eoo`05NmioogooOomg_@03Ool0
0g_NOomoo`02Ool00g_NOomoo`08Ool00g_NOomoo`02Ool00g_NOomoo`1oOol0061oo`04001oog_N
Nmh2Ool00g_NOomoo`0<Ool01@00OomkgWoo00000Woo00=kgWooOol067oo00Eg_A24Nmioog_N009o
o`03Nmioogoo009oo`03Nmioogoo00Uoo`03Nmioogoo009oo`09NmioogooOomkgWooNmioo`0001Ao
o`04Kg/Lig_NNmhMOol017_NOomcW1243Goo00IkgWooOomg_GooNmh6Ool00acWG_Moo`0OOol01GNm
8@Q[FWooMkd02Woo00=S62U:Nmh00W_N00=oog_NOol06Woo00=cW7ooOol01goo00AkgWoo8@QJeQ1o
o`06NmioogooOolQ25kg37oo00<000@Q00000`002Goo00EkgWooOom6<Cg_00ioo`04F]HU:GooNmi2
Ool00g_NOomoo`05Ool00g_NOomoo`02Ool017_NOomoog_N1Woo00EkgWooMkeoog_N009oo`03Nmio
og_N009oo`03Nmioogoo00Aoo`03Mkeoogoo00Aoo`03NmioogNm00Aoo`03Nmioogoo00=oo`03Nmio
ogoo009oo`03Nmioogoo00Eoo`03Nmioogoo00Aoo`03Liaoogoo085oo`00H7oo00<007NmOol00goo
00=kgWooOol01goo00=g_GooOol00Woo00D48GNmOomoo`0000Aoo`03Nmioogoo01Aoo`06NmiooeJe
7>Moog_N2Woo00=kgWooNmh00goo00=kgWooOol00Woo00=kgWooNmh027oo00MkgRU:CW=oog_NOomg
_@02Ool00g_NOomoo`02Nmh8Ool00c6<AS5oo`0POol00g_N>Li6<@04Ool2Nmh4Ool01WNmOomoogoo
Mke6<@9oo`03NmioogNm009oo`05F]HQ27ooOomkgP0OOol00eJe:DYoo`02Ool00gNmOomoo`06Ool0
0f<H6<Ioo`0MOol017_NOomoof<H1Goo0W_N0Woo00=>Lbe[Ool047oo00IkgWooOomoo`Q2Mkd:Ool0
17NmOomoo`003Goo00EkgWooOomNmb4800moo`03:DYBU7oo041oo`03Nmioogoo00Uoo`03MkekgWoo
00Ioo`04NmioogooMkd5Ool00gNmOomoo`02Ool017_NOomoogNm2Goo00=kgWooOol02Woo0W_N2goo
00EkgWooOomoogNm009oo`03MkekgWoo009oo`03Nmioogoo07moo`00H7oo00=W>GooOol00W_N0Woo
00=kgWooOol02Goo00QkgWNm001oogNmOol007oo0W_N6Woo00<U:EkgNmh04goo00=kgWooOol027oo
00MkgWooOomooekg;F]g_@03Ool2Nmh=Ool00`Q2OomkgP02Ool00g_NOomoo`0HOol01W_NOomkgWoo
HaPU:@ioo`04Kg/48@aSE[D5Ool012e[E[Eoog_N7goo00AcW7oo249kgP]oo`03G_LQ27oo00=oo`03
Nmioogoo01Yoo`03000YBVLi009oo`07NmioogooOomg_AS6Li`04Woo00AkgWooNmh48@ioo`04Mkd0
07ooMkd=Ool00fLi6<Ioo`0>Ool01FLi8@QkgWooNmh0@Goo00=kgWooOol00Woo00AkgWooOomkgP9o
o`03Mkeoogoo00=oo`03Nmioogoo009oo`03Mkeoogoo009kgP=oo`04Kg]oogooMkd7Ool017NmOomk
gW_N27oo00EkgWooOomoogNm00=oo`03NmioogNm00Ioo`07MkeoogooMkekgWooNmh00goo00AkgWoo
OomkgX5oo`00HGoo0W_N0Woo00=g_GooOol027oo00=kgWooNmh00Woo00D007ooOomoo`00009oo`03
NmioogNm01Moo`03Nmh8@WNm009oo`03Nmioogoo00Eoo`06MkeoogooNmioogNm0Woo00=kgWooOol0
0goo00AkgWooOomg_@Qoo`05125oog_NOomkgP02Ool00e:D6<I[FP03Ool00g_NOomoo`03Ool00e[F
9BUoo`0ROol00g>L48AcW003Ool2Nmh3Ool01W_NOomoogooNmiJeP<000067>M[FW_NOomg_@000Woo
00=kgWooOol07goo00<YBUJeNmh02Woo00=_NdicOol07Goo0W_N00Ioo`00000002U:JeX3Ool017_N
AS5247>L4Woo00Ag_GooMkd48@eoo`04Nmioogoo000>Ool00fmk48Aoo`0;Ool01W_NOomoogoo@Q0m
kdEoo`9kgPEoo`03Nmioog_N009oo`03Nmioogoo00Ioo`03Mkeoogoo00=oo`03Nmioogoo00moo`9k
gP03Liaoog_N00Aoo`03Mkeoogoo00Eoo`9kgP03OomkgWoo009oo`05NmioogooOomg_@02Ool2Nmj5
Ool0061oo`04NmioogooNmh?Ool00g_NOol48@03Ool00`00Mkeoo`02Ool00g_NOomoo`0EOol01G>L
36=oogooNmh02goo00EkgWooOomoog_N00Ioo`03Nmioogoo00Ioo`05Nmioogoo249kgP02Ool00gNm
@Q048@0200000gNmOomoo`07Ool01C6<CW=oogooNmh06goo00=cW7ooOol00WNm00<@Q0006<H00b48
00@U:BU:=Jdmk`96<@06?Nm245kgHaQ6<@@Q100000DaS6]JF]He[G_N021oo`06Mkeoog_NDY@aS7_N
2goo00AkgWooOomkgQeoo`03Mkd000@Q00<00005:DYNmgooMkd<H`0DOol017_NOomkgP003Woo0W_N
00=oo`@QNmh037oo00=cW0aSOol02goo00MkgWooOomoogNm5:EcW018Ool00gNmOomoo`07Ool00gNm
Nmioo`0:Ool00g_NOomoo`03Ool00g_NOomoo`05Ool00g_NOomoo`05Ool00g_NOomoo`05Ool00gNm
Oomoo`0:Ool017NmOomoog_N1Woo00=kgWooOol0P7oo001POol00bDYLiaoo`0?Ool01G_NOomoogNm
12400P0000=kgWooOol00W_N00=oog_NOol05Goo00EW>AcWOomoogNm00Moo`03Mkeoogoo009oo`9k
gP03MkeoogNm009oo`03Nmioog_N00Aoo`04MkeoogooMkd4Ool01AcWG_M_NcF]24800P0000<8@P00
Mkd01Goo00QkgWooOomooacWG_Moog_N7Woo00MkgWooOomoocg_;F]JeP03G_L01eJeCW=243W>?Nm2
43F]008Q20056<H00000000<H`0200000`@Q<H`mk`03Ool00g_NOomoo`0LOol01G_NOomcW0Q2<H`0
300000<48@0000007`000P@Q00T000@Q000003W>?Nm247ooNmh05Goo00<48G_NOol03goo00=g_@Q2
Ool02goo00=S61cWOol047oo00<e[D8@Ool0A7oo00IBU248OomooeJe1242000021cWOomooe[F9BUo
og_NJeX3000021BUOomkgUkg9BUoog_NIcT300004b48Nmioof<H8@QkgWooIcT000Q2000LigooMkeW
>B48Nmioof<H00<000055:Eoog_NHaPYBP02Nmh01F]J000000@Q6<H00Woo00aJeR48OomoofLi0004
8@007>McW7ooNmh3Ool00g_NOomoo`1nOol0061oo`03G_Moogoo00Aoo`03Nmioogoo011oo`03Mkeo
ogoo01Aoo`07NmioogooOomkgUJe:DX00goo00=kgWooOol00Woo00=kgWooNmh00goo00IkgP@QOomk
gWoo124400000`@QNmioo`02Ool01G_NOomkgWooNmh00goo00<]Jb4800000P0000`48@00000004YB
?Nm245JeHaQNmf<HMkd2Ool00a24LiakgP0NOol01g_NOomoog_NOomBU36<00eoo`03CW<000000080
000548@e[Fmk<Ha>L`0SOol01G_NLi`8@WooNmh02Goo00A[FUkgNmikgQmoo`031240000000800005
5:EF]Goo48A_N`0GOol00a24Kg]oo`0:Ool017_NOomoog_N0Woo00<007ooOol01Woo00IkgWooOomo
odic=Jd=Ool01WNmOomkgWooKg/DYDQoo`03Nmioogoo009oo`03Nmioogoo00Eoo`05MkeoogooOomk
gP02Ool00g_NOomoo`0@Ool017_NOomoog_N1goo00Ag_GooOomg_@9oo`03Nmioogoo009oo`04Nmio
ogooNmh4Ool01GNmOomoogooNmh0QGoo002FOol00dYB<Haoo`07Ool00g_NOomoo`02Ool00g_NOol0
0004Ool00`00Oomoo`03Ool017_NOomoog_N1goo00@aS4YBDY@<H`@00008248mkd8@>LhQ21S68@PL
i`88@P037>L007oo00Ioo`03Nmioogoo00=oo`04Nmioogoo0002Ool2Nmh00goo001oo`0;Ool017Nm
OomJeRDY1Woo00=kgWooOol00Woo00=kgWooDY@00P0000<8@THaOol00Woo00<Q25JeOol02goo00Ak
gWooNmh000Aoo`0412400000248:Ool01G_NOomoo`00Mkd00Woo00=kgWooOol017oo00AkgV]JF]Ik
gR1oo`0900048@0048AJeWooNmiNmbDY01Qoo`03>Li247oo00Yoo`07NmioogooOomg_Goo000027oo
00IkgWooOomooc6<CW<BOol00b48F]Ioo`0mOol00g_NOomkgP02Ool00fLiNmikgP0>Ool00g_NOomo
o`0hOol00dHaKg]oo`24Ool0069oo`03Nmioogoo035oo`03DY@]Jgoo00Qoo`04MkeoogooNmh2Ool0
2000OomoogooNmioo`00Nmh4Ool2Nmh8Ool01RU:G_MkgW>L?Nl48@80000336=oogoo00Qoo`03001o
og_N00Qoo`03Nmioogoo00=oo`03001kgWoo00=oo`03001oogoo00Moo`9kgP=oo`03F]HLigoo00=o
o`06NmioogooMkeoogNm0goo00Y:DQcWCW=oog_NOomkgWoo8@QNm`Uoo`07NmioogooOomkgWoo0000
0goo00<007_NOol00Woo00<007ooOol01goo00EkgWooOol<HgNm009kgPAoo`03Nmioogoo009oo`03
Mkeoogoo01moo`03000@Q5kg00Aoo`03;F]>Lgoo01Ioo`06Nmi[FQS6Mkeoog_N1Goo00IkgWooOomo
o`00Nmh3Ool00`00Oomoo`09Ool017_N48Ag_G_N4Goo00=243W>Ool0@Woo00<aS5:DNmh027oo00Ek
gWooOomoogNm00Ioo`03Nmioogoo00Aoo`9kgPAoo`05NmioogooOomkgP0SOol00g_NF]I_N`25Ool0
061oo`037>Moogoo03=oo`04HaPLigooNmh6Ool00g_NOomoo`02Ool00g_NOol00002Ool01G_NOomk
gWoo00000Woo00=g_GooOol02Goo00<Lif<HOol00Woo00AcW2U:000HaP9oo`03Nmioogoo00Eoo`03
125oog_N00Yoo`05Nmioog_NOol00002Ool017NmOomkgP002goo00IkgWooNmiNmbU:Nmh4Ool015kg
IcUoog_N0Woo00AkgWooOomg_@9oo`06MkeoogooOolU:E[F2goo0W_N0Woo00D007ooOomoo`0000Ao
o`03001oogoo00Uoo`03Nmh8@W_N00Aoo`05NmioogooOomcW002Ool00g_NOomoo`0:Ool2Nmh@Ool0
17_NOomooe[F0Woo00Ig_G_NOomoo`aSMkdDOol00g_NOomkgP02Ool01Q24MkekgWooNmig_@9oo`03
Nmioogoo00=oo`0400048@00000<Ool00eJe9BUoo`0BOol016mk6<Ioog_N?Goo00IkgWooOomoobU:
DY@@Ool3NmhfOol00g_NOomoo`25Ool0061oo`03001oogNm009oo`03Nmioogoo02ioo`03Kg/@Q7oo
00Qoo`04MkeoogooMkd2Ool01@00MkeoogooNmh00Woo00EkgP00Oomoog_N00Yoo`0348A[FW_N00Ao
o`03HaPe[G_N00Uoo`0336=cW7oo00ioo`04001oogooNmh2Ool00`00Oomoo`09Ool01G_NOomoodic
:DX00goo00AS61cW001:DP=oo`03Nmioogoo00Moo`03NmhYBU:D00moo`06001oogooOol007Nm0Woo
00=g_@00Ool02Woo00Eg_@Q2Oomoog_N00=oo`03F]I247oo009oo`03Kg]BU7oo00Qoo`03Nmioogoo
01=oo`05Nmioog_NOomkgP03Ool00f<H7>Moo`0IOol014ic8@QoogNm1goo00Eg_GooNmioog_N00ao
o`05NmiooaBUJeYkgP0COol01A24Kg]oogooNmh0?Goo00EkgWoo=JeBU7_N00Qoo`04MkeoogooMkd2
Ool00g_NOomoo`02Ool01G_NF]He[AcW36<0100000D48AS6>Li>Lfmk0:moo`00H7oo00<007ooOol0
<goo00=kgQ24Mkd01goo00=kgWooOol00goo00=kgP@QOol017oo00EkgWooOol007Nm00=oo`03Nmio
ogoo009oo`04Nmioog>L48@3Ool00g_NOomoo`05Ool2Nmh2Ool2Nmh00goo7>MNm`09Ool017NmOomo
og_N0Woo00L007ooOomoog>LOol0000>Ool01D8@BU9ooekg8@P00`0000E>LgooOomoog_N009oo`03
MkekgWoo00=oo`04NmioodHa@Q09Ool027_NOomoogooMkekgPQ2Nmh2Ool00`00OomkgP02Ool00`@Q
Oomoo`09Ool00f]J5:Eoo`03Ool02Ekg9BT002e[OomkgWooF]HQ2002Nmh?Ool00g_NOomoo`0:Ool0
1GNmOomoogooNmh017oo00=243g_Nmh06Woo00<HaU[FOol03Goo00=kgWooOol02Goo00=243W>Nmh0
0Woo00=kgWooOol03goo00DYBU:DOomoog_N03moo`03BU9JeWoo00moo`09Nmioog>L<H`8@RDYCW=N
mfmk00Aoo`0:NmiS64Ha<H`8@RU:F]IkgWooNmhSOol01TicKg]oog_NOomkgX5oo`00H7oo00D007oo
Oomoog_N009oo`03Nmioogoo02eoo`03:DYBU7oo00Qoo`06MkeoogooMkekgP000Woo00Ag_GooOomo
o`9kgP04001oogooNmh3Ool00g_NOomoo`02Ool00dic:DYoo`03Ool01G_NOomoogooNmh02Goo00<m
kd8@Ool02goo00AkgWooNmh000Eoo`03001oogoo00Yoo`05NmioobDY=JdQ20050000348@F]IJeV<H
IcUNme[FHaQ[FV<HG_MS609Nm`03IcTmkbDY00]oo`05Nmig_GooNmh00002Ool00gNm249oo`02Ool0
0g_N001oo`0:Ool01TYB<Haoog_NIcTU:@800003124]Jgoo009oo`03HaPU:Goo01Aoo`03Nmioogoo
00Moo`9kgP08Oom[FU[FJeYcW7oo<HaBU0Aoo`03Nmioogoo019oo`07Nmioog>L7>McW7ooLi`00Woo
00=g_GooOol017oo00=kgWooNmh02Woo00=_NacWKg/00Woo00=cW7ooOol047oo00=>LcF]Ool0@Goo
00=g_GooOol02Goo00AkgWooOomg_@9oo`04Li`]JaS6@Q03Nmh5Ool00g_NOomoo`03Ool015:D7>LY
BVLi0Woo00=kgWooOol07goo00<U:EkgOol00Woo00=kgWooOol0Ogoo001POol00f<HOomkgP0dOol0
0eJe:DYoo`06Ool027NmOomoog_NOol007oo0006Ool00g_NOol00004Ool00g_NOomoo`04Ool00bDY
E[Eoo`02Ool00g_NOomoo`02Ool00gNmOomoo`07Ool00f<H8@QkgP07Ool00gNmOomoo`02Ool01G_N
Ool007ooNmh00goo00<007ooOol02goo00=g_@aS48@01P0000<HaR489BT00acW00DHaQcW7>LHaR48
008Li`046<HLibDY36<?Ool02P00Oomoogoo001g_GooNmioo`002goo00@Q25kgIcT]J`80000C1248
@P00:DYNmdYB=JdaS0Q2@Q0mkd8@?Nm243g_AS4mkc6<9BT00QcW0R4800<HaQcW8@P00R4800<LiaS6
5:D02@0000<48@0000000QS600DU:DicOolHaV]J01Qoo`06NmioogooNmiBU2DY0Woo00=kgWooNmh0
17oo00=kgWooOol00Woo00=kgWooOol01Goo0W_N00<DYFmkOol00W_N4goo00=W>AS6Nmh0?goo00Ek
gWooOomoogNm00]oo`06NmioogooDY@@Q4YB1Goo00=kgWooNmh027oo00IkgWooG_LLicF]NmhROol0
0aS6HaQoo`24Ool009Moo`03Nmh8@W_N00aoo`8000=oo`03001oogoo009oo`05001oogooOomkgP07
Ool00`Q2Oomoo`06Ool00g_NOomoo`08Ool00g_N36=cW005Ool00g_NOomkgP03Ool017_N125g_@@Q
0goo00<007oo00002Goo00YkgWooOomooe:D:DYoodic48@48@800003125:DWoo00Uoo`03Nmioogoo
009oo`039BUBU7oo00Qoo`06Nmioogoo001oo`000goo00<007ooOol00Woo00<007ooOol01goo0W_N
00<@Q7>L:DX00P0000X48@00000000Q29BTe[DHa=JdYBP<mk`=24005>Li244icF]INm`02HaP00ekg
HaQS6003G_L00f<HIcU_N`0AOol00`00Nmioo`02Ool00g_NOomoo`0DOol027_NOomooe:D8@QcW7oo
Li`8Ool00g_NOomoo`06Ool017_NLi`HaVLi5goo00A_N`Q2LiakgSaoo`06NmioogooNmi[FW_N2goo
00MkgWooOolicRU:Nmioo`02Nmh=Ool027_NOomkgW_NOom24248Li`QOol00acWIcUoo`24Ool007Mo
o`80009oo`03Nmioogoo01Yoo`03AS4icWoo00Aoo`03Nmioogoo00Aoo`03Mkd48Goo009oo`03Nmh4
8@00008000]oo`03=Je:DW_N01=oo`03>Li6<Goo009oo`03Mkeoogoo00Moo`8000=oo`03Nmh48@00
00eoo`039BUJeWoo009oo`06DY@@Q000001JeW_N2Woo00IkgWooOomkgVLi7>L6Ool017_NOomoogNm
0goo0P000goo00<007ooOol00Woo00<007ooOol017oo00IkgWooOomoodHa=Jd2Ool00f]J:DX00002
00000`@Q;F]oo`06Ool00g_NOomkgP0MOol01W_NOomoogooJeX@Q1moo`03E[DQ26]J00aoo`03Nmio
ogoo00=oo`04E[DLig>LNmhGOol03Tic124@Q000124002487>LU:Be[>Li6<DicF]H2HaP00gNmOomo
o`0]Ool01W_NOomoogooAS5BU0Aoo`04MkeoogooOol2Nmh01GooMkeooacWAS4067oo00AJeR48Kg]k
gPEoo`04NmioogooOol2Nmh00gooNmioo`0AOol00dicLiaoo`24Ool0061oo`038@QcW7oo009oo`03
Nmioogoo00Yoo`08NmioogooOomkgP00Oomg_@Aoo`03Nmioogoo01Qoo`035:E_Ngoo00Moo`07Nmio
ogooOomcW7ooNmh00Woo00=kgWooOol00Woo0W_N0goo0W_N0Woo00E_N`aSOomoofmk015oo`08Nmig
_A24Nmioog_NOomkgPUoo`03001oog_N009oo`03Nmh48Goo00Moo`08Nmioog_NOom_NacWOomkgP=o
o`04Nmi>La24CW<9Ool017_NOomoog_N0Woo00EcW2DYIcUg_G_N00Qoo`04Nmioogoo0004Ool4000:
Ool02Fmk48Ag_G_NOomg_GooKg/e[@0200001Re[Oomoog_NOomcW09oo`03Nmioogoo01moo`04Nmio
ofLi6<HPOol01f]J6<HaS6]JOomkgWoo009kgP=oo`03Nmioogoo00=oo`05IcTU:BU:LiakgP0IOol0
1@aSKg]oog_NOol00V<H00UJeTic@Q0icS6<9BTLiaS624800P0000`<Hb489BTQ248@>Li245[FHaQW
>FmkNmhQOol00g_NOomoo`02Nmh01GooNmioog_NJeX00Woo00QkgWooOomoogNmOolLie[F6Woo00=_
Nb48Nmh00W_N0Woo00AkgWooOomkgPAoo`9kgYQoo`00H7oo00ANmgooOomkgP=oo`03Nmioogoo00Uo
o`05MkekgWooOol00003Ool00gNmOomoo`0JOol01g_NG_LU:GooNmioog_N00Ioo`03Mkeoogoo00=o
o`03Nmioog_N00]oo`05NmhYBUkgOomkgP0COol00gNm@Q0icP0@Ool00g_NOomg_@0:Ool2Nmh00goo
6<IJeP07Ool2Nmh00gNmOomoo`06Ool00g_NOomoo`04Ool01ekg6<IoogooMkeoog_N00=oo`9kgP05
OomkgWooOomcW006Ool00g_NOomoo`02Ool00g_NOomoo`03Ool00dYB=Jeoo`04Ool01GNmOom_NcW>
<H`00goo00=_Ne[FOol07Goo00EkgWooOomkgWNm00=oo`03F]HU:Goo01ioo`07Nmioog_NCW<<HcF]
G_L017oo0W_N0Woo00I_NgNmE[DLiaS6E[DLOol00aBUJeYkgP0?Ool06G_NIcUNmekg?Nm6<Cg_:DXQ
21cW5:D48@00124@Q1S69BTaS3W>?Nm:DU[FHaQNmf]J009oo`03Nmioog_N00=oo`04NmioogooNmh@
Ool01FLi000e[GNmOol00g_N00=oocF]AS4067oo00Ig_G_NOomooe[F6<H2Ool2Nmh6Ool00g_NOomo
o`2IOol0061oo`03Nmig_Goo00=oo`03Nmioogoo00Uoo`03Mkeoogoo009oo`03001oog_N00=oo`03
Nmioogoo01Uoo`03Nmi2448@00Moo`04NmioogooNmh@Ool017_NOom6<CW>5goo00EkgQS6Kg]oog_N
00]oo`9kgPeoo`08Nmiooe:D8@Qoog_NOomkgP=oo`03Nmioogoo00]oo`04NmioogooNmh2Ool012U:
E[Eoog_N0goo0W_N0Woo00=kgWooOol017oo00=kgWooOol01Goo00akgWooMkeoog_NOom_N`Q2Oomk
gWooNmh8Ool01GNmOomW>E[FNmh017oo00=kgWooOol05goo00=g_GooOol017oo00=BU2e[Ool087oo
00QkgWNmHaPaS248000HaS6<148@00DaS0Q2124U:F<H009oo`03Nmioogoo01Uoo`059BUNmgNmOomg
_@0>Ool00g_NOomoo`09Ool037_NLiaW>EkgE[E:DT8@?NlYBR489BTLi`80000=36<Q21BU9BTmkd8@
AS5F]EkgHaQ_NgNmNmh02Goo00ES66mkOomkgVLi0080000348A>Lgoo009oo`05BU8]JgooOomg_@0C
Ool00g_NOomoo`05Ool00dHa<Haoo`02Ool01GNmOomoogooNmh00goo00=_N`00Ool047oo00=>Lg>L
Ool0Q7oo001SOol017_NOomoog_N37oo0W_N0Woo00<007ooOol017oo00=kgWooOol06Woo00DaS4ic
Oomoog_N00Yoo`03Nmioogoo009oo`03Nmioogoo00Ioo`03BU8aS7oo00Aoo`03Nmioogoo015oo`04
IcTQ27ooNmh9Ool01G_NOomoogooNmh03Goo00=[FQS6Nmh01Goo00EkgWooOomoog_N011oo`04Nmio
oacWHaP5Ool00g_NOomkgP03Ool017_NOomoogNm0goo00=kgWooNmh00goo00UkgWooOomoog>L7>M_
NgooMkd017oo00=kgWooOol0:Goo00IkgWooOomooe:D<H`OOol2Nmh027ooMkdDY@@QJeYoof<H@Q02
?Nl01cW>AS5:DQS6G_MoogNm01aoo`9kgP037>MNmgoo009oo`03Nmioogoo00eoo`03Nmioogoo00eo
o`04NmioogooOol2Nmh3Ool016]JIcUS65:D0SW>00De[B488@PLia2400848@0448@LiacW8@P2@Q00
1cW>F]HYBSg_Liaoof<H00@000057>MS66mk6<IkgP0OOol00bDYG_MkgP03Ool01GNmOomoogooNmh0
0Woo00<48GooOol03goo00=>Lg>LOol0Q7oo001POol00aS6Oomoo`02Ool2Nmh9Ool00g_NOomkgP04
Ool010@QOomoogNm8Goo00<LidicOol00Woo00EkgWooOomkgWoo00AkgP9oo`9kgPQoo`03LiaF]C6<
00Aoo`03Nmioogoo01Aoo`03F]HU:G_N00Yoo`03Nmioogoo00=oo`03Nmioogoo00Moo`03Kg/DYGNm
00Aoo`05MkeoogooOomkgP0;Ool017_NOomoog_N0goo00EkgWooLi`U:F]J00Moo`03Mkeoogoo00Io
o`03Mkeoog_N009oo`09MkekgWooOomcW7oo9BUF]G_N00Aoo`04NmioogooOol2NmhTOol00g_NOomg
_@05Ool00eJe:DYoo`0OOol00gNmNmhaS00200000b48Mkeoo`06Ool00acWHaQoo`03Ool00g_NOomo
o`0IOol01248G_MoogNm3Woo00EkgWooOomoog_N009oo`9kgP=oo`03Nmioogoo00eoo`05Nmioogoo
OomkgP08Ool01GNmJeYNmf]JAS400Sg_00E240@Q6<HDY@Q20080000312400000008000055:E:DWoo
OomkgP0FOol2Nmh2Ool2Nmh017ooLi`DYG_N1Goo00=kgWooOol00Woo00<007ooOol0UWoo001POol0
1000Oomg_GNm4Woo0`0017oo00=kgWooOol06goo00Ag_Goo<H`]J`=oo`03Nmioog_N011oo`05Lia:
DR48Mkeoo`02Nmh3Ool00gNmOomoo`0>Ool02GNmOomoog_NOom:DS6<MkekgP07Ool017_NOomoogNm
0Woo00=g_GooOol01Woo00Ag_G>L6<I[FP=oo`03Nmioogoo01Uoo`05IcTHaVmkOomkgP09Ool00g_N
Oomoo`02Ool00gNmOomoo`03Ool2Nmh017oo9BUBU7_N0Woo00Eg_GooNmioogNm00Eoo`05Nmioogoo
Kg]>L`04Ool00g_NOomoo`0HOol00g>L=JeW>@04Ool00e[F8@Qoo`0POol00dic00048@0200000cW>
Nmioo`03Nmh2Ool01B48F]IoogooMkd077oo00=kgQS6HaP02goo00=kgWooOol02goo0W_N2Goo00=g
_GooOol00W_N0Woo00=g_GooOol03Woo00=kgWooOol00Woo00HaS5:DOomkgTHa1243000010Q21248
@V]J5Woo00=kgWooOol027oo00<aS4YBNmh01goo00=kgWoo1240V7oo001POol01`00NmioogooMkeo
og_N011oo`04125oogooNmh3Ool00g_NOomoo`0KOol2Nmh00dic6<IS6009Ool01G_NOomoogooNmh0
0Woo00IkgWooOomF]BU:@Q0JOol00g_NOomoo`02Ool015[F7>M_Ng_N57oo00AcW5kg5:E_Naeoo`07
NmioogooOom[FQS6DY@037oo00=g_GooOol01goo00=W>B48DY@02goo00=kgWooOol00goo00=Nmb48
Ool07goo00@<H`006<INm`9oo`04HaPHaWooNmh2Ool00g_NOomoo`0IOol00f<H0000000400000e[F
Nmioo`04Ool011cWHaQoog_N0Woo00=kgWooOol06Goo00@@Q6mkOomkgP9oo`03Kg]g_Goo03Moo`05
NmioogooAS5F]@02Ool0248@000000008@Q6<CW>CW<3Ool017_NOomoog_N6Woo00=kgW>L48@00Woo
00=kgWooOol01Goo00<007ooOol03goo00=>Lg>LOol0Q7oo001POol00`00Oomoo`0=Ool00g_NOomk
gP02Ool01G_NOol007ooNmh01Goo00=kgWooOol077oo00EkgV]J6<HYBU[F009oo`03Nmioogoo00Yo
o`04F]HQ22DYG_LPOol01G_NLi`HaTHaLi`04Goo00AkgVmk>LhU:BAoo`04Li`aS2e[Li`<Ool00g_N
Oomoo`03Ool017_N?NlDYF]J4Woo00=S6248Ool00goo00=kgWooOol06Goo00T@Q00000000248F]I[
FQBUNmh00goo00=kgWooOol05Goo00YkgWooOomg_EJe@Q0mkbDY7>Lmk`924003Oomg_Goo00=oo`03
7>MW>Goo009oo`03Nmioogoo00Uoo`03Nmioogoo00ioo`0848A_NgooOom:DQcW001_N`9oo`03Nmio
ogoo00Ioo`03Nmioogoo02Yoo`03Nmioogoo00=oo`08NmhaS0@Q=Je[FW_NOol<H`9kgPmoo`04Nmio
ogooNmh>Ool017_N48A_Ng_N0Woo00AkgWooOomkgP9oo`8000=oo`03Nmioogoo00Yoo`037>MW>Goo
08Aoo`00H7oo00=NmgooOol06Goo00=kgWooOol087oo00Qg_GooF]HQ2124?Nm[FW_N0goo00YcW7oo
Oomg_GooIcTaS1BU7>MJeP9oo`03Nmioogoo01ioo`05NmioocF]5:E6<@04Ool00g_NOomoo`04Ool0
27_NOomoogNmKg]6<A24DY@ROol00g_NOomoo`02Ool014ic48@e[Fmk0goo00=kgWooOol00Woo00Ag
_GooOomkgP9oo`04Nmi240aS@Q0=Ool00g_NOomoo`04Ool015kg7>Moog_N0goo0W_N1Goo0W_N1Woo
00=_Nf<HHaP01f<H0T8@00<000@Q12400`0000<<H`@QOol00Woo00=kgWooNmh04Goo00=kgWooOol0
0Woo00MkgWooOomoog_NOomkgP02?Nl6Ool02SW>=Je241BU9BU6<Cg_E[Eoog_N2Woo00=kgWooOol0
0Woo00=kgWooOol027oo00Ag_@@QMkdaS088@P800003Nmioog_N009oo`03Nmioogoo00Ioo`03Nmio
ogoo00ioo`03Nmioogoo009kgP9oo`04Mkeoog_NNmh9Ool00g_NOomoo`04Ool027NmOomoogooNmio
of<HKg/3Ool00ekg6<Ioo`0SOol00cg_AS5oo`02Ool00g_NOomoo`02Ool017Nm249oo`000goo00=k
gWooOol02Goo00<HaV<HOol0Q7oo001QOol01GNmOomoogooNmh04Woo00=kgWooNmh09goo00IkgVLi
AS4DY@@Q6<H27>L0248@;F/HaQS6124LidYBKg/5Ool00g_NOomoo`0NOol027_NOom_NcW>5:DU:EJe
Mkd4Ool02W_NOomkgWooNmhmkbe[36<mkg_N:Woo00EBU0aS6<I>Lf]J00Uoo`04CW<]Ja24>Lh2Mkd2
Nmh>Ool047_NOomoog_NKg]:DWooIcUNmeJeDYA6<D8@>Lh]Jb480QcW00@U:BU:36<8@P@0000348@L
iacW00LLi`8mk`091240000000048@007>L@Q6]J01Uoo`9kgP03OomkgWoo00Aoo`8mk`=oo`06Nmio
og_N@Q0000@Q0`0000<<Hf]JNmh02Woo00AkgWooNmikgPeoo`03@Q08@P0000@00003249g_Goo009o
o`9kgPIoo`9g_A9oo`9kgQYoo`05HaQcW7ooOomkgP02Ool017_NOom:DT8@4Woo00=kgWooMkd037oo
00EkgWooOomS624800Eoo`05Nmioog_NOomcW003Ool01GNmOomoogooNmh02Goo00<U:EkgOol00Woo
00=kgWooOol0Ogoo001SOol017NmOomoog_N2Goo00Eg_GooOomoog_N009oo`03Nmioogoo02Moo`03
Nmioogoo009oo`0:Nmi[FV<HG_Lmke:DIcU[FWooNmh2Ool00g_NOomoo`02Ool00g_NOomoo`0ROol0
1g>LDY@YBPaS248Lib48008e[@068@PHaPQ2124mkeJe:7oo00=kgWooOol00Woo00IkgWooHaPe[@aS
00027>L02C6<>LhU:AcW24848CF]DYA_N`02Ool00gNmOomoo`02Ool02GNmNmioogooNmicW6<HF]I2
4002?Nl04C6<7>LQ21cW248000Q236<HaR48:DXaS3W>?Nm6<E:DF]H00V<H00ANme[FJeYg_@=oo`03
Nmioogoo00Yoo`0948@00000000@Q5JeNmhYBUJe00=oo`03Nmioogoo00moo`03Nmioog_N00Qoo`04
Mkeood8@@Q07Ool01Re[000000Q2001BU15oo`03Nmioog_N00Qoo`03NmhicP000080000324800000
008000039BTQ21BU00=24005BU9JeV<HIcUg_@0/Ool01g_NOomoog_NBU9Nmg_N009oo`06Nmioogoo
Oole[DYB5Goo00=kgWooOol037oo00=W>AS6Ool03goo00=kgWooOol027oo00I>LfmkOomkgWooNmj1
Ool0061oo`037>Mg_Goo00=oo`03Mkeoogoo00Yoo`04NmioogooMkd2Ool017_NOomoogNm97oo00Ak
gWooOomkgP9oo`03Nmioog_N00Aoo`03Nmioogoo02ioo`04Nmig_F<HG_L2BU800ekgHaQg_@04Ool0
0g_NOomcW00QOol01G_NOomoogooNmh017oo00=kgWooNmh00Woo00UNmfLiBU96<EkgIcUg_GooNmh0
17oo00=W>EkgDY@00T8@00<aS2485:D00P@Q00dDYB48<Ha:DSg_BU9Nmf<HIcUcW7NmOomkgP0EOol0
0g_NOomoo`07Ool02g_N36<8@Q24DYAoog_NOolicTHaNmh05goo00AkgWooOom_N`Ioo`03>Lhmkgoo
00=oo`05MkeoogooKg/@Q00200001Cg_OomoogooNmh02Woo00A_NgooOomkgPaoo`03>Li6<D8@00@0
000=6<IooekgHaQW>CW>@Q0icRe[9BTLiaBU12400P0000/DYAS68@P]JcF]@Q1>Le[FHaQW>GNm00=o
o`03MkekgWoo00Uoo`03Nmioogoo00Aoo`03Nmioogoo009oo`03Nmioogoo00Qoo`03Nmioogoo00=o
o`039BUBU7oo011oo`@00003OomkgWoo00aoo`03Kg/<Hgoo009oo`03Nmioogoo009oo`=kgP9oo`05
NmioogooOomkgP2@Ool0061oo`05HaQoog_NOomkgP0DOol00g_NOomoo`0YOol00g_NMkeoo`09Ool2
Nmh[Ool01G_NOomkgWooNmh027oo00=g_GooOol097oo00EkgWooOomoog_N00Qoo`0DMkeoogooLiaN
me:D?Nle[AS67>L001248@PLidHa>Li6<E[FHaQg_@Aoo`04NmioogNmNmh2Ool01G_NOomoogNmCW<0
0Woo00AkgWooOomkgQYoo`038@Q6<G_N00=oo`05NmiJeQcWOomkgP0HOol00g_NOomkgP04Ool017_N
@Q16<G_N0goo00UkgWooOomoof<H124HaWooNmh037oo00=kgWooNmh03Goo00UkgQcWIcUkgWNm7>L8
@P008@P00Woo00=kgWooOol01Goo00akgWooOomkgVLiHaQNmeJeAS4icRe[8@P27>L02`Q2000001BU
9BTYBRDY?NlicT8@E[D00VLi00=_NgooOol01Woo00=kgWooOol017oo0g_N00=oog_NNmh00goo00Ak
gWooNmioo`9kgP03OolLif]J011oo`06001oogooOomkgP0037oo00AkgWooOol000Ioo`03Mkeoogoo
00Moo`03Nmioogoo00Moo`03Nmioogoo08Eoo`00H7oo00EkgWooNmioog_N00]oo`03Nmioogoo00Ao
o`03MkekgWoo00=oo`03Mkeoogoo021oo`04NmioogooLi`4Ool00gNmOomoo`05Ool00g_NOomoo`04
Ool00gNmOomoo`0WOol017_NOomkgW_N27oo00=g_GooOol087oo00AkgWooOomg_@Ioo`0?MkeJeUJe
AS4U:Be[248001BU8@PicT8@DYA[FWNm01Moo`04JeY>LgooNmh@Ool2Nmh:Ool00g_NOomg_@03Ool0
1g_NOomoogoo249oog_N01=oo`03Nmioogoo00Qoo`04Nmioog>LLi`7Ool017NmOom6<GNm5Goo00=k
gWooOol01goo00P007ooOomg_GooDY@@Q2e[1Goo00AkgWooOomkgP=oo`9kgPUoo`06NmioogooNmi_
Nekg0U[F00M244Ha?NlU:AS65:D<H`02000031246<HHaRDY?Nm6<Cg_G_MJeUkgKg]kgPQoo`03IcUc
W7oo00Ioo`037>MJeWoo00moo`07001oogooMkeoo`@QMkd02goo00AkgWooOol000Uoo`05Mkeoogoo
OomcW00<Ool00g_NF]I_N`25Ool006Ioo`03Mkeoogoo00Yoo`07Mkeoog_N124000@QNmh00goo00=k
gWooNmh08Goo00EkgWooOomoog_N00aoo`03Nmioogoo05aoo`0=MkeoogooG_MBU4Ha8@PHaP@Q36<Y
BS6<@Q000U[F00=kgWooOol08Woo00=kgWooOol06Goo00=g_GooOol01Woo00<LieJeOol05Woo00Ak
gWooOol000]oo`06NmioogooNmioog_N0Woo00=g_GooOol037oo00@007ooOomkgP]oo`04BU8e[Goo
Nmh2Ool2Nmh00f<HOomkgP04Ool00g_NOomoo`0OOol02fmkIcUW>E[F@Q0icT8@9BTQ21cW48@00P00
00d8@QS68@PQ23F]?Nm241cW>LiNmfLiOomkgP02Ool00g_N;F]BU00@Ool01P@QOomoogooMkd48@io
o`03Kg/DYG_N00Ioo`05NmioogooOomkgP03Ool00g_NOomoo`09Ool00dHaKg]oo`24Ool0061oo`03
8@Qoogoo00eoo`03Nmioogoo009oo`05001oogooOol00003Ool00g_NOomoo`2<Ool01W_NKg]F]D8@
;F/HaP88@P066<HaS4YBF]IcW7_N:Goo00=kgWooOol05goo00EkgWooOomoog_N00Aoo`04Nmioogoo
IcT2=Jd00g_NOomoo`0<Ool00g_NOomoo`05Ool017_NOol48G_N3Goo00=kgWooNmh017oo0W_N37oo
00AkgP@QOomkgP]oo`03:DYF]Goo00=oo`03Nmioogoo03Eoo`0;LiaW>EkgIcTmkd8@AS4<Ha248@PH
aP0300028@P00cF]AS5kgP05Ool00gNmOomoo`07Ool2000017_NOomoo`0037oo00AkgWooG_LLi`Ao
o`04NmioogooNmh4Ool01G_NOomoogooMkd03Woo00=kgWooOol0P7oo001POol00`00NmikgP0AOol0
0g_N48Ag_@03Ool00g_NOomkgP02Ool00g_NOomoo`1mOol00g_NOomkgP03Ool2Nmh037>LDY@mkb48
36<48ABU<Ha6<EJeIcUkgP=oo`03Nmioog_N02Moo`03Kg]BU7oo01eoo`05MkeoocF]5:DQ20022483
00000c6<249oo`0;Ool01W_NOomkgWoo001kgPIoo`07001kgWooOol48GooNmh00goo00<007ooOol0
0P0000=g_@00Ool00`0000=kgWoo00000Woo00@007ooOol0009oo`800006Li`007ooOomkgP002goo
00=g_@Q2Ool00Woo00=g_GooOol0>7oo0W_N17oo00<]Je:DOol017oo00AS65JeCW<aS11oo`07001o
o`0000048GooMkd037oo00=kgUkg9BT01Goo0W_N17oo00AkgWooOomg_@aoo`03Mkeoogoo08Aoo`00
H7oo00<007ooOol03Goo00Mg_GooNmikgWoo00048@0200000`@QOomkgP02Ool00gNmOomoo`1/Ool0
17_NOomoog_N2Goo0W_N1Woo00YS64ic?NlQ20Q236<]Jd8@HaQkgP=oo`03Nmioogoo009oo`9kgRYo
o`03IcTQ27oo01eoo`03NmioofLi008000031240000000848@03Ool]JdHa00moo`03001oogoo00Ao
o`06Nmh48GooOomkgP000Woo00IkgWooNmh48Goo0002Ool00`0012400002Ool017_N125kgP000Woo
00/007ooOol007oo001g_Goo248007_N009oo`03125kgWoo00Uoo`03BU8icW_N04=oo`05BU9JeW_N
Oomg_@02Ool01WNmOomcW124OomkgPioo`05001oog_NOomg_@02Ool00g>LOomoo`0:Ool00cF]BU9o
o`07Ool00gNmOomoo`02Ool017NmOomoog_N2Woo00=BU7>LNmh0Q7oo001POol00`00Mkeoo`04Ool0
0g_NOomoo`0;Ool01@00Oomoogoo00000Woo00=g_GooOol0Jgoo00=kgWooOol02Woo00=kgWooOol0
0Woo00YcW5[F?Nl]J`Q2124LicW>AS5S60Eoo`9kgPYoo`03Nmioogoo02Ioo`03G_LDYGoo021oo`03
;F/0000000<00004HaQoofmk48@2Nmh:Ool01W_NOomkgPQ2Oomg_@Eoo`07001oogooOol007ooNmh0
0goo00@007oo001kgP9oo`05001oogooNmh00002Ool010@QOomkgP000Woo00<007_N00000goo00D0
07ooOomoo`0000Moo`08NmioogooNmh@Q5:D@Q16<@8mk`03>Lhmkdic03Qoo`04NmioogooNmh;Ool0
1124JeYoog_N3Goo00<007ooNmh00Woo00=kgWooOol037oo00<8@WNmOol01Woo00QkgWooOol000@Q
001oog_N0Woo00=g_GooOol01goo00<YBV<HNmh0Q7oo001POol016<HOomoog_N37oo00=g_GooOol0
0Woo00D007ooNmioo`0000=oo`03Nmioogoo07=oo`=kgP9oo`09G_M:DRU:5:D@Q2DY@Q1F]GNm009o
o`04NmioogooNmh8Ool00g_NOomoo`0^Ool00ekg;F]kgP0GOol00g_NOomoo`02Ool01G_NOomkgW_N
@Q000P0000@48@00;F]kgP9oo`03=JeNmg_N00eoo`03001oogoo00Eoo`0=001oogooOol48@001240
07_NOol007_NOol0100000Moo`00125oog_NOol00002Ool010@QOomoo`000Woo0`0000D48GooOomo
o`0000Yoo`04BU8Q20001243000212400dYBOomoo`0nOol00g_NOomoo`02Ool017_NOom6<CF]1Goo
00=kgWooOol01goo00<007ooOol00Woo00<007ooOol02Goo00Ig_GooG_LLigooNmh3Ool01W_NOomo
ogooMkd000=oo`04001oog_NNmh:Ool00aS6F]Ioo`24Ool0065oo`=kgQ9oo`0300048@00009oo`04
NmioogooNmiYOol2Nmh6Ool037_NOomoog>LF]He[ABU000U:CW>E[E_N`Eoo`04NmioogooNmh2Ool0
0g_NOomoo`06Ool00g_NOomoo`0]Ool00fmkF]Ioo`0MOol01G_NKg/LiaBU?Nl00P0000L@Q7_NOomo
og_NLi`<H`02Nmh<Ool01000Oomoog_N0goo00IkgP@QOomoog_N0003Ool01@00Ool007oo00000goo
00<8@P00Nmh00Woo00H007oo124007Nm0002Ool00`00Ool00003Ool01P00Nmioogoo125kgPQoo`04
JeXQ26Li;F/200001@Q2000000aSNmh0>Goo00Ig_GooOomoof]JKg/3Ool00g_NOomoo`02Ool00fmk
6<IcW00?Ool40002Ool00g_NOomoo`09Ool00bDYE[Eoo`02Ool01G_NOomoogooNmh00Woo00L007oo
Oomoog_NOomkgP0;Ool00bDYG_Moo`24Ool0061oo`03Nmioogoo011oo`03Nmioogoo00Moo`03Nmio
og_N06Yoo`08NmioogooOomg_F]J?NlU:@8<H`04:DY>Lf]JMkd;Ool00g_NOomoo`07Ool00g_NOomo
o`03Ool00g_NOomoo`0[Ool00g_NOomoo`0DOol00g_NOomoo`04Ool017>L<H`005:D0Woo00@HaP@Q
CW=kgPAoo`03AS4aS7oo00Yoo`04Nmig_@@QNmh6Ool02`00Nmioogoo001oofmkOol007oo00000W_N
0`0000=g_Goo00000P000Woo00<007oo24800`000goo0`000goo00=kgP00Ool017oo00AkgWooOomg
_@92409oo`086<H0000000048BU:OomkgS]oo`04Lia>Le[FNmh5Ool01W_NOomood8@?NmkgPioo`03
Mkeoogoo009oo`03Mkeoogoo00Moo`05Nmiooe[F;F]kgP02Ool017_NOomoog_N17oo0`000P@Q00=k
gWooOol02Goo00=kgU:DKg/0QGoo001POol00b48Nmioo`04Ool00g_NOomoo`0@Ool017_NOomoog_N
JWoo00IkgWooOomW>Cg_7>L25:D00d8@F]Ig_@0>Ool00g_NOomoo`10Ool00g_NOomoo`0FOol01G_N
AS4<HcW>Mkd00goo00=NmbU:Ool01Goo00=kgQcWIcT037oo00<007ooOol017oo00MkgWoo125kgWoo
001kgP02Ool00`00Ool48@04Ool00g_NOomoo`07Ool00g>LOomkgP02Ool00g_NOomg_@04Ool017_N
125oog_N17oo00YkgWooNmi[FQS6OomkgWooLi`<H`800005248Lia24DYAcW002Ool00g_NOomoo`0c
Ool00gNmOomoo`04Ool00g_NOomkgP03Ool017_NOolDYF]J47oo00=kgWooNmh02goo00=kgQcWIcT0
0Woo00=kgWooOol00Woo00EkgWooOomoo`0000=oo`03001oogoo099oo`00H7oo00=S67ooOol03Goo
00=kgWooOol00goo00=kgWooOol0KGoo00Ug_FmkAS4YBPaS48@e[F<HNmh0DGoo00=cW4YBOol06Goo
00AF]ABU:DY[FPEoo`03Nmioogoo00=oo`05NmioogooDY@YBP04Ool00g_NOomkgP03Ool00`00Ool0
0006Ool01G_NOomoo`00Ool00P0000D8@P00Nmioo`0001Yoo`03125oog_N009oo`03Nmioogoo00=o
o`039BUNmgoo009oo`0;NmiNm`@Q000icWooF]HLiaS6?NmcW00:Ool00g_NOomoo`0hOol01Ekg8@Qo
ogooMkd01Woo00=kgWooOol02Goo00=kgWooOol01Woo00Dmkd8@Oomoog_N009oo`03Nmioog_N00=o
o`06Nmh48GooNmioo`004Goo00=kgWooOol0P7oo001UOol00gNmOomoo`0;Ool00g_NOomoo`1ROol0
0g_NOomoo`08Ool026mkCW<]JaBU248icUJeLi`3Ool2Nmi@Ool00fmkG_MkgP0=Ool00gNmOomoo`05
Ool01W_NOom[FRDY48AF]@ioo`05Mkeoogoo9BU>L`03Ool017_NOomoog_N0goo00<000@QOol00Woo
00=kgWooOol01Goo00=kgWNmOol07Woo00AkgWooOomkgP=oo`05NmioogooCW<]J`06Ool014ic36=c
W7>L0Woo00EW>BU:36<icW>L00=oo`03Mkeoogoo00Qoo`03Nmioogoo02Aoo`04NmioofmkMkd9Ool0
17_NOomF]BU:37oo00=kgWooOol02goo00AkgWooBU8YBP9oo`03Kg]oogNm00=oo`03Mkeoogoo009o
o`04Nmh000000002Ool00gNmOomoo`09Ool014icLiaoog_NPgoo001SOol00gNmOomoo`0?Ool00g_N
OomkgP1MOol00g_NOomoo`08Ool01f<H?NlDY@aS:DYF]G>L05Uoo`03Nmioogoo00ioo`04Mkeoogoo
Nmh2Ool01GNmNmi240aS>Lh017oo00=kgWooOol00goo0W_N00=oog_NOol00goo00AS61BU8@QcW09k
gPAoo`07MkeoogooNmh8@WooNmh01Woo00=kgWooNmh01Goo00=kgWooOol06Goo00=g_GooOol01Goo
00Ig_G>L8@Q[FWooNmh5Ool00e:DOomoo`04Ool01F]J;F/8@Re[Kg/00goo0W_N0Woo00=kgWNmOol0
1Goo00=kgWooOol07goo00IkgWooOomoobe[CW<;Ool01W_N?NlmkgNmOomg_@Ioo`03Nmioogoo00Qo
o`09MkeoogooOomkgWooE[DYBWoo009kgP03Oomg_Goo00Moo`03Nmioogoo011oo`06CW=cW7ooMkeo
og_NPGoo001POol01BDYNmioogooNmh00Woo00=kgWooOol0KGoo00AkgWooMkeg_@9oo`06HaP]J`Q2
7>LmkfLi37oo00=kgWooOol0IGoo00IS60@Q9BUcW7ooNmh?Ool01gNm;F/48E[FHaPLig_N00=oo`03
Nmioogoo00=oo`03NmioogNm00Aoo`04NmioogooKg/2Ool00gNmOomoo`02Ool00g_NOomoo`0NOol0
1W_NOomg_B48IcUkgPEoo`08MkeoogooNmioog_NOomkgP=oo`05Lia6<@Q29BUS600cOol00bU:DYAo
o`08Ool01g_NOomoogNm>LhaS7Nm00Aoo`03Mkeoogoo00Yoo`03Nmioogoo00=oo`03?NlYBW>L00=o
o`04MkeoogooNmh3Ool01WNmOomoog_NOomkgPEoo`03Liaoogoo08moo`00H7oo00<007ooNmh047oo
00Ag_GooOomkgUUoo`04NmioogooOol2Nmh3Ool01g_NF]HQ20@Q7>M>Lg>L009kgUioo`05Lia:DWoo
OomkgP0;Ool02gNmOomoog_NOomW>AS65:E[FWooNmh01goo00=kgWooOol00goo00ig_GooNmi240Q2
=Jeoog_NOomF]BDYOomkgWNm1Goo00=cW7ooOol00Woo00=kgWooNmh02Woo00=kgWooNmh07Woo00Ek
gWooLi`]Je[F00Uoo`03NmioogNm00=oo`04Nmig_GooOol2Mkd014Ha48@HaU[F2Goo00=kgWooOol0
8goo00EkgWoo<HaF]G_N00Yoo`06NmioogooF]H@Q6Li1Woo00=g_GooOol02Goo00EkgWooLi`Q248@
00=oo`05NmioogooOomkgP0<Ool01G_NOomkgWooNmh0T7oo001POol00`00OomkgP0COol00g_NOomo
o`1GOol00g_NOomoo`03Ool01WNmCW<Q20aS8@QJeP9oo`03Mkeoogoo00Uoo`03Nmioogoo05=oo`03
G_LQ27oo00moo`05Nmig_CF]249:DP02Ool017>LOomoog_N37oo00IJeQBU9BUcW7ooMkd3Ool00dic
;F]oo`03Ool00gNmOomkgP02Ool00g>LOomoo`04Ool2Nmh00gooNmig_@02Ool00g_NOomoo`0KOol0
0g>LOomoo`03Ool017_N=Je>Lg_N0Woo00=kgWooOol017oo00EkgWooMkeoog_N00Qoo`05NmiBU1BU
5:EBU00_Ool00cg_F]Ioo`0=Ool01G_NLi`DYBe[HaP00Woo00=kgWooOol017oo00=kgWooOol017oo
00Ag_D8@48AF]@Aoo`03Nmioogoo00Qoo`04Nmioog_NOol3Nmh2Ool00g>LOomoo`08Ool00e:DKg]o
o`24Ool0061oo`05001kgWooOomkgP0=Ool00gNmOomoo`02Ool00g_NOomoo`1GOol037_NOomooe[F
8@P@Q248F]Ig_GooNmig_F=oo`03G_LLigoo00moo`06AS4<HcF]Nmioog_N0goo00=kgWooNmh02Goo
00IcW1cW5:EF]GooNmh4Ool017NmOolicT8@1goo00=kgWooOol00Woo00=kgWooOol00Woo00AkgWoo
Oomg_@Aoo`03Nmioogoo01ioo`03>Lhmkgoo009oo`03Nmioog_N00Aoo`03Nmioog_N00=oo`04Mkek
gWooNmh2Ool02W_NOomoogooNmiJeQcW6<I:DW_N:Woo00=kgWooOol037oo00=g_GooMkd00goo00A>
Lb488@QF]@9oo`03Nmioogoo00Ioo`05NmiW>Be[48@mk`06Ool00g_NOomoo`02Ool01G_NOomoogoo
Nmh02goo00=kgWooOol01goo00<Q26<HOol0Q7oo001POol015kgOomoog_N0Woo00=kgWooOol01goo
00=kgWooNmh00goo00=kgP@QOol0F7oo00I[FSW>36<HaTicMkeYOol00ekg9BUoo`03Ool00g_NOomo
o`07Ool01U[F6<HQ26]JOomkgP=oo`03Nmioogoo00=oo`03Nmioogoo00=oo`05Nmi240@Q@Q1g_@03
Ool00g_NOomoo`02Ool017_NOole[D8@47oo00=kgWooOol087oo00=kgWooOol00Woo00=243F]Ool0
1Woo00=kgWooOol00goo00=kgWooOol03Woo00EJeRDY36=6<GNm02Moo`03Nmioogoo00aoo`03Nmio
og_N00Eoo`08NmiNmbDY124Licg_AS5F]@9Nm`07E[E:DSg_8@P8@QcWDY@00Woo00=kgWooOol02Goo
00=kgWooOol00goo00=kgWooOol017oo00=kgWooOol02Goo00DLif<HOomoog_N089oo`00HGoo00=k
gWooNmh04goo00<007ooOol0CGoo0W_N0goo00QkgWooMke>LaBU48@aS6Li0Woo00=kgWooOol0Igoo
00A_Ne:DOomkgPIoo`08NmioogooOom_NbU:48A>L`Eoo`03Nmioogoo00Aoo`04NmioogooNmh2Ool0
15:D5:DYBVmk2Goo00MkgWooOomg_Cg_9BUkgP07Ool2NmhXOol01WNmOomoogoo8@Pe[B5oo`07JeX]
J`aS=JecW7ooNmh03goo00=kgWooOol057oo00=W>GNmOol04Goo00EkgWooOomoof<H008mk`076<H8
@QcW8@Pmkd8@DY@05Goo0W_N1goo00=kgWooOol02Goo00<Q25[FOol0Q7oo001gOol00`00Oomoo`19
Ool017_NOomoog_N0goo0g_N00Dmk`Q27>MNmgNm00Eoo`03Nmioogoo06moo`08MkeoogooLi`mk`00
AS5kgPMoo`06Mkeoog_NNmioog_N17oo00A[FRDY5:EF]@Yoo`03Nmioogoo00=oo`03F]HDYFLi00Ao
o`9kgP=oo`03Nmioogoo01]oo`04NmioogooNmh3Ool01g_NOomoog_NIcTHaUkg02=oo`06Nmi_NcF]
124aS7Nm0Woo00=kgWooOol00goo00=g_GooNmh00Woo00=g_GooOol04Woo00IkgWooOomg_DYBG_LI
Ool00dYB>Lioo`0HOol00g_NOomoo`03Ool00gNmOomkgP03Ool00g_NOomoo`07Ool00dicKg]oo`24
Ool0061oo`058@QcW7ooOomkgP0BOol00`00Oomoo`1?Ool027_NIcT]J`00;F]cW7ooNmh3Ool00g_N
Oomoo`1]Ool017NmOomoog_N0Woo00IkgUJe36<U:GooNmh9Ool017NmOomoog_N0Woo00EkgWoo@Q08
@Sg_00ioo`08NmioogooNmioog>L5:DicP9oo`05MkeoogooOomkgP0YOol015Je6<I_NgNm97oo00Mk
gWooMkd]J`Q2;F][FP05Ool00g_NOomoo`02Nmh_Ool00g_NOomoo`03Ool00e:D9BUoo`02Ool00gNm
Oomoo`0@Ool00g_NOomoo`03Ool00g_NOol8@P04Ool00g_NOomoo`0<Ool00g_NOomoo`21Ool0061o
o`05G_MoogooOomkgP0BOol00`00Oomoo`18Ool017NmOomoogNm0Woo00IS61cW36=6<G_NOol2Nmh0
0gooNmig_@1]Ool016LiE[Eoog_N0Woo00]kgWooOom[FR486<IS67ooNmioog_N00Uoo`0=Nmioogoo
NmiooeJe000YBWNmOomkgWooNmh02Goo00AkgWooOomkgP9oo`05BU8@Q00048@e[@02Ool00g>LOomo
o`0QOol2Nmh2Ool01g_NOomoogoo:DXaS7>L02Eoo`03Nmioogoo009oo`05Nmi:DPaS:DYNm`04Ool2
Nmh2Ool00g_NOomoo`0EOol2Nmh2Ool00g_NOomoo`0@Ool00g_NOomoo`03Ool01Dic=JeoogooMkd0
5goo00EkgWooOomoo`0000=oo`04NmioogooNmh9Ool00g_NOomoo`24Ool0069oo`05NmioogooMkek
gP0@Ool00`00Oomoo`1<Ool016<H6<H8@U:D0W_NM7oo00=g_DicOol017oo00EcW36<48A6<GNm009o
o`03Nmioogoo009oo`03Nmioogoo00Eoo`06Nmioofmk8@P@Q6<H0Woo00=kgWooOol03Goo00=[FSF]
36<00`0000A_NdYB48A>L`Eoo`03Nmioogoo01]oo`03Nmioogoo00=oo`07NmiF]ABU001NmgooMkd0
9Woo00=g_GooOol00goo00E:DPaS5:EF]G_N00Aoo`03Nmioogoo01Aoo`9kgP9oo`03JeYg_Goo011o
o`03Mkeoogoo00Eoo`03DY@YBW_N00=oo`03Nmioogoo011oo`03Nmioogoo00=oo`03001oo`0000=o
o`03Nmioogoo00Qoo`04NmiF]G>LMkf4Ool0069oo`03Mkeoogoo019oo`03001oogoo04Moo`09Nmio
ogooJeXYBP@QE[Eoog_N00Eoo`9kgW1oo`03Nmioogoo009oo`04E[D8@S6<Kg/3Ool00g_NOomoo`02
Nmh7Ool2Nmh017Nm<H`48DHa0Woo00AcW7ooOomkgPaoo`03JeXQ200000@00009249oogooLi`]J`aS
DYAoog_N025oo`06MkekgWooBU8DYBDY0Vmk00D48EkgOomoog_N02aoo`04F]HLiaBUCW<7Ool00gNm
Oomoo`0COol00gNm<Ha>L`0DOol02G_NOomoog_NOomBU2e[OomkgP0EOol00g>LOomkgP02Ool017Nm
36=oo`000Woo00=kgWooOol02Woo00=BU7>LNmh0Q7oo001POol00acWNmioo`04Ool00g_NOomoo`0=
Ool00`00Oomoo`17Ool01W_NOole[@@QBU9oo`9kgP9oo`03Nmioogoo07Ioo`04G_LDYABULi`=Ool0
2W_NOomoog_NOomBU1BU=Jeg_G_N0goo00=kgWooOol037oo00=g_C6<00000`0000<48CF]Ool00W_N
00Ioofmk<H`LiekgMkd5Ool00g_NOomoo`0GOol01W_NOomJeQ24:DYcW0=oo`03F]H8@V]J02Moo`04
MkeoogooNmh5Ool01e[F9BT48DHaMkeoog_N01Ioo`9kgP04Oole[EJeNmhAOol01G_NOomoog_NAS40
100000@48@00125g_AAoo`03Mkeoog>L009oo`03001oo`0000Eoo`03Nmioogoo00Moo`03Liaoogoo
08Aoo`00H7oo00D007ooOomoog_N019oo`03001oogoo04Moo`04E[D@Q36<LiakOol026]JE[EcW2e[
5:EBU7ooNmh@Ool016<H7>LHaUkg1Goo00=kgWooOol03goo00<icP0012400P0000=:DWooOol00goo
00IkgV]J8@PU:D8@Li`2Ool00g_NOomoo`0GOol01G_NBU8HaRDYJeX01Woo00=JePaSHaP0<Goo00E[
FRDY36<icW_N00=oo`03Nmioogoo01=oo`039BUBU7oo01=oo`04NmioofLi36<500000dicOomkgP0G
Ool01@00Oomoogoo00003Goo00EkgWooOomoog_N08=oo`00H7oo00<007ooNmh00Woo00=kgWooOol0
5goo00=kgWooOol05Woo00=kgWooOol09Goo00Dmk`aSE[EoogNm01Qoo`03Nmioogoo01=oo`03Nmio
ogoo01aoo`03Nmioogoo00moo`06NmioogooNmioog_N5Woo00ENm`aS249247Nm00Aoo`03Nmioogoo
00Ioo`09NmioogooOomcW3F]48A:DW_N011oo`04NmioogooMkd3Ool00g_NF]H@Q00200000`@QKg]k
gP03Ool017NmOomooc6<0RU:00@8@QBUAS5S60]oo`03Nmioogoo00Eoo`9kgP07OomW>CW>6<H48@aS
F]H00goo00AkgWooOomkgP9oo`03CW<@Q7>L039oo`05Kg/aS0aS<HacW00COol01W_NOomoog_NAS5N
ma9oo`03Nmioogoo009oo`03=Jd0000000800003249oogoo00=oo`03Nmioogoo00moo`04Nmioogoo
0003Ool00`00Oomoo`02Ool00gNmOomoo`07Ool00dicKg]oo`24Ool0061oo`03001kgWoo00=oo`03
Nmioogoo00Uoo`03Nmioogoo009kgPAoo`03NmioogNm029oo`9kgPAoo`03Nmioogoo00Yoo`9kgP9o
o`03Nmioogoo00=oo`07NmicW1S69BUkgWooNmh00Woo00=kgWooOol04Goo00=kgWooOol00Woo00=k
gWooOol00Woo00=kgWooOol00goo0W_N2Goo0W_N7Goo00AkgWooOomkgPMoo`03Nmioogoo00Aoo`03
NmioogNm00Ioo`05NmioogooOomkgP03Ool00g_NOomoo`04Ool01G_NDY@<Ha24JeX01goo0W_N1Goo
00QkgWooNmig_E:D248aS7Nm4Goo00=kgWooOol01Goo00IcW0aSHaQW>@@Q36<2Ool3Nmh01GooNmi6
<AS6Kg/00Woo00M_Ncg_6<H8@S6<CW=[FP03Ool016<HG_Moog_N0Woo00=kgWooOol00Woo0UJe00Hi
cPQ25:E>Lf<HOol200001QcWCW=oogNmOomkgPAoo`03AS4<HgNm00Aoo`03Liaoogoo02Uoo`0:Nmio
ogooKg/icPaS:DY_NgooNmh2Ool00g_NOomoo`04Ool2Nmh2Ool017NmOomoog_N47oo00EkgWooOomo
og_N00=oo`0:MkeoogooKg/48@00248004YBNmh6Ool00g_NOomoo`0:Ool00g_NOomoo`0FOol00bU:
HaQoo`24Ool0061oo`03IcUoogoo00=oo`03Mkeoogoo00Yoo`03Kg]oogoo009oo`03Liaoogoo02Mo
o`03Nmioogoo01Ioo`08Nmioof]J48A247NmOomg_@9oo`03Mkeoogoo01=oo`9kgP=oo`03Mkeoogoo
00=oo`04Mkeoog_NNmh3Ool017_NOomoogoo0W_N7Woo00=g_GooMkd02Woo00=[FU[FF]H00T8@00AB
U5JeHaQg_@=oo`05MkekgWooOomg_@02Ool01G_NOomoogooNmh00goo00Ug_G_NOomoof]J:DXDYCg_
9BT01Goo00=kgWNmOol017oo0W_N0goo00AW>AS65:EcW1Eoo`09NmioogooNmioogNm125BU7oo009g
_@04?NmoogooNmh3Ool00ekg48AW>@04Ool02g_NOomcW4ic<H`HaP0048@Li`@Q36<00T8@00I:DT8@
=JdYBQS648@2000022U:BU9g_GooLiaoog_N7>L2000010@Q001246<H17oo00Eg_Goo@Q0@Q7Nm00Ao
o`03Kg]oogoo02eoo`05Nmi6<@aS9BUS6004Ool00g_NOomoo`07Ool017_NOomoogoo0W_N3goo00=g
_GooOol00Woo00=kgWooNmh00Woo00@e[@00000<H`Aoo`03Nmioogoo00=oo`03MkecW7oo00eoo`03
Nmioog_N00Moo`03Nmioogoo00Moo`035:ENmgoo08Aoo`00H7oo00EkgWooOomoog>L00]oo`03Nmio
ogoo009oo`03Nmioogoo009oo`06MkeoogooNmioog_N87oo00EkgWooOomoog_N01Ioo`05Nmi[FPQ2
F]IkgP0IOol00g_NOomoo`04Ool01W_NIcUJeTic?Nm:DP9Nm`04JeYoog_NLi`;Ool00g_NOomoo`0H
Ool01G_NOomoogooNmh00goo00=g_E[F<H`00Q2400`U:BU:?NlicRe[9BTHaQBU8@Q6<GNmNmh8Ool0
17_NOomoogoo0W_N0goo00LicPaSAS5cW7NmBU9kgP0>Ool017Nm:DX@Q5Je0Woo00=kgWooOol00goo
00=kgWooOol02goo00YkgWooOomkgWooMkdDYD8@OomkgPAoo`09NmioogooNmi_N`Q2F]Ioog_N00Qo
o`04Nmioog>LCW<200003BU:AS4mkcW>AS5JeVLiLiaooacWHaQoog_N009oo`03Nmiood8@00D00003
124e[Goo00Aoo`04MkdmkaS6Li`4Ool00gNmOomoo`0XOol01G_NOomoogooMkd00W_N00M6<ABU6<IN
mgooNmig_@04Ool01g_NOomoogooMkeoog_N00=oo`03JeYg_Goo00Qoo`03Nmioogoo00Aoo`03Mkeo
og>L00Eoo`06Kg/8@P00@Q1oogNm0Woo0W_N0Woo00=g_GooOol03Goo00AkgWooOom_N`=oo`04Liao
ogooNmh;Ool00bDYG_Moo`24Ool0069oo`03Mkeoogoo00aoo`03Kg]oogoo00Moo`03Mkeoogoo02Qo
o`09LiaNmdYBAS4mkd8@BU9Nmg>L00aoo`03Kg/<HeJe009oo`04MkeoogooNmh2Ool00gNmOomoo`0A
Ool037_NOomoof]JDY@U:@@Q6<HU:C6<@Q0e[@8Q208DY@03;F]F]G>L009oo`03MkekgWoo025oo`03
Mkeoogoo009oo`06Mke241BU8@QBU7Nm0goo00=kgWooOol00Woo00MkgUJe=Jd48CF]Kg]kgP06Ool0
17_NOomoogNm0goo00ABU0aS:DYg_@=oo`03Mkeoogoo00Eoo`03Nmioogoo00=oo`05Nmhmk`aS>Lic
W002Ool00g_NOomoo`0@Ool00gNmOomkgP04Ool00bDY<Haoo`03Ool02G_NOomoogooNmioog_N36=:
DP07Ool00fmkOomoo`03Ool01G_N8@P00000;F/01Woo00AkgWNm6<I_N`=oo`04MkeoogooG_L20000
10@Q00048BU:1Goo00QkgWooOol]Jb48Mkeoog_N;goo00=kgWooOol00goo00IF]ABU5:EJeWooNmh<
Ool017NmAS5JeW_N2goo00Ag_GooOomkgPEoo`09F]IS648@BU8HaPQ2DYAW>G>L01=oo`03Nmioog_N
00Qoo`03Nmioogoo00Yoo`05NmiF]FmkOomkgP23Ool0061oo`048@QkgWooNmh<Ool00g_NOomg_@06
Ool017_NOomoogNm9Goo00=kgUkg<H`00Q2400<LicW>>Lh00Sg_00TaS24848@48C6<F]IkgWooNmh0
1Goo00=cW0aSF]H017oo0W_N67oo00McW36<36<e[EJeOomkgP02Ool00g_NOomoo`02Ool01V]JDY@]
JaBU@Q1kgP=oo`03Nmioogoo01aoo`03Nmig_Goo009kgP05Oom240aS?Nmg_@02Ool2Nmh01GooNmio
ogooNmh00Woo00QkgWooOomooeJe36<icV]J0goo00=kgWooOol00goo00UkgV<H8@PDYF<HOomkgWoo
Nmh00goo00=kgWooOol01Woo00Ig_GooHaPDYBU:JeX3Ool017NmOomoog_N1Woo00=kgWooOol03Goo
00<]JbU:Nmh02Woo00<Q23W>Ool017oo00=kgWooOol00goo00AkgWooNmiW>@848@800003HaQoogoo
00Eoo`0348A_Ng_N00Ioo`0724800000000aS7ooNmh027oo00<aS2U:Ool00Woo00=kgWooOol0<goo
00AJeQBU48A>L`Eoo`03Nmioogoo009oo`03Nmioogoo00aoo`04NmioogooNmh2Ool01G_NKg]>LbDY
00000RDY0SW>00Pe[BDY;F/DY@Q25:DmkfLi0Woo0W_N47oo0W_N00Ioog_NOomkgWooMkd3Ool00g_N
Oomoo`07Ool017_NOomoog_NPgoo001POol00e[FOomoo`02Ool00g_NOomoo`0=Ool017_N00048@00
9Woo00MkgWooBU8HaQcWBU9cW009Ool01G_NCW<Q21S6DY@00Woo00IkgWooOomkgRe[>Lh2Ool00gNm
Oomg_@04Ool00g_NOomoo`0AOol01W>L;F/8@TicOomkgPUoo`09NmioogooOomkgS6<48@icWNm00Eo
o`03Nmioogoo01Moo`08NmioogooOomg_Goo48A6<@9oo`03Nmig_G_N00eoo`05Mkeooe:D5:EW>@05
Ool01W_NOomcW3g_249>L`Ioo`03JeYJeW_N00Eoo`08Nmioog_NOomkgRDY249JeP9oo`03Nmioogoo
009oo`03Nmioogoo009oo`9kgPmoo`04Nmi:DQcWNmh4Ool02W_NOomoogooNmioobU:9BUoog_N1Goo
0W_N00Moog_NNmioog_NOolHaP02000010@Q000aS7_N1Woo00<<HgNmOol00W_N17oo00HU:@@Q000e
[ABUIcT2Ool017_NOomoog_N17oo00DYBR48Oomoog_N02Uoo`03Nmioogoo00]oo`05IcTQ20aSAS5g
_@04Ool00g_NOomoo`03Ool00g_NOomoo`09Ool00g_NOomoo`02Ool026mk>Lh@Q3F]E[EkgWooMkd4
Ool027_NOomoofLi?NlLibDYE[D?Ool00g_NOomoo`02Ool01G_NOomoogooNmh00Woo00=kgWooOol0
2Goo00=g_GooOol00Woo00=kgWooOol0Ogoo001QOol00g_NOomoo`03Ool00g_NOomoo`0;Ool01P00
Oomoogoo125kgP9oo`03Nmioogoo01ioo`05MkeS60aS>Li[FP0?Ool016Li9BTLie:D0goo00MF]ABU
Oomoog_NOomkgP0HOol01FLi48ABU7ooNmh04Goo00Ag_D8@9BU[FQmoo`06MkeoogooHaPHaVLi4Goo
00=kgWooOol00Woo00IcW248BU9g_GooNmh2Ool00d8@36<e[@02Nmh6Ool00g>LCW=oo`08Ool00d8@
36<mk`0KOol01g_NOomoogooG_L<Hfmk00Yoo`03BU8Lig_N00aoo`06NmiooeJe124000@Q0`0000=[
FW_NOol017oo00<@Q7>LOol01Goo00QkgU:D001NmgooBU8HaW_N0Woo00AkgWooOomkgP=oo`03MkdU
:Be[035oo`03Nmioogoo00Moo`05Li`]J`Q2=JecW004Ool01W_NOomkgWooJeYg_@]oo`06Mkeoogoo
=Jd<HdYB17oo00AkgWooOomkgPQoo`04G_LU:B48HaP2Ool00g_NOomoo`0=Ool01G_NOomoogooNmh0
17oo00=kgWooOol01Woo00AkgU:DLiakgP9oo`03Nmioogoo07moo`00IGoo00=kgWooOol02Goo00Mk
gWooOomkgP00OomkgP0ROol027_NOomoogoo>LhU:GNmNmhBOol00f]J;F/aS002Ool01BDYE[Eoogoo
Mkd057oo00QkgWooOomg_GooAS4U:F]J5Woo00AS61cWHaQkgP9oo`03Nmioogoo00Qoo`03Nmioogoo
00Aoo`05NmioogooOomkgP02Ool01g_NOomoogooG_LHaWNm01Ioo`0;Nmioog>L=Je6<G_NOomW>ABU
8@Q[FP03Ool01G_NOomoogooNmh01goo00MkgWooOom>LaS6:DY[FP0KOol01g_NOomoogooG_L8@V]J
009oo`03Nmioogoo00Eoo`03F]H8@V]J00moo`035:D0000000@00003<Hag_Goo00Aoo`05001oogoo
OomkgP04Ool027>LIcUg_GooLia6<AcWMkd3Ool01G_NOomkgWooMkd00Woo00@DYCF]OomkgPMoo`03
Nmioogoo02ioo`0;Nmioog>L>Lh<Hbe[Kg]oog_NOomcW002Ool01C6<CW=oogooNmh017oo00=g_Goo
Ool00Woo00A[FRDYAS5kgQ=oo`03F]HQ25:D009oo`04NmioogooNmh3Ool01G_NOomoogooNmh00goo
00=kgWooOol03goo00AkgU:DLiakgP9oo`03Nmioogoo07moo`00H7oo00@Lig_NOomkgPaoo`06Mkeo
ogooOomkgP@Q0P0000<8@P00Ool017oo00=g_GooOol06Woo00=kgR48BU800W_N4Woo00MkgWooNmi:
DR48Li`48@02NmhGOol2Nmh017oo@Q0e[GNm1Goo00=kgWooOol047oo00E_NacWJeYoog_N01Aoo`03
Mkeoogoo009kgP=oo`06JeXHaWooLiaoog_N4Goo00AkgWooOomg_@9oo`06MkdU:EJe;F/@Q5Je2Goo
00=kgWooOol00Woo00]g_GooOomoogNm:DXLieJeOomkgWNm01aoo`05MkecW124F]IkgP06Ool01WNm
Oomoof<H125W>@9oo`9kgPioo`05Nmhe[DYBOomkgP07Ool00`00Oomoo`0<Ool0136<;F]oog_N0Woo
00EkgWooOomkgWoo009kgP036<I247oo00Aoo`03Nmioog_N03=oo`07Nmig_G_N>Lh<Hbe[JeX017oo
00<]JdicOol02Goo00Ag_F<H9BUNmaIoo`03Li`YBSg_00=oo`03Nmioogoo00Qoo`04MkekgWooMkdA
Ool00gNmOomoo`02Ool00g_NOomoo`1oOol0061oo`03001oogoo00Aoo`03Nmioogoo00]oo`05001o
ogooNmh00003Ool00g_NOomoo`0IOol01G_NOomooaBUG_L05Woo00IkgWooOomJeQS69BT3Ool00g>L
Oomoo`0AOol01W_NOomoogooDY@YBP=oo`03Nmioogoo01Eoo`03Li`HaVmk009oo`03Nmioogoo01Ao
o`06NmioogooNmhHaV]J5Goo00=kgWooOol01Goo00<YBU[FNmh00Woo00=cW7ooOol00Woo00=kgWoo
Nmh00Woo00=g_D8@Ool00Woo00MkgT8@000mkgNmOomkgP02Ool00gNmOomoo`0BOol00g_NOomoo`04
Ool00gNm7>M24003Ool017NmOomoog_N0Woo00IkgVmk5:E>LgooNmh3Ool00g_NOomoo`08Ool01W>L
Oomoogoo:DYBU09kgP9oo`03Nmioogoo009oo`03001oogoo00aoo`03NmhU:BU:00Yoo`03Nmh48DYB
009oo`05Nmioog_NOomkgP0aOol01G_NMkeoogooMkd00Woo00A240aS8@QNm`9kgP05;F]BU7_NOomk
gP02Ool00g_NOomoo`02Ool00fLi5:E[FP0DOol01g_NOomoogooNmhicSF]009oo`05NmioogooOomk
gP03Ool00g_NOomoo`03Ool00`Q2Oomoo`0?Ool017_NOomoog_NPgoo001POol00`00Oomoo`0=Ool0
1W_NOomoogNmOol000=oo`03001oog_N01moo`038@QNmgoo01=oo`05MkeoogooNmig_@02Ool00d8@
48Aoo`0GOol017_NOomNmbDY0Woo00=kgWooOol05Woo00MkgWooLi`U:FmkOomkgP08Ool00g_NOomo
o`05Ool00g_NOomoo`02Nmh4Ool00b48F]Ioo`02Ool00g_NOomoo`0FOol017_NOom[FPQ20Woo00=k
gWooOol027oo00QS62e[NmiooeJe124]Jg_N1goo00=kgWooOol047oo00=kgWooOol00goo00AkgWoo
8@PicPEoo`03Nmioogoo009oo`03MkdLicg_019oo`05Nmioog_N<HaBU006Ool017_NOomg_@@Q3Goo
00EkgWooMkdQ23W>009oo`05MkeoogooOomkgP03Ool017_N36=:DW_N?goo00I6<AS67>MF]DHaG_L5
Ool01g_NOomoog_NJeXLig>L009oo`03Nmioog_N019oo`06LiaoogooOole[Cg_0Woo0W_N1Goo00=k
gWooOol00goo00<007ooOol03Woo00EkgUJeKg]oog_N08=oo`00H7oo00D<Hg_NOomoogNm015oo`<0
0004Oomg_GooNmhMOol01BDYG_MoogooNmh067oo00EkgWooCW<aS7Nm01Eoo`07MkeoogNm36=kgWoo
Mkd01goo00=kgWooOol04Woo00=BU36<Li`06Goo00ABU2U:OomkgQMoo`03Nmioogoo00Aoo`03BU8e
[G>L00Uoo`0<Nmiooe:D8@Q_Nb4848AJeWooNmioog_N67oo00=kgWooOol017oo00<icR48Nmh00Woo
00=kgWooOol017oo00Eg_C6<:DYoog_N00=oo`03Nmioogoo00Uoo`03Mkeoogoo009oo`05=Je:DWoo
OomkgP05Ool00g>L249oo`0=Ool01G_NOomg_ABUCW<02Woo00AW>A24F]Ig_@9oo`9kgS5oo`03Mkeo
ogoo00Moo`05NmiJeR4848A:DP09Ool00acWJeYoo`03Ool00g_NOomoo`0@Ool00g_NOomoo`02Nmh0
0goo:DY:DP02Ool00g_NOomoo`07Ool00g_NOol48@0AOol00bDYG_Moo`24Ool0061oo`03F]Ioogoo
011oo`03Nmioogoo00Moo`03Nmioogoo01Uoo`04BU8aS7ooNmhLOol017>L<HaBU7Nm57oo00Ag_Goo
?Nm:DPAoo`9kgQYoo`039BUS67_N00moo`03Kg]cW7oo00Eoo`04NmhLifmkMkd2Ool00g_NOomkgP0I
Ool017NmOolDYG>L1Goo00=g_Cg_Nmh00Woo00EcW6]J124<HdHa00Qoo`03Nmioogoo01Uoo`04@Q0D
YGooNmh4Ool00g_NOomkgP02Ool00cg_7>MkgP03Ool00g_NOomkgP0;Ool01g_NOomoog_NOolaS4ic
00Qoo`03Kg/@Q7oo00moo`04MkecW0aSE[D3Ool01G_NOomoogooNmh00Woo00=S60Q2F]H017oo00=k
gWooOol0=Woo00=kgWooOol00Woo00IS62e[36=6<G_NOol2Nmh01GooNmhU:E:DNmh00goo00=kgWoo
Ool047oo0W_N1Goo00=g_AcWJeX037oo00=kgP00Ool047oo00<DYEkgOol0Q7oo001ROol01GNmOomo
ogooNmh03Woo0W_N17oo00=kgWooOol06Woo00AkgQBUMkeg_A]oo`9kgP03Oom_NaS601Ioo`05HaPH
aWooOomg_@06Ool2NmhFOol00fmk5:EkgP0?Ool015Je249247>L0Woo00EkgWooBU8aS7_N009oo`03
Nmioogoo01=oo`03Nmioogoo009oo`08NmioogooOom>LbU:OomkgP9oo`04Li`mk`00F]H2Ool01UJe
000U:GNmOomg_@Aoo`03Nmig_Goo009oo`03Nmioogoo015oo`03Nmioog_N009oo`03E[DDYF]J009o
o`03Mkeoogoo00Eoo`03DY@<HgNm009oo`06MkeoogooNmioog_N2Goo00QkgWooOomoog_NOol]JeJe
0goo0W_N0goo00=[FQ24Ool04Goo00=W>@Q2G_L00goo0W_N0Woo0W_N00Aoofmk249JeSEoo`03Nmio
ogoo00Uoo`0;Kg]cW6]J<H`8@T8@Nmig_GooIcTQ2007Ool00g_NOomoo`0?Ool00g_NOomkgP02Ool0
17_NOom243F]3Goo00<8@WooOol03goo00<YBV<HOol0Q7oo001POol00g_NOomoo`0BOol00g_NOomo
o`02Ool00g_NOomoo`0KOol01CW>AS5oogooNmh057oo00AkgWooOomkgPIoo`03@Q0icWoo01Aoo`03
<Ha>Lgoo00Ioo`03Nmioogoo01Qoo`03<Ha>Lgoo00ioo`06BU800000248mkg>L0Woo00DYBUJeOomo
og_N01Qoo`03Nmioogoo00=oo`9kgP0636=g_GooMkeoofmk0P0000DHaV<H7>LHaVLi00Moo`05Nmio
ogooOomkgP0IOol01F<H36=W>GooNmh027oo00AS60@QKg]kgQAoo`05Mkeoog_N8@QJeP08Ool00f]J
5:Eoo`0?Ool01W_NOomooe[F48AW>@Uoo`04MkeNm`Q2IcTcOol00g_NOomoo`09Ool037_NAS5JeWoo
NmicW3F]001g_Goo36=W>@Ioo`03Mkeoogoo015oo`03Nmioog_N00Aoo`0336=_Ngoo00Eoo`03Nmio
ogoo00=oo`03001oogoo00moo`03CW=_Ngoo08Aoo`00H7oo00<Q27ooOol00Woo00=kgWooOol02Goo
00IkgWooOomkgWooNmh2Ool01G_NOomoogooNmh06Goo00=g_@Q2Nmh02goo00=kgWooOol00goo00=k
gWooNmh00goo00=kgWooOol00goo00MkgWooOomoog_N125kgP03Ool00g_NOomoo`09Ool01W_NOomo
ogooNmh48A9oo`03Nmioogoo00ioo`04JeXDYGooMkd4Ool00g_NOomoo`05Ool02W_NDY@000001240
00@Q?Nm_N`aS2Woo00AkgWooOomkgPIoo`03Mkeoog>L00aoo`03NmhLif<H00=oo`0:36<000@Q0004
8DicOomkgWooNmhOOol01W_NOomoofmk48AJeP9oo`04NmioogooNmh3Ool2Nmh00`aSE[Eoo`0COol0
0g_NOomoo`02Ool00b48HaQoo`07Ool016<H7>Moog_N47oo00EkgWooG_L<Hfmk00Uoo`06NmiNm`@Q
JeYoog_N0Woo00=kgWooOol0=7oo00=g_GooOol01goo00AkgWooG_LU:@ioo`03Nmioogoo015oo`05
F]HU:G_NOomkgP03Ool017_NOomoog_N0Woo00<007ooOol03Woo00EkgWooOomoog_N08=oo`00H7oo
00AJeWooOomkgQ5oo`03Liaoogoo00=oo`03Liaoogoo01Uoo`03E[DYBWoo00eoo`03MkekgWoo00Yo
o`03Nmioogoo00Eoo`049BUBU7ooNmh2Ool00g_NOomoo`04Ool2Nmh4Ool017_NOomF]BU:3Woo00Ak
gWooOomkgPEoo`03Nmioogoo00Uoo`06Li`Lifmk248000Q2100000<48@0000000`0000<8@P001240
0`0000@48@0036<U:@]oo`9kgPAoo`03NmioogNm00Aoo`03Nmioogoo00Uoo`06DY@YBWNmOolmk`@Q
0P000P@Q00AcW7ooMke>Lb5oo`9kgP036<I6<Goo00Ioo`08LiaoogooOol<HdHaOomkgQ=oo`03Nmio
ogoo009oo`038@QNmgoo00Moo`03G_LQ27oo01=oo`04Mke>LaS6Mkd4Ool017_NOomoog_N0Woo00=>
La24Li`00Woo00=g_GooOol00Woo00=g_GooOol0<Woo00EkgWooOomoog_N00Eoo`039BUF]Goo00mo
o`03Mkeoogoo00moo`03Nmh@Q7_N00Moo`04Mkeoog_NNmhBOol00g>LOomoo`24Ool006=oo`03Nmio
ogoo011oo`03Nmioogoo00Eoo`03Nmioogoo01Ioo`03:DYF]Goo009oo`03Nmioogoo00Eoo`03Mkeo
ogoo009oo`9kgP08OomkgWooNmioog_NOomkgPUoo`05E[DYBWooOomkgP02Ool00gNmOomF]@0;Ool0
0bDYE[Eoo`0<Ool00gNmOomkgP03Ool017NmOomoogNm1Goo00EkgWooOomoog_N009oo`03NmhYBTic
00Eoo`03Nmioogoo00Eoo`05NmiF]@0000048@0200000be[>LhicP0>Ool00gNmOomoo`03Ool017_N
Mkeoog_N0Woo00=kgWooOol01Woo00Eg_F]J6<Ioof]J00H00004;F]kgWNmAS4QOol00g_N9BTaS005
Ool027_NOomoogooNmioobDY=Jd3Ool2NmhFOol00b48G_Moo`07Ool00e[F8@Qoo`0EOol00cg_48Ao
o`05Ool00g_NOomoo`02Ool00dic48AW>@04Ool2Nmh00gooNmioo`0dOol00fLiLiaoo`04Ool00gNm
249oo`0=Ool00gNmOomoo`0COol01RDYE[Eoog_NOomkgPMoo`03001oogoo00moo`03DYAcW7_N08Ao
o`00H7oo00=cW7ooOol03Goo00=kgWooOol00Woo00Ag_GooOomkgP9oo`05NmioogooOomkgP0FOol0
0gNm36=g_@03Ool00g_NOomoo`02Ool00g_NOomoo`02Ool2NmhEOol00`Q2Mkeoo`03Ool00e:D2488
@P0;Ool00`aSLiakgP0>Ool017_NOomoogNm1Woo00=g_GooOol027oo00DmkcW>Oomoog_N00]oo`09
BU800000124YBWNmOolYBUJe00eoo`03Nmioogoo00=oo`03Nmioogoo009oo`03Nmioogoo00=oo`03
Nmioogoo009oo`07Nmi_NaBUNmhLi`@Q36<01@0000=NmgooNmh07goo00AkgWoo=JdLi`9oo`03Nmio
ogoo00Aoo`07Liaooc6<8@QkgWooNmh06Goo00<Q25kgOol01goo00=F]BU:Ool05Woo00<aS2U:Ool0
0goo00AkgWooOomg_@=oo`03>LhQ27Nm009oo`04LiaoogooMkdcOol01G_NOomoocF]DY@01Goo00=F
]B48Ool02Woo00=kgWooOol00Woo0W_N4Woo00AJeRDYOomg_@Moo`03Nmioog_N011oo`04NmiF]G>L
Mkf4Ool0061oo`03:DYoogoo01]oo`03Nmioogoo01Eoo`03Kg/<Hgoo00moo`05MkeoogooOomcW002
Ool00g_NOomkgP02Ool01GNmOomoogooNmh00Woo00Ag_Goo36=cW09oo`06AS4<H`00124HaW_N27oo
00=kgWoo24800W_N3Goo00=kgWooMkd00goo00=kgWooMkd03Goo00=BU2e[Mkd00goo00=kgWooNmh0
0Woo0W_N00Qg_GooOomF]@Q2=Je[FW_N0Woo00<Q25[FOol02Goo00QkgWooOomoogNm001oog_N0Woo
100037oo00YkgP@QKg/icTicF]INmfmkOomg_BAoo`04AS4HaWooMkd9Ool0148@6<IcW7_N0Woo00=k
gWooOol05Woo00<LiekgOol01goo00=BU2e[Ool05Goo00AkgWoo7>LaS0Eoo`08NmioogooOomg_Goo
>LhHaP9kgP=oo`03Nmioogoo03Aoo`03:DY>Lgoo00Aoo`03?Nm247oo02=oo`03Li`@Q7oo00Ioo`03
Nmioogoo01=oo`03Nmioogoo08Aoo`00H7oo00<007ooOol03Woo0W_N00=oog_NNmh01Goo00Eg_Goo
Oomoog_N01Ioo`04HaPLigooNmh9Ool01G_NOomkgWooLi`00Woo0W_N1Goo00=kgWooOol01goo00Qk
gWoo;F]JeU:D48@8@PaS0P0000<<HgooOol01Goo00EkgWooOomg_@Q200Aoo`03Nmioogoo00Qoo`03
001cW7oo00Aoo`04Nmh8@WooMkd2Ool00g_NOomoo`04Ool01g_NOomNmb48OomkgW>L00Yoo`04NmiW
>F]JMkd3Ool00g_N7>MS6008Ool01G_NOomoogooNmh00Woo00D007NmOomoo`0000=oo`03Nmh006mk
00Eoo`03Nmioogoo00=oo`03001kgWoo00=oo`07NmioogooOomkgW>LCW<07goo00IF]@Q2MkekgWoo
Nmh5Ool01GNmOom[FPaSJeX00goo00AkgWooNmikgQIoo`037>MS67oo00Moo`03CW<aS7oo00eoo`03
Nmioogoo00Moo`04NmhLid8@Nmh5Ool01g_NOomoog_NOol]JbDY00=oo`03Nmioogoo03Eoo`03:DYB
U7oo00Aoo`03=Je:DW_N00aoo`05Nmioog_NOomcW00BOol00gNm125oo`02Ool017_NOomoog_N0Woo
00=kgWooMkd057oo00=kgWooOol0PGoo001POol00`00Oomoo`0=Ool02W_NOomoogooNmh8@WooNmio
o`000goo00=kgWooOol05Woo00=BU2e[Ool027oo00=kgWooOol00Woo00Ig_@Q2OomkgWooNmh40000
0g_NOomoo`02Ool017NmOomoog_N17oo00<U:AcW00000`0000@8@P@Q0008@PL0000436<LigNm248?
Ool02@00OomoogooNmioog_NOol0000=Ool00ekg7>Moo`04Ool00g_NOomoo`04Ool00g_NOomoo`03
Ool01G_NOomoobU:G_L02Woo00=kgWooOol00Woo00<007ooOol00Woo00EkgWooOomoo`@Q009oo`9k
gP=oo`09NmioogooNmioo`00Nmioog_N00Eoo`04Kg]oof<H7>LMOol017_NJeX<HfLi0W_N1Goo00Ig
_GooNmicW0Q2F]H3Ool017_NOomoog_N5goo00<HaVLiOol01goo00=:DSF]Ool05Woo00EkgWooOol<
He:D00]oo`03;F/HaWoo03Eoo`06NmioogooOom245[F1Goo00<YBU:DOol02Woo00=kgWooOol00Woo
00=g_@Q2Ool04Woo00L48GooOomoog_NOomg_@02Ool00gNmOomoo`0BOol00dicKg]oo`24Ool0061o
o`03125kgWoo00moo`04Nmioog_N0002Ool01@00OomoogooNmh05goo00AkgWooBU8aS0Uoo`04Nmio
ogooNmh2Ool01@00Oomoogoo000017oo00<48G_NOol00Woo00=kgWooNmh00Woo00UkgWooOole[Dic
G_LQ200024800P0000<@Q7ooOol027oo00EkgP@QOomoog_N00aoo`05001oogooNmh48@0500000g_N
Oomoo`05Ool01W_NOomoogooF]HU:@Yoo`03Nmioogoo00Qoo`03<Ha>Lgoo00Yoo`05NmioogooOol0
0008Ool00`00OomkgP02Ool00g_NOomoo`04Ool00g>L249oo`04Ool01g_NOomkgWooNmiNmacW01ao
o`04Nmig_A24DY@:Ool00g_N5:E6<@05Ool017NmOomoog_N5Goo00=kgQS6JeX027oo00=6<CF]Ool0
5goo00Eg_GooKg/@Q5kg00=oo`03Nmioog_N00Eoo`049BTaS7ooNmheOol00g_NOomkgP03Ool01G_N
OomooaS6IcT02goo00AkgWooOomkgP9oo`03001oogoo00moo`06Nmioo`aSKg]oog_N0goo00=kgWoo
Ool057oo00<Q25[FOol0Q7oo001POol00ekgOomkgP0AOol01GNm125oogoo124077oo00EkgU[F;F]o
og_N009oo`03Nmioogoo009oo`03Nmioogoo00=oo`04001oogooMkd2Ool017_NOomoo`@Q0goo00=k
gWooOol017oo00AkgWoo;F]BU09oo`05G_LQ2000000<H`0;Ool00a24Kg]oo`07Ool00gNmOomoo`03
Ool00`00Oomoo`02Ool01000Oomoo`@Q2goo00IkgWooDY@]JgooNmhCOol013g_@Q1oog_N0Woo00=k
gWooOol01Goo00AkgWooOol0009oo`07NmioogooOomg_Goo00000Woo00=kgWooOol00goo00Ig_Goo
OomNmbDYNmh9Ool00ekg8@Qoo`0FOol00g_NOomoo`02Ool01G_N5:DmkgooMkd00Woo00=kgWooOol0
0goo00=kgR48=Jd077oo00IkgWooOomooa24Li`8Ool00cg_@Q1oo`0JOol016Li249S67_N1Goo00Mk
gWooOomoog_N8@Pe[@06Ool00gNmOomoo`0`Ool00g_NOomoo`03Ool00c6<CW=oo`09Ool00g_NOomk
gP02Ool01g_NOol007ooNmioog_N009oo`03Nmioogoo00Yoo`04001oogooNmh3Ool01G_NOomoogoo
Nmh017oo00=kgWooNmh02goo00DLif<HOomoog_N089oo`00H7oo00=kgWooOol00goo00=kgWooOol0
2Woo00UkgWoo000000@QNmioogNmNmh06Woo00EW>AcWOomoogNm009oo`03Nmioogoo00Aoo`05Nmio
ogoo001kgP02Ool00g_NOomoo`02Ool01000OomkgW_N0Woo00AkgWooOomg_@=oo`036<IW>G_N00=o
o`03HaPQ212400]oo`0336=cW7_N00Eoo`09NmioogooOomkgWooNmioo`Q200Aoo`04001oogoo0002
Ool00gNmOomoo`03Ool00g_NOomoo`02Ool00d8@?Nmg_@02Ool015[FIcUoog_N2Goo00YkgWooOomk
gWooE[DYBW_NOomg_@9oo`07NmioogooOomkgWooNmh00goo00T48GooNmioog_NOol000Q200000Woo
00=g_GooNmh01goo00=6<CW>Ool02Goo00=_NdicOol00goo00=kgWooOol03goo00=kgWooMkd00Woo
00EkgRDY?Nmoog>L00Eoo`06Nmioog_NOolicRDY8Goo00<@Q6mkOol01goo00<mkd8@Ool06Goo00Ek
gWooE[D<Hfmk00Yoo`03NmhDYCg_00=oo`03Mkeoogoo009oo`03Nmioogoo02aoo`03Kg]cW7oo00Ao
o`03>Li6<Goo015oo`05001oogooOomkgP0=Ool00g>L249oo`07Ool01WNmNmioogNmOomkgP9oo`04
NmioogooNmh9Ool00b48HaQoo`24Ool006=oo`04NmioogooNmh9Ool00g_NOomoo`02Ool00`00Ool0
000NOol00g>L36=oo`04Ool00g_NOomoo`02Nmh00gooNmioo`02Ool01`00Oomoogoo249oog_N009o
o`03249oogoo00Aoo`03Nmioogoo00=oo`03249cW7oo00Aoo`04Mke[FWooNmh9Ool00cF]CW=oo`02
Ool01g_NOomoogooNmioog_N00=oo`03Nmh48G>L009oo`09Mkeoo`00Ool48GooNmioog_N00Eoo`0;
MkeoogooMkdU:EJeOomNmaBU001>L`0;Ool00g_NOomoo`02Ool017>L249kgW_N17oo00=kgWooNmh0
0goo00AkgWooOol0009oo`08MkeoogooOomg_Goo125kgPAoo`03Mkeoogoo00=oo`037>MNmgoo02Ao
o`05NmioocF]9BUg_@03Ool00g_NOomkgP04Ool0148@48Aoog_N87oo00<@Q6mkOol01goo00<icTHa
Ool077oo00=F]AS6HaP00goo00IkgWooOomoog_NOol2Nmh011cW>Lioog_N17oo00=g_GooOol0:Goo
00Ig_GooOomg_DYBE[D5Ool00dYB=Jeoo`0AOol00`00Oomoo`02Ool00g_NOomoo`0:Ool00fLi6<Io
o`04Ool00g_NOomoo`03Ool01`Q2000000@Q001oog_N00]oo`03DYA_Ngoo08Aoo`00H7oo00<Q27_N
Ool00Woo0W_N3Woo00X8@W_NOol48GooNmioog_NOomcW1Moo`03Nmh<HgNm00=oo`03Nmioogoo00Eo
o`07Nmioogoo001oog_NOol00P0000H8@P@Q001g_GooNmh2Ool00gNmOomoo`04Ool01GNm36=kgWoo
Nmh047oo00ENmb48OomoogNm009oo`03NmioogNm009oo`05MkekgWooOol00002Ool027>LOomoo`00
Ool007ooNmh2Ool00g_NOomoo`04Ool01GNmOol@Q4ic6<H00P0000<48E:DOol03Goo0WNm00AoobU:
G_Mg_@9oo`03Nmioogoo00Eoo`06Nmh007oo125oog_N0Woo00MkgWooOomkgP00OomkgP08Ool00gNm
48Aoo`0VOol01DYB6<IcW7ooNmh01Woo00Eg_GooF]H<Hg>L021oo`04Nmiooa24Kg/8Ool00cF]BU9o
o`0HOol027NmOomoog_NOom241cWMkd2Ool00gNmOomoo`03Ool01G_NOomg_A24AS400goo00Ag_Goo
OomkgRaoo`05NmioogooOomkgP04Ool00fLi7>Moo`09Ool01GNmOomoogooNmh00Woo00=kgWoo0000
17oo00=kgWooOol027oo00=kgU:D=Jd00Woo00AkgWooOomkgPEoo`08001oogooNmioog_NOomkgY5o
o`00H7oo00=NmgooOol04Woo00D007ooOomkgP@Q00Eoo`03Mkeoogoo01Eoo`04;F]F]GooNmh6Ool0
0gNmOomkgP02Ool00gNm001oo`02Ool01000OomoogNm17oo00=kgWooOol01Goo00Mg_EJe;F]oog_N
OomkgP02Ool00g_NOomoo`0:Ool00gNm36=kgP03Ool2Nmh3Ool01WNmOomg_@@QOol000Ioo`050004
8GooOomkgP04Ool027NmOomoog_NOolicP00248400000cW>F]IS600:HaP02E[FG_MW>FLiOomBU2DY
OomkgP0;Ool20003Ool01P00Oomoog_NOol0009oo`03Nmioogoo00Eoo`03?Nle[Goo00Yoo`03IcUJ
eW_N00Aoo`03Nmioogoo00ioo`07NmioogooF]H@Q6mkNmh00Woo00=kgWooOol017oo00=S60Q2Kg/0
0goo00=kgWooOol07Goo00<<HfmkOol01goo00<aS4icOol05Woo00=kgWooNmh00Woo00EkgWooOolm
kb4800=oo`03Mkeoogoo00Aoo`04Nmi[FQS6BU86Ool00g_NOomoo`0[Ool00g>LNmioo`04Ool00g_N
48A_N`0<Ool017_NOomoogNm0Woo00@<Hg_NOomoo`9kgP]oo`058@QJeWooOomkgP06Ool00g_NOol4
8@03Ool017_NOomoog_NTGoo001QOol017NmOomoog_N3Goo00A_NgooOol000=oo`03Liaoogoo01Uo
o`04Nmiooe[F6<H7Ool00g_NOomoo`02Ool01000Ool48G_N0goo00D48GooOomoog_N00=oo`03Nmio
ogoo00Eoo`037>MNmgoo01=oo`05<Ha6<GooOomkgP03Ool00g_NOomoo`02Ool017_N0008@W_N1Goo
0P000goo00=kgWooOol00Woo00EkgWooOomcW0@Q0080000712400000000LiaS68@P021cW00XQ22DY
8@PHaRDY;F]cW7oo7>MS60Moo`07LiaoogooNmig_Goo00000Woo00MkgWoo000000@Q001oo`02Nmh7
Ool00g_N48AcW00;Ool00fmkF]Ioo`0FOol017NmHaP<Hekg0Woo0W_N0Woo00]kgWooOomoofmk6<IF
]GooNmioogNm021oo`03249g_Goo00Moo`03:DYBU7oo01Yoo`07NmioogooOomkgRe[8@P01Goo00=k
gWooOol00goo00M[FQ24F]Ioog_NOomg_@0ZOol00g_NOomkgP02Ool00gNmNmioo`05Ool00bU:DYAo
o`0@Ool00gNmOol48@04Ool00g_NOomoo`08Ool00`@QNmioo`09Ool017_N001oog_N0goo00=kgWoo
Ool02Goo00I>Lg>LOomg_GooNmj1Ool006Aoo`03Nmioogoo00aoo`03Nmioo`00009oo`03Nmioogoo
009oo`03Nmioogoo01Moo`05Nmh@Q7>LOomkgP0:Ool20002Ool017_NOol007Nm17oo00Ag_GooOomk
gP9oo`07NmioogooMkd@Q7ooNmh017oo00Ag_GooOomkgP]oo`05Mkd@Q7ooMkekgP09Ool00g_N001o
o`03Ool01gNmOomoo`00Nmioog_N00Aoo`0=NmioogooOomJeRDYDY@DY@@Q0008@P00BU803goo00Ek
gWooOomF]BU:009oo`07MkeoogooOomkgWooNmh017oo00=g_GooOol02Goo00=cW7ooOol017oo00A6
<CF]OomkgP]oo`04LiaoogooNmhDOol00g>L36=BU005Ool00g_NOomoo`02Ool017>L8@PmkgNm0Woo
00=kgWooNmh07goo00<007_NOol01goo00<YBUJeOol05Goo00AkgWooOomkgP=oo`07LiaoogooOolU
:C6<Nmh01Woo00UkgWooOomoof<H249F]GooNmh0;goo00=kgS6<BU801Woo00=JeRe[Mkd027oo00=k
gWooOol017oo00Qg_GooMkd007ooNmioog_N2Woo00=BU2U:Ool02goo00<8@WooNmh00Woo00=kgWoo
Ool02Woo00A>Lg>LOomkgX=oo`00H7oo00<LigooOol03goo00AkgWooOomkgPAoo`06MkeoogooNmio
og_N47oo00=kgWooOol01Goo00=243g_Ool027oo00MkgWooOomoo`00OomkgP02Ool500000g_NOomk
gP07Ool00cF]AS5oo`09Ool00g_NOomoo`09Ool01CW>?NmoogooNmh03goo0W_N00=oog_NOol00goo
00=kgWooOol00goo00HHaV<HOomooeJe5:D200000e:DOomoo`09Ool00g_NOomoo`05Ool00acWG_Mk
gP02Ool00g_NOomoo`02Ool017_NOomoog_N1Goo00=kgWooOol01Woo00IcW7ooOomoogNm36<AOol0
0g_NOomkgP0BOol00aBUAS5oo`02Ool00g_NOomoo`05Ool00be[:DYoo`03Ool00g_NOomoo`0OOol0
0`00Oomoo`07Ool00bDYF]Ioo`0FOol01GNmOomoogooNmh00Woo00IkgWooOomkgR48?Nl;Ool00fmk
249W>@0_Ool017_NOol]Jdic17oo00EkgWooOol@Q6mk00]oo`04Mkeoog_N1245000<Ool00g_N7>MW
>@06Ool00g_NOomoo`03Ool00`00Oomoo`0COol00g_NOomoo`20Ool0061oo`05001oogooOomkgP02
Ool00g_NOomoo`0^Ool00g_N7>MW>@02Ool00g_NOomoo`04Ool00g_NOomoo`0?Ool02G_NOomoogoo
Kg/HaWNmOomg_@0DOol01G_N48AcW7ooNmh01Goo00=kgWooOol047oo00QkgWooNmiooeJe;F]oog_N
0goo00=>Lb48BU8057oo00<LifLiOol05Woo00=kgWooOol00Woo00=g_AS6JeX03Goo00=[FTicOol0
3Goo00=kgWooOol01Goo00<LicW>Nmh00goo00=kgWooOol017oo00=241BUOol09Woo00<007ooOol0
1goo00<Lif<HOol08Goo00=g_ABUCW<02goo00=Nm`Q2HaP017oo00=kgWooOol00Woo00=kgWooOol0
8Goo00EkgWooOol]Jdic00Moo`03JeX@Q7oo01Qoo`04NmioogooMkd3Ool00dYB=JekgP03Ool01G_N
OomoogooNmh00Woo00=kgWoo0000V7oo001POol01000OomkgW_N0Woo00=kgWooOol027oo00Ag_Goo
OomkgPIoo`04NmioogooMkdJOol00e[F8@Qoo`02Ool2NmhEOol02GNmOomoogooMkdU:E[FOomkgP0D
Ool01G_NOomW>B48Mkd017oo00Ag_GooOomkgPUoo`05NmioogooOomkgP04Ool01G_NOomNmb48Nmh0
1Woo0W_N57oo00IcW1cWMkeg_GooNmh>Ool3Nmh00gooNmioo`03Ool01G_N<HaNmgooMkd037oo00=S
62e[Ool03goo0W_N0Woo00AkgS6<:DYcW0=oo`03Nmioogoo00Aoo`04E[D@Q7>LNmhVOol00`00Oomo
o`07Ool00acWHaQoo`0QOol2Nmh01PQ2E[EoogooNmig_@Eoo`07Nmiooekg48A_NgooNmh017oo0W_N
00=oogNmOol08goo00=kgT8@E[D00goo00MkgWooOomoog_N@Q1:DP02Ool00g_NOomoo`0DOol027Nm
OomoogNmOomcW0aSNmh3Ool00g_NOomkgP03Ool2Nmh2Ool00`@QOomoo`0>Ool00g_NDYA_N`25Ool0
061oo`03001g_Goo00=oo`03Nmioogoo02moo`04Nmiood8@=Jd4Ool017_NOomoog_N37oo00Mg_Goo
Oomoog_NOomkgP02Ool013W>@Q1oog_N0Woo00=kgWooOol04Goo00MkgWooG_LQ27NmOomkgP0?Ool0
0g_NMkeoo`06Ool00g_N7>M[FP0NOol00fLi6<I_N`04Ool00g_NOomoo`07Ool00g_NOomoo`02Ool0
17_NOomoog_N0Woo00<YBT8@Ool03Woo00=NmaBUOol03Woo00QkgWooOomkgWooCW<HaW>L0Woo00Ak
gWooOomoo`9kgP9oo`04G_L<HfLiNmhWOol00`00Oomoo`07Ool00aS6IcUoo`0QOol01GNmOomg_A24
G_L01Goo00=kgWooNmh00Woo00IkgTic6<IW>GooNmh3Ool00g_NOomoo`0ROol3Nmh3Ool017_NOomo
og_N17oo00=cW248G_L00Woo00=kgWooNmh05Goo00Mg_GooOolLif<HOomg_@05Ool00g_NOomoo`03
Ool00fmk001oo`0@Ool00bDYG_Moo`24Ool0061oo`03IcUoogoo009kgP9oo`03Nmioogoo00Ioo`03
Nmioogoo00=oo`04MkekgW_NMkd5Ool00g_NOomoo`0FOol01G_NOomkgS6<DY@00Woo00=kgWooOol0
4Goo00QkgWooOomkgWooAS4icWNm5Goo00=kgWooNmh00Woo00=kgUJe=Jd00Woo00AkgWooOomg_A=o
o`08G_LLif]JNmioog_NOomg_@9oo`03Nmioogoo01Aoo`06Mkeoof]J7>MF]G_N3goo00=g_GooOol0
0goo00AS61S6DYAoo`9kgP03Oomg_Goo00Yoo`03HaPQ27oo00=oo`03Nmioogoo00Qoo`09Nmioogoo
OomF]@aSJeYoog_N009oo`03Nmioogoo00=oo`03Li`@Q5Je009oo`03Nmioogoo02Aoo`03001oogoo
00Moo`035:E[FWoo021oo`08MkeoogooNmiJeQ24Kg]kgPUoo`04NmiBU0Q2Mkd3Ool00g>LOomoo`0R
Ool017_NOomoog_N0goo00=kgWooOol00goo00IkgWooOomg_AS6JeX3Ool00g_NOomoo`0BOol01g_N
OomkgRU:E[EoogNm009oo`03Mkeoogoo01Yoo`036<IJeWoo08Aoo`00HGoo0W_N0Woo00=g_GooOol0
2Goo00AkgWooOomg_@Ioo`04MkeoogooNmhJOol01GNmOomkgRDYAS4027oo00=kgWooOol037oo00Eg
_GooBU8aS7Nm01eoo`03DY@DYF]J00ioo`04MkeoogooNmh4Ool01UJe8@Q[FW_NOomkgQaoo`08Nmio
ogooKg/YBTHaKg]kgP9oo`9kgPIoo`03Nmioogoo00Aoo`04Mke>Lb48Kg/7Ool00g_NOomoo`07Ool0
1FmkCW=oogooNmh03Goo00Eg_GooIcT8@U[F00Ioo`07Nmioog_NOomg_AS6BU80:Goo00=kgP@QOol0
27oo00<<HfmkOol09Goo00=:DQBULi`01goo00MkgWooOomkgT8@7>Mg_@03Ool00gNmOomoo`0SOol0
1G_NOomoofLiLi`02Woo00MkgQS6IcUkgWNmOomkgP0DOol01G_N;F]>LgooNmh027oo00=kgWooOol0
0goo00=kgWooOol03goo00<YBV<HNmh0Q7oo001POol017_NOomoog_N3Woo00EkgWooOomoo`000084
8@05001oogooOomkgP0LOol01G_NOomkgSF]<H`00W_N0Woo0W_N4Goo00<YBSF]Li`00goo00AkgWoo
NmikgQ9oo`0:NmioogooOomkgWooLi`U:CF]Mkd2Ool2Nmh9Ool01W_NOomoogNmOom_N`8YBP05Nmio
ogooOomkgP03Ool2Nmh00gooNmioo`0EOol027NmOomoogoo>LhHaT8@Kg/>Ool01GNm?NlHaS6<Nmh0
0Woo00=g_GooOol03Woo00AkgWooOomkgPaoo`05Mkeoof]J249JeP08Ool01gNmOomkgRU:<Haoog_N
02Qoo`03Mkd8@Woo00Qoo`03249g_Goo021oo`03Liaoogoo00=oo`03@Q0HaW_N009oo`03Nmioogoo
00Ioo`04=JdDYGooMkdUOol027_NOomoogooNmi6<E[FNmh9Ool01G_NIcTQ24icOol00W_N4goo00=_
NaBUCW<01Goo00=kgWooNmh01goo00=kgWooOol04Goo00=BU7>LNmh0Q7oo001POol00bDYLiaoo`0=
Ool01g_NOomoog_NOol007oo009g_@04Ool007ooNmh2Ool00g_NOomoo`0FOol00g_NOomoo`03Ool0
14YB6<IS67>L1Goo00=g_GooOol01goo00IkgWooOomBU124F]H2Ool2Nmh4Ool00g_NOomoo`0?Ool0
17NmOomoog_N0goo00EkgWNmAS4@Q3g_00=oo`03Nmioogoo00Eoo`08MkeoogooOomg_Be[48ABU0=o
o`06MkeoogooNmioogNm1Woo00=kgWooOol047oo00=kgWooOol00goo00Ig_D8@5:DLidYBLi`8Ool0
1VLiE[DYBPaS@Q1_N`9kgPAoo`03Nmioogoo00aoo`03Nmioogoo00ioo`03NmhHaT8@009oo`03Nmio
ogNm00Aoo`05Mkeoocg_8@QkgP02Ool00gNmOomkgP0UOol00gNm36=oo`08Ool00`@QMkeoo`0NOol0
0g_NMkeoo`02Ool01W_NOomkgWoo@Q0HaPMoo`03NmioogNm009oo`05=JdHaWooOomkgP0fOol01W_N
=JdU:GNmOomkgQ1oo`04Mke6<AcWJeX2Ool00g_NMkekgP0=Ool00g_NOomoo`0?Ool00gNmOomoo`24
Ool0061oo`03G_Moogoo00Aoo`03Nmioogoo00]oo`06001kgWooOomkgP0097oo00A[FR489BU>L`9o
o`03Nmioogoo00Yoo`04E[DHaR48Kg/2Ool00g_NOomoo`03Ool00gNmOomoo`0JOol01g_N?Nl8@RDY
CW=g_G_N00Moo`05IcU241BU36=:DP07Ool00g_NOomoo`03Ool00g_NOomoo`0EOol00g_NOomoo`04
Ool01GNmHaPe[@aS24800QcW00PaS3F]9BTHaPaS5:DYBUJe0W_N0goo00=kgWooOol01Goo00=kgWoo
Ool01goo00A[FUkgNmikgPioo`037>Le[Goo00Moo`06NmioogooBU8<HgNm17oo00=g_GooOol097oo
00=cW0aSOol027oo00<48G_NOol097oo00IkgWooOomoocF]9BT2Ool00g_NOomoo`04Ool01G_NOomk
gSF]8@P00Woo00=kgWooOol08Goo00Ag_GooOomg_@eoo`08NmioogooDY@@Q36<MkekgPioo`03@Q0D
YC6<00=oo`05NmioogooOomg_@03Ool00g_NOomoo`0LOol00g_NOomoo`20Ool007=oo`03Nmioog_N
00Aoo`03001oogoo02Aoo`06F]HYBQBU;F]F]GNm17oo00UkgWooOomg_E[F;F/DYBDYHaP00Woo00=g
_GooOol097oo00=kgU[F=Jd00PQ200X@Q1cW8@PQ21S648@001BU>LiW>C9oo`08LiaW>E[FDYA>LeJe
IcUcW1Yoo`03IcUJeW_N00Moo`03Nmioogoo009oo`05Nmiood8@6<Ig_@05Ool00gNmOomkgP02Ool0
15Je48AcW7_N:goo00=cW0aSOol00Woo00=kgWooOol00goo00<007ooOol09Woo00EkgWooOolLicF]
00=oo`04NmioogooNmh5Ool00bDY;F]oo`09Ool00g_NOomoo`0LOol00fmkOomkgP0<Ool017_NOomk
gUJe0Q2400<icVLiOol01goo00QcW4ic:DX48C6<Nmioog_N2goo00=kgWooOol037oo00=kgWooOol0
27oo00=>Lg>LNmh0Q7oo001ROol00g_NOomoo`0AOol40005Ool00g>LOomoo`0QOol03g>LCW<U:@aS
000Q21S67>LYBQS600048BDYCW=_N`02Ool00g_NOomoo`0XOol02G_NOomkgV]JHaQNmf<HIcU[FP0g
Ool00g_NOomoo`02NmhQOol00g_NOomoo`02Ool017_NOomoogNm0Woo00=6<@Q2Ool00Woo00Ag_Goo
OomkgP=oo`05Nmi[FQBUG_MkgP0/Ool00g>L36=oo`08Ool00`00Oomoo`0XOol01W_NOolDYCg_Oomk
gP9oo`03Mkeoogoo00Eoo`03:DXU:Goo009oo`03Mkeoogoo00Aoo`03Nmioogoo01Moo`08Nmioogoo
OolYBTHaOomkgP=oo`03Nmioogoo009oo`03Nmioogoo00=oo`07NmioofmkBU8DY@005:D00QcW00LQ
21S65:D48@aS;F]F]@02Ool2Nmh4Ool00g_NOomoo`0IOol2Nmh2Ool017_NOom>Lf]JQGoo001POol0
0acWOomoo`0>Ool2Nmh2Ool01`00Oomoog_NOomkgWoo009kgREoo`06NmioogooOomkgU[F0ekg00=W
>GNmOol01goo00=kgWooOol08goo0W_N2Woo0W_NGWoo00AkgWooOomg_@=oo`04DY@8@WooNmh2Ool0
1G_NOomoogooNmh00Woo00=cW1S6AS40;Woo00=_Na24Ool01goo00=g_@Q2Ool0:goo00=kgP00DY@0
0Woo00ig_GooOomkgWooNmioog_NOomg_B48@Q1oog_N0Woo0W_N00=oogNmOol06Goo00UkgWooOomg
_Goo<HaBU7ooNmh01goo00=kgWooOol00W_N17oo00MkgWooOomkgVmkG_MS6002G_L00g>LMkeoo`07
Ool2MkdCOol017NmOomoogNm1Goo00EkgWooOomoog_N08Uoo`00H7oo00<007ooMkd00Woo00=kgWoo
Ool037oo00=kgP00Ool00Woo00=g_@00Ool00goo00=kgWooOol0:Goo0W_N<goo00=kgWooOol0GGoo
00=[FTicNmh01goo00QkgWooOomoofLi48AS67_N0Woo00=kgWooNmh00Woo00MkgWooOolU:CF]Oomk
gP0]Ool00f]J5:Eoo`07Ool00g>L36=oo`0/Ool00gNm48AF]@04Ool017_NOomoog_N0goo00Eg_A24
@Q1oog_N00=oo`03Nmioogoo01aoo`04Nmioobe[DY@6Ool00g_NOomoo`02Ool01G_NOomoogooMkd0
17oo00=kgWooOol037oo00=kgWooOol02goo00=kgWooOol01Woo00=kgWooOol017oo00AkgWooOomk
gP=oo`03Nmioogoo08Ioo`00H7oo00<007ooOol03goo0W_N00=oo`00Ool00goo00<007ooLi`08goo
00=kgWooOol02Woo00AkgWooOomkgP=oo`03Nmioogoo02=oo`03Nmioogoo00Qoo`03Nmioogoo05Qo
o`03JeXU:Goo00Yoo`07Mkd<HdicOomkgWooNmh01goo00<icR48Ool0;goo00=[FQS6Ool01goo00=_
Na24Ool0;7oo00IkgV<H36=[FWooNmh2Ool00g>LOomoo`02Ool3Nmh01`Q2CW=oogooNmioogNm009o
o`03Nmioogoo01]oo`03@Q1Nmg_N00Qoo`04MkeoogooNmh:Ool00g>LOomoo`04Ool00g_NOomoo`03
Ool2Nmh2Ool2NmhBOol017NmOomoog_N1goo00EkgWooOom:DW>L009oo`03Nmioogoo081oo`00H7oo
00D007ooOomoog_N009oo`03Nmioogoo00aoo`<00005249kgWooOomkgP0YOol00g_NOomoo`05Ool0
17_NOomkgW_N:Goo0W_N@Woo00=kgWooOol07Goo00=S61BUOol027oo0W_N00@DYD8@OomkgP=oo`04
NmioogooNmh2Ool00dYB5:EcW00`Ool00fLi7>Moo`07Ool00f]J48Aoo`0WOol00gNmOomoo`04Ool0
0e[F001_N`04Ool017_NOomoog_N0goo00E_NaBUCW=oogNm009oo`03Nmioogoo01moo`0AJeXicWNm
Oom[FQS67>LQ23W>OomkgV]J?NmkgWooJeXLi`028@P01CF]Oomg_FLiBU800Woo00aW>B485:DU:D8@
NmioofLi@Q1g_GooKg/27>L01R48>LioogooG_Lmk`9oo`09HaPQ21S67>M6<G_NOomNmcF]009oo`05
IcT]JaBU6<Hmk`02Ool02U[F>LioogooJeXQ21S69BT@Q6<H0goo00=kgWooOol0Ogoo001POol00f<H
OomkgP0>Ool01G_NOomkgWooNmh00goo00=kgWooMkd00Woo00=kgWooOol0;goo00=kgWooOol0<7oo
0W_N@Woo00=kgWooOol05Woo00=NmbU:Nmh017oo00=kgWooLi`00Woo00<Lic6<Ool01Woo00Mg_Goo
Oomooe[F48A[FP0aOol00f<H7>Moo`07Ool00fLi6<Ioo`0XOol00g_NOomoo`02Ool01GNmOomF]@Q2
Li`017oo00=kgWooOol00Woo00EkgWooJeX<He[F02Eoo`03LiaW>Goo009oo`05E[E[FUkgHaQoo`02
Mkd026<HOomkgW_NG_MJeV<HIcT2Ool01G_NG_MoogooNmh00ekg00EW>GooOomkgUkg009oo`0DNmiJ
eV<HG_MS67ooNmioofLiOomkgWooG_MS65kgIcUkgWooNmi_N`9oo`03Kg]Nmf<H009W>@0=Nmioogoo
IcUoogNmOomS66LiF]IW>GooNmh00Woo00=kgWooOol0Ogoo001iOol00g_NOomoo`02Ool00g_NOomo
o`0^Ool00g_NOomoo`2>Ool00g_NHaQoo`05Ool027_NOomooc6<;F]g_GooNmh4Ool02G_NOomoogoo
Kg/8@V<HOomg_@0`Ool00ekg8@Qoo`07Ool00f<H8@Qoo`0[Ool00g_NOomoo`02Ool01DYB5:EcW7oo
Mkd01Goo00MkgWooOomoofLi36=JeP0POol00g_NOomoo`0EOol00gNmOomoo`0=Ool017_NOomoog_N
47oo00=kgWooOol05Goo00=kgWooOol0OWoo001TOol00g_NOomoo`02Ool01G_NOomkgWooNmh01Goo
00EkgWooOomoog_N00Aoo`03Nmioogoo009kgPAoo`03Nmioogoo00Moo`04NmioogooNmh3Ool00g_N
Oomoo`0;Ool00g_NOomoo`05Ool017_NOomoog_N0goo00=g_GooNmh01Goo00=kgWooOol00goo00Ek
gWooNmioog_N00Eoo`05NmioogooOomkgP04Ool00g_NOomoo`02Nmh4Ool00g_NOomoo`07Ool017_N
Oomoog_N0goo00=kgWooOol02goo00=kgWooOol01Goo00IkgWooOomkgWooNmh2Ool00g_NOomoo`03
Ool01WNmOomoog_NOomkgPEoo`9kgP=oo`03Nmioogoo00Moo`03Nmioog_N009oo`03Nmioogoo00Io
o`03Mkeoogoo00Aoo`03Nmioog_N009oo`07NmioogooOom>La24Mkd01Goo00=kgWooOol00Woo00=g
_@aSE[D00Woo00=kgWooOol03Woo00=kgWooOol07Goo00ENmb48Nmioog_N00Eoo`05HaPLigooOomk
gP06Ool00g_NOomoo`0;Ool00g_NOomoo`0BOol017_NOomoogNm0Woo00<icRDYNmh017oo00=kgWoo
Ool017oo00AS6124JeYkgPAoo`03Nmioogoo015oo`03Nmioogoo009oo`03Nmioogoo00]oo`03Nmio
ogoo00Uoo`03Nmioogoo0;Uoo`00H7oo00<LigooOol037oo0W_N1goo00AkgWooOomkgPQoo`03Nmio
ogoo00=oo`05NmioogooOomkgP02Ool2Nmh7Ool00g_NOomoo`03Ool00g_NOomkgP07Ool00g_NMkeo
o`03Ool00g_NOomoo`05Ool2Nmh=Ool2Nmh7Ool017_NOomoog_N27oo00=kgWooOol00goo00EkgWoo
Oomoog_N009oo`9kgPMoo`03Nmioogoo00=oo`03Nmioog_N00Moo`03Nmig_Goo00Yoo`0<Nmig_Goo
Oomg_G_NOomg_GooNmioog_N17oo00=kgWooOol00Woo00EkgWooOomoog_N00=oo`04Nmig_GooNmh<
Ool00g_NOomoo`06Ool01g_NOomkgWooG_L8@WNm00Moo`06NmioogooOolQ248@0Woo00AkgWooOomg
_@9oo`05NmioogooMkekgP06Ool00gNmOomoo`05Ool01G_NOomoogooMkd00Woo00=g_GooOol02goo
00IkgWNmOomoof<H8@P7Ool017_NF]HQ27_N0Woo0W_N1Goo00AkgWooOomcW09oo`9kgPQoo`04Nmio
ogooNmh2Ool01G_NOomoogNmNmh01Woo00=g_GooOol00Woo00IcW7ooNmhaS2U:Nmh4Ool02g_NOomo
ogooLiaoog_NE[D48FmkNmh01Goo00AkgWooOomkgP9oo`9kgP9oo`9kgP05OomkgWooOomkgP03Ool0
1G_NOomoogooNmh00Woo00=cW7ooOol00W_N27oo00AkgWooOomkgPAoo`03Nmioogoo0;Yoo`00H7oo
00=F]GooOol017oo00=kgWooOol00Woo00=g_GooOol037oo00AkgWooOomcW0Yoo`04MkeoogooMkd2
Ool00gNmOomoo`02Ool017NmOomoog_N2goo00Ag_GooOomcW0Moo`03Mkeoogoo009kgPIoo`04Mkeo
ogooNmh2Ool00g_NOomoo`02Ool00gNmOomoo`0<Ool017_NOomoog>L2Woo00Ag_GooOomg_@9oo`03
Mkeoogoo009oo`04MkeoogooNmh;Ool017NmOomoog>L1goo00Ig_GooOomg_GooNmh@Ool01G_NOomo
ogooNmh00Woo00=kgWooOol017oo0W_N0Woo00AcW7ooOomg_@Eoo`03Liaoog>L009oo`06Nmioogoo
OomcW36<0Woo00MkgWooNmioofLi125W>@03Ool017NmOomoog_N0goo00AkgS6<9BUkgPUoo`03Mkeo
ogoo009oo`03Nmioog_N00Moo`9kgPMoo`03Nmioogoo011oo`03G_LLigoo00=oo`09LiaoogooOomN
mc6<Mkeoog_N00=oo`04NmioogooNmh<Ool00gNmOomkgP08Ool00gNmOomoo`02Ool00g_NOomkgP0:
Ool01g_N8@Pe[GooNmioog_N009oo`03Liaoogoo00=oo`05G_L<Hf]JOomkgP06Ool00g_NOomoo`09
Ool00g_NOomoo`05Ool00g_NOomoo`0:Ool00gNmOomkgP07Ool01GNmOomoogooNmh0^Woo001QOol2
Nmh3Ool00g_NOomkgP03Ool01g_NOomoogooNmioog_N00Ioo`04LiaoogooNmh7Ool00g_NOomkgP02
Ool00g_NOomoo`02Ool017NmOomoogNm1Goo00=kgWooOol017oo00AkgWooOomkgP9oo`06Nmioogoo
Mkeoog>L0goo00=kgWooOol017oo00Eg_GooOomoog_N009oo`06NmioogooMkeoog_N0goo00MkgWoo
Oomoog_NOomkgP06Ool017>LOomoog_N1goo00=kgWooNmh00Woo00=kgWooOol00Woo00Ag_GooOomg
_@Eoo`03Nmioogoo00Aoo`04NmioogooNmh2Ool01W_NOomoogNmOomcW0=oo`03Nmioogoo00Aoo`03
Nmioogoo009kgP9oo`03Nmioogoo009oo`03Nmig_Goo009oo`03Nmioogoo009oo`9kgP9oo`03Mkeo
ogoo00Aoo`03Nmioogoo009oo`03Nmioog_N00]oo`03NmiW>Goo00Aoo`04MkdHaU:DNmh3Ool02W_N
OomoogooNmioog_N@Q0Q27_N17oo00Ig_GooOomkgWooMkd2Ool00gNmOomkgP05Ool00g>LOomoo`05
Ool00g_NOomkgP04Ool00g_NOomoo`03Ool00g_NOomoo`02Ool01G_NOomoogooLi`00Woo00=S61cW
Ool01Woo00=g_Dic<H`017oo0W_N1goo00=g_GooOol00Woo00AcW7ooNmikgPEoo`03Liaoogoo009o
o`06MkeoogooMkeoog_N1Goo00=cW7ooOol01goo00<Q23g_Ool027oo00IcW7ooOom:DQBUJeX3Ool0
0g_NOomg_@04Ool01G_NOomoogooMkd00Woo00AkgWooOomkgPYoo`03Mkeoogoo009oo`04Liaoog_N
Nmh5Ool00g>LOomoo`04Ool00g_NOomoo`2jOol0065oo`057>L8@P00001JeP02Ool01AcWF]IoogNm
9BT00P0000H8@V<HOomoob48G_L2Ool01AS600048@00IcT00Woo00HU:E[FOomooa24124200001Fmk
Nmig_AcWIcT00Woo00D<H`00000006<H009kgP097>MW>GNmOolLi`00248006Li009oo`057>MW>Goo
OolQ200200002@@QIcUoogoo9BUNmg_NOolDY@0300001FLiMkeoobDYF]H00Woo00DU:@@Q00048E:D
009oo`057>MJeWooMkdU:@0200001PQ2HaQoogoo8@QNm`9oo`056<H000@Q001W>@02Ool01RDYF]Io
ogoo48@48@800005Kg]kgWNm7>MW>@02Ool01@aS00000000HaP00W_N00TLifLiMkeooacW0008@P00
IcT00Woo00DLifLiOomoob4800800009125W>GooOolU:EkgNmiooaBU00800006125F]G_NOolLie[F
0Woo010Q2000248005kgMkeoobDYHaQoog_N7>L48@00125Nm`9oo`056<IS67ooOolU:@0300001F]J
NmioobDYF]H00Woo00TU:@0000048E:DOomg_B48HaP00Woo00LHaPQ2000005kgOomkgP02Ool01GNm
48@icWooNmh00Woo00AkgWooNmicW09oo`04LiaNm`aSKg/3Ool00g_NOomoo`02Nmh01GooNmioogoo
Nmh00Woo00=kgWooOol047oo00Ag_GooOomcW0Aoo`03Nmioogoo00Eoo`07NmioogooNmiBU36<Nmh0
0Woo0W_N0goo00=:DRe[Ool00Woo00=kgWooOol01Goo0W_N00=oog_NNmh01Woo00=kgWooOol01Woo
00AkgWooOomkgP9oo`03Nmioogoo00Uoo`0;NmioogNmOom_Na24DYAoog_NOomcW002Ool00g_NOomo
o`03Ool00dYB7>McW002Ool00bDYE[Eoo`02Ool00gNmOomoo`08Ool01G_NOomoogooNmh01Goo0W_N
00=oog_NNmh01Woo00=kgWooOol01Woo00AkgWooNmikgP9oo`03Mkeoogoo0;Moo`00IWoo00=kgWoo
Ool01Woo00AkgWooNmig_@=oo`04NmioogooNmh2Ool00g_NOomoo`06Ool00g_NOomoo`03Ool00g_N
Oomoo`09Ool00g_NOomoo`0=Ool00gNmOomkgP07Ool01G_NOomoogooNmh00goo00=kgWooOol02goo
00AkgWooNmig_@=oo`04NmioogooNmh2Ool00g_NOomoo`06Ool00g_NOomoo`03Ool00g_NOomoo`09
Ool00g_NOomoo`0=Ool00gNmOomkgP07Ool00g_NOomoo`05Ool00g>LOomoo`03Ool00g_NOomoo`07
Ool017NmOomoog>L0Woo00=kgWooOol02Woo00=g_GooOol01Goo00=kgWooOol00goo00Ig_GooOomo
obe[:DX4Ool00g_NOomkgP02Ool01WNmOom[FP00JeYkgP=oo`03NmioogNm00Eoo`03Nmioogoo00eo
o`04NmioogooOol2Nmh017ooMkeoog_N2Woo00AkgWooOomkgP9oo`05Nmi>Lc6<OomkgP03Ool033g_
5:DQ21BU124U:CF]?NmoogNmOomkgP=oo`03Nmioogoo00Moo`03Nmioog_N00Aoo`04MkeoogooNmh2
Ool00g_NOomoo`0;Ool00gNmOomoo`04Ool01GNm001S67ooMkd00Woo00Ig_GooOomoogNmNmh2Ool0
1Sg_5:EcW1BU000e[@]oo`03Liaoogoo00Uoo`03Nmioogoo00Moo`03Nmioog_N00Aoo`06Mkeoogoo
Nmioog_N0Woo00=kgWooOol0^Goo001ROol017NmOomkgW_N0Woo00=kgWooOol057oo00=kgWooMkd0
17oo00=kgWooOol00goo00AkgWooOomg_@Eoo`03Mkeoogoo00Aoo`03Nmioog_N009oo`04Nmioogoo
Mkd8Ool00g_NOomoo`0>Ool00g_NOomkgP0FOol00g_NOomg_@04Ool00g_NOomoo`03Ool017_NOomo
ogNm1Goo00=g_GooOol017oo00=kgWooNmh00Woo00AkgWooOomg_@Qoo`09NmioogooOomkgWooMkeo
og_N009oo`0=48AcW7ooOol48@00248006mkNmioo`aSKg/00Woo00D8@P00124007Nm009oo`055:Ec
W7ooOol@Q00300001FmkOomoo`aSJeX00Woo00D<H`00000007Nm009oo`0536=cW7_NOol8@P030000
1G>L;F/Lia24JeX00Woo00DDY@00000007Nm009oo`88@P03G_Mg_B4800<00005Mkeoogoo5:EW>@02
Ool050@Q24800000JeYoog_N36=cW7ooMkd8@QBU00048G>LNmiooaBUJeX2Ool02@aS0008@P00Mkeo
og_N48A_N`02Ool02@@Q00000000MkekgWoo36=_N`02Ool01@0012400000Li`00Woo00D<H`@Q0000
00@Q00<00005Kg]oog_N48A_N`02Ool02A2400048@00MkeoogNm48AcW002Ool312401P00MkekgW_N
5:ES609oo`0R1248@P00001[FWooNmh<Hg>LOomg_@Q25:D000@QMkeoog_N249cW7_NOol8@P001240
07>LNmioo`@QMkeoog_N48@3000026]J@Q0000Q2000HaWoo248300001GNmOomg_@aSLi`00Woo00TD
Y@0036<006mkOomkgQBUKg/00Woo00T@Q000124007NmOomg_A24Li`00Woo0`@Q00H007NmNmikgQBU
HaP2Ool01@aS000YBW_NLi`0^Woo001YOol01G_NOomoogooNmh037oo00=kgWooOol03Woo00=kgWoo
Nmh03Goo00=kgWooOol017oo00=kgWooOol03Woo00=kgWooOol02goo00EkgWooOomoog_N00aoo`03
Nmioogoo00ioo`03Nmioog_N00eoo`03Nmioogoo00Aoo`03Nmioogoo00]oo`03Nmioog_N009oo`03
48Ag_Goo009oo`03Nmioogoo00Uoo`06NmioogooNmioogNm27oo00EkgWooOomoog_N00aoo`05Nmio
og_NOomkgP02Ool00dHa5:EkgP04Ool00gNmOomkgP03Ool00g_N6<I:DP02Ool00gNmOomoo`0DOol0
0g_NOomoo`05Ool01G_NOomoogooNmh00Woo00=g_GooOol03Woo00=>Lbe[Ool017oo00=kgQBU0000
0`0000<<Hg_NOol01Goo00AkgWooOomkgPAoo`03Nmioogoo00Aoo`03Nmioogoo015oo`04Nmioogoo
Nmh8Ool00e[F36=_N`07Ool01GNmOomoog>L6<H0100000=W>GooOol00Woo00=kgWooOol03Woo00Ak
gWooOomkgPAoo`03Nmioogoo00Aoo`03Nmioogoo00Ioo`03G_LQ27oo0;]oo`00ogoo2goo00Eg_Goo
Ool8@W>L01moo`03Nmioogoo011oo`05NmiooeJe36=cW003Ool00g_NOomoo`02Ool01W_NOomoobDY
=JekgS1oo`03Nmioogoo00Ioo`03CW<]Jgoo009oo`05NmioogooAS448@0300001DYBOomoogooNmh0
<Woo00AkgU[F36=_N`Qoo`03Mkd48@@Q008000031240048@009oo`03Nmioogoo011oo`03Nmioog_N
01Aoo`9kgP03Kg]oog_N0;Yoo`00ogoo2Goo00MkgWooOomoog>L5:EW>@0WOol017_NOomkgW_N1Woo
00EkgWooIcT8@U[F00Eoo`09NmioogooNmioog_N=JdYBW_N02moo`03Nmioogoo009oo`03Nmioogoo
009oo`06Nmi>LcF]Liaoog_N0Woo00=kgWoo48@00P0000<HaWNmOol0=7oo00EkgWooNmi6<ABU009g
_@=oo`05Mkeoog_NG_LU:@0200001PQ2000001cWOomg_@Uoo`03Nmioogoo00Eoo`04NmioogooNmhG
Ool00g_NOomoo`2jOol00?moo`ioo`03249_Ngoo01]oo`9kgPAoo`03Nmig_Goo00Ioo`03Nmioogoo
00Aoo`05Mkd48E[FOomkgP04Ool00g_NKg]oo`02Ool00e[F36=kgP02NmhdOol00g_NOomoo`02Ool0
0dYB;F]oo`06Ool013W>248005:D0Woo00AkgWooNmig_C9oo`05Mkeoocg_;F]oo`02Nmh6Ool017>L
BU8<H`Q20P0000AkgWooOomkgP]oo`04NmioogooNmh4Ool00g_NOomkgP0AOol00g_NOomoo`2mOol0
0?moo`eoo`03Nmioogoo02Qoo`06MkekgW>LKg]cW7_N0goo00Ag_@aSAS5kgPIoo`0;Li`004icOomW
>@00JeYkgWooNmioo`02Nmh/Ool00g_NOomoo`06Ool017_NG_MBU7_N0Woo0V<H0Woo00=g_@005:D0
0goo00=kgWooOol0=Goo00=kgS6<:DX01Woo00=kgWooOol00Woo00ANmc6<5:E2409oo`04JeY:DR48
2482124300001QS6<HaBU7NmOomkgP9oo`07MkekgWooOomkgWooNmh04Woo00ES63F]Oomoog_N0;Uo
o`00ogoo:Woo00=kgWooOol00goo00=kgWooOol00Woo00iS63g_8@P8@P0036<DY@Q20008@R48>LhL
icF]1goo00UkgTYB124002U:5:EW>GooMkd0=Goo00=kgWooMkd00Woo00A_NeJe<H`@Q08000077>LD
Y@Q2000LiaBU?Nl00g_N0goo00=kgWooOol0<Goo00EkgWooNmhU:CF]009oo`03Nmioogoo00Moo`08
NmicW3W>36<DYCF]G_Mg_@9kgP=oo`07JeYBU2e[124HaU:DNmh017oo00Ag_GooOomkgQ=oo`03JeYo
ogoo0;Yoo`00ogoo2Woo0g_N00=oog_NOol07Goo00=kgWooOol00Woo00MkgSW>124LidHaF]IkgP05
Ool01g_NG_M241S6001247>L009kgPAoo`05=Jd000@Q000DY@02Mkd017ooNmioogNm;7oo00=kgWoo
Ool01Woo00QF]AS6248]JeJeJeYkgWNm17oo00I[FTYB:DX48BU:HaP2Ool00gNmOomoo`0`Ool2Nmh3
Ool00g_N6<I24002Ool017_NOomoog_N0Woo00Mg_GooLi`mk`Q2?NmcW00=Ool01VLi<H`@Q48@Oomk
gP9oo`9kgQ=oo`05NmioogooOomkgP2iOol00?moo`ioo`0336=_Ng_N01aoo`07NmioogooLi`icQ24
?Nl00Woo00=kgWooOol02Goo00Eg_Cg_6<I247_N00Aoo`0348@00000008000035:EkgVmk00=oo`03
Mkeoogoo02Uoo`04NmioogooMkd2Ool01GNmDY@HaRDYJeX01Woo00Ag_GooOomkgPAoo`04F]HU:AS6
IcTbOol00g_NOomkgP02Ool01G_NOomkgQ24DY@027oo00AS61S6AS5g_@]oo`03Nmioogoo00=oo`05
Li`mk`aSOomcW003Ool00g_NOomoo`0>Ool00g_NOomoo`2mOol00?moo`]oo`03Nmioogoo025oo`04
F]HHaTHaMkd4Ool00g_NOomoo`0:Ool017Nm?NlLif<H0Woo00=cW00000000`0000D48ABUOomkgWNm
031oo`08Nmioog>L=Jd]Jf]JOomkgPAoo`04NmioogooNmh7Ool017_NJeXHaSg_>7oo00IkgVmk36=N
mgooMkd4Ool01DYB6<IcW7ooNmh04goo00=S61S6G_L00Woo00=kgWooOol04Goo00=W>C6<Ool0^goo
003oOolYOol00g_NOomoo`02Ool00dYB7>MkgP0AOol02G_NOomcW7ooJeXDYEJeOom:DP0400000acW
F]Ioo`0dOol00fmk7>MBU00EOol017_NCW<LigNm>7oo00=W>@aSIcT017oo00<Q24icMkd05goo00=g
_B48E[D027oo00=kgWooOol02Woo00=F]BDYMkd0^goo003oOolZOol01G_NOomoobDYAS404goo0W_N
17oo00TYBSg_;F/8@P@Q:DY_NgooNmh0=7oo00=W>AS6IcT05goo00Eg_F<H6<Ig_G_N009oo`03Nmio
ogoo039oo`08F]H<HfmkOomkgSg_E[E_NaYoo`038@QS67>L015oo`08Mkeoof]J8@Qoog_NOomkg[Qo
o`00ogoo2goo0W_N00=oo`aSLi`06Goo00EkgWooOom6<Cg_009kgQ=oo`0:MkeoogooMkeoogNm=Jd<
Hd8@NmhdOol01W_NOomg_G>L6<I[FQYoo`03Kg/@Q7oo00Aoo`03Nmioogoo02moo`08NmiooeJe36=k
gU:D<HakgQ]oo`03NmhHaVmk009oo`03Nmioogoo00ioo`03F]HDYGoo0;]oo`00ogoo3Woo00<@Q6]J
Ool06Woo00A6<C6<OomkgQQoo`06Nmioog_N;F]W>Fmk=Woo00=g_B48IcT00Woo00=kgWooOol05Goo
00EkgWooG_LYBWNm03Ioo`06Nmiooe:DBU8YBWNm6Woo00IkgWooOomcW1cWMkdAOol00gNmNmicW003
Ool00g_NOomoo`2fOol00?moo`ioo`0348A[FWoo01Uoo`04JeXHaW_NNmhCOol00g_NOomoo`04Ool0
1G>LOomcW1S6Li`0=Goo00=kgS6<E[D00W_N77oo00=243W>Ool0=7oo00IkgWooOomooaBUIcTMOol0
17_NOom:DS6<4Woo00=kgWooNmh0^goo003oOol;Ool2Nmh00goo36=cW00IOol00g_N7>M[FP03Ool0
0gNmOomoo`0AOol017_NOomoog>L17oo00AF]B48OomkgS=oo`03F]HU:Goo01eoo`04MkeooaS6Li`c
Ool01g_NOomoogoo@Q0e[G_N01eoo`05Nmig_Goo7>MS600?Ool00g_NOomoo`2mOol00?moobUoo`08
DY@YBWooNmioog_NOomkgQ5oo`04NmioogooNmh2Ool01W_NOomoog_N:DYS609oo`03Nmioogoo02io
o`03NmhHaV<H00Aoo`03Nmioogoo01Ioo`07MkeoogooF]HHaWooMkd0=7oo00=cW1BUNmh077oo00=g
_GooOol00Woo00=BU36<Ool047oo00ES648@Nmioog_N0;Uoo`00ogoo:Goo00@<Hg_NNmikgP9oo`03
Nmioogoo01Aoo`03Nmioogoo00=oo`03HaPDYGoo039oo`04AS4icWooMkd2Ool00g_NOomoo`0KOol0
12U:DYAoog_N<7oo00EkgWooNmiJeRDY01ioo`07MkeoogooNmioo`Q2Mkd047oo00Eg_FLiOomoog_N
0;Uoo`00ogoo2goo00=kgWooOol05Woo00MkgWooOomooe[F9BUkgP03Ool00g_NOomkgP0LOol00aS6
JeYoo`0]Ool01W_NOomoogoo48AcW0moo`03Nmioogoo00aoo`06NmioogooOomF]BDY=Goo00@U:EJe
OomkgPaoo`03NmioogNm00=oo`04NmioogooNmh;Ool00cF]AS5oo`0>Ool00gNmOomoo`2lOol00?mo
o`ioo`0336=_Ng_N01Moo`03<Ha>Lgoo00=oo`03Nmioogoo00Yoo`04LiaoogooMkd;Ool01G_NOomo
ocg_@Q00<Goo00=_NacWLi`03Woo00=kgWooNmh00Woo00=g_GooOol02goo0W_N00<<HgooOol0<Goo
0W_N00<DYGNmOol037oo00=g_GooOol00goo00IkgWooOomg_GooNmh:Ool00ekg8@Qoo`0@Ool00g_N
Oomoo`2jOol00?moo`Yoo`=kgP03OomkgWoo01=oo`03Nmioogoo009oo`0336=g_Goo00ioo`03Nmio
ogoo00=oo`03Nmioogoo00Qoo`05NmioogooJeX@Q00aOol00dYB>Lioo`0BOol00g_NOomoo`0:Ool0
1WNmOomoogoo9BUJeS=oo`03HaPHaWoo00aoo`06Nmioog_NMkeoog_N0Woo00Ig_G_NOomkgWooNmh:
Ool00`@QOomoo`02Ool00g_NOomoo`09Ool00f<H>Lioo`2kOol00?moob=oo`06NmioogooOomcW0aS
47oo00=kgWooOol04Woo00<007_NOol0;7oo00EkgWooNmhYBU:D011oo`03Nmioog_N00eoo`06Nmio
ogooMke>LcW><goo00EBU2U:Oomoog_N00]oo`05NmioogooOomkgP05Ool00g_NOomoo`0:Ool00`@Q
Nmioo`0<Ool017_NOomS6248_7oo003oOol=Ool00g_NOomoo`0GOol015kg8@Qoog_N3goo00EcW7oo
Oomoog_N00moo`0336=_Ngoo02moo`037>MNmgoo00ioo`03Mkeoogoo00eoo`03Nmioogoo009oo`03
DY@e[G_N039oo`04CW<aS7ooNmh=Ool00g_NOol0000300000gooMkeoo`0=Ool01ABUJeYoogooNmh0
37oo00=NmaS6Ool0^goo003oOol>Ool00`Q2Kg]oo`0FOol00dic<Haoo`03Ool00g_NOomoo`0:Ool0
10Q200048@0047oo00<Q26<HOol0;goo00<@Q6mkOol047oo00EkgWoo125oog_N00ioo`03G_LQ27oo
039oo`03@Q0mkgoo00aoo`06Nmioogoo001oogNm0Woo00<007ooOol00Woo00=kgWooOol027oo00DQ
25[FOomoog_N00aoo`03E[DYBW_N0;]oo`00ogoo2Goo00MkgWooOomoog>L5:EW>@0GOol00dHa>Lio
o`0?Ool00`00OomkgP02Ool00`00OomkgP0=Ool00bU:F]Ioo`0_Ool00`@QNmioo`0>Ool2Nmh2Ool0
0`00Oomoo`0:Ool01WNmOomoogooKg/<Hc=oo`03?Nm247_N00]oo`03Nmioog_N00Aoo`03MkekgP@Q
00=oo`03Nmioogoo00Uoo`037>MNmgoo00aoo`04Mkeoog_NIcVlOol00?moo`]oo`05Mkeoogoo249c
W00BOol00g_NOomoo`02Ool01Dic>LioogooNmh047oo00=g_Goo00002goo00IkgWooOomoobDYE[D[
Ool00g_NOomoo`02Ool00`@QNmioo`0>Ool400000`@Q001kgP0>Ool00fLi6<Ioo`0bOol014ic<Hao
og_N3goo00EkgWooOomoo`0000ioo`03NmhDYG>L00=oo`03Nmioogoo0<Moo`00ogoo3Woo00<<Hfmk
Ool04goo00EkgWooOom>Lbe[00Aoo`03Nmioog_N00ioo`03001oogoo00eoo`037>MS67oo02moo`03
5:E_Ngoo00moo`04001oogoo000;Ool00g_NOomoo`02Ool00e[F9BUoo`0aOol01W_NHaPYBW_NOomk
gPeoo`03125oogoo009oo`03001oogoo009oo`03Nmioogoo00=oo`0:NmioogooNmioo`00OomkgWoo
Nmh=Ool00g_NOomoo`2jOol00?moo`eoo`03Nmioogoo01Moo`03HaPHaWoo015oo`06Liaoogoo001o
og_N3Goo00<@Q6mkOol0;goo00@Lif<HOomkgPioo`04001oog_N124@Ool00e:D:DYoo`0bOol00f<H
5:Eoo`02Ool00g_NOomoo`0:Ool50002Nmh01gooMkeoogooNmioog_N00Aoo`05MkeoogNm125kgP02
Ool00g_NOomkgP0:Ool016<HAS5kgWoo0W_N^7oo003oOolWOol01GNm36=kgWooNmh00Woo00=kgWoo
Ool02Woo00@48@00001kgPioo`03Mkd<HgNm031oo`05>Li:DW_NOomkgP0>Ool01P00Ool007NmOomg
_@eoo`03=Je:DWoo039oo`03Nmh@Q6mk00aoo`05Nmioogoo36=g_@07Ool2Nmh6Ool01W_NOomkgUJe
;F]kgP9oo`03Nmioogoo00Yoo`03MkeNmgoo0;]oo`00ogoo2Woo00EkgWooNmioogNm01Uoo`036<I[
FW_N00ioo`06NmioogooOomkgP@Q37oo0W_N00=NmbDYOol0<7oo00=JeR48Ool03Woo00EkgWoo001o
o`@Q011oo`0348A_Ngoo031oo`05Nmioogoo>Li2400;Ool01W_NOomoogNmOol000=oo`04MkekgWoo
Nmh7Ool027_NOomoogoo7>MS67ooNmh2Ool00g_NOomoo`07Ool2Nmh3Ool00g_NOomoo`2hOol00?mo
o`ioo`035:E_Ng_N015oo`03Nmioogoo00=oo`03@Q0icWoo00Aoo`03Nmioogoo00aoo`03001kgWoo
00aoo`03:DYBU7oo031oo`04Mkd8@WooLi`2Ool00g_NOomoo`0;Ool200000gooNmioo`08Ool01W_N
Oomoog>LMkd@Q3=oo`04Nmiooe[F7>L@Ool00`00Nmioo`06Ool00g_NOomoo`02Ool02GNmOomoog_N
Ool8@WNmOomkgP02Ool00g_NOomoo`0:Ool00gNmOomoo`2jOol00?moo`eoo`03Nmioogoo019oo`03
Nmioog_N00=oo`05Kg/@Q7ooOomkgP0<Ool01`00Oomoog>LOol48G_N00eoo`0336=cW7oo02ioo`05
Nmioogoo;F]:DP0AOol00`@Q001oo`0;Ool01G_NOomoocF]@Q00=7oo00EkgWoo6<I[FWNm00Uoo`07
NmioogNmNmioo`0012400P0000D48GooNmioog_N00Moo`05NmioocF]@Q1kgP05Ool00g_NOomoo`08
Ool00f]J=Jeoo`2kOol00?moobUoo`03;F]F]Goo00ioo`0400048@000002Ool00g_NOomoo`09Ool0
0dic=Jeoo`0bOol01F]J6<IoogooNmh03Woo00EkgP00Oomoog_N00Uoo`05Mkeoog_N6<IcW00bOol0
1W_NOomoog_NJeXDY@moo`03Liaoogoo00=oo`03Nmioog_N00Moo`04Nmig_ABUNmh?Ool017_NOomS
61cW_7oo003oOol:Ool00g_NOomoo`0LOol01F]J5:EkgWooNmh03Goo00=g_GooOol03Goo00Eg_A24
Mkeoog_N039oo`03<Ha>Lgoo009oo`03Nmioogoo00eoo`03Nmioogoo00Yoo`03@Q0mkg_N03Ioo`03
NmhicTHa00Yoo`03Nmioogoo019oo`03:DYF]Goo00Eoo`03Nmioogoo00Uoo`03F]HQ27oo0;]oo`00
ogoo3Woo00<DYG>LOol06Goo00De[DHaOomoog_N01=oo`9kgP9oo`03Nmioogoo009oo`03=Je6<Goo
03Aoo`03Mkd@Q7Nm009oo`03Mkeoogoo01Eoo`09NmioogooNmicW124Nmioog_N039oo`09Nmioogoo
Oomg_A24Liaoog_N00Yoo`03Nmioogoo00Aoo`03Nmioogoo00Moo`03E[DYBWoo019oo`03HaPQ27oo
009oo`03Nmioogoo0;Ioo`00ogoo3Woo00<48F]JOol06Goo00=g_BU:HaP00Woo00=kgWooOol01Woo
00=kgWooOol01Woo00=kgWooOol017oo00IkgWooG_LQ27ooMkddOol00g_NDY@icP08Ool00g_NOomo
o`09Ool01GNmOomoogooMkd01Goo00@Q25kgOomkgS9oo`03Nmioogoo00=oo`03JeXHaW_N00Aoo`03
Nmioog_N015oo`05NmioogooG_LLi`0DOol00g_NKg]kgP2kOol00?moo`eoo`03MkdQ26mk01Uoo`05
Nmioog>L6<Ig_@03Ool2Nmh3Ool00g_NOomoo`0@Ool016<H8@QkgW_N0Woo00=kgWooOol0;goo00Qk
gWooNmi6<Cg_Nmioog_N5Woo0g_N00L]Je:DOomoog_NOomkgP0cOol02G_NOomkgWooG_LHaWNmOomk
gP02Ool00g_NOomoo`0<Ool00g_NOomoo`03Ool016Li7>MkgW_N4goo00=kgWooNmh0^goo003oOol>
Ool00`00Liaoo`0IOol01W_NOomS61cWLiakgPAoo`05NmioogooOomg_@08Ool00g_NOomoo`02Nmh2
Ool016mk:DYcW7Nm0Woo00=kgWooOol0<Goo00EkgWooLi`]Je:D00Moo`9kgPUoo`9kgPAoo`04Nmio
ocW>AS44Ool00g_NOomoo`0bOol027_NOomoog>LOomJeQcWJeX2Ool00g_NOomoo`06Ool00g_NOomo
o`03Ool00g_NOomoo`02Nmh01gooE[DHaV]JNmioog_N011oo`04LiaoogooMkflOol00?moo`aoo`03
Nmioogoo01]oo`07NmioogooF]HQ26LiMkd05Woo00AF]AS6JeYcW09oo`9kgP03OomkgWoo02moo`03
Nmioogoo009oo`8]J`03Nmioogoo019oo`05NmioogNm9BU6<@0nOol01G_NOomW>AS6CW<057oo00=k
gSW>:DX017oo00=kgWooOol047oo00AW>CW>Nmikg[Yoo`00ogoo2Woo00=kgWooOol00goo00=kgWoo
Ool06Woo00AkgVmk9BUBU0Eoo`03Nmioogoo00Qoo`08NmioogooOomg_CF];F]g_@=oo`04Nmioogoo
NmhcOol01g_NOomoogooCW<Q26mk00=oo`03Mkeoogoo00Yoo`09Mkeoog_NOomNmbDYDYAoogNm00=o
o`03Nmioogoo035oo`05NmioogooOomg_@02Ool02G_NOomoobU:5:E>LgooMkekgP0:Ool01gNmOomo
og>LAS4@Q4Ha009kgP03Oomg_Goo01Aoo`03JeYoog_N0;Yoo`00ogoo:goo00QkgWooOomoog>L=Jd@
Q4ic4Goo00E>LaBU@Q1oog_N00Eoo`03Nmioogoo035oo`03Mkeoogoo00=oo`04JeX8@SF]JeX=Ool0
1g_NOomoofmk;F/Lif]J00=oo`03Mkeoogoo009kgSAoo`05LiaoogooNmicW002Ool027NmOom_Nc6<
36=BU7>LNmh5Ool00g_NOomkgP02Ool01F<H:DXLicF]Li`01Goo00=g_GooOol047oo0W_N_Goo003o
Ool;Ool01G_NOomooa24Li`077oo00=kgWooNmh00Woo00I_Nc6<48@e[F]JNmh:Ool01ekg=Jd@Q36<
Liaoog_N00=oo`03Nmioogoo03=oo`03Nmioog_N00Aoo`07NmioodHa6<HU:EJeLi`02Woo00Eg_DYB
8@PLie:D00Aoo`03Nmioogoo00=oo`03Nmioogoo03=oo`03Nmioogoo00Ioo`0ALi`e[@aS6<H]Jcg_
AS5JeV<HE[Dmkd8@9BT8@QS6CW=cW006Ool00g_NOomoo`0@Ool00g_NOomoo`2mOol00?moo`aoo`03
Nmioogoo02Aoo`05Kg]241S636<U:@02@Q002U[FHaQ>LdHa@Q0YBPQ28@Q6<G>LAGoo01=kgWooOomF
]BDY36<Q23W>?NmBU5kgE[E>LdHa<H`HaPaS<HaNm`1>Ool02f]JDYA2436<9BTQ22U:?Nm6<E[FMkd0
7Goo00AkgVLi?Nmkg[]oo`00ogoo=Woo00McW5[FAS4mkbDY7>LaS002?Nl00e:DMkeoo`03Ool00g_N
Oomoo`13Ool03g_NOomoog_NG_M243g_:DXQ22U:<H`icTicIcUkgP1gOol01W_NOomS6248Oomkg[Yo
o`00ogoo3Goo0W_N>Goo00=kgWooOol0C7oo00=kgWooOol0D7oo00=kgWooOol09Woo00=S61BUOol0
^goo003oOol>Ool00a24Liaoo`0POol2NmiFOol00gNmOomoo`02Ool017_NOomoog_N0Woo0W_N0goo
00=kgWooOol0EGoo00=kgWooOol07goo00ANmbDYOomkg[Yoo`00ogoo3Woo00<8@V]JOol0:Goo00=k
gWooOol00Woo00=kgWooOol0BGoo00=kgWooOol02Woo00=kgWooOol0CWoo00=kgWooOol09goo00=g
_F<HOol0^goo003oOol<Ool2Nmh00acWJeYoo`0POol00g_NOomoo`02Ool2Nmh4Ool2Nmh3Ool00g_N
Oomoo`15Ool00g_NOomoo`0=Ool2Nmh5Ool00g_NOomoo`1eOol00g_NOomoo`2fOol00?moo`]oo`05
Nmioogoo001cW00SOol00g_NOomoo`09Ool00g_NOomoo`1?Ool00g_NOomoo`08Ool00g_NOomoo`1e
Ool00g>LOomoo`2jOol00?moo`eoo`03Nmioogoo0?moo`Aoo`03IcU247oo0;]oo`00ogoo2Woo00=k
gWooOol00Woo00=kgWooOol0DWoo00EkgWooOomoo`0000=oo`04001oogoo0002Ool02@00Oomoogoo
249g_Goo001g_@02Ool01000Oomoo`001Woo00D007_NOomkgP@Q009oo`07001oog_NOol48Goo0000
0Woo00<007ooOol00goo00@007ooOol0009oo`05001oogooOol00002Ool01@00Oomoogoo00000Woo
00L007ooOomoo`00Ool00003Ool010@QOomoo`000goo00<007NmOol0CWoo00=g_FmkNmh0^goo003o
Ool;Ool017_NOomkgW>LEGoo00AkgWooOol000Eoo`06001oo`00Nmioo`Q20goo00D007ooOol007oo
009g_@=oo`04001oogooNmh2Ool00gNmOomoo`02Ool01@@QNmioo`00Nmh00Woo00<007_N00000Woo
00@007ooOomkgP9oo`06001cW7oo001oogNm0Woo0W_N00P48GooOomoog_NOomkgP000Woo00L007oo
Oomoo`00Ool00003Ool00g_NOomoo`03Ool00gNm125oo`1AOol00g_NOomoo`2iOol00?moo`]oo`05
Nmioogoo5:EcW01BOol00g_NOomoo`02Ool01000Oomoog_N0Woo00<48G_N00000Woo00L007ooOomo
o`00Mkeoo`0300001`@Q001oogoo001oog_N009oo`03Nmioogoo00<00004Nmioogoo0003Ool00`00
Ool00002Ool00`00Oomoo`03Ool01`00Oomoo`00NmioogNm00<0000<OomkgWNmOol48@00125oog_N
Ool007Nm0Woo00<007oo0000100000=oog>LOol00P0000D48GooMkekgWoo009kgTaoo`03Nmioogoo
0;Yoo`00ogoo2Woo00EkgWooOomoogNm05Eoo`9kgP03Ool007oo009oo`0<Nmioo`00Ool48GooLi`4
8GooNmioo`000Woo00P48GooOomkgP00Oomg_@000goo00IkgWooOol007ooNmh4Ool02P00Oomoogoo
001oo`00Mkeoo`001Goo00@007ooNmh0009oo`03001kgWoo00Aoo`03001oogoo00Aoo`07001oogoo
Ool48G_N00000goo00@48GooOol000Uoo`03Nmioogoo04Qoo`03HaQ247_N0;]oo`00ogooHWoo00=g
_GooNmh00Woo00<007ooOol00goo00D007oo001kgWoo00800006OomkgP00Nmioo`000goo00L007_N
Ool000@QOomkgP03Ool01@00Oomoogoo00000Woo00L007ooOomoo`00Ool00002Ool00`00Oomoo`03
Ool01000Nmioo`000Woo00D007ooOomkgP00009oo`05001oogooOol00002Ool01`00Oomg_G_N001o
o`00009oo`05Nmh007ooOol00003Ool01000OomoogNmCGoo00=Nmb48Ool0^goo003oOol9Ool00g_N
OomkgP02NmiDOol02G_NOomoogooMkd007ooLiaoo`02Nmh3000010@QNmh007oo0P0017oo0`000Woo
00AkgP00Nmh0009oo`03Mkeoogoo00<0009oo`03Nmioo`0000800003Ool0000000848@80009oo`07
Mkd00000001oo`00Nmh00Woo0`0017oo0`0000EkgWooLi`007_N009oo`03001kgWoo00<000Aoo`<0
009oo`05NmioogooOomkgP1:Ool00ekg7>Moo`2kOol00?moo`ioo`03249cW7oo051oo`04Nmioog_N
Nmh2Ool01W_N001oogNmOol0009oo`05001oogoo001kgP06Ool01G_NOomoogooNmh037oo00Eg_G_N
Oomoog_N00Aoo`06001oogoo001oog_N0Woo00AkgP@QOomcW0=oo`03Mkeoog_N00ioo`04Nmioogoo
Mkd2Ool00g_NOomg_@05Ool00g_NOomoo`02Ool00gNmOomoo`18Ool017_NF]HYBWNm^goo003oOol=
Ool00g_N48A_N`1FOol00gNmOomoo`030003Ool01000Oomoo`0017oo00=kgWooNmh03Goo00AkgWoo
Oomg_@=oo`03Nmioogoo009oo`05Nmioo`0012400005Ool01000Oomoo`@Q2goo00=kgWooNmh00Woo
00=kgWooOol03goo00IkgWooOomg_GooNmi;Ool01F<HOomkgWooNmh0^7oo003oOol=Ool00g_N48A_
N`3oOol3Ool017_NOomoog_N^goo003oOol>Ool00`Q2Liaoo`3oOol4Ool00g_NOomoo`2jOol00?mo
o`Uoo`03Nmioog_N009kg_moo`Ioo`05HaPicWooNmig_@2iOol00?mooomooa=oo`9kgP03JeYoogoo
0;Yoo`00ogoo2Woo00EkgWooOomoogNm0?moo`Eoo`05Nmig_GooOomkgP2iOol00?moo`]oo`05Nmio
ogoo5:EcW03oOol2Ool2Nmh2Ool017_NOomoog_N^7oo003oOol;Ool017_NOomkgW>Logoo1Goo00=N
mcW>Ool0^goo003oOol:Ool00g_NOomoo`02Ool00g_NOomoo`3oOol01W_NOomS61cWOomkg[Yoo`00
ogoo2Woo00AkgWooOomkgPEoo`03Nmioogoo00Aoo`03Nmioogoo00Ioo`03Nmioogoo00Yoo`03Nmio
ogoo009oo`03Nmioogoo009oo`06NmioogooNmioog_N1Woo00AkgWooOomkgPEoo`03Nmioogoo01=o
o`03Nmioogoo00=oo`03Nmioogoo00Aoo`03Nmioogoo00Ioo`03Nmioogoo00Yoo`03Nmioogoo009o
o`03Nmioogoo009oo`06NmioogooNmioog_N1Woo00AkgWooOomkgPEoo`03Nmioogoo01=oo`03Nmio
ogoo00=oo`03Nmioogoo00Aoo`03Nmioogoo00Ioo`03Nmioogoo00Yoo`03Nmioogoo009oo`03Nmio
ogoo009oo`06NmioogooNmioog_N1Woo00AkgWooOomkgPEoo`03Nmioogoo011oo`04NmiW>B48Nmjk
Ool00?moo`Uoo`03NmioogNm009oo`0348AcW7oo00Ioo`03Nmioogoo00=oo`03Nmioogoo00Aoo`03
Nmioogoo015oo`=kgPQoo`03Mkeoogoo00ioo`03Nmioogoo00Aoo`05NmioogooOomkgP03Ool00g_N
Oomoo`09Ool00g_NOomoo`03Ool00g_NOomoo`04Ool00g_NOomoo`0AOol3Nmh8Ool00gNmOomoo`0>
Ool00g_NOomoo`04Ool01G_NOomoogooNmh00goo00=kgWooOol02Goo00=kgWooOol00goo00=kgWoo
Ool017oo00=kgWooOol04Goo0g_N27oo00=g_GooOol03Woo00=kgWooOol017oo00EkgWooOomoog_N
00=oo`05F]HLigooOomkgP2iOol00?moo`]oo`05Nmioogoo5:EW>@0;Ool00g_NOomoo`02Nmh;Ool0
0g_NOomoo`06Ool2Nmh00gooMkeoo`03Ool01W_NOomoog_NOomg_@Moo`9kgPEoo`03Nmioogoo00=o
o`04NmioogooNmh3Ool01G_NOomoogooMkd04Goo00=kgWooOol00W_N2goo00=kgWooOol01Woo0W_N
00=oogNmOol00goo00IkgWooOomkgWooMkd7Ool2Nmh5Ool00g_NOomoo`03Ool017_NOomoog_N0goo
00EkgWooOomoogNm015oo`03Nmioogoo009kgP]oo`03Nmioogoo00Ioo`9kgP03Oomg_Goo00=oo`06
NmioogooNmioogNm1goo0W_N1Goo00=kgWooOol00goo00AkgWooOomkgP=oo`03Nmioogoo00=oo`03
NmiW>G_N0;]oo`00ogoo37oo00Ag_Goo001cW0=oo`04NmioogooNmh5Ool00gNmOomkgP04Ool01WNm
OomoogooMkekgPEoo`03Nmioogoo00Qoo`05NmioogooOomkgP06Ool01GNmOomoogooNmh01Goo00Mk
gWooOomoog_NOomkgP09Ool00g_NOomoo`04Ool00gNmOomoo`03Ool017_NOomoog_N1Goo00=g_Goo
Nmh017oo00Ig_GooOomoogNmNmh5Ool00g_NOomoo`08Ool01G_NOomoogooNmh01Woo00Eg_GooOomo
og_N00Eoo`07NmioogooOomkgWooNmh02Goo00=kgWooOol017oo00=g_GooOol00goo00AkgWooOomk
gPEoo`03Mkeoog_N00Aoo`06MkeoogooOomg_G_N1Goo00=kgWooOol027oo00EkgWooOomoog_N00Io
o`05MkeoogooOomkgP05Ool01g_NOomoogooNmioog_N00Uoo`06NmioogooNmioog_N0goo00=cW7oo
Ool0]goo003oOol:Ool01W_NOomkgWNm7>M_N`Qoo`03Nmioogoo00Eoo`9kgPQoo`=kgPUoo`03Nmio
og_N00Moo`03Mkeoogoo01=oo`03Nmioog_N00=oo`06NmioogooOomkgWoo0W_N17oo00=kgWooOol0
1Goo00=kgWooOol01Goo0W_N27oo0g_N2Goo00=kgWooNmh01goo00=g_GooOol04goo00=kgWooNmh0
0goo00IkgWooOomoog_NOol2Nmh4Ool00g_NOomoo`05Ool00g_NOomoo`05Ool2Nmh8Ool3Nmh9Ool0
0g_NOomkgP07Ool00gNmOomoo`0COol00g_NOomkgP03Ool01G_NOomoogooNmh017oo0W_N^Woo003o
Ool>Ool01W_NOomoogooNmioo`9kgP05OomkgWooOomkgP02Ool00gNmOomoo`02Ool01GNmOomoogoo
Mkd01Woo00=kgWooNmh027oo00=kgWooNmh00goo00=g_GooOol017oo00Ag_GooOomkgPIoo`03Nmio
ogoo019oo`9kgPAoo`06Nmioog_NNmioog_N0Woo00AkgWooOomg_@Aoo`05MkeoogooOomg_@06Ool0
0g_NOomkgP08Ool00g_NOomkgP03Ool00gNmOomoo`04Ool017NmOomoog_N1Woo00=kgWooOol04Woo
0W_N17oo00IkgWooNmikgWooNmh2Ool017_NOomoogNm17oo00Eg_GooOomoogNm00Ioo`03Nmioog_N
00Qoo`03Nmioog_N00=oo`03Mkeoogoo00Aoo`04MkeoogooNmh6Ool00g_NOomoo`0?Ool017_NOomN
mcF]_7oo003oOol9Ool00g_NOomkgP05Ool00g_NOomoo`02Ool01W_NOomoogooMkeoo`9kgP9oo`03
Nmioogoo009oo`05NmioogooNmig_@02Ool00g_NOomoo`05Ool017NmOomoogNm0goo00EkgWooOomo
og_N009oo`05MkeoogooOomkgP03Ool00g>LOomoo`03Ool00g_NOomoo`02Ool017NmOomoog_N0goo
00EkgWooOomoog_N00=oo`06NmioogooMkeoog_N17oo00IkgWooOomoogNmOol2Nmh2Ool00g_NOomo
o`02Ool01G_NOomoog_NMkd00Woo00=kgWooOol01Goo00Ag_GooOomg_@=oo`05NmioogooOomkgP02
Ool01GNmOomoogooNmh00goo00=cW7ooOol00goo00=kgWooOol00Woo00Ag_GooOomkgP=oo`05Nmio
ogooOomkgP03Ool01W_NOomoogNmOomkgPAoo`06NmioogooOomg_Goo0W_N0Woo00=kgWooOol00Woo
00EkgWooOomkgWNm009oo`03Nmioogoo00Eoo`04MkeoogooMkd3Ool01G_NOomoogooNmh00Woo00Eg
_GooOomoog_N00=oo`03Liaoogoo00=oo`03Nmioogoo009oo`04MkeoogooNmh3Ool01G_NOomoogoo
Nmh00Woo00=g_F]JOol0^goo003oOol=Ool01g_NOolU:EkgOomkgQcW00<00005IcUoog_N7>MNm`02
Ool031S600048@00G_Moog_N8@QS67_NOolQ20<00008IcUoog_N8@QS67_NOolU:@800006125JeWoo
MkdU:E[F0Woo00TQ2000000006<HOomkgRU:F]H00Woo00DQ20@Q0008@U[F009oo`097>MNmgooMkdU
:@@Q00048Ekg009oo`05:DYJeWooOolQ200200002@@QHaQoogoo9BUJeWooNmhLi`0300001FLiOomk
gQcWG_L00Woo00`HaP00124005kgOomkgR48HaQkgWoo8@P3000026LiOomkgR48HaQkgWoo9BT20000
1P@QF]IoogNm9BUJeP9oo`098@P00000001S67ooNmhYBU[F009oo`058@P48@00249JeP02Ool02AcW
G_MoogNm9BT48@00125Nm`02Ool01BU:F]Ioogoo8@P00P0000T48F<HOomoobDYF]Ioog_N7>L00`00
00EW>GooNmhLiekg009oo`0<6<H000@Q001NmgooNmhQ26<HNmioob480`0000QW>GooNmhQ26<HNmio
obDY0P0000H48E[FOomg_BDYF]H2Ool02B4800000000HaQoog_N:DYJeP02Ool01B48124000Q2F]H0
0Woo00TLiekgOomg_BDY124000@QG_L00Woo00DYBU[FOomoob4800800003249NmgNm0;]oo`00ogoo
ogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9o
o`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mo
oomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooB
Ool00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003o
OoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoo
dWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00
ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomo
om9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol0
0?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOooo
OooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo
003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogoo
ogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9o
o`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mo
oomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooB
Ool00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003o
OoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoo
dWoo003oOoooOooBOol00?mooomoom9oo`00ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00
ogooogoodWoo003oOoooOooBOol00?mooomoom9oo`00\
\>"],
  ImageRangeCache->{{{0, 719}, {539, 0}} -> {-0.00359504, 0.99648, 1.00001, \
1.00001}}],

Cell["The compartments has been numbered as follow: ", "Text"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "\<\"Plasma\"\>"},
          {"2", "\<\"RBC\"\>"},
          {"3", "\<\"ST0\"\>"},
          {"4", "\<\"ST1\"\>"},
          {"5", "\<\"ST2\"\>"},
          {"6", "\<\"Liver1\"\>"},
          {"7", "\<\"Liver2\"\>"},
          {"8", "\<\"UrinaryPath\"\>"},
          {"9", "\<\"OtherKidney\"\>"},
          {"10", "\<\"TrabecularSurface\"\>"},
          {"11", "\<\"ExchTrabVol\"\>"},
          {"12", "\<\"NonExchTrabVol\"\>"},
          {"13", "\<\"CorticalSurf\"\>"},
          {"14", "\<\"CorticalVolExch\"\>"},
          {"15", "\<\"CorticalVolNonExch\"\>"},
          {"16", "\<\"Bladder\"\>"},
          {"17", "\<\"Urine\"\>"},
          {"18", "\<\"ULI\"\>"},
          {"19", "\<\"LLI\"\>"},
          {"20", "\<\"FEC\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Text"],

Cell["\<\
Transfer rates are taken from Table A.12.1. (ICRP 78) (For GI compartments \
are applied the trasfer rate included in ICRP 30]).\
\>", "Text"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"Plasma to ST0\"\>", "\<\"k[1,3]->\"\>", "10.5`"},
          {"\<\"Plasma to RBC\"\>", "\<\"k[1,2]->\"\>", "0.245`"},
          {"\<\"Plasma to urinary bladder\"\>", "\<\"k[1,16]->\"\>", 
            "15.43`"},
          {"\<\"Plasma to Kidneys (urinary path)\"\>", "\<\"k[1,8]->\"\>", 
            "2.94`"},
          {"\<\"Plasma to other kidney tissue\"\>", "\<\"k[1,9]->\"\>", 
            "0.0122`"},
          {"\<\"Plasma to ULI contents\"\>", "\<\"k[1,18]->\"\>", "0.122`"},
          {"\<\"Plasma to liver 1\"\>", "\<\"k[1,6]->\"\>", "0.367`"},
          {"\<\"Plasma to ST1\"\>", "\<\"k[1,4]->\"\>", "1.63`"},
          {"\<\"Plasma to ST2\"\>", "\<\"k[1,5]->\"\>", "0.0735`"},
          {"\<\"Plasma to trabecular surface\"\>", "\<\"k[1,10]->\"\>", 
            "2.04`"},
          {"\<\"Plasma to cortical surfaces\"\>", "\<\"k[1,13]->\"\>", 
            "1.63`"},
          {"\<\"ST0 to plasma\"\>", "\<\"k[3,1]->\"\>", "8.32`"},
          {"\<\"RBC to Plasma\"\>", "\<\"k[2,1]->\"\>", "0.347`"},
          {"\<\"Kidneys (Urinary path) to urinary bladder\"\>", \
"\<\"k[8,16]->\"\>", "0.099`"},
          {"\<\"Other kidney tissue to plasma\"\>", "\<\"k[9,1]->\"\>", 
            "0.00038`"},
          {"\<\"Liver 1 to plasma\"\>", "\<\"k[6,1]->\"\>", "0.092`"},
          {"\<\"Liver 1 to liver2\"\>", "\<\"k[6,7]->\"\>", "0.00693`"},
          {"\<\"ST1 to plasma\"\>", "\<\"k[4,1]->\"\>", "0.0347`"},
          {"\<\"ST2 to plasma\"\>", "\<\"k[5,1]->\"\>", "0.000019`"},
          {"\<\"Cortical(Bone) surfaces to plasma\"\>", "\<\"k[13,1]->\"\>", 
            "0.0693`"},
          {"\<\"Cortical (Bone) surface to exch cortical volume\"\>", \
"\<\"k[13,14]->\"\>", "0.0693`"},
          {"\<\"Liver 2 to plasma\"\>", "\<\"k[7,1]->\"\>", "0.00019`"},
          {"\<\"Nonexch trab vol to plasma\"\>", "\<\"k[12,1]->\"\>", 
            "0.000493`"},
          {"\<\"Nonexch cort vol to plasma\"\>", "\<\"k[15,1]->\"\>", 
            "0.0000821`"},
          {"\<\"Cortical(Exch bone) vol to cortical (bone) surfaces\"\>", "\<\
\"k[14,13]->\"\>", "0.0173`"},
          {"\<\"Exch trabecular vol to nonexch trabecular vol\"\>", \
"\<\"k[11,12]->\"\>", "0.00578`"},
          {"\<\"Trabecular surface to plasma\"\>", "\<\"k[10,1]->\"\>", 
            "0.0693`"},
          {"\<\"Exch cortical vol to nonexch cortical vol\"\>", \
"\<\"k[14,15]->\"\>", "0.00578`"},
          {"\<\"Exch trabecular vol to trabecular surface\"\>", \
"\<\"k[11,10]->\"\>", "0.0173`"},
          {"\<\"Trabecular surface to Exchan. Trabecular vol.\"\>", \
"\<\"k[10,11]->\"\>", "0.0693`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Text"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"Bladder (16) to urine(17)\"\>", "\<\"k[16,17]->\"\>", "12"},
          {"\<\"ULI (18) to LLI(19)\"\>", "\<\"k[18,19]->\"\>", "1.8"},
          {"\<\"LLI (19) to FEC(20)\"\>", "\<\"k[19,20]->\"\>", "1"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Text"],

Cell["The transfer coefficients for uranium are the following     ", "Text"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(uraniumModel = {{1, 3, 10.5`}, {1, 2, 
          0.245`}, {1, 16, 15.43`}, {1, 8, 2.94`}, {1, 9, 0.0122`}, {1, 18, 
          0.122`}, {1, 6, 0.367`}, {1, 4, 1.63`}, {1, 5, 0.0735`}, {1, 10, 
          2.04`}, {1, 13, 1.63`}, {3, 1, 8.32`}, {2, 1, 0.347`}, {8, 16, 
          0.099`}, {9, 1, 0.00038`}, {6, 1, 0.092`}, {6, 7, 0.00693`}, {4, 1, 
          0.0347`}, {5, 1, 0.000019`}, {13, 1, 0.0693`}, {13, 14, 
          0.0693`}, {7, 1, 0.00019`}, {11, 12, 0.00578`}, {12, 1, 
          0.000493`}, {15, 1, 0.0000821`}, {14, 13, 0.0173`}, {14, 15, 
          0.00578`}, {10, 1, 0.0693`}, {11, 10, 0.0173`}, {10, 11, 
          0.0693`}, {16, 17, 12}, {18, 19, 1.8}, {19, 20, 
          1}}; \)\)\)], "Input",
  CellLabel->"In[93]:="],

Cell["\<\
The instant urine and faecal rate excrection for a single input 1 in \
compartment 1 can be evaluated as follow \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({qAcuteUrine[t_], \ qAcuteFaecal[t_]} = 
      D[{x\_17[t], \ x\_20[t]} /. 
          AcuteInput[CompartMatrix[20, uraniumModel], PadRight[{1}, 20]\ , \ 
            t, \ \ x], t]\)], "Input",
  CellLabel->"In[94]:="],

Cell[BoxData[
    \({\(-6.484613617692144`\)\ \[ExponentialE]\^\(\(-37.94948560700164`\)\ t\
\) + 3.953084447283053`\ \[ExponentialE]\^\(\(-12.`\)\ t\) + 
        2.5080052914141464`\ \[ExponentialE]\^\(\(-5.378003510238974`\)\ t\) \
+ 0.`\ \[ExponentialE]\^\(\(-1.8`\)\ t\) + 
        0.`\ \[ExponentialE]\^\(\(-1.`\)\ t\) + 
        0.0019478977353659284`\ \[ExponentialE]\^\(\(-0.34363683318187815`\)\ \
t\) + 1.4781569299126104`*^-32\ \[ExponentialE]\^\(\(-0.14818320752681727`\)\ \
t\) + 0.0029994770875514734`\ \[ExponentialE]\^\(\(-0.1388439316660916`\)\ \
t\) + 0.0005840636960558403`\ \[ExponentialE]\^\(\(-0.099`\)\ t\) + 
        0.014921999311429299`\ \[ExponentialE]\^\(\(-0.09727564424805021`\)\ \
t\) + 0.0021844405683457894`\ \[ExponentialE]\^\(\(-0.03219349814880698`\)\ t\
\) + 2.8931260428970465`*^-32\ \[ExponentialE]\^\(\(-0.013496792473182589`\)\ \
t\) + 0.000873762531068001`\ \[ExponentialE]\^\(\(-0.012583816550724035`\)\ t\
\) + 0.000010231337689305302`\ \
\[ExponentialE]\^\(\(-0.00048219329019067516`\)\ t\) + 
        2.761977633020772`*^-7\ \[ExponentialE]\^\(\(-0.00037973603767434393`\
\)\ t\) + 
        2.5256249269113317`*^-7\ \
\[ExponentialE]\^\(\(-0.00018974063918836685`\)\ t\) + 
        1.4025513903033542`*^-6\ \
\[ExponentialE]\^\(\(-0.00008066471443853456`\)\ t\) + 
        7.541579132873981`*^-8\ \[ExponentialE]\^\(\(-0.00001892428233107514`\
\)\ t\) + 0.`\ \[ExponentialE]\^\(0.`\ t\), 
      0.00014948719483443685`\ \[ExponentialE]\^\(\(-37.94948560700164`\)\ \
t\) + 0.`\ \[ExponentialE]\^\(\(-12.`\)\ t\) + 
        0.0012619446795848984`\ \[ExponentialE]\^\(\(-5.378003510238974`\)\ t\
\) - 0.013687718817788042`\ \[ExponentialE]\^\(\(-1.8`\)\ t\) + 
        0.012158277773956727`\ \[ExponentialE]\^\(\(-1.`\)\ t\) + 
        0.00003052454682865494`\ \[ExponentialE]\^\(\(-0.34363683318187815`\)\
\ t\) + 2.3821716184977877`*^-34\ \
\[ExponentialE]\^\(\(-0.14818320752681727`\)\ t\) + 
        0.00005601548390795326`\ \[ExponentialE]\^\(\(-0.1388439316660916`\)\ \
t\) + 0.`\ \[ExponentialE]\^\(\(-0.099`\)\ t\) + 
        0.000011478364256597591`\ \
\[ExponentialE]\^\(\(-0.09727564424805021`\)\ t\) + 
        0.000014132138957412616`\ \
\[ExponentialE]\^\(\(-0.03219349814880698`\)\ t\) + 
        1.8630072227272443`*^-34\ \[ExponentialE]\^\(\(-0.013496792473182589`\
\)\ t\) + 
        5.777364473501699`*^-6\ \[ExponentialE]\^\(\(-0.012583816550724035`\)\
\ t\) + 6.794404523969056`*^-8\ \[ExponentialE]\^\(\(-0.00048219329019067516`\
\)\ t\) + 
        1.8341975864271674`*^-9\ \
\[ExponentialE]\^\(\(-0.00037973603767434393`\)\ t\) + 
        1.6772871011553434`*^-9\ \
\[ExponentialE]\^\(\(-0.00018974063918836685`\)\ t\) + 
        9.314603200837936`*^-9\ \[ExponentialE]\^\(\(-0.00008066471443853456`\
\)\ t\) + 
        5.008547281364859`*^-10\ \
\[ExponentialE]\^\(\(-0.00001892428233107514`\)\ t\) + 
        0.`\ \[ExponentialE]\^\(0.`\ t\)}\)], "Output",
  CellLabel->"Out[94]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LogPlot[{qAcuteUrine[t], \ qAcuteFaecal[t]}, \ {t, \ 2, 10}]\)], "Input",\

  CellLabel->"In[95]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.119048 0.974391 0.215529 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[-0.0125 .0474 -46 -6.25 ]
[-0.0125 .0474 0 6.25 ]
[-0.0125 .11228 -40 -6.25 ]
[-0.0125 .11228 0 6.25 ]
[-0.0125 .26292 -40 -6.25 ]
[-0.0125 .26292 0 6.25 ]
[-0.0125 .32781 -34 -6.25 ]
[-0.0125 .32781 0 6.25 ]
[-0.0125 .47845 -34 -6.25 ]
[-0.0125 .47845 0 6.25 ]
[-0.0125 .54333 -28 -6.25 ]
[-0.0125 .54333 0 6.25 ]
[ -0.0005 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(4)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(6)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(8)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0474 m
.00625 .0474 L
s
gsave
-0.0125 .0474 -107 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00005) show
105.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11228 m
.00625 .11228 L
s
gsave
-0.0125 .11228 -101 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0001) show
99.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .26292 m
.00625 .26292 L
s
gsave
-0.0125 .26292 -101 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0005) show
99.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .32781 m
.00625 .32781 L
s
gsave
-0.0125 .32781 -95 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
93.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .47845 m
.00625 .47845 L
s
gsave
-0.0125 .47845 -95 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.005) show
93.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .54333 m
.00625 .54333 L
s
gsave
-0.0125 .54333 -89 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .02651 m
.00375 .02651 L
s
0 .06446 m
.00375 .06446 L
s
0 .07889 m
.00375 .07889 L
s
0 .09139 m
.00375 .09139 L
s
0 .10241 m
.00375 .10241 L
s
0 .17716 m
.00375 .17716 L
s
0 .21511 m
.00375 .21511 L
s
0 .24204 m
.00375 .24204 L
s
0 .27999 m
.00375 .27999 L
s
0 .29442 m
.00375 .29442 L
s
0 .30692 m
.00375 .30692 L
s
0 .31794 m
.00375 .31794 L
s
0 .39269 m
.00375 .39269 L
s
0 .43064 m
.00375 .43064 L
s
0 .45757 m
.00375 .45757 L
s
0 .49552 m
.00375 .49552 L
s
0 .50995 m
.00375 .50995 L
s
0 .52245 m
.00375 .52245 L
s
0 .53347 m
.00375 .53347 L
s
0 .60821 m
.00375 .60821 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.06244 .59996 L
.10458 .59653 L
.14415 .59339 L
.18221 .5904 L
.22272 .58726 L
.26171 .58427 L
.30316 .58112 L
.34309 .57812 L
.3815 .57526 L
.42237 .57225 L
.46172 .56937 L
.49955 .56663 L
.53984 .56374 L
.57861 .56098 L
.61984 .55807 L
.65954 .55528 L
.69774 .55263 L
.73838 .54982 L
.77751 .54715 L
.81909 .54432 L
.85916 .54162 L
.89771 .53904 L
.93871 .53631 L
.97619 .53383 L
s
.02381 .35643 m
.06244 .33354 L
.10458 .30725 L
.14415 .28198 L
.18221 .25762 L
.22272 .23204 L
.26171 .20814 L
.30316 .18386 L
.34309 .1619 L
.3815 .14235 L
.42237 .12344 L
.46172 .10719 L
.49955 .09338 L
.53984 .08056 L
.57861 .06992 L
.61984 .06023 L
.65954 .05225 L
.69774 .04562 L
.73838 .03949 L
.77751 .03432 L
.81909 .02944 L
.85916 .02522 L
.89771 .02151 L
.93871 .01785 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[95]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00=03oool4
000003L0oooo0`00000c0?ooo`<00000=`3oool2000003<0oooo1@0000020?ooo`8000000`3oool0
03@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0b0?ooo`040000003oool0oooo
000003D0oooo00@000000?ooo`3oool00000=03oool01@000000oooo0?ooo`3oool000000080oooo
0@0000010?ooo`40oooo000e0?ooo`030000003oool0oooo03D0oooo1@00000c0?ooo`040000003o
ool0oooo000003D0oooo00@000000?ooo`3oool00000=03oool01@000000oooo0?ooo`3oool00000
0080oooo0@0000010?ooo`40oooo000f0?ooo`030000003oool0oooo03@0oooo00@000000?ooo`3o
ool00000=03oool3000003L0oooo0P00000e0?ooo`050000003oool0oooo0?ooo`0000000P3oool1
00000040oooo0@3oool003@0oooo00@000000?ooo`3oool00000=P3oool00`000000oooo0000000e
0?ooo`030000003oool0oooo03D0oooo00@000000?ooo`3oool00000=03oool01@000000oooo0?oo
o`3oool000000080oooo0@0000010?ooo`40oooo000e0?ooo`800000>03oool2000003D0oooo0`00
000f0?ooo`800000=03oool2000000@0oooo0P0000030?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<03oooo_00000040oooo000`0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`040?oo
o`00<03oool00`000000oooo0?ooo`3]0?ooo`00<03oool00`000000oooo0?ooo`3R0?ooo`D00000
1P3oool00300oooo00<000000?ooo`3oool0f@3oool9000000/0oooo000`0?ooo`030000003oool0
oooo0<l0oooo2P00000D0?ooo`00<03oool200000<L0oooo2@00000N0?ooo`00<03oool00`000000
oooo0?ooo`2l0?ooo`X000009`3oool00300oooo00<000000?ooo`3oool0/P3oool:00000340oooo
00040?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00
00040?ooo`8000001P3oool00`000000oooo0?ooo`2Y0?ooo`T00000>`3oool000<0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool0X@3oool8000004@0oooo00030?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`03
0?ooo`<00000W@3oool4000004`0oooo00030?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000`3oool2000000H0oooo00<000000?ooo`3oool0V03oool50000
0500oooo00030?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo09@0oooo1000001E0?ooo`00
103oool2000000X0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`<00000
1@3oool00`000000oooo0?ooo`2?0?ooo`D00000F@3oool00300oooo0P00002;0?ooo`D00000GP3o
ool00300oooo00<000000?ooo`3oool0QP3oool4000006<0oooo000`0?ooo`030000003oool0oooo
08<0oooo0`00001W0?ooo`00<03oool200000840oooo0`00001Z0?ooo`00<03oool00`000000oooo
0?ooo`1m0?ooo`<00000K@3oool00300oooo00<000000?ooo`3oool0NP3oool300000700oooo000`
0?ooo`800000M`3oool4000007<0oooo000`0?ooo`030000003oool0oooo07<0oooo0`00001g0?oo
o`00<03oool00`000000oooo0?ooo`1`0?ooo`<00000NP3oool00300oooo0P00001^0?ooo`<00000
O@3oool000X0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000000`3o
ool5000000@0oooo00<000000?ooo`3oool0JP3oool300000800oooo00090?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool3000006P0oooo0P0000230?oo
o`002@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0IP3oool2000008D0oooo00090?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1T0?ooo`800000Q`3oool0
00T0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0640oooo0`0000290?ooo`002P3oool2000000X0oooo0P0000040?ooo`800000
103oool2000000@0oooo0P0000060?ooo`030000003oool0oooo05l0oooo0P00002<0?ooo`00<03o
ool00`000000oooo0?ooo`1L0?ooo`<00000SP3oool00300oooo00<000000?ooo`3oool0FP3oool2
00000940oooo000`0?ooo`030000003oool0oooo05P0oooo0P00002C0?ooo`00<03oool00`000000
oooo0?ooo`1F0?ooo`800000U@3oool00300oooo00<000000?ooo`3oool0E03oool2000009L0oooo
000`0?ooo`030000003oool0oooo0580oooo0P00002I0?ooo`00<03oool00`000000oooo0?ooo`1@
0?ooo`800000V`3oool00300oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`2K0?oo
o`00<03oool00`000000oooo0?ooo`1=0?ooo`800000WP3oool00300oooo00<000000?ooo`3oool0
B`3oool200000:00oooo000`0?ooo`030000003oool0oooo04T0oooo0P00002R0?ooo`00<03oool2
000004P0oooo0P00002T0?ooo`00<03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
0:@0oooo000`0?ooo`030000003oool0oooo04@0oooo0P00002W0?ooo`00<03oool00`000000oooo
0?ooo`120?ooo`800000Z@3oool00300oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`2Y0?ooo`00<03oool00`000000oooo0?ooo`0o0?ooo`800000[03oool00300oooo00<000000?oo
o`3oool0?@3oool200000:h0oooo000`0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool0[P3oool00300oooo00<000000?ooo`3oool0>P3oool200000;40oooo000`0?ooo`800000>@3o
ool200000;<0oooo000`0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0/`3oool0
0300oooo00<000000?ooo`3oool0=@3oool200000;H0oooo000`0?ooo`030000003oool0oooo03<0
oooo0P00002h0?ooo`00<03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0;P0oooo
000`0?ooo`030000003oool0oooo0300oooo0P00002k0?ooo`00<03oool200000300oooo00<00000
0?ooo`3oool0^`3oool00300oooo00<000000?ooo`3oool0;@3oool200000;h0oooo000`0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0_P3oool00300oooo00<000000?ooo`3oool0
:P3oool200000<40oooo000:0?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103o
ool2000000@0oooo0P0000060?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0`@3o
ool000T0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000005
0?ooo`<000009`3oool200000<@0oooo00090?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0<@0
oooo00090?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo0P0000060?ooo`030000003o
ool0oooo02@0oooo0P0000370?ooo`002@3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`370?oo
o`002P3oool2000000X0oooo0P0000040?ooo`800000103oool2000000@0oooo0`0000050?ooo`80
00008P3oool200000<X0oooo000`0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
bP3oool00300oooo00<000000?ooo`3oool07P3oool200000<d0oooo000`0?ooo`030000003oool0
oooo01`0oooo0P00003?0?ooo`00<03oool2000001`0oooo00<000000?ooo`3oool0c`3oool00300
oooo00<000000?ooo`3oool06@3oool200000=80oooo000`0?ooo`030000003oool0oooo01L0oooo
0P00003D0?ooo`00<03oool2000001L0oooo00<000000?ooo`3oool0e03oool00300oooo00<00000
0?ooo`3oool0503oool200000=L0oooo000`0?ooo`8000004`3oool200000=T0oooo000@0?ooo`80
0000103oool2000000@0oooo0P0000040?ooo`8000000`3oool5000000@0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`3I0?ooo`003`3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`04
0?ooo`<000003`3oool200000=`0oooo000?0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool03@3oool200000=h0oooo000?0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3N0?ooo`003`3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo0P00003Q0?ooo`00403oool2
000000X0oooo0P0000040?ooo`800000103oool2000000H0oooo00<000000?ooo`3oool0203oool2
00000><0oooo000`0?ooo`030000003oool0oooo00H0oooo0P00003U0?ooo`00<03oool00`000000
oooo0?ooo`040?ooo`800000i`3oool00300oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`3W0?ooo`00<03oool00`000000oooo0?ooo`3]0?ooo`00<03oool00`000000oooo0?ooo`3]
0?ooo`00<03oool00`000000oooo0?ooo`3]0?ooo`00<03oool00`000000oooo0?ooo`3]0?ooo`00
<03oool00`000000oooo0?ooo`3]0?ooo`00<03oool00`000000oooo0?ooo`3]0?ooo`00<03oool0
0`000000oooo0?ooo`3]0?ooo`00<03oool00`000000oooo0?ooo`3]0?ooo`00<03oool200000>h0
oooo000`0?ooo`030000003oool0oooo0>d0oooo000`0?ooo`030000003oool0oooo0>d0oooo000`
0?ooo`030000003oool0oooo0>d0oooo000`0?ooo`030000003oool0oooo0>d0oooo000`0?ooo`03
0000003oool0oooo0>d0oooo000`0?ooo`030000003oool0oooo0>d0oooo000`0?ooo`030000003o
ool0oooo0>d0oooo000`0?ooo`030000003oool0oooo0>d0oooo000`0?ooo`800000kP3oool00300
oooo00<000000?ooo`3oool0k@3oool00300oooo00<000000?ooo`3oool0k@3oool00300oooo00<0
00000?ooo`3oool0k@3oool00300oooo00<000000?ooo`3oool0k@3oool00300oooo00<000000?oo
o`3oool0k@3oool00300oooo0P00003^0?ooo`00<03oool00`000000oooo0?ooo`3]0?ooo`00<03o
ool00`000000oooo0?ooo`3]0?ooo`00<03oool00`000000oooo0?ooo`3]0?ooo`00403oool20000
00@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000060?ooo`030000003oool0oooo
0>d0oooo000?0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo0`00003]0?ooo`003`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0>d0oooo000?0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00030?ooo`8000001P3oool00`000000oooo0?ooo`3]0?ooo`003`3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0>d0oooo000@0?ooo`8000002P3oool2000000@0oooo
0P0000040?ooo`<000001@3oool200000>h0oooo000`0?ooo`030000003oool0oooo0>d0oooo000`
0?ooo`030000003oool0oooo0>d0oooo000`0?ooo`030000003oool0oooo0>d0oooo000`0?ooo`80
0000kP3oool00300oooo00<000000?ooo`3oool0k@3oool00300oooo00<000000?ooo`3oool0k@3o
ool00300oooo0P00003^0?ooo`00<03oool00`000000oooo0?ooo`3]0?ooo`00<03oool200000><0
oooo1@0000060?ooo`005P3oool2000000@0oooo0P0000040?ooo`8000000`3oool5000000@0oooo
00<000000?ooo`3oool0f@3oool9000000/0oooo000E0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0<H0
oooo4`00000D0?ooo`005@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0103oool300000;`0oooo2P00000W0?ooo`005@3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`2Y0?oooa<00000<@3oool001D0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0W`3o
ool:000004@0oooo000F0?ooo`8000002P3oool2000000@0oooo0P0000060?ooo`030000003oool0
oooo08d0oooo4P00001>0?ooo`00<03oool00`000000oooo0?ooo`230?ooo`X00000H03oool00300
oooo00<000000?ooo`3oool0L03ooolC000006X0oooo000`0?ooo`030000003oool0oooo06L0oooo
2@00001m0?ooo`00<03oool00`000000oooo0?ooo`1D0?oooa<00000QP3oool00300oooo00<00000
0?ooo`3oool0B`3oool9000009T0oooo000`0?ooo`030000003oool0oooo03P0oooo4`00002R0?oo
o`00<03oool00`000000oooo0?ooo`0^0?ooo`X00000]@3oool00300oooo00<000000?ooo`3oool0
9@3oool900000;l0oooo000`0?ooo`030000003oool0oooo0180oooo4`0000380?ooo`00<03oool0
0`000000oooo0?ooo`080?ooo`X00000f`3oool00300oooo00<000000?ooo`3oool00`3oool50000
0>D0oooo000`0?ooo`800000kP3oool00300oooo00<000000?ooo`3oool0k@3oool00300oooo00<0
00000?ooo`3oool0k@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.0692856, -4.93097, \
0.0353406, 0.0195205}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[95]="]
}, Open  ]],

Cell["\<\
The same problem asuming a constant intake (chronic) an single input 1 in \
compartment 1 can be evaluated as follow \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({qConstantUrine[t1_], \ qConstantFaecal[t1_]} = 
      D[{x\_17[t1], \ x\_20[t1]} /. 
          SystemDSolve[CompartMatrix[20, uraniumModel], PadRight[{0}, 20]\ , 
            PadRight[{1}, 20], \ t, \ t1, \ x], \ t1]\)], "Input",
  CellLabel->"In[96]:="],

Cell[BoxData[
    \({\(\(0.9934025524551127`\)\(\[InvisibleSpace]\)\) + 
        0.1708748752182227`\ \[ExponentialE]\^\(\(-37.94948560700164`\)\ t1\) \
- 0.3294237039402544`\ \[ExponentialE]\^\(\(-12.`\)\ t1\) - 
        0.46634504545027744`\ \[ExponentialE]\^\(\(-5.378003510238974`\)\ \
t1\) - 0.0056684777278661405`\ \[ExponentialE]\^\(\(-0.34363683318187815`\)\ \
t1\) - 0.02160322782248037`\ \[ExponentialE]\^\(\(-0.1388439316660916`\)\ \
t1\) - 0.005899633293493335`\ \[ExponentialE]\^\(\(-0.099`\)\ t1\) - 
        0.15339913116770126`\ \[ExponentialE]\^\(\(-0.09727564424805021`\)\ \
t1\) - 0.0678534702332974`\ \[ExponentialE]\^\(\(-0.03219349814880698`\)\ \
t1\) - 0.06943541552326009`\ \[ExponentialE]\^\(\(-0.012583816550724035`\)\ \
t1\) - 0.021218332767051762`\ \[ExponentialE]\^\(\(-0.00048219329019067516`\)\
\ t1\) - 0.000727341458012843`\ \[ExponentialE]\^\(\(-0.00037973603767434393`\
\)\ t1\) - 
        0.0013310932954136376`\ \[ExponentialE]\^\(\(-0.00018974063918836685`\
\)\ t1\) - 
        0.01738742150227383`\ \[ExponentialE]\^\(\(-0.00008066471443853456`\)\
\ t1\) - 0.003985133491952888`\ \[ExponentialE]\^\(\(-0.00001892428233107514`\
\)\ t1\), \(\(0.0065974475448842525`\)\(\[InvisibleSpace]\)\) - 
        3.9391099100130255`*^-6\ \[ExponentialE]\^\(\(-37.94948560700164`\)\ \
t1\) - 0.0002346492852193812`\ \[ExponentialE]\^\(\(-5.378003510238974`\)\ t1\
\) + 0.0076042882321044674`\ \[ExponentialE]\^\(\(-1.8`\)\ t1\) - 
        0.012158277773956727`\ \[ExponentialE]\^\(\(-1.`\)\ t1\) - 
        0.0000888279249520935`\ \[ExponentialE]\^\(\(-0.34363683318187815`\)\ \
t1\) - 0.0004034420751111108`\ \[ExponentialE]\^\(\(-0.1388439316660916`\)\ \
t1\) - 0.00011799833704856354`\ \[ExponentialE]\^\(\(-0.09727564424805021`\)\ \
t1\) - 0.00043897494121608284`\ \[ExponentialE]\^\(\(-0.03219349814880698`\)\ \
t1\) - 0.0004591106720456193`\ \[ExponentialE]\^\(\(-0.012583816550724035`\)\ \
t1\) - 0.00014090624366179636`\ \[ExponentialE]\^\(\(-0.00048219329019067516`\
\)\ t1\) - 
        4.830190986508761`*^-6\ \[ExponentialE]\^\(\(-0.00037973603767434393`\
\)\ t1\) - 
        8.839893806250966`*^-6\ \[ExponentialE]\^\(\(-0.00018974063918836685`\
\)\ t1\) - 
        0.00011547308219798557`\ \
\[ExponentialE]\^\(\(-0.00008066471443853456`\)\ t1\) - 
        0.00002646624687658795`\ \
\[ExponentialE]\^\(\(-0.00001892428233107514`\)\ t1\)}\)], "Output",
  CellLabel->"Out[96]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LogPlot[{qConstantUrine[t], \ qConstantFaecal[t]}, \ {t, \ 2, 
        100}]\)], "Input",
  CellLabel->"In[97]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.603319 0.240349 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -6 -9 ]
[.21429 -0.0125 6 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[-0.0125 .05027 -34 -6.25 ]
[-0.0125 .05027 0 6.25 ]
[-0.0125 .12262 -28 -6.25 ]
[-0.0125 .12262 0 6.25 ]
[-0.0125 .29062 -28 -6.25 ]
[-0.0125 .29062 0 6.25 ]
[-0.0125 .36297 -22 -6.25 ]
[-0.0125 .36297 0 6.25 ]
[-0.0125 .53097 -22 -6.25 ]
[-0.0125 .53097 0 6.25 ]
[-0.0125 .60332 -10 -6.25 ]
[-0.0125 .60332 0 6.25 ]
[ -0.0005 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(20)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(40)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(60)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(80)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(100)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .05027 m
.00625 .05027 L
s
gsave
-0.0125 .05027 -95 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.005) show
93.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12262 m
.00625 .12262 L
s
gsave
-0.0125 .12262 -89 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .29062 m
.00625 .29062 L
s
gsave
-0.0125 .29062 -89 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
87.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .36297 m
.00625 .36297 L
s
gsave
-0.0125 .36297 -83 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .53097 m
.00625 .53097 L
s
gsave
-0.0125 .53097 -83 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
81.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -71 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .02698 m
.00375 .02698 L
s
0 .0693 m
.00375 .0693 L
s
0 .08539 m
.00375 .08539 L
s
0 .09933 m
.00375 .09933 L
s
0 .11162 m
.00375 .11162 L
s
0 .19497 m
.00375 .19497 L
s
0 .2373 m
.00375 .2373 L
s
0 .26733 m
.00375 .26733 L
s
0 .30965 m
.00375 .30965 L
s
0 .32574 m
.00375 .32574 L
s
0 .33968 m
.00375 .33968 L
s
0 .35197 m
.00375 .35197 L
s
0 .43532 m
.00375 .43532 L
s
0 .47765 m
.00375 .47765 L
s
0 .50767 m
.00375 .50767 L
s
0 .55 m
.00375 .55 L
s
0 .56609 m
.00375 .56609 L
s
0 .58003 m
.00375 .58003 L
s
0 .59232 m
.00375 .59232 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.04286 .56106 m
.06129 .56614 L
.08072 .57036 L
.1021 .57403 L
.12201 .57678 L
.15931 .58068 L
.19752 .58354 L
.23814 .58575 L
.27727 .58735 L
.31491 .58855 L
.35496 .58957 L
.39353 .59038 L
.43061 .59104 L
.47009 .59164 L
.50808 .59214 L
.54848 .5926 L
.5874 .593 L
.62483 .59335 L
.66466 .59368 L
.70301 .59397 L
.74376 .59425 L
.78302 .5945 L
.8208 .59472 L
.86099 .59493 L
.89968 .59512 L
.9369 .5953 L
.97619 .59546 L
s
.04286 .01472 m
.04506 .02285 L
.04741 .0296 L
.04945 .03421 L
.05165 .03822 L
.05425 .04192 L
.0567 .04465 L
.06129 .04836 L
.06362 .04974 L
.06619 .05098 L
.07139 .05285 L
.07621 .05407 L
.08072 .05495 L
.09111 .05641 L
.10061 .05739 L
.12201 .05909 L
.16093 .06132 L
.19836 .06289 L
.23819 .06419 L
.27654 .06519 L
.31729 .06608 L
.35655 .06681 L
.39433 .06742 L
.43451 .06799 L
.47321 .06848 L
.51042 .06891 L
.55004 .06932 L
.58817 .06969 L
.6287 .07004 L
.66775 .07034 L
.70532 .07062 L
.74528 .07088 L
.78376 .07112 L
.82076 .07133 L
.86016 .07153 L
.89807 .07172 L
.93839 .0719 L
.97619 .07206 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[97]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00:@3oool2
000002T0oooo100000030?ooo`800000:03oool300000080oooo0P00000V0?ooo`<00000103oool2
000002L0oooo0P0000040?ooo`800000903oool500000080oooo0P0000040?ooo`8000000`3oool0
02P0oooo00@000000?ooo`3oool00000:03oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000002P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0S0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000009@3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000002D0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo0@0000010?ooo`40oooo000X0?ooo`040000003oool0oooo000002T0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000U0?ooo`D0000000D0oooo0000
003oool0oooo0000000U0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
9@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo0@0000010?ooo`40oooo000X
0?ooo`040000003oool0oooo000002X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo02<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000U0?oo
o`<000000`3oool010000000oooo0?ooo`00000V0?ooo`8000000`3oool010000000oooo0?ooo`00
000U0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`40
00000@3oool10?ooo`00:03oool010000000oooo0?ooo`00000X0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000009P3oool00`000000oooo000000020?ooo`040000003oool0
oooo000002H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000U0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000009@3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool100000040oooo0@3oool002T0oooo0P00000Z
0?ooo`800000103oool2000002P0oooo0P0000030?ooo`8000009`3oool3000000<0oooo0P00000W
0?ooo`800000103oool2000002D0oooo0P0000040?ooo`800000103oool2000000<0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo000U0?ooooL00000103oool002D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool01`3oool002D0oooo00<0
00000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3^
0?ooo`009@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0>h0oooo000U0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0k@3oool002D0oooo0P0000090?ooo`030000
003oool0oooo0>d0oooo000U0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0k@3o
ool002D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3/0?ooo`009@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0>`0oooo00040?ooo`800000103oool2000000@0
oooo0P0000040?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`3[0?ooo`000`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`030000003o
ool0oooo00/0oooo0P00003[0?ooo`000`3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`040?ooo`80
00003@3oool200000>X0oooo00030?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000030?ooo`8000001`3oool00`000000oooo0?ooo`0>
0?ooo`H00000i03oool000<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0D0?ooo``00000f03oool000@0oooo0P00000:0?ooo`800000103oool2000000@0oooo0`00
00060?ooo`030000003oool0oooo0200oooo7000002l0?ooo`009@3oool00`000000oooo0?ooo`0l
0?ooocX00000PP3oool002D0oooo0P00001g0?ooogT000002@3oool002D0oooo00<000000?ooo`3o
ool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03o
ool002D0oooo0P00003i0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool00`000000
oooo0?ooo`3h0?ooo`009@3oool200000?T0oooo000U0?ooo`030000003oool0oooo0?P0oooo000U
0?ooo`030000003oool0oooo0?P0oooo000U0?ooo`800000n@3oool000X0oooo0P0000040?ooo`80
0000103oool2000000<0oooo1@0000050?ooo`030000003oool0oooo0?P0oooo00090?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0?P0oooo00090?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`050?ooo`800000n@3oool000T0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0n03oool000T0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0n03oool000X0oooo0P00
000:0?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool0n03oool002D0oooo00<00000
0?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3o
ool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03o
ool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0
oooo00<000000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<0
00000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<000000?oo
o`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0
n03oool002D0oooo0P00003i0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool00`00
0000oooo0?ooo`3h0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool00`000000oooo
0?ooo`3h0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool00`000000oooo0?ooo`3h
0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`00
9@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool200000?T0oooo000U0?ooo`030000003oool0
oooo0?P0oooo000U0?ooo`030000003oool0oooo0?P0oooo000U0?ooo`030000003oool0oooo0?P0
oooo000U0?ooo`030000003oool0oooo0?P0oooo000U0?ooo`030000003oool0oooo0?P0oooo000U
0?ooo`030000003oool0oooo0?P0oooo000U0?ooo`800000n@3oool002D0oooo00<000000?ooo`3o
ool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03o
ool002D0oooo00<000000?ooo`3oool0n03oool000X0oooo0P0000040?ooo`800000103oool20000
00@0oooo0P0000070?ooo`030000003oool0oooo0?P0oooo00090?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`800000n@3o
ool000T0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0n03oool000T0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000030?ooo`8000001`3oool00`000000oooo0?ooo`3h0?ooo`00
2@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`3h0?ooo`002P3oool2000000X0oooo0P0000040?ooo`<0
00001P3oool00`000000oooo0?ooo`3h0?ooo`009@3oool200000?T0oooo000U0?ooo`030000003o
ool0oooo0?P0oooo000U0?ooo`030000003oool0oooo0?P0oooo000U0?ooo`030000003oool0oooo
0?P0oooo000U0?ooo`800000n@3oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<0
00000?ooo`3oool0n03oool002D0oooo0P00003i0?ooo`009@3oool00`000000oooo0?ooo`3h0?oo
o`009@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool200000?T0oooo000U0?ooo`030000003o
ool0oooo0?P0oooo000@0?ooo`800000103oool2000000<0oooo1@0000050?ooo`030000003oool0
oooo0?P0oooo000?0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool01@3oool2
00000?T0oooo000?0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`3h0?ooo`003`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0n03oool000l0oooo00@000000?ooo`3oool000002P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0?P0oooo000@0?ooo`8000002P3oool20000
00L0oooo00<000000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo
00<000000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<00000
0?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3o
ool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03o
ool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0
oooo00<000000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<0
00000?ooo`3oool0n03oool002D0oooo0P00003i0?ooo`009@3oool00`000000oooo0?ooo`3h0?oo
o`009@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`009@3o
ool00`000000oooo0?ooo`3h0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool00`00
0000oooo0?ooo`3h0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool00`000000oooo
0?ooo`3h0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool200000?T0oooo000U0?oo
o`030000003oool0oooo0?P0oooo000U0?ooo`030000003oool0oooo0?P0oooo000U0?ooo`030000
003oool0oooo0?P0oooo000U0?ooo`030000003oool0oooo0?P0oooo000U0?ooo`030000003oool0
oooo0?P0oooo000U0?ooo`030000003oool0oooo0?P0oooo000U0?ooo`030000003oool0oooo0?P0
oooo000U0?ooo`800000n@3oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<00000
0?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03oool00100oooo0P0000040?ooo`80
0000103oool2000000L0oooo00<000000?ooo`3oool0n03oool000l0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?P0oooo000?0?ooo`04
0000003oool0oooo000000/0oooo00<000000?ooo`3oool0103oool200000?T0oooo000?0?ooo`04
0000003oool0oooo000000T0oooo0P0000070?ooo`030000003oool0oooo0?P0oooo000?0?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3h0?oo
o`00403oool2000000X0oooo0`0000060?ooo`030000003oool0oooo0?P0oooo000U0?ooo`800000
n@3oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03oool0
02D0oooo00<000000?ooo`3oool01`3oool300000>h0oooo000U0?ooo`8000002`3oool500000>T0
oooo000U0?ooo`030000003oool0oooo00l0oooo1@00003T0?ooo`009@3oool00`000000oooo0?oo
o`0D0?ooo`D00000g`3oool002D0oooo00<000000?ooo`3oool06@3oool700000=P0oooo000U0?oo
o`8000008@3oool900000<l0oooo000U0?ooo`030000003oool0oooo02T0oooo7@00002b0?ooo`00
9@3oool00`000000oooo0?ooo`160?ooobH00000S03oool002D0oooo0P00001]0?oooh<000002@3o
ool001/0oooo1@0000050?ooo`030000003oool0oooo0?P0oooo000M0?ooo`030000003oool0oooo
00D0oooo0P00003i0?ooo`007@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?P0
oooo000M0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0n03oool001d0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`3h0?ooo`00703oool2000000L0oooo00<00000
0?ooo`3oool0n03oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-18.2788, -2.79577, \
0.425465, 0.016859}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[97]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[uraniumModel, qAcuteUrine, \ qAcuteFaecal, \ qConstantUrine, \ 
      qConstantFaecal]; \)], "Input",
  CellLabel->"In[98]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Variable clearances", "SubsectionIcon"],

Cell[TextData[{
  "\n",
  Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0002gP0@0005P0000400000`000?X000090@00
00000000000F6@00gaX00215CDH00040h2d00;@000090000000000000000000080<005P2003C0000
WP0004H000342P00^0X004M4BD<1002000<00?<eFF000000X0X000402@000dL5000:01D0000001@0
000V1Pl07P3ooooo100D0000EfmbI0h0CFUSLVmcKfId85M_LV@500002`8000001@0000`2c`>>0`d0
003k0P00000000000000000000000@0<100002d1000400000P4100D000090P00008E0000n`;4o`00
00000901000000A0019DJFeULb1>IGLPDVm]HFh0H0040000;@4100<0000N00L0000F1<l3SP<00000
400002H63`0F0?ooool00?ooooooooooU0<00=03000300007P040000;P4000D0000:0P0000050000
2@8000001@000042oooo00L0003l0P4000000000100002d10P090000nP850000003oool08P040000
;@4300@000030@P01`000184c`??0hh3T`<500002`8000001@0000`2aP2j00D0000<0/H0^P040000
104=00@0000^0AP0100000810@0500002@8000001@000042oooo00<0000N00@000040@L05@000?/2
l_l00000002l0P000004000@E6U]IG<PCVEg859_KF5^01D0100002d1100500002`;ooooo1`000245
0@0b01X0I`0700005PC30;L0000000@000040@d01`000?`20@00000000040000;@4500T0003j0PH0
0@000000000R00@0000]0@H01`0001/4:P210040DP0700008@D10340G`1V00L0000K16l0P0160540
2P0002H63`0:0?ooool0000000070000o0800000000000@0000]0@L02@000?X21@000000oooo0280
100002d1200<000090<406h0A`1Z03`0LP0l06h0A`040000;@4600D0000D0RX0KP0500004`9406h0
2P0002H63`0:0?ooool10000000E0000n`;do`0000000901000000@0011DJFeULb1>IGLPDVm]HFh0
M@040000;@4900@0003`0@@01`0002450@1;03X0BP0E0000n`;go`0000000901000000@0011DJFeU
Lb1>IGLPDVm]HFh05@040000;@4400@0003`0@T01`0002450P0a<T00DP0E0000n`;do`0000000901
000000@0011DJFeULb1>IGLPDVm]HFh0M@040000;@4900@0003`0@@01`0002450@1;03X0MP0E0000
n`;go`0000000901000000@0011DJFeULb1>IGLPDVm]HFh05@040000;@4400@0003`0@T01`000245
0P0b<D00OP0E0000n`;do`0000000901000000@0011DJFeULb1>IGLPDVm]HFh0M@040000;@4900@0
003`0@@01`0002450@1403X0WP0E0000n`;go`0000000901000000@0011DJFeULb1>IGLPDVm]HFh0
5@040000;@4400@0003`0@T01`0002450P1YMSh0YP0:00009PH?00X0ooooo`00000000@0000]0@P0
300002@3101S02X0I`0e05l0=@1S02X0100002d11P050000508/06<01@0001<2AP1S00X0000V1Pl0
2P3ooooo0@0000002P0002H63`0:0?ooool0000000040000;@4800`0000T0`@0X01G09D0F`2E05<0
X01G00@0000]0@H01@0001@2E`2000D0000C0UL0W@0:00009PH?00X0ooooo`40000001D0003k0_Co
00000000T0400000100045AYKFEc84iUMb1BKfeQKP1e00@0000]0@T010000?01100700008@D104/0
H`2301D0003k0_Oo00000000T0400000100045AYKFEc84iUMb1BKfeQKP0E00@0000]0@@010000?01
2@0700008@D2034`J@2;00X0000V1Pl02P3ooooo00000000100002d1200<000090<402l0E`0j05<0
>P1K02l0E`040000;@4600D0000D0UL0D@0500004`9G03402P0002H63`0:0?ooool10000000E0000
n`;do`0000000901000000@0011DJFeULb1>IGLPDVm]HFh0M@040000;@4900@0003`0@@01`000245
0@1;0680?@0E0000n`;go`0000000901000000@0011DJFeULb1>IGLPDVm]HFh05@040000;@4400@0
003`0@T01`0002450@0a06H0AP0700008@D106L0IP1;00@0000]0@D01`0001/4K`0a04H00P0E0000
n`;bo`0000000;`2000000@0011DJFeULb1>IGLPDVm]HFh0M@040000;@4900@0003`0@@02@000245
1@12JFaYL`1O00X02P0002H63`0:0?ooool0000000040000;@4700@0000]0@P0300002@3100G09T0
4`2>01/0SP0G09T0100002d11P050000509^01L01@0001<2UP0G00X0000V1Pl02P3ooooo0@000000
100002d11@0700006`C00340U`0200L0000Q1@80AfV`00l02P0002H63`0:0?ooool0000000040000
;@4700@0000]0@P0300002@3101Z06l0IP1j0600M01Z06l0100002d11P050000509`06P01@0001<2
[00a00X0000V1Pl02P3ooooo0@0000005@000?/2m?l00000002@0@000004000@E6U]IG<PCVEg859_
KF5^01D0100002d110040000l04900L0000Q1@40B`2903d05@000?/2mol00000002@0@000004000@
E6U]IG<PCVEg859_KF5^07D0100002d12@040000l04400L0000Q1@40H@2<04H0100002d11@070000
60B401d0N@0B00D0000D0WD07`0500004`:600l02P0002H63`0:0?ooool0000000040000;@4700@0
000]0@P0300002@3102204`0R@1308d0B`2204`0100002d11P050000509508`01@0001<2BP2300X0
000V1Pl02P3ooooo0@0000001`000?`2003oool000040000;@4400@0000]0@P0400002@31P2<04D0
T`140900?`2I0440U@0k09`0>P040000;@460100000U0`H0S01509<0A02@03l0V@1109D0>`2L03X0
400002D31P2<04D0T`140900?`2I0440U@0k09`0>P0400009`7oo`@0003`0@D010000?0120040000
;@4400T0003j0P0000000000000R00@0000]0@D0100002L1ool800009PH?00H0ooooo`40100002L1
ool=0000<PZI0i<30@040000002>0ll3800K00@0000]0@000`000000oooooooooooooooooooooooo
4@0000`0000800002`000100003c00001@4000T0000@0000l`0000D1000:00004000000000000000
2@000100002>0`00c`<00180000<00000@0001P0000<000000000U80001<0@000@000<Coool00000
00000000002@0@00000000A0019D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP0000L71`L71`L7
1`L71`L71`L71`L71`L71`L71`L71`000000000000071`L71`L71`L71`L71`L71`L71`L71`L71`L7
1`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L7
1`L71`L71`L71`L71`L71`L71`L71`L70?l71`L71`L000L71`L71`L71`L71`L71`L71`L71`L71`L7
1`L7n0L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L700000000000000000000000000000000
0@410@410@410@L79@0000`0000100008@0000P0000N00006000000000000000SP<00<l3000Q0000
200001P0000<000000000140000<0000200001l0000H0000T`<008h3003?0`00c`<000X0000@0000
000000000009000040000;X0003600002@000100002j0000aP0001H0000<0000600002H0000L0000
0P0000D00000000000000?ooo`0U000030000080000W0000600000<00001000000000000000U0000
300000<0000Q0000200001@0000<00001`0000X0000@0000oooooooooomB0000C04000@0003boooo
0000000000000000_08000000004000@E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h000071`L7
1`L71`L71`L71`Oh1`000?ooool71`L71`L000001`L71`L71`L71`L71`L71`L71`L71`L71`L71`L7
1`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L7
1`L71`L71`L71`L700L71`L71`L01`L71`L71`L71`L71`L700071`L71`L71`L71`L71`L71`L71`L7
1`L71`L71`L71`L71`L71`L71`L71`L71`L71`L0000000001`L71`00000000000000000000000000
000000410@410@410@471bD0000<0000100005@0001D0000R00002@0002@0000=`000040003II@Y2
M14;@VL0000J00000@0004`000000000000000000000000000000500000b00L71`0001h0000H0000
00000000002g0000``0001@0000<00003@0002H0000L00001@0000H00001000000000000000U0000
300000D0000W0000600000H00001000000000000000U0000300000H0000[00006000058000010000
P@0002T0001D0000E00008L0001o0000S`00098000010000fFD:@W@A2d9V0000G`000040001<0000
000000000000000000000000001@0000<@3oo`L0000[00006000054000160000O`0006l0000V0000
700000L00005000000000000003oool09@0000`0000700009@0000`000040020EP0002`0002<0000
D00009L0001O0000100006h0A`1Z03`0LP0l06h0A`0K0000400006h0000Z00009@0000`000050000
=P000100001^0000A0000580001<0@0020000?Coool0000000000000002@0@00000000@0011D06T0
K@1U07<0801>06D0M`0P0580K`1]0640KP000?Shn?Shn?Shn?Shn?Shn?Shn?Shn?Shn?Shn03oo`00
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool00?ooooooooooooooooooooooooooooooZ?4000000?Shn?Shn?Shn?Shn?Shn?Shn?Sh
n?Shn?Shn?Shn?P0000000000000000000000000000000000@410@410@410Ooo9@0000`000080000
:00000`0000400009@0000`000080000E00005@0001R0000CP0006d0001P00000@000=UU2T9d4@]2
BP0003X000010000C0000000000000000000000000000000D00004/0ool90000DP0004`100040000
moooo`00000000000000090100000000100045@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^0000
oooooooooooooooooooooooooooooooooooooooo00000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool000000000n?Shn?Shn?Shn?Shn?Shn?Shn?Shn?Shn?Shn000n03ooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool000000000000000000000
0000000000010@410@410@41oolU0000300000@0000X0000300000P0000U0000300000@0001D0000
F00006d0001F0000N00006@000010000fFD:@W@A2d9B0000@0000080001<00000000000000000000
00000000001@0000<@0b00@000050000DP0004`100080000m?ooo`00000000000000090100000000
100045@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^0000oooooooooooooooooooooooooooooooo
oooooooo00000?ooooooooooooooooooooooooooooooooooo`000000003hn?Shn?Shn?Shn?Shn?Sh
n?Shn?Shn?Shn?Shn?Sh0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`00ooooooooooooooooooooooooooooooooooooooooooooo`L71`L71`Oo
1`L71oSo1`L71`L71`0000000000000000000000000000000000000000010@410@410@41oolU0000
300000P0000X0000300000@0000U0000300000P0001D0000E00009`0001>0000Y`00060000010000
fFD:@W@A2d9f0000>P000040001<0000000000000000000000000000001@0000B`3oo`T0001B0000
C04000@0003goooo0000000000000000T04000000004000@E01Y06d0I@1c0200CP1U07L0801B06l0
K@1Q06h0003oooooooooooooooooooooooooooooooooooooool00000oooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`L71`L71`L71`Oo1`L71ooo
oooooooooooooooooooooooooooo1`L71`L71`L71ol71`L7n?l71`L71`L7000000000?oooooooooo
ooooooooooooooooooooool71`L7ooooooooooooooooooooooooooooooooooooooooo`0000000000
0000000000000000000000410@410@410@7oobD0000<0000100002P0000<0000200002D0000<0000
100005@0001H0000Y`0005H0002b0000I0000040003II@Y2M14;@Wh0001000000P0004`000000000
000000000000000000000500000b0340100000D0001B0000C04000P0003doooo0000000000000000
T04000000004000@E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h000071`L71`L71`L71`L71`L7
1`L71`L71`L71`L71`L000001`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L7
1`L71`L71`Oho`L71`L71`L0000000001`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L7
1`L71`L71`L71`L71`L71`L71`L71`L700071`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L7
1`L71`L71`L71`L71`L71`L71`L71`L71`L71`00000000000000000000000000000000410@410@41
0@471bD0000<0000200002P0000<0000100002D0000<0000200005@0001D0000d@0004h0003K0000
H0000040003II@Y2M14;@Yh0000j00000@0004`000000000000000000000000000000500001400L7
20000580001<0@0010000?Ooool0000000000000002@0@00000000@0011D06T0K@1U07<0801>06D0
M`0P0580K`1]0640KP0000L71`L71`L71`L71`L71`L71`L71`L71oSo1`L71`000000000000071`L7
1`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L7
1`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L000L7
1`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L7
000000000000000000000000000000000@410@410@410OSh9@0000`000040000:00000`000080000
9@0000`000040000E00005P0003K0000D`000><0001Q00000@000=UU2T9d4@]2YP0003h000020000
C0000000000000000000000000000000D00006T0MP0200001@0002D0000<00001`0005H0000/0000
OP0003T000280000A`0000@0001S02X0I`0e05l0=@1S02X06`000100001S0000;00002D0000<0000
1@0003H0000@0000H`0004H0000U0000300000L0001F0000;0000<D0001_0000d`0007T000040000
X01G09D0F`2E05<0X01G01/0000@0000P00005L0000U0000300000D0000f0000400009d0001G0000
DP0004`100080000m?ooo`00000000000000090100000000100045@0J@1]06D0L`0P04h0I@1g0200
DP1_06d0H@1^00000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
1`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L00000
00000000000000000000000000010@410@410@411`LU0000300000P0000X0000300000@0000U0000
300000P0001D0000E0000:d000240000^00009H000010000fFD:@W@A2d:30000H`000040001<0000
000000000000000000000000001@0000B`071`T0001B0000C04000@0003goooo0000000000000000
T04000000004000@E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h000071`L71`L71`L71`L71`L7
1`L71`L71`L71`L71`L000001`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L7
1`L71`L71`L71`L71`L71`L71`L71`L71`00000000071`L71`L71`L71`L71`L71`L71`L71`L71`L7
1`L71`L71`L71`L71`L71`L71`L71`L700071`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L7
1`L71`L71`L71`L71`L71`L71`L71`L700000000000000000000000000000000000000410@410@41
0@471bD0000<0000100002P0000<0000200002D0000<0000100005@0001H0000^00008`000330000
VP000040003II@Y2M14;@X/0001Y00000P0004`000000000000000000000000000000500000a0300
100000D0000U0000300000L0001F0000;00003l0001_0000C@0007T000040000;`1G03X0D`0j05/0
;`1G01/0000@0000D@0005L0000U0000300000D0000f000040000340001G0000DP0004`100080000
m?ooo`00000000000000090100000000100045@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^0000
1`L71`L71`L71`L71`L71`L71`L71`L71`L71`L7000000L71`L71`L71`L71`L71`L71`L71`L0o`L7
1`L71`071`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L7
1`L71`L71`L71`L71`00000000071`L71`L71`L71`L71`L71`L71`001`L71`L71`L71`Ohn?Shn?Sh
n?Shn?Shn?Shn?Shn?Shn?Shn?Shn?Shn?Shn?Shn?Shn?Shn?Shn?Shn?P000000000000000000000
0000000000010@410@410@411`LU0000300000P0000X0000300000@0000U0000300000P0001D0000
E000054000230000G00009D000010000fFD:@W@A2d8m0000HP000040001<00000000000000000000
00000000001@0000B`3hn0T0001B0000C04000@0003goooo0000000000000000T04000000004000@
E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h000071`L0oooooooooooooooooooooooooooooooo
ool00000oooooooooooooooooooooooooooooooooooooooooooooooooooo0000000000L71`L71`L7
1`L71`L71`L71`L71`L71`L71`L71`L71oShn?Shn?Shn?Shn?Shn?Shn?Shn?Shn?Shn?Shn?Shn?Sh
n?Shn?Shn?Shn?Sh003hn?Shn?Shn?Shn?Shn?Shn?Shn?Shn?Shn?Shn?Shn03o1`L0oooooooooooo
ooooooooooooooooooooo`00000000000000000000000000000000410@410@410@7oobD0000<0000
100002P0000<0000200002D0000<0000100005@0001D0000G@0008P0001R0000UP000040003II@Y2
M14;@TH0001V00000@0004`000000000000000000000000000000500000a0?Sh1@0005@0001D0000
I00008P0001X0000UP000040003II@Y2M14;@T/0001V00000@0004`0000000000000000000000000
00000500001W0?oo100002D0000<00001P0002/0000H00000P0004H0000a0000K`000580001<0@00
20000?;oool0000000000000002l0P00000000@0011D06T0K@1U07<0801>06D0M`0P0580K`1]0640
KP000?Sh0?Shn?Shn?Shn?Shn0L0ooooooooooooooooo`00003oooooooooool00?oooooooooooooo
ool0oooooooooooooooooooo0?ooooooooooooooo`3o0000000000L71`L71`L71`L71`L71`L71`L7
1`L71`L71`L71`L70?Shn?Sh0?Shn?Shn03hn?Shn?P0n?Shn?Shn03hn?P0003hn?Shn?P0n?Shn?Sh
0?Shn?Shn?P0n?Shn?Sh0?Shn?Shn03hn?Shn?P0n?Shn?P70?ooooooo`3ooooo0000000000000000
00000000000000000@410@410@410@L79@0000`000080000:00000`0000400009@0000`000080000
E00006`0000>0000O`0002l0002B00000@000=UU2T9d4@]22P0005l000050000C000000000000000
0000000000000000F0000480J@1/06T0L`071`T000040000100000@0000500009@0000`000070000
9@0000`000040020EP0002`0000J0000_@0002D0003;0000100001L0V@0C08h06`2>01L0V@0K0000
400001L0001^00009@0000`000050000=P000100000G0000UP0002D0000<00001P0002/0000H0000
0P0009L0000a0000_`0005@0001H00005@000>T0000W0000o0000040003II@Y2M14;@Pl0002`0000
0P0004`000000000000000000000000000000500001706T02P0000@0000U0000300000L0000U0000
300000@0081F0000;00007l0002D0000S0000:8000040000JP1_06H0NP1P07@0JP1_01/0000@0000
J0000700000U0000300000D0000f000040000340002/0000DP0004`100040000m?ooo`0000000000
0000090100000000100045@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^0000n?Shn?Shn?Sh0000
00000?oooooooooooooooooo00000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`00000000071`L71`L71`L71`L0000000000000000000000000000000010@41
0@410@411`LU0000300000@0000X0000300000P0000U0000300000@0001D0000E0000540002f0000
G0000<P000010000fFD:@W@A2d8m0000R@000040001<0000000000000000000000000000001@0000
B`071`T0001B0000C04000P0003goooo0000000000000000T04000000004000@E01Y06d0I@1c0200
CP1U07L0801B06l0K@1Q06h000071`L71`L71`L71`L71`L71`L71`L71`L71`L71`L000001`L71`L7
1`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L7
1`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L7n?l71`L71`L70000000000L71`L71`L7
00071`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L71`L7
1`L71`00000000000000000000000000000000410@410@410@471bD0000<0000200002P0000<0000
100002D0000<0000200005@0001D0000G@000;X0001Q0000b0000040003II@Y2M14;@TH0002<0000
0@0004`000000000000000000000000000000500001Q00L7100002D0000<00001P0002X0000H0000
4P0007T0000L0000P`0001/0000@00007`0007D0000f0000400000l0002600009@0000`000070000
9@0000`000040020EP0002`0002/0000FP000;X0001V000010000880C02904<0S@1;0880C00K0000
400008`0001500009@0000`000050000=P00010000230000BP0002D0000<00001`0002D0000<0000
0000P5H0000d0000^@0004h0003>0000G00000H0002<04D0T`140900?`2I0440U@0k09`0>P0U0000
300000D0001G0000=0000;T0001>0000cP0005`000060000S01509<0A02@03l0V@1109D0>`2L03X0
E`0003@0002i0000CP000<h0001L00001P0008`0A@2C04@0T00o09T0@@2E03/0W00j0280000<0000
ooooobP0000<00001P0002P0000<00001`0002H0000L00001`0000000000000000000000000U0000
300000L0000U000030000000080R000030000?oooolR000030000?oooomD0000E0000?@0003g0000
nP0000T100010000=V3Q@:c^hD2C0`00V@<00040001<00001000000000000000SP<00<l3001@0000
803ooaX0001;000040000000000500009@0000`0000=0020:00000`000010000:00000`000030000
:00000`000020000:00000`000070000:00000`0000500009@0000`0000=0020:00000`000080000
3P0001@000000000400001@0
\>"], "Graphics",
    GeneratedCell->False,
    CellAutoOverwrite->False,
    ImageSize->{246, 262}]
}], "Text"],

Cell[TextData[{
  "In this model is supposed that the transfer  ",
  Cell[BoxData[
      \(k\_\(bilis, gi\)\)]],
  " from Bilis to GI it is a UnitStep function [h[t,8, 2]]"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{"h", 
            StyleBox["[",
              FormatType->StandardForm], 
            StyleBox[\(t_, \ a_, \ d_\),
              FormatType->StandardForm], 
            StyleBox["]",
              FormatType->StandardForm]}], 
          StyleBox[" ",
            FormatType->StandardForm], 
          StyleBox[":=",
            FormatType->StandardForm], 
          StyleBox[\(1 - UnitStep[Mod[t, \ a + d] - d]\),
            FormatType->StandardForm]}], 
        StyleBox[";",
          FormatType->StandardForm]}], 
      StyleBox[" ",
        FormatType->StandardForm]}]], "Input",
  CellLabel->"In[99]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[h[t, 8, \ 2], {t, 0, 110}, PlotPoints \[Rule] 1000, 
      PlotRange -> All]; \)], "Input",
  CellLabel->"In[100]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00865801 0.0147151 0.588604 [
[.19697 .00222 -6 -9 ]
[.19697 .00222 6 0 ]
[.37013 .00222 -6 -9 ]
[.37013 .00222 6 0 ]
[.54329 .00222 -6 -9 ]
[.54329 .00222 6 0 ]
[.71645 .00222 -6 -9 ]
[.71645 .00222 6 0 ]
[.88961 .00222 -9 -9 ]
[.88961 .00222 9 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.19697 .01472 m
.19697 .02097 L
s
[(20)] .19697 .00222 0 1 Mshowa
.37013 .01472 m
.37013 .02097 L
s
[(40)] .37013 .00222 0 1 Mshowa
.54329 .01472 m
.54329 .02097 L
s
[(60)] .54329 .00222 0 1 Mshowa
.71645 .01472 m
.71645 .02097 L
s
[(80)] .71645 .00222 0 1 Mshowa
.88961 .01472 m
.88961 .02097 L
s
[(100)] .88961 .00222 0 1 Mshowa
.125 Mabswid
.0671 .01472 m
.0671 .01847 L
s
.11039 .01472 m
.11039 .01847 L
s
.15368 .01472 m
.15368 .01847 L
s
.24026 .01472 m
.24026 .01847 L
s
.28355 .01472 m
.28355 .01847 L
s
.32684 .01472 m
.32684 .01847 L
s
.41342 .01472 m
.41342 .01847 L
s
.45671 .01472 m
.45671 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.58658 .01472 m
.58658 .01847 L
s
.62987 .01472 m
.62987 .01847 L
s
.67316 .01472 m
.67316 .01847 L
s
.75974 .01472 m
.75974 .01847 L
s
.80303 .01472 m
.80303 .01847 L
s
.84632 .01472 m
.84632 .01847 L
s
.9329 .01472 m
.9329 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .60332 m
.02474 .60332 L
.02575 .60332 L
.0267 .60332 L
.02761 .60332 L
.02859 .60332 L
.02952 .60332 L
.03052 .60332 L
.03148 .60332 L
.0324 .60332 L
.03338 .60332 L
.03433 .60332 L
.03524 .60332 L
.03621 .60332 L
.03714 .60332 L
.03813 .60332 L
.03908 .60332 L
.04 .60332 L
.04051 .60332 L
.04075 .60332 L
.04098 .60332 L
.04103 .60332 L
.04109 .60332 L
.04112 .60332 L
.04115 .01472 L
.04116 .01472 L
.04118 .01472 L
.04121 .01472 L
.04124 .01472 L
.04125 .01472 L
.04127 .01472 L
.0413 .01472 L
.04133 .01472 L
.04135 .01472 L
.04136 .01472 L
.04139 .01472 L
.04141 .01472 L
.04142 .01472 L
.04144 .01472 L
.04146 .01472 L
.04149 .01472 L
.04152 .01472 L
.04155 .01472 L
.04157 .01472 L
.04158 .01472 L
.04161 .01472 L
.04164 .01472 L
.04167 .01472 L
.0417 .01472 L
.04173 .01472 L
Mistroke
.04175 .01472 L
.04178 .01472 L
.04181 .01472 L
.04184 .01472 L
.04187 .01472 L
.04189 .01472 L
.04192 .01472 L
.04195 .01472 L
.04197 .01472 L
.04201 .01472 L
.04203 .01472 L
.04206 .01472 L
.04209 .01472 L
.04212 .01472 L
.04215 .01472 L
.04218 .01472 L
.04219 .01472 L
.04221 .01472 L
.04224 .01472 L
.04226 .01472 L
.04228 .01472 L
.0423 .01472 L
.04233 .01472 L
.04235 .01472 L
.04236 .01472 L
.04238 .01472 L
.0424 .01472 L
.04243 .01472 L
.04246 .01472 L
.04247 .01472 L
.04249 .01472 L
.04251 .01472 L
.04252 .01472 L
.04254 .01472 L
.04256 .01472 L
.04259 .01472 L
.04261 .01472 L
.04262 .01472 L
.04264 .01472 L
.04266 .01472 L
.04269 .01472 L
.04271 .01472 L
.04272 .01472 L
.04275 .01472 L
.04277 .01472 L
.04279 .01472 L
.04282 .01472 L
.04285 .01472 L
.04288 .01472 L
.0429 .01472 L
Mistroke
.04293 .01472 L
.04296 .01472 L
.04299 .01472 L
.04301 .01472 L
.04305 .01472 L
.04306 .01472 L
.04308 .01472 L
.04311 .01472 L
.04314 .01472 L
.04316 .01472 L
.04319 .01472 L
.04321 .01472 L
.04324 .01472 L
.04327 .01472 L
.0433 .01472 L
.04333 .01472 L
.04335 .01472 L
.04338 .01472 L
.0434 .01472 L
.04342 .01472 L
.04345 .01472 L
.04347 .01472 L
.04349 .01472 L
.04351 .01472 L
.04354 .01472 L
.04356 .01472 L
.04357 .01472 L
.04359 .01472 L
.04361 .01472 L
.04364 .01472 L
.04366 .01472 L
.04367 .01472 L
.0437 .01472 L
.04373 .01472 L
.04376 .01472 L
.04379 .01472 L
.04382 .01472 L
.04385 .01472 L
.04387 .01472 L
.04388 .01472 L
.04391 .01472 L
.04394 .01472 L
.04396 .01472 L
.04398 .01472 L
.044 .01472 L
.04403 .01472 L
.04406 .01472 L
.04409 .01472 L
.04411 .01472 L
.04413 .01472 L
Mistroke
.04414 .01472 L
.04416 .01472 L
.04419 .01472 L
.04422 .01472 L
.04424 .01472 L
.04425 .01472 L
.04429 .01472 L
.04431 .01472 L
.04432 .01472 L
.04434 .01472 L
.04436 .01472 L
.04437 .01472 L
.04439 .01472 L
.04442 .01472 L
.04445 .01472 L
.04448 .01472 L
.04451 .01472 L
.04453 .01472 L
.04454 .01472 L
.04456 .01472 L
.04457 .01472 L
.04459 .01472 L
.04461 .01472 L
.04464 .01472 L
.04467 .01472 L
.04469 .01472 L
.04472 .01472 L
.04475 .01472 L
.04477 .01472 L
.04478 .01472 L
.04481 .01472 L
.04484 .01472 L
.04487 .01472 L
.04489 .01472 L
.0449 .01472 L
.04493 .01472 L
.04496 .01472 L
.04499 .01472 L
.04501 .01472 L
.04504 .01472 L
.04507 .01472 L
.0451 .01472 L
.04512 .01472 L
.04514 .01472 L
.04517 .01472 L
.04518 .01472 L
.0452 .01472 L
.04523 .01472 L
.04526 .01472 L
.04529 .01472 L
Mistroke
.04531 .01472 L
.04534 .01472 L
.04537 .01472 L
.04539 .01472 L
.04542 .01472 L
.04544 .01472 L
.04547 .01472 L
.0455 .01472 L
.04553 .01472 L
.04556 .01472 L
.04558 .01472 L
.04561 .01472 L
.04564 .01472 L
.04567 .01472 L
.0457 .01472 L
.04573 .01472 L
.04576 .01472 L
.04577 .01472 L
.04579 .01472 L
.04582 .01472 L
.04585 .01472 L
.04587 .01472 L
.04588 .01472 L
.04591 .01472 L
.04594 .01472 L
.04596 .01472 L
.04597 .01472 L
.046 .01472 L
.04603 .01472 L
.04606 .01472 L
.04609 .01472 L
.04612 .01472 L
.04615 .01472 L
.04617 .01472 L
.0462 .01472 L
.04623 .01472 L
.04626 .01472 L
.04629 .01472 L
.0463 .01472 L
.04632 .01472 L
.04635 .01472 L
.04638 .01472 L
.04641 .01472 L
.04644 .01472 L
.04647 .01472 L
.04649 .01472 L
.0465 .01472 L
.04653 .01472 L
.04655 .01472 L
.04657 .01472 L
Mistroke
.04659 .01472 L
.0466 .01472 L
.04662 .01472 L
.04664 .01472 L
.04666 .01472 L
.04667 .01472 L
.0467 .01472 L
.04673 .01472 L
.04676 .01472 L
.04678 .01472 L
.04679 .01472 L
.04682 .01472 L
.04685 .01472 L
.04688 .01472 L
.0469 .01472 L
.04693 .01472 L
.04696 .01472 L
.04699 .01472 L
.04701 .01472 L
.04702 .01472 L
.04705 .01472 L
.04707 .01472 L
.04709 .01472 L
.04712 .01472 L
.04715 .01472 L
.04718 .01472 L
.0472 .01472 L
.04723 .01472 L
.04726 .01472 L
.04728 .01472 L
.04731 .01472 L
.04733 .01472 L
.04736 .01472 L
.04739 .01472 L
.04742 .01472 L
.04745 .01472 L
.04747 .01472 L
.0475 .01472 L
.04753 .01472 L
.04756 .01472 L
.04759 .01472 L
.04761 .01472 L
.04764 .01472 L
.04768 .01472 L
.0477 .01472 L
.04772 .01472 L
.04774 .01472 L
.04775 .01472 L
.04777 .01472 L
.0478 .01472 L
Mistroke
.04783 .01472 L
.04786 .01472 L
.04789 .01472 L
.04792 .01472 L
.04795 .01472 L
.04797 .01472 L
.048 .01472 L
.04803 .01472 L
.04806 .01472 L
.04809 .01472 L
.04811 .01472 L
.04814 .01472 L
.04817 .01472 L
.0482 .01472 L
.04823 .01472 L
.04826 .01472 L
.04828 .01472 L
.0483 .01472 L
.04833 .01472 L
.04834 .01472 L
.04836 .01472 L
.04837 .01472 L
.04839 .01472 L
.04842 .01472 L
.04844 .01472 L
.04846 .01472 L
.04847 .01472 L
.04849 .01472 L
.04851 .01472 L
.04852 .01472 L
.04854 .01472 L
.04856 .01472 L
.04859 .01472 L
.04862 .01472 L
.04865 .01472 L
.04868 .01472 L
.04871 .01472 L
.04873 .01472 L
.04876 .01472 L
.04879 .01472 L
.04882 .01472 L
.04884 .01472 L
.04887 .01472 L
.0489 .01472 L
.04893 .01472 L
.04896 .01472 L
.04899 .01472 L
.04901 .01472 L
.04903 .01472 L
.04906 .01472 L
Mistroke
.04909 .01472 L
.04911 .01472 L
.04914 .01472 L
.04917 .01472 L
.0492 .01472 L
.04922 .01472 L
.04924 .01472 L
.04927 .01472 L
.0493 .01472 L
.04932 .01472 L
.04935 .01472 L
.04938 .01472 L
.04941 .01472 L
.04944 .01472 L
.04945 .01472 L
.04947 .01472 L
.0495 .01472 L
.04953 .01472 L
.04956 .01472 L
.04959 .01472 L
.04962 .01472 L
.04964 .01472 L
.04967 .01472 L
.0497 .01472 L
.04973 .01472 L
.04975 .01472 L
.04978 .01472 L
.04981 .01472 L
.04984 .01472 L
.04987 .01472 L
.0499 .01472 L
.04992 .01472 L
.04994 .01472 L
.04997 .01472 L
.05 .01472 L
.05002 .01472 L
.05005 .01472 L
.05008 .01472 L
.05011 .01472 L
.05013 .01472 L
.05016 .01472 L
.05018 .01472 L
.05021 .01472 L
.05024 .01472 L
.05026 .01472 L
.05029 .01472 L
.05032 .01472 L
.05035 .01472 L
.05036 .01472 L
.05038 .01472 L
Mistroke
.05041 .01472 L
.05044 .01472 L
.05047 .01472 L
.05048 .01472 L
.0505 .01472 L
.05053 .01472 L
.05056 .01472 L
.05058 .01472 L
.05061 .01472 L
.05063 .01472 L
.05066 .01472 L
.05069 .01472 L
.05071 .01472 L
.05073 .01472 L
.05076 .01472 L
.05078 .01472 L
.05079 .01472 L
.05082 .01472 L
.05085 .01472 L
.05088 .01472 L
.05091 .01472 L
.05093 .01472 L
.05096 .01472 L
.05099 .01472 L
.05101 .01472 L
.05104 .01472 L
.05107 .01472 L
.0511 .01472 L
.05112 .01472 L
.05115 .01472 L
.05118 .01472 L
.05121 .01472 L
.05123 .01472 L
.05126 .01472 L
.05129 .01472 L
.05132 .01472 L
.05135 .01472 L
.05138 .01472 L
.05141 .01472 L
.05142 .01472 L
.05144 .01472 L
.05146 .01472 L
.05148 .01472 L
.05151 .01472 L
.05153 .01472 L
.05156 .01472 L
.05159 .01472 L
.05162 .01472 L
.05165 .01472 L
.05168 .01472 L
Mistroke
.0517 .01472 L
.05173 .01472 L
.05176 .01472 L
.05179 .01472 L
.05182 .01472 L
.05185 .01472 L
.05188 .01472 L
.05191 .01472 L
.05193 .01472 L
.05197 .01472 L
.05198 .01472 L
.052 .01472 L
.05203 .01472 L
.05205 .01472 L
.05206 .01472 L
.05208 .01472 L
.0521 .01472 L
.05213 .01472 L
.05214 .01472 L
.05216 .01472 L
.05218 .01472 L
.0522 .01472 L
.05221 .01472 L
.05223 .01472 L
.05225 .01472 L
.05226 .01472 L
.05229 .01472 L
.05232 .01472 L
.05235 .01472 L
.05238 .01472 L
.05241 .01472 L
.05244 .01472 L
.05247 .01472 L
.05249 .01472 L
.05252 .01472 L
.05255 .01472 L
.05258 .01472 L
.05261 .01472 L
.05264 .01472 L
.05266 .01472 L
.0527 .01472 L
.05271 .01472 L
.05273 .01472 L
.05276 .01472 L
.05279 .01472 L
.05282 .01472 L
.05284 .01472 L
.05287 .01472 L
.0529 .01472 L
.05293 .01472 L
Mistroke
.05295 .01472 L
.05297 .01472 L
.053 .01472 L
.05303 .01472 L
.05306 .01472 L
.05309 .01472 L
.05311 .01472 L
.05314 .01472 L
.05316 .01472 L
.05317 .01472 L
.0532 .01472 L
.05323 .01472 L
.05326 .01472 L
.05329 .01472 L
.05332 .01472 L
.05335 .01472 L
.05338 .01472 L
.0534 .01472 L
.05343 .01472 L
.05346 .01472 L
.05349 .01472 L
.05352 .01472 L
.05355 .01472 L
.05357 .01472 L
.05361 .01472 L
.05362 .01472 L
.05364 .01472 L
.05367 .01472 L
.0537 .01472 L
.05373 .01472 L
.05375 .01472 L
.05378 .01472 L
.05381 .01472 L
.05384 .01472 L
.05386 .01472 L
.05389 .01472 L
.05391 .01472 L
.05394 .01472 L
.05397 .01472 L
.054 .01472 L
.05402 .01472 L
.05405 .01472 L
.05407 .01472 L
.05408 .01472 L
.05411 .01472 L
.05414 .01472 L
.05417 .01472 L
.05419 .01472 L
.0542 .01472 L
.05423 .01472 L
Mistroke
.05426 .01472 L
.05429 .01472 L
.05431 .01472 L
.05434 .01472 L
.05437 .01472 L
.0544 .01472 L
.05442 .01472 L
.05443 .01472 L
.05446 .01472 L
.05448 .01472 L
.0545 .01472 L
.05452 .01472 L
.05456 .01472 L
.05459 .01472 L
.05461 .01472 L
.05464 .01472 L
.05467 .01472 L
.05469 .01472 L
.05471 .01472 L
.05474 .01472 L
.05477 .01472 L
.0548 .01472 L
.05483 .01472 L
.05486 .01472 L
.05488 .01472 L
.05491 .01472 L
.05494 .01472 L
.05497 .01472 L
.055 .01472 L
.05502 .01472 L
.05505 .01472 L
.05508 .01472 L
.05511 .01472 L
.05513 .01472 L
.05515 .01472 L
.05516 .01472 L
.05518 .01472 L
.05521 .01472 L
.05524 .01472 L
.05527 .01472 L
.0553 .01472 L
.05533 .01472 L
.05535 .01472 L
.05538 .01472 L
.05541 .01472 L
.05543 .01472 L
.05547 .01472 L
.0555 .01472 L
.05552 .01472 L
.05555 .01472 L
Mistroke
.05558 .01472 L
.05561 .01472 L
.05564 .01472 L
.05567 .01472 L
.05569 .01472 L
.0557 .01472 L
.05573 .01472 L
.05575 .01472 L
.05577 .01472 L
.05578 .01472 L
.0558 .01472 L
.05583 .01472 L
.05585 .01472 L
.05586 .01472 L
.05588 .01472 L
.0559 .01472 L
.05592 .01472 L
.05593 .01472 L
.05595 .01472 L
.05597 .01472 L
.05599 .01472 L
.05602 .01472 L
.05605 .01472 L
.05609 .01472 L
.05612 .01472 L
.05614 .01472 L
.05617 .01472 L
.0562 .01472 L
.05622 .01472 L
.05625 .01472 L
.05628 .01472 L
.05631 .01472 L
.05634 .01472 L
.05637 .01472 L
.0564 .01472 L
.05642 .01472 L
.05643 .01472 L
.05646 .01472 L
.05649 .01472 L
.05652 .01472 L
.05655 .01472 L
.05658 .01472 L
.0566 .01472 L
.05663 .01472 L
.05665 .01472 L
.05668 .01472 L
.0567 .01472 L
.05673 .01472 L
.05676 .01472 L
.05679 .01472 L
Mistroke
.05681 .01472 L
.05684 .01472 L
.05686 .01472 L
.05688 .01472 L
.0569 .01472 L
.05693 .01472 L
.05696 .01472 L
.05699 .01472 L
.05702 .01472 L
.05705 .01472 L
.05708 .01472 L
.0571 .01472 L
.05713 .01472 L
.05716 .01472 L
.05719 .01472 L
.05722 .01472 L
.05725 .01472 L
.05728 .01472 L
.05731 .01472 L
.05733 .01472 L
.05734 .01472 L
.05737 .01472 L
.0574 .01472 L
.05743 .01472 L
.05746 .01472 L
.05749 .01472 L
.05751 .01472 L
.05754 .01472 L
.05756 .01472 L
.05759 .01472 L
.05762 .01472 L
.05764 .01472 L
.05767 .01472 L
.0577 .01472 L
.05772 .01472 L
.05775 .01472 L
.05777 .01472 L
.05779 .01472 L
.05781 .01472 L
.05784 .01472 L
.05787 .01472 L
.05789 .01472 L
.05791 .01472 L
.05793 .01472 L
.05796 .01472 L
.05799 .01472 L
.05801 .01472 L
.05804 .01472 L
.05807 .01472 L
.0581 .01472 L
Mistroke
.05812 .01472 L
.05813 .01472 L
.05817 .01472 L
.05818 .01472 L
.0582 .01472 L
.05823 .01472 L
.05826 .01472 L
.05829 .01472 L
.05832 .01472 L
.05834 .01472 L
.05837 .01472 L
.05839 .01472 L
.05842 .01472 L
.05844 .01472 L
.05847 .01472 L
.0585 .01472 L
.05853 .01472 L
.05856 .01472 L
.05859 .01472 L
.05861 .01472 L
.05864 .01472 L
.05867 .01472 L
.0587 .01472 L
.05873 .01472 L
.05876 .01472 L
.05879 .01472 L
.05882 .01472 L
.05883 .01472 L
.05885 .01472 L
.05887 .01472 L
.05888 .01472 L
.05891 .01472 L
.05894 .01472 L
.05897 .01472 L
.059 .01472 L
.05903 .01472 L
.05906 .01472 L
.05908 .01472 L
.05911 .01472 L
.05914 .01472 L
.05917 .01472 L
.0592 .01472 L
.05922 .01472 L
.05925 .01472 L
.05929 .01472 L
.05931 .01472 L
.05934 .01472 L
.05937 .01472 L
.05939 .01472 L
.05941 .01472 L
Mistroke
.05944 .01472 L
.05945 .01472 L
.05947 .01472 L
.05949 .01472 L
.0595 .01472 L
.05953 .01472 L
.05955 .01472 L
.05957 .01472 L
.05958 .01472 L
.0596 .01472 L
.05962 .01472 L
.05964 .01472 L
.05965 .01472 L
.05967 .01472 L
.0597 .01472 L
.05973 .01472 L
.05976 .01472 L
.05979 .01472 L
.05982 .01472 L
.05985 .01472 L
.05987 .01472 L
.0599 .01472 L
.05993 .01472 L
.05995 .01472 L
.05998 .01472 L
.06001 .01472 L
.06004 .01472 L
.06007 .01472 L
.0601 .01472 L
.06012 .01472 L
.06014 .01472 L
.06017 .01472 L
.0602 .01472 L
.06022 .01472 L
.06025 .01472 L
.06028 .01472 L
.06031 .01472 L
.06033 .01472 L
.06035 .01472 L
.06038 .01472 L
.06041 .01472 L
.06043 .01472 L
.06046 .01472 L
.06049 .01472 L
.06052 .01472 L
.06055 .01472 L
.06056 .01472 L
.06058 .01472 L
.06061 .01472 L
.06064 .01472 L
Mistroke
.06067 .01472 L
.0607 .01472 L
.06073 .01472 L
.06075 .01472 L
.06078 .01472 L
.06081 .01472 L
.06084 .01472 L
.06086 .01472 L
.06089 .01472 L
.06092 .01472 L
.06095 .01472 L
.06098 .01472 L
.06101 .01472 L
.06103 .01472 L
.06105 .01472 L
.06108 .01472 L
.06111 .01472 L
.06113 .01472 L
.06116 .01472 L
.06119 .01472 L
.06122 .01472 L
.06124 .01472 L
.06126 .01472 L
.06129 .01472 L
.06132 .01472 L
.06134 .01472 L
.06137 .01472 L
.0614 .01472 L
.06143 .01472 L
.06146 .01472 L
.06147 .01472 L
.06149 .01472 L
.06152 .01472 L
.06155 .01472 L
.06158 .01472 L
.06159 .01472 L
.06161 .01472 L
.06164 .01472 L
.06167 .01472 L
.06169 .01472 L
.06172 .01472 L
.06174 .01472 L
.06177 .01472 L
.0618 .01472 L
.06182 .01472 L
.06184 .01472 L
.06187 .01472 L
.06188 .01472 L
.0619 .01472 L
.06193 .01472 L
Mistroke
.06196 .01472 L
.06199 .01472 L
.06202 .01472 L
.06204 .01472 L
.06207 .01472 L
.0621 .01472 L
.06212 .01472 L
.06215 .01472 L
.06218 .01472 L
.0622 .01472 L
.06223 .01472 L
.06226 .01472 L
.06229 .01472 L
.06231 .01472 L
.06234 .01472 L
.06237 .01472 L
.0624 .01472 L
.06243 .01472 L
.06246 .01472 L
.06249 .01472 L
.06252 .01472 L
.06253 .01472 L
.06255 .01472 L
.06257 .01472 L
.06258 .01472 L
.06261 .01472 L
.06264 .01472 L
.06267 .01472 L
.0627 .01472 L
.06273 .01472 L
.06276 .01472 L
.06279 .01472 L
.06281 .01472 L
.06284 .01472 L
.06287 .01472 L
.0629 .01472 L
.06293 .01472 L
.06296 .01472 L
.06299 .01472 L
.06302 .01472 L
.06304 .01472 L
.06307 .01472 L
.06309 .01472 L
.06311 .01472 L
.06314 .01472 L
.06316 .01472 L
.06317 .01472 L
.06319 .01472 L
.0632 .01472 L
.06323 .01472 L
Mistroke
.06325 .01472 L
.06327 .01472 L
.06328 .01472 L
.0633 .01472 L
.06332 .01472 L
.06334 .01472 L
.06335 .01472 L
.06337 .01472 L
.0634 .01472 L
.06343 .01472 L
.06346 .01472 L
.06349 .01472 L
.06352 .01472 L
.06355 .01472 L
.06357 .01472 L
.0636 .01472 L
.06363 .01472 L
.06365 .01472 L
.06368 .01472 L
.06372 .01472 L
.06374 .01472 L
.06377 .01472 L
.0638 .01472 L
.06382 .01472 L
.06384 .01472 L
.06387 .01472 L
.0639 .01472 L
.06392 .01472 L
.06395 .01472 L
.06398 .01472 L
.06401 .01472 L
.06403 .01472 L
.06406 .01472 L
.06408 .01472 L
.06411 .01472 L
.06414 .01472 L
.06416 .01472 L
.06419 .01472 L
.06422 .01472 L
.06425 .01472 L
.06426 .01472 L
.06428 .01472 L
.06431 .01472 L
.06434 .01472 L
.06437 .01472 L
.0644 .01472 L
.06443 .01472 L
.06446 .01472 L
.06448 .01472 L
.06451 .01472 L
Mistroke
.06454 .01472 L
.06456 .01472 L
.06459 .01472 L
.06462 .01472 L
.06465 .01472 L
.06468 .01472 L
.06471 .01472 L
.06473 .01472 L
.06475 .01472 L
.06478 .01472 L
.06481 .01472 L
.06483 .01472 L
.06486 .01472 L
.06489 .01472 L
.06492 .01472 L
.06494 .01472 L
.06497 .01472 L
.06499 .01472 L
.06502 .01472 L
.06505 .01472 L
.06507 .01472 L
.0651 .01472 L
.06513 .01472 L
.06516 .01472 L
.06517 .01472 L
.06519 .01472 L
.06522 .01472 L
.06525 .01472 L
.06528 .01472 L
.06531 .01472 L
.06534 .01472 L
.06537 .01472 L
.06539 .01472 L
.06542 .01472 L
.06545 .01472 L
.06547 .01472 L
.0655 .01472 L
.06554 .01472 L
.06556 .01472 L
.06559 .01472 L
.06562 .01472 L
.06564 .01472 L
.06566 .01472 L
.06569 .01472 L
.06572 .01472 L
.06574 .01472 L
.06577 .01472 L
.0658 .01472 L
.06583 .01472 L
.06585 .01472 L
Mistroke
.06588 .01472 L
.0659 .01472 L
.06593 .01472 L
.06596 .01472 L
.06599 .01472 L
.06601 .01472 L
.06604 .01472 L
.06607 .01472 L
.06608 .01472 L
.0661 .01472 L
.06613 .01472 L
.06616 .01472 L
.06619 .01472 L
.0662 .01472 L
.06622 .01472 L
.06625 .01472 L
.06628 .01472 L
.0663 .01472 L
.06633 .01472 L
.06636 .01472 L
.06639 .01472 L
.06642 .01472 L
.06643 .01472 L
.06645 .01472 L
.06648 .01472 L
.0665 .01472 L
.06651 .01472 L
.06654 .01472 L
.06657 .01472 L
.0666 .01472 L
.06663 .01472 L
.06666 .01472 L
.06668 .01472 L
.06671 .01472 L
.06673 .01472 L
.06676 .01472 L
.06679 .01472 L
.06682 .01472 L
.06684 .01472 L
.06687 .01472 L
.0669 .01472 L
.06693 .01472 L
.06695 .01472 L
.06698 .01472 L
.06701 .01472 L
.06704 .01472 L
.06707 .01472 L
.0671 .01472 L
.06713 .01472 L
.06715 .01472 L
Mistroke
.06716 .01472 L
.06718 .01472 L
.0672 .01472 L
.06723 .01472 L
.06725 .01472 L
.06728 .01472 L
.06732 .01472 L
.06734 .01472 L
.06737 .01472 L
.0674 .01472 L
.06742 .01472 L
.06745 .01472 L
.06748 .01472 L
.06751 .01472 L
.06754 .01472 L
.06757 .01472 L
.0676 .01472 L
.06763 .01472 L
.06766 .01472 L
.06769 .01472 L
.06771 .01472 L
.06772 .01472 L
.06775 .01472 L
.06777 .01472 L
.06778 .01472 L
.0678 .01472 L
.06782 .01472 L
.06785 .01472 L
.06787 .01472 L
.06788 .01472 L
.0679 .01472 L
.06792 .01472 L
.06793 .01472 L
.06795 .01472 L
.06797 .01472 L
.06798 .01472 L
.06801 .01472 L
.06804 .01472 L
.06807 .01472 L
.0681 .01472 L
.06813 .01472 L
.06816 .01472 L
.06819 .01472 L
.06821 .01472 L
.06824 .01472 L
.06827 .01472 L
.0683 .01472 L
.06833 .01472 L
.06836 .01472 L
.06839 .01472 L
Mistroke
.06842 .01472 L
.06843 .01472 L
.06845 .01472 L
.06848 .01472 L
.06851 .01472 L
.06854 .01472 L
.06857 .01472 L
.06859 .01472 L
.06862 .01472 L
.06865 .01472 L
.06867 .01472 L
.0687 .01472 L
.06872 .01472 L
.06875 .01472 L
.06878 .01472 L
.06881 .01472 L
.06883 .01472 L
.06886 .01472 L
.06888 .01472 L
.06889 .01472 L
.06892 .01472 L
.06895 .01472 L
.06898 .01472 L
.06901 .01472 L
.06904 .01472 L
.06907 .01472 L
.0691 .01472 L
.06912 .01472 L
.06915 .01472 L
.06918 .01472 L
.06921 .01472 L
.06924 .01472 L
.06927 .01472 L
.0693 .01472 L
.06933 .01472 L
.06935 .01472 L
.06936 .01472 L
.06939 .01472 L
.06942 .01472 L
.06945 .01472 L
.06948 .01472 L
.0695 .01472 L
.06953 .01472 L
.06956 .01472 L
.06958 .01472 L
.06961 .01472 L
.06963 .01472 L
.06966 .01472 L
.06969 .01472 L
.06972 .01472 L
Mistroke
.06974 .01472 L
.06977 .01472 L
.06979 .01472 L
.0698 .01472 L
.06983 .01472 L
.06986 .01472 L
.06989 .01472 L
.06991 .01472 L
.06992 .01472 L
.06995 .01472 L
.06998 .01472 L
.07001 .01472 L
.07003 .01472 L
.07006 .01472 L
.07009 .01472 L
.07012 .01472 L
.07014 .01472 L
.07015 .01472 L
.07018 .01472 L
.0702 .01472 L
.07022 .01472 L
.07025 .01472 L
.07028 .01472 L
.07031 .01472 L
.07033 .01472 L
.07036 .01472 L
.07039 .01472 L
.07041 .01472 L
.07044 .01472 L
.07046 .01472 L
.07049 .01472 L
.07052 .01472 L
.07055 .01472 L
.07058 .01472 L
.07061 .01472 L
.07063 .01472 L
.07066 .01472 L
.07069 .01472 L
.07072 .01472 L
.07075 .01472 L
.07077 .01472 L
.07081 .01472 L
.07083 .01472 L
.07085 .01472 L
.07087 .01472 L
.07088 .01472 L
.0709 .01472 L
.07093 .01472 L
.07096 .01472 L
.07099 .01472 L
Mistroke
.07102 .01472 L
.07105 .01472 L
.07108 .01472 L
.0711 .01472 L
.07113 .01472 L
.07116 .01472 L
.07119 .01472 L
.07122 .01472 L
.07124 .01472 L
.07127 .01472 L
.0713 .01472 L
.07133 .01472 L
.07136 .01472 L
.07139 .01472 L
.07141 .01472 L
.07143 .01472 L
.07146 .01472 L
.07147 .01472 L
.07149 .01472 L
.0715 .01472 L
.07152 .01472 L
.07155 .01472 L
.07157 .01472 L
.07159 .01472 L
.0716 .01472 L
.07162 .01472 L
.07164 .01472 L
.07165 .01472 L
.07167 .01472 L
.07169 .01472 L
.07172 .01472 L
.07175 .01472 L
.07178 .01472 L
.07181 .01472 L
.07184 .01472 L
.07186 .01472 L
.07189 .01472 L
.07192 .01472 L
.07195 .01472 L
.07197 .01472 L
.072 .01472 L
.07203 .01472 L
.07206 .01472 L
.07209 .01472 L
.07212 .01472 L
.07214 .01472 L
.07215 .01472 L
.07219 .01472 L
.07222 .01472 L
.07224 .01472 L
Mistroke
.07227 .01472 L
.0723 .01472 L
.07233 .01472 L
.07235 .01472 L
.07237 .01472 L
.0724 .01472 L
.07243 .01472 L
.07245 .01472 L
.07248 .01472 L
.07251 .01472 L
.07254 .01472 L
.07257 .01472 L
.07258 .01472 L
.0726 .01472 L
.07263 .01472 L
.07266 .01472 L
.07268 .01472 L
.07272 .01472 L
.07275 .01472 L
.07277 .01472 L
.0728 .01472 L
.07283 .01472 L
.07286 .01472 L
.07288 .01472 L
.07291 .01472 L
.07294 .01472 L
.07297 .01472 L
.073 .01472 L
.07303 .01472 L
.07305 .01472 L
.07306 .01472 L
.0731 .01472 L
.07313 .01472 L
.07315 .01472 L
.07318 .01472 L
.07321 .01472 L
.07324 .01472 L
.07326 .01472 L
.07328 .01472 L
.07331 .01472 L
.07334 .01472 L
.07336 .01472 L
.07339 .01472 L
.07342 .01472 L
.07345 .01472 L
.07348 .01472 L
.07349 .01472 L
.07351 .01472 L
.07354 .01472 L
.07357 .01472 L
Mistroke
.0736 .01472 L
.07361 .01472 L
.07363 .01472 L
.07365 .01472 L
.07368 .01472 L
.07371 .01472 L
.07374 .01472 L
.07376 .01472 L
.07379 .01472 L
.07382 .01472 L
.07384 .01472 L
.07386 .01472 L
.07389 .01472 L
.0739 .01472 L
.07392 .01472 L
.07395 .01472 L
.07398 .01472 L
.07401 .01472 L
.07404 .01472 L
.07406 .01472 L
.07409 .01472 L
.07412 .01472 L
.07414 .01472 L
.07417 .01472 L
.0742 .01472 L
.07422 .01472 L
.07425 .01472 L
.07428 .01472 L
.07431 .01472 L
.07433 .01472 L
.07436 .01472 L
.07439 .01472 L
.07442 .01472 L
.07445 .01472 L
.07448 .01472 L
.07451 .01472 L
.07454 .01472 L
.07455 .01472 L
.07457 .01472 L
.07459 .01472 L
.0746 .01472 L
.07463 .01472 L
.07466 .01472 L
.07469 .01472 L
.07472 .01472 L
.07475 .01472 L
.07478 .01472 L
.07481 .01472 L
.07483 .01472 L
.07486 .01472 L
Mistroke
.07489 .01472 L
.07492 .01472 L
.07495 .01472 L
.07498 .01472 L
.07501 .01472 L
.07504 .01472 L
.07506 .01472 L
.07509 .01472 L
.07511 .01472 L
.07513 .01472 L
.07516 .01472 L
.07518 .01472 L
.07519 .01472 L
.07521 .01472 L
.07522 .01472 L
.07525 .01472 L
.07527 .01472 L
.07529 .01472 L
.07531 .01472 L
.07532 .01472 L
.07534 .01472 L
.07536 .01472 L
.07537 .01472 L
.07539 .01472 L
.07542 .01472 L
.07545 .01472 L
.07548 .01472 L
.07551 .01472 L
.07554 .01472 L
.07557 .01472 L
.07559 .01472 L
.07562 .01472 L
.07565 .01472 L
.07568 .01472 L
.0757 .01472 L
.07574 .01472 L
.07576 .01472 L
.07579 .01472 L
.07582 .01472 L
.07584 .01472 L
.07586 .01472 L
.07589 .01472 L
.07592 .01472 L
.07594 .01472 L
.07597 .01472 L
.076 .01472 L
.07603 .01472 L
.07605 .01472 L
.07608 .01472 L
.0761 .01472 L
Mistroke
.07613 .01472 L
.07616 .01472 L
.07619 .01472 L
.07621 .01472 L
.07624 .01472 L
.07627 .01472 L
.07628 .01472 L
.0763 .01472 L
.07633 .01472 L
.07636 .01472 L
.07639 .01472 L
.07642 .01472 L
.07645 .01472 L
.07648 .01472 L
.0765 .01472 L
.07653 .01472 L
.07656 .01472 L
.07658 .01472 L
.07661 .01472 L
.07665 .01472 L
.07667 .01472 L
.0767 .01472 L
.07673 .01472 L
.07675 .01472 L
.07677 .01472 L
.0768 .01472 L
.07683 .01472 L
.07685 .01472 L
.07688 .01472 L
.07691 .01472 L
.07694 .01472 L
.07696 .01472 L
.07699 .01472 L
.07701 .01472 L
.07704 .01472 L
.07707 .01472 L
.0771 .01472 L
.07712 .01472 L
.07715 .01472 L
.07718 .01472 L
.07719 .01472 L
.07721 .01472 L
.07724 .01472 L
.07727 .01472 L
.0773 .01472 L
.07731 .01472 L
.07733 .01472 L
.07736 .01472 L
.07739 .01472 L
.07741 .01472 L
Mistroke
.07744 .01472 L
.07747 .01472 L
.0775 .01472 L
.07752 .01472 L
.07754 .01472 L
.07756 .01472 L
.07759 .01472 L
.07761 .01472 L
.07762 .01472 L
.07765 .01472 L
.07768 .01472 L
.07771 .01472 L
.07774 .01472 L
.07776 .01472 L
.07779 .01472 L
.07782 .01472 L
.07784 .01472 L
.07787 .01472 L
.0779 .01472 L
.07793 .01472 L
.07795 .01472 L
.07798 .01472 L
.07801 .01472 L
.07804 .01472 L
.07806 .01472 L
.07809 .01472 L
.07812 .01472 L
.07815 .01472 L
.07818 .01472 L
.07821 .01472 L
.07824 .01472 L
.07825 .01472 L
.07827 .01472 L
.07829 .01472 L
.07831 .01472 L
.07834 .01472 L
.07836 .01472 L
.07839 .01472 L
.07842 .01472 L
.07845 .01472 L
.07848 .01472 L
.07851 .01472 L
.07853 .01472 L
.07856 .01472 L
.07859 .01472 L
.07862 .01472 L
.07865 .01472 L
.07868 .01472 L
.07871 .01472 L
.07874 .01472 L
Mistroke
.07876 .01472 L
.0788 .01472 L
.07881 .01472 L
.07883 .01472 L
.07886 .01472 L
.07888 .01472 L
.07889 .01472 L
.07891 .01472 L
.07893 .01472 L
.07896 .01472 L
.07897 .01472 L
.07899 .01472 L
.07901 .01472 L
.07903 .01472 L
.07904 .01472 L
.07906 .01472 L
.07908 .01472 L
.07909 .01472 L
.07912 .01472 L
.07915 .01472 L
.07918 .01472 L
.07921 .01472 L
.07924 .01472 L
.07927 .01472 L
.0793 .01472 L
.07932 .01472 L
.07935 .01472 L
.07938 .01472 L
.07941 .01472 L
.07944 .01472 L
.07946 .01472 L
.07949 .01472 L
.07953 .01472 L
.07954 .01472 L
.07956 .01472 L
.07959 .01472 L
.07962 .01472 L
.07965 .01472 L
.07967 .01472 L
.0797 .01472 L
.07973 .01472 L
.07975 .01472 L
.07978 .01472 L
.0798 .01472 L
.07983 .01472 L
.07986 .01472 L
.07989 .01472 L
.07991 .01472 L
.07994 .01472 L
.07997 .01472 L
Mistroke
.07999 .01472 L
.08 .01472 L
.08003 .01472 L
.08006 .01472 L
.08009 .01472 L
.08012 .01472 L
.08015 .01472 L
.08018 .01472 L
.08021 .01472 L
.08023 .01472 L
.08026 .01472 L
.08029 .01472 L
.08032 .01472 L
.08035 .01472 L
.08037 .01472 L
.0804 .01472 L
.08043 .01472 L
.08045 .01472 L
.08047 .01472 L
.0805 .01472 L
.08053 .01472 L
.08055 .01472 L
.08058 .01472 L
.08061 .01472 L
.08064 .01472 L
.08066 .01472 L
.08069 .01472 L
.08071 .01472 L
.08074 .01472 L
.08077 .01472 L
.0808 .01472 L
.08082 .01472 L
.08085 .01472 L
.08088 .01472 L
.0809 .01472 L
.08091 .01472 L
.08094 .01472 L
.08097 .01472 L
.081 .01472 L
.08103 .01472 L
.08106 .01472 L
.08109 .01472 L
.08111 .01472 L
.08114 .01472 L
.08117 .01472 L
.0812 .01472 L
.08123 .01472 L
.08126 .01472 L
.08128 .01472 L
.08131 .01472 L
Mistroke
.08135 .01472 L
.08136 .01472 L
.08138 .01472 L
.08141 .01472 L
.08144 .01472 L
.08147 .01472 L
.08149 .01472 L
.08152 .01472 L
.08155 .01472 L
.08158 .01472 L
.0816 .01472 L
.08163 .01472 L
.08165 .01472 L
.08168 .01472 L
.08171 .01472 L
.08174 .01472 L
.08176 .01472 L
.08179 .01472 L
.08181 .01472 L
.08182 .01472 L
.08185 .01472 L
.08188 .01472 L
.08191 .01472 L
.08193 .01472 L
.08194 .01472 L
.08197 .01472 L
.082 .01472 L
.08203 .01472 L
.08205 .01472 L
.08208 .01472 L
.08211 .01472 L
.08214 .01472 L
.08215 .01472 L
.08217 .01472 L
.0822 .01472 L
.08222 .01472 L
.08224 .01472 L
.08226 .01472 L
.0823 .01472 L
.08232 .01472 L
.08235 .01472 L
.08238 .01472 L
.0824 .01472 L
.08243 .01472 L
.08245 .01472 L
.08248 .01472 L
.08251 .01472 L
.08254 .01472 L
.08257 .01472 L
.0826 .01472 L
Mistroke
.08262 .01472 L
.08265 .01472 L
.08268 .01472 L
.08271 .01472 L
.08274 .01472 L
.08276 .01472 L
.08279 .01472 L
.08282 .01472 L
.08285 .01472 L
.08287 .01472 L
.08288 .01472 L
.0829 .01472 L
.08292 .01472 L
.08295 .01472 L
.08298 .01472 L
.08301 .01472 L
.08304 .01472 L
.08307 .01472 L
.08309 .01472 L
.08312 .01472 L
.08315 .01472 L
.08317 .01472 L
.08321 .01472 L
.08323 .01472 L
.08326 .01472 L
.08329 .01472 L
.08332 .01472 L
.08335 .01472 L
.08338 .01472 L
.08341 .01472 L
.08343 .01472 L
.08344 .01472 L
.08347 .01472 L
.08349 .01472 L
.08351 .01472 L
.08352 .01472 L
.08354 .01472 L
.08357 .01472 L
.08359 .01472 L
.0836 .01472 L
.08362 .01472 L
.08364 .01472 L
.08366 .01472 L
.08367 .01472 L
.08369 .01472 L
.08371 .01472 L
.08373 .01472 L
.08376 .01472 L
.08379 .01472 L
.08383 .01472 L
Mistroke
.08386 .01472 L
.08388 .01472 L
.08391 .01472 L
.08394 .01472 L
.08396 .01472 L
.08399 .01472 L
.08402 .01472 L
.08405 .01472 L
.08408 .01472 L
.08411 .01472 L
.08414 .01472 L
.08416 .01472 L
.08417 .01472 L
.0842 .01472 L
.08423 .01472 L
.08426 .01472 L
.08429 .01472 L
.08432 .01472 L
.08434 .01472 L
.08437 .01472 L
.08439 .01472 L
.08442 .01472 L
.08445 .01472 L
.08447 .01472 L
.0845 .01472 L
.08453 .01472 L
.08455 .01472 L
.08458 .01472 L
.0846 .01472 L
.08462 .01472 L
.08464 .01472 L
.08467 .01472 L
.0847 .01472 L
.08474 .01472 L
.08477 .01472 L
.08479 .01472 L
.08482 .01472 L
.08485 .01472 L
.08487 .01472 L
.0849 .01472 L
.08493 .01472 L
.08496 .01472 L
.08499 .01472 L
.08502 .01472 L
.08505 .01472 L
.08507 .01472 L
.08508 .01472 L
.08512 .01472 L
.08514 .01472 L
.08517 .01472 L
Mistroke
.0852 .01472 L
.08523 .01472 L
.08525 .01472 L
.08528 .01472 L
.0853 .01472 L
.08533 .01472 L
.08536 .01472 L
.08538 .01472 L
.08541 .01472 L
.08544 .01472 L
.08547 .01472 L
.0855 .01472 L
.08551 .01472 L
.08553 .01472 L
.08556 .01472 L
.08559 .01472 L
.08561 .01472 L
.08563 .01472 L
.08565 .01472 L
.08567 .01472 L
.0857 .01472 L
.08573 .01472 L
.08576 .01472 L
.08578 .01472 L
.08581 .01472 L
.08584 .01472 L
.08586 .01472 L
.08587 .01472 L
.08591 .01472 L
.08592 .01472 L
.08594 .01472 L
.08597 .01472 L
.086 .01472 L
.08603 .01472 L
.08606 .01472 L
.08608 .01472 L
.08611 .01472 L
.08613 .01472 L
.08616 .01472 L
.08619 .01472 L
.08622 .01472 L
.08624 .01472 L
.08627 .01472 L
.0863 .01472 L
.08633 .01472 L
.08635 .01472 L
.08638 .01472 L
.08641 .01472 L
.08644 .01472 L
.08647 .01472 L
Mistroke
.0865 .01472 L
.08653 .01472 L
.08656 .01472 L
.08657 .01472 L
.08659 .01472 L
.08661 .01472 L
.08662 .01472 L
.08665 .01472 L
.08668 .01472 L
.08671 .01472 L
.08674 .01472 L
.08677 .01472 L
.0868 .01472 L
.08683 .01472 L
.08685 .01472 L
.08688 .01472 L
.08691 .01472 L
.08694 .01472 L
.08697 .01472 L
.087 .01472 L
.08703 .01472 L
.08706 .01472 L
.08708 .01472 L
.08711 .01472 L
.08713 .01472 L
.08715 .01472 L
.08718 .01472 L
.08719 .01472 L
.08721 .01472 L
.08723 .01472 L
.08724 .01472 L
.08727 .01472 L
.08729 .01472 L
.08731 .01472 L
.08733 .01472 L
.08734 .01472 L
.08736 .01472 L
.08738 .01472 L
.08739 .01472 L
.08741 .01472 L
.08744 .01472 L
.08747 .01472 L
.0875 .01472 L
.08753 .01472 L
.08756 .01472 L
.08759 .01472 L
.08761 .01472 L
.08764 .01472 L
.08767 .01472 L
.0877 .01472 L
Mistroke
.08772 .01472 L
.08776 .01472 L
.08778 .01472 L
.08781 .01472 L
.08784 .01472 L
.08786 .01472 L
.08788 .01472 L
.08791 .01472 L
.08794 .01472 L
.08796 .01472 L
.08799 .01472 L
.08802 .01472 L
.08805 .01472 L
.08807 .01472 L
.0881 .01472 L
.08812 .01472 L
.08815 .01472 L
.08818 .01472 L
.08821 .01472 L
.08823 .01472 L
.08826 .01472 L
.08829 .01472 L
.0883 .01472 L
.08832 .01472 L
.08835 .01472 L
.08838 .01472 L
.08841 .01472 L
.08844 .01472 L
.08847 .01472 L
.0885 .01472 L
.08852 .01472 L
.08855 .01472 L
.08858 .01472 L
.08861 .01472 L
.08863 .01472 L
.08867 .01472 L
.08869 .01472 L
.08872 .01472 L
.08875 .01472 L
.08877 .01472 L
.08879 .01472 L
.08882 .01472 L
.08885 .01472 L
.08887 .01472 L
.0889 .01472 L
.08893 .01472 L
.08896 .01472 L
.08898 .01472 L
.08901 .01472 L
.08903 .01472 L
Mistroke
.08906 .01472 L
.08909 .01472 L
.08912 .01472 L
.08914 .01472 L
.08917 .01472 L
.0892 .01472 L
.08922 .01472 L
.08923 .01472 L
.08926 .01472 L
.08929 .01472 L
.08932 .01472 L
.08933 .01472 L
.08935 .01472 L
.08938 .01472 L
.08941 .01472 L
.08943 .01472 L
.08946 .01472 L
.08949 .01472 L
.08952 .01472 L
.08955 .01472 L
.08956 .01472 L
.08958 .01472 L
.08961 .01472 L
.08963 .01472 L
.08964 .01472 L
.08967 .01472 L
.0897 .01472 L
.08973 .01472 L
.08976 .01472 L
.08979 .01472 L
.08981 .01472 L
.08984 .01472 L
.08986 .01472 L
.08989 .01472 L
.08992 .01472 L
.08995 .01472 L
.08997 .01472 L
.09 .01472 L
.09003 .01472 L
.09006 .01472 L
.09008 .01472 L
.09011 .01472 L
.09014 .01472 L
.09017 .01472 L
.0902 .01472 L
.09023 .01472 L
.09026 .01472 L
.09028 .01472 L
.09029 .01472 L
.09031 .01472 L
Mistroke
.09033 .01472 L
.09036 .01472 L
.09038 .01472 L
.09041 .01472 L
.09045 .01472 L
.09047 .01472 L
.0905 .01472 L
.09053 .01472 L
.09055 .01472 L
.09058 .01472 L
.09061 .01472 L
.09064 .01472 L
.09067 .01472 L
.0907 .01472 L
.09073 .01472 L
.09076 .01472 L
.09079 .01472 L
.09082 .01472 L
.09084 .01472 L
.09085 .01472 L
.09088 .01472 L
.0909 .01472 L
.09091 .01472 L
.09093 .01472 L
.09095 .01472 L
.09098 .01472 L
.09099 .01472 L
.09101 .01472 L
.09103 .01472 L
.09105 .01472 L
.09106 .01472 L
.09108 .01472 L
.0911 .01472 L
.09111 .01472 L
.09114 .01472 L
.09117 .01472 L
.0912 .01472 L
.09123 .01472 L
.09126 .01472 L
.09129 .01472 L
.09132 .01472 L
.09134 .01472 L
.09137 .01472 L
.0914 .01472 L
.09143 .01472 L
.09146 .01472 L
.09149 .01472 L
.09152 .01472 L
.09155 .01472 L
.09156 .01472 L
Mistroke
.09158 .01472 L
.09161 .01472 L
.09164 .01472 L
.09167 .01472 L
.09169 .01472 L
.09172 .01472 L
.09175 .01472 L
.09178 .01472 L
.0918 .01472 L
.09183 .01472 L
.09185 .01472 L
.09188 .01472 L
.09191 .01472 L
.09194 .01472 L
.09196 .01472 L
.09199 .01472 L
.09201 .01472 L
.09202 .01472 L
.09205 .01472 L
.09208 .01472 L
.09211 .01472 L
.09214 .01472 L
.09217 .01472 L
.0922 .01472 L
.09223 .01472 L
.09225 .01472 L
.09228 .01472 L
.09231 .01472 L
.09234 .01472 L
.09237 .01472 L
.0924 .01472 L
.09242 .01472 L
.09246 .01472 L
.09247 .01472 L
.09249 .01472 L
.09252 .01472 L
.09255 .01472 L
.09258 .01472 L
.0926 .01472 L
.09263 .01472 L
.09266 .01472 L
.09269 .01472 L
.09271 .01472 L
.09274 .01472 L
.09276 .01472 L
.09279 .01472 L
.09282 .01472 L
.09285 .01472 L
.09287 .01472 L
.0929 .01472 L
Mistroke
.09292 .01472 L
.09293 .01472 L
.09296 .01472 L
.09299 .01472 L
.09302 .01472 L
.09304 .01472 L
.09305 .01472 L
.09308 .01472 L
.09311 .01472 L
.09314 .01472 L
.09316 .01472 L
.09319 .01472 L
.09322 .01472 L
.09325 .01472 L
.09326 .01472 L
.09328 .01472 L
.09331 .01472 L
.09333 .01472 L
.09335 .01472 L
.09337 .01472 L
.09341 .01472 L
.09344 .01472 L
.09346 .01472 L
.09349 .01472 L
.09351 .01472 L
.09354 .01472 L
.09356 .01472 L
.09359 .01472 L
.09362 .01472 L
.09365 .01472 L
.09368 .01472 L
.09371 .01472 L
.09373 .01472 L
.09376 .01472 L
.09379 .01472 L
.09382 .01472 L
.09385 .01472 L
.09387 .01472 L
.0939 .01472 L
.09393 .01472 L
.09396 .01472 L
.09398 .01472 L
.09399 .01472 L
.09401 .01472 L
.09403 .01472 L
.09406 .01472 L
.09409 .01472 L
.09412 .01472 L
.09415 .01472 L
.09417 .01472 L
Mistroke
.0942 .01472 L
.09423 .01472 L
.09425 .01472 L
.09428 .01472 L
.09431 .01472 L
.09434 .01472 L
.09437 .01472 L
.0944 .01472 L
.09443 .01472 L
.09446 .01472 L
.09449 .01472 L
.09452 .01472 L
.09454 .01472 L
.09455 .01472 L
.09458 .01472 L
.0946 .01472 L
.09462 .01472 L
.09463 .01472 L
.09465 .01472 L
.09468 .01472 L
.0947 .01472 L
.09471 .01472 L
.09473 .01472 L
.09475 .01472 L
.09477 .01472 L
.09478 .01472 L
.0948 .01472 L
.09481 .01472 L
.09484 .01472 L
.09487 .01472 L
.0949 .01472 L
.09493 .01472 L
.09496 .01472 L
.09499 .01472 L
.09502 .01472 L
.09504 .01472 L
.09507 .01472 L
.0951 .01472 L
.09513 .01472 L
.09516 .01472 L
.09519 .01472 L
.09522 .01472 L
.09525 .01472 L
.09527 .01472 L
.09528 .01472 L
.09531 .01472 L
.09534 .01472 L
.09537 .01472 L
.0954 .01472 L
.09543 .01472 L
Mistroke
.09545 .01472 L
.09548 .01472 L
.0955 .01472 L
.09553 .01472 L
.09555 .01472 L
.09558 .01472 L
.09561 .01472 L
.09564 .01472 L
.09566 .01472 L
.09569 .01472 L
.09571 .01472 L
.09572 .01472 L
.09575 .01472 L
.09578 .01472 L
.09581 .01472 L
.09584 .01472 L
.09587 .01472 L
.0959 .01472 L
.09593 .01472 L
.09595 .01472 L
.09598 .01472 L
.09601 .01472 L
.09604 .01472 L
.09607 .01472 L
.0961 .01472 L
.09613 .01472 L
.09616 .01472 L
.09618 .01472 L
.09619 .01472 L
.09622 .01472 L
.09625 .01472 L
.09628 .01472 L
.09631 .01472 L
.09633 .01472 L
.09636 .01472 L
.09639 .01472 L
.09641 .01472 L
.09644 .01472 L
.09646 .01472 L
.09649 .01472 L
.09652 .01472 L
.09655 .01472 L
.09657 .01472 L
.0966 .01472 L
.09662 .01472 L
.09663 .01472 L
.09666 .01472 L
.09669 .01472 L
.09672 .01472 L
.09675 .01472 L
Mistroke
.09678 .01472 L
.09681 .01472 L
.09684 .01472 L
.09686 .01472 L
.09689 .01472 L
.09692 .01472 L
.09695 .01472 L
.09698 .01472 L
.09701 .01472 L
.09704 .01472 L
.09707 .01472 L
.09709 .01472 L
.0971 .01472 L
.09713 .01472 L
.09716 .01472 L
.09719 .01472 L
.09722 .01472 L
.09725 .01472 L
.09727 .01472 L
.0973 .01472 L
.09732 .01472 L
.09735 .01472 L
.09737 .01472 L
.0974 .01472 L
.09743 .01472 L
.09746 .01472 L
.09748 .01472 L
.09751 .01472 L
.09753 .01472 L
.09755 .01472 L
.09757 .01472 L
.0976 .01472 L
.09763 .01472 L
.09765 .01472 L
.09766 .01472 L
.09769 .01472 L
.09772 .01472 L
.09775 .01472 L
.09777 .01472 L
.0978 .01472 L
.09783 .01472 L
.09786 .01472 L
.09788 .01472 L
.09789 .01472 L
.09792 .01472 L
.09794 .01472 L
.09796 .01472 L
.09799 .01472 L
.09802 .01472 L
.09805 .01472 L
Mistroke
.09808 .01472 L
.0981 .01472 L
.09813 .01472 L
.09815 .01472 L
.09818 .01472 L
.0982 .01472 L
.09823 .01472 L
.09826 .01472 L
.09829 .01472 L
.09832 .01472 L
.09835 .01472 L
.09837 .01472 L
.0984 .01472 L
.09843 .01472 L
.09846 .01472 L
.09849 .01472 L
.09852 .01472 L
.09855 .01472 L
.09858 .01472 L
.09859 .01472 L
.09861 .01472 L
.09863 .01472 L
.09864 .01472 L
.09867 .01472 L
.0987 .01472 L
.09873 .01472 L
.09876 .01472 L
.09879 .01472 L
.09882 .01472 L
.09884 .01472 L
.09887 .01472 L
.0989 .01472 L
.09893 .01472 L
.09896 .01472 L
.09899 .01472 L
.09901 .01472 L
.09905 .01472 L
.09908 .01472 L
.0991 .01472 L
.09913 .01472 L
.09915 .01472 L
.09917 .01472 L
.0992 .01472 L
.09921 .01472 L
.09923 .01472 L
.09925 .01472 L
.09926 .01472 L
.09929 .01472 L
.09931 .01472 L
.09933 .01472 L
Mistroke
.09934 .01472 L
.09936 .01472 L
.09938 .01472 L
.0994 .01472 L
.09941 .01472 L
.09943 .01472 L
.09946 .01472 L
.09949 .01472 L
.09952 .01472 L
.09955 .01472 L
.09958 .01472 L
.09961 .01472 L
.09963 .01472 L
.09966 .01472 L
.09969 .01472 L
.09971 .01472 L
.09974 .01472 L
.09978 .01472 L
.0998 .01472 L
.09983 .01472 L
.09986 .01472 L
.09988 .01472 L
.0999 .01472 L
.09993 .01472 L
.09996 .01472 L
.09998 .01472 L
.10001 .01472 L
.10004 .01472 L
.10007 .01472 L
.10009 .01472 L
.10012 .01472 L
.10014 .01472 L
.10017 .01472 L
.1002 .01472 L
.10023 .01472 L
.10025 .01472 L
.10028 .01472 L
.10031 .01472 L
.10032 .01472 L
.10034 .01472 L
.10037 .01472 L
.1004 .01472 L
.10043 .01472 L
.10046 .01472 L
.10049 .01472 L
.10052 .01472 L
.10054 .01472 L
.10057 .01472 L
.1006 .01472 L
.10062 .01472 L
Mistroke
.10065 .01472 L
.10069 .01472 L
.10071 .01472 L
.10074 .01472 L
.10077 .01472 L
.10079 .01472 L
.10081 .01472 L
.10084 .01472 L
.10087 .01472 L
.10089 .01472 L
.10092 .01472 L
.10095 .01472 L
.10098 .01472 L
.101 .01472 L
.10103 .01472 L
.10105 .01472 L
.10108 .01472 L
.10111 .01472 L
.10114 .01472 L
.10116 .01472 L
.10119 .01472 L
.10122 .01472 L
.10124 .01472 L
.10125 .01472 L
.10128 .01472 L
.10131 .01472 L
.10134 .01472 L
.10135 .01472 L
.10137 .01472 L
.1014 .01472 L
.10143 .01472 L
.10145 .01472 L
.10148 .01472 L
.10151 .01472 L
.10154 .01472 L
.10157 .01472 L
.10158 .01472 L
.1016 .01472 L
.10163 .01472 L
.10165 .01472 L
.10166 .01472 L
.10169 .01472 L
.10172 .01472 L
.10175 .01472 L
.10178 .01472 L
.10181 .01472 L
.10183 .01472 L
.10186 .01472 L
.10188 .01472 L
.10191 .01472 L
Mistroke
.10194 .01472 L
.10197 .01472 L
.10199 .01472 L
.10202 .01472 L
.10205 .01472 L
.10208 .01472 L
.1021 .01472 L
.10213 .01472 L
.10216 .01472 L
.10219 .01472 L
.10222 .01472 L
.10225 .01472 L
.10228 .01472 L
.1023 .01472 L
.10231 .01472 L
.10233 .01472 L
.10235 .01472 L
.10238 .01472 L
.1024 .01472 L
.10243 .01472 L
.10247 .01472 L
.10249 .01472 L
.10252 .01472 L
.10255 .01472 L
.10257 .01472 L
.1026 .01472 L
.10263 .01472 L
.10266 .01472 L
.10269 .01472 L
.10272 .01472 L
.10275 .01472 L
.10278 .01472 L
.10281 .01472 L
.10284 .01472 L
.10286 .01472 L
.10287 .01472 L
.1029 .01472 L
.10292 .01472 L
.10293 .01472 L
.10295 .01472 L
.10297 .01472 L
.103 .01472 L
.10302 .01472 L
.10303 .01472 L
.10305 .01472 L
.10307 .01472 L
.10308 .01472 L
.1031 .01472 L
.10312 .01472 L
.10313 .01472 L
Mistroke
.10316 .01472 L
.10319 .01472 L
.10322 .01472 L
.10325 .01472 L
.10328 .01472 L
.10331 .01472 L
.10334 .01472 L
.10336 .01472 L
.10339 .01472 L
.10342 .01472 L
.10345 .01472 L
.10348 .01472 L
.10351 .01472 L
.10354 .01472 L
.10357 .01472 L
.10359 .01472 L
.1036 .01472 L
.10363 .01472 L
.10366 .01472 L
.10369 .01472 L
.10372 .01472 L
.10374 .01472 L
.10377 .01472 L
.1038 .01472 L
.10382 .01472 L
.10385 .01472 L
.10387 .01472 L
.1039 .01472 L
.10393 .01472 L
.10396 .01472 L
.10398 .01472 L
.10401 .01472 L
.10403 .01472 L
.10404 .01472 L
.10407 .01472 L
.1041 .01472 L
.10413 .01472 L
.10416 .01472 L
.10419 .01472 L
.10422 .01472 L
.10425 .01472 L
.10427 .01472 L
.1043 .01472 L
.10433 .01472 L
.10436 .01472 L
.10439 .01472 L
.10442 .01472 L
.10445 .01472 L
.10448 .01472 L
.1045 .01472 L
Mistroke
.10451 .01472 L
.10454 .01472 L
.10457 .01472 L
.1046 .01472 L
.10463 .01472 L
.10466 .01472 L
.10468 .01472 L
.10471 .01472 L
.10473 .01472 L
.10476 .01472 L
.10478 .01472 L
.10481 .01472 L
.10484 .01472 L
.10487 .01472 L
.10489 .01472 L
.10492 .01472 L
.10494 .01472 L
.10495 .01472 L
.10498 .01472 L
.10501 .01472 L
.10504 .01472 L
.10506 .01472 L
.10507 .01472 L
.1051 .01472 L
.10513 .01472 L
.10516 .01472 L
.10518 .01472 L
.10521 .01472 L
.10524 .01472 L
.10527 .01472 L
.10529 .01472 L
.1053 .01472 L
.10533 .01472 L
.10535 .01472 L
.10537 .01472 L
.1054 .01472 L
.10543 .01472 L
.10546 .01472 L
.10548 .01472 L
.10551 .01472 L
.10554 .01472 L
.10556 .01472 L
.10559 .01472 L
.10561 .01472 L
.10564 .01472 L
.10567 .01472 L
.1057 .01472 L
.10573 .01472 L
.10576 .01472 L
.10578 .01472 L
Mistroke
.10581 .01472 L
.10584 .01472 L
.10587 .01472 L
.1059 .01472 L
.10592 .01472 L
.10596 .01472 L
.10598 .01472 L
.106 .01472 L
.10602 .01472 L
.10603 .01472 L
.10605 .01472 L
.10608 .01472 L
.10611 .01472 L
.10614 .01472 L
.10617 .01472 L
.1062 .01472 L
.10623 .01472 L
.10625 .01472 L
.10628 .01472 L
.10631 .01472 L
.10634 .01472 L
.10637 .01472 L
.10639 .01472 L
.10642 .01472 L
.10645 .01472 L
.10648 .01472 L
.10651 .01472 L
.10654 .01472 L
.10656 .01472 L
.10658 .01472 L
.10661 .01472 L
.10662 .01472 L
.10664 .01472 L
.10665 .01472 L
.10667 .01472 L
.1067 .01472 L
.10672 .01472 L
.10673 .01472 L
.10675 .01472 L
.10677 .01472 L
.10679 .01472 L
.1068 .01472 L
.10682 .01472 L
.10684 .01472 L
.10687 .01472 L
.1069 .01472 L
.10693 .01472 L
.10696 .01472 L
.10699 .01472 L
.10701 .01472 L
Mistroke
.10704 .01472 L
.10707 .01472 L
.1071 .01472 L
.10712 .01472 L
.10715 .01472 L
.10718 .01472 L
.10721 .01472 L
.10724 .01472 L
.10727 .01472 L
.10729 .01472 L
.1073 .01472 L
.10734 .01472 L
.10737 .01472 L
.10739 .01472 L
.10742 .01472 L
.10745 .01472 L
.10748 .01472 L
.1075 .01472 L
.10752 .01472 L
.10755 .01472 L
.10758 .01472 L
.1076 .01472 L
.10763 .01472 L
.10766 .01472 L
.10769 .01472 L
.10772 .01472 L
.10773 .01472 L
.10775 .01472 L
.10778 .01472 L
.10781 .01472 L
.10783 .01472 L
.10787 .01472 L
.1079 .01472 L
.10792 .01472 L
.10795 .01472 L
.10798 .01472 L
.108 .01472 L
.10803 .01472 L
.10806 .01472 L
.10809 .01472 L
.10812 .01472 L
.10815 .01472 L
.10818 .01472 L
.1082 .01472 L
.10821 .01472 L
.10825 .01472 L
.10828 .01472 L
.1083 .01472 L
.10833 .01472 L
.10836 .01472 L
Mistroke
.10839 .01472 L
.10841 .01472 L
.10843 .01472 L
.10846 .01472 L
.10849 .01472 L
.10851 .01472 L
.10854 .01472 L
.10857 .01472 L
.1086 .01472 L
.10863 .01472 L
.10864 .01472 L
.10866 .01472 L
.10869 .01472 L
.10872 .01472 L
.10874 .01472 L
.10876 .01472 L
.10878 .01472 L
.1088 .01472 L
.10883 .01472 L
.10886 .01472 L
.10889 .01472 L
.10891 .01472 L
.10894 .01472 L
.10897 .01472 L
.10899 .01472 L
.109 .01472 L
.10904 .01472 L
.10905 .01472 L
.10907 .01472 L
.1091 .01472 L
.10913 .01472 L
.10916 .01472 L
.10919 .01472 L
.10921 .01472 L
.10924 .01472 L
.10926 .01472 L
.10929 .01472 L
.10932 .01472 L
.10935 .01472 L
.10937 .01472 L
.1094 .01472 L
.10943 .01472 L
.10946 .01472 L
.10948 .01472 L
.10951 .01472 L
.10954 .01472 L
.10957 .01472 L
.1096 .01472 L
.10963 .01472 L
.10966 .01472 L
Mistroke
.10969 .01472 L
.1097 .01472 L
.10972 .01472 L
.10974 .01472 L
.10975 .01472 L
.10978 .01472 L
.10981 .01472 L
.10984 .01472 L
.10987 .01472 L
.1099 .01472 L
.10993 .01472 L
.10995 .01472 L
.10998 .01472 L
.11001 .01472 L
.11004 .01472 L
.11007 .01472 L
.1101 .01472 L
.11012 .01472 L
.11016 .01472 L
.11019 .01472 L
.11021 .01472 L
.11024 .01472 L
.11026 .01472 L
.11028 .01472 L
.11031 .01472 L
.11032 .01472 L
.11034 .01472 L
.11036 .01472 L
.11037 .01472 L
.1104 .60332 L
.11042 .60332 L
.11044 .60332 L
.11047 .60332 L
.1106 .60332 L
.11153 .60332 L
.11253 .60332 L
.11349 .60332 L
.11441 .60332 L
.11539 .60332 L
.11634 .60332 L
.11725 .60332 L
.11821 .60332 L
.11915 .60332 L
.12014 .60332 L
.12109 .60332 L
.12201 .60332 L
.12298 .60332 L
.12392 .60332 L
.12492 .60332 L
.12588 .60332 L
Mistroke
.12681 .60332 L
.12729 .60332 L
.12753 .60332 L
.1276 .60332 L
.12763 .60332 L
.12767 .60332 L
.12768 .60332 L
.1277 .60332 L
.12772 .01472 L
.12773 .01472 L
.12776 .01472 L
.12778 .01472 L
.12779 .01472 L
.12782 .01472 L
.12785 .01472 L
.12788 .01472 L
.12791 .01472 L
.12794 .01472 L
.12795 .01472 L
.12797 .01472 L
.128 .01472 L
.12803 .01472 L
.12806 .01472 L
.12809 .01472 L
.12812 .01472 L
.12815 .01472 L
.12817 .01472 L
.12818 .01472 L
.1282 .01472 L
.12822 .01472 L
.12823 .01472 L
.12825 .01472 L
.12828 .01472 L
.1283 .01472 L
.12833 .01472 L
.12836 .01472 L
.12839 .01472 L
.12842 .01472 L
.12844 .01472 L
.12847 .01472 L
.12849 .01472 L
.12852 .01472 L
.12855 .01472 L
.12858 .01472 L
.1286 .01472 L
.12863 .01472 L
.12865 .01472 L
.12866 .01472 L
.12869 .01472 L
.12872 .01472 L
Mistroke
.12875 .01472 L
.12877 .01472 L
.12879 .01472 L
.12881 .01472 L
.12884 .01472 L
.12887 .01472 L
.1289 .01472 L
.12892 .01472 L
.12895 .01472 L
.12898 .01472 L
.129 .01472 L
.12902 .01472 L
.12905 .01472 L
.12906 .01472 L
.12908 .01472 L
.12911 .01472 L
.12914 .01472 L
.12917 .01472 L
.1292 .01472 L
.12922 .01472 L
.12925 .01472 L
.12928 .01472 L
.1293 .01472 L
.12933 .01472 L
.12936 .01472 L
.12939 .01472 L
.12941 .01472 L
.12944 .01472 L
.12947 .01472 L
.12949 .01472 L
.12952 .01472 L
.12955 .01472 L
.12958 .01472 L
.12961 .01472 L
.12964 .01472 L
.12966 .01472 L
.12967 .01472 L
.1297 .01472 L
.12973 .01472 L
.12975 .01472 L
.12977 .01472 L
.1298 .01472 L
.12983 .01472 L
.12984 .01472 L
.12986 .01472 L
.12989 .01472 L
.12991 .01472 L
.12994 .01472 L
.12998 .01472 L
.13 .01472 L
Mistroke
.13003 .01472 L
.13006 .01472 L
.13008 .01472 L
.13011 .01472 L
.13014 .01472 L
.13017 .01472 L
.13019 .01472 L
.13021 .01472 L
.13024 .01472 L
.13027 .01472 L
.1303 .01472 L
.13032 .01472 L
.13035 .01472 L
.13037 .01472 L
.13039 .01472 L
.13042 .01472 L
.13044 .01472 L
.13045 .01472 L
.13047 .01472 L
.13049 .01472 L
.13051 .01472 L
.13052 .01472 L
.13054 .01472 L
.13056 .01472 L
.13059 .01472 L
.13062 .01472 L
.13065 .01472 L
.13066 .01472 L
.13068 .01472 L
.13071 .01472 L
.13074 .01472 L
.13076 .01472 L
.13079 .01472 L
.13082 .01472 L
.13084 .01472 L
.13088 .01472 L
.13089 .01472 L
.13091 .01472 L
.13094 .01472 L
.13096 .01472 L
.13097 .01472 L
.131 .01472 L
.13103 .01472 L
.13106 .01472 L
.13109 .01472 L
.13111 .01472 L
.13114 .01472 L
.13117 .01472 L
.13119 .01472 L
.13122 .01472 L
Mistroke
.13125 .01472 L
.13128 .01472 L
.1313 .01472 L
.13133 .01472 L
.13136 .01472 L
.13138 .01472 L
.13141 .01472 L
.13144 .01472 L
.13147 .01472 L
.1315 .01472 L
.13153 .01472 L
.13156 .01472 L
.13159 .01472 L
.13161 .01472 L
.13162 .01472 L
.13164 .01472 L
.13166 .01472 L
.13169 .01472 L
.13171 .01472 L
.13173 .01472 L
.13175 .01472 L
.13178 .01472 L
.13181 .01472 L
.13183 .01472 L
.13186 .01472 L
.13189 .01472 L
.13192 .01472 L
.13194 .01472 L
.13197 .01472 L
.132 .01472 L
.13203 .01472 L
.13206 .01472 L
.13208 .01472 L
.13209 .01472 L
.13212 .01472 L
.13215 .01472 L
.13218 .01472 L
.13221 .01472 L
.13224 .01472 L
.13226 .01472 L
.13227 .01472 L
.13231 .01472 L
.13232 .01472 L
.13234 .01472 L
.13236 .01472 L
.13238 .01472 L
.13239 .01472 L
.13241 .01472 L
.13243 .01472 L
.13244 .01472 L
Mistroke
.13247 .01472 L
.1325 .01472 L
.13253 .01472 L
.13256 .01472 L
.13259 .01472 L
.13262 .01472 L
.13265 .01472 L
.13267 .01472 L
.1327 .01472 L
.13273 .01472 L
.13276 .01472 L
.13279 .01472 L
.13282 .01472 L
.13285 .01472 L
.13288 .01472 L
.1329 .01472 L
.13291 .01472 L
.13294 .01472 L
.13297 .01472 L
.133 .01472 L
.13303 .01472 L
.13306 .01472 L
.13308 .01472 L
.13311 .01472 L
.13313 .01472 L
.13316 .01472 L
.13319 .01472 L
.13321 .01472 L
.13324 .01472 L
.13327 .01472 L
.1333 .01472 L
.13332 .01472 L
.13334 .01472 L
.13336 .01472 L
.13338 .01472 L
.13341 .01472 L
.13344 .01472 L
.13346 .01472 L
.13348 .01472 L
.1335 .01472 L
.13353 .01472 L
.13356 .01472 L
.13359 .01472 L
.13361 .01472 L
.13364 .01472 L
.13367 .01472 L
.13369 .01472 L
.1337 .01472 L
.13374 .01472 L
.13375 .01472 L
Mistroke
.13377 .01472 L
.1338 .01472 L
.13383 .01472 L
.13386 .01472 L
.13389 .01472 L
.13391 .01472 L
.13394 .01472 L
.13396 .01472 L
.13399 .01472 L
.13402 .01472 L
.13405 .01472 L
.13407 .01472 L
.1341 .01472 L
.13413 .01472 L
.13416 .01472 L
.13418 .01472 L
.13421 .01472 L
.13424 .01472 L
.13427 .01472 L
.1343 .01472 L
.13433 .01472 L
.13436 .01472 L
.13439 .01472 L
.1344 .01472 L
.13442 .01472 L
.13444 .01472 L
.13445 .01472 L
.13448 .01472 L
.13451 .01472 L
.13454 .01472 L
.13457 .01472 L
.1346 .01472 L
.13463 .01472 L
.13465 .01472 L
.13468 .01472 L
.13471 .01472 L
.13474 .01472 L
.13477 .01472 L
.1348 .01472 L
.13483 .01472 L
.13486 .01472 L
.13489 .01472 L
.13491 .01472 L
.13494 .01472 L
.13496 .01472 L
.13498 .01472 L
.13501 .01472 L
.13502 .01472 L
.13504 .01472 L
.13506 .01472 L
Mistroke
.13507 .01472 L
.1351 .01472 L
.13512 .01472 L
.13514 .01472 L
.13516 .01472 L
.13517 .01472 L
.13519 .01472 L
.13521 .01472 L
.13522 .01472 L
.13524 .01472 L
.13527 .01472 L
.1353 .01472 L
.13533 .01472 L
.13536 .01472 L
.13539 .01472 L
.13542 .01472 L
.13544 .01472 L
.13547 .01472 L
.1355 .01472 L
.13553 .01472 L
.13555 .01472 L
.13559 .01472 L
.13561 .01472 L
.13564 .01472 L
.13567 .01472 L
.13569 .01472 L
.13571 .01472 L
.13574 .01472 L
.13577 .01472 L
.13579 .01472 L
.13582 .01472 L
.13585 .01472 L
.13588 .01472 L
.1359 .01472 L
.13593 .01472 L
.13595 .01472 L
.13598 .01472 L
.13601 .01472 L
.13604 .01472 L
.13606 .01472 L
.13609 .01472 L
.13612 .01472 L
.13613 .01472 L
.13615 .01472 L
.13618 .01472 L
.13621 .01472 L
.13624 .01472 L
.13627 .01472 L
.1363 .01472 L
.13633 .01472 L
Mistroke
.13635 .01472 L
.13638 .01472 L
.13641 .01472 L
.13644 .01472 L
.13646 .01472 L
.1365 .01472 L
.13652 .01472 L
.13655 .01472 L
.13658 .01472 L
.1366 .01472 L
.13662 .01472 L
.13665 .01472 L
.13668 .01472 L
.1367 .01472 L
.13673 .01472 L
.13676 .01472 L
.13679 .01472 L
.13681 .01472 L
.13684 .01472 L
.13686 .01472 L
.13689 .01472 L
.13692 .01472 L
.13695 .01472 L
.13697 .01472 L
.137 .01472 L
.13703 .01472 L
.13705 .01472 L
.13706 .01472 L
.13709 .01472 L
.13712 .01472 L
.13715 .01472 L
.13716 .01472 L
.13718 .01472 L
.13721 .01472 L
.13724 .01472 L
.13726 .01472 L
.13729 .01472 L
.13732 .01472 L
.13735 .01472 L
.13738 .01472 L
.13739 .01472 L
.13741 .01472 L
.13744 .01472 L
.13746 .01472 L
.13747 .01472 L
.1375 .01472 L
.13753 .01472 L
.13756 .01472 L
.13759 .01472 L
.13762 .01472 L
Mistroke
.13764 .01472 L
.13767 .01472 L
.13769 .01472 L
.13772 .01472 L
.13775 .01472 L
.13778 .01472 L
.1378 .01472 L
.13783 .01472 L
.13786 .01472 L
.13789 .01472 L
.13791 .01472 L
.13794 .01472 L
.13797 .01472 L
.138 .01472 L
.13803 .01472 L
.13806 .01472 L
.13809 .01472 L
.13811 .01472 L
.13812 .01472 L
.13814 .01472 L
.13816 .01472 L
.13819 .01472 L
.13821 .01472 L
.13824 .01472 L
.13828 .01472 L
.1383 .01472 L
.13833 .01472 L
.13836 .01472 L
.13838 .01472 L
.13841 .01472 L
.13844 .01472 L
.13847 .01472 L
.1385 .01472 L
.13853 .01472 L
.13856 .01472 L
.13859 .01472 L
.13862 .01472 L
.13865 .01472 L
.13867 .01472 L
.13868 .01472 L
.13871 .01472 L
.13873 .01472 L
.13874 .01472 L
.13876 .01472 L
.13878 .01472 L
.13881 .01472 L
.13883 .01472 L
.13884 .01472 L
.13886 .01472 L
.13888 .01472 L
Mistroke
.13889 .01472 L
.13891 .01472 L
.13893 .01472 L
.13894 .01472 L
.13897 .01472 L
.139 .01472 L
.13903 .01472 L
.13906 .01472 L
.13909 .01472 L
.13912 .01472 L
.13915 .01472 L
.13917 .01472 L
.1392 .01472 L
.13923 .01472 L
.13926 .01472 L
.13929 .01472 L
.13932 .01472 L
.13935 .01472 L
.13938 .01472 L
.13939 .01472 L
.13941 .01472 L
.13944 .01472 L
.13947 .01472 L
.1395 .01472 L
.13952 .01472 L
.13955 .01472 L
.13958 .01472 L
.13961 .01472 L
.13963 .01472 L
.13966 .01472 L
.13968 .01472 L
.13971 .01472 L
.13974 .01472 L
.13977 .01472 L
.13979 .01472 L
.13982 .01472 L
.13984 .01472 L
.13985 .01472 L
.13988 .01472 L
.13991 .01472 L
.13994 .01472 L
.13997 .01472 L
.14 .01472 L
.14003 .01472 L
.14006 .01472 L
.14008 .01472 L
.14011 .01472 L
.14014 .01472 L
.14017 .01472 L
.1402 .01472 L
Mistroke
.14023 .01472 L
.14026 .01472 L
.14029 .01472 L
.1403 .01472 L
.14032 .01472 L
.14035 .01472 L
.14038 .01472 L
.14041 .01472 L
.14044 .01472 L
.14046 .01472 L
.14049 .01472 L
.14052 .01472 L
.14054 .01472 L
.14057 .01472 L
.14059 .01472 L
.14062 .01472 L
.14065 .01472 L
.14068 .01472 L
.1407 .01472 L
.14073 .01472 L
.14075 .01472 L
.14076 .01472 L
.14079 .01472 L
.14082 .01472 L
.14085 .01472 L
.14087 .01472 L
.14088 .01472 L
.14091 .01472 L
.14094 .01472 L
.14097 .01472 L
.14099 .01472 L
.14102 .01472 L
.14105 .01472 L
.14108 .01472 L
.1411 .01472 L
.14111 .01472 L
.14114 .01472 L
.14116 .01472 L
.14118 .01472 L
.14121 .01472 L
.14124 .01472 L
.14127 .01472 L
.14129 .01472 L
.14132 .01472 L
.14135 .01472 L
.14137 .01472 L
.14139 .01472 L
.14142 .01472 L
.14145 .01472 L
.14148 .01472 L
Mistroke
.14151 .01472 L
.14154 .01472 L
.14156 .01472 L
.14159 .01472 L
.14162 .01472 L
.14165 .01472 L
.14168 .01472 L
.1417 .01472 L
.14173 .01472 L
.14176 .01472 L
.14179 .01472 L
.14181 .01472 L
.14183 .01472 L
.14184 .01472 L
.14186 .01472 L
.14189 .01472 L
.14192 .01472 L
.14195 .01472 L
.14198 .01472 L
.14201 .01472 L
.14203 .01472 L
.14206 .01472 L
.14209 .01472 L
.14211 .01472 L
.14215 .01472 L
.14218 .01472 L
.1422 .01472 L
.14223 .01472 L
.14226 .01472 L
.14229 .01472 L
.14232 .01472 L
.14235 .01472 L
.14237 .01472 L
.14238 .01472 L
.14241 .01472 L
.14243 .01472 L
.14245 .01472 L
.14246 .01472 L
.14248 .01472 L
.14251 .01472 L
.14253 .01472 L
.14254 .01472 L
.14256 .01472 L
.14258 .01472 L
.1426 .01472 L
.14261 .01472 L
.14263 .01472 L
.14265 .01472 L
.14267 .01472 L
.14271 .01472 L
Mistroke
.14273 .01472 L
.14277 .01472 L
.1428 .01472 L
.14282 .01472 L
.14285 .01472 L
.14288 .01472 L
.1429 .01472 L
.14293 .01472 L
.14296 .01472 L
.14299 .01472 L
.14302 .01472 L
.14305 .01472 L
.14308 .01472 L
.1431 .01472 L
.14311 .01472 L
.14314 .01472 L
.14317 .01472 L
.1432 .01472 L
.14323 .01472 L
.14326 .01472 L
.14328 .01472 L
.14331 .01472 L
.14333 .01472 L
.14336 .01472 L
.14338 .01472 L
.14341 .01472 L
.14344 .01472 L
.14347 .01472 L
.14349 .01472 L
.14352 .01472 L
.14354 .01472 L
.14356 .01472 L
.14358 .01472 L
.14361 .01472 L
.14364 .01472 L
.14367 .01472 L
.1437 .01472 L
.14373 .01472 L
.14376 .01472 L
.14378 .01472 L
.14381 .01472 L
.14384 .01472 L
.14387 .01472 L
.1439 .01472 L
.14393 .01472 L
.14396 .01472 L
.14399 .01472 L
.14401 .01472 L
.14402 .01472 L
.14405 .01472 L
Mistroke
.14408 .01472 L
.14411 .01472 L
.14414 .01472 L
.14417 .01472 L
.14419 .01472 L
.14422 .01472 L
.14424 .01472 L
.14427 .01472 L
.14429 .01472 L
.14432 .01472 L
.14435 .01472 L
.14438 .01472 L
.1444 .01472 L
.14443 .01472 L
.14445 .01472 L
.14447 .01472 L
.14449 .01472 L
.14452 .01472 L
.14455 .01472 L
.14457 .01472 L
.14458 .01472 L
.14461 .01472 L
.14464 .01472 L
.14467 .01472 L
.14469 .01472 L
.14472 .01472 L
.14475 .01472 L
.14478 .01472 L
.1448 .01472 L
.14481 .01472 L
.14484 .01472 L
.14486 .01472 L
.14488 .01472 L
.14491 .01472 L
.14494 .01472 L
.14497 .01472 L
.14499 .01472 L
.14502 .01472 L
.14505 .01472 L
.14507 .01472 L
.1451 .01472 L
.14512 .01472 L
.14515 .01472 L
.14518 .01472 L
.14521 .01472 L
.14524 .01472 L
.14527 .01472 L
.14529 .01472 L
.14532 .01472 L
.14535 .01472 L
Mistroke
.14538 .01472 L
.14541 .01472 L
.14543 .01472 L
.14547 .01472 L
.1455 .01472 L
.14551 .01472 L
.14553 .01472 L
.14554 .01472 L
.14556 .01472 L
.14559 .01472 L
.14562 .01472 L
.14565 .01472 L
.14568 .01472 L
.14571 .01472 L
.14574 .01472 L
.14576 .01472 L
.14579 .01472 L
.14582 .01472 L
.14585 .01472 L
.14588 .01472 L
.1459 .01472 L
.14593 .01472 L
.14596 .01472 L
.14599 .01472 L
.14602 .01472 L
.14605 .01472 L
.14607 .01472 L
.14609 .01472 L
.14612 .01472 L
.14613 .01472 L
.14615 .01472 L
.14616 .01472 L
.14618 .01472 L
.14621 .01472 L
.14623 .01472 L
.14624 .01472 L
.14626 .01472 L
.14628 .01472 L
.1463 .01472 L
.14631 .01472 L
.14633 .01472 L
.14635 .01472 L
.14638 .01472 L
.14641 .01472 L
.14644 .01472 L
.14647 .01472 L
.1465 .01472 L
.14652 .01472 L
.14655 .01472 L
.14658 .01472 L
Mistroke
.14661 .01472 L
.14663 .01472 L
.14666 .01472 L
.14669 .01472 L
.14672 .01472 L
.14675 .01472 L
.14678 .01472 L
.1468 .01472 L
.14681 .01472 L
.14685 .01472 L
.14688 .01472 L
.1469 .01472 L
.14693 .01472 L
.14696 .01472 L
.14698 .01472 L
.14701 .01472 L
.14703 .01472 L
.14706 .01472 L
.14709 .01472 L
.14711 .01472 L
.14714 .01472 L
.14717 .01472 L
.1472 .01472 L
.14722 .01472 L
.14724 .01472 L
.14726 .01472 L
.14728 .01472 L
.14731 .01472 L
.14734 .01472 L
.14738 .01472 L
.14741 .01472 L
.14743 .01472 L
.14746 .01472 L
.14749 .01472 L
.14751 .01472 L
.14754 .01472 L
.14757 .01472 L
.1476 .01472 L
.14763 .01472 L
.14766 .01472 L
.14769 .01472 L
.14771 .01472 L
.14772 .01472 L
.14775 .01472 L
.14778 .01472 L
.14781 .01472 L
.14784 .01472 L
.14787 .01472 L
.14789 .01472 L
.14792 .01472 L
Mistroke
.14794 .01472 L
.14797 .01472 L
.148 .01472 L
.14802 .01472 L
.14805 .01472 L
.14808 .01472 L
.1481 .01472 L
.14813 .01472 L
.14815 .01472 L
.14817 .01472 L
.14819 .01472 L
.14822 .01472 L
.14825 .01472 L
.14829 .01472 L
.14832 .01472 L
.14834 .01472 L
.14837 .01472 L
.1484 .01472 L
.14842 .01472 L
.14845 .01472 L
.14848 .01472 L
.14851 .01472 L
.14854 .01472 L
.14857 .01472 L
.1486 .01472 L
.14862 .01472 L
.14863 .01472 L
.14867 .01472 L
.1487 .01472 L
.14872 .01472 L
.14875 .01472 L
.14878 .01472 L
.1488 .01472 L
.14883 .01472 L
.14885 .01472 L
.14888 .01472 L
.14891 .01472 L
.14893 .01472 L
.14896 .01472 L
.14899 .01472 L
.14902 .01472 L
.14905 .01472 L
.14906 .01472 L
.14908 .01472 L
.14911 .01472 L
.14914 .01472 L
.14916 .01472 L
.14918 .01472 L
.1492 .01472 L
.14922 .01472 L
Mistroke
.14925 .01472 L
.14928 .01472 L
.14931 .01472 L
.14933 .01472 L
.14936 .01472 L
.14939 .01472 L
.14941 .01472 L
.14943 .01472 L
.14946 .01472 L
.14947 .01472 L
.14949 .01472 L
.14952 .01472 L
.14955 .01472 L
.14958 .01472 L
.14961 .01472 L
.14963 .01472 L
.14966 .01472 L
.14969 .01472 L
.14971 .01472 L
.14974 .01472 L
.14977 .01472 L
.14979 .01472 L
.14982 .01472 L
.14985 .01472 L
.14988 .01472 L
.1499 .01472 L
.14993 .01472 L
.14996 .01472 L
.14999 .01472 L
.15002 .01472 L
.15005 .01472 L
.15008 .01472 L
.15011 .01472 L
.15012 .01472 L
.15014 .01472 L
.15016 .01472 L
.15017 .01472 L
.1502 .01472 L
.15023 .01472 L
.15026 .01472 L
.15029 .01472 L
.15032 .01472 L
.15035 .01472 L
.15038 .01472 L
.1504 .01472 L
.15043 .01472 L
.15046 .01472 L
.15049 .01472 L
.15052 .01472 L
.15055 .01472 L
Mistroke
.15058 .01472 L
.15061 .01472 L
.15063 .01472 L
.15066 .01472 L
.15068 .01472 L
.1507 .01472 L
.15073 .01472 L
.15074 .01472 L
.15076 .01472 L
.15078 .01472 L
.15079 .01472 L
.15083 .01472 L
.15084 .01472 L
.15086 .01472 L
.15088 .01472 L
.15089 .01472 L
.15091 .01472 L
.15093 .01472 L
.15094 .01472 L
.15096 .01472 L
.15099 .01472 L
.15102 .01472 L
.15105 .01472 L
.15108 .01472 L
.15111 .01472 L
.15114 .01472 L
.15117 .01472 L
.15119 .01472 L
.15122 .01472 L
.15125 .01472 L
.15128 .01472 L
.15131 .01472 L
.15133 .01472 L
.15136 .01472 L
.15139 .01472 L
.15141 .01472 L
.15143 .01472 L
.15146 .01472 L
.15149 .01472 L
.15151 .01472 L
.15154 .01472 L
.15157 .01472 L
.1516 .01472 L
.15162 .01472 L
.15165 .01472 L
.15167 .01472 L
.1517 .01472 L
.15173 .01472 L
.15176 .01472 L
.15178 .01472 L
Mistroke
.15181 .01472 L
.15184 .01472 L
.15186 .01472 L
.15187 .01472 L
.1519 .01472 L
.15193 .01472 L
.15196 .01472 L
.15199 .01472 L
.15202 .01472 L
.15205 .01472 L
.15208 .01472 L
.1521 .01472 L
.15213 .01472 L
.15216 .01472 L
.15219 .01472 L
.15222 .01472 L
.15224 .01472 L
.15227 .01472 L
.1523 .01472 L
.15232 .01472 L
.15234 .01472 L
.15237 .01472 L
.1524 .01472 L
.15243 .01472 L
.15245 .01472 L
.15248 .01472 L
.15251 .01472 L
.15253 .01472 L
.15256 .01472 L
.15259 .01472 L
.15261 .01472 L
.15264 .01472 L
.15267 .01472 L
.1527 .01472 L
.15272 .01472 L
.15275 .01472 L
.15277 .01472 L
.15278 .01472 L
.15281 .01472 L
.15284 .01472 L
.15287 .01472 L
.15289 .01472 L
.1529 .01472 L
.15293 .01472 L
.15296 .01472 L
.15299 .01472 L
.15301 .01472 L
.15304 .01472 L
.15307 .01472 L
.1531 .01472 L
Mistroke
.15311 .01472 L
.15313 .01472 L
.15316 .01472 L
.15318 .01472 L
.15319 .01472 L
.15322 .01472 L
.15325 .01472 L
.15328 .01472 L
.15331 .01472 L
.15334 .01472 L
.15336 .01472 L
.15339 .01472 L
.15341 .01472 L
.15344 .01472 L
.15347 .01472 L
.1535 .01472 L
.15353 .01472 L
.15355 .01472 L
.15358 .01472 L
.15361 .01472 L
.15363 .01472 L
.15366 .01472 L
.1537 .01472 L
.15372 .01472 L
.15375 .01472 L
.15378 .01472 L
.15381 .01472 L
.15383 .01472 L
.15384 .01472 L
.15386 .01472 L
.15388 .01472 L
.15391 .01472 L
.15394 .01472 L
.15397 .01472 L
.154 .01472 L
.15402 .01472 L
.15405 .01472 L
.15408 .01472 L
.1541 .01472 L
.15413 .01472 L
.15416 .01472 L
.15419 .01472 L
.15422 .01472 L
.15425 .01472 L
.15428 .01472 L
.15431 .01472 L
.15434 .01472 L
.15437 .01472 L
.15439 .01472 L
.1544 .01472 L
Mistroke
.15443 .01472 L
.15445 .01472 L
.15447 .01472 L
.15448 .01472 L
.1545 .01472 L
.15453 .01472 L
.15455 .01472 L
.15456 .01472 L
.15458 .01472 L
.1546 .01472 L
.15461 .01472 L
.15463 .01472 L
.15465 .01472 L
.15466 .01472 L
.15469 .01472 L
.15472 .01472 L
.15475 .01472 L
.15478 .01472 L
.15481 .01472 L
.15484 .01472 L
.15487 .01472 L
.15489 .01472 L
.15492 .01472 L
.15495 .01472 L
.15498 .01472 L
.15501 .01472 L
.15504 .01472 L
.15507 .01472 L
.1551 .01472 L
.15512 .01472 L
.15513 .01472 L
.15516 .01472 L
.15519 .01472 L
.15522 .01472 L
.15525 .01472 L
.15528 .01472 L
.1553 .01472 L
.15533 .01472 L
.15535 .01472 L
.15538 .01472 L
.1554 .01472 L
.15543 .01472 L
.15546 .01472 L
.15549 .01472 L
.15551 .01472 L
.15554 .01472 L
.15556 .01472 L
.15557 .01472 L
.1556 .01472 L
.15563 .01472 L
Mistroke
.15566 .01472 L
.15569 .01472 L
.15572 .01472 L
.15575 .01472 L
.15578 .01472 L
.1558 .01472 L
.15583 .01472 L
.15586 .01472 L
.15589 .01472 L
.15592 .01472 L
.15595 .01472 L
.15598 .01472 L
.15601 .01472 L
.15603 .01472 L
.15604 .01472 L
.15607 .01472 L
.1561 .01472 L
.15613 .01472 L
.15616 .01472 L
.15619 .01472 L
.15621 .01472 L
.15624 .01472 L
.15626 .01472 L
.15629 .01472 L
.15631 .01472 L
.15634 .01472 L
.15637 .01472 L
.1564 .01472 L
.15642 .01472 L
.15645 .01472 L
.15647 .01472 L
.15649 .01472 L
.15651 .01472 L
.15654 .01472 L
.15657 .01472 L
.15659 .01472 L
.1566 .01472 L
.15663 .01472 L
.15666 .01472 L
.15669 .01472 L
.15671 .01472 L
.15674 .01472 L
.15677 .01472 L
.1568 .01472 L
.15682 .01472 L
.15683 .01472 L
.15686 .01472 L
.15688 .01472 L
.1569 .01472 L
.15693 .01472 L
Mistroke
.15696 .01472 L
.15699 .01472 L
.15701 .01472 L
.15704 .01472 L
.15707 .01472 L
.15709 .01472 L
.15712 .01472 L
.15714 .01472 L
.15717 .01472 L
.1572 .01472 L
.15723 .01472 L
.15726 .01472 L
.15729 .01472 L
.15731 .01472 L
.15734 .01472 L
.15737 .01472 L
.1574 .01472 L
.15743 .01472 L
.15745 .01472 L
.15749 .01472 L
.15752 .01472 L
.15753 .01472 L
.15755 .01472 L
.15756 .01472 L
.15758 .01472 L
.15761 .01472 L
.15764 .01472 L
.15767 .01472 L
.1577 .01472 L
.15773 .01472 L
.15776 .01472 L
.15778 .01472 L
.15781 .01472 L
.15784 .01472 L
.15787 .01472 L
.1579 .01472 L
.15792 .01472 L
.15795 .01472 L
.15798 .01472 L
.15801 .01472 L
.15804 .01472 L
.15807 .01472 L
.15809 .01472 L
.15811 .01472 L
.15814 .01472 L
.15815 .01472 L
.15817 .01472 L
.15818 .01472 L
.1582 .01472 L
.15823 .01472 L
Mistroke
.15825 .01472 L
.15827 .01472 L
.15828 .01472 L
.1583 .01472 L
.15832 .01472 L
.15834 .01472 L
.15835 .01472 L
.15837 .01472 L
.1584 .01472 L
.15843 .01472 L
.15846 .01472 L
.15849 .01472 L
.15852 .01472 L
.15854 .01472 L
.15857 .01472 L
.1586 .01472 L
.15863 .01472 L
.15865 .01472 L
.15868 .01472 L
.15871 .01472 L
.15874 .01472 L
.15877 .01472 L
.1588 .01472 L
.15882 .01472 L
.15883 .01472 L
.15887 .01472 L
.1589 .01472 L
.15892 .01472 L
.15895 .01472 L
.15898 .01472 L
.15901 .01472 L
.15903 .01472 L
.15905 .01472 L
.15908 .01472 L
.15911 .01472 L
.15913 .01472 L
.15916 .01472 L
.15919 .01472 L
.15922 .01472 L
.15925 .01472 L
.15926 .01472 L
.15928 .01472 L
.15931 .01472 L
.15934 .01472 L
.15936 .01472 L
.1594 .01472 L
.15943 .01472 L
.15945 .01472 L
.15948 .01472 L
.15951 .01472 L
Mistroke
.15953 .01472 L
.15956 .01472 L
.15959 .01472 L
.15962 .01472 L
.15965 .01472 L
.15968 .01472 L
.15971 .01472 L
.15973 .01472 L
.15974 .01472 L
.15978 .01472 L
.15981 .01472 L
.15983 .01472 L
.15986 .01472 L
.15989 .01472 L
.15992 .01472 L
.15994 .01472 L
.15996 .01472 L
.15999 .01472 L
.16002 .01472 L
.16004 .01472 L
.16007 .01472 L
.1601 .01472 L
.16013 .01472 L
.16016 .01472 L
.16017 .01472 L
.16019 .01472 L
.16022 .01472 L
.16025 .01472 L
.16027 .01472 L
.16029 .01472 L
.16031 .01472 L
.16033 .01472 L
.16036 .01472 L
.16039 .01472 L
.16042 .01472 L
.16044 .01472 L
.16047 .01472 L
.1605 .01472 L
.16052 .01472 L
.16053 .01472 L
.16057 .01472 L
.16058 .01472 L
.1606 .01472 L
.16063 .01472 L
.16066 .01472 L
.16069 .01472 L
.16072 .01472 L
.16074 .01472 L
.16077 .01472 L
.16079 .01472 L
Mistroke
.16082 .01472 L
.16085 .01472 L
.16088 .01472 L
.1609 .01472 L
.16093 .01472 L
.16096 .01472 L
.16099 .01472 L
.16101 .01472 L
.16104 .01472 L
.16107 .01472 L
.1611 .01472 L
.16113 .01472 L
.16116 .01472 L
.16119 .01472 L
.16122 .01472 L
.16123 .01472 L
.16125 .01472 L
.16127 .01472 L
.16128 .01472 L
.16131 .01472 L
.16134 .01472 L
.16137 .01472 L
.1614 .01472 L
.16143 .01472 L
.16146 .01472 L
.16148 .01472 L
.16151 .01472 L
.16154 .01472 L
.16157 .01472 L
.1616 .01472 L
.16163 .01472 L
.16165 .01472 L
.16169 .01472 L
.16172 .01472 L
.16174 .01472 L
.16177 .01472 L
.16179 .01472 L
.16181 .01472 L
.16184 .01472 L
.16185 .01472 L
.16187 .01472 L
.16189 .01472 L
.1619 .01472 L
.16193 .01472 L
.16195 .01472 L
.16197 .01472 L
.16198 .01472 L
.162 .01472 L
.16202 .01472 L
.16204 .01472 L
Mistroke
.16205 .01472 L
.16207 .01472 L
.1621 .01472 L
.16213 .01472 L
.16216 .01472 L
.16219 .01472 L
.16222 .01472 L
.16225 .01472 L
.16227 .01472 L
.1623 .01472 L
.16233 .01472 L
.16235 .01472 L
.16238 .01472 L
.16241 .01472 L
.16244 .01472 L
.16247 .01472 L
.1625 .01472 L
.16252 .01472 L
.16254 .01472 L
.16257 .01472 L
.1626 .01472 L
.16262 .01472 L
.16265 .01472 L
.16268 .01472 L
.16271 .01472 L
.16273 .01472 L
.16276 .01472 L
.16278 .01472 L
.16281 .01472 L
.16283 .01472 L
.16286 .01472 L
.16289 .01472 L
.16292 .01472 L
.16295 .01472 L
.16296 .01472 L
.16298 .01472 L
.16301 .01472 L
.16304 .01472 L
.16307 .01472 L
.1631 .01472 L
.16313 .01472 L
.16315 .01472 L
.16318 .01472 L
.16321 .01472 L
.16324 .01472 L
.16326 .01472 L
.16329 .01472 L
.16332 .01472 L
.16335 .01472 L
.16338 .01472 L
Mistroke
.16341 .01472 L
.16343 .01472 L
.16345 .01472 L
.16348 .01472 L
.16351 .01472 L
.16353 .01472 L
.16356 .01472 L
.16359 .01472 L
.16362 .01472 L
.16364 .01472 L
.16366 .01472 L
.16369 .01472 L
.16372 .01472 L
.16374 .01472 L
.16377 .01472 L
.1638 .01472 L
.16383 .01472 L
.16386 .01472 L
.16387 .01472 L
.16389 .01472 L
.16392 .01472 L
.16395 .01472 L
.16398 .01472 L
.16401 .01472 L
.16404 .01472 L
.16407 .01472 L
.16409 .01472 L
.16412 .01472 L
.16415 .01472 L
.16417 .01472 L
.1642 .01472 L
.16423 .01472 L
.16426 .01472 L
.16429 .01472 L
.16432 .01472 L
.16434 .01472 L
.16436 .01472 L
.16439 .01472 L
.16442 .01472 L
.16444 .01472 L
.16447 .01472 L
.1645 .01472 L
.16453 .01472 L
.16455 .01472 L
.16458 .01472 L
.1646 .01472 L
.16463 .01472 L
.16466 .01472 L
.16469 .01472 L
.16471 .01472 L
Mistroke
.16474 .01472 L
.16477 .01472 L
.16478 .01472 L
.1648 .01472 L
.16483 .01472 L
.16486 .01472 L
.16489 .01472 L
.1649 .01472 L
.16492 .01472 L
.16495 .01472 L
.16498 .01472 L
.165 .01472 L
.16503 .01472 L
.16506 .01472 L
.16509 .01472 L
.16511 .01472 L
.16513 .01472 L
.16515 .01472 L
.16518 .01472 L
.1652 .01472 L
.16521 .01472 L
.16524 .01472 L
.16527 .01472 L
.1653 .01472 L
.16533 .01472 L
.16535 .01472 L
.16538 .01472 L
.16541 .01472 L
.16543 .01472 L
.16546 .01472 L
.16549 .01472 L
.16552 .01472 L
.16554 .01472 L
.16557 .01472 L
.1656 .01472 L
.16563 .01472 L
.16565 .01472 L
.16568 .01472 L
.16571 .01472 L
.16574 .01472 L
.16577 .01472 L
.1658 .01472 L
.16583 .01472 L
.16585 .01472 L
.16586 .01472 L
.16588 .01472 L
.1659 .01472 L
.16593 .01472 L
.16595 .01472 L
.16598 .01472 L
Mistroke
.16602 .01472 L
.16604 .01472 L
.16607 .01472 L
.1661 .01472 L
.16612 .01472 L
.16615 .01472 L
.16618 .01472 L
.16621 .01472 L
.16624 .01472 L
.16627 .01472 L
.1663 .01472 L
.16633 .01472 L
.16636 .01472 L
.16639 .01472 L
.1664 .01472 L
.16642 .01472 L
.16645 .01472 L
.16647 .01472 L
.16648 .01472 L
.1665 .01472 L
.16652 .01472 L
.16655 .01472 L
.16656 .01472 L
.16658 .01472 L
.1666 .01472 L
.16662 .01472 L
.16663 .01472 L
.16665 .01472 L
.16667 .01472 L
.16668 .01472 L
.16671 .01472 L
.16674 .01472 L
.16677 .01472 L
.1668 .01472 L
.16683 .01472 L
.16686 .01472 L
.16689 .01472 L
.16691 .01472 L
.16694 .01472 L
.16697 .01472 L
.167 .01472 L
.16703 .01472 L
.16706 .01472 L
.16709 .01472 L
.16712 .01472 L
.16713 .01472 L
.16715 .01472 L
.16718 .01472 L
.16721 .01472 L
.16724 .01472 L
Mistroke
.16726 .01472 L
.16729 .01472 L
.16732 .01472 L
.16735 .01472 L
.16737 .01472 L
.1674 .01472 L
.16742 .01472 L
.16745 .01472 L
.16748 .01472 L
.16751 .01472 L
.16753 .01472 L
.16756 .01472 L
.16758 .01472 L
.16759 .01472 L
.16762 .01472 L
.16765 .01472 L
.16768 .01472 L
.16771 .01472 L
.16774 .01472 L
.16777 .01472 L
.1678 .01472 L
.16782 .01472 L
.16785 .01472 L
.16788 .01472 L
.16791 .01472 L
.16794 .01472 L
.16797 .01472 L
.168 .01472 L
.16803 .01472 L
.16804 .01472 L
.16806 .01472 L
.16809 .01472 L
.16812 .01472 L
.16815 .01472 L
.16818 .01472 L
.1682 .01472 L
.16823 .01472 L
.16826 .01472 L
.16828 .01472 L
.16831 .01472 L
.16833 .01472 L
.16836 .01472 L
.16839 .01472 L
.16842 .01472 L
.16844 .01472 L
.16847 .01472 L
.16849 .01472 L
.1685 .01472 L
.16853 .01472 L
.16856 .01472 L
Mistroke
.16859 .01472 L
.16861 .01472 L
.16862 .01472 L
.16865 .01472 L
.16868 .01472 L
.16871 .01472 L
.16873 .01472 L
.16876 .01472 L
.16879 .01472 L
.16882 .01472 L
.16884 .01472 L
.16885 .01472 L
.16888 .01472 L
.1689 .01472 L
.16892 .01472 L
.16895 .01472 L
.16898 .01472 L
.16901 .01472 L
.16903 .01472 L
.16906 .01472 L
.16909 .01472 L
.16911 .01472 L
.16914 .01472 L
.16916 .01472 L
.16919 .01472 L
.16922 .01472 L
.16925 .01472 L
.16928 .01472 L
.16931 .01472 L
.16933 .01472 L
.16936 .01472 L
.16939 .01472 L
.16942 .01472 L
.16944 .01472 L
.16947 .01472 L
.16951 .01472 L
.16953 .01472 L
.16955 .01472 L
.16957 .01472 L
.16958 .01472 L
.1696 .01472 L
.16963 .01472 L
.16966 .01472 L
.16969 .01472 L
.16972 .01472 L
.16975 .01472 L
.16978 .01472 L
.1698 .01472 L
.16983 .01472 L
.16986 .01472 L
Mistroke
.16989 .01472 L
.16992 .01472 L
.16994 .01472 L
.16997 .01472 L
.17 .01472 L
.17003 .01472 L
.17006 .01472 L
.17009 .01472 L
.17011 .01472 L
.17013 .01472 L
.17016 .01472 L
.17017 .01472 L
.17019 .01472 L
.1702 .01472 L
.17022 .01472 L
.17025 .01472 L
.17027 .01472 L
.17028 .01472 L
.1703 .01472 L
.17032 .01472 L
.17034 .01472 L
.17035 .01472 L
.17037 .01472 L
.17039 .01472 L
.17042 .01472 L
.17045 .01472 L
.17048 .01472 L
.17051 .01472 L
.17054 .01472 L
.17056 .01472 L
.17059 .01472 L
.17062 .01472 L
.17065 .01472 L
.17067 .01472 L
.1707 .01472 L
.17073 .01472 L
.17076 .01472 L
.17079 .01472 L
.17082 .01472 L
.17084 .01472 L
.17085 .01472 L
.17089 .01472 L
.17092 .01472 L
.17094 .01472 L
.17097 .01472 L
.171 .01472 L
.17103 .01472 L
.17105 .01472 L
.17107 .01472 L
.1711 .01472 L
Mistroke
.17113 .01472 L
.17115 .01472 L
.17118 .01472 L
.17121 .01472 L
.17124 .01472 L
.17127 .01472 L
.17128 .01472 L
.1713 .01472 L
.17133 .01472 L
.17136 .01472 L
.17138 .01472 L
.17142 .01472 L
.17145 .01472 L
.17147 .01472 L
.1715 .01472 L
.17153 .01472 L
.17156 .01472 L
.17158 .01472 L
.17161 .01472 L
.17164 .01472 L
.17167 .01472 L
.1717 .01472 L
.17173 .01472 L
.17175 .01472 L
.17176 .01472 L
.1718 .01472 L
.17183 .01472 L
.17185 .01472 L
.17188 .01472 L
.17191 .01472 L
.17194 .01472 L
.17196 .01472 L
.17198 .01472 L
.17201 .01472 L
.17204 .01472 L
.17206 .01472 L
.17209 .01472 L
.17212 .01472 L
.17215 .01472 L
.17218 .01472 L
.17219 .01472 L
.17221 .01472 L
.17224 .01472 L
.17227 .01472 L
.17229 .01472 L
.17231 .01472 L
.17233 .01472 L
.17235 .01472 L
.17238 .01472 L
.17241 .01472 L
Mistroke
.17244 .01472 L
.17246 .01472 L
.17249 .01472 L
.17252 .01472 L
.17254 .01472 L
.17256 .01472 L
.17259 .01472 L
.1726 .01472 L
.17262 .01472 L
.17265 .01472 L
.17268 .01472 L
.17271 .01472 L
.17274 .01472 L
.17276 .01472 L
.17279 .01472 L
.17282 .01472 L
.17284 .01472 L
.17287 .01472 L
.1729 .01472 L
.17292 .01472 L
.17295 .01472 L
.17298 .01472 L
.17301 .01472 L
.17303 .01472 L
.17306 .01472 L
.17309 .01472 L
.17312 .01472 L
.17315 .01472 L
.17318 .01472 L
.17321 .01472 L
.17324 .01472 L
.17325 .01472 L
.17327 .01472 L
.17329 .01472 L
.1733 .01472 L
.17333 .01472 L
.17336 .01472 L
.17339 .01472 L
.17342 .01472 L
.17345 .01472 L
.17348 .01472 L
.17351 .01472 L
.17353 .01472 L
.17356 .01472 L
.17359 .01472 L
.17362 .01472 L
.17365 .01472 L
.17368 .01472 L
.17371 .01472 L
.17374 .01472 L
Mistroke
.17376 .01472 L
.17379 .01472 L
.17381 .01472 L
.17383 .01472 L
.17386 .01472 L
.17388 .01472 L
.17389 .01472 L
.17391 .01472 L
.17392 .01472 L
.17395 .01472 L
.17397 .01472 L
.17399 .01472 L
.17401 .01472 L
.17402 .01472 L
.17404 .01472 L
.17406 .01472 L
.17407 .01472 L
.17409 .01472 L
.17412 .01472 L
.17415 .01472 L
.17418 .01472 L
.17421 .01472 L
.17424 .01472 L
.17427 .01472 L
.17429 .01472 L
.17432 .01472 L
.17435 .01472 L
.17438 .01472 L
.1744 .01472 L
.17444 .01472 L
.17446 .01472 L
.17449 .01472 L
.17452 .01472 L
.17454 .01472 L
.17456 .01472 L
.17459 .01472 L
.17462 .01472 L
.17464 .01472 L
.17467 .01472 L
.1747 .01472 L
.17473 .01472 L
.17475 .01472 L
.17478 .01472 L
.1748 .01472 L
.17483 .01472 L
.17486 .01472 L
.17489 .01472 L
.17491 .01472 L
.17494 .01472 L
.17497 .01472 L
Mistroke
.17498 .01472 L
.175 .01472 L
.17503 .01472 L
.17506 .01472 L
.17509 .01472 L
.17512 .01472 L
.17515 .01472 L
.17518 .01472 L
.1752 .01472 L
.17523 .01472 L
.17526 .01472 L
.17528 .01472 L
.17531 .01472 L
.17535 .01472 L
.17537 .01472 L
.1754 .01472 L
.17543 .01472 L
.17545 .01472 L
.17547 .01472 L
.1755 .01472 L
.17553 .01472 L
.17555 .01472 L
.17558 .01472 L
.17561 .01472 L
.17564 .01472 L
.17566 .01472 L
.17569 .01472 L
.17571 .01472 L
.17574 .01472 L
.17577 .01472 L
.1758 .01472 L
.17582 .01472 L
.17585 .01472 L
.17588 .01472 L
.17589 .01472 L
.17591 .01472 L
.17594 .01472 L
.17597 .01472 L
.176 .01472 L
.17601 .01472 L
.17603 .01472 L
.17606 .01472 L
.17609 .01472 L
.17611 .01472 L
.17614 .01472 L
.17617 .01472 L
.1762 .01472 L
.17622 .01472 L
.17624 .01472 L
.17626 .01472 L
Mistroke
.17629 .01472 L
.17631 .01472 L
.17632 .01472 L
.17635 .01472 L
.17638 .01472 L
.17641 .01472 L
.17644 .01472 L
.17646 .01472 L
.17649 .01472 L
.17652 .01472 L
.17654 .01472 L
.17657 .01472 L
.1766 .01472 L
.17663 .01472 L
.17665 .01472 L
.17668 .01472 L
.17671 .01472 L
.17674 .01472 L
.17676 .01472 L
.17679 .01472 L
.17682 .01472 L
.17685 .01472 L
.17688 .01472 L
.17691 .01472 L
.17694 .01472 L
.17696 .01472 L
.17697 .01472 L
.17699 .01472 L
.17701 .01472 L
.17704 .01472 L
.17706 .01472 L
.17709 .01472 L
.17712 .01472 L
.17715 .01472 L
.17718 .01472 L
.17721 .01472 L
.17723 .01472 L
.17726 .01472 L
.17729 .01472 L
.17732 .01472 L
.17735 .01472 L
.17738 .01472 L
.17741 .01472 L
.17744 .01472 L
.17746 .01472 L
.1775 .01472 L
.17751 .01472 L
.17753 .01472 L
.17756 .01472 L
.17758 .01472 L
Mistroke
.17759 .01472 L
.17761 .01472 L
.17763 .01472 L
.17766 .01472 L
.17767 .01472 L
.17769 .01472 L
.17771 .01472 L
.17773 .01472 L
.17774 .01472 L
.17776 .01472 L
.17778 .01472 L
.17779 .01472 L
.17782 .01472 L
.17785 .01472 L
.17788 .01472 L
.17791 .01472 L
.17794 .01472 L
.17797 .01472 L
.178 .01472 L
.17802 .01472 L
.17805 .01472 L
.17808 .01472 L
.17811 .01472 L
.17814 .01472 L
.17816 .01472 L
.17819 .01472 L
.17823 .01472 L
.17824 .01472 L
.17826 .01472 L
.17829 .01472 L
.17832 .01472 L
.17835 .01472 L
.17837 .01472 L
.1784 .01472 L
.17843 .01472 L
.17845 .01472 L
.17848 .01472 L
.1785 .01472 L
.17853 .01472 L
.17856 .01472 L
.17859 .01472 L
.17861 .01472 L
.17864 .01472 L
.17867 .01472 L
.17869 .01472 L
.1787 .01472 L
.17873 .01472 L
.17876 .01472 L
.17879 .01472 L
.17882 .01472 L
Mistroke
.17885 .01472 L
.17888 .01472 L
.17891 .01472 L
.17893 .01472 L
.17896 .01472 L
.17899 .01472 L
.17902 .01472 L
.17905 .01472 L
.17907 .01472 L
.1791 .01472 L
.17913 .01472 L
.17915 .01472 L
.17917 .01472 L
.1792 .01472 L
.17923 .01472 L
.17925 .01472 L
.17928 .01472 L
.17931 .01472 L
.17934 .01472 L
.17936 .01472 L
.17939 .01472 L
.17941 .01472 L
.17944 .01472 L
.17947 .01472 L
.1795 .01472 L
.17952 .01472 L
.17955 .01472 L
.17958 .01472 L
.1796 .01472 L
.17961 .01472 L
.17964 .01472 L
.17967 .01472 L
.1797 .01472 L
.17973 .01472 L
.17976 .01472 L
.17979 .01472 L
.17981 .01472 L
.17984 .01472 L
.17987 .01472 L
.1799 .01472 L
.17993 .01472 L
.17996 .01472 L
.17998 .01472 L
.18001 .01472 L
.18005 .01472 L
.18006 .01472 L
.18008 .01472 L
.18011 .01472 L
.18014 .01472 L
.18017 .01472 L
Mistroke
.18019 .01472 L
.18022 .01472 L
.18025 .01472 L
.18028 .01472 L
.1803 .01472 L
.18033 .01472 L
.18035 .01472 L
.18038 .01472 L
.18041 .01472 L
.18044 .01472 L
.18046 .01472 L
.18049 .01472 L
.18051 .01472 L
.18052 .01472 L
.18055 .01472 L
.18058 .01472 L
.18061 .01472 L
.18063 .01472 L
.18064 .01472 L
.18067 .01472 L
.1807 .01472 L
.18073 .01472 L
.18075 .01472 L
.18078 .01472 L
.18081 .01472 L
.18084 .01472 L
.18085 .01472 L
.18087 .01472 L
.1809 .01472 L
.18092 .01472 L
.18094 .01472 L
.18096 .01472 L
.181 .01472 L
.18103 .01472 L
.18105 .01472 L
.18108 .01472 L
.1811 .01472 L
.18113 .01472 L
.18115 .01472 L
.18118 .01472 L
.18121 .01472 L
.18124 .01472 L
.18127 .01472 L
.1813 .01472 L
.18132 .01472 L
.18135 .01472 L
.18138 .01472 L
.18141 .01472 L
.18144 .01472 L
.18146 .01472 L
Mistroke
.18149 .01472 L
.18152 .01472 L
.18155 .01472 L
.18157 .01472 L
.18159 .01472 L
.1816 .01472 L
.18162 .01472 L
.18165 .01472 L
.18168 .01472 L
.18171 .01472 L
.18174 .01472 L
.18177 .01472 L
.18179 .01472 L
.18182 .01472 L
.18185 .01472 L
.18187 .01472 L
.18191 .01472 L
.18194 .01472 L
.18196 .01472 L
.18199 .01472 L
.18202 .01472 L
.18205 .01472 L
.18208 .01472 L
.18211 .01472 L
.18213 .01472 L
.18214 .01472 L
.18217 .01472 L
.18219 .01472 L
.18221 .01472 L
.18222 .01472 L
.18224 .01472 L
.18227 .01472 L
.18229 .01472 L
.1823 .01472 L
.18232 .01472 L
.18234 .01472 L
.18236 .01472 L
.18237 .01472 L
.18239 .01472 L
.18241 .01472 L
.18243 .01472 L
.18247 .01472 L
.18249 .01472 L
.18253 .01472 L
.18256 .01472 L
.18258 .01472 L
.18261 .01472 L
.18264 .01472 L
.18266 .01472 L
.18269 .01472 L
Mistroke
.18272 .01472 L
.18275 .01472 L
.18278 .01472 L
.18281 .01472 L
.18284 .01472 L
.18286 .01472 L
.18287 .01472 L
.18291 .01472 L
.18293 .01472 L
.18296 .01472 L
.18299 .01472 L
.18302 .01472 L
.18304 .01472 L
.18307 .01472 L
.18309 .01472 L
.18312 .01472 L
.18315 .01472 L
.18317 .01472 L
.1832 .01472 L
.18323 .01472 L
.18326 .01472 L
.18328 .01472 L
.1833 .01472 L
.18332 .01472 L
.18334 .01472 L
.18337 .01472 L
.1834 .01472 L
.18344 .01472 L
.18347 .01472 L
.18349 .01472 L
.18352 .01472 L
.18355 .01472 L
.18357 .01472 L
.1836 .01472 L
.18363 .01472 L
.18366 .01472 L
.18369 .01472 L
.18372 .01472 L
.18375 .01472 L
.18377 .01472 L
.18378 .01472 L
.18382 .01472 L
.18385 .01472 L
.18387 .01472 L
.1839 .01472 L
.18393 .01472 L
.18396 .01472 L
.18398 .01472 L
.184 .01472 L
.18403 .01472 L
Mistroke
.18406 .01472 L
.18408 .01472 L
.18411 .01472 L
.18414 .01472 L
.18417 .01472 L
.1842 .01472 L
.18421 .01472 L
.18423 .01472 L
.18426 .01472 L
.18429 .01472 L
.18431 .01472 L
.18433 .01472 L
.18435 .01472 L
.18437 .01472 L
.1844 .01472 L
.18443 .01472 L
.18446 .01472 L
.18448 .01472 L
.18451 .01472 L
.18454 .01472 L
.18456 .01472 L
.18458 .01472 L
.18461 .01472 L
.18462 .01472 L
.18464 .01472 L
.18467 .01472 L
.1847 .01472 L
.18473 .01472 L
.18476 .01472 L
.18478 .01472 L
.18481 .01472 L
.18484 .01472 L
.18486 .01472 L
.18489 .01472 L
.18492 .01472 L
.18494 .01472 L
.18497 .01472 L
.185 .01472 L
.18503 .01472 L
.18505 .01472 L
.18508 .01472 L
.18511 .01472 L
.18514 .01472 L
.18517 .01472 L
.1852 .01472 L
.18523 .01472 L
.18526 .01472 L
.18527 .01472 L
.18529 .01472 L
.18531 .01472 L
Mistroke
.18532 .01472 L
.18535 .01472 L
.18538 .01472 L
.18541 .01472 L
.18544 .01472 L
.18547 .01472 L
.1855 .01472 L
.18553 .01472 L
.18555 .01472 L
.18558 .01472 L
.18561 .01472 L
.18564 .01472 L
.18567 .01472 L
.1857 .01472 L
.18573 .01472 L
.18576 .01472 L
.18578 .01472 L
.18581 .01472 L
.18583 .01472 L
.18585 .01472 L
.18588 .01472 L
.18589 .01472 L
.18591 .01472 L
.18593 .01472 L
.18594 .01472 L
.18598 .01472 L
.18599 .01472 L
.18601 .01472 L
.18603 .01472 L
.18604 .01472 L
.18606 .01472 L
.18608 .01472 L
.18609 .01472 L
.18611 .01472 L
.18614 .01472 L
.18617 .01472 L
.1862 .01472 L
.18623 .01472 L
.18626 .01472 L
.18629 .01472 L
.18632 .01472 L
.18634 .01472 L
.18637 .01472 L
.1864 .01472 L
.18643 .01472 L
.18646 .01472 L
.18648 .01472 L
.18651 .01472 L
.18654 .01472 L
.18656 .01472 L
Mistroke
.18658 .01472 L
.18661 .01472 L
.18664 .01472 L
.18666 .01472 L
.18669 .01472 L
.18672 .01472 L
.18675 .01472 L
.18677 .01472 L
.1868 .01472 L
.18682 .01472 L
.18685 .01472 L
.18688 .01472 L
.18691 .01472 L
.18693 .01472 L
.18696 .01472 L
.18699 .01472 L
.18701 .01472 L
.18702 .01472 L
.18705 .01472 L
.18708 .01472 L
.18711 .01472 L
.18714 .01472 L
.18717 .01472 L
.1872 .01472 L
.18723 .01472 L
.18725 .01472 L
.18728 .01472 L
.18731 .01472 L
.18734 .01472 L
.18737 .01472 L
.18739 .01472 L
.18742 .01472 L
.18745 .01472 L
.18747 .01472 L
.18749 .01472 L
.18752 .01472 L
.18755 .01472 L
.18757 .01472 L
.1876 .01472 L
.18763 .01472 L
.18766 .01472 L
.18768 .01472 L
.18771 .01472 L
.18773 .01472 L
.18776 .01472 L
.18779 .01472 L
.18782 .01472 L
.18784 .01472 L
.18787 .01472 L
.1879 .01472 L
Mistroke
.18792 .01472 L
.18793 .01472 L
.18796 .01472 L
.18799 .01472 L
.18802 .01472 L
.18804 .01472 L
.18805 .01472 L
.18808 .01472 L
.18811 .01472 L
.18813 .01472 L
.18816 .01472 L
.18819 .01472 L
.18822 .01472 L
.18825 .01472 L
.18826 .01472 L
.18828 .01472 L
.18831 .01472 L
.18833 .01472 L
.18834 .01472 L
.18837 .01472 L
.1884 .01472 L
.18843 .01472 L
.18846 .01472 L
.18849 .01472 L
.18851 .01472 L
.18854 .01472 L
.18856 .01472 L
.18859 .01472 L
.18862 .01472 L
.18865 .01472 L
.18867 .01472 L
.1887 .01472 L
.18873 .01472 L
.18876 .01472 L
.18878 .01472 L
.18881 .01472 L
.18885 .01472 L
.18887 .01472 L
.1889 .01472 L
.18893 .01472 L
.18896 .01472 L
.18898 .01472 L
.18899 .01472 L
.18901 .01472 L
.18903 .01472 L
.18906 .01472 L
.18908 .01472 L
.18911 .01472 L
.18915 .01472 L
.18917 .01472 L
Mistroke
.1892 .01472 L
.18923 .01472 L
.18925 .01472 L
.18928 .01472 L
.18931 .01472 L
.18934 .01472 L
.18937 .01472 L
.1894 .01472 L
.18943 .01472 L
.18946 .01472 L
.18949 .01472 L
.18952 .01472 L
.18954 .01472 L
.18955 .01472 L
.18958 .01472 L
.1896 .01472 L
.18961 .01472 L
.18963 .01472 L
.18965 .01472 L
.18968 .01472 L
.1897 .01472 L
.18971 .01472 L
.18973 .01472 L
.18975 .01472 L
.18976 .01472 L
.18978 .01472 L
.1898 .01472 L
.18981 .01472 L
.18984 .01472 L
.18987 .01472 L
.1899 .01472 L
.18993 .01472 L
.18996 .01472 L
.18999 .01472 L
.19002 .01472 L
.19004 .01472 L
.19007 .01472 L
.1901 .01472 L
.19013 .01472 L
.19016 .01472 L
.19019 .01472 L
.19022 .01472 L
.19025 .01472 L
.19027 .01472 L
.19028 .01472 L
.19031 .01472 L
.19034 .01472 L
.19037 .01472 L
.1904 .01472 L
.19042 .01472 L
Mistroke
.19045 .01472 L
.19048 .01472 L
.1905 .01472 L
.19053 .01472 L
.19055 .01472 L
.19058 .01472 L
.19061 .01472 L
.19064 .01472 L
.19066 .01472 L
.19069 .01472 L
.19071 .01472 L
.19072 .01472 L
.19075 .01472 L
.19078 .01472 L
.19081 .01472 L
.19084 .01472 L
.19087 .01472 L
.1909 .01472 L
.19093 .01472 L
.19095 .01472 L
.19098 .01472 L
.19101 .01472 L
.19104 .01472 L
.19107 .01472 L
.1911 .01472 L
.19113 .01472 L
.19116 .01472 L
.19118 .01472 L
.19119 .01472 L
.19122 .01472 L
.19125 .01472 L
.19128 .01472 L
.19131 .01472 L
.19133 .01472 L
.19136 .01472 L
.19139 .01472 L
.19141 .01472 L
.19144 .01472 L
.19146 .01472 L
.19149 .01472 L
.19152 .01472 L
.19155 .01472 L
.19157 .01472 L
.1916 .01472 L
.19162 .01472 L
.19163 .01472 L
.19166 .01472 L
.19169 .01472 L
.19172 .01472 L
.19174 .01472 L
Mistroke
.19175 .01472 L
.19178 .01472 L
.19181 .01472 L
.19184 .01472 L
.19186 .01472 L
.19189 .01472 L
.19192 .01472 L
.19195 .01472 L
.19197 .01472 L
.19198 .01472 L
.19201 .01472 L
.19203 .01472 L
.19205 .01472 L
.19208 .01472 L
.19211 .01472 L
.19214 .01472 L
.19216 .01472 L
.19219 .01472 L
.19222 .01472 L
.19224 .01472 L
.19227 .01472 L
.19229 .01472 L
.19232 .01472 L
.19235 .01472 L
.19238 .01472 L
.19241 .01472 L
.19243 .01472 L
.19246 .01472 L
.19249 .01472 L
.19252 .01472 L
.19255 .01472 L
.19257 .01472 L
.1926 .01472 L
.19263 .01472 L
.19266 .01472 L
.19268 .01472 L
.1927 .01472 L
.19271 .01472 L
.19273 .01472 L
.19276 .01472 L
.19279 .01472 L
.19282 .01472 L
.19285 .01472 L
.19288 .01472 L
.1929 .01472 L
.19293 .01472 L
.19296 .01472 L
.19298 .01472 L
.19302 .01472 L
.19305 .01472 L
Mistroke
.19307 .01472 L
.1931 .01472 L
.19313 .01472 L
.19316 .01472 L
.19319 .01472 L
.19322 .01472 L
.19324 .01472 L
.19325 .01472 L
.19328 .01472 L
.1933 .01472 L
.19332 .01472 L
.19333 .01472 L
.19335 .01472 L
.19338 .01472 L
.1934 .01472 L
.19341 .01472 L
.19343 .01472 L
.19345 .01472 L
.19347 .01472 L
.19348 .01472 L
.1935 .01472 L
.19352 .01472 L
.19354 .01472 L
.19358 .01472 L
.1936 .01472 L
.19364 .01472 L
.19367 .01472 L
.19369 .01472 L
.19372 .01472 L
.19375 .01472 L
.19377 .01472 L
.1938 .01472 L
.19383 .01472 L
.19386 .01472 L
.19389 .01472 L
.19392 .01472 L
.19395 .01472 L
.19397 .01472 L
.19398 .01472 L
.19401 .01472 L
.19404 .01472 L
.19407 .01472 L
.1941 .01472 L
.19413 .01472 L
.19415 .01472 L
.19418 .01472 L
.1942 .01472 L
.19423 .01472 L
.19425 .01472 L
.19428 .01472 L
Mistroke
.19431 .01472 L
.19434 .01472 L
.19436 .01472 L
.19439 .01472 L
.19441 .01472 L
.19443 .01472 L
.19445 .01472 L
.19448 .01472 L
.19451 .01472 L
.19454 .01472 L
.19457 .01472 L
.1946 .01472 L
.19463 .01472 L
.19465 .01472 L
.19468 .01472 L
.19471 .01472 L
.19474 .01472 L
.19477 .01472 L
.1948 .01472 L
.19483 .01472 L
.19486 .01472 L
.19488 .01472 L
.19489 .01472 L
.19492 .01472 L
.19495 .01472 L
.19498 .01472 L
.19501 .01472 L
.19504 .01472 L
.19506 .01472 L
.19509 .01472 L
.19511 .01472 L
.19514 .01472 L
.19516 .01472 L
.19519 .01472 L
.19522 .01472 L
.19525 .01472 L
.19527 .01472 L
.1953 .01472 L
.19532 .01472 L
.19534 .01472 L
.19536 .01472 L
.19539 .01472 L
.19542 .01472 L
.19545 .01472 L
.19548 .01472 L
.19551 .01472 L
.19554 .01472 L
.19556 .01472 L
.19559 .01472 L
.19562 .01472 L
Mistroke
.19565 .01472 L
.19568 .01472 L
.19571 .01472 L
.19574 .01472 L
.19577 .01472 L
.19579 .01472 L
.1958 .01472 L
.19583 .01472 L
.19586 .01472 L
.19589 .01472 L
.19592 .01472 L
.19595 .01472 L
.19597 .01472 L
.196 .01472 L
.19602 .01472 L
.19605 .01472 L
.19608 .01472 L
.1961 .01472 L
.19613 .01472 L
.19616 .01472 L
.19619 .01472 L
.19621 .01472 L
.19623 .01472 L
.19625 .01472 L
.19627 .01472 L
.1963 .01472 L
.19633 .01472 L
.19635 .01472 L
.19637 .01472 L
.19639 .01472 L
.19642 .01472 L
.19645 .01472 L
.19648 .01472 L
.1965 .01472 L
.19653 .01472 L
.19656 .01472 L
.19658 .01472 L
.19659 .01472 L
.19663 .01472 L
.19664 .01472 L
.19666 .01472 L
.19669 .01472 L
.19672 .01472 L
.19675 .01472 L
.19678 .01472 L
.1968 .01472 L
.19683 .01472 L
.19686 .01472 L
.19688 .01472 L
.19691 .01472 L
Mistroke
.19694 .01472 L
.19696 .01472 L
.19699 .60332 L
.19702 .60332 L
.19705 .60332 L
.1971 .60332 L
.19722 .60332 L
.19814 .60332 L
.19913 .60332 L
.20008 .60332 L
.20099 .60332 L
.20197 .60332 L
.2029 .60332 L
.2039 .60332 L
.20486 .60332 L
.20578 .60332 L
.20676 .60332 L
.20771 .60332 L
.20861 .60332 L
.20958 .60332 L
.21051 .60332 L
.2115 .60332 L
.21245 .60332 L
.21337 .60332 L
.21384 .60332 L
.21398 .60332 L
.21411 .60332 L
.21416 .60332 L
.21422 .60332 L
.21425 .60332 L
.21427 .60332 L
.21429 .01472 L
.21432 .01472 L
.21435 .01472 L
.21438 .01472 L
.21439 .01472 L
.21441 .01472 L
.21444 .01472 L
.21446 .01472 L
.21447 .01472 L
.2145 .01472 L
.21453 .01472 L
.21456 .01472 L
.21459 .01472 L
.21461 .01472 L
.21463 .01472 L
.21464 .01472 L
.21466 .01472 L
.21469 .01472 L
.21472 .01472 L
Mistroke
.21474 .01472 L
.21475 .01472 L
.21479 .01472 L
.2148 .01472 L
.21482 .01472 L
.21484 .01472 L
.21486 .01472 L
.21487 .01472 L
.21489 .01472 L
.21492 .01472 L
.21495 .01472 L
.21498 .01472 L
.21501 .01472 L
.21503 .01472 L
.21504 .01472 L
.21506 .01472 L
.21507 .01472 L
.21509 .01472 L
.21511 .01472 L
.21514 .01472 L
.21517 .01472 L
.21519 .01472 L
.21522 .01472 L
.21525 .01472 L
.21527 .01472 L
.21528 .01472 L
.21531 .01472 L
.21534 .01472 L
.21537 .01472 L
.21539 .01472 L
.2154 .01472 L
.21543 .01472 L
.21546 .01472 L
.21549 .01472 L
.21551 .01472 L
.21554 .01472 L
.21557 .01472 L
.2156 .01472 L
.21562 .01472 L
.21564 .01472 L
.21567 .01472 L
.21568 .01472 L
.2157 .01472 L
.21573 .01472 L
.21576 .01472 L
.21579 .01472 L
.21582 .01472 L
.21584 .01472 L
.21587 .01472 L
.21589 .01472 L
Mistroke
.21592 .01472 L
.21595 .01472 L
.21598 .01472 L
.216 .01472 L
.21603 .01472 L
.21606 .01472 L
.21608 .01472 L
.21611 .01472 L
.21614 .01472 L
.21617 .01472 L
.2162 .01472 L
.21623 .01472 L
.21626 .01472 L
.21627 .01472 L
.21629 .01472 L
.21632 .01472 L
.21635 .01472 L
.21637 .01472 L
.21638 .01472 L
.21641 .01472 L
.21644 .01472 L
.21646 .01472 L
.21647 .01472 L
.2165 .01472 L
.21653 .01472 L
.21656 .01472 L
.21659 .01472 L
.21662 .01472 L
.21665 .01472 L
.21667 .01472 L
.2167 .01472 L
.21673 .01472 L
.21676 .01472 L
.21679 .01472 L
.21681 .01472 L
.21682 .01472 L
.21685 .01472 L
.21688 .01472 L
.21691 .01472 L
.21694 .01472 L
.21697 .01472 L
.21699 .01472 L
.217 .01472 L
.21704 .01472 L
.21705 .01472 L
.21707 .01472 L
.21709 .01472 L
.21711 .01472 L
.21712 .01472 L
.21714 .01472 L
Mistroke
.21716 .01472 L
.21717 .01472 L
.2172 .01472 L
.21723 .01472 L
.21726 .01472 L
.21728 .01472 L
.21729 .01472 L
.21732 .01472 L
.21735 .01472 L
.21738 .01472 L
.2174 .01472 L
.21743 .01472 L
.21746 .01472 L
.21749 .01472 L
.21751 .01472 L
.21752 .01472 L
.21756 .01472 L
.21757 .01472 L
.21759 .01472 L
.21762 .01472 L
.21765 .01472 L
.21768 .01472 L
.21771 .01472 L
.21773 .01472 L
.21776 .01472 L
.21778 .01472 L
.21781 .01472 L
.21784 .01472 L
.21787 .01472 L
.21789 .01472 L
.21792 .01472 L
.21795 .01472 L
.21797 .01472 L
.218 .01472 L
.21803 .01472 L
.21806 .01472 L
.21809 .01472 L
.21812 .01472 L
.21815 .01472 L
.21818 .01472 L
.21821 .01472 L
.21822 .01472 L
.21824 .01472 L
.21826 .01472 L
.21827 .01472 L
.2183 .01472 L
.21833 .01472 L
.21835 .01472 L
.21836 .01472 L
.21839 .01472 L
Mistroke
.21842 .01472 L
.21845 .01472 L
.21848 .01472 L
.21851 .01472 L
.21854 .01472 L
.21856 .01472 L
.21859 .01472 L
.21862 .01472 L
.21865 .01472 L
.21868 .01472 L
.21869 .01472 L
.21871 .01472 L
.21874 .01472 L
.21877 .01472 L
.2188 .01472 L
.21883 .01472 L
.21886 .01472 L
.21887 .01472 L
.21889 .01472 L
.21892 .01472 L
.21894 .01472 L
.21896 .01472 L
.21897 .01472 L
.21899 .01472 L
.21901 .01472 L
.21903 .01472 L
.21904 .01472 L
.21906 .01472 L
.21909 .01472 L
.21912 .01472 L
.21915 .01472 L
.21918 .01472 L
.21921 .01472 L
.21924 .01472 L
.21927 .01472 L
.21929 .01472 L
.21932 .01472 L
.21935 .01472 L
.21938 .01472 L
.21941 .01472 L
.21943 .01472 L
.21946 .01472 L
.2195 .01472 L
.21951 .01472 L
.21953 .01472 L
.21956 .01472 L
.21959 .01472 L
.21962 .01472 L
.21964 .01472 L
.21967 .01472 L
Mistroke
.2197 .01472 L
.21973 .01472 L
.21975 .01472 L
.21978 .01472 L
.2198 .01472 L
.21983 .01472 L
.21986 .01472 L
.21989 .01472 L
.21991 .01472 L
.21994 .01472 L
.21996 .01472 L
.21997 .01472 L
.22 .01472 L
.22003 .01472 L
.22006 .01472 L
.22008 .01472 L
.22009 .01472 L
.22012 .01472 L
.22015 .01472 L
.22018 .01472 L
.2202 .01472 L
.22023 .01472 L
.22026 .01472 L
.22029 .01472 L
.2203 .01472 L
.22032 .01472 L
.22035 .01472 L
.22037 .01472 L
.22039 .01472 L
.22041 .01472 L
.22045 .01472 L
.22047 .01472 L
.2205 .01472 L
.22053 .01472 L
.22055 .01472 L
.22058 .01472 L
.2206 .01472 L
.22063 .01472 L
.22066 .01472 L
.22069 .01472 L
.22072 .01472 L
.22075 .01472 L
.22077 .01472 L
.2208 .01472 L
.22083 .01472 L
.22086 .01472 L
.22089 .01472 L
.22091 .01472 L
.22094 .01472 L
.22097 .01472 L
Mistroke
.221 .01472 L
.22102 .01472 L
.22103 .01472 L
.22105 .01472 L
.22107 .01472 L
.2211 .01472 L
.22113 .01472 L
.22116 .01472 L
.22119 .01472 L
.22121 .01472 L
.22124 .01472 L
.22127 .01472 L
.22129 .01472 L
.22132 .01472 L
.22135 .01472 L
.22138 .01472 L
.22141 .01472 L
.22144 .01472 L
.22147 .01472 L
.2215 .01472 L
.22153 .01472 L
.22156 .01472 L
.22158 .01472 L
.22159 .01472 L
.22162 .01472 L
.22164 .01472 L
.22166 .01472 L
.22167 .01472 L
.22169 .01472 L
.22172 .01472 L
.22174 .01472 L
.22175 .01472 L
.22177 .01472 L
.22179 .01472 L
.22181 .01472 L
.22182 .01472 L
.22184 .01472 L
.22185 .01472 L
.22188 .01472 L
.22191 .01472 L
.22194 .01472 L
.22197 .01472 L
.222 .01472 L
.22203 .01472 L
.22206 .01472 L
.22208 .01472 L
.22211 .01472 L
.22214 .01472 L
.22217 .01472 L
.2222 .01472 L
Mistroke
.22223 .01472 L
.22226 .01472 L
.22229 .01472 L
.22231 .01472 L
.22232 .01472 L
.22235 .01472 L
.22238 .01472 L
.22241 .01472 L
.22244 .01472 L
.22247 .01472 L
.22249 .01472 L
.22252 .01472 L
.22254 .01472 L
.22257 .01472 L
.22259 .01472 L
.22262 .01472 L
.22265 .01472 L
.22268 .01472 L
.2227 .01472 L
.22273 .01472 L
.22275 .01472 L
.22277 .01472 L
.22279 .01472 L
.22282 .01472 L
.22285 .01472 L
.22288 .01472 L
.22291 .01472 L
.22294 .01472 L
.22297 .01472 L
.22299 .01472 L
.22302 .01472 L
.22305 .01472 L
.22308 .01472 L
.22311 .01472 L
.22314 .01472 L
.22317 .01472 L
.2232 .01472 L
.22322 .01472 L
.22323 .01472 L
.22326 .01472 L
.22329 .01472 L
.22332 .01472 L
.22335 .01472 L
.22338 .01472 L
.2234 .01472 L
.22343 .01472 L
.22345 .01472 L
.22348 .01472 L
.2235 .01472 L
.22353 .01472 L
Mistroke
.22356 .01472 L
.22359 .01472 L
.22361 .01472 L
.22364 .01472 L
.22366 .01472 L
.22368 .01472 L
.2237 .01472 L
.22373 .01472 L
.22376 .01472 L
.22378 .01472 L
.22379 .01472 L
.22382 .01472 L
.22385 .01472 L
.22388 .01472 L
.2239 .01472 L
.22393 .01472 L
.22396 .01472 L
.22399 .01472 L
.22401 .01472 L
.22402 .01472 L
.22405 .01472 L
.22407 .01472 L
.22409 .01472 L
.22412 .01472 L
.22415 .01472 L
.22418 .01472 L
.2242 .01472 L
.22423 .01472 L
.22426 .01472 L
.22428 .01472 L
.22431 .01472 L
.22433 .01472 L
.22436 .01472 L
.22439 .01472 L
.22442 .01472 L
.22445 .01472 L
.22448 .01472 L
.2245 .01472 L
.22453 .01472 L
.22456 .01472 L
.22459 .01472 L
.22462 .01472 L
.22465 .01472 L
.22468 .01472 L
.22471 .01472 L
.22472 .01472 L
.22474 .01472 L
.22475 .01472 L
.22477 .01472 L
.2248 .01472 L
Mistroke
.22483 .01472 L
.22486 .01472 L
.22489 .01472 L
.22492 .01472 L
.22495 .01472 L
.22497 .01472 L
.225 .01472 L
.22503 .01472 L
.22506 .01472 L
.22509 .01472 L
.22511 .01472 L
.22514 .01472 L
.22517 .01472 L
.2252 .01472 L
.22523 .01472 L
.22526 .01472 L
.22528 .01472 L
.2253 .01472 L
.22533 .01472 L
.22534 .01472 L
.22536 .01472 L
.22537 .01472 L
.22539 .01472 L
.22542 .01472 L
.22544 .01472 L
.22546 .01472 L
.22547 .01472 L
.22549 .01472 L
.22551 .01472 L
.22553 .01472 L
.22554 .01472 L
.22556 .01472 L
.22559 .01472 L
.22562 .01472 L
.22565 .01472 L
.22568 .01472 L
.22571 .01472 L
.22573 .01472 L
.22576 .01472 L
.22579 .01472 L
.22582 .01472 L
.22584 .01472 L
.22587 .01472 L
.2259 .01472 L
.22593 .01472 L
.22596 .01472 L
.22599 .01472 L
.22601 .01472 L
.22602 .01472 L
.22606 .01472 L
Mistroke
.22609 .01472 L
.22611 .01472 L
.22614 .01472 L
.22617 .01472 L
.2262 .01472 L
.22622 .01472 L
.22624 .01472 L
.22627 .01472 L
.2263 .01472 L
.22632 .01472 L
.22635 .01472 L
.22638 .01472 L
.22641 .01472 L
.22644 .01472 L
.22645 .01472 L
.22647 .01472 L
.2265 .01472 L
.22653 .01472 L
.22655 .01472 L
.22659 .01472 L
.22662 .01472 L
.22664 .01472 L
.22667 .01472 L
.2267 .01472 L
.22672 .01472 L
.22675 .01472 L
.22678 .01472 L
.22681 .01472 L
.22684 .01472 L
.22687 .01472 L
.2269 .01472 L
.22692 .01472 L
.22693 .01472 L
.22697 .01472 L
.227 .01472 L
.22702 .01472 L
.22705 .01472 L
.22708 .01472 L
.22711 .01472 L
.22713 .01472 L
.22715 .01472 L
.22718 .01472 L
.22721 .01472 L
.22723 .01472 L
.22726 .01472 L
.22729 .01472 L
.22732 .01472 L
.22735 .01472 L
.22736 .01472 L
.22738 .01472 L
Mistroke
.22741 .01472 L
.22744 .01472 L
.22746 .01472 L
.22748 .01472 L
.2275 .01472 L
.22752 .01472 L
.22755 .01472 L
.22758 .01472 L
.22761 .01472 L
.22763 .01472 L
.22766 .01472 L
.22769 .01472 L
.22771 .01472 L
.22772 .01472 L
.22776 .01472 L
.22777 .01472 L
.22779 .01472 L
.22782 .01472 L
.22785 .01472 L
.22788 .01472 L
.22791 .01472 L
.22793 .01472 L
.22796 .01472 L
.22798 .01472 L
.22801 .01472 L
.22804 .01472 L
.22807 .01472 L
.22809 .01472 L
.22812 .01472 L
.22815 .01472 L
.22818 .01472 L
.2282 .01472 L
.22823 .01472 L
.22826 .01472 L
.22829 .01472 L
.22832 .01472 L
.22835 .01472 L
.22838 .01472 L
.22841 .01472 L
.22842 .01472 L
.22844 .01472 L
.22846 .01472 L
.22847 .01472 L
.2285 .01472 L
.22853 .01472 L
.22856 .01472 L
.22859 .01472 L
.22862 .01472 L
.22865 .01472 L
.22867 .01472 L
Mistroke
.2287 .01472 L
.22873 .01472 L
.22876 .01472 L
.22879 .01472 L
.22882 .01472 L
.22884 .01472 L
.22888 .01472 L
.2289 .01472 L
.22893 .01472 L
.22896 .01472 L
.22898 .01472 L
.229 .01472 L
.22903 .01472 L
.22904 .01472 L
.22906 .01472 L
.22908 .01472 L
.22909 .01472 L
.22912 .01472 L
.22914 .01472 L
.22916 .01472 L
.22917 .01472 L
.22919 .01472 L
.22921 .01472 L
.22923 .01472 L
.22924 .01472 L
.22926 .01472 L
.22929 .01472 L
.22932 .01472 L
.22935 .01472 L
.22938 .01472 L
.22941 .01472 L
.22944 .01472 L
.22946 .01472 L
.22949 .01472 L
.22952 .01472 L
.22954 .01472 L
.22957 .01472 L
.2296 .01472 L
.22963 .01472 L
.22966 .01472 L
.22969 .01472 L
.22971 .01472 L
.22973 .01472 L
.22976 .01472 L
.22979 .01472 L
.22981 .01472 L
.22984 .01472 L
.22987 .01472 L
.2299 .01472 L
.22992 .01472 L
Mistroke
.22994 .01472 L
.22997 .01472 L
.23 .01472 L
.23002 .01472 L
.23005 .01472 L
.23008 .01472 L
.23011 .01472 L
.23014 .01472 L
.23015 .01472 L
.23017 .01472 L
.2302 .01472 L
.23023 .01472 L
.23026 .01472 L
.23029 .01472 L
.23032 .01472 L
.23034 .01472 L
.23037 .01472 L
.2304 .01472 L
.23043 .01472 L
.23045 .01472 L
.23048 .01472 L
.23051 .01472 L
.23054 .01472 L
.23057 .01472 L
.2306 .01472 L
.23062 .01472 L
.23064 .01472 L
.23067 .01472 L
.2307 .01472 L
.23072 .01472 L
.23075 .01472 L
.23078 .01472 L
.23081 .01472 L
.23083 .01472 L
.23085 .01472 L
.23088 .01472 L
.23091 .01472 L
.23093 .01472 L
.23096 .01472 L
.23099 .01472 L
.23102 .01472 L
.23105 .01472 L
.23106 .01472 L
.23108 .01472 L
.23111 .01472 L
.23114 .01472 L
.23117 .01472 L
.2312 .01472 L
.23123 .01472 L
.23125 .01472 L
Mistroke
.23128 .01472 L
.23131 .01472 L
.23134 .01472 L
.23136 .01472 L
.23139 .01472 L
.23142 .01472 L
.23145 .01472 L
.23148 .01472 L
.23151 .01472 L
.23153 .01472 L
.23155 .01472 L
.23158 .01472 L
.23161 .01472 L
.23163 .01472 L
.23166 .01472 L
.23169 .01472 L
.23172 .01472 L
.23174 .01472 L
.23177 .01472 L
.23179 .01472 L
.23182 .01472 L
.23185 .01472 L
.23187 .01472 L
.2319 .01472 L
.23193 .01472 L
.23196 .01472 L
.23197 .01472 L
.23199 .01472 L
.23202 .01472 L
.23205 .01472 L
.23208 .01472 L
.23209 .01472 L
.23211 .01472 L
.23214 .01472 L
.23217 .01472 L
.23219 .01472 L
.23222 .01472 L
.23224 .01472 L
.23227 .01472 L
.2323 .01472 L
.23232 .01472 L
.23234 .01472 L
.23237 .01472 L
.23239 .01472 L
.2324 .01472 L
.23243 .01472 L
.23246 .01472 L
.23249 .01472 L
.23252 .01472 L
.23254 .01472 L
Mistroke
.23257 .01472 L
.2326 .01472 L
.23262 .01472 L
.23265 .01472 L
.23268 .01472 L
.23271 .01472 L
.23273 .01472 L
.23276 .01472 L
.23279 .01472 L
.23282 .01472 L
.23284 .01472 L
.23287 .01472 L
.2329 .01472 L
.23293 .01472 L
.23296 .01472 L
.23299 .01472 L
.23302 .01472 L
.23303 .01472 L
.23305 .01472 L
.23307 .01472 L
.23309 .01472 L
.23312 .01472 L
.23314 .01472 L
.23317 .01472 L
.2332 .01472 L
.23323 .01472 L
.23326 .01472 L
.23329 .01472 L
.23331 .01472 L
.23334 .01472 L
.23337 .01472 L
.2334 .01472 L
.23343 .01472 L
.23346 .01472 L
.23349 .01472 L
.23352 .01472 L
.23355 .01472 L
.23358 .01472 L
.23359 .01472 L
.23361 .01472 L
.23364 .01472 L
.23366 .01472 L
.23367 .01472 L
.23369 .01472 L
.23371 .01472 L
.23374 .01472 L
.23375 .01472 L
.23377 .01472 L
.23379 .01472 L
.23381 .01472 L
Mistroke
.23382 .01472 L
.23384 .01472 L
.23386 .01472 L
.23387 .01472 L
.2339 .01472 L
.23393 .01472 L
.23396 .01472 L
.23399 .01472 L
.23402 .01472 L
.23405 .01472 L
.23408 .01472 L
.2341 .01472 L
.23413 .01472 L
.23416 .01472 L
.23419 .01472 L
.23422 .01472 L
.23425 .01472 L
.23427 .01472 L
.23431 .01472 L
.23432 .01472 L
.23434 .01472 L
.23437 .01472 L
.2344 .01472 L
.23443 .01472 L
.23445 .01472 L
.23448 .01472 L
.23451 .01472 L
.23454 .01472 L
.23456 .01472 L
.23458 .01472 L
.23461 .01472 L
.23464 .01472 L
.23467 .01472 L
.2347 .01472 L
.23472 .01472 L
.23475 .01472 L
.23477 .01472 L
.23478 .01472 L
.23481 .01472 L
.23484 .01472 L
.23487 .01472 L
.2349 .01472 L
.23493 .01472 L
.23496 .01472 L
.23499 .01472 L
.23501 .01472 L
.23504 .01472 L
.23507 .01472 L
.2351 .01472 L
.23513 .01472 L
Mistroke
.23516 .01472 L
.23518 .01472 L
.23522 .01472 L
.23523 .01472 L
.23525 .01472 L
.23528 .01472 L
.23531 .01472 L
.23534 .01472 L
.23536 .01472 L
.23539 .01472 L
.23542 .01472 L
.23545 .01472 L
.23547 .01472 L
.2355 .01472 L
.23552 .01472 L
.23555 .01472 L
.23558 .01472 L
.23561 .01472 L
.23563 .01472 L
.23566 .01472 L
.23568 .01472 L
.23569 .01472 L
.23572 .01472 L
.23575 .01472 L
.23578 .01472 L
.2358 .01472 L
.23581 .01472 L
.23584 .01472 L
.23587 .01472 L
.2359 .01472 L
.23592 .01472 L
.23595 .01472 L
.23598 .01472 L
.23601 .01472 L
.23603 .01472 L
.23604 .01472 L
.23607 .01472 L
.23609 .01472 L
.23611 .01472 L
.23613 .01472 L
.23617 .01472 L
.2362 .01472 L
.23622 .01472 L
.23625 .01472 L
.23628 .01472 L
.2363 .01472 L
.23632 .01472 L
.23635 .01472 L
.23638 .01472 L
.23641 .01472 L
Mistroke
.23644 .01472 L
.23647 .01472 L
.23649 .01472 L
.23652 .01472 L
.23655 .01472 L
.23658 .01472 L
.23661 .01472 L
.23663 .01472 L
.23666 .01472 L
.23669 .01472 L
.23672 .01472 L
.23674 .01472 L
.23676 .01472 L
.23677 .01472 L
.23679 .01472 L
.23682 .01472 L
.23685 .01472 L
.23688 .01472 L
.23691 .01472 L
.23694 .01472 L
.23696 .01472 L
.23699 .01472 L
.23702 .01472 L
.23704 .01472 L
.23708 .01472 L
.23711 .01472 L
.23713 .01472 L
.23716 .01472 L
.23719 .01472 L
.23722 .01472 L
.23725 .01472 L
.23728 .01472 L
.2373 .01472 L
.23731 .01472 L
.23734 .01472 L
.23736 .01472 L
.23738 .01472 L
.23739 .01472 L
.23741 .01472 L
.23744 .01472 L
.23746 .01472 L
.23747 .01472 L
.23749 .01472 L
.23751 .01472 L
.23753 .01472 L
.23754 .01472 L
.23756 .01472 L
.23758 .01472 L
.2376 .01472 L
.23764 .01472 L
Mistroke
.23766 .01472 L
.2377 .01472 L
.23773 .01472 L
.23775 .01472 L
.23778 .01472 L
.23781 .01472 L
.23783 .01472 L
.23786 .01472 L
.23789 .01472 L
.23792 .01472 L
.23795 .01472 L
.23798 .01472 L
.23801 .01472 L
.23803 .01472 L
.23804 .01472 L
.23807 .01472 L
.2381 .01472 L
.23813 .01472 L
.23816 .01472 L
.23819 .01472 L
.23821 .01472 L
.23824 .01472 L
.23826 .01472 L
.23829 .01472 L
.23832 .01472 L
.23834 .01472 L
.23837 .01472 L
.2384 .01472 L
.23842 .01472 L
.23845 .01472 L
.23847 .01472 L
.23849 .01472 L
.23851 .01472 L
.23854 .01472 L
.23857 .01472 L
.23861 .01472 L
.23864 .01472 L
.23866 .01472 L
.23869 .01472 L
.23872 .01472 L
.23874 .01472 L
.23877 .01472 L
.2388 .01472 L
.23883 .01472 L
.23886 .01472 L
.23889 .01472 L
.23892 .01472 L
.23894 .01472 L
.23895 .01472 L
.23898 .01472 L
Mistroke
.23901 .01472 L
.23904 .01472 L
.23907 .01472 L
.2391 .01472 L
.23912 .01472 L
.23915 .01472 L
.23917 .01472 L
.2392 .01472 L
.23923 .01472 L
.23925 .01472 L
.23928 .01472 L
.23931 .01472 L
.23934 .01472 L
.23936 .01472 L
.23938 .01472 L
.2394 .01472 L
.23942 .01472 L
.23945 .01472 L
.23948 .01472 L
.2395 .01472 L
.23952 .01472 L
.23954 .01472 L
.23957 .01472 L
.2396 .01472 L
.23963 .01472 L
.23965 .01472 L
.23968 .01472 L
.23971 .01472 L
.23973 .01472 L
.23974 .01472 L
.23978 .01472 L
.23979 .01472 L
.23981 .01472 L
.23984 .01472 L
.23987 .01472 L
.2399 .01472 L
.23993 .01472 L
.23995 .01472 L
.23998 .01472 L
.24 .01472 L
.24003 .01472 L
.24006 .01472 L
.24009 .01472 L
.24011 .01472 L
.24014 .01472 L
.24017 .01472 L
.2402 .01472 L
.24022 .01472 L
.24025 .01472 L
.24028 .01472 L
Mistroke
.24031 .01472 L
.24034 .01472 L
.24037 .01472 L
.2404 .01472 L
.24043 .01472 L
.24044 .01472 L
.24046 .01472 L
.24048 .01472 L
.24049 .01472 L
.24052 .01472 L
.24055 .01472 L
.24058 .01472 L
.24061 .01472 L
.24064 .01472 L
.24067 .01472 L
.24069 .01472 L
.24072 .01472 L
.24075 .01472 L
.24078 .01472 L
.24081 .01472 L
.24084 .01472 L
.24086 .01472 L
.2409 .01472 L
.24092 .01472 L
.24095 .01472 L
.24098 .01472 L
.241 .01472 L
.24102 .01472 L
.24105 .01472 L
.24106 .01472 L
.24108 .01472 L
.2411 .01472 L
.24111 .01472 L
.24114 .01472 L
.24116 .01472 L
.24118 .01472 L
.24119 .01472 L
.24121 .01472 L
.24123 .01472 L
.24125 .01472 L
.24126 .01472 L
.24128 .01472 L
.24131 .01472 L
.24134 .01472 L
.24137 .01472 L
.2414 .01472 L
.24143 .01472 L
.24146 .01472 L
.24148 .01472 L
.24151 .01472 L
Mistroke
.24154 .01472 L
.24156 .01472 L
.24159 .01472 L
.24162 .01472 L
.24165 .01472 L
.24168 .01472 L
.24171 .01472 L
.24173 .01472 L
.24175 .01472 L
.24178 .01472 L
.24181 .01472 L
.24183 .01472 L
.24186 .01472 L
.24189 .01472 L
.24192 .01472 L
.24194 .01472 L
.24197 .01472 L
.24199 .01472 L
.24202 .01472 L
.24204 .01472 L
.24207 .01472 L
.2421 .01472 L
.24213 .01472 L
.24216 .01472 L
.24217 .01472 L
.24219 .01472 L
.24222 .01472 L
.24225 .01472 L
.24228 .01472 L
.24231 .01472 L
.24234 .01472 L
.24237 .01472 L
.24239 .01472 L
.24242 .01472 L
.24245 .01472 L
.24247 .01472 L
.2425 .01472 L
.24253 .01472 L
.24256 .01472 L
.24259 .01472 L
.24262 .01472 L
.24264 .01472 L
.24266 .01472 L
.24269 .01472 L
.24272 .01472 L
.24274 .01472 L
.24277 .01472 L
.2428 .01472 L
.24283 .01472 L
.24285 .01472 L
Mistroke
.24288 .01472 L
.2429 .01472 L
.24293 .01472 L
.24296 .01472 L
.24298 .01472 L
.24301 .01472 L
.24304 .01472 L
.24307 .01472 L
.24308 .01472 L
.2431 .01472 L
.24313 .01472 L
.24316 .01472 L
.24319 .01472 L
.2432 .01472 L
.24322 .01472 L
.24325 .01472 L
.24328 .01472 L
.2433 .01472 L
.24333 .01472 L
.24335 .01472 L
.24338 .01472 L
.24341 .01472 L
.24343 .01472 L
.24345 .01472 L
.24348 .01472 L
.24349 .01472 L
.24351 .01472 L
.24354 .01472 L
.24357 .01472 L
.2436 .01472 L
.24363 .01472 L
.24365 .01472 L
.24368 .01472 L
.24371 .01472 L
.24373 .01472 L
.24376 .01472 L
.24379 .01472 L
.24382 .01472 L
.24384 .01472 L
.24387 .01472 L
.2439 .01472 L
.24392 .01472 L
.24395 .01472 L
.24398 .01472 L
.24401 .01472 L
.24404 .01472 L
.24407 .01472 L
.2441 .01472 L
.24413 .01472 L
.24414 .01472 L
Mistroke
.24416 .01472 L
.24418 .01472 L
.24419 .01472 L
.24422 .01472 L
.24425 .01472 L
.24428 .01472 L
.24431 .01472 L
.24434 .01472 L
.24437 .01472 L
.2444 .01472 L
.24442 .01472 L
.24445 .01472 L
.24448 .01472 L
.24451 .01472 L
.24454 .01472 L
.24457 .01472 L
.2446 .01472 L
.24463 .01472 L
.24465 .01472 L
.24468 .01472 L
.2447 .01472 L
.24472 .01472 L
.24475 .01472 L
.24477 .01472 L
.24478 .01472 L
.2448 .01472 L
.24481 .01472 L
.24485 .01472 L
.24486 .01472 L
.24488 .01472 L
.2449 .01472 L
.24491 .01472 L
.24493 .01472 L
.24495 .01472 L
.24496 .01472 L
.24498 .01472 L
.24501 .01472 L
.24504 .01472 L
.24507 .01472 L
.2451 .01472 L
.24513 .01472 L
.24516 .01472 L
.24518 .01472 L
.24521 .01472 L
.24524 .01472 L
.24527 .01472 L
.24529 .01472 L
.24533 .01472 L
.24535 .01472 L
.24538 .01472 L
Mistroke
.24541 .01472 L
.24543 .01472 L
.24545 .01472 L
.24548 .01472 L
.24551 .01472 L
.24553 .01472 L
.24556 .01472 L
.24559 .01472 L
.24562 .01472 L
.24564 .01472 L
.24567 .01472 L
.24569 .01472 L
.24572 .01472 L
.24575 .01472 L
.24578 .01472 L
.2458 .01472 L
.24583 .01472 L
.24586 .01472 L
.24587 .01472 L
.24589 .01472 L
.24592 .01472 L
.24595 .01472 L
.24598 .01472 L
.24601 .01472 L
.24604 .01472 L
.24607 .01472 L
.24609 .01472 L
.24612 .01472 L
.24615 .01472 L
.24617 .01472 L
.2462 .01472 L
.24624 .01472 L
.24626 .01472 L
.24629 .01472 L
.24632 .01472 L
.24634 .01472 L
.24636 .01472 L
.24639 .01472 L
.24642 .01472 L
.24644 .01472 L
.24647 .01472 L
.2465 .01472 L
.24653 .01472 L
.24655 .01472 L
.24658 .01472 L
.2466 .01472 L
.24663 .01472 L
.24666 .01472 L
.24669 .01472 L
.24671 .01472 L
Mistroke
.24674 .01472 L
.24677 .01472 L
.24678 .01472 L
.2468 .01472 L
.24683 .01472 L
.24686 .01472 L
.24689 .01472 L
.24692 .01472 L
.24695 .01472 L
.24698 .01472 L
.247 .01472 L
.24703 .01472 L
.24706 .01472 L
.24708 .01472 L
.24711 .01472 L
.24715 .01472 L
.24717 .01472 L
.2472 .01472 L
.24723 .01472 L
.24725 .01472 L
.24727 .01472 L
.2473 .01472 L
.24733 .01472 L
.24735 .01472 L
.24738 .01472 L
.24741 .01472 L
.24744 .01472 L
.24746 .01472 L
.24749 .01472 L
.24751 .01472 L
.24754 .01472 L
.24757 .01472 L
.2476 .01472 L
.24762 .01472 L
.24765 .01472 L
.24768 .01472 L
.2477 .01472 L
.24771 .01472 L
.24774 .01472 L
.24777 .01472 L
.2478 .01472 L
.24781 .01472 L
.24783 .01472 L
.24786 .01472 L
.24789 .01472 L
.24791 .01472 L
.24794 .01472 L
.24797 .01472 L
.248 .01472 L
.24803 .01472 L
Mistroke
.24804 .01472 L
.24806 .01472 L
.24809 .01472 L
.24811 .01472 L
.24812 .01472 L
.24815 .01472 L
.24818 .01472 L
.24821 .01472 L
.24824 .01472 L
.24827 .01472 L
.24829 .01472 L
.24832 .01472 L
.24834 .01472 L
.24837 .01472 L
.2484 .01472 L
.24843 .01472 L
.24845 .01472 L
.24848 .01472 L
.24851 .01472 L
.24854 .01472 L
.24856 .01472 L
.24859 .01472 L
.24862 .01472 L
.24865 .01472 L
.24868 .01472 L
.24871 .01472 L
.24874 .01472 L
.24876 .01472 L
.24877 .01472 L
.24879 .01472 L
.24881 .01472 L
.24884 .01472 L
.24886 .01472 L
.24889 .01472 L
.24893 .01472 L
.24895 .01472 L
.24898 .01472 L
.24901 .01472 L
.24903 .01472 L
.24906 .01472 L
.24909 .01472 L
.24912 .01472 L
.24915 .01472 L
.24918 .01472 L
.24921 .01472 L
.24924 .01472 L
.24927 .01472 L
.2493 .01472 L
.24932 .01472 L
.24933 .01472 L
Mistroke
.24936 .01472 L
.24938 .01472 L
.24939 .01472 L
.24941 .01472 L
.24943 .01472 L
.24946 .01472 L
.24948 .01472 L
.24949 .01472 L
.24951 .01472 L
.24953 .01472 L
.24954 .01472 L
.24956 .01472 L
.24958 .01472 L
.24959 .01472 L
.24962 .01472 L
.24965 .01472 L
.24968 .01472 L
.24971 .01472 L
.24974 .01472 L
.24977 .01472 L
.2498 .01472 L
.24982 .01472 L
.24985 .01472 L
.24988 .01472 L
.24991 .01472 L
.24994 .01472 L
.24997 .01472 L
.25 .01472 L
.25003 .01472 L
.25005 .01472 L
.25006 .01472 L
.25009 .01472 L
.25012 .01472 L
.25015 .01472 L
.25018 .01472 L
.25021 .01472 L
.25023 .01472 L
.25026 .01472 L
.25028 .01472 L
.25031 .01472 L
.25033 .01472 L
.25036 .01472 L
.25039 .01472 L
.25042 .01472 L
.25044 .01472 L
.25047 .01472 L
.25049 .01472 L
.2505 .01472 L
.25053 .01472 L
.25056 .01472 L
Mistroke
.25059 .01472 L
.25062 .01472 L
.25065 .01472 L
.25068 .01472 L
.25071 .01472 L
.25073 .01472 L
.25076 .01472 L
.25079 .01472 L
.25082 .01472 L
.25085 .01472 L
.25088 .01472 L
.25091 .01472 L
.25094 .01472 L
.25096 .01472 L
.25097 .01472 L
.251 .01472 L
.25103 .01472 L
.25106 .01472 L
.25109 .01472 L
.25112 .01472 L
.25114 .01472 L
.25117 .01472 L
.25119 .01472 L
.25122 .01472 L
.25124 .01472 L
.25127 .01472 L
.2513 .01472 L
.25133 .01472 L
.25135 .01472 L
.25138 .01472 L
.2514 .01472 L
.25142 .01472 L
.25144 .01472 L
.25147 .01472 L
.2515 .01472 L
.25152 .01472 L
.25153 .01472 L
.25156 .01472 L
.25159 .01472 L
.25162 .01472 L
.25164 .01472 L
.25167 .01472 L
.2517 .01472 L
.25173 .01472 L
.25175 .01472 L
.25176 .01472 L
.25179 .01472 L
.25181 .01472 L
.25183 .01472 L
.25186 .01472 L
Mistroke
.25189 .01472 L
.25192 .01472 L
.25194 .01472 L
.25197 .01472 L
.252 .01472 L
.25202 .01472 L
.25205 .01472 L
.25207 .01472 L
.2521 .01472 L
.25213 .01472 L
.25216 .01472 L
.25219 .01472 L
.25222 .01472 L
.25224 .01472 L
.25227 .01472 L
.2523 .01472 L
.25233 .01472 L
.25236 .01472 L
.25239 .01472 L
.25242 .01472 L
.25245 .01472 L
.25246 .01472 L
.25248 .01472 L
.2525 .01472 L
.25251 .01472 L
.25254 .01472 L
.25257 .01472 L
.2526 .01472 L
.25263 .01472 L
.25266 .01472 L
.25269 .01472 L
.25271 .01472 L
.25274 .01472 L
.25277 .01472 L
.2528 .01472 L
.25283 .01472 L
.25285 .01472 L
.25288 .01472 L
.25291 .01472 L
.25294 .01472 L
.25297 .01472 L
.253 .01472 L
.25302 .01472 L
.25304 .01472 L
.25307 .01472 L
.25308 .01472 L
.2531 .01472 L
.25312 .01472 L
.25313 .01472 L
.25316 .01472 L
Mistroke
.25318 .01472 L
.2532 .01472 L
.25321 .01472 L
.25323 .01472 L
.25325 .01472 L
.25327 .01472 L
.25328 .01472 L
.2533 .01472 L
.25333 .01472 L
.25336 .01472 L
.25339 .01472 L
.25342 .01472 L
.25345 .01472 L
.25348 .01472 L
.2535 .01472 L
.25353 .01472 L
.25356 .01472 L
.25358 .01472 L
.25361 .01472 L
.25364 .01472 L
.25367 .01472 L
.2537 .01472 L
.25373 .01472 L
.25375 .01472 L
.25377 .01472 L
.2538 .01472 L
.25383 .01472 L
.25385 .01472 L
.25388 .01472 L
.25391 .01472 L
.25394 .01472 L
.25396 .01472 L
.25398 .01472 L
.25401 .01472 L
.25404 .01472 L
.25406 .01472 L
.25409 .01472 L
.25412 .01472 L
.25415 .01472 L
.25418 .01472 L
.25419 .01472 L
.25421 .01472 L
.25424 .01472 L
.25427 .01472 L
.2543 .01472 L
.25433 .01472 L
.25436 .01472 L
.25438 .01472 L
.25441 .01472 L
.25444 .01472 L
Mistroke
.25447 .01472 L
.25449 .01472 L
.25452 .01472 L
.25455 .01472 L
.25458 .01472 L
.25461 .01472 L
.25464 .01472 L
.25466 .01472 L
.25468 .01472 L
.25471 .01472 L
.25474 .01472 L
.25476 .01472 L
.25479 .01472 L
.25482 .01472 L
.25485 .01472 L
.25487 .01472 L
.2549 .01472 L
.25492 .01472 L
.25495 .01472 L
.25498 .01472 L
.255 .01472 L
.25503 .01472 L
.25506 .01472 L
.25509 .01472 L
.2551 .01472 L
.25512 .01472 L
.25515 .01472 L
.25518 .01472 L
.25521 .01472 L
.25522 .01472 L
.25524 .01472 L
.25527 .01472 L
.2553 .01472 L
.25532 .01472 L
.25535 .01472 L
.25537 .01472 L
.2554 .01472 L
.25543 .01472 L
.25545 .01472 L
.25547 .01472 L
.2555 .01472 L
.25552 .01472 L
.25553 .01472 L
.25556 .01472 L
.25559 .01472 L
.25562 .01472 L
.25565 .01472 L
.25567 .01472 L
.2557 .01472 L
.25573 .01472 L
Mistroke
.25575 .01472 L
.25578 .01472 L
.25581 .01472 L
.25584 .01472 L
.25586 .01472 L
.25589 .01472 L
.25592 .01472 L
.25594 .01472 L
.25597 .01472 L
.256 .01472 L
.25603 .01472 L
.25606 .01472 L
.25609 .01472 L
.25612 .01472 L
.25615 .01472 L
.25616 .01472 L
.25618 .01472 L
.2562 .01472 L
.25621 .01472 L
.25624 .01472 L
.25627 .01472 L
.2563 .01472 L
.25633 .01472 L
.25636 .01472 L
.25639 .01472 L
.25642 .01472 L
.25644 .01472 L
.25647 .01472 L
.2565 .01472 L
.25653 .01472 L
.25656 .01472 L
.25659 .01472 L
.25662 .01472 L
.25665 .01472 L
.25667 .01472 L
.25671 .01472 L
.25672 .01472 L
.25674 .01472 L
.25677 .01472 L
.25679 .01472 L
.2568 .01472 L
.25682 .01472 L
.25684 .01472 L
.25687 .01472 L
.25688 .01472 L
.2569 .01472 L
.25692 .01472 L
.25694 .01472 L
.25695 .01472 L
.25697 .01472 L
Mistroke
.25699 .01472 L
.257 .01472 L
.25703 .01472 L
.25706 .01472 L
.25709 .01472 L
.25712 .01472 L
.25715 .01472 L
.25718 .01472 L
.25721 .01472 L
.25723 .01472 L
.25726 .01472 L
.25729 .01472 L
.25732 .01472 L
.25735 .01472 L
.25737 .01472 L
.2574 .01472 L
.25743 .01472 L
.25745 .01472 L
.25747 .01472 L
.2575 .01472 L
.25753 .01472 L
.25755 .01472 L
.25758 .01472 L
.25761 .01472 L
.25764 .01472 L
.25766 .01472 L
.25769 .01472 L
.25771 .01472 L
.25774 .01472 L
.25777 .01472 L
.2578 .01472 L
.25782 .01472 L
.25785 .01472 L
.25788 .01472 L
.2579 .01472 L
.25791 .01472 L
.25794 .01472 L
.25797 .01472 L
.258 .01472 L
.25803 .01472 L
.25806 .01472 L
.25809 .01472 L
.25812 .01472 L
.25814 .01472 L
.25817 .01472 L
.2582 .01472 L
.25823 .01472 L
.25826 .01472 L
.25828 .01472 L
.25831 .01472 L
Mistroke
.25834 .01472 L
.25836 .01472 L
.25838 .01472 L
.25841 .01472 L
.25844 .01472 L
.25846 .01472 L
.25849 .01472 L
.25852 .01472 L
.25855 .01472 L
.25857 .01472 L
.2586 .01472 L
.25862 .01472 L
.25865 .01472 L
.25868 .01472 L
.25871 .01472 L
.25873 .01472 L
.25876 .01472 L
.25879 .01472 L
.25881 .01472 L
.25882 .01472 L
.25885 .01472 L
.25888 .01472 L
.25891 .01472 L
.25892 .01472 L
.25894 .01472 L
.25897 .01472 L
.259 .01472 L
.25902 .01472 L
.25905 .01472 L
.25908 .01472 L
.25911 .01472 L
.25914 .01472 L
.25915 .01472 L
.25917 .01472 L
.2592 .01472 L
.25922 .01472 L
.25923 .01472 L
.25926 .01472 L
.25929 .01472 L
.25932 .01472 L
.25935 .01472 L
.25938 .01472 L
.2594 .01472 L
.25943 .01472 L
.25945 .01472 L
.25948 .01472 L
.25951 .01472 L
.25954 .01472 L
.25956 .01472 L
.25959 .01472 L
Mistroke
.25962 .01472 L
.25965 .01472 L
.25967 .01472 L
.2597 .01472 L
.25973 .01472 L
.25976 .01472 L
.25979 .01472 L
.25982 .01472 L
.25985 .01472 L
.25987 .01472 L
.25988 .01472 L
.2599 .01472 L
.25992 .01472 L
.25995 .01472 L
.25997 .01472 L
.26 .01472 L
.26004 .01472 L
.26006 .01472 L
.26009 .01472 L
.26012 .01472 L
.26014 .01472 L
.26017 .01472 L
.2602 .01472 L
.26023 .01472 L
.26026 .01472 L
.26029 .01472 L
.26032 .01472 L
.26035 .01472 L
.26038 .01472 L
.26041 .01472 L
.26042 .01472 L
.26044 .01472 L
.26047 .01472 L
.26049 .01472 L
.2605 .01472 L
.26052 .01472 L
.26054 .01472 L
.26057 .01472 L
.26058 .01472 L
.2606 .01472 L
.26062 .01472 L
.26064 .01472 L
.26065 .01472 L
.26067 .01472 L
.26069 .01472 L
.2607 .01472 L
.26073 .01472 L
.26076 .01472 L
.26079 .01472 L
.26082 .01472 L
Mistroke
.26085 .01472 L
.26088 .01472 L
.26091 .01472 L
.26093 .01472 L
.26096 .01472 L
.26099 .01472 L
.26102 .01472 L
.26105 .01472 L
.26108 .01472 L
.2611 .01472 L
.26114 .01472 L
.26115 .01472 L
.26117 .01472 L
.2612 .01472 L
.26123 .01472 L
.26126 .01472 L
.26128 .01472 L
.26131 .01472 L
.26134 .01472 L
.26137 .01472 L
.26139 .01472 L
.26141 .01472 L
.26144 .01472 L
.26147 .01472 L
.2615 .01472 L
.26153 .01472 L
.26155 .01472 L
.26158 .01472 L
.2616 .01472 L
.26161 .01472 L
.26164 .01472 L
.26167 .01472 L
.2617 .01472 L
.26173 .01472 L
.26176 .01472 L
.26179 .01472 L
.26182 .01472 L
.26184 .01472 L
.26187 .01472 L
.2619 .01472 L
.26193 .01472 L
.26196 .01472 L
.26198 .01472 L
.26201 .01472 L
.26205 .01472 L
.26206 .01472 L
.26208 .01472 L
.26211 .01472 L
.26214 .01472 L
.26217 .01472 L
Mistroke
.26219 .01472 L
.26222 .01472 L
.26225 .01472 L
.26228 .01472 L
.2623 .01472 L
.26232 .01472 L
.26235 .01472 L
.26238 .01472 L
.26241 .01472 L
.26244 .01472 L
.26246 .01472 L
.26249 .01472 L
.26251 .01472 L
.26252 .01472 L
.26255 .01472 L
.26258 .01472 L
.26261 .01472 L
.26264 .01472 L
.26267 .01472 L
.2627 .01472 L
.26272 .01472 L
.26275 .01472 L
.26278 .01472 L
.26281 .01472 L
.26284 .01472 L
.26287 .01472 L
.2629 .01472 L
.26292 .01472 L
.26296 .01472 L
.26297 .01472 L
.26299 .01472 L
.26302 .01472 L
.26305 .01472 L
.26308 .01472 L
.2631 .01472 L
.26313 .01472 L
.26316 .01472 L
.26319 .01472 L
.26321 .01472 L
.26324 .01472 L
.26326 .01472 L
.26329 .01472 L
.26332 .01472 L
.26335 .01472 L
.26337 .01472 L
.2634 .01472 L
.26342 .01472 L
.26343 .01472 L
.26346 .01472 L
.26349 .01472 L
Mistroke
.26352 .01472 L
.26354 .01472 L
.26355 .01472 L
.26358 .01472 L
.26361 .01472 L
.26364 .01472 L
.26366 .01472 L
.26369 .01472 L
.26372 .01472 L
.26375 .01472 L
.26377 .01472 L
.26378 .01472 L
.26381 .01472 L
.26383 .01472 L
.26385 .01472 L
.26388 .01472 L
.26391 .01472 L
.26394 .01472 L
.26396 .01472 L
.26399 .01472 L
.26402 .01472 L
.26404 .01472 L
.26407 .01472 L
.26409 .01472 L
.26412 .01472 L
.26415 .01472 L
.26418 .01472 L
.26421 .01472 L
.26423 .01472 L
.26426 .01472 L
.26429 .01472 L
.26432 .01472 L
.26435 .01472 L
.26437 .01472 L
.2644 .01472 L
.26444 .01472 L
.26446 .01472 L
.26448 .01472 L
.2645 .01472 L
.26451 .01472 L
.26453 .01472 L
.26456 .01472 L
.26459 .01472 L
.26462 .01472 L
.26465 .01472 L
.26468 .01472 L
.26471 .01472 L
.26473 .01472 L
.26476 .01472 L
.26479 .01472 L
Mistroke
.26482 .01472 L
.26485 .01472 L
.26487 .01472 L
.2649 .01472 L
.26493 .01472 L
.26496 .01472 L
.26499 .01472 L
.26502 .01472 L
.26504 .01472 L
.26506 .01472 L
.26509 .01472 L
.2651 .01472 L
.26512 .01472 L
.26513 .01472 L
.26515 .01472 L
.26518 .01472 L
.2652 .01472 L
.26521 .01472 L
.26523 .01472 L
.26525 .01472 L
.26527 .01472 L
.26528 .01472 L
.2653 .01472 L
.26532 .01472 L
.26535 .01472 L
.26538 .01472 L
.26541 .01472 L
.26544 .01472 L
.26547 .01472 L
.26549 .01472 L
.26552 .01472 L
.26555 .01472 L
.26558 .01472 L
.2656 .01472 L
.26563 .01472 L
.26566 .01472 L
.26569 .01472 L
.26572 .01472 L
.26575 .01472 L
.26577 .01472 L
.26578 .01472 L
.26582 .01472 L
.26585 .01472 L
.26587 .01472 L
.2659 .01472 L
.26593 .01472 L
.26596 .01472 L
.26598 .01472 L
.266 .01472 L
.26603 .01472 L
Mistroke
.26606 .01472 L
.26608 .01472 L
.26611 .01472 L
.26614 .01472 L
.26617 .01472 L
.2662 .01472 L
.26621 .01472 L
.26623 .01472 L
.26626 .01472 L
.26629 .01472 L
.26631 .01472 L
.26635 .01472 L
.26638 .01472 L
.2664 .01472 L
.26643 .01472 L
.26646 .01472 L
.26649 .01472 L
.26651 .01472 L
.26654 .01472 L
.26657 .01472 L
.2666 .01472 L
.26663 .01472 L
.26666 .01472 L
.26668 .01472 L
.2667 .01472 L
.26673 .01472 L
.26676 .01472 L
.26678 .01472 L
.26681 .01472 L
.26684 .01472 L
.26687 .01472 L
.26689 .01472 L
.26691 .01472 L
.26694 .01472 L
.26697 .01472 L
.26699 .01472 L
.26702 .01472 L
.26705 .01472 L
.26708 .01472 L
.26711 .01472 L
.26712 .01472 L
.26714 .01472 L
.26717 .01472 L
.2672 .01472 L
.26723 .01472 L
.26724 .01472 L
.26726 .01472 L
.26729 .01472 L
.26732 .01472 L
.26734 .01472 L
Mistroke
.26737 .01472 L
.26739 .01472 L
.26742 .01472 L
.26745 .01472 L
.26747 .01472 L
.26749 .01472 L
.26752 .01472 L
.26754 .01472 L
.26755 .01472 L
.26758 .01472 L
.26761 .01472 L
.26764 .01472 L
.26767 .01472 L
.26769 .01472 L
.26772 .01472 L
.26775 .01472 L
.26777 .01472 L
.2678 .01472 L
.26783 .01472 L
.26786 .01472 L
.26788 .01472 L
.26791 .01472 L
.26794 .01472 L
.26796 .01472 L
.26799 .01472 L
.26802 .01472 L
.26805 .01472 L
.26808 .01472 L
.26811 .01472 L
.26814 .01472 L
.26817 .01472 L
.26818 .01472 L
.2682 .01472 L
.26822 .01472 L
.26823 .01472 L
.26826 .01472 L
.26829 .01472 L
.26832 .01472 L
.26835 .01472 L
.26838 .01472 L
.26841 .01472 L
.26844 .01472 L
.26846 .01472 L
.26849 .01472 L
.26852 .01472 L
.26855 .01472 L
.26858 .01472 L
.26861 .01472 L
.26864 .01472 L
.26867 .01472 L
Mistroke
.26869 .01472 L
.26873 .01472 L
.26874 .01472 L
.26876 .01472 L
.26879 .01472 L
.26881 .01472 L
.26882 .01472 L
.26884 .01472 L
.26886 .01472 L
.26889 .01472 L
.2689 .01472 L
.26892 .01472 L
.26894 .01472 L
.26896 .01472 L
.26897 .01472 L
.26899 .01472 L
.26901 .01472 L
.26902 .01472 L
.26905 .01472 L
.26908 .01472 L
.26911 .01472 L
.26914 .01472 L
.26917 .01472 L
.2692 .01472 L
.26923 .01472 L
.26925 .01472 L
.26928 .01472 L
.26931 .01472 L
.26934 .01472 L
.26937 .01472 L
.26939 .01472 L
.26942 .01472 L
.26946 .01472 L
.26947 .01472 L
.26949 .01472 L
.26952 .01472 L
.26955 .01472 L
.26958 .01472 L
.2696 .01472 L
.26963 .01472 L
.26966 .01472 L
.26968 .01472 L
.26971 .01472 L
.26973 .01472 L
.26976 .01472 L
.26979 .01472 L
.26982 .01472 L
.26985 .01472 L
.26987 .01472 L
.2699 .01472 L
Mistroke
.26992 .01472 L
.26993 .01472 L
.26996 .01472 L
.26999 .01472 L
.27002 .01472 L
.27005 .01472 L
.27008 .01472 L
.27011 .01472 L
.27014 .01472 L
.27016 .01472 L
.27019 .01472 L
.27022 .01472 L
.27025 .01472 L
.27028 .01472 L
.2703 .01472 L
.27033 .01472 L
.27037 .01472 L
.27038 .01472 L
.2704 .01472 L
.27043 .01472 L
.27046 .01472 L
.27049 .01472 L
.27051 .01472 L
.27054 .01472 L
.27057 .01472 L
.2706 .01472 L
.27062 .01472 L
.27065 .01472 L
.27067 .01472 L
.2707 .01472 L
.27073 .01472 L
.27076 .01472 L
.27078 .01472 L
.27081 .01472 L
.27083 .01472 L
.27084 .01472 L
.27087 .01472 L
.2709 .01472 L
.27093 .01472 L
.27095 .01472 L
.27096 .01472 L
.27099 .01472 L
.27102 .01472 L
.27105 .01472 L
.27107 .01472 L
.2711 .01472 L
.27113 .01472 L
.27116 .01472 L
.27117 .01472 L
.27119 .01472 L
Mistroke
.27122 .01472 L
.27124 .01472 L
.27125 .01472 L
.27128 .01472 L
.27131 .01472 L
.27134 .01472 L
.27137 .01472 L
.2714 .01472 L
.27142 .01472 L
.27145 .01472 L
.27147 .01472 L
.2715 .01472 L
.27153 .01472 L
.27156 .01472 L
.27159 .01472 L
.27162 .01472 L
.27164 .01472 L
.27167 .01472 L
.2717 .01472 L
.27172 .01472 L
.27176 .01472 L
.27178 .01472 L
.27181 .01472 L
.27184 .01472 L
.27187 .01472 L
.27189 .01472 L
.2719 .01472 L
.27192 .01472 L
.27194 .01472 L
.27197 .01472 L
.272 .01472 L
.27203 .01472 L
.27206 .01472 L
.27208 .01472 L
.27211 .01472 L
.27214 .01472 L
.27216 .01472 L
.27219 .01472 L
.27222 .01472 L
.27225 .01472 L
.27228 .01472 L
.27231 .01472 L
.27234 .01472 L
.27237 .01472 L
.2724 .01472 L
.27243 .01472 L
.27245 .01472 L
.27246 .01472 L
.27249 .01472 L
.27251 .01472 L
Mistroke
.27253 .01472 L
.27254 .01472 L
.27256 .01472 L
.27259 .01472 L
.27261 .01472 L
.27262 .01472 L
.27264 .01472 L
.27266 .01472 L
.27267 .01472 L
.27269 .01472 L
.27271 .01472 L
.27272 .01472 L
.27275 .01472 L
.27278 .01472 L
.27281 .01472 L
.27284 .01472 L
.27287 .01472 L
.2729 .01472 L
.27293 .01472 L
.27295 .01472 L
.27298 .01472 L
.27301 .01472 L
.27304 .01472 L
.27307 .01472 L
.2731 .01472 L
.27313 .01472 L
.27316 .01472 L
.27318 .01472 L
.27319 .01472 L
.27322 .01472 L
.27325 .01472 L
.27328 .01472 L
.27331 .01472 L
.27334 .01472 L
.27336 .01472 L
.27339 .01472 L
.27341 .01472 L
.27344 .01472 L
.27346 .01472 L
.27349 .01472 L
.27352 .01472 L
.27355 .01472 L
.27357 .01472 L
.2736 .01472 L
.27362 .01472 L
.27363 .01472 L
.27366 .01472 L
.27369 .01472 L
.27372 .01472 L
.27375 .01472 L
Mistroke
.27378 .01472 L
.27381 .01472 L
.27384 .01472 L
.27386 .01472 L
.27389 .01472 L
.27392 .01472 L
.27395 .01472 L
.27398 .01472 L
.27401 .01472 L
.27404 .01472 L
.27407 .01472 L
.27409 .01472 L
.2741 .01472 L
.27413 .01472 L
.27416 .01472 L
.27419 .01472 L
.27422 .01472 L
.27425 .01472 L
.27427 .01472 L
.2743 .01472 L
.27432 .01472 L
.27435 .01472 L
.27437 .01472 L
.2744 .01472 L
.27443 .01472 L
.27446 .01472 L
.27448 .01472 L
.27451 .01472 L
.27453 .01472 L
.27454 .01472 L
.27457 .01472 L
.2746 .01472 L
.27463 .01472 L
.27465 .01472 L
.27466 .01472 L
.27469 .01472 L
.27472 .01472 L
.27475 .01472 L
.27477 .01472 L
.2748 .01472 L
.27483 .01472 L
.27486 .01472 L
.27488 .01472 L
.27489 .01472 L
.27492 .01472 L
.27494 .01472 L
.27496 .01472 L
.27499 .01472 L
.27502 .01472 L
.27505 .01472 L
Mistroke
.27507 .01472 L
.2751 .01472 L
.27513 .01472 L
.27515 .01472 L
.27518 .01472 L
.2752 .01472 L
.27523 .01472 L
.27526 .01472 L
.27529 .01472 L
.27532 .01472 L
.27535 .01472 L
.27537 .01472 L
.2754 .01472 L
.27543 .01472 L
.27546 .01472 L
.27549 .01472 L
.27551 .01472 L
.27555 .01472 L
.27557 .01472 L
.27559 .01472 L
.27561 .01472 L
.27562 .01472 L
.27564 .01472 L
.27567 .01472 L
.2757 .01472 L
.27573 .01472 L
.27576 .01472 L
.27579 .01472 L
.27582 .01472 L
.27584 .01472 L
.27587 .01472 L
.2759 .01472 L
.27593 .01472 L
.27596 .01472 L
.27598 .01472 L
.27601 .01472 L
.27604 .01472 L
.27607 .01472 L
.2761 .01472 L
.27613 .01472 L
.27615 .01472 L
.27617 .01472 L
.2762 .01472 L
.27621 .01472 L
.27623 .01472 L
.27624 .01472 L
.27626 .01472 L
.27629 .01472 L
.27631 .01472 L
.27632 .01472 L
Mistroke
.27634 .01472 L
.27636 .01472 L
.27638 .01472 L
.27639 .01472 L
.27641 .01472 L
.27643 .01472 L
.27646 .01472 L
.27649 .01472 L
.27651 .01472 L
.27655 .01472 L
.27658 .01472 L
.2766 .01472 L
.27663 .01472 L
.27666 .01472 L
.27668 .01472 L
.27671 .01472 L
.27674 .01472 L
.27677 .01472 L
.2768 .01472 L
.27683 .01472 L
.27686 .01472 L
.27688 .01472 L
.27689 .01472 L
.27693 .01472 L
.27695 .01472 L
.27698 .01472 L
.27701 .01472 L
.27704 .01472 L
.27706 .01472 L
.27709 .01472 L
.27711 .01472 L
.27714 .01472 L
.27717 .01472 L
.27719 .01472 L
.27722 .01472 L
.27725 .01472 L
.27727 .01472 L
.2773 .01472 L
.27732 .01472 L
.27734 .01472 L
.27736 .01472 L
.27739 .01472 L
.27742 .01472 L
.27746 .01472 L
.27749 .01472 L
.27751 .01472 L
.27754 .01472 L
.27757 .01472 L
.27759 .01472 L
.27762 .01472 L
Mistroke
.27765 .01472 L
.27768 .01472 L
.27771 .01472 L
.27774 .01472 L
.27777 .01472 L
.27779 .01472 L
.2778 .01472 L
.27783 .01472 L
.27786 .01472 L
.27789 .01472 L
.27792 .01472 L
.27795 .01472 L
.27797 .01472 L
.278 .01472 L
.27802 .01472 L
.27805 .01472 L
.27808 .01472 L
.2781 .01472 L
.27813 .01472 L
.27816 .01472 L
.27818 .01472 L
.27821 .01472 L
.27823 .01472 L
.27825 .01472 L
.27827 .01472 L
.2783 .01472 L
.27833 .01472 L
.27837 .01472 L
.2784 .01472 L
.27842 .01472 L
.27845 .01472 L
.27848 .01472 L
.2785 .01472 L
.27853 .01472 L
.27856 .01472 L
.27859 .01472 L
.27862 .01472 L
.27865 .01472 L
.27868 .01472 L
.2787 .01472 L
.27871 .01472 L
.27875 .01472 L
.27878 .01472 L
.2788 .01472 L
.27883 .01472 L
.27886 .01472 L
.27889 .01472 L
.27891 .01472 L
.27893 .01472 L
.27896 .01472 L
Mistroke
.27899 .01472 L
.27901 .01472 L
.27904 .01472 L
.27907 .01472 L
.2791 .01472 L
.27913 .01472 L
.27914 .01472 L
.27916 .01472 L
.27919 .01472 L
.27922 .01472 L
.27924 .01472 L
.27926 .01472 L
.27928 .01472 L
.2793 .01472 L
.27933 .01472 L
.27936 .01472 L
.27939 .01472 L
.27941 .01472 L
.27944 .01472 L
.27947 .01472 L
.27949 .01472 L
.27951 .01472 L
.27954 .01472 L
.27955 .01472 L
.27957 .01472 L
.2796 .01472 L
.27963 .01472 L
.27966 .01472 L
.27969 .01472 L
.27971 .01472 L
.27974 .01472 L
.27977 .01472 L
.27979 .01472 L
.27982 .01472 L
.27985 .01472 L
.27988 .01472 L
.2799 .01472 L
.27993 .01472 L
.27996 .01472 L
.27998 .01472 L
.28001 .01472 L
.28004 .01472 L
.28007 .01472 L
.2801 .01472 L
.28013 .01472 L
.28016 .01472 L
.28019 .01472 L
.2802 .01472 L
.28022 .01472 L
.28024 .01472 L
Mistroke
.28025 .01472 L
.28028 .01472 L
.28031 .01472 L
.28034 .01472 L
.28037 .01472 L
.2804 .01472 L
.28043 .01472 L
.28046 .01472 L
.28048 .01472 L
.28051 .01472 L
.28054 .01472 L
.28057 .01472 L
.2806 .01472 L
.28063 .01472 L
.28066 .01472 L
.28069 .01472 L
.28071 .01472 L
.28075 .01472 L
.28076 .01472 L
.28078 .01472 L
.28081 .01472 L
.28083 .01472 L
.28084 .01472 L
.28086 .01472 L
.28088 .01472 L
.28091 .01472 L
.28092 .01472 L
.28094 .01472 L
.28096 .01472 L
.28098 .01472 L
.28099 .01472 L
.28101 .01472 L
.28103 .01472 L
.28104 .01472 L
.28107 .01472 L
.2811 .01472 L
.28113 .01472 L
.28116 .01472 L
.28119 .01472 L
.28122 .01472 L
.28125 .01472 L
.28127 .01472 L
.2813 .01472 L
.28133 .01472 L
.28136 .01472 L
.28139 .01472 L
.28141 .01472 L
.28144 .01472 L
.28148 .01472 L
.28149 .01472 L
Mistroke
.28151 .01472 L
.28154 .01472 L
.28157 .01472 L
.2816 .01472 L
.28162 .01472 L
.28165 .01472 L
.28168 .01472 L
.28171 .01472 L
.28173 .01472 L
.28175 .01472 L
.28178 .01472 L
.28181 .01472 L
.28184 .01472 L
.28187 .01472 L
.28189 .01472 L
.28192 .01472 L
.28194 .01472 L
.28195 .01472 L
.28198 .01472 L
.28201 .01472 L
.28204 .01472 L
.28207 .01472 L
.2821 .01472 L
.28213 .01472 L
.28216 .01472 L
.28218 .01472 L
.28221 .01472 L
.28224 .01472 L
.28227 .01472 L
.2823 .01472 L
.28232 .01472 L
.28235 .01472 L
.28239 .01472 L
.2824 .01472 L
.28242 .01472 L
.28245 .01472 L
.28248 .01472 L
.28251 .01472 L
.28253 .01472 L
.28256 .01472 L
.28259 .01472 L
.28262 .01472 L
.28264 .01472 L
.28267 .01472 L
.28269 .01472 L
.28272 .01472 L
.28275 .01472 L
.28278 .01472 L
.2828 .01472 L
.28283 .01472 L
Mistroke
.28285 .01472 L
.28286 .01472 L
.28289 .01472 L
.28292 .01472 L
.28295 .01472 L
.28297 .01472 L
.28298 .01472 L
.28301 .01472 L
.28304 .01472 L
.28307 .01472 L
.28309 .01472 L
.28312 .01472 L
.28315 .01472 L
.28318 .01472 L
.28319 .01472 L
.28321 .01472 L
.28324 .01472 L
.28326 .01472 L
.28328 .01472 L
.2833 .01472 L
.28334 .01472 L
.28337 .01472 L
.28339 .01472 L
.28342 .01472 L
.28345 .01472 L
.28347 .01472 L
.28349 .01472 L
.28352 .01472 L
.28355 .60332 L
.28358 .60332 L
.28361 .60332 L
.28383 .60332 L
.28477 .60332 L
.28577 .60332 L
.28674 .60332 L
.28766 .60332 L
.28865 .60332 L
.2896 .60332 L
.29051 .60332 L
.29149 .60332 L
.29242 .60332 L
.29342 .60332 L
.29438 .60332 L
.2953 .60332 L
.29628 .60332 L
.29722 .60332 L
.29813 .60332 L
.2991 .60332 L
.30003 .60332 L
.30051 .60332 L
Mistroke
.30063 .60332 L
.30075 .60332 L
.30079 .60332 L
.30082 .60332 L
.30086 .60332 L
.30087 .01472 L
.30089 .01472 L
.30092 .01472 L
.30094 .01472 L
.30095 .01472 L
.30098 .01472 L
.301 .01472 L
.30102 .01472 L
.30105 .01472 L
.30107 .01472 L
.3011 .01472 L
.30113 .01472 L
.30116 .01472 L
.30118 .01472 L
.3012 .01472 L
.30123 .01472 L
.30126 .01472 L
.30128 .01472 L
.30131 .01472 L
.30134 .01472 L
.30136 .01472 L
.30139 .01472 L
.30142 .01472 L
.30145 .01472 L
.30148 .01472 L
.30149 .01472 L
.30151 .01472 L
.30154 .01472 L
.30157 .01472 L
.3016 .01472 L
.30162 .01472 L
.30163 .01472 L
.30166 .01472 L
.30168 .01472 L
.3017 .01472 L
.30171 .01472 L
.30173 .01472 L
.30176 .01472 L
.30179 .01472 L
.30182 .01472 L
.30185 .01472 L
.30188 .01472 L
.3019 .01472 L
.30191 .01472 L
.30194 .01472 L
Mistroke
.30197 .01472 L
.302 .01472 L
.30203 .01472 L
.30206 .01472 L
.30209 .01472 L
.30212 .01472 L
.30214 .01472 L
.30217 .01472 L
.3022 .01472 L
.30223 .01472 L
.30226 .01472 L
.30229 .01472 L
.30232 .01472 L
.30235 .01472 L
.30236 .01472 L
.30238 .01472 L
.30241 .01472 L
.30244 .01472 L
.30247 .01472 L
.30249 .01472 L
.30252 .01472 L
.30255 .01472 L
.30258 .01472 L
.3026 .01472 L
.30262 .01472 L
.30265 .01472 L
.30268 .01472 L
.30271 .01472 L
.30274 .01472 L
.30276 .01472 L
.30279 .01472 L
.30281 .01472 L
.30282 .01472 L
.30285 .01472 L
.30288 .01472 L
.30291 .01472 L
.30294 .01472 L
.30297 .01472 L
.303 .01472 L
.30303 .01472 L
.30305 .01472 L
.30308 .01472 L
.30311 .01472 L
.30314 .01472 L
.30317 .01472 L
.30319 .01472 L
.30322 .01472 L
.30326 .01472 L
.30327 .01472 L
.30329 .01472 L
Mistroke
.30332 .01472 L
.30335 .01472 L
.30338 .01472 L
.3034 .01472 L
.30343 .01472 L
.30346 .01472 L
.30348 .01472 L
.30351 .01472 L
.30353 .01472 L
.30356 .01472 L
.30359 .01472 L
.30362 .01472 L
.30364 .01472 L
.30367 .01472 L
.3037 .01472 L
.30372 .01472 L
.30373 .01472 L
.30376 .01472 L
.30379 .01472 L
.30382 .01472 L
.30385 .01472 L
.30388 .01472 L
.30391 .01472 L
.30394 .01472 L
.30396 .01472 L
.30399 .01472 L
.30402 .01472 L
.30405 .01472 L
.30408 .01472 L
.3041 .01472 L
.30413 .01472 L
.30416 .01472 L
.30418 .01472 L
.3042 .01472 L
.30423 .01472 L
.30426 .01472 L
.30428 .01472 L
.30431 .01472 L
.30434 .01472 L
.30437 .01472 L
.30439 .01472 L
.30442 .01472 L
.30444 .01472 L
.30447 .01472 L
.3045 .01472 L
.30453 .01472 L
.30455 .01472 L
.30458 .01472 L
.30461 .01472 L
.30463 .01472 L
Mistroke
.30464 .01472 L
.30467 .01472 L
.3047 .01472 L
.30473 .01472 L
.30476 .01472 L
.30479 .01472 L
.30482 .01472 L
.30484 .01472 L
.30487 .01472 L
.3049 .01472 L
.30493 .01472 L
.30496 .01472 L
.30499 .01472 L
.30501 .01472 L
.30504 .01472 L
.30508 .01472 L
.30509 .01472 L
.30511 .01472 L
.30514 .01472 L
.30517 .01472 L
.3052 .01472 L
.30522 .01472 L
.30525 .01472 L
.30528 .01472 L
.30531 .01472 L
.30533 .01472 L
.30536 .01472 L
.30538 .01472 L
.30541 .01472 L
.30544 .01472 L
.30547 .01472 L
.30549 .01472 L
.30552 .01472 L
.30554 .01472 L
.30555 .01472 L
.30558 .01472 L
.30561 .01472 L
.30564 .01472 L
.30566 .01472 L
.30567 .01472 L
.3057 .01472 L
.30573 .01472 L
.30576 .01472 L
.30578 .01472 L
.30581 .01472 L
.30584 .01472 L
.30587 .01472 L
.30588 .01472 L
.3059 .01472 L
.30593 .01472 L
Mistroke
.30595 .01472 L
.30597 .01472 L
.30599 .01472 L
.30603 .01472 L
.30605 .01472 L
.30608 .01472 L
.30611 .01472 L
.30613 .01472 L
.30616 .01472 L
.30618 .01472 L
.30621 .01472 L
.30624 .01472 L
.30627 .01472 L
.3063 .01472 L
.30633 .01472 L
.30635 .01472 L
.30638 .01472 L
.30641 .01472 L
.30644 .01472 L
.30647 .01472 L
.30649 .01472 L
.30652 .01472 L
.30655 .01472 L
.30658 .01472 L
.3066 .01472 L
.30661 .01472 L
.30663 .01472 L
.30665 .01472 L
.30668 .01472 L
.30671 .01472 L
.30674 .01472 L
.30677 .01472 L
.3068 .01472 L
.30682 .01472 L
.30685 .01472 L
.30688 .01472 L
.3069 .01472 L
.30694 .01472 L
.30696 .01472 L
.30699 .01472 L
.30702 .01472 L
.30705 .01472 L
.30708 .01472 L
.30711 .01472 L
.30714 .01472 L
.30716 .01472 L
.30717 .01472 L
.3072 .01472 L
.30722 .01472 L
.30724 .01472 L
Mistroke
.30725 .01472 L
.30727 .01472 L
.3073 .01472 L
.30732 .01472 L
.30733 .01472 L
.30735 .01472 L
.30737 .01472 L
.30739 .01472 L
.3074 .01472 L
.30742 .01472 L
.30744 .01472 L
.30746 .01472 L
.30749 .01472 L
.30752 .01472 L
.30756 .01472 L
.30759 .01472 L
.30761 .01472 L
.30764 .01472 L
.30767 .01472 L
.30769 .01472 L
.30772 .01472 L
.30775 .01472 L
.30778 .01472 L
.30781 .01472 L
.30784 .01472 L
.30787 .01472 L
.30789 .01472 L
.3079 .01472 L
.30793 .01472 L
.30796 .01472 L
.30799 .01472 L
.30802 .01472 L
.30805 .01472 L
.30807 .01472 L
.3081 .01472 L
.30812 .01472 L
.30815 .01472 L
.30818 .01472 L
.3082 .01472 L
.30823 .01472 L
.30826 .01472 L
.30828 .01472 L
.30831 .01472 L
.30833 .01472 L
.30835 .01472 L
.30837 .01472 L
.3084 .01472 L
.30843 .01472 L
.30847 .01472 L
.3085 .01472 L
Mistroke
.30852 .01472 L
.30855 .01472 L
.30858 .01472 L
.3086 .01472 L
.30863 .01472 L
.30866 .01472 L
.30869 .01472 L
.30872 .01472 L
.30875 .01472 L
.30878 .01472 L
.3088 .01472 L
.30881 .01472 L
.30885 .01472 L
.30887 .01472 L
.3089 .01472 L
.30893 .01472 L
.30896 .01472 L
.30898 .01472 L
.30901 .01472 L
.30903 .01472 L
.30906 .01472 L
.30909 .01472 L
.30911 .01472 L
.30914 .01472 L
.30917 .01472 L
.3092 .01472 L
.30923 .01472 L
.30924 .01472 L
.30926 .01472 L
.30929 .01472 L
.30932 .01472 L
.30934 .01472 L
.30936 .01472 L
.30938 .01472 L
.3094 .01472 L
.30943 .01472 L
.30946 .01472 L
.30949 .01472 L
.30951 .01472 L
.30954 .01472 L
.30957 .01472 L
.30959 .01472 L
.3096 .01472 L
.30964 .01472 L
.30965 .01472 L
.30967 .01472 L
.3097 .01472 L
.30973 .01472 L
.30976 .01472 L
.30979 .01472 L
Mistroke
.30981 .01472 L
.30984 .01472 L
.30986 .01472 L
.30989 .01472 L
.30992 .01472 L
.30995 .01472 L
.30997 .01472 L
.31 .01472 L
.31003 .01472 L
.31006 .01472 L
.31008 .01472 L
.31011 .01472 L
.31014 .01472 L
.31017 .01472 L
.3102 .01472 L
.31023 .01472 L
.31026 .01472 L
.31029 .01472 L
.3103 .01472 L
.31032 .01472 L
.31034 .01472 L
.31035 .01472 L
.31038 .01472 L
.31041 .01472 L
.31044 .01472 L
.31047 .01472 L
.3105 .01472 L
.31053 .01472 L
.31056 .01472 L
.31058 .01472 L
.31061 .01472 L
.31064 .01472 L
.31067 .01472 L
.3107 .01472 L
.31073 .01472 L
.31076 .01472 L
.31079 .01472 L
.31081 .01472 L
.31084 .01472 L
.31086 .01472 L
.31088 .01472 L
.31091 .01472 L
.31092 .01472 L
.31094 .01472 L
.31096 .01472 L
.31097 .01472 L
.311 .01472 L
.31102 .01472 L
.31104 .01472 L
.31106 .01472 L
Mistroke
.31107 .01472 L
.31109 .01472 L
.31111 .01472 L
.31112 .01472 L
.31114 .01472 L
.31117 .01472 L
.3112 .01472 L
.31123 .01472 L
.31126 .01472 L
.31129 .01472 L
.31132 .01472 L
.31134 .01472 L
.31137 .01472 L
.3114 .01472 L
.31143 .01472 L
.31145 .01472 L
.31149 .01472 L
.31151 .01472 L
.31154 .01472 L
.31157 .01472 L
.31159 .01472 L
.31161 .01472 L
.31164 .01472 L
.31167 .01472 L
.31169 .01472 L
.31172 .01472 L
.31175 .01472 L
.31178 .01472 L
.3118 .01472 L
.31183 .01472 L
.31185 .01472 L
.31188 .01472 L
.31191 .01472 L
.31194 .01472 L
.31196 .01472 L
.31199 .01472 L
.31202 .01472 L
.31203 .01472 L
.31205 .01472 L
.31208 .01472 L
.31211 .01472 L
.31214 .01472 L
.31217 .01472 L
.3122 .01472 L
.31223 .01472 L
.31225 .01472 L
.31228 .01472 L
.31231 .01472 L
.31234 .01472 L
.31236 .01472 L
Mistroke
.3124 .01472 L
.31242 .01472 L
.31245 .01472 L
.31248 .01472 L
.3125 .01472 L
.31252 .01472 L
.31255 .01472 L
.31258 .01472 L
.3126 .01472 L
.31263 .01472 L
.31266 .01472 L
.31269 .01472 L
.31271 .01472 L
.31274 .01472 L
.31276 .01472 L
.31279 .01472 L
.31282 .01472 L
.31285 .01472 L
.31287 .01472 L
.3129 .01472 L
.31293 .01472 L
.31295 .01472 L
.31296 .01472 L
.31299 .01472 L
.31302 .01472 L
.31305 .01472 L
.31306 .01472 L
.31308 .01472 L
.31311 .01472 L
.31314 .01472 L
.31316 .01472 L
.31319 .01472 L
.31322 .01472 L
.31325 .01472 L
.31328 .01472 L
.31329 .01472 L
.31331 .01472 L
.31334 .01472 L
.31336 .01472 L
.31337 .01472 L
.3134 .01472 L
.31343 .01472 L
.31346 .01472 L
.31349 .01472 L
.31352 .01472 L
.31354 .01472 L
.31357 .01472 L
.31359 .01472 L
.31362 .01472 L
.31365 .01472 L
Mistroke
.31368 .01472 L
.3137 .01472 L
.31373 .01472 L
.31376 .01472 L
.31379 .01472 L
.31381 .01472 L
.31384 .01472 L
.31387 .01472 L
.3139 .01472 L
.31393 .01472 L
.31396 .01472 L
.31399 .01472 L
.31401 .01472 L
.31402 .01472 L
.31404 .01472 L
.31406 .01472 L
.31409 .01472 L
.31411 .01472 L
.31414 .01472 L
.31418 .01472 L
.3142 .01472 L
.31423 .01472 L
.31426 .01472 L
.31428 .01472 L
.31431 .01472 L
.31434 .01472 L
.31437 .01472 L
.3144 .01472 L
.31443 .01472 L
.31446 .01472 L
.31449 .01472 L
.31452 .01472 L
.31455 .01472 L
.31457 .01472 L
.31458 .01472 L
.31461 .01472 L
.31463 .01472 L
.31464 .01472 L
.31466 .01472 L
.31468 .01472 L
.31471 .01472 L
.31472 .01472 L
.31474 .01472 L
.31476 .01472 L
.31478 .01472 L
.31479 .01472 L
.31481 .01472 L
.31483 .01472 L
.31484 .01472 L
.31487 .01472 L
Mistroke
.3149 .01472 L
.31493 .01472 L
.31496 .01472 L
.31499 .01472 L
.31502 .01472 L
.31505 .01472 L
.31507 .01472 L
.3151 .01472 L
.31513 .01472 L
.31516 .01472 L
.31519 .01472 L
.31522 .01472 L
.31525 .01472 L
.31528 .01472 L
.31529 .01472 L
.31531 .01472 L
.31534 .01472 L
.31537 .01472 L
.3154 .01472 L
.31542 .01472 L
.31545 .01472 L
.31548 .01472 L
.31551 .01472 L
.31553 .01472 L
.31556 .01472 L
.31558 .01472 L
.31561 .01472 L
.31564 .01472 L
.31567 .01472 L
.31569 .01472 L
.31572 .01472 L
.31574 .01472 L
.31575 .01472 L
.31578 .01472 L
.31581 .01472 L
.31584 .01472 L
.31587 .01472 L
.3159 .01472 L
.31593 .01472 L
.31596 .01472 L
.31598 .01472 L
.31601 .01472 L
.31604 .01472 L
.31607 .01472 L
.3161 .01472 L
.31613 .01472 L
.31615 .01472 L
.31619 .01472 L
.3162 .01472 L
.31622 .01472 L
Mistroke
.31625 .01472 L
.31628 .01472 L
.31631 .01472 L
.31633 .01472 L
.31636 .01472 L
.31639 .01472 L
.31642 .01472 L
.31644 .01472 L
.31647 .01472 L
.31649 .01472 L
.31652 .01472 L
.31655 .01472 L
.31658 .01472 L
.3166 .01472 L
.31663 .01472 L
.31665 .01472 L
.31666 .01472 L
.31669 .01472 L
.31672 .01472 L
.31675 .01472 L
.31677 .01472 L
.31678 .01472 L
.31681 .01472 L
.31684 .01472 L
.31687 .01472 L
.31689 .01472 L
.31692 .01472 L
.31695 .01472 L
.31698 .01472 L
.31699 .01472 L
.31701 .01472 L
.31704 .01472 L
.31706 .01472 L
.31708 .01472 L
.3171 .01472 L
.31714 .01472 L
.31717 .01472 L
.31719 .01472 L
.31722 .01472 L
.31724 .01472 L
.31727 .01472 L
.31729 .01472 L
.31732 .01472 L
.31735 .01472 L
.31738 .01472 L
.31741 .01472 L
.31744 .01472 L
.31746 .01472 L
.31749 .01472 L
.31752 .01472 L
Mistroke
.31755 .01472 L
.31758 .01472 L
.3176 .01472 L
.31763 .01472 L
.31766 .01472 L
.31769 .01472 L
.31771 .01472 L
.31772 .01472 L
.31774 .01472 L
.31776 .01472 L
.31779 .01472 L
.31782 .01472 L
.31785 .01472 L
.31788 .01472 L
.3179 .01472 L
.31793 .01472 L
.31796 .01472 L
.31798 .01472 L
.31801 .01472 L
.31804 .01472 L
.31807 .01472 L
.3181 .01472 L
.31813 .01472 L
.31816 .01472 L
.31819 .01472 L
.31822 .01472 L
.31825 .01472 L
.31827 .01472 L
.31828 .01472 L
.31831 .01472 L
.31833 .01472 L
.31835 .01472 L
.31836 .01472 L
.31838 .01472 L
.31841 .01472 L
.31843 .01472 L
.31844 .01472 L
.31846 .01472 L
.31848 .01472 L
.31849 .01472 L
.31851 .01472 L
.31853 .01472 L
.31854 .01472 L
.31857 .01472 L
.3186 .01472 L
.31863 .01472 L
.31866 .01472 L
.31869 .01472 L
.31872 .01472 L
.31875 .01472 L
Mistroke
.31877 .01472 L
.3188 .01472 L
.31883 .01472 L
.31886 .01472 L
.31889 .01472 L
.31892 .01472 L
.31895 .01472 L
.31898 .01472 L
.319 .01472 L
.31901 .01472 L
.31904 .01472 L
.31907 .01472 L
.3191 .01472 L
.31913 .01472 L
.31916 .01472 L
.31918 .01472 L
.31921 .01472 L
.31923 .01472 L
.31926 .01472 L
.31928 .01472 L
.31931 .01472 L
.31934 .01472 L
.31937 .01472 L
.31939 .01472 L
.31942 .01472 L
.31944 .01472 L
.31945 .01472 L
.31948 .01472 L
.31951 .01472 L
.31954 .01472 L
.31957 .01472 L
.3196 .01472 L
.31963 .01472 L
.31966 .01472 L
.31968 .01472 L
.31971 .01472 L
.31974 .01472 L
.31977 .01472 L
.3198 .01472 L
.31983 .01472 L
.31986 .01472 L
.31989 .01472 L
.31991 .01472 L
.31992 .01472 L
.31995 .01472 L
.31998 .01472 L
.32001 .01472 L
.32004 .01472 L
.32006 .01472 L
.32009 .01472 L
Mistroke
.32012 .01472 L
.32014 .01472 L
.32017 .01472 L
.32019 .01472 L
.32022 .01472 L
.32025 .01472 L
.32028 .01472 L
.3203 .01472 L
.32033 .01472 L
.32035 .01472 L
.32036 .01472 L
.32039 .01472 L
.32042 .01472 L
.32045 .01472 L
.32048 .01472 L
.32051 .01472 L
.32054 .01472 L
.32057 .01472 L
.32059 .01472 L
.32062 .01472 L
.32065 .01472 L
.32068 .01472 L
.32071 .01472 L
.32074 .01472 L
.32077 .01472 L
.3208 .01472 L
.32082 .01472 L
.32083 .01472 L
.32086 .01472 L
.32089 .01472 L
.32092 .01472 L
.32095 .01472 L
.32098 .01472 L
.321 .01472 L
.32103 .01472 L
.32105 .01472 L
.32108 .01472 L
.3211 .01472 L
.32113 .01472 L
.32116 .01472 L
.32119 .01472 L
.32121 .01472 L
.32124 .01472 L
.32126 .01472 L
.32128 .01472 L
.3213 .01472 L
.32133 .01472 L
.32136 .01472 L
.32138 .01472 L
.32139 .01472 L
Mistroke
.32142 .01472 L
.32145 .01472 L
.32148 .01472 L
.3215 .01472 L
.32153 .01472 L
.32156 .01472 L
.32159 .01472 L
.32161 .01472 L
.32162 .01472 L
.32165 .01472 L
.32167 .01472 L
.32169 .01472 L
.32172 .01472 L
.32175 .01472 L
.32178 .01472 L
.32181 .01472 L
.32183 .01472 L
.32186 .01472 L
.32188 .01472 L
.32191 .01472 L
.32193 .01472 L
.32196 .01472 L
.32199 .01472 L
.32202 .01472 L
.32205 .01472 L
.32208 .01472 L
.3221 .01472 L
.32213 .01472 L
.32216 .01472 L
.32219 .01472 L
.32222 .01472 L
.32225 .01472 L
.32228 .01472 L
.32231 .01472 L
.32232 .01472 L
.32234 .01472 L
.32236 .01472 L
.32237 .01472 L
.3224 .01472 L
.32243 .01472 L
.32246 .01472 L
.32249 .01472 L
.32252 .01472 L
.32255 .01472 L
.32257 .01472 L
.3226 .01472 L
.32263 .01472 L
.32266 .01472 L
.32269 .01472 L
.32272 .01472 L
Mistroke
.32274 .01472 L
.32278 .01472 L
.32281 .01472 L
.32283 .01472 L
.32286 .01472 L
.32288 .01472 L
.3229 .01472 L
.32293 .01472 L
.32294 .01472 L
.32296 .01472 L
.32298 .01472 L
.32299 .01472 L
.32302 .01472 L
.32304 .01472 L
.32306 .01472 L
.32307 .01472 L
.32309 .01472 L
.32311 .01472 L
.32313 .01472 L
.32314 .01472 L
.32316 .01472 L
.32319 .01472 L
.32322 .01472 L
.32325 .01472 L
.32328 .01472 L
.32331 .01472 L
.32334 .01472 L
.32336 .01472 L
.32339 .01472 L
.32342 .01472 L
.32344 .01472 L
.32347 .01472 L
.32351 .01472 L
.32353 .01472 L
.32356 .01472 L
.32359 .01472 L
.32361 .01472 L
.32363 .01472 L
.32366 .01472 L
.32369 .01472 L
.32371 .01472 L
.32374 .01472 L
.32377 .01472 L
.3238 .01472 L
.32382 .01472 L
.32385 .01472 L
.32387 .01472 L
.3239 .01472 L
.32393 .01472 L
.32396 .01472 L
Mistroke
.32398 .01472 L
.32401 .01472 L
.32404 .01472 L
.32405 .01472 L
.32407 .01472 L
.3241 .01472 L
.32413 .01472 L
.32416 .01472 L
.32419 .01472 L
.32422 .01472 L
.32425 .01472 L
.32427 .01472 L
.3243 .01472 L
.32433 .01472 L
.32435 .01472 L
.32438 .01472 L
.32442 .01472 L
.32444 .01472 L
.32447 .01472 L
.3245 .01472 L
.32452 .01472 L
.32454 .01472 L
.32457 .01472 L
.3246 .01472 L
.32462 .01472 L
.32465 .01472 L
.32468 .01472 L
.32471 .01472 L
.32473 .01472 L
.32476 .01472 L
.32478 .01472 L
.32481 .01472 L
.32484 .01472 L
.32487 .01472 L
.32489 .01472 L
.32492 .01472 L
.32495 .01472 L
.32497 .01472 L
.32498 .01472 L
.32501 .01472 L
.32504 .01472 L
.32507 .01472 L
.32508 .01472 L
.3251 .01472 L
.32513 .01472 L
.32516 .01472 L
.32518 .01472 L
.32521 .01472 L
.32524 .01472 L
.32527 .01472 L
Mistroke
.3253 .01472 L
.32531 .01472 L
.32533 .01472 L
.32536 .01472 L
.32538 .01472 L
.32539 .01472 L
.32542 .01472 L
.32545 .01472 L
.32548 .01472 L
.32551 .01472 L
.32554 .01472 L
.32556 .01472 L
.32559 .01472 L
.32561 .01472 L
.32564 .01472 L
.32567 .01472 L
.3257 .01472 L
.32572 .01472 L
.32575 .01472 L
.32578 .01472 L
.32581 .01472 L
.32583 .01472 L
.32586 .01472 L
.32589 .01472 L
.32592 .01472 L
.32595 .01472 L
.32598 .01472 L
.32601 .01472 L
.32603 .01472 L
.32604 .01472 L
.32606 .01472 L
.32608 .01472 L
.32611 .01472 L
.32613 .01472 L
.32616 .01472 L
.3262 .01472 L
.32622 .01472 L
.32625 .01472 L
.32628 .01472 L
.3263 .01472 L
.32633 .01472 L
.32636 .01472 L
.32639 .01472 L
.32642 .01472 L
.32645 .01472 L
.32648 .01472 L
.32651 .01472 L
.32654 .01472 L
.32657 .01472 L
.32659 .01472 L
Mistroke
.3266 .01472 L
.32663 .01472 L
.32665 .01472 L
.32666 .01472 L
.32668 .01472 L
.3267 .01472 L
.32673 .01472 L
.32675 .01472 L
.32676 .01472 L
.32678 .01472 L
.3268 .01472 L
.32681 .01472 L
.32683 .01472 L
.32685 .01472 L
.32686 .01472 L
.32689 .01472 L
.32692 .01472 L
.32695 .01472 L
.32698 .01472 L
.32701 .01472 L
.32704 .01472 L
.32707 .01472 L
.32709 .01472 L
.32712 .01472 L
.32715 .01472 L
.32718 .01472 L
.32721 .01472 L
.32724 .01472 L
.32727 .01472 L
.3273 .01472 L
.32732 .01472 L
.32733 .01472 L
.32736 .01472 L
.32739 .01472 L
.32742 .01472 L
.32745 .01472 L
.32747 .01472 L
.3275 .01472 L
.32753 .01472 L
.32755 .01472 L
.32758 .01472 L
.3276 .01472 L
.32763 .01472 L
.32766 .01472 L
.32769 .01472 L
.32771 .01472 L
.32774 .01472 L
.32776 .01472 L
.32777 .01472 L
.3278 .01472 L
Mistroke
.32783 .01472 L
.32786 .01472 L
.32789 .01472 L
.32792 .01472 L
.32795 .01472 L
.32798 .01472 L
.328 .01472 L
.32803 .01472 L
.32806 .01472 L
.32809 .01472 L
.32812 .01472 L
.32815 .01472 L
.32818 .01472 L
.32821 .01472 L
.32823 .01472 L
.32824 .01472 L
.32827 .01472 L
.3283 .01472 L
.32833 .01472 L
.32836 .01472 L
.32838 .01472 L
.32841 .01472 L
.32844 .01472 L
.32846 .01472 L
.32849 .01472 L
.32851 .01472 L
.32854 .01472 L
.32857 .01472 L
.3286 .01472 L
.32862 .01472 L
.32865 .01472 L
.32867 .01472 L
.32868 .01472 L
.32871 .01472 L
.32874 .01472 L
.32877 .01472 L
.32879 .01472 L
.3288 .01472 L
.32883 .01472 L
.32886 .01472 L
.32889 .01472 L
.32891 .01472 L
.32894 .01472 L
.32897 .01472 L
.329 .01472 L
.32902 .01472 L
.32903 .01472 L
.32906 .01472 L
.32908 .01472 L
.3291 .01472 L
Mistroke
.32913 .01472 L
.32916 .01472 L
.32919 .01472 L
.32921 .01472 L
.32924 .01472 L
.32927 .01472 L
.32929 .01472 L
.32932 .01472 L
.32934 .01472 L
.32937 .01472 L
.3294 .01472 L
.32943 .01472 L
.32946 .01472 L
.32949 .01472 L
.32951 .01472 L
.32954 .01472 L
.32957 .01472 L
.3296 .01472 L
.32963 .01472 L
.32965 .01472 L
.32969 .01472 L
.32971 .01472 L
.32973 .01472 L
.32975 .01472 L
.32976 .01472 L
.32978 .01472 L
.32981 .01472 L
.32984 .01472 L
.32987 .01472 L
.3299 .01472 L
.32993 .01472 L
.32996 .01472 L
.32998 .01472 L
.33001 .01472 L
.33004 .01472 L
.33007 .01472 L
.3301 .01472 L
.33012 .01472 L
.33015 .01472 L
.33018 .01472 L
.33021 .01472 L
.33024 .01472 L
.33027 .01472 L
.33029 .01472 L
.33031 .01472 L
.33034 .01472 L
.33035 .01472 L
.33037 .01472 L
.33038 .01472 L
.3304 .01472 L
Mistroke
.33043 .01472 L
.33045 .01472 L
.33046 .01472 L
.33048 .01472 L
.3305 .01472 L
.33052 .01472 L
.33053 .01472 L
.33055 .01472 L
.33057 .01472 L
.3306 .01472 L
.33063 .01472 L
.33066 .01472 L
.33069 .01472 L
.33072 .01472 L
.33074 .01472 L
.33077 .01472 L
.3308 .01472 L
.33083 .01472 L
.33085 .01472 L
.33088 .01472 L
.33091 .01472 L
.33094 .01472 L
.33097 .01472 L
.331 .01472 L
.33102 .01472 L
.33103 .01472 L
.33107 .01472 L
.3311 .01472 L
.33112 .01472 L
.33115 .01472 L
.33118 .01472 L
.3312 .01472 L
.33123 .01472 L
.33125 .01472 L
.33128 .01472 L
.33131 .01472 L
.33133 .01472 L
.33136 .01472 L
.33139 .01472 L
.33142 .01472 L
.33145 .01472 L
.33146 .01472 L
.33148 .01472 L
.33151 .01472 L
.33154 .01472 L
.33156 .01472 L
.3316 .01472 L
.33163 .01472 L
.33165 .01472 L
.33168 .01472 L
Mistroke
.33171 .01472 L
.33173 .01472 L
.33176 .01472 L
.33179 .01472 L
.33182 .01472 L
.33185 .01472 L
.33188 .01472 L
.33191 .01472 L
.33193 .01472 L
.33194 .01472 L
.33198 .01472 L
.33201 .01472 L
.33203 .01472 L
.33206 .01472 L
.33209 .01472 L
.33211 .01472 L
.33214 .01472 L
.33216 .01472 L
.33219 .01472 L
.33222 .01472 L
.33224 .01472 L
.33227 .01472 L
.3323 .01472 L
.33233 .01472 L
.33236 .01472 L
.33237 .01472 L
.33239 .01472 L
.33242 .01472 L
.33245 .01472 L
.33247 .01472 L
.33249 .01472 L
.33251 .01472 L
.33253 .01472 L
.33256 .01472 L
.33259 .01472 L
.33262 .01472 L
.33264 .01472 L
.33267 .01472 L
.3327 .01472 L
.33272 .01472 L
.33273 .01472 L
.33277 .01472 L
.33278 .01472 L
.3328 .01472 L
.33283 .01472 L
.33286 .01472 L
.33289 .01472 L
.33292 .01472 L
.33294 .01472 L
.33297 .01472 L
Mistroke
.33299 .01472 L
.33302 .01472 L
.33305 .01472 L
.33308 .01472 L
.3331 .01472 L
.33313 .01472 L
.33316 .01472 L
.33319 .01472 L
.33321 .01472 L
.33324 .01472 L
.33327 .01472 L
.3333 .01472 L
.33333 .01472 L
.33336 .01472 L
.33339 .01472 L
.33342 .01472 L
.33343 .01472 L
.33345 .01472 L
.33347 .01472 L
.33348 .01472 L
.33351 .01472 L
.33354 .01472 L
.33357 .01472 L
.3336 .01472 L
.33363 .01472 L
.33366 .01472 L
.33368 .01472 L
.33371 .01472 L
.33374 .01472 L
.33377 .01472 L
.3338 .01472 L
.33383 .01472 L
.33385 .01472 L
.33389 .01472 L
.33392 .01472 L
.33394 .01472 L
.33397 .01472 L
.33399 .01472 L
.33401 .01472 L
.33404 .01472 L
.33405 .01472 L
.33407 .01472 L
.33409 .01472 L
.3341 .01472 L
.33413 .01472 L
.33415 .01472 L
.33417 .01472 L
.33418 .01472 L
.3342 .01472 L
.33422 .01472 L
Mistroke
.33424 .01472 L
.33425 .01472 L
.33427 .01472 L
.3343 .01472 L
.33433 .01472 L
.33436 .01472 L
.33439 .01472 L
.33442 .01472 L
.33445 .01472 L
.33447 .01472 L
.3345 .01472 L
.33453 .01472 L
.33455 .01472 L
.33458 .01472 L
.33462 .01472 L
.33464 .01472 L
.33467 .01472 L
.3347 .01472 L
.33472 .01472 L
.33474 .01472 L
.33477 .01472 L
.3348 .01472 L
.33482 .01472 L
.33485 .01472 L
.33488 .01472 L
.33491 .01472 L
.33493 .01472 L
.33496 .01472 L
.33498 .01472 L
.33501 .01472 L
.33504 .01472 L
.33506 .01472 L
.33509 .01472 L
.33512 .01472 L
.33515 .01472 L
.33516 .01472 L
.33518 .01472 L
.33521 .01472 L
.33524 .01472 L
.33527 .01472 L
.3353 .01472 L
.33533 .01472 L
.33536 .01472 L
.33538 .01472 L
.33541 .01472 L
.33544 .01472 L
.33546 .01472 L
.33549 .01472 L
.33552 .01472 L
.33555 .01472 L
Mistroke
.33558 .01472 L
.33561 .01472 L
.33563 .01472 L
.33565 .01472 L
.33568 .01472 L
.33571 .01472 L
.33573 .01472 L
.33576 .01472 L
.33579 .01472 L
.33582 .01472 L
.33584 .01472 L
.33587 .01472 L
.33589 .01472 L
.33592 .01472 L
.33595 .01472 L
.33597 .01472 L
.336 .01472 L
.33603 .01472 L
.33606 .01472 L
.33607 .01472 L
.33609 .01472 L
.33612 .01472 L
.33615 .01472 L
.33618 .01472 L
.33621 .01472 L
.33624 .01472 L
.33627 .01472 L
.33629 .01472 L
.33632 .01472 L
.33635 .01472 L
.33637 .01472 L
.3364 .01472 L
.33644 .01472 L
.33646 .01472 L
.33649 .01472 L
.33652 .01472 L
.33654 .01472 L
.33656 .01472 L
.33659 .01472 L
.33662 .01472 L
.33664 .01472 L
.33667 .01472 L
.3367 .01472 L
.33673 .01472 L
.33675 .01472 L
.33678 .01472 L
.3368 .01472 L
.33683 .01472 L
.33686 .01472 L
.33689 .01472 L
Mistroke
.33691 .01472 L
.33694 .01472 L
.33697 .01472 L
.33698 .01472 L
.337 .01472 L
.33703 .01472 L
.33706 .01472 L
.33709 .01472 L
.3371 .01472 L
.33712 .01472 L
.33715 .01472 L
.33718 .01472 L
.3372 .01472 L
.33723 .01472 L
.33726 .01472 L
.33729 .01472 L
.33732 .01472 L
.33733 .01472 L
.33735 .01472 L
.33738 .01472 L
.3374 .01472 L
.33741 .01472 L
.33744 .01472 L
.33747 .01472 L
.3375 .01472 L
.33753 .01472 L
.33756 .01472 L
.33758 .01472 L
.33761 .01472 L
.33763 .01472 L
.33766 .01472 L
.33769 .01472 L
.33772 .01472 L
.33774 .01472 L
.33777 .01472 L
.3378 .01472 L
.33783 .01472 L
.33785 .01472 L
.33788 .01472 L
.33791 .01472 L
.33794 .01472 L
.33797 .01472 L
.338 .01472 L
.33803 .01472 L
.33805 .01472 L
.33806 .01472 L
.33808 .01472 L
.3381 .01472 L
.33813 .01472 L
.33815 .01472 L
Mistroke
.33819 .01472 L
.33822 .01472 L
.33824 .01472 L
.33827 .01472 L
.3383 .01472 L
.33832 .01472 L
.33835 .01472 L
.33838 .01472 L
.33841 .01472 L
.33844 .01472 L
.33847 .01472 L
.3385 .01472 L
.33853 .01472 L
.33856 .01472 L
.33859 .01472 L
.33861 .01472 L
.33862 .01472 L
.33865 .01472 L
.33867 .01472 L
.33868 .01472 L
.3387 .01472 L
.33872 .01472 L
.33875 .01472 L
.33877 .01472 L
.33878 .01472 L
.3388 .01472 L
.33882 .01472 L
.33883 .01472 L
.33885 .01472 L
.33887 .01472 L
.33888 .01472 L
.33891 .01472 L
.33894 .01472 L
.33897 .01472 L
.339 .01472 L
.33903 .01472 L
.33906 .01472 L
.33909 .01472 L
.33911 .01472 L
.33914 .01472 L
.33917 .01472 L
.3392 .01472 L
.33923 .01472 L
.33926 .01472 L
.33929 .01472 L
.33932 .01472 L
.33934 .01472 L
.33935 .01472 L
.33938 .01472 L
.33941 .01472 L
Mistroke
.33944 .01472 L
.33947 .01472 L
.33949 .01472 L
.33952 .01472 L
.33955 .01472 L
.33957 .01472 L
.3396 .01472 L
.33962 .01472 L
.33965 .01472 L
.33968 .01472 L
.33971 .01472 L
.33973 .01472 L
.33976 .01472 L
.33978 .01472 L
.33979 .01472 L
.33982 .01472 L
.33985 .01472 L
.33988 .01472 L
.33991 .01472 L
.33994 .01472 L
.33997 .01472 L
.34 .01472 L
.34002 .01472 L
.34005 .01472 L
.34008 .01472 L
.34011 .01472 L
.34014 .01472 L
.34017 .01472 L
.3402 .01472 L
.34023 .01472 L
.34025 .01472 L
.34026 .01472 L
.34029 .01472 L
.34032 .01472 L
.34035 .01472 L
.34038 .01472 L
.34041 .01472 L
.34043 .01472 L
.34046 .01472 L
.34048 .01472 L
.34051 .01472 L
.34053 .01472 L
.34056 .01472 L
.34059 .01472 L
.34062 .01472 L
.34064 .01472 L
.34067 .01472 L
.34069 .01472 L
.34071 .01472 L
.34073 .01472 L
Mistroke
.34076 .01472 L
.34079 .01472 L
.34081 .01472 L
.34082 .01472 L
.34085 .01472 L
.34088 .01472 L
.34091 .01472 L
.34093 .01472 L
.34096 .01472 L
.34099 .01472 L
.34102 .01472 L
.34104 .01472 L
.34105 .01472 L
.34108 .01472 L
.3411 .01472 L
.34112 .01472 L
.34115 .01472 L
.34118 .01472 L
.34121 .01472 L
.34124 .01472 L
.34126 .01472 L
.34129 .01472 L
.34131 .01472 L
.34134 .01472 L
.34136 .01472 L
.34139 .01472 L
.34142 .01472 L
.34145 .01472 L
.34148 .01472 L
.34151 .01472 L
.34153 .01472 L
.34156 .01472 L
.34159 .01472 L
.34162 .01472 L
.34165 .01472 L
.34168 .01472 L
.34171 .01472 L
.34174 .01472 L
.34175 .01472 L
.34177 .01472 L
.34179 .01472 L
.3418 .01472 L
.34183 .01472 L
.34186 .01472 L
.34189 .01472 L
.34192 .01472 L
.34195 .01472 L
.34198 .01472 L
.342 .01472 L
.34203 .01472 L
Mistroke
.34206 .01472 L
.34209 .01472 L
.34212 .01472 L
.34215 .01472 L
.34217 .01472 L
.34221 .01472 L
.34223 .01472 L
.34226 .01472 L
.34229 .01472 L
.34231 .01472 L
.34233 .01472 L
.34236 .01472 L
.34237 .01472 L
.34239 .01472 L
.34241 .01472 L
.34242 .01472 L
.34245 .01472 L
.34247 .01472 L
.34249 .01472 L
.3425 .01472 L
.34252 .01472 L
.34254 .01472 L
.34256 .01472 L
.34257 .01472 L
.34259 .01472 L
.34262 .01472 L
.34265 .01472 L
.34268 .01472 L
.34271 .01472 L
.34274 .01472 L
.34277 .01472 L
.34279 .01472 L
.34282 .01472 L
.34285 .01472 L
.34287 .01472 L
.3429 .01472 L
.34293 .01472 L
.34296 .01472 L
.34299 .01472 L
.34302 .01472 L
.34304 .01472 L
.34306 .01472 L
.34309 .01472 L
.34312 .01472 L
.34314 .01472 L
.34317 .01472 L
.3432 .01472 L
.34323 .01472 L
.34325 .01472 L
.34328 .01472 L
Mistroke
.3433 .01472 L
.34333 .01472 L
.34336 .01472 L
.34338 .01472 L
.34341 .01472 L
.34344 .01472 L
.34347 .01472 L
.34348 .01472 L
.3435 .01472 L
.34353 .01472 L
.34356 .01472 L
.34359 .01472 L
.34362 .01472 L
.34365 .01472 L
.34368 .01472 L
.3437 .01472 L
.34373 .01472 L
.34376 .01472 L
.34378 .01472 L
.34381 .01472 L
.34385 .01472 L
.34387 .01472 L
.3439 .01472 L
.34393 .01472 L
.34395 .01472 L
.34397 .01472 L
.344 .01472 L
.34403 .01472 L
.34405 .01472 L
.34408 .01472 L
.34411 .01472 L
.34414 .01472 L
.34416 .01472 L
.34419 .01472 L
.34421 .01472 L
.34424 .01472 L
.34427 .01472 L
.3443 .01472 L
.34432 .01472 L
.34435 .01472 L
.34438 .01472 L
.34439 .01472 L
.34441 .01472 L
.34444 .01472 L
.34447 .01472 L
.3445 .01472 L
.34451 .01472 L
.34453 .01472 L
.34456 .01472 L
.34459 .01472 L
Mistroke
.34461 .01472 L
.34464 .01472 L
.34467 .01472 L
.3447 .01472 L
.34472 .01472 L
.34474 .01472 L
.34476 .01472 L
.34479 .01472 L
.34481 .01472 L
.34482 .01472 L
.34485 .01472 L
.34488 .01472 L
.34491 .01472 L
.34494 .01472 L
.34496 .01472 L
.34499 .01472 L
.34502 .01472 L
.34504 .01472 L
.34507 .01472 L
.3451 .01472 L
.34513 .01472 L
.34515 .01472 L
.34518 .01472 L
.34521 .01472 L
.34524 .01472 L
.34526 .01472 L
.34529 .01472 L
.34532 .01472 L
.34535 .01472 L
.34538 .01472 L
.34541 .01472 L
.34544 .01472 L
.34546 .01472 L
.34547 .01472 L
.34549 .01472 L
.34551 .01472 L
.34554 .01472 L
.34556 .01472 L
.34559 .01472 L
.34563 .01472 L
.34565 .01472 L
.34568 .01472 L
.34571 .01472 L
.34573 .01472 L
.34576 .01472 L
.34579 .01472 L
.34582 .01472 L
.34585 .01472 L
.34588 .01472 L
.34591 .01472 L
Mistroke
.34594 .01472 L
.34597 .01472 L
.346 .01472 L
.34601 .01472 L
.34603 .01472 L
.34606 .01472 L
.34608 .01472 L
.34609 .01472 L
.34611 .01472 L
.34613 .01472 L
.34616 .01472 L
.34617 .01472 L
.34619 .01472 L
.34621 .01472 L
.34623 .01472 L
.34624 .01472 L
.34626 .01472 L
.34628 .01472 L
.34629 .01472 L
.34632 .01472 L
.34635 .01472 L
.34638 .01472 L
.34641 .01472 L
.34644 .01472 L
.34647 .01472 L
.3465 .01472 L
.34652 .01472 L
.34655 .01472 L
.34658 .01472 L
.34661 .01472 L
.34664 .01472 L
.34667 .01472 L
.34669 .01472 L
.34673 .01472 L
.34674 .01472 L
.34676 .01472 L
.34679 .01472 L
.34682 .01472 L
.34685 .01472 L
.34687 .01472 L
.3469 .01472 L
.34693 .01472 L
.34696 .01472 L
.34698 .01472 L
.347 .01472 L
.34703 .01472 L
.34706 .01472 L
.34709 .01472 L
.34712 .01472 L
.34714 .01472 L
Mistroke
.34717 .01472 L
.34719 .01472 L
.3472 .01472 L
.34723 .01472 L
.34726 .01472 L
.34729 .01472 L
.34732 .01472 L
.34735 .01472 L
.34738 .01472 L
.34741 .01472 L
.34743 .01472 L
.34746 .01472 L
.34749 .01472 L
.34752 .01472 L
.34755 .01472 L
.34757 .01472 L
.3476 .01472 L
.34764 .01472 L
.34765 .01472 L
.34767 .01472 L
.3477 .01472 L
.34773 .01472 L
.34776 .01472 L
.34778 .01472 L
.34781 .01472 L
.34784 .01472 L
.34787 .01472 L
.34789 .01472 L
.34791 .01472 L
.34794 .01472 L
.34797 .01472 L
.348 .01472 L
.34803 .01472 L
.34805 .01472 L
.34808 .01472 L
.3481 .01472 L
.34811 .01472 L
.34814 .01472 L
.34817 .01472 L
.3482 .01472 L
.34822 .01472 L
.34823 .01472 L
.34826 .01472 L
.34829 .01472 L
.34832 .01472 L
.34834 .01472 L
.34837 .01472 L
.3484 .01472 L
.34843 .01472 L
.34844 .01472 L
Mistroke
.34846 .01472 L
.34849 .01472 L
.34851 .01472 L
.34853 .01472 L
.34855 .01472 L
.34859 .01472 L
.34861 .01472 L
.34864 .01472 L
.34867 .01472 L
.34869 .01472 L
.34872 .01472 L
.34874 .01472 L
.34877 .01472 L
.3488 .01472 L
.34883 .01472 L
.34886 .01472 L
.34889 .01472 L
.34891 .01472 L
.34894 .01472 L
.34897 .01472 L
.34899 .01472 L
.34903 .01472 L
.34905 .01472 L
.34908 .01472 L
.34911 .01472 L
.34914 .01472 L
.34916 .01472 L
.34917 .01472 L
.34919 .01472 L
.34921 .01472 L
.34924 .01472 L
.34927 .01472 L
.3493 .01472 L
.34933 .01472 L
.34935 .01472 L
.34938 .01472 L
.34941 .01472 L
.34943 .01472 L
.34946 .01472 L
.34949 .01472 L
.34952 .01472 L
.34955 .01472 L
.34958 .01472 L
.34961 .01472 L
.34964 .01472 L
.34967 .01472 L
.3497 .01472 L
.34972 .01472 L
.34973 .01472 L
.34976 .01472 L
Mistroke
.34978 .01472 L
.3498 .01472 L
.34981 .01472 L
.34983 .01472 L
.34986 .01472 L
.34988 .01472 L
.34989 .01472 L
.34991 .01472 L
.34993 .01472 L
.34994 .01472 L
.34996 .01472 L
.34998 .01472 L
.34999 .01472 L
.35002 .01472 L
.35005 .01472 L
.35008 .01472 L
.35011 .01472 L
.35014 .01472 L
.35017 .01472 L
.3502 .01472 L
.35022 .01472 L
.35025 .01472 L
.35028 .01472 L
.35031 .01472 L
.35034 .01472 L
.35037 .01472 L
.3504 .01472 L
.35043 .01472 L
.35045 .01472 L
.35046 .01472 L
.35049 .01472 L
.35052 .01472 L
.35055 .01472 L
.35058 .01472 L
.35061 .01472 L
.35063 .01472 L
.35066 .01472 L
.35068 .01472 L
.35071 .01472 L
.35073 .01472 L
.35076 .01472 L
.35079 .01472 L
.35082 .01472 L
.35084 .01472 L
.35087 .01472 L
.35089 .01472 L
.3509 .01472 L
.35093 .01472 L
.35096 .01472 L
.35099 .01472 L
Mistroke
.35102 .01472 L
.35105 .01472 L
.35108 .01472 L
.35111 .01472 L
.35113 .01472 L
.35116 .01472 L
.35119 .01472 L
.35122 .01472 L
.35125 .01472 L
.35128 .01472 L
.35131 .01472 L
.35134 .01472 L
.35136 .01472 L
.35137 .01472 L
.3514 .01472 L
.35143 .01472 L
.35146 .01472 L
.35149 .01472 L
.35151 .01472 L
.35154 .01472 L
.35157 .01472 L
.35159 .01472 L
.35162 .01472 L
.35164 .01472 L
.35167 .01472 L
.3517 .01472 L
.35173 .01472 L
.35175 .01472 L
.35178 .01472 L
.3518 .01472 L
.35181 .01472 L
.35184 .01472 L
.35187 .01472 L
.3519 .01472 L
.35192 .01472 L
.35193 .01472 L
.35196 .01472 L
.35199 .01472 L
.35202 .01472 L
.35204 .01472 L
.35207 .01472 L
.3521 .01472 L
.35213 .01472 L
.35215 .01472 L
.35216 .01472 L
.35219 .01472 L
.35221 .01472 L
.35223 .01472 L
.35226 .01472 L
.35229 .01472 L
Mistroke
.35232 .01472 L
.35234 .01472 L
.35237 .01472 L
.3524 .01472 L
.35242 .01472 L
.35245 .01472 L
.35247 .01472 L
.3525 .01472 L
.35253 .01472 L
.35256 .01472 L
.35259 .01472 L
.35261 .01472 L
.35264 .01472 L
.35267 .01472 L
.3527 .01472 L
.35273 .01472 L
.35275 .01472 L
.35278 .01472 L
.35282 .01472 L
.35284 .01472 L
.35286 .01472 L
.35288 .01472 L
.35289 .01472 L
.35291 .01472 L
.35294 .01472 L
.35297 .01472 L
.353 .01472 L
.35303 .01472 L
.35306 .01472 L
.35308 .01472 L
.35311 .01472 L
.35314 .01472 L
.35316 .01472 L
.3532 .01472 L
.35323 .01472 L
.35325 .01472 L
.35328 .01472 L
.35331 .01472 L
.35334 .01472 L
.35337 .01472 L
.3534 .01472 L
.35342 .01472 L
.35343 .01472 L
.35346 .01472 L
.35348 .01472 L
.3535 .01472 L
.35351 .01472 L
.35353 .01472 L
.35356 .01472 L
.35358 .01472 L
Mistroke
.35359 .01472 L
.35361 .01472 L
.35363 .01472 L
.35365 .01472 L
.35366 .01472 L
.35368 .01472 L
.3537 .01472 L
.35372 .01472 L
.35376 .01472 L
.35378 .01472 L
.35382 .01472 L
.35385 .01472 L
.35387 .01472 L
.3539 .01472 L
.35393 .01472 L
.35395 .01472 L
.35398 .01472 L
.35401 .01472 L
.35404 .01472 L
.35407 .01472 L
.3541 .01472 L
.35413 .01472 L
.35415 .01472 L
.35416 .01472 L
.35419 .01472 L
.35422 .01472 L
.35425 .01472 L
.35428 .01472 L
.35431 .01472 L
.35433 .01472 L
.35436 .01472 L
.35438 .01472 L
.35441 .01472 L
.35443 .01472 L
.35446 .01472 L
.35449 .01472 L
.35452 .01472 L
.35454 .01472 L
.35457 .01472 L
.35459 .01472 L
.35461 .01472 L
.35463 .01472 L
.35466 .01472 L
.35469 .01472 L
.35472 .01472 L
.35475 .01472 L
.35478 .01472 L
.35481 .01472 L
.35483 .01472 L
.35486 .01472 L
Mistroke
.35489 .01472 L
.35492 .01472 L
.35495 .01472 L
.35498 .01472 L
.35501 .01472 L
.35504 .01472 L
.35506 .01472 L
.35507 .01472 L
.3551 .01472 L
.35513 .01472 L
.35516 .01472 L
.35519 .01472 L
.35522 .01472 L
.35524 .01472 L
.35527 .01472 L
.35529 .01472 L
.35532 .01472 L
.35534 .01472 L
.35537 .01472 L
.3554 .01472 L
.35543 .01472 L
.35545 .01472 L
.35548 .01472 L
.3555 .01472 L
.35552 .01472 L
.35554 .01472 L
.35557 .01472 L
.3556 .01472 L
.35563 .01472 L
.35566 .01472 L
.35569 .01472 L
.35572 .01472 L
.35574 .01472 L
.35577 .01472 L
.3558 .01472 L
.35583 .01472 L
.35586 .01472 L
.35589 .01472 L
.35592 .01472 L
.35595 .01472 L
.35597 .01472 L
.35598 .01472 L
.35601 .01472 L
.35604 .01472 L
.35607 .01472 L
.3561 .01472 L
.35613 .01472 L
.35615 .01472 L
.35618 .01472 L
.3562 .01472 L
Mistroke
.35623 .01472 L
.35625 .01472 L
.35628 .01472 L
.35631 .01472 L
.35634 .01472 L
.35636 .01472 L
.35639 .01472 L
.35641 .01472 L
.35643 .01472 L
.35645 .01472 L
.35648 .01472 L
.35651 .01472 L
.35653 .01472 L
.35655 .01472 L
.35657 .01472 L
.3566 .01472 L
.35663 .01472 L
.35665 .01472 L
.35668 .01472 L
.35671 .01472 L
.35674 .01472 L
.35676 .01472 L
.35677 .01472 L
.35681 .01472 L
.35682 .01472 L
.35684 .01472 L
.35687 .01472 L
.3569 .01472 L
.35693 .01472 L
.35696 .01472 L
.35698 .01472 L
.35701 .01472 L
.35703 .01472 L
.35706 .01472 L
.35709 .01472 L
.35712 .01472 L
.35714 .01472 L
.35717 .01472 L
.3572 .01472 L
.35723 .01472 L
.35725 .01472 L
.35728 .01472 L
.35731 .01472 L
.35734 .01472 L
.35737 .01472 L
.3574 .01472 L
.35743 .01472 L
.35746 .01472 L
.35747 .01472 L
.35749 .01472 L
Mistroke
.35751 .01472 L
.35752 .01472 L
.35755 .01472 L
.35758 .01472 L
.35761 .01472 L
.35764 .01472 L
.35767 .01472 L
.3577 .01472 L
.35772 .01472 L
.35775 .01472 L
.35778 .01472 L
.35781 .01472 L
.35784 .01472 L
.35787 .01472 L
.35789 .01472 L
.35793 .01472 L
.35796 .01472 L
.35798 .01472 L
.35801 .01472 L
.35803 .01472 L
.35805 .01472 L
.35808 .01472 L
.35809 .01472 L
.35811 .01472 L
.35813 .01472 L
.35814 .01472 L
.35817 .01472 L
.35819 .01472 L
.35821 .01472 L
.35822 .01472 L
.35824 .01472 L
.35826 .01472 L
.35828 .01472 L
.35829 .01472 L
.35831 .01472 L
.35834 .01472 L
.35837 .01472 L
.3584 .01472 L
.35843 .01472 L
.35846 .01472 L
.35849 .01472 L
.35851 .01472 L
.35854 .01472 L
.35857 .01472 L
.35859 .01472 L
.35862 .01472 L
.35866 .01472 L
.35868 .01472 L
.35871 .01472 L
.35874 .01472 L
Mistroke
.35876 .01472 L
.35878 .01472 L
.35881 .01472 L
.35884 .01472 L
.35886 .01472 L
.35889 .01472 L
.35892 .01472 L
.35895 .01472 L
.35897 .01472 L
.359 .01472 L
.35902 .01472 L
.35905 .01472 L
.35908 .01472 L
.35911 .01472 L
.35913 .01472 L
.35916 .01472 L
.35919 .01472 L
.3592 .01472 L
.35922 .01472 L
.35925 .01472 L
.35928 .01472 L
.35931 .01472 L
.35934 .01472 L
.35937 .01472 L
.3594 .01472 L
.35942 .01472 L
.35945 .01472 L
.35948 .01472 L
.3595 .01472 L
.35953 .01472 L
.35957 .01472 L
.35959 .01472 L
.35962 .01472 L
.35965 .01472 L
.35967 .01472 L
.35969 .01472 L
.35972 .01472 L
.35975 .01472 L
.35977 .01472 L
.3598 .01472 L
.35983 .01472 L
.35986 .01472 L
.35988 .01472 L
.35991 .01472 L
.35993 .01472 L
.35996 .01472 L
.35999 .01472 L
.36002 .01472 L
.36004 .01472 L
.36007 .01472 L
Mistroke
.3601 .01472 L
.36012 .01472 L
.36013 .01472 L
.36016 .01472 L
.36019 .01472 L
.36022 .01472 L
.36023 .01472 L
.36025 .01472 L
.36028 .01472 L
.36031 .01472 L
.36033 .01472 L
.36036 .01472 L
.36039 .01472 L
.36042 .01472 L
.36045 .01472 L
.36046 .01472 L
.36048 .01472 L
.36051 .01472 L
.36053 .01472 L
.36054 .01472 L
.36057 .01472 L
.3606 .01472 L
.36063 .01472 L
.36066 .01472 L
.36069 .01472 L
.36071 .01472 L
.36074 .01472 L
.36076 .01472 L
.36079 .01472 L
.36082 .01472 L
.36085 .01472 L
.36087 .01472 L
.3609 .01472 L
.36093 .01472 L
.36096 .01472 L
.36098 .01472 L
.36101 .01472 L
.36104 .01472 L
.36107 .01472 L
.3611 .01472 L
.36113 .01472 L
.36116 .01472 L
.36118 .01472 L
.36119 .01472 L
.36121 .01472 L
.36123 .01472 L
.36126 .01472 L
.36128 .01472 L
.36131 .01472 L
.36135 .01472 L
Mistroke
.36137 .01472 L
.3614 .01472 L
.36143 .01472 L
.36145 .01472 L
.36148 .01472 L
.36151 .01472 L
.36154 .01472 L
.36157 .01472 L
.3616 .01472 L
.36163 .01472 L
.36166 .01472 L
.36169 .01472 L
.36172 .01472 L
.36174 .01472 L
.36175 .01472 L
.36178 .01472 L
.3618 .01472 L
.36181 .01472 L
.36183 .01472 L
.36185 .01472 L
.36188 .01472 L
.3619 .01472 L
.36191 .01472 L
.36193 .01472 L
.36195 .01472 L
.36196 .01472 L
.36198 .01472 L
.362 .01472 L
.36201 .01472 L
.36204 .01472 L
.36207 .01472 L
.3621 .01472 L
.36213 .01472 L
.36216 .01472 L
.36219 .01472 L
.36222 .01472 L
.36224 .01472 L
.36227 .01472 L
.3623 .01472 L
.36233 .01472 L
.36236 .01472 L
.36239 .01472 L
.36242 .01472 L
.36245 .01472 L
.36246 .01472 L
.36248 .01472 L
.36251 .01472 L
.36254 .01472 L
.36257 .01472 L
.36259 .01472 L
Mistroke
.36262 .01472 L
.36265 .01472 L
.36268 .01472 L
.3627 .01472 L
.36273 .01472 L
.36275 .01472 L
.36278 .01472 L
.36281 .01472 L
.36284 .01472 L
.36286 .01472 L
.36289 .01472 L
.36291 .01472 L
.36292 .01472 L
.36295 .01472 L
.36298 .01472 L
.36301 .01472 L
.36304 .01472 L
.36307 .01472 L
.3631 .01472 L
.36313 .01472 L
.36315 .01472 L
.36318 .01472 L
.36321 .01472 L
.36324 .01472 L
.36327 .01472 L
.3633 .01472 L
.36333 .01472 L
.36336 .01472 L
.36337 .01472 L
.36339 .01472 L
.36342 .01472 L
.36345 .01472 L
.36348 .01472 L
.36351 .01472 L
.36353 .01472 L
.36356 .01472 L
.36359 .01472 L
.36361 .01472 L
.36364 .01472 L
.36366 .01472 L
.36369 .01472 L
.36372 .01472 L
.36375 .01472 L
.36377 .01472 L
.3638 .01472 L
.36382 .01472 L
.36383 .01472 L
.36386 .01472 L
.36389 .01472 L
.36392 .01472 L
Mistroke
.36394 .01472 L
.36395 .01472 L
.36398 .01472 L
.36401 .01472 L
.36404 .01472 L
.36406 .01472 L
.36409 .01472 L
.36412 .01472 L
.36415 .01472 L
.36417 .01472 L
.36418 .01472 L
.36421 .01472 L
.36423 .01472 L
.36425 .01472 L
.36428 .01472 L
.36431 .01472 L
.36434 .01472 L
.36436 .01472 L
.36439 .01472 L
.36442 .01472 L
.36444 .01472 L
.36446 .01472 L
.36449 .01472 L
.36452 .01472 L
.36455 .01472 L
.36458 .01472 L
.36461 .01472 L
.36463 .01472 L
.36466 .01472 L
.36469 .01472 L
.36472 .01472 L
.36475 .01472 L
.36477 .01472 L
.3648 .01472 L
.36483 .01472 L
.36486 .01472 L
.36488 .01472 L
.3649 .01472 L
.36491 .01472 L
.36493 .01472 L
.36496 .01472 L
.36499 .01472 L
.36502 .01472 L
.36505 .01472 L
.36508 .01472 L
.3651 .01472 L
.36513 .01472 L
.36516 .01472 L
.36518 .01472 L
.36522 .01472 L
Mistroke
.36525 .01472 L
.36527 .01472 L
.3653 .01472 L
.36533 .01472 L
.36536 .01472 L
.36539 .01472 L
.36542 .01472 L
.36544 .01472 L
.36545 .01472 L
.36548 .01472 L
.3655 .01472 L
.36552 .01472 L
.36553 .01472 L
.36555 .01472 L
.36558 .01472 L
.3656 .01472 L
.36561 .01472 L
.36563 .01472 L
.36565 .01472 L
.36567 .01472 L
.36568 .01472 L
.3657 .01472 L
.36572 .01472 L
.36574 .01472 L
.36578 .01472 L
.3658 .01472 L
.36584 .01472 L
.36587 .01472 L
.36589 .01472 L
.36592 .01472 L
.36595 .01472 L
.36597 .01472 L
.366 .01472 L
.36603 .01472 L
.36606 .01472 L
.36609 .01472 L
.36612 .01472 L
.36615 .01472 L
.36617 .01472 L
.36618 .01472 L
.36621 .01472 L
.36624 .01472 L
.36627 .01472 L
.3663 .01472 L
.36633 .01472 L
.36635 .01472 L
.36638 .01472 L
.3664 .01472 L
.36643 .01472 L
.36645 .01472 L
Mistroke
.36648 .01472 L
.36651 .01472 L
.36654 .01472 L
.36656 .01472 L
.36659 .01472 L
.36661 .01472 L
.36663 .01472 L
.36665 .01472 L
.36668 .01472 L
.36671 .01472 L
.36674 .01472 L
.36677 .01472 L
.3668 .01472 L
.36683 .01472 L
.36685 .01472 L
.36688 .01472 L
.36691 .01472 L
.36694 .01472 L
.36697 .01472 L
.367 .01472 L
.36703 .01472 L
.36706 .01472 L
.36708 .01472 L
.36709 .01472 L
.36712 .01472 L
.36715 .01472 L
.36718 .01472 L
.36721 .01472 L
.36724 .01472 L
.36726 .01472 L
.36729 .01472 L
.36731 .01472 L
.36734 .01472 L
.36736 .01472 L
.36739 .01472 L
.36742 .01472 L
.36745 .01472 L
.36747 .01472 L
.3675 .01472 L
.36752 .01472 L
.36754 .01472 L
.36756 .01472 L
.36759 .01472 L
.36762 .01472 L
.36764 .01472 L
.36765 .01472 L
.36768 .01472 L
.36771 .01472 L
.36774 .01472 L
.36776 .01472 L
Mistroke
.36779 .01472 L
.36782 .01472 L
.36785 .01472 L
.36787 .01472 L
.36788 .01472 L
.36791 .01472 L
.36793 .01472 L
.36795 .01472 L
.36798 .01472 L
.36801 .01472 L
.36804 .01472 L
.36807 .01472 L
.36809 .01472 L
.36812 .01472 L
.36814 .01472 L
.36817 .01472 L
.36819 .01472 L
.36822 .01472 L
.36825 .01472 L
.36828 .01472 L
.36831 .01472 L
.36834 .01472 L
.36836 .01472 L
.36839 .01472 L
.36842 .01472 L
.36845 .01472 L
.36848 .01472 L
.36851 .01472 L
.36854 .01472 L
.36857 .01472 L
.36858 .01472 L
.3686 .01472 L
.36861 .01472 L
.36863 .01472 L
.36866 .01472 L
.36869 .01472 L
.36872 .01472 L
.36875 .01472 L
.36878 .01472 L
.36881 .01472 L
.36883 .01472 L
.36886 .01472 L
.36889 .01472 L
.36892 .01472 L
.36895 .01472 L
.36897 .01472 L
.369 .01472 L
.36903 .01472 L
.36906 .01472 L
.36909 .01472 L
Mistroke
.36912 .01472 L
.36914 .01472 L
.36916 .01472 L
.36919 .01472 L
.3692 .01472 L
.36922 .01472 L
.36923 .01472 L
.36925 .01472 L
.36928 .01472 L
.3693 .01472 L
.36932 .01472 L
.36933 .01472 L
.36935 .01472 L
.36937 .01472 L
.36939 .01472 L
.3694 .01472 L
.36942 .01472 L
.36945 .01472 L
.36948 .01472 L
.36951 .01472 L
.36954 .01472 L
.36957 .01472 L
.36959 .01472 L
.36962 .01472 L
.36965 .01472 L
.36968 .01472 L
.3697 .01472 L
.36973 .01472 L
.36976 .01472 L
.36979 .01472 L
.36982 .01472 L
.36985 .01472 L
.36987 .01472 L
.36988 .01472 L
.36992 .01472 L
.36995 .01472 L
.36997 .01472 L
.37 .01472 L
.37003 .01472 L
.37005 .01472 L
.37008 .01472 L
.3701 .01472 L
.37013 .01472 L
.37016 .60332 L
.37018 .60332 L
.37021 .60332 L
.37027 .60332 L
.37039 .60332 L
.37138 .60332 L
.37234 .60332 L
Mistroke
.37327 .60332 L
.37425 .60332 L
.37519 .60332 L
.3761 .60332 L
.37707 .60332 L
.378 .60332 L
.379 .60332 L
.37995 .60332 L
.38087 .60332 L
.38185 .60332 L
.38279 .60332 L
.38379 .60332 L
.38475 .60332 L
.38568 .60332 L
.38615 .60332 L
.38666 .60332 L
.3869 .60332 L
.38715 .60332 L
.38728 .60332 L
.38734 .60332 L
.38739 .60332 L
.38742 .60332 L
.38744 .60332 L
.38747 .01472 L
.3875 .01472 L
.38753 .01472 L
.38755 .01472 L
.38758 .01472 L
.38761 .01472 L
.38764 .01472 L
.38766 .01472 L
.38767 .01472 L
.3877 .01472 L
.38773 .01472 L
.38776 .01472 L
.38778 .01472 L
.38781 .01472 L
.38784 .01472 L
.38787 .01472 L
.38789 .01472 L
.38791 .01472 L
.38794 .01472 L
.38795 .01472 L
.38797 .01472 L
.388 .01472 L
.38803 .01472 L
.38806 .01472 L
.38809 .01472 L
.38811 .01472 L
.38814 .01472 L
Mistroke
.38817 .01472 L
.38819 .01472 L
.38822 .01472 L
.38825 .01472 L
.38828 .01472 L
.3883 .01472 L
.38833 .01472 L
.38835 .01472 L
.38838 .01472 L
.38841 .01472 L
.38844 .01472 L
.38847 .01472 L
.3885 .01472 L
.38853 .01472 L
.38854 .01472 L
.38856 .01472 L
.38859 .01472 L
.38862 .01472 L
.38864 .01472 L
.38866 .01472 L
.38869 .01472 L
.38871 .01472 L
.38873 .01472 L
.38875 .01472 L
.38878 .01472 L
.3888 .01472 L
.38883 .01472 L
.38886 .01472 L
.38889 .01472 L
.38892 .01472 L
.38895 .01472 L
.38897 .01472 L
.389 .01472 L
.38903 .01472 L
.38906 .01472 L
.38908 .01472 L
.38909 .01472 L
.38913 .01472 L
.38916 .01472 L
.38919 .01472 L
.38921 .01472 L
.38924 .01472 L
.38926 .01472 L
.38928 .01472 L
.38931 .01472 L
.38932 .01472 L
.38934 .01472 L
.38936 .01472 L
.38938 .01472 L
.38939 .01472 L
Mistroke
.38941 .01472 L
.38943 .01472 L
.38944 .01472 L
.38947 .01472 L
.38951 .01472 L
.38953 .01472 L
.38955 .01472 L
.38957 .01472 L
.38959 .01472 L
.38962 .01472 L
.38965 .01472 L
.38968 .01472 L
.3897 .01472 L
.38973 .01472 L
.38976 .01472 L
.38978 .01472 L
.3898 .01472 L
.38983 .01472 L
.38984 .01472 L
.38986 .01472 L
.38989 .01472 L
.38992 .01472 L
.38995 .01472 L
.38998 .01472 L
.39 .01472 L
.39003 .01472 L
.39006 .01472 L
.39008 .01472 L
.39011 .01472 L
.39014 .01472 L
.39017 .01472 L
.39019 .01472 L
.39022 .01472 L
.39024 .01472 L
.39027 .01472 L
.3903 .01472 L
.39033 .01472 L
.39036 .01472 L
.39039 .01472 L
.39042 .01472 L
.39045 .01472 L
.39048 .01472 L
.39049 .01472 L
.39051 .01472 L
.39053 .01472 L
.39055 .01472 L
.39058 .01472 L
.3906 .01472 L
.39062 .01472 L
.39063 .01472 L
Mistroke
.39066 .01472 L
.39069 .01472 L
.39072 .01472 L
.39075 .01472 L
.39078 .01472 L
.39081 .01472 L
.39083 .01472 L
.39086 .01472 L
.39089 .01472 L
.39092 .01472 L
.39095 .01472 L
.39096 .01472 L
.39098 .01472 L
.39101 .01472 L
.39104 .01472 L
.39107 .01472 L
.3911 .01472 L
.39113 .01472 L
.39115 .01472 L
.39116 .01472 L
.39119 .01472 L
.39121 .01472 L
.39123 .01472 L
.39125 .01472 L
.39126 .01472 L
.39128 .01472 L
.3913 .01472 L
.39132 .01472 L
.39133 .01472 L
.39136 .01472 L
.39139 .01472 L
.39142 .01472 L
.39145 .01472 L
.39148 .01472 L
.39151 .01472 L
.39154 .01472 L
.39156 .01472 L
.39159 .01472 L
.39162 .01472 L
.39165 .01472 L
.39168 .01472 L
.39171 .01472 L
.39174 .01472 L
.39177 .01472 L
.39179 .01472 L
.3918 .01472 L
.39183 .01472 L
.39186 .01472 L
.39189 .01472 L
.39192 .01472 L
Mistroke
.39195 .01472 L
.39197 .01472 L
.392 .01472 L
.39202 .01472 L
.39205 .01472 L
.39207 .01472 L
.3921 .01472 L
.39213 .01472 L
.39216 .01472 L
.39218 .01472 L
.39221 .01472 L
.39223 .01472 L
.39224 .01472 L
.39227 .01472 L
.3923 .01472 L
.39233 .01472 L
.39235 .01472 L
.39236 .01472 L
.39239 .01472 L
.39242 .01472 L
.39245 .01472 L
.39247 .01472 L
.3925 .01472 L
.39253 .01472 L
.39256 .01472 L
.39258 .01472 L
.39259 .01472 L
.39262 .01472 L
.39264 .01472 L
.39266 .01472 L
.39269 .01472 L
.39272 .01472 L
.39275 .01472 L
.39277 .01472 L
.3928 .01472 L
.39283 .01472 L
.39285 .01472 L
.39288 .01472 L
.3929 .01472 L
.39293 .01472 L
.39296 .01472 L
.39299 .01472 L
.39302 .01472 L
.39305 .01472 L
.39307 .01472 L
.3931 .01472 L
.39313 .01472 L
.39316 .01472 L
.39319 .01472 L
.39321 .01472 L
Mistroke
.39325 .01472 L
.39328 .01472 L
.39329 .01472 L
.39331 .01472 L
.39332 .01472 L
.39334 .01472 L
.39337 .01472 L
.3934 .01472 L
.39343 .01472 L
.39346 .01472 L
.39349 .01472 L
.39352 .01472 L
.39354 .01472 L
.39357 .01472 L
.3936 .01472 L
.39363 .01472 L
.39366 .01472 L
.39368 .01472 L
.39371 .01472 L
.39374 .01472 L
.39377 .01472 L
.3938 .01472 L
.39383 .01472 L
.39385 .01472 L
.39387 .01472 L
.3939 .01472 L
.39391 .01472 L
.39393 .01472 L
.39394 .01472 L
.39396 .01472 L
.39399 .01472 L
.39401 .01472 L
.39403 .01472 L
.39404 .01472 L
.39406 .01472 L
.39408 .01472 L
.3941 .01472 L
.39411 .01472 L
.39413 .01472 L
.39416 .01472 L
.39419 .01472 L
.39422 .01472 L
.39425 .01472 L
.39428 .01472 L
.39431 .01472 L
.39433 .01472 L
.39436 .01472 L
.39439 .01472 L
.39441 .01472 L
.39444 .01472 L
Mistroke
.39447 .01472 L
.3945 .01472 L
.39453 .01472 L
.39456 .01472 L
.39458 .01472 L
.3946 .01472 L
.39463 .01472 L
.39466 .01472 L
.39468 .01472 L
.39471 .01472 L
.39474 .01472 L
.39477 .01472 L
.39479 .01472 L
.39481 .01472 L
.39484 .01472 L
.39487 .01472 L
.39489 .01472 L
.39492 .01472 L
.39495 .01472 L
.39498 .01472 L
.39501 .01472 L
.39502 .01472 L
.39504 .01472 L
.39507 .01472 L
.3951 .01472 L
.39513 .01472 L
.39516 .01472 L
.39519 .01472 L
.39521 .01472 L
.39524 .01472 L
.39527 .01472 L
.3953 .01472 L
.39532 .01472 L
.39535 .01472 L
.39538 .01472 L
.39541 .01472 L
.39544 .01472 L
.39547 .01472 L
.39549 .01472 L
.39551 .01472 L
.39554 .01472 L
.39557 .01472 L
.39559 .01472 L
.39562 .01472 L
.39565 .01472 L
.39568 .01472 L
.3957 .01472 L
.39572 .01472 L
.39575 .01472 L
.39578 .01472 L
Mistroke
.3958 .01472 L
.39583 .01472 L
.39586 .01472 L
.39589 .01472 L
.39592 .01472 L
.39593 .01472 L
.39595 .01472 L
.39598 .01472 L
.39601 .01472 L
.39604 .01472 L
.39605 .01472 L
.39607 .01472 L
.3961 .01472 L
.39613 .01472 L
.39615 .01472 L
.39618 .01472 L
.3962 .01472 L
.39623 .01472 L
.39626 .01472 L
.39628 .01472 L
.3963 .01472 L
.39633 .01472 L
.39635 .01472 L
.39636 .01472 L
.39639 .01472 L
.39642 .01472 L
.39645 .01472 L
.39648 .01472 L
.3965 .01472 L
.39653 .01472 L
.39656 .01472 L
.39658 .01472 L
.39661 .01472 L
.39664 .01472 L
.39667 .01472 L
.39669 .01472 L
.39672 .01472 L
.39675 .01472 L
.39677 .01472 L
.3968 .01472 L
.39683 .01472 L
.39686 .01472 L
.39689 .01472 L
.39692 .01472 L
.39695 .01472 L
.39698 .01472 L
.39699 .01472 L
.39701 .01472 L
.39703 .01472 L
.39704 .01472 L
Mistroke
.39707 .01472 L
.3971 .01472 L
.39713 .01472 L
.39716 .01472 L
.39719 .01472 L
.39722 .01472 L
.39725 .01472 L
.39727 .01472 L
.3973 .01472 L
.39733 .01472 L
.39736 .01472 L
.39739 .01472 L
.39742 .01472 L
.39745 .01472 L
.39748 .01472 L
.3975 .01472 L
.39754 .01472 L
.39755 .01472 L
.39757 .01472 L
.3976 .01472 L
.39762 .01472 L
.39763 .01472 L
.39765 .01472 L
.39766 .01472 L
.3977 .01472 L
.39771 .01472 L
.39773 .01472 L
.39775 .01472 L
.39776 .01472 L
.39778 .01472 L
.3978 .01472 L
.39781 .01472 L
.39783 .01472 L
.39786 .01472 L
.39789 .01472 L
.39792 .01472 L
.39795 .01472 L
.39798 .01472 L
.39801 .01472 L
.39804 .01472 L
.39806 .01472 L
.39809 .01472 L
.39812 .01472 L
.39815 .01472 L
.39818 .01472 L
.3982 .01472 L
.39823 .01472 L
.39826 .01472 L
.39828 .01472 L
.3983 .01472 L
Mistroke
.39833 .01472 L
.39836 .01472 L
.39838 .01472 L
.39841 .01472 L
.39844 .01472 L
.39847 .01472 L
.39849 .01472 L
.39852 .01472 L
.39854 .01472 L
.39857 .01472 L
.3986 .01472 L
.39863 .01472 L
.39865 .01472 L
.39868 .01472 L
.39871 .01472 L
.39873 .01472 L
.39874 .01472 L
.39877 .01472 L
.3988 .01472 L
.39883 .01472 L
.39886 .01472 L
.39889 .01472 L
.39892 .01472 L
.39894 .01472 L
.39897 .01472 L
.399 .01472 L
.39903 .01472 L
.39906 .01472 L
.39909 .01472 L
.39911 .01472 L
.39914 .01472 L
.39917 .01472 L
.39919 .01472 L
.39921 .01472 L
.39924 .01472 L
.39927 .01472 L
.39929 .01472 L
.39932 .01472 L
.39935 .01472 L
.39938 .01472 L
.3994 .01472 L
.39943 .01472 L
.39945 .01472 L
.39948 .01472 L
.39951 .01472 L
.39954 .01472 L
.39956 .01472 L
.39959 .01472 L
.39962 .01472 L
.39964 .01472 L
Mistroke
.39965 .01472 L
.39968 .01472 L
.39971 .01472 L
.39974 .01472 L
.39975 .01472 L
.39977 .01472 L
.3998 .01472 L
.39983 .01472 L
.39985 .01472 L
.39988 .01472 L
.39991 .01472 L
.39994 .01472 L
.39997 .01472 L
.39998 .01472 L
.4 .01472 L
.40003 .01472 L
.40005 .01472 L
.40006 .01472 L
.40009 .01472 L
.40012 .01472 L
.40015 .01472 L
.40018 .01472 L
.40021 .01472 L
.40023 .01472 L
.40026 .01472 L
.40028 .01472 L
.40031 .01472 L
.40034 .01472 L
.40037 .01472 L
.40039 .01472 L
.40042 .01472 L
.40045 .01472 L
.40048 .01472 L
.4005 .01472 L
.40053 .01472 L
.40056 .01472 L
.40059 .01472 L
.40062 .01472 L
.40065 .01472 L
.40068 .01472 L
.4007 .01472 L
.40071 .01472 L
.40073 .01472 L
.40075 .01472 L
.40078 .01472 L
.4008 .01472 L
.40083 .01472 L
.40087 .01472 L
.40089 .01472 L
.40092 .01472 L
Mistroke
.40095 .01472 L
.40097 .01472 L
.401 .01472 L
.40103 .01472 L
.40106 .01472 L
.40109 .01472 L
.40112 .01472 L
.40115 .01472 L
.40118 .01472 L
.40121 .01472 L
.40124 .01472 L
.40125 .01472 L
.40127 .01472 L
.4013 .01472 L
.40132 .01472 L
.40133 .01472 L
.40135 .01472 L
.40137 .01472 L
.4014 .01472 L
.40141 .01472 L
.40143 .01472 L
.40145 .01472 L
.40147 .01472 L
.40148 .01472 L
.4015 .01472 L
.40152 .01472 L
.40153 .01472 L
.40156 .01472 L
.40159 .01472 L
.40162 .01472 L
.40165 .01472 L
.40168 .01472 L
.40171 .01472 L
.40174 .01472 L
.40176 .01472 L
.40179 .01472 L
.40182 .01472 L
.40185 .01472 L
.40188 .01472 L
.40191 .01472 L
.40193 .01472 L
.40197 .01472 L
.40198 .01472 L
.402 .01472 L
.40203 .01472 L
.40206 .01472 L
.40209 .01472 L
.40211 .01472 L
.40214 .01472 L
.40217 .01472 L
Mistroke
.4022 .01472 L
.40222 .01472 L
.40224 .01472 L
.40227 .01472 L
.4023 .01472 L
.40233 .01472 L
.40236 .01472 L
.40238 .01472 L
.40241 .01472 L
.40243 .01472 L
.40244 .01472 L
.40247 .01472 L
.4025 .01472 L
.40253 .01472 L
.40256 .01472 L
.40259 .01472 L
.40262 .01472 L
.40265 .01472 L
.40267 .01472 L
.4027 .01472 L
.40273 .01472 L
.40276 .01472 L
.40279 .01472 L
.40281 .01472 L
.40284 .01472 L
.40288 .01472 L
.40289 .01472 L
.40291 .01472 L
.40294 .01472 L
.40297 .01472 L
.403 .01472 L
.40302 .01472 L
.40305 .01472 L
.40308 .01472 L
.40311 .01472 L
.40313 .01472 L
.40315 .01472 L
.40318 .01472 L
.40321 .01472 L
.40324 .01472 L
.40327 .01472 L
.40329 .01472 L
.40332 .01472 L
.40334 .01472 L
.40335 .01472 L
.40338 .01472 L
.40341 .01472 L
.40344 .01472 L
.40347 .01472 L
.4035 .01472 L
Mistroke
.40353 .01472 L
.40355 .01472 L
.40358 .01472 L
.40361 .01472 L
.40364 .01472 L
.40367 .01472 L
.4037 .01472 L
.40373 .01472 L
.40375 .01472 L
.40379 .01472 L
.4038 .01472 L
.40382 .01472 L
.40385 .01472 L
.40388 .01472 L
.40391 .01472 L
.40393 .01472 L
.40396 .01472 L
.40399 .01472 L
.40402 .01472 L
.40404 .01472 L
.40407 .01472 L
.40409 .01472 L
.40412 .01472 L
.40415 .01472 L
.40418 .01472 L
.4042 .01472 L
.40423 .01472 L
.40425 .01472 L
.40426 .01472 L
.40429 .01472 L
.40432 .01472 L
.40435 .01472 L
.40437 .01472 L
.40438 .01472 L
.40441 .01472 L
.40444 .01472 L
.40447 .01472 L
.40449 .01472 L
.40452 .01472 L
.40455 .01472 L
.40458 .01472 L
.4046 .01472 L
.40461 .01472 L
.40464 .01472 L
.40466 .01472 L
.40468 .01472 L
.40471 .01472 L
.40474 .01472 L
.40477 .01472 L
.40479 .01472 L
Mistroke
.40482 .01472 L
.40485 .01472 L
.40487 .01472 L
.40489 .01472 L
.40492 .01472 L
.40495 .01472 L
.40498 .01472 L
.40501 .01472 L
.40504 .01472 L
.40506 .01472 L
.40509 .01472 L
.40512 .01472 L
.40515 .01472 L
.40518 .01472 L
.4052 .01472 L
.40523 .01472 L
.40526 .01472 L
.40529 .01472 L
.40531 .01472 L
.40533 .01472 L
.40534 .01472 L
.40536 .01472 L
.40539 .01472 L
.40542 .01472 L
.40545 .01472 L
.40548 .01472 L
.40551 .01472 L
.40553 .01472 L
.40556 .01472 L
.40559 .01472 L
.40562 .01472 L
.40565 .01472 L
.40568 .01472 L
.4057 .01472 L
.40573 .01472 L
.40576 .01472 L
.40579 .01472 L
.40582 .01472 L
.40585 .01472 L
.40587 .01472 L
.40589 .01472 L
.40592 .01472 L
.40593 .01472 L
.40595 .01472 L
.40596 .01472 L
.40598 .01472 L
.40601 .01472 L
.40603 .01472 L
.40604 .01472 L
.40606 .01472 L
Mistroke
.40608 .01472 L
.4061 .01472 L
.40611 .01472 L
.40613 .01472 L
.40615 .01472 L
.40618 .01472 L
.40621 .01472 L
.40623 .01472 L
.40627 .01472 L
.4063 .01472 L
.40632 .01472 L
.40635 .01472 L
.40638 .01472 L
.40641 .01472 L
.40643 .01472 L
.40646 .01472 L
.40649 .01472 L
.40652 .01472 L
.40655 .01472 L
.40658 .01472 L
.4066 .01472 L
.40661 .01472 L
.40665 .01472 L
.40668 .01472 L
.4067 .01472 L
.40673 .01472 L
.40676 .01472 L
.40679 .01472 L
.40681 .01472 L
.40683 .01472 L
.40686 .01472 L
.40689 .01472 L
.40691 .01472 L
.40694 .01472 L
.40697 .01472 L
.407 .01472 L
.40703 .01472 L
.40704 .01472 L
.40706 .01472 L
.40709 .01472 L
.40712 .01472 L
.40714 .01472 L
.40718 .01472 L
.40721 .01472 L
.40723 .01472 L
.40726 .01472 L
.40729 .01472 L
.40732 .01472 L
.40734 .01472 L
.40737 .01472 L
Mistroke
.4074 .01472 L
.40743 .01472 L
.40746 .01472 L
.40749 .01472 L
.40751 .01472 L
.40753 .01472 L
.40756 .01472 L
.40759 .01472 L
.40761 .01472 L
.40764 .01472 L
.40767 .01472 L
.4077 .01472 L
.40772 .01472 L
.40774 .01472 L
.40777 .01472 L
.4078 .01472 L
.40782 .01472 L
.40785 .01472 L
.40788 .01472 L
.40791 .01472 L
.40794 .01472 L
.40795 .01472 L
.40797 .01472 L
.408 .01472 L
.40803 .01472 L
.40806 .01472 L
.40807 .01472 L
.40809 .01472 L
.40812 .01472 L
.40815 .01472 L
.40817 .01472 L
.4082 .01472 L
.40822 .01472 L
.40825 .01472 L
.40828 .01472 L
.4083 .01472 L
.40832 .01472 L
.40835 .01472 L
.40837 .01472 L
.40838 .01472 L
.40841 .01472 L
.40844 .01472 L
.40847 .01472 L
.4085 .01472 L
.40852 .01472 L
.40855 .01472 L
.40858 .01472 L
.4086 .01472 L
.40863 .01472 L
.40866 .01472 L
Mistroke
.40869 .01472 L
.40871 .01472 L
.40874 .01472 L
.40877 .01472 L
.40879 .01472 L
.40882 .01472 L
.40885 .01472 L
.40888 .01472 L
.40891 .01472 L
.40894 .01472 L
.40897 .01472 L
.409 .01472 L
.40901 .01472 L
.40903 .01472 L
.40905 .01472 L
.40906 .01472 L
.40909 .01472 L
.40912 .01472 L
.40915 .01472 L
.40918 .01472 L
.40921 .01472 L
.40924 .01472 L
.40927 .01472 L
.40929 .01472 L
.40932 .01472 L
.40935 .01472 L
.40938 .01472 L
.40941 .01472 L
.40944 .01472 L
.40947 .01472 L
.4095 .01472 L
.40952 .01472 L
.40956 .01472 L
.40957 .01472 L
.40959 .01472 L
.40962 .01472 L
.40964 .01472 L
.40965 .01472 L
.40967 .01472 L
.40969 .01472 L
.40972 .01472 L
.40973 .01472 L
.40975 .01472 L
.40977 .01472 L
.40979 .01472 L
.4098 .01472 L
.40982 .01472 L
.40984 .01472 L
.40985 .01472 L
.40988 .01472 L
Mistroke
.40991 .01472 L
.40994 .01472 L
.40997 .01472 L
.41 .01472 L
.41003 .01472 L
.41006 .01472 L
.41008 .01472 L
.41011 .01472 L
.41014 .01472 L
.41017 .01472 L
.4102 .01472 L
.41022 .01472 L
.41025 .01472 L
.41029 .01472 L
.4103 .01472 L
.41032 .01472 L
.41035 .01472 L
.41038 .01472 L
.41041 .01472 L
.41043 .01472 L
.41046 .01472 L
.41049 .01472 L
.41051 .01472 L
.41054 .01472 L
.41056 .01472 L
.41059 .01472 L
.41062 .01472 L
.41065 .01472 L
.41067 .01472 L
.4107 .01472 L
.41073 .01472 L
.41075 .01472 L
.41076 .01472 L
.41079 .01472 L
.41082 .01472 L
.41085 .01472 L
.41088 .01472 L
.41091 .01472 L
.41094 .01472 L
.41097 .01472 L
.41099 .01472 L
.41102 .01472 L
.41105 .01472 L
.41108 .01472 L
.41111 .01472 L
.41113 .01472 L
.41116 .01472 L
.4112 .01472 L
.41121 .01472 L
.41123 .01472 L
Mistroke
.41126 .01472 L
.41129 .01472 L
.41132 .01472 L
.41134 .01472 L
.41137 .01472 L
.4114 .01472 L
.41143 .01472 L
.41145 .01472 L
.41148 .01472 L
.4115 .01472 L
.41153 .01472 L
.41156 .01472 L
.41159 .01472 L
.41161 .01472 L
.41164 .01472 L
.41166 .01472 L
.41167 .01472 L
.4117 .01472 L
.41173 .01472 L
.41176 .01472 L
.41178 .01472 L
.41179 .01472 L
.41182 .01472 L
.41185 .01472 L
.41188 .01472 L
.4119 .01472 L
.41193 .01472 L
.41196 .01472 L
.41199 .01472 L
.412 .01472 L
.41202 .01472 L
.41205 .01472 L
.41207 .01472 L
.41208 .01472 L
.41211 .01472 L
.41214 .01472 L
.41217 .01472 L
.4122 .01472 L
.41223 .01472 L
.41225 .01472 L
.41228 .01472 L
.4123 .01472 L
.41233 .01472 L
.41236 .01472 L
.41239 .01472 L
.41242 .01472 L
.41244 .01472 L
.41247 .01472 L
.4125 .01472 L
.41252 .01472 L
Mistroke
.41255 .01472 L
.41259 .01472 L
.41261 .01472 L
.41264 .01472 L
.41267 .01472 L
.4127 .01472 L
.41272 .01472 L
.41273 .01472 L
.41275 .01472 L
.41277 .01472 L
.4128 .01472 L
.41283 .01472 L
.41286 .01472 L
.41289 .01472 L
.41291 .01472 L
.41294 .01472 L
.41297 .01472 L
.41299 .01472 L
.41302 .01472 L
.41305 .01472 L
.41308 .01472 L
.41311 .01472 L
.41314 .01472 L
.41317 .01472 L
.4132 .01472 L
.41323 .01472 L
.41326 .01472 L
.41328 .01472 L
.41329 .01472 L
.41332 .01472 L
.41334 .01472 L
.41336 .01472 L
.41337 .01472 L
.41339 .01472 L
.41342 .01472 L
.41344 .01472 L
.41345 .01472 L
.41347 .01472 L
.41349 .01472 L
.4135 .01472 L
.41352 .01472 L
.41354 .01472 L
.41355 .01472 L
.41358 .01472 L
.41361 .01472 L
.41364 .01472 L
.41367 .01472 L
.4137 .01472 L
.41373 .01472 L
.41376 .01472 L
Mistroke
.41378 .01472 L
.41381 .01472 L
.41384 .01472 L
.41387 .01472 L
.4139 .01472 L
.41393 .01472 L
.41396 .01472 L
.41399 .01472 L
.41401 .01472 L
.41402 .01472 L
.41405 .01472 L
.41408 .01472 L
.41411 .01472 L
.41414 .01472 L
.41417 .01472 L
.41419 .01472 L
.41422 .01472 L
.41424 .01472 L
.41427 .01472 L
.41429 .01472 L
.41432 .01472 L
.41435 .01472 L
.41438 .01472 L
.4144 .01472 L
.41443 .01472 L
.41445 .01472 L
.41446 .01472 L
.41449 .01472 L
.41452 .01472 L
.41455 .01472 L
.41458 .01472 L
.41461 .01472 L
.41464 .01472 L
.41467 .01472 L
.41469 .01472 L
.41472 .01472 L
.41475 .01472 L
.41478 .01472 L
.41481 .01472 L
.41484 .01472 L
.41487 .01472 L
.4149 .01472 L
.41492 .01472 L
.41493 .01472 L
.41496 .01472 L
.41499 .01472 L
.41502 .01472 L
.41505 .01472 L
.41508 .01472 L
.4151 .01472 L
Mistroke
.41513 .01472 L
.41515 .01472 L
.41518 .01472 L
.4152 .01472 L
.41523 .01472 L
.41526 .01472 L
.41529 .01472 L
.41531 .01472 L
.41534 .01472 L
.41536 .01472 L
.41537 .01472 L
.4154 .01472 L
.41543 .01472 L
.41546 .01472 L
.41548 .01472 L
.41549 .01472 L
.41552 .01472 L
.41555 .01472 L
.41558 .01472 L
.4156 .01472 L
.41563 .01472 L
.41566 .01472 L
.41569 .01472 L
.41571 .01472 L
.41572 .01472 L
.41575 .01472 L
.41577 .01472 L
.41579 .01472 L
.41582 .01472 L
.41585 .01472 L
.41588 .01472 L
.4159 .01472 L
.41593 .01472 L
.41596 .01472 L
.41598 .01472 L
.41601 .01472 L
.41603 .01472 L
.41606 .01472 L
.41609 .01472 L
.41612 .01472 L
.41615 .01472 L
.41618 .01472 L
.4162 .01472 L
.41623 .01472 L
.41626 .01472 L
.41629 .01472 L
.41631 .01472 L
.41634 .01472 L
.41638 .01472 L
.4164 .01472 L
Mistroke
.41642 .01472 L
.41644 .01472 L
.41645 .01472 L
.41647 .01472 L
.4165 .01472 L
.41653 .01472 L
.41656 .01472 L
.41659 .01472 L
.41662 .01472 L
.41664 .01472 L
.41667 .01472 L
.4167 .01472 L
.41673 .01472 L
.41676 .01472 L
.41679 .01472 L
.41681 .01472 L
.41684 .01472 L
.41687 .01472 L
.4169 .01472 L
.41693 .01472 L
.41696 .01472 L
.41698 .01472 L
.417 .01472 L
.41703 .01472 L
.41704 .01472 L
.41706 .01472 L
.41707 .01472 L
.41709 .01472 L
.41712 .01472 L
.41714 .01472 L
.41715 .01472 L
.41717 .01472 L
.41719 .01472 L
.41721 .01472 L
.41722 .01472 L
.41724 .01472 L
.41726 .01472 L
.41729 .01472 L
.41732 .01472 L
.41734 .01472 L
.41738 .01472 L
.41741 .01472 L
.41743 .01472 L
.41746 .01472 L
.41749 .01472 L
.41751 .01472 L
.41754 .01472 L
.41757 .01472 L
.4176 .01472 L
.41763 .01472 L
Mistroke
.41766 .01472 L
.41769 .01472 L
.41771 .01472 L
.41772 .01472 L
.41776 .01472 L
.41778 .01472 L
.41781 .01472 L
.41784 .01472 L
.41787 .01472 L
.41789 .01472 L
.41792 .01472 L
.41794 .01472 L
.41797 .01472 L
.418 .01472 L
.41802 .01472 L
.41805 .01472 L
.41808 .01472 L
.4181 .01472 L
.41813 .01472 L
.41815 .01472 L
.41817 .01472 L
.41819 .01472 L
.41822 .01472 L
.41825 .01472 L
.41829 .01472 L
.41831 .01472 L
.41834 .01472 L
.41837 .01472 L
.4184 .01472 L
.41842 .01472 L
.41845 .01472 L
.41848 .01472 L
.41851 .01472 L
.41854 .01472 L
.41857 .01472 L
.4186 .01472 L
.41862 .01472 L
.41863 .01472 L
.41866 .01472 L
.41869 .01472 L
.41872 .01472 L
.41875 .01472 L
.41878 .01472 L
.4188 .01472 L
.41883 .01472 L
.41885 .01472 L
.41888 .01472 L
.41891 .01472 L
.41893 .01472 L
.41896 .01472 L
Mistroke
.41899 .01472 L
.41901 .01472 L
.41904 .01472 L
.41906 .01472 L
.41908 .01472 L
.4191 .01472 L
.41913 .01472 L
.41916 .01472 L
.4192 .01472 L
.41923 .01472 L
.41925 .01472 L
.41928 .01472 L
.41931 .01472 L
.41933 .01472 L
.41936 .01472 L
.41939 .01472 L
.41942 .01472 L
.41945 .01472 L
.41948 .01472 L
.41951 .01472 L
.41953 .01472 L
.41954 .01472 L
.41958 .01472 L
.41961 .01472 L
.41963 .01472 L
.41966 .01472 L
.41969 .01472 L
.41971 .01472 L
.41974 .01472 L
.41976 .01472 L
.41979 .01472 L
.41982 .01472 L
.41984 .01472 L
.41987 .01472 L
.4199 .01472 L
.41993 .01472 L
.41996 .01472 L
.41997 .01472 L
.41999 .01472 L
.42002 .01472 L
.42005 .01472 L
.42007 .01472 L
.42009 .01472 L
.42011 .01472 L
.42013 .01472 L
.42016 .01472 L
.42019 .01472 L
.42022 .01472 L
.42024 .01472 L
.42027 .01472 L
Mistroke
.4203 .01472 L
.42032 .01472 L
.42034 .01472 L
.42037 .01472 L
.42038 .01472 L
.4204 .01472 L
.42043 .01472 L
.42046 .01472 L
.42049 .01472 L
.42052 .01472 L
.42054 .01472 L
.42057 .01472 L
.4206 .01472 L
.42062 .01472 L
.42065 .01472 L
.42068 .01472 L
.4207 .01472 L
.42073 .01472 L
.42076 .01472 L
.42079 .01472 L
.42081 .01472 L
.42084 .01472 L
.42087 .01472 L
.4209 .01472 L
.42093 .01472 L
.42096 .01472 L
.42099 .01472 L
.42102 .01472 L
.42103 .01472 L
.42105 .01472 L
.42107 .01472 L
.42108 .01472 L
.42111 .01472 L
.42114 .01472 L
.42117 .01472 L
.4212 .01472 L
.42123 .01472 L
.42126 .01472 L
.42129 .01472 L
.42131 .01472 L
.42134 .01472 L
.42137 .01472 L
.4214 .01472 L
.42143 .01472 L
.42146 .01472 L
.42149 .01472 L
.42152 .01472 L
.42154 .01472 L
.42158 .01472 L
.42159 .01472 L
Mistroke
.42161 .01472 L
.42164 .01472 L
.42166 .01472 L
.42167 .01472 L
.42169 .01472 L
.42171 .01472 L
.42174 .01472 L
.42175 .01472 L
.42177 .01472 L
.42179 .01472 L
.42181 .01472 L
.42182 .01472 L
.42184 .01472 L
.42186 .01472 L
.42187 .01472 L
.4219 .01472 L
.42193 .01472 L
.42196 .01472 L
.42199 .01472 L
.42202 .01472 L
.42205 .01472 L
.42208 .01472 L
.4221 .01472 L
.42213 .01472 L
.42216 .01472 L
.42219 .01472 L
.42222 .01472 L
.42224 .01472 L
.42227 .01472 L
.42231 .01472 L
.42232 .01472 L
.42234 .01472 L
.42237 .01472 L
.4224 .01472 L
.42243 .01472 L
.42245 .01472 L
.42248 .01472 L
.42251 .01472 L
.42254 .01472 L
.42256 .01472 L
.42258 .01472 L
.42261 .01472 L
.42264 .01472 L
.42267 .01472 L
.4227 .01472 L
.42272 .01472 L
.42275 .01472 L
.42277 .01472 L
.42278 .01472 L
.42281 .01472 L
Mistroke
.42284 .01472 L
.42287 .01472 L
.4229 .01472 L
.42293 .01472 L
.42296 .01472 L
.42299 .01472 L
.42301 .01472 L
.42304 .01472 L
.42307 .01472 L
.4231 .01472 L
.42313 .01472 L
.42315 .01472 L
.42318 .01472 L
.42322 .01472 L
.42323 .01472 L
.42325 .01472 L
.42328 .01472 L
.42331 .01472 L
.42334 .01472 L
.42336 .01472 L
.42339 .01472 L
.42342 .01472 L
.42345 .01472 L
.42347 .01472 L
.4235 .01472 L
.42352 .01472 L
.42355 .01472 L
.42358 .01472 L
.42361 .01472 L
.42363 .01472 L
.42366 .01472 L
.42368 .01472 L
.42369 .01472 L
.42372 .01472 L
.42375 .01472 L
.42378 .01472 L
.4238 .01472 L
.42381 .01472 L
.42384 .01472 L
.42387 .01472 L
.4239 .01472 L
.42392 .01472 L
.42395 .01472 L
.42398 .01472 L
.42401 .01472 L
.42402 .01472 L
.42404 .01472 L
.42407 .01472 L
.42409 .01472 L
.42411 .01472 L
Mistroke
.42413 .01472 L
.42417 .01472 L
.4242 .01472 L
.42422 .01472 L
.42425 .01472 L
.42427 .01472 L
.4243 .01472 L
.42432 .01472 L
.42435 .01472 L
.42438 .01472 L
.42441 .01472 L
.42444 .01472 L
.42447 .01472 L
.42449 .01472 L
.42452 .01472 L
.42455 .01472 L
.42458 .01472 L
.42461 .01472 L
.42463 .01472 L
.42466 .01472 L
.42469 .01472 L
.42472 .01472 L
.42474 .01472 L
.42476 .01472 L
.42477 .01472 L
.42479 .01472 L
.42482 .01472 L
.42485 .01472 L
.42488 .01472 L
.42491 .01472 L
.42494 .01472 L
.42496 .01472 L
.42499 .01472 L
.42502 .01472 L
.42504 .01472 L
.42508 .01472 L
.42511 .01472 L
.42513 .01472 L
.42516 .01472 L
.42519 .01472 L
.42522 .01472 L
.42525 .01472 L
.42528 .01472 L
.4253 .01472 L
.42531 .01472 L
.42534 .01472 L
.42536 .01472 L
.42538 .01472 L
.42539 .01472 L
.42541 .01472 L
Mistroke
.42544 .01472 L
.42546 .01472 L
.42547 .01472 L
.42549 .01472 L
.42551 .01472 L
.42553 .01472 L
.42554 .01472 L
.42556 .01472 L
.42558 .01472 L
.4256 .01472 L
.42564 .01472 L
.42566 .01472 L
.4257 .01472 L
.42573 .01472 L
.42575 .01472 L
.42578 .01472 L
.42581 .01472 L
.42583 .01472 L
.42586 .01472 L
.42589 .01472 L
.42592 .01472 L
.42595 .01472 L
.42598 .01472 L
.42601 .01472 L
.42603 .01472 L
.42604 .01472 L
.42607 .01472 L
.4261 .01472 L
.42613 .01472 L
.42616 .01472 L
.42619 .01472 L
.42621 .01472 L
.42624 .01472 L
.42626 .01472 L
.42629 .01472 L
.42632 .01472 L
.42634 .01472 L
.42637 .01472 L
.4264 .01472 L
.42642 .01472 L
.42645 .01472 L
.42647 .01472 L
.42649 .01472 L
.42651 .01472 L
.42654 .01472 L
.42657 .01472 L
.42661 .01472 L
.42664 .01472 L
.42666 .01472 L
.42669 .01472 L
Mistroke
.42672 .01472 L
.42674 .01472 L
.42677 .01472 L
.4268 .01472 L
.42683 .01472 L
.42686 .01472 L
.42689 .01472 L
.42692 .01472 L
.42694 .01472 L
.42695 .01472 L
.42699 .01472 L
.42701 .01472 L
.42704 .01472 L
.42707 .01472 L
.4271 .01472 L
.42712 .01472 L
.42715 .01472 L
.42717 .01472 L
.4272 .01472 L
.42723 .01472 L
.42725 .01472 L
.42728 .01472 L
.42731 .01472 L
.42734 .01472 L
.42736 .01472 L
.42738 .01472 L
.4274 .01472 L
.42743 .01472 L
.42745 .01472 L
.42748 .01472 L
.4275 .01472 L
.42752 .01472 L
.42754 .01472 L
.42757 .01472 L
.4276 .01472 L
.42763 .01472 L
.42765 .01472 L
.42768 .01472 L
.42771 .01472 L
.42773 .01472 L
.42774 .01472 L
.42778 .01472 L
.42779 .01472 L
.42781 .01472 L
.42784 .01472 L
.42787 .01472 L
.4279 .01472 L
.42793 .01472 L
.42795 .01472 L
.42798 .01472 L
Mistroke
.428 .01472 L
.42803 .01472 L
.42806 .01472 L
.42809 .01472 L
.42811 .01472 L
.42814 .01472 L
.42817 .01472 L
.4282 .01472 L
.42822 .01472 L
.42825 .01472 L
.42828 .01472 L
.42831 .01472 L
.42834 .01472 L
.42837 .01472 L
.4284 .01472 L
.42843 .01472 L
.42844 .01472 L
.42846 .01472 L
.42848 .01472 L
.42849 .01472 L
.42852 .01472 L
.42855 .01472 L
.42858 .01472 L
.42861 .01472 L
.42864 .01472 L
.42867 .01472 L
.42869 .01472 L
.42872 .01472 L
.42875 .01472 L
.42878 .01472 L
.42881 .01472 L
.42884 .01472 L
.42886 .01472 L
.4289 .01472 L
.42893 .01472 L
.42895 .01472 L
.42898 .01472 L
.429 .01472 L
.42902 .01472 L
.42905 .01472 L
.42906 .01472 L
.42908 .01472 L
.4291 .01472 L
.42911 .01472 L
.42914 .01472 L
.42916 .01472 L
.42918 .01472 L
.42919 .01472 L
.42921 .01472 L
.42923 .01472 L
Mistroke
.42925 .01472 L
.42926 .01472 L
.42928 .01472 L
.42931 .01472 L
.42934 .01472 L
.42937 .01472 L
.4294 .01472 L
.42943 .01472 L
.42946 .01472 L
.42948 .01472 L
.42951 .01472 L
.42954 .01472 L
.42956 .01472 L
.42959 .01472 L
.42963 .01472 L
.42965 .01472 L
.42968 .01472 L
.42971 .01472 L
.42973 .01472 L
.42975 .01472 L
.42978 .01472 L
.42981 .01472 L
.42983 .01472 L
.42986 .01472 L
.42989 .01472 L
.42992 .01472 L
.42994 .01472 L
.42997 .01472 L
.42999 .01472 L
.43002 .01472 L
.43005 .01472 L
.43008 .01472 L
.4301 .01472 L
.43013 .01472 L
.43016 .01472 L
.43017 .01472 L
.43019 .01472 L
.43022 .01472 L
.43025 .01472 L
.43028 .01472 L
.43031 .01472 L
.43034 .01472 L
.43037 .01472 L
.43039 .01472 L
.43042 .01472 L
.43045 .01472 L
.43047 .01472 L
.4305 .01472 L
.43054 .01472 L
.43056 .01472 L
Mistroke
.43059 .01472 L
.43062 .01472 L
.43064 .01472 L
.43066 .01472 L
.43069 .01472 L
.43072 .01472 L
.43074 .01472 L
.43077 .01472 L
.4308 .01472 L
.43083 .01472 L
.43085 .01472 L
.43088 .01472 L
.4309 .01472 L
.43093 .01472 L
.43096 .01472 L
.43099 .01472 L
.43101 .01472 L
.43104 .01472 L
.43107 .01472 L
.43108 .01472 L
.4311 .01472 L
.43113 .01472 L
.43116 .01472 L
.43119 .01472 L
.4312 .01472 L
.43122 .01472 L
.43125 .01472 L
.43128 .01472 L
.4313 .01472 L
.43133 .01472 L
.43136 .01472 L
.43139 .01472 L
.43141 .01472 L
.43143 .01472 L
.43145 .01472 L
.43148 .01472 L
.4315 .01472 L
.43151 .01472 L
.43154 .01472 L
.43157 .01472 L
.4316 .01472 L
.43163 .01472 L
.43165 .01472 L
.43168 .01472 L
.43171 .01472 L
.43173 .01472 L
.43176 .01472 L
.43179 .01472 L
.43182 .01472 L
.43184 .01472 L
Mistroke
.43187 .01472 L
.4319 .01472 L
.43193 .01472 L
.43195 .01472 L
.43198 .01472 L
.43201 .01472 L
.43204 .01472 L
.43207 .01472 L
.4321 .01472 L
.43213 .01472 L
.43214 .01472 L
.43216 .01472 L
.43218 .01472 L
.4322 .01472 L
.43223 .01472 L
.43225 .01472 L
.43228 .01472 L
.43231 .01472 L
.43234 .01472 L
.43237 .01472 L
.4324 .01472 L
.43242 .01472 L
.43245 .01472 L
.43248 .01472 L
.43251 .01472 L
.43254 .01472 L
.43257 .01472 L
.4326 .01472 L
.43263 .01472 L
.43265 .01472 L
.43269 .01472 L
.4327 .01472 L
.43272 .01472 L
.43275 .01472 L
.43277 .01472 L
.43278 .01472 L
.4328 .01472 L
.43282 .01472 L
.43285 .01472 L
.43286 .01472 L
.43288 .01472 L
.4329 .01472 L
.43292 .01472 L
.43293 .01472 L
.43295 .01472 L
.43297 .01472 L
.43298 .01472 L
.43301 .01472 L
.43304 .01472 L
.43307 .01472 L
Mistroke
.4331 .01472 L
.43313 .01472 L
.43316 .01472 L
.43319 .01472 L
.43321 .01472 L
.43324 .01472 L
.43327 .01472 L
.4333 .01472 L
.43333 .01472 L
.43335 .01472 L
.43338 .01472 L
.43342 .01472 L
.43343 .01472 L
.43345 .01472 L
.43348 .01472 L
.43351 .01472 L
.43354 .01472 L
.43356 .01472 L
.43359 .01472 L
.43362 .01472 L
.43364 .01472 L
.43367 .01472 L
.43369 .01472 L
.43372 .01472 L
.43375 .01472 L
.43378 .01472 L
.4338 .01472 L
.43383 .01472 L
.43386 .01472 L
.43388 .01472 L
.43389 .01472 L
.43392 .01472 L
.43395 .01472 L
.43398 .01472 L
.43401 .01472 L
.43404 .01472 L
.43407 .01472 L
.4341 .01472 L
.43412 .01472 L
.43415 .01472 L
.43418 .01472 L
.43421 .01472 L
.43424 .01472 L
.43426 .01472 L
.43429 .01472 L
.43432 .01472 L
.43434 .01472 L
.43436 .01472 L
.43439 .01472 L
.43442 .01472 L
Mistroke
.43444 .01472 L
.43447 .01472 L
.4345 .01472 L
.43453 .01472 L
.43455 .01472 L
.43458 .01472 L
.4346 .01472 L
.43463 .01472 L
.43466 .01472 L
.43469 .01472 L
.43471 .01472 L
.43474 .01472 L
.43477 .01472 L
.43479 .01472 L
.4348 .01472 L
.43483 .01472 L
.43486 .01472 L
.43489 .01472 L
.43491 .01472 L
.43492 .01472 L
.43495 .01472 L
.43498 .01472 L
.435 .01472 L
.43503 .01472 L
.43506 .01472 L
.43509 .01472 L
.43512 .01472 L
.43513 .01472 L
.43515 .01472 L
.43518 .01472 L
.4352 .01472 L
.43521 .01472 L
.43524 .01472 L
.43527 .01472 L
.4353 .01472 L
.43533 .01472 L
.43536 .01472 L
.43538 .01472 L
.43541 .01472 L
.43543 .01472 L
.43546 .01472 L
.43549 .01472 L
.43552 .01472 L
.43554 .01472 L
.43557 .01472 L
.4356 .01472 L
.43563 .01472 L
.43565 .01472 L
.43568 .01472 L
.43571 .01472 L
Mistroke
.43574 .01472 L
.43577 .01472 L
.4358 .01472 L
.43583 .01472 L
.43585 .01472 L
.43586 .01472 L
.43588 .01472 L
.4359 .01472 L
.43593 .01472 L
.43595 .01472 L
.43598 .01472 L
.43602 .01472 L
.43604 .01472 L
.43607 .01472 L
.4361 .01472 L
.43612 .01472 L
.43615 .01472 L
.43618 .01472 L
.43621 .01472 L
.43624 .01472 L
.43627 .01472 L
.4363 .01472 L
.43633 .01472 L
.43636 .01472 L
.43639 .01472 L
.43641 .01472 L
.43642 .01472 L
.43645 .01472 L
.43647 .01472 L
.43648 .01472 L
.4365 .01472 L
.43652 .01472 L
.43655 .01472 L
.43656 .01472 L
.43658 .01472 L
.4366 .01472 L
.43662 .01472 L
.43663 .01472 L
.43665 .01472 L
.43667 .01472 L
.43668 .01472 L
.43671 .01472 L
.43674 .01472 L
.43677 .01472 L
.4368 .01472 L
.43683 .01472 L
.43686 .01472 L
.43689 .01472 L
.43691 .01472 L
.43694 .01472 L
Mistroke
.43697 .01472 L
.437 .01472 L
.43703 .01472 L
.43706 .01472 L
.43708 .01472 L
.43712 .01472 L
.43713 .01472 L
.43715 .01472 L
.43718 .01472 L
.43721 .01472 L
.43724 .01472 L
.43726 .01472 L
.43729 .01472 L
.43732 .01472 L
.43735 .01472 L
.43737 .01472 L
.43739 .01472 L
.43742 .01472 L
.43745 .01472 L
.43748 .01472 L
.43751 .01472 L
.43753 .01472 L
.43756 .01472 L
.43758 .01472 L
.43759 .01472 L
.43762 .01472 L
.43765 .01472 L
.43768 .01472 L
.43771 .01472 L
.43774 .01472 L
.43777 .01472 L
.4378 .01472 L
.43782 .01472 L
.43785 .01472 L
.43788 .01472 L
.43791 .01472 L
.43794 .01472 L
.43796 .01472 L
.43799 .01472 L
.43803 .01472 L
.43804 .01472 L
.43806 .01472 L
.43809 .01472 L
.43812 .01472 L
.43815 .01472 L
.43817 .01472 L
.4382 .01472 L
.43823 .01472 L
.43826 .01472 L
.43828 .01472 L
Mistroke
.4383 .01472 L
.43833 .01472 L
.43836 .01472 L
.43839 .01472 L
.43842 .01472 L
.43844 .01472 L
.43847 .01472 L
.43849 .01472 L
.4385 .01472 L
.43853 .01472 L
.43856 .01472 L
.43859 .01472 L
.43862 .01472 L
.43865 .01472 L
.43868 .01472 L
.43871 .01472 L
.43873 .01472 L
.43876 .01472 L
.43879 .01472 L
.43882 .01472 L
.43885 .01472 L
.43888 .01472 L
.4389 .01472 L
.43894 .01472 L
.43895 .01472 L
.43897 .01472 L
.439 .01472 L
.43903 .01472 L
.43906 .01472 L
.43908 .01472 L
.43911 .01472 L
.43914 .01472 L
.43917 .01472 L
.43919 .01472 L
.43922 .01472 L
.43924 .01472 L
.43927 .01472 L
.4393 .01472 L
.43933 .01472 L
.43935 .01472 L
.43938 .01472 L
.4394 .01472 L
.43941 .01472 L
.43944 .01472 L
.43947 .01472 L
.4395 .01472 L
.43952 .01472 L
.43953 .01472 L
.43956 .01472 L
.43959 .01472 L
Mistroke
.43962 .01472 L
.43964 .01472 L
.43967 .01472 L
.4397 .01472 L
.43973 .01472 L
.43975 .01472 L
.43976 .01472 L
.43979 .01472 L
.43981 .01472 L
.43983 .01472 L
.43985 .01472 L
.43989 .01472 L
.43992 .01472 L
.43994 .01472 L
.43997 .01472 L
.44 .01472 L
.44002 .01472 L
.44004 .01472 L
.44007 .01472 L
.4401 .01472 L
.44013 .01472 L
.44016 .01472 L
.44019 .01472 L
.44021 .01472 L
.44024 .01472 L
.44027 .01472 L
.4403 .01472 L
.44033 .01472 L
.44035 .01472 L
.44038 .01472 L
.44041 .01472 L
.44044 .01472 L
.44046 .01472 L
.44048 .01472 L
.44049 .01472 L
.44051 .01472 L
.44054 .01472 L
.44057 .01472 L
.4406 .01472 L
.44063 .01472 L
.44066 .01472 L
.44068 .01472 L
.44071 .01472 L
.44074 .01472 L
.44076 .01472 L
.4408 .01472 L
.44083 .01472 L
.44085 .01472 L
.44088 .01472 L
.44091 .01472 L
Mistroke
.44094 .01472 L
.44097 .01472 L
.441 .01472 L
.44102 .01472 L
.44103 .01472 L
.44107 .01472 L
.44108 .01472 L
.4411 .01472 L
.44111 .01472 L
.44113 .01472 L
.44116 .01472 L
.44118 .01472 L
.44119 .01472 L
.44121 .01472 L
.44123 .01472 L
.44125 .01472 L
.44126 .01472 L
.44128 .01472 L
.4413 .01472 L
.44132 .01472 L
.44136 .01472 L
.44138 .01472 L
.44142 .01472 L
.44145 .01472 L
.44147 .01472 L
.4415 .01472 L
.44153 .01472 L
.44155 .01472 L
.44158 .01472 L
.44161 .01472 L
.44164 .01472 L
.44167 .01472 L
.4417 .01472 L
.44173 .01472 L
.44175 .01472 L
.44176 .01472 L
.4418 .01472 L
.44183 .01472 L
.44185 .01472 L
.44188 .01472 L
.44191 .01472 L
.44193 .01472 L
.44196 .01472 L
.44198 .01472 L
.44201 .01472 L
.44204 .01472 L
.44206 .01472 L
.44209 .01472 L
.44212 .01472 L
.44215 .01472 L
Mistroke
.44217 .01472 L
.44219 .01472 L
.44221 .01472 L
.44224 .01472 L
.44226 .01472 L
.44229 .01472 L
.44233 .01472 L
.44236 .01472 L
.44238 .01472 L
.44241 .01472 L
.44244 .01472 L
.44246 .01472 L
.44249 .01472 L
.44252 .01472 L
.44255 .01472 L
.44258 .01472 L
.44261 .01472 L
.44264 .01472 L
.44266 .01472 L
.44267 .01472 L
.44271 .01472 L
.44274 .01472 L
.44276 .01472 L
.44279 .01472 L
.44282 .01472 L
.44285 .01472 L
.44287 .01472 L
.44289 .01472 L
.44292 .01472 L
.44295 .01472 L
.44297 .01472 L
.443 .01472 L
.44303 .01472 L
.44306 .01472 L
.44309 .01472 L
.4431 .01472 L
.44312 .01472 L
.44315 .01472 L
.44318 .01472 L
.4432 .01472 L
.44322 .01472 L
.44324 .01472 L
.44326 .01472 L
.44329 .01472 L
.44332 .01472 L
.44335 .01472 L
.44337 .01472 L
.4434 .01472 L
.44343 .01472 L
.44345 .01472 L
Mistroke
.44347 .01472 L
.4435 .01472 L
.44351 .01472 L
.44353 .01472 L
.44356 .01472 L
.44359 .01472 L
.44362 .01472 L
.44365 .01472 L
.44367 .01472 L
.4437 .01472 L
.44373 .01472 L
.44375 .01472 L
.44378 .01472 L
.44381 .01472 L
.44383 .01472 L
.44386 .01472 L
.44389 .01472 L
.44392 .01472 L
.44394 .01472 L
.44397 .01472 L
.444 .01472 L
.44403 .01472 L
.44406 .01472 L
.44409 .01472 L
.44412 .01472 L
.44415 .01472 L
.44416 .01472 L
.44418 .01472 L
.4442 .01472 L
.44421 .01472 L
.44424 .01472 L
.44427 .01472 L
.4443 .01472 L
.44433 .01472 L
.44436 .01472 L
.44439 .01472 L
.44442 .01472 L
.44444 .01472 L
.44447 .01472 L
.4445 .01472 L
.44453 .01472 L
.44456 .01472 L
.44459 .01472 L
.44462 .01472 L
.44465 .01472 L
.44467 .01472 L
.4447 .01472 L
.44472 .01472 L
.44474 .01472 L
.44477 .01472 L
Mistroke
.44478 .01472 L
.4448 .01472 L
.44482 .01472 L
.44483 .01472 L
.44487 .01472 L
.44488 .01472 L
.4449 .01472 L
.44492 .01472 L
.44493 .01472 L
.44495 .01472 L
.44497 .01472 L
.44498 .01472 L
.445 .01472 L
.44503 .01472 L
.44506 .01472 L
.44509 .01472 L
.44512 .01472 L
.44515 .01472 L
.44518 .01472 L
.4452 .01472 L
.44523 .01472 L
.44526 .01472 L
.44529 .01472 L
.44532 .01472 L
.44535 .01472 L
.44537 .01472 L
.4454 .01472 L
.44543 .01472 L
.44545 .01472 L
.44547 .01472 L
.4455 .01472 L
.44553 .01472 L
.44555 .01472 L
.44558 .01472 L
.44561 .01472 L
.44564 .01472 L
.44566 .01472 L
.44569 .01472 L
.44571 .01472 L
.44574 .01472 L
.44577 .01472 L
.4458 .01472 L
.44582 .01472 L
.44585 .01472 L
.44588 .01472 L
.44589 .01472 L
.44591 .01472 L
.44594 .01472 L
.44597 .01472 L
.446 .01472 L
Mistroke
.44603 .01472 L
.44606 .01472 L
.44609 .01472 L
.44611 .01472 L
.44614 .01472 L
.44617 .01472 L
.4462 .01472 L
.44622 .01472 L
.44626 .01472 L
.44628 .01472 L
.44631 .01472 L
.44634 .01472 L
.44636 .01472 L
.44638 .01472 L
.44641 .01472 L
.44644 .01472 L
.44646 .01472 L
.44649 .01472 L
.44652 .01472 L
.44655 .01472 L
.44657 .01472 L
.4466 .01472 L
.44662 .01472 L
.44665 .01472 L
.44668 .01472 L
.44671 .01472 L
.44673 .01472 L
.44676 .01472 L
.44679 .01472 L
.44681 .01472 L
.44682 .01472 L
.44685 .01472 L
.44688 .01472 L
.44691 .01472 L
.44692 .01472 L
.44694 .01472 L
.44697 .01472 L
.447 .01472 L
.44702 .01472 L
.44705 .01472 L
.44708 .01472 L
.44711 .01472 L
.44714 .01472 L
.44715 .01472 L
.44717 .01472 L
.4472 .01472 L
.44722 .01472 L
.44723 .01472 L
.44726 .01472 L
.44729 .01472 L
Mistroke
.44732 .01472 L
.44735 .01472 L
.44738 .01472 L
.4474 .01472 L
.44743 .01472 L
.44745 .01472 L
.44748 .01472 L
.44751 .01472 L
.44754 .01472 L
.44756 .01472 L
.44759 .01472 L
.44762 .01472 L
.44765 .01472 L
.44767 .01472 L
.4477 .01472 L
.44773 .01472 L
.44776 .01472 L
.44779 .01472 L
.44782 .01472 L
.44785 .01472 L
.44787 .01472 L
.44788 .01472 L
.4479 .01472 L
.44792 .01472 L
.44795 .01472 L
.44797 .01472 L
.448 .01472 L
.44804 .01472 L
.44806 .01472 L
.44809 .01472 L
.44812 .01472 L
.44814 .01472 L
.44817 .01472 L
.4482 .01472 L
.44823 .01472 L
.44826 .01472 L
.44829 .01472 L
.44832 .01472 L
.44835 .01472 L
.44838 .01472 L
.44841 .01472 L
.44842 .01472 L
.44844 .01472 L
.44847 .01472 L
.44849 .01472 L
.4485 .01472 L
.44852 .01472 L
.44854 .01472 L
.44857 .01472 L
.44858 .01472 L
Mistroke
.4486 .01472 L
.44862 .01472 L
.44864 .01472 L
.44865 .01472 L
.44867 .01472 L
.44869 .01472 L
.4487 .01472 L
.44873 .01472 L
.44876 .01472 L
.44879 .01472 L
.44882 .01472 L
.44885 .01472 L
.44888 .01472 L
.44891 .01472 L
.44893 .01472 L
.44896 .01472 L
.44899 .01472 L
.44902 .01472 L
.44905 .01472 L
.44908 .01472 L
.4491 .01472 L
.44914 .01472 L
.44915 .01472 L
.44917 .01472 L
.4492 .01472 L
.44923 .01472 L
.44926 .01472 L
.44928 .01472 L
.44931 .01472 L
.44934 .01472 L
.44937 .01472 L
.44939 .01472 L
.44941 .01472 L
.44944 .01472 L
.44947 .01472 L
.4495 .01472 L
.44953 .01472 L
.44955 .01472 L
.44958 .01472 L
.4496 .01472 L
.44961 .01472 L
.44964 .01472 L
.44967 .01472 L
.4497 .01472 L
.44973 .01472 L
.44976 .01472 L
.44979 .01472 L
.44982 .01472 L
.44984 .01472 L
.44987 .01472 L
Mistroke
.4499 .01472 L
.44993 .01472 L
.44996 .01472 L
.44999 .01472 L
.45001 .01472 L
.45005 .01472 L
.45006 .01472 L
.45008 .01472 L
.45011 .01472 L
.45014 .01472 L
.45017 .01472 L
.45019 .01472 L
.45022 .01472 L
.45025 .01472 L
.45028 .01472 L
.4503 .01472 L
.45032 .01472 L
.45035 .01472 L
.45038 .01472 L
.45041 .01472 L
.45044 .01472 L
.45046 .01472 L
.45049 .01472 L
.45051 .01472 L
.45052 .01472 L
.45055 .01472 L
.45058 .01472 L
.45061 .01472 L
.45063 .01472 L
.45064 .01472 L
.45067 .01472 L
.4507 .01472 L
.45073 .01472 L
.45075 .01472 L
.45078 .01472 L
.45081 .01472 L
.45084 .01472 L
.45085 .01472 L
.45087 .01472 L
.4509 .01472 L
.45092 .01472 L
.45094 .01472 L
.45096 .01472 L
.451 .01472 L
.45102 .01472 L
.45105 .01472 L
.45108 .01472 L
.4511 .01472 L
.45113 .01472 L
.45115 .01472 L
Mistroke
.45118 .01472 L
.45121 .01472 L
.45124 .01472 L
.45127 .01472 L
.4513 .01472 L
.45132 .01472 L
.45135 .01472 L
.45138 .01472 L
.4514 .01472 L
.45144 .01472 L
.45146 .01472 L
.45149 .01472 L
.45152 .01472 L
.45155 .01472 L
.45157 .01472 L
.45158 .01472 L
.4516 .01472 L
.45162 .01472 L
.45165 .01472 L
.45168 .01472 L
.45171 .01472 L
.45174 .01472 L
.45176 .01472 L
.45179 .01472 L
.45182 .01472 L
.45184 .01472 L
.45187 .01472 L
.4519 .01472 L
.45193 .01472 L
.45196 .01472 L
.45199 .01472 L
.45202 .01472 L
.45205 .01472 L
.45208 .01472 L
.45211 .01472 L
.45213 .01472 L
.45214 .01472 L
.45217 .01472 L
.45219 .01472 L
.45221 .01472 L
.45222 .01472 L
.45224 .01472 L
.45227 .01472 L
.45229 .01472 L
.4523 .01472 L
.45232 .01472 L
.45234 .01472 L
.45235 .01472 L
.45237 .01472 L
.45239 .01472 L
Mistroke
.4524 .01472 L
.45243 .01472 L
.45246 .01472 L
.45249 .01472 L
.45252 .01472 L
.45255 .01472 L
.45258 .01472 L
.45261 .01472 L
.45263 .01472 L
.45266 .01472 L
.45269 .01472 L
.45272 .01472 L
.45275 .01472 L
.45278 .01472 L
.45281 .01472 L
.45284 .01472 L
.45286 .01472 L
.45287 .01472 L
.4529 .01472 L
.45293 .01472 L
.45296 .01472 L
.45299 .01472 L
.45301 .01472 L
.45304 .01472 L
.45307 .01472 L
.45309 .01472 L
.45312 .01472 L
.45314 .01472 L
.45317 .01472 L
.4532 .01472 L
.45323 .01472 L
.45325 .01472 L
.45328 .01472 L
.4533 .01472 L
.45331 .01472 L
.45334 .01472 L
.45337 .01472 L
.4534 .01472 L
.45343 .01472 L
.45346 .01472 L
.45349 .01472 L
.45352 .01472 L
.45354 .01472 L
.45357 .01472 L
.4536 .01472 L
.45363 .01472 L
.45366 .01472 L
.45369 .01472 L
.45372 .01472 L
.45375 .01472 L
Mistroke
.45376 .01472 L
.45378 .01472 L
.45381 .01472 L
.45384 .01472 L
.45387 .01472 L
.45389 .01472 L
.45392 .01472 L
.45395 .01472 L
.45398 .01472 L
.454 .01472 L
.45403 .01472 L
.45405 .01472 L
.45408 .01472 L
.45411 .01472 L
.45414 .01472 L
.45416 .01472 L
.45419 .01472 L
.45421 .01472 L
.45422 .01472 L
.45425 .01472 L
.45428 .01472 L
.45431 .01472 L
.45434 .01472 L
.45437 .01472 L
.4544 .01472 L
.45443 .01472 L
.45445 .01472 L
.45448 .01472 L
.45451 .01472 L
.45454 .01472 L
.45457 .01472 L
.4546 .01472 L
.45463 .01472 L
.45466 .01472 L
.45468 .01472 L
.45469 .01472 L
.45472 .01472 L
.45475 .01472 L
.45478 .01472 L
.45481 .01472 L
.45483 .01472 L
.45486 .01472 L
.45489 .01472 L
.45491 .01472 L
.45494 .01472 L
.45496 .01472 L
.45499 .01472 L
.45502 .01472 L
.45505 .01472 L
.45507 .01472 L
Mistroke
.4551 .01472 L
.45512 .01472 L
.45513 .01472 L
.45516 .01472 L
.45519 .01472 L
.45522 .01472 L
.45524 .01472 L
.45525 .01472 L
.45528 .01472 L
.45531 .01472 L
.45534 .01472 L
.45536 .01472 L
.45539 .01472 L
.45542 .01472 L
.45545 .01472 L
.45547 .01472 L
.45548 .01472 L
.45551 .01472 L
.45553 .01472 L
.45555 .01472 L
.45558 .01472 L
.45561 .01472 L
.45564 .01472 L
.45566 .01472 L
.45569 .01472 L
.45572 .01472 L
.45574 .01472 L
.45577 .01472 L
.45579 .01472 L
.45582 .01472 L
.45585 .01472 L
.45588 .01472 L
.45591 .01472 L
.45594 .01472 L
.45596 .01472 L
.45599 .01472 L
.45602 .01472 L
.45605 .01472 L
.45608 .01472 L
.4561 .01472 L
.45614 .01472 L
.45617 .01472 L
.45618 .01472 L
.4562 .01472 L
.45621 .01472 L
.45623 .01472 L
.45626 .01472 L
.45629 .01472 L
.45632 .01472 L
.45635 .01472 L
Mistroke
.45638 .01472 L
.45641 .01472 L
.45643 .01472 L
.45646 .01472 L
.45649 .01472 L
.45652 .01472 L
.45655 .01472 L
.45657 .01472 L
.4566 .01472 L
.45663 .01472 L
.45666 .01472 L
.45669 .01472 L
.45672 .60332 L
.45674 .60332 L
.45676 .60332 L
.45682 .60332 L
.45708 .60332 L
.45802 .60332 L
.45893 .60332 L
.45989 .60332 L
.46082 .60332 L
.46181 .60332 L
.46276 .60332 L
.46367 .60332 L
.46465 .60332 L
.46558 .60332 L
.46658 .60332 L
.46754 .60332 L
.46846 .60332 L
.46945 .60332 L
.47039 .60332 L
.4713 .60332 L
.47227 .60332 L
.4732 .60332 L
.47344 .60332 L
.47371 .60332 L
.47383 .60332 L
.4739 .60332 L
.47396 .60332 L
.47399 .60332 L
.47402 .60332 L
.47403 .01472 L
.47405 .01472 L
.47408 .01472 L
.47411 .01472 L
.47414 .01472 L
.47417 .01472 L
.47419 .01472 L
.47422 .01472 L
.47425 .01472 L
Mistroke
.47428 .01472 L
.47431 .01472 L
.47434 .01472 L
.47435 .01472 L
.47437 .01472 L
.4744 .01472 L
.47443 .01472 L
.47446 .01472 L
.47449 .01472 L
.47451 .01472 L
.47454 .01472 L
.47457 .01472 L
.4746 .01472 L
.47462 .01472 L
.47465 .01472 L
.47467 .01472 L
.47468 .01472 L
.47472 .01472 L
.47475 .01472 L
.47477 .01472 L
.47479 .01472 L
.47481 .01472 L
.47484 .01472 L
.47486 .01472 L
.47487 .01472 L
.47489 .01472 L
.47491 .01472 L
.47494 .01472 L
.47497 .01472 L
.475 .01472 L
.47502 .01472 L
.47505 .01472 L
.47507 .01472 L
.47509 .01472 L
.47512 .01472 L
.47515 .01472 L
.47518 .01472 L
.47521 .01472 L
.47524 .01472 L
.47527 .01472 L
.47529 .01472 L
.47532 .01472 L
.47535 .01472 L
.47538 .01472 L
.47541 .01472 L
.47544 .01472 L
.47546 .01472 L
.47549 .01472 L
.47552 .01472 L
.47554 .01472 L
Mistroke
.47556 .01472 L
.47559 .01472 L
.47562 .01472 L
.47564 .01472 L
.47567 .01472 L
.4757 .01472 L
.47573 .01472 L
.47575 .01472 L
.47578 .01472 L
.4758 .01472 L
.47583 .01472 L
.47586 .01472 L
.47589 .01472 L
.47591 .01472 L
.47594 .01472 L
.47597 .01472 L
.47598 .01472 L
.476 .01472 L
.47603 .01472 L
.47606 .01472 L
.47609 .01472 L
.47612 .01472 L
.47615 .01472 L
.47618 .01472 L
.4762 .01472 L
.47623 .01472 L
.47626 .01472 L
.47628 .01472 L
.47631 .01472 L
.47635 .01472 L
.47637 .01472 L
.4764 .01472 L
.47643 .01472 L
.47645 .01472 L
.47647 .01472 L
.4765 .01472 L
.47653 .01472 L
.47655 .01472 L
.47658 .01472 L
.47661 .01472 L
.47664 .01472 L
.47666 .01472 L
.47669 .01472 L
.47671 .01472 L
.47674 .01472 L
.47677 .01472 L
.4768 .01472 L
.47682 .01472 L
.47685 .01472 L
.47688 .01472 L
Mistroke
.47689 .01472 L
.47691 .01472 L
.47694 .01472 L
.47697 .01472 L
.477 .01472 L
.47703 .01472 L
.47706 .01472 L
.47709 .01472 L
.47711 .01472 L
.47714 .01472 L
.47717 .01472 L
.4772 .01472 L
.47722 .01472 L
.47726 .01472 L
.47728 .01472 L
.47731 .01472 L
.47734 .01472 L
.47736 .01472 L
.47738 .01472 L
.47741 .01472 L
.47744 .01472 L
.47746 .01472 L
.47749 .01472 L
.47752 .01472 L
.47755 .01472 L
.47757 .01472 L
.4776 .01472 L
.47762 .01472 L
.47765 .01472 L
.47768 .01472 L
.47771 .01472 L
.47773 .01472 L
.47776 .01472 L
.47779 .01472 L
.47781 .01472 L
.47782 .01472 L
.47785 .01472 L
.47788 .01472 L
.47791 .01472 L
.47793 .01472 L
.47794 .01472 L
.47797 .01472 L
.478 .01472 L
.47802 .01472 L
.47805 .01472 L
.47808 .01472 L
.47811 .01472 L
.47814 .01472 L
.47815 .01472 L
.47817 .01472 L
Mistroke
.4782 .01472 L
.47822 .01472 L
.47823 .01472 L
.47826 .01472 L
.47829 .01472 L
.47832 .01472 L
.47835 .01472 L
.47838 .01472 L
.4784 .01472 L
.47843 .01472 L
.47845 .01472 L
.47848 .01472 L
.47851 .01472 L
.47854 .01472 L
.47857 .01472 L
.47859 .01472 L
.47862 .01472 L
.47865 .01472 L
.47867 .01472 L
.4787 .01472 L
.47874 .01472 L
.47876 .01472 L
.47879 .01472 L
.47882 .01472 L
.47885 .01472 L
.47887 .01472 L
.47888 .01472 L
.4789 .01472 L
.47892 .01472 L
.47895 .01472 L
.47898 .01472 L
.47901 .01472 L
.47904 .01472 L
.47906 .01472 L
.47909 .01472 L
.47912 .01472 L
.47914 .01472 L
.47917 .01472 L
.4792 .01472 L
.47923 .01472 L
.47926 .01472 L
.47929 .01472 L
.47932 .01472 L
.47935 .01472 L
.47938 .01472 L
.47941 .01472 L
.47943 .01472 L
.47944 .01472 L
.47947 .01472 L
.47949 .01472 L
Mistroke
.47951 .01472 L
.47952 .01472 L
.47954 .01472 L
.47957 .01472 L
.47959 .01472 L
.4796 .01472 L
.47962 .01472 L
.47964 .01472 L
.47966 .01472 L
.47967 .01472 L
.47969 .01472 L
.4797 .01472 L
.47973 .01472 L
.47976 .01472 L
.47979 .01472 L
.47982 .01472 L
.47985 .01472 L
.47988 .01472 L
.47991 .01472 L
.47993 .01472 L
.47996 .01472 L
.47999 .01472 L
.48002 .01472 L
.48005 .01472 L
.48008 .01472 L
.48011 .01472 L
.48014 .01472 L
.48016 .01472 L
.48017 .01472 L
.4802 .01472 L
.48023 .01472 L
.48026 .01472 L
.48029 .01472 L
.48032 .01472 L
.48034 .01472 L
.48037 .01472 L
.48039 .01472 L
.48042 .01472 L
.48044 .01472 L
.48047 .01472 L
.4805 .01472 L
.48053 .01472 L
.48055 .01472 L
.48058 .01472 L
.4806 .01472 L
.48062 .01472 L
.48064 .01472 L
.48067 .01472 L
.4807 .01472 L
.48073 .01472 L
Mistroke
.48076 .01472 L
.48079 .01472 L
.48082 .01472 L
.48084 .01472 L
.48087 .01472 L
.4809 .01472 L
.48093 .01472 L
.48096 .01472 L
.48099 .01472 L
.48102 .01472 L
.48105 .01472 L
.48107 .01472 L
.48108 .01472 L
.48111 .01472 L
.48114 .01472 L
.48117 .01472 L
.4812 .01472 L
.48123 .01472 L
.48125 .01472 L
.48128 .01472 L
.4813 .01472 L
.48133 .01472 L
.48136 .01472 L
.48138 .01472 L
.48141 .01472 L
.48144 .01472 L
.48147 .01472 L
.48149 .01472 L
.48151 .01472 L
.48153 .01472 L
.48155 .01472 L
.48158 .01472 L
.48161 .01472 L
.48163 .01472 L
.48165 .01472 L
.48167 .01472 L
.4817 .01472 L
.48173 .01472 L
.48176 .01472 L
.48178 .01472 L
.48181 .01472 L
.48184 .01472 L
.48186 .01472 L
.48187 .01472 L
.48191 .01472 L
.48192 .01472 L
.48194 .01472 L
.48197 .01472 L
.482 .01472 L
.48203 .01472 L
Mistroke
.48206 .01472 L
.48208 .01472 L
.48211 .01472 L
.48213 .01472 L
.48216 .01472 L
.48219 .01472 L
.48222 .01472 L
.48224 .01472 L
.48227 .01472 L
.4823 .01472 L
.48233 .01472 L
.48235 .01472 L
.48238 .01472 L
.48241 .01472 L
.48244 .01472 L
.48247 .01472 L
.4825 .01472 L
.48253 .01472 L
.48256 .01472 L
.48257 .01472 L
.48259 .01472 L
.48261 .01472 L
.48262 .01472 L
.48265 .01472 L
.48268 .01472 L
.48271 .01472 L
.48274 .01472 L
.48277 .01472 L
.4828 .01472 L
.48282 .01472 L
.48285 .01472 L
.48288 .01472 L
.48291 .01472 L
.48294 .01472 L
.48297 .01472 L
.483 .01472 L
.48303 .01472 L
.48306 .01472 L
.48308 .01472 L
.48311 .01472 L
.48313 .01472 L
.48315 .01472 L
.48318 .01472 L
.48319 .01472 L
.48321 .01472 L
.48323 .01472 L
.48324 .01472 L
.48327 .01472 L
.48329 .01472 L
.48331 .01472 L
Mistroke
.48333 .01472 L
.48334 .01472 L
.48336 .01472 L
.48338 .01472 L
.48339 .01472 L
.48341 .01472 L
.48344 .01472 L
.48347 .01472 L
.4835 .01472 L
.48353 .01472 L
.48356 .01472 L
.48359 .01472 L
.48361 .01472 L
.48364 .01472 L
.48367 .01472 L
.4837 .01472 L
.48372 .01472 L
.48376 .01472 L
.48378 .01472 L
.48381 .01472 L
.48384 .01472 L
.48386 .01472 L
.48388 .01472 L
.48391 .01472 L
.48394 .01472 L
.48396 .01472 L
.48399 .01472 L
.48402 .01472 L
.48405 .01472 L
.48407 .01472 L
.4841 .01472 L
.48412 .01472 L
.48415 .01472 L
.48418 .01472 L
.48421 .01472 L
.48423 .01472 L
.48426 .01472 L
.48429 .01472 L
.4843 .01472 L
.48432 .01472 L
.48435 .01472 L
.48438 .01472 L
.48441 .01472 L
.48444 .01472 L
.48447 .01472 L
.4845 .01472 L
.48452 .01472 L
.48455 .01472 L
.48458 .01472 L
.48461 .01472 L
Mistroke
.48463 .01472 L
.48467 .01472 L
.48469 .01472 L
.48472 .01472 L
.48475 .01472 L
.48477 .01472 L
.48479 .01472 L
.48482 .01472 L
.48485 .01472 L
.48487 .01472 L
.4849 .01472 L
.48493 .01472 L
.48496 .01472 L
.48498 .01472 L
.48501 .01472 L
.48503 .01472 L
.48506 .01472 L
.48509 .01472 L
.48512 .01472 L
.48514 .01472 L
.48517 .01472 L
.4852 .01472 L
.48522 .01472 L
.48523 .01472 L
.48526 .01472 L
.48529 .01472 L
.48532 .01472 L
.48533 .01472 L
.48535 .01472 L
.48538 .01472 L
.48541 .01472 L
.48543 .01472 L
.48546 .01472 L
.48549 .01472 L
.48552 .01472 L
.48555 .01472 L
.48556 .01472 L
.48558 .01472 L
.48561 .01472 L
.48563 .01472 L
.48564 .01472 L
.48567 .01472 L
.4857 .01472 L
.48573 .01472 L
.48576 .01472 L
.48579 .01472 L
.48581 .01472 L
.48584 .01472 L
.48586 .01472 L
.48589 .01472 L
Mistroke
.48592 .01472 L
.48595 .01472 L
.48597 .01472 L
.486 .01472 L
.48603 .01472 L
.48606 .01472 L
.48608 .01472 L
.48611 .01472 L
.48614 .01472 L
.48617 .01472 L
.4862 .01472 L
.48623 .01472 L
.48626 .01472 L
.48628 .01472 L
.48629 .01472 L
.48631 .01472 L
.48633 .01472 L
.48636 .01472 L
.48638 .01472 L
.48641 .01472 L
.48645 .01472 L
.48647 .01472 L
.4865 .01472 L
.48653 .01472 L
.48655 .01472 L
.48658 .01472 L
.48661 .01472 L
.48664 .01472 L
.48667 .01472 L
.4867 .01472 L
.48673 .01472 L
.48676 .01472 L
.48679 .01472 L
.48682 .01472 L
.48684 .01472 L
.48685 .01472 L
.48688 .01472 L
.4869 .01472 L
.48691 .01472 L
.48693 .01472 L
.48695 .01472 L
.48698 .01472 L
.487 .01472 L
.48701 .01472 L
.48703 .01472 L
.48705 .01472 L
.48706 .01472 L
.48708 .01472 L
.4871 .01472 L
.48711 .01472 L
Mistroke
.48714 .01472 L
.48717 .01472 L
.4872 .01472 L
.48723 .01472 L
.48726 .01472 L
.48729 .01472 L
.48732 .01472 L
.48734 .01472 L
.48737 .01472 L
.4874 .01472 L
.48743 .01472 L
.48746 .01472 L
.48749 .01472 L
.48752 .01472 L
.48755 .01472 L
.48756 .01472 L
.48758 .01472 L
.48761 .01472 L
.48764 .01472 L
.48767 .01472 L
.4877 .01472 L
.48772 .01472 L
.48775 .01472 L
.48778 .01472 L
.4878 .01472 L
.48783 .01472 L
.48785 .01472 L
.48788 .01472 L
.48791 .01472 L
.48794 .01472 L
.48796 .01472 L
.48799 .01472 L
.48801 .01472 L
.48802 .01472 L
.48805 .01472 L
.48808 .01472 L
.48811 .01472 L
.48814 .01472 L
.48817 .01472 L
.4882 .01472 L
.48823 .01472 L
.48825 .01472 L
.48828 .01472 L
.48831 .01472 L
.48834 .01472 L
.48837 .01472 L
.4884 .01472 L
.48843 .01472 L
.48846 .01472 L
.48847 .01472 L
Mistroke
.48849 .01472 L
.48852 .01472 L
.48855 .01472 L
.48858 .01472 L
.48861 .01472 L
.48863 .01472 L
.48866 .01472 L
.48869 .01472 L
.48871 .01472 L
.48874 .01472 L
.48876 .01472 L
.48879 .01472 L
.48882 .01472 L
.48885 .01472 L
.48887 .01472 L
.4889 .01472 L
.48892 .01472 L
.48893 .01472 L
.48896 .01472 L
.48899 .01472 L
.48902 .01472 L
.48904 .01472 L
.48905 .01472 L
.48908 .01472 L
.48911 .01472 L
.48914 .01472 L
.48916 .01472 L
.48919 .01472 L
.48922 .01472 L
.48925 .01472 L
.48927 .01472 L
.48928 .01472 L
.48931 .01472 L
.48933 .01472 L
.48935 .01472 L
.48938 .01472 L
.48941 .01472 L
.48944 .01472 L
.48946 .01472 L
.48949 .01472 L
.48952 .01472 L
.48954 .01472 L
.48956 .01472 L
.48959 .01472 L
.48962 .01472 L
.48965 .01472 L
.48968 .01472 L
.48971 .01472 L
.48973 .01472 L
.48976 .01472 L
Mistroke
.48979 .01472 L
.48982 .01472 L
.48985 .01472 L
.48987 .01472 L
.4899 .01472 L
.48993 .01472 L
.48996 .01472 L
.48998 .01472 L
.49 .01472 L
.49001 .01472 L
.49003 .01472 L
.49006 .01472 L
.49009 .01472 L
.49012 .01472 L
.49015 .01472 L
.49018 .01472 L
.4902 .01472 L
.49023 .01472 L
.49026 .01472 L
.49028 .01472 L
.49032 .01472 L
.49035 .01472 L
.49037 .01472 L
.4904 .01472 L
.49043 .01472 L
.49046 .01472 L
.49049 .01472 L
.49052 .01472 L
.49054 .01472 L
.49055 .01472 L
.49058 .01472 L
.4906 .01472 L
.49062 .01472 L
.49063 .01472 L
.49065 .01472 L
.49068 .01472 L
.4907 .01472 L
.49071 .01472 L
.49073 .01472 L
.49075 .01472 L
.49077 .01472 L
.49078 .01472 L
.4908 .01472 L
.49082 .01472 L
.49084 .01472 L
.49088 .01472 L
.4909 .01472 L
.49094 .01472 L
.49097 .01472 L
.49099 .01472 L
Mistroke
.49102 .01472 L
.49105 .01472 L
.49107 .01472 L
.4911 .01472 L
.49113 .01472 L
.49116 .01472 L
.49119 .01472 L
.49122 .01472 L
.49125 .01472 L
.49127 .01472 L
.49128 .01472 L
.49131 .01472 L
.49134 .01472 L
.49137 .01472 L
.4914 .01472 L
.49143 .01472 L
.49145 .01472 L
.49148 .01472 L
.4915 .01472 L
.49153 .01472 L
.49155 .01472 L
.49158 .01472 L
.49161 .01472 L
.49164 .01472 L
.49166 .01472 L
.49169 .01472 L
.49171 .01472 L
.49173 .01472 L
.49175 .01472 L
.49178 .01472 L
.49181 .01472 L
.49184 .01472 L
.49187 .01472 L
.4919 .01472 L
.49193 .01472 L
.49195 .01472 L
.49198 .01472 L
.49201 .01472 L
.49204 .01472 L
.49207 .01472 L
.4921 .01472 L
.49213 .01472 L
.49216 .01472 L
.49218 .01472 L
.49219 .01472 L
.49222 .01472 L
.49225 .01472 L
.49228 .01472 L
.49231 .01472 L
.49234 .01472 L
Mistroke
.49236 .01472 L
.49239 .01472 L
.49241 .01472 L
.49244 .01472 L
.49246 .01472 L
.49249 .01472 L
.49252 .01472 L
.49255 .01472 L
.49257 .01472 L
.4926 .01472 L
.49262 .01472 L
.49264 .01472 L
.49266 .01472 L
.49269 .01472 L
.49272 .01472 L
.49274 .01472 L
.49275 .01472 L
.49278 .01472 L
.49281 .01472 L
.49284 .01472 L
.49286 .01472 L
.49289 .01472 L
.49292 .01472 L
.49295 .01472 L
.49297 .01472 L
.49298 .01472 L
.49301 .01472 L
.49303 .01472 L
.49305 .01472 L
.49308 .01472 L
.49311 .01472 L
.49314 .01472 L
.49316 .01472 L
.49319 .01472 L
.49322 .01472 L
.49324 .01472 L
.49327 .01472 L
.49329 .01472 L
.49332 .01472 L
.49335 .01472 L
.49338 .01472 L
.49341 .01472 L
.49344 .01472 L
.49346 .01472 L
.49349 .01472 L
.49352 .01472 L
.49355 .01472 L
.49358 .01472 L
.49361 .01472 L
.49364 .01472 L
Mistroke
.49367 .01472 L
.49368 .01472 L
.4937 .01472 L
.49371 .01472 L
.49373 .01472 L
.49376 .01472 L
.49379 .01472 L
.49382 .01472 L
.49385 .01472 L
.49388 .01472 L
.49391 .01472 L
.49393 .01472 L
.49396 .01472 L
.49399 .01472 L
.49402 .01472 L
.49405 .01472 L
.49407 .01472 L
.4941 .01472 L
.49413 .01472 L
.49416 .01472 L
.49419 .01472 L
.49422 .01472 L
.49424 .01472 L
.49426 .01472 L
.49429 .01472 L
.4943 .01472 L
.49432 .01472 L
.49433 .01472 L
.49435 .01472 L
.49438 .01472 L
.4944 .01472 L
.49442 .01472 L
.49443 .01472 L
.49445 .01472 L
.49447 .01472 L
.49448 .01472 L
.4945 .01472 L
.49452 .01472 L
.49455 .01472 L
.49458 .01472 L
.49461 .01472 L
.49464 .01472 L
.49467 .01472 L
.49469 .01472 L
.49472 .01472 L
.49475 .01472 L
.49478 .01472 L
.4948 .01472 L
.49483 .01472 L
.49486 .01472 L
Mistroke
.49489 .01472 L
.49492 .01472 L
.49495 .01472 L
.49497 .01472 L
.49498 .01472 L
.49502 .01472 L
.49505 .01472 L
.49507 .01472 L
.4951 .01472 L
.49513 .01472 L
.49515 .01472 L
.49518 .01472 L
.4952 .01472 L
.49523 .01472 L
.49526 .01472 L
.49528 .01472 L
.49531 .01472 L
.49534 .01472 L
.49537 .01472 L
.49539 .01472 L
.49541 .01472 L
.49543 .01472 L
.49545 .01472 L
.49548 .01472 L
.49551 .01472 L
.49555 .01472 L
.49558 .01472 L
.4956 .01472 L
.49563 .01472 L
.49566 .01472 L
.49568 .01472 L
.49571 .01472 L
.49574 .01472 L
.49577 .01472 L
.4958 .01472 L
.49583 .01472 L
.49586 .01472 L
.49588 .01472 L
.49589 .01472 L
.49593 .01472 L
.49595 .01472 L
.49598 .01472 L
.49601 .01472 L
.49604 .01472 L
.49606 .01472 L
.49609 .01472 L
.49611 .01472 L
.49614 .01472 L
.49617 .01472 L
.49619 .01472 L
Mistroke
.49622 .01472 L
.49625 .01472 L
.49627 .01472 L
.4963 .01472 L
.49632 .01472 L
.49634 .01472 L
.49636 .01472 L
.49639 .01472 L
.49642 .01472 L
.49646 .01472 L
.49649 .01472 L
.49651 .01472 L
.49654 .01472 L
.49657 .01472 L
.49659 .01472 L
.49662 .01472 L
.49665 .01472 L
.49668 .01472 L
.49671 .01472 L
.49674 .01472 L
.49677 .01472 L
.49679 .01472 L
.4968 .01472 L
.49684 .01472 L
.49687 .01472 L
.49689 .01472 L
.49692 .01472 L
.49695 .01472 L
.49698 .01472 L
.497 .01472 L
.49702 .01472 L
.49705 .01472 L
.49708 .01472 L
.4971 .01472 L
.49713 .01472 L
.49716 .01472 L
.49719 .01472 L
.49722 .01472 L
.49723 .01472 L
.49725 .01472 L
.49728 .01472 L
.49731 .01472 L
.49733 .01472 L
.49735 .01472 L
.49737 .01472 L
.49739 .01472 L
.49742 .01472 L
.49745 .01472 L
.49748 .01472 L
.4975 .01472 L
Mistroke
.49753 .01472 L
.49756 .01472 L
.49758 .01472 L
.4976 .01472 L
.49763 .01472 L
.49764 .01472 L
.49766 .01472 L
.49769 .01472 L
.49772 .01472 L
.49775 .01472 L
.49778 .01472 L
.4978 .01472 L
.49783 .01472 L
.49786 .01472 L
.49788 .01472 L
.49791 .01472 L
.49794 .01472 L
.49796 .01472 L
.49799 .01472 L
.49802 .01472 L
.49805 .01472 L
.49807 .01472 L
.4981 .01472 L
.49813 .01472 L
.49816 .01472 L
.49819 .01472 L
.49822 .01472 L
.49825 .01472 L
.49828 .01472 L
.49829 .01472 L
.49831 .01472 L
.49833 .01472 L
.49834 .01472 L
.49837 .01472 L
.4984 .01472 L
.49843 .01472 L
.49846 .01472 L
.49849 .01472 L
.49852 .01472 L
.49855 .01472 L
.49857 .01472 L
.4986 .01472 L
.49863 .01472 L
.49866 .01472 L
.49869 .01472 L
.49872 .01472 L
.49875 .01472 L
.49878 .01472 L
.4988 .01472 L
.49884 .01472 L
Mistroke
.49885 .01472 L
.49887 .01472 L
.4989 .01472 L
.49891 .01472 L
.49893 .01472 L
.49895 .01472 L
.49897 .01472 L
.499 .01472 L
.49901 .01472 L
.49903 .01472 L
.49905 .01472 L
.49906 .01472 L
.49908 .01472 L
.4991 .01472 L
.49912 .01472 L
.49913 .01472 L
.49916 .01472 L
.49919 .01472 L
.49922 .01472 L
.49925 .01472 L
.49928 .01472 L
.49931 .01472 L
.49934 .01472 L
.49936 .01472 L
.49939 .01472 L
.49942 .01472 L
.49945 .01472 L
.49948 .01472 L
.4995 .01472 L
.49953 .01472 L
.49956 .01472 L
.49958 .01472 L
.4996 .01472 L
.49963 .01472 L
.49966 .01472 L
.49968 .01472 L
.49971 .01472 L
.49974 .01472 L
.49977 .01472 L
.49979 .01472 L
.49982 .01472 L
.49984 .01472 L
.49987 .01472 L
.4999 .01472 L
.49993 .01472 L
.49995 .01472 L
.49998 .01472 L
.50001 .01472 L
.50003 .01472 L
.50004 .01472 L
Mistroke
.50007 .01472 L
.5001 .01472 L
.50013 .01472 L
.50016 .01472 L
.50019 .01472 L
.50022 .01472 L
.50025 .01472 L
.50027 .01472 L
.5003 .01472 L
.50033 .01472 L
.50036 .01472 L
.50039 .01472 L
.50041 .01472 L
.50044 .01472 L
.50048 .01472 L
.50049 .01472 L
.50051 .01472 L
.50054 .01472 L
.50057 .01472 L
.5006 .01472 L
.50062 .01472 L
.50065 .01472 L
.50068 .01472 L
.50071 .01472 L
.50073 .01472 L
.50076 .01472 L
.50078 .01472 L
.50081 .01472 L
.50084 .01472 L
.50087 .01472 L
.50089 .01472 L
.50092 .01472 L
.50094 .01472 L
.50095 .01472 L
.50098 .01472 L
.50101 .01472 L
.50104 .01472 L
.50106 .01472 L
.50107 .01472 L
.5011 .01472 L
.50113 .01472 L
.50116 .01472 L
.50118 .01472 L
.50121 .01472 L
.50124 .01472 L
.50127 .01472 L
.50128 .01472 L
.5013 .01472 L
.50133 .01472 L
.50135 .01472 L
Mistroke
.50136 .01472 L
.50139 .01472 L
.50142 .01472 L
.50145 .01472 L
.50148 .01472 L
.50151 .01472 L
.50153 .01472 L
.50156 .01472 L
.50158 .01472 L
.50161 .01472 L
.50164 .01472 L
.50167 .01472 L
.5017 .01472 L
.50173 .01472 L
.50175 .01472 L
.50178 .01472 L
.50181 .01472 L
.50183 .01472 L
.50187 .01472 L
.50189 .01472 L
.50192 .01472 L
.50195 .01472 L
.50198 .01472 L
.502 .01472 L
.50201 .01472 L
.50203 .01472 L
.50205 .01472 L
.50208 .01472 L
.50211 .01472 L
.50214 .01472 L
.50217 .01472 L
.50219 .01472 L
.50222 .01472 L
.50225 .01472 L
.50227 .01472 L
.5023 .01472 L
.50233 .01472 L
.50236 .01472 L
.50239 .01472 L
.50242 .01472 L
.50245 .01472 L
.50248 .01472 L
.50251 .01472 L
.50254 .01472 L
.50256 .01472 L
.50257 .01472 L
.5026 .01472 L
.50262 .01472 L
.50264 .01472 L
.50265 .01472 L
Mistroke
.50267 .01472 L
.5027 .01472 L
.50272 .01472 L
.50273 .01472 L
.50275 .01472 L
.50277 .01472 L
.50278 .01472 L
.5028 .01472 L
.50282 .01472 L
.50283 .01472 L
.50286 .01472 L
.50289 .01472 L
.50292 .01472 L
.50295 .01472 L
.50298 .01472 L
.50301 .01472 L
.50304 .01472 L
.50306 .01472 L
.50309 .01472 L
.50312 .01472 L
.50315 .01472 L
.50318 .01472 L
.50321 .01472 L
.50324 .01472 L
.50327 .01472 L
.50329 .01472 L
.5033 .01472 L
.50333 .01472 L
.50336 .01472 L
.50339 .01472 L
.50342 .01472 L
.50345 .01472 L
.50347 .01472 L
.5035 .01472 L
.50352 .01472 L
.50355 .01472 L
.50357 .01472 L
.5036 .01472 L
.50363 .01472 L
.50366 .01472 L
.50368 .01472 L
.50371 .01472 L
.50373 .01472 L
.50374 .01472 L
.50377 .01472 L
.5038 .01472 L
.50383 .01472 L
.50386 .01472 L
.50389 .01472 L
.50392 .01472 L
Mistroke
.50395 .01472 L
.50397 .01472 L
.504 .01472 L
.50403 .01472 L
.50406 .01472 L
.50409 .01472 L
.50412 .01472 L
.50415 .01472 L
.50418 .01472 L
.5042 .01472 L
.50421 .01472 L
.50424 .01472 L
.50427 .01472 L
.5043 .01472 L
.50433 .01472 L
.50436 .01472 L
.50438 .01472 L
.50441 .01472 L
.50443 .01472 L
.50446 .01472 L
.50448 .01472 L
.50451 .01472 L
.50454 .01472 L
.50457 .01472 L
.50459 .01472 L
.50462 .01472 L
.50464 .01472 L
.50466 .01472 L
.50468 .01472 L
.50471 .01472 L
.50474 .01472 L
.50476 .01472 L
.50477 .01472 L
.5048 .01472 L
.50483 .01472 L
.50486 .01472 L
.50488 .01472 L
.50491 .01472 L
.50494 .01472 L
.50497 .01472 L
.50499 .01472 L
.505 .01472 L
.50503 .01472 L
.50505 .01472 L
.50507 .01472 L
.5051 .01472 L
.50513 .01472 L
.50516 .01472 L
.50518 .01472 L
.50521 .01472 L
Mistroke
.50524 .01472 L
.50526 .01472 L
.50529 .01472 L
.50531 .01472 L
.50534 .01472 L
.50537 .01472 L
.5054 .01472 L
.50543 .01472 L
.50546 .01472 L
.50548 .01472 L
.50551 .01472 L
.50554 .01472 L
.50557 .01472 L
.5056 .01472 L
.50562 .01472 L
.50566 .01472 L
.50569 .01472 L
.5057 .01472 L
.50572 .01472 L
.50573 .01472 L
.50575 .01472 L
.50578 .01472 L
.50581 .01472 L
.50584 .01472 L
.50587 .01472 L
.5059 .01472 L
.50593 .01472 L
.50595 .01472 L
.50598 .01472 L
.50601 .01472 L
.50604 .01472 L
.50607 .01472 L
.50609 .01472 L
.50612 .01472 L
.50615 .01472 L
.50618 .01472 L
.50621 .01472 L
.50624 .01472 L
.50626 .01472 L
.50628 .01472 L
.50631 .01472 L
.50632 .01472 L
.50634 .01472 L
.50635 .01472 L
.50637 .01472 L
.5064 .01472 L
.50642 .01472 L
.50644 .01472 L
.50645 .01472 L
.50647 .01472 L
Mistroke
.50649 .01472 L
.50651 .01472 L
.50652 .01472 L
.50654 .01472 L
.50657 .01472 L
.5066 .01472 L
.50663 .01472 L
.50666 .01472 L
.50669 .01472 L
.50671 .01472 L
.50674 .01472 L
.50677 .01472 L
.5068 .01472 L
.50682 .01472 L
.50685 .01472 L
.50688 .01472 L
.50691 .01472 L
.50694 .01472 L
.50697 .01472 L
.50699 .01472 L
.507 .01472 L
.50704 .01472 L
.50707 .01472 L
.50709 .01472 L
.50712 .01472 L
.50715 .01472 L
.50718 .01472 L
.5072 .01472 L
.50722 .01472 L
.50725 .01472 L
.50728 .01472 L
.5073 .01472 L
.50733 .01472 L
.50736 .01472 L
.50739 .01472 L
.50742 .01472 L
.50743 .01472 L
.50745 .01472 L
.50748 .01472 L
.50751 .01472 L
.50753 .01472 L
.50757 .01472 L
.5076 .01472 L
.50762 .01472 L
.50765 .01472 L
.50768 .01472 L
.50771 .01472 L
.50773 .01472 L
.50776 .01472 L
.50779 .01472 L
Mistroke
.50782 .01472 L
.50785 .01472 L
.50788 .01472 L
.5079 .01472 L
.50791 .01472 L
.50795 .01472 L
.50798 .01472 L
.508 .01472 L
.50803 .01472 L
.50806 .01472 L
.50809 .01472 L
.50811 .01472 L
.50813 .01472 L
.50816 .01472 L
.50819 .01472 L
.50821 .01472 L
.50824 .01472 L
.50827 .01472 L
.5083 .01472 L
.50833 .01472 L
.50834 .01472 L
.50836 .01472 L
.50839 .01472 L
.50842 .01472 L
.50844 .01472 L
.50846 .01472 L
.50848 .01472 L
.5085 .01472 L
.50853 .01472 L
.50856 .01472 L
.50859 .01472 L
.50861 .01472 L
.50864 .01472 L
.50867 .01472 L
.50869 .01472 L
.5087 .01472 L
.50874 .01472 L
.50875 .01472 L
.50877 .01472 L
.5088 .01472 L
.50883 .01472 L
.50886 .01472 L
.50889 .01472 L
.50891 .01472 L
.50894 .01472 L
.50896 .01472 L
.50899 .01472 L
.50902 .01472 L
.50905 .01472 L
.50907 .01472 L
Mistroke
.5091 .01472 L
.50913 .01472 L
.50916 .01472 L
.50918 .01472 L
.50921 .01472 L
.50924 .01472 L
.50927 .01472 L
.5093 .01472 L
.50933 .01472 L
.50936 .01472 L
.50939 .01472 L
.5094 .01472 L
.50942 .01472 L
.50944 .01472 L
.50945 .01472 L
.50948 .01472 L
.50951 .01472 L
.50954 .01472 L
.50957 .01472 L
.5096 .01472 L
.50963 .01472 L
.50965 .01472 L
.50968 .01472 L
.50971 .01472 L
.50974 .01472 L
.50977 .01472 L
.5098 .01472 L
.50982 .01472 L
.50986 .01472 L
.50989 .01472 L
.50991 .01472 L
.50994 .01472 L
.50996 .01472 L
.50998 .01472 L
.51001 .01472 L
.51002 .01472 L
.51004 .01472 L
.51006 .01472 L
.51007 .01472 L
.5101 .01472 L
.51012 .01472 L
.51014 .01472 L
.51015 .01472 L
.51017 .01472 L
.51019 .01472 L
.51021 .01472 L
.51022 .01472 L
.51024 .01472 L
.51027 .01472 L
.5103 .01472 L
Mistroke
.51033 .01472 L
.51036 .01472 L
.51039 .01472 L
.51042 .01472 L
.51044 .01472 L
.51047 .01472 L
.5105 .01472 L
.51052 .01472 L
.51055 .01472 L
.51058 .01472 L
.51061 .01472 L
.51064 .01472 L
.51067 .01472 L
.51069 .01472 L
.51071 .01472 L
.51074 .01472 L
.51077 .01472 L
.51079 .01472 L
.51082 .01472 L
.51085 .01472 L
.51088 .01472 L
.5109 .01472 L
.51093 .01472 L
.51095 .01472 L
.51098 .01472 L
.51101 .01472 L
.51103 .01472 L
.51106 .01472 L
.51109 .01472 L
.51112 .01472 L
.51113 .01472 L
.51115 .01472 L
.51118 .01472 L
.51121 .01472 L
.51124 .01472 L
.51127 .01472 L
.5113 .01472 L
.51133 .01472 L
.51135 .01472 L
.51138 .01472 L
.51141 .01472 L
.51143 .01472 L
.51146 .01472 L
.51149 .01472 L
.51152 .01472 L
.51155 .01472 L
.51158 .01472 L
.5116 .01472 L
.51162 .01472 L
.51165 .01472 L
Mistroke
.51168 .01472 L
.5117 .01472 L
.51173 .01472 L
.51176 .01472 L
.51179 .01472 L
.51181 .01472 L
.51183 .01472 L
.51186 .01472 L
.51189 .01472 L
.51191 .01472 L
.51194 .01472 L
.51197 .01472 L
.512 .01472 L
.51203 .01472 L
.51204 .01472 L
.51206 .01472 L
.51209 .01472 L
.51212 .01472 L
.51215 .01472 L
.51218 .01472 L
.51221 .01472 L
.51224 .01472 L
.51226 .01472 L
.51229 .01472 L
.51232 .01472 L
.51234 .01472 L
.51237 .01472 L
.5124 .01472 L
.51243 .01472 L
.51246 .01472 L
.51249 .01472 L
.51251 .01472 L
.51253 .01472 L
.51256 .01472 L
.51259 .01472 L
.51261 .01472 L
.51264 .01472 L
.51267 .01472 L
.5127 .01472 L
.51272 .01472 L
.51275 .01472 L
.51277 .01472 L
.5128 .01472 L
.51283 .01472 L
.51286 .01472 L
.51288 .01472 L
.51291 .01472 L
.51294 .01472 L
.51295 .01472 L
.51297 .01472 L
Mistroke
.513 .01472 L
.51303 .01472 L
.51306 .01472 L
.51307 .01472 L
.51309 .01472 L
.51312 .01472 L
.51315 .01472 L
.51317 .01472 L
.5132 .01472 L
.51323 .01472 L
.51326 .01472 L
.51328 .01472 L
.5133 .01472 L
.51332 .01472 L
.51335 .01472 L
.51337 .01472 L
.51338 .01472 L
.51341 .01472 L
.51344 .01472 L
.51347 .01472 L
.5135 .01472 L
.51352 .01472 L
.51355 .01472 L
.51358 .01472 L
.5136 .01472 L
.51363 .01472 L
.51366 .01472 L
.51369 .01472 L
.51371 .01472 L
.51374 .01472 L
.51377 .01472 L
.5138 .01472 L
.51382 .01472 L
.51385 .01472 L
.51388 .01472 L
.51391 .01472 L
.51394 .01472 L
.51397 .01472 L
.514 .01472 L
.51402 .01472 L
.51403 .01472 L
.51405 .01472 L
.51407 .01472 L
.5141 .01472 L
.51412 .01472 L
.51415 .01472 L
.51419 .01472 L
.51421 .01472 L
.51424 .01472 L
.51427 .01472 L
Mistroke
.51429 .01472 L
.51432 .01472 L
.51435 .01472 L
.51438 .01472 L
.51441 .01472 L
.51444 .01472 L
.51447 .01472 L
.5145 .01472 L
.51453 .01472 L
.51456 .01472 L
.51458 .01472 L
.51459 .01472 L
.51462 .01472 L
.51464 .01472 L
.51465 .01472 L
.51467 .01472 L
.51469 .01472 L
.51472 .01472 L
.51473 .01472 L
.51475 .01472 L
.51477 .01472 L
.51479 .01472 L
.5148 .01472 L
.51482 .01472 L
.51484 .01472 L
.51485 .01472 L
.51488 .01472 L
.51491 .01472 L
.51494 .01472 L
.51497 .01472 L
.515 .01472 L
.51503 .01472 L
.51506 .01472 L
.51508 .01472 L
.51511 .01472 L
.51514 .01472 L
.51517 .01472 L
.5152 .01472 L
.51523 .01472 L
.51526 .01472 L
.51529 .01472 L
.5153 .01472 L
.51532 .01472 L
.51535 .01472 L
.51538 .01472 L
.51541 .01472 L
.51543 .01472 L
.51546 .01472 L
.51549 .01472 L
.51552 .01472 L
Mistroke
.51554 .01472 L
.51557 .01472 L
.51559 .01472 L
.51562 .01472 L
.51565 .01472 L
.51568 .01472 L
.5157 .01472 L
.51573 .01472 L
.51575 .01472 L
.51576 .01472 L
.51579 .01472 L
.51582 .01472 L
.51585 .01472 L
.51588 .01472 L
.51591 .01472 L
.51594 .01472 L
.51597 .01472 L
.51599 .01472 L
.51602 .01472 L
.51605 .01472 L
.51608 .01472 L
.51611 .01472 L
.51614 .01472 L
.51617 .01472 L
.5162 .01472 L
.51622 .01472 L
.51623 .01472 L
.51626 .01472 L
.51629 .01472 L
.51632 .01472 L
.51635 .01472 L
.51637 .01472 L
.5164 .01472 L
.51643 .01472 L
.51645 .01472 L
.51648 .01472 L
.5165 .01472 L
.51653 .01472 L
.51656 .01472 L
.51659 .01472 L
.51661 .01472 L
.51664 .01472 L
.51666 .01472 L
.51667 .01472 L
.5167 .01472 L
.51673 .01472 L
.51676 .01472 L
.51678 .01472 L
.51679 .01472 L
.51682 .01472 L
Mistroke
.51685 .01472 L
.51688 .01472 L
.5169 .01472 L
.51693 .01472 L
.51696 .01472 L
.51699 .01472 L
.51701 .01472 L
.51702 .01472 L
.51705 .01472 L
.51707 .01472 L
.51709 .01472 L
.51712 .01472 L
.51715 .01472 L
.51718 .01472 L
.5172 .01472 L
.51723 .01472 L
.51726 .01472 L
.51728 .01472 L
.51731 .01472 L
.51733 .01472 L
.51736 .01472 L
.51739 .01472 L
.51742 .01472 L
.51745 .01472 L
.51748 .01472 L
.5175 .01472 L
.51753 .01472 L
.51756 .01472 L
.51759 .01472 L
.51761 .01472 L
.51764 .01472 L
.51768 .01472 L
.5177 .01472 L
.51772 .01472 L
.51774 .01472 L
.51775 .01472 L
.51777 .01472 L
.5178 .01472 L
.51783 .01472 L
.51786 .01472 L
.51789 .01472 L
.51792 .01472 L
.51795 .01472 L
.51797 .01472 L
.518 .01472 L
.51803 .01472 L
.51806 .01472 L
.51809 .01472 L
.51811 .01472 L
.51814 .01472 L
Mistroke
.51817 .01472 L
.5182 .01472 L
.51823 .01472 L
.51826 .01472 L
.51828 .01472 L
.5183 .01472 L
.51833 .01472 L
.51834 .01472 L
.51836 .01472 L
.51837 .01472 L
.51839 .01472 L
.51842 .01472 L
.51844 .01472 L
.51846 .01472 L
.51847 .01472 L
.51849 .01472 L
.51851 .01472 L
.51852 .01472 L
.51854 .01472 L
.51856 .01472 L
.51859 .01472 L
.51862 .01472 L
.51865 .01472 L
.51868 .01472 L
.51871 .01472 L
.51873 .01472 L
.51876 .01472 L
.51879 .01472 L
.51882 .01472 L
.51884 .01472 L
.51887 .01472 L
.5189 .01472 L
.51893 .01472 L
.51896 .01472 L
.51899 .01472 L
.51901 .01472 L
.51902 .01472 L
.51906 .01472 L
.51909 .01472 L
.51911 .01472 L
.51914 .01472 L
.51917 .01472 L
.5192 .01472 L
.51922 .01472 L
.51924 .01472 L
.51927 .01472 L
.5193 .01472 L
.51932 .01472 L
.51935 .01472 L
.51938 .01472 L
Mistroke
.51941 .01472 L
.51944 .01472 L
.51945 .01472 L
.51947 .01472 L
.5195 .01472 L
.51953 .01472 L
.51955 .01472 L
.51959 .01472 L
.51962 .01472 L
.51964 .01472 L
.51967 .01472 L
.5197 .01472 L
.51973 .01472 L
.51975 .01472 L
.51978 .01472 L
.51981 .01472 L
.51984 .01472 L
.51987 .01472 L
.5199 .01472 L
.51992 .01472 L
.51993 .01472 L
.51997 .01472 L
.52 .01472 L
.52002 .01472 L
.52005 .01472 L
.52008 .01472 L
.52011 .01472 L
.52013 .01472 L
.52015 .01472 L
.52018 .01472 L
.52021 .01472 L
.52023 .01472 L
.52026 .01472 L
.52029 .01472 L
.52032 .01472 L
.52035 .01472 L
.52036 .01472 L
.52038 .01472 L
.52041 .01472 L
.52044 .01472 L
.52047 .01472 L
.52048 .01472 L
.5205 .01472 L
.52053 .01472 L
.52055 .01472 L
.52058 .01472 L
.52061 .01472 L
.52063 .01472 L
.52066 .01472 L
.52069 .01472 L
Mistroke
.52071 .01472 L
.52073 .01472 L
.52076 .01472 L
.52077 .01472 L
.52079 .01472 L
.52082 .01472 L
.52085 .01472 L
.52088 .01472 L
.52091 .01472 L
.52093 .01472 L
.52096 .01472 L
.52099 .01472 L
.52101 .01472 L
.52104 .01472 L
.52107 .01472 L
.52109 .01472 L
.52112 .01472 L
.52115 .01472 L
.52118 .01472 L
.5212 .01472 L
.52123 .01472 L
.52126 .01472 L
.52129 .01472 L
.52132 .01472 L
.52135 .01472 L
.52138 .01472 L
.52141 .01472 L
.52142 .01472 L
.52144 .01472 L
.52146 .01472 L
.52147 .01472 L
.5215 .01472 L
.52153 .01472 L
.52156 .01472 L
.52159 .01472 L
.52162 .01472 L
.52165 .01472 L
.52168 .01472 L
.5217 .01472 L
.52173 .01472 L
.52176 .01472 L
.52179 .01472 L
.52182 .01472 L
.52185 .01472 L
.52188 .01472 L
.52191 .01472 L
.52193 .01472 L
.52196 .01472 L
.52198 .01472 L
.522 .01472 L
Mistroke
.52203 .01472 L
.52205 .01472 L
.52206 .01472 L
.52208 .01472 L
.52209 .01472 L
.52213 .01472 L
.52214 .01472 L
.52216 .01472 L
.52218 .01472 L
.52219 .01472 L
.52221 .01472 L
.52223 .01472 L
.52224 .01472 L
.52226 .01472 L
.52229 .01472 L
.52232 .01472 L
.52235 .01472 L
.52238 .01472 L
.52241 .01472 L
.52244 .01472 L
.52246 .01472 L
.52249 .01472 L
.52252 .01472 L
.52255 .01472 L
.52258 .01472 L
.52261 .01472 L
.52263 .01472 L
.52266 .01472 L
.52269 .01472 L
.52271 .01472 L
.52273 .01472 L
.52276 .01472 L
.52279 .01472 L
.52281 .01472 L
.52284 .01472 L
.52287 .01472 L
.5229 .01472 L
.52292 .01472 L
.52295 .01472 L
.52297 .01472 L
.523 .01472 L
.52303 .01472 L
.52306 .01472 L
.52308 .01472 L
.52311 .01472 L
.52314 .01472 L
.52315 .01472 L
.52317 .01472 L
.5232 .01472 L
.52323 .01472 L
Mistroke
.52326 .01472 L
.52329 .01472 L
.52332 .01472 L
.52335 .01472 L
.52337 .01472 L
.5234 .01472 L
.52343 .01472 L
.52345 .01472 L
.52348 .01472 L
.52352 .01472 L
.52354 .01472 L
.52357 .01472 L
.5236 .01472 L
.52362 .01472 L
.52364 .01472 L
.52367 .01472 L
.5237 .01472 L
.52372 .01472 L
.52375 .01472 L
.52378 .01472 L
.52381 .01472 L
.52383 .01472 L
.52386 .01472 L
.52388 .01472 L
.52391 .01472 L
.52394 .01472 L
.52397 .01472 L
.52399 .01472 L
.52402 .01472 L
.52405 .01472 L
.52406 .01472 L
.52408 .01472 L
.52411 .01472 L
.52414 .01472 L
.52417 .01472 L
.52418 .01472 L
.5242 .01472 L
.52423 .01472 L
.52426 .01472 L
.52428 .01472 L
.52431 .01472 L
.52434 .01472 L
.52437 .01472 L
.5244 .01472 L
.52441 .01472 L
.52443 .01472 L
.52446 .01472 L
.52448 .01472 L
.52449 .01472 L
.52452 .01472 L
Mistroke
.52455 .01472 L
.52458 .01472 L
.52461 .01472 L
.52463 .01472 L
.52466 .01472 L
.52469 .01472 L
.52471 .01472 L
.52474 .01472 L
.52477 .01472 L
.5248 .01472 L
.52482 .01472 L
.52485 .01472 L
.52488 .01472 L
.52491 .01472 L
.52493 .01472 L
.52496 .01472 L
.52499 .01472 L
.52502 .01472 L
.52505 .01472 L
.52508 .01472 L
.52511 .01472 L
.52513 .01472 L
.52514 .01472 L
.52516 .01472 L
.52518 .01472 L
.52521 .01472 L
.52523 .01472 L
.52526 .01472 L
.5253 .01472 L
.52532 .01472 L
.52535 .01472 L
.52538 .01472 L
.5254 .01472 L
.52543 .01472 L
.52546 .01472 L
.52549 .01472 L
.52552 .01472 L
.52555 .01472 L
.52558 .01472 L
.52561 .01472 L
.52564 .01472 L
.52567 .01472 L
.52568 .01472 L
.5257 .01472 L
.52573 .01472 L
.52575 .01472 L
.52576 .01472 L
.52578 .01472 L
.5258 .01472 L
.52583 .01472 L
Mistroke
.52584 .01472 L
.52586 .01472 L
.52588 .01472 L
.5259 .01472 L
.52591 .01472 L
.52593 .01472 L
.52595 .01472 L
.52596 .01472 L
.52599 .01472 L
.52602 .01472 L
.52605 .01472 L
.52608 .01472 L
.52611 .01472 L
.52614 .01472 L
.52617 .01472 L
.52619 .01472 L
.52622 .01472 L
.52625 .01472 L
.52628 .01472 L
.52631 .01472 L
.52633 .01472 L
.52636 .01472 L
.5264 .01472 L
.52641 .01472 L
.52643 .01472 L
.52646 .01472 L
.52649 .01472 L
.52652 .01472 L
.52654 .01472 L
.52657 .01472 L
.5266 .01472 L
.52662 .01472 L
.52665 .01472 L
.52667 .01472 L
.5267 .01472 L
.52673 .01472 L
.52676 .01472 L
.52679 .01472 L
.52681 .01472 L
.52684 .01472 L
.52686 .01472 L
.52687 .01472 L
.5269 .01472 L
.52693 .01472 L
.52696 .01472 L
.52699 .01472 L
.52702 .01472 L
.52705 .01472 L
.52708 .01472 L
.5271 .01472 L
Mistroke
.52713 .01472 L
.52716 .01472 L
.52719 .01472 L
.52722 .01472 L
.52724 .01472 L
.52727 .01472 L
.5273 .01472 L
.52732 .01472 L
.52734 .01472 L
.52737 .01472 L
.5274 .01472 L
.52743 .01472 L
.52745 .01472 L
.52748 .01472 L
.52751 .01472 L
.52753 .01472 L
.52756 .01472 L
.52758 .01472 L
.52761 .01472 L
.52764 .01472 L
.52767 .01472 L
.52769 .01472 L
.52772 .01472 L
.52775 .01472 L
.52777 .01472 L
.52778 .01472 L
.52781 .01472 L
.52784 .01472 L
.52787 .01472 L
.5279 .01472 L
.52793 .01472 L
.52796 .01472 L
.52798 .01472 L
.52801 .01472 L
.52804 .01472 L
.52807 .01472 L
.5281 .01472 L
.52813 .01472 L
.52815 .01472 L
.52818 .01472 L
.52822 .01472 L
.52823 .01472 L
.52825 .01472 L
.52828 .01472 L
.52831 .01472 L
.52834 .01472 L
.52836 .01472 L
.52839 .01472 L
.52842 .01472 L
.52845 .01472 L
Mistroke
.52847 .01472 L
.5285 .01472 L
.52852 .01472 L
.52855 .01472 L
.52858 .01472 L
.52861 .01472 L
.52863 .01472 L
.52866 .01472 L
.52868 .01472 L
.52869 .01472 L
.52872 .01472 L
.52875 .01472 L
.52878 .01472 L
.5288 .01472 L
.52881 .01472 L
.52884 .01472 L
.52887 .01472 L
.5289 .01472 L
.52892 .01472 L
.52895 .01472 L
.52898 .01472 L
.52901 .01472 L
.52902 .01472 L
.52904 .01472 L
.52907 .01472 L
.52909 .01472 L
.52911 .01472 L
.52913 .01472 L
.52917 .01472 L
.5292 .01472 L
.52922 .01472 L
.52925 .01472 L
.52928 .01472 L
.5293 .01472 L
.52932 .01472 L
.52935 .01472 L
.52938 .01472 L
.52941 .01472 L
.52944 .01472 L
.52947 .01472 L
.52949 .01472 L
.52952 .01472 L
.52955 .01472 L
.52958 .01472 L
.52961 .01472 L
.52963 .01472 L
.52966 .01472 L
.52969 .01472 L
.52972 .01472 L
.52974 .01472 L
Mistroke
.52976 .01472 L
.52977 .01472 L
.52979 .01472 L
.52982 .01472 L
.52985 .01472 L
.52988 .01472 L
.52991 .01472 L
.52994 .01472 L
.52996 .01472 L
.52999 .01472 L
.53002 .01472 L
.53004 .01472 L
.53008 .01472 L
.53011 .01472 L
.53013 .01472 L
.53016 .01472 L
.53019 .01472 L
.53022 .01472 L
.53025 .01472 L
.53028 .01472 L
.5303 .01472 L
.53031 .01472 L
.53035 .01472 L
.53036 .01472 L
.53038 .01472 L
.53039 .01472 L
.53041 .01472 L
.53044 .01472 L
.53046 .01472 L
.53047 .01472 L
.53049 .01472 L
.53051 .01472 L
.53053 .01472 L
.53054 .01472 L
.53056 .01472 L
.53058 .01472 L
.5306 .01472 L
.53064 .01472 L
.53066 .01472 L
.5307 .01472 L
.53073 .01472 L
.53075 .01472 L
.53078 .01472 L
.53081 .01472 L
.53083 .01472 L
.53086 .01472 L
.53089 .01472 L
.53092 .01472 L
.53095 .01472 L
.53098 .01472 L
Mistroke
.53101 .01472 L
.53103 .01472 L
.53104 .01472 L
.53108 .01472 L
.53111 .01472 L
.53113 .01472 L
.53116 .01472 L
.53119 .01472 L
.53121 .01472 L
.53124 .01472 L
.53126 .01472 L
.53129 .01472 L
.53132 .01472 L
.53134 .01472 L
.53137 .01472 L
.5314 .01472 L
.53143 .01472 L
.53145 .01472 L
.53147 .01472 L
.53149 .01472 L
.53152 .01472 L
.53155 .01472 L
.53157 .01472 L
.53161 .01472 L
.53164 .01472 L
.53166 .01472 L
.53169 .01472 L
.53172 .01472 L
.53174 .01472 L
.53177 .01472 L
.5318 .01472 L
.53183 .01472 L
.53186 .01472 L
.53189 .01472 L
.53192 .01472 L
.53194 .01472 L
.53195 .01472 L
.53199 .01472 L
.53202 .01472 L
.53204 .01472 L
.53207 .01472 L
.5321 .01472 L
.53213 .01472 L
.53215 .01472 L
.53217 .01472 L
.5322 .01472 L
.53223 .01472 L
.53225 .01472 L
.53228 .01472 L
.53231 .01472 L
Mistroke
.53234 .01472 L
.53237 .01472 L
.53238 .01472 L
.5324 .01472 L
.53243 .01472 L
.53246 .01472 L
.53249 .01472 L
.5325 .01472 L
.53252 .01472 L
.53254 .01472 L
.53257 .01472 L
.5326 .01472 L
.53263 .01472 L
.53265 .01472 L
.53268 .01472 L
.53271 .01472 L
.53273 .01472 L
.53275 .01472 L
.53278 .01472 L
.53279 .01472 L
.53281 .01472 L
.53284 .01472 L
.53287 .01472 L
.5329 .01472 L
.53293 .01472 L
.53295 .01472 L
.53298 .01472 L
.53301 .01472 L
.53303 .01472 L
.53306 .01472 L
.53309 .01472 L
.53312 .01472 L
.53314 .01472 L
.53317 .01472 L
.5332 .01472 L
.53322 .01472 L
.53325 .01472 L
.53328 .01472 L
.53331 .01472 L
.53334 .01472 L
.53337 .01472 L
.5334 .01472 L
.53343 .01472 L
.53344 .01472 L
.53346 .01472 L
.53348 .01472 L
.53349 .01472 L
.53352 .01472 L
.53355 .01472 L
.53358 .01472 L
Mistroke
.53361 .01472 L
.53364 .01472 L
.53367 .01472 L
.5337 .01472 L
.53372 .01472 L
.53375 .01472 L
.53378 .01472 L
.53381 .01472 L
.53384 .01472 L
.53387 .01472 L
.5339 .01472 L
.53393 .01472 L
.53395 .01472 L
.53399 .01472 L
.534 .01472 L
.53402 .01472 L
.53405 .01472 L
.53406 .01472 L
.53408 .01472 L
.5341 .01472 L
.53412 .01472 L
.53415 .01472 L
.53416 .01472 L
.53418 .01472 L
.5342 .01472 L
.53421 .01472 L
.53423 .01472 L
.53425 .01472 L
.53427 .01472 L
.53428 .01472 L
.53431 .01472 L
.53434 .01472 L
.53437 .01472 L
.5344 .01472 L
.53443 .01472 L
.53446 .01472 L
.53449 .01472 L
.53451 .01472 L
.53454 .01472 L
.53457 .01472 L
.5346 .01472 L
.53463 .01472 L
.53465 .01472 L
.53468 .01472 L
.53471 .01472 L
.53473 .01472 L
.53475 .01472 L
.53478 .01472 L
.53481 .01472 L
.53483 .01472 L
Mistroke
.53486 .01472 L
.53489 .01472 L
.53492 .01472 L
.53494 .01472 L
.53497 .01472 L
.53499 .01472 L
.53502 .01472 L
.53505 .01472 L
.53508 .01472 L
.5351 .01472 L
.53513 .01472 L
.53516 .01472 L
.53518 .01472 L
.53519 .01472 L
.53522 .01472 L
.53525 .01472 L
.53528 .01472 L
.53531 .01472 L
.53534 .01472 L
.53537 .01472 L
.5354 .01472 L
.53542 .01472 L
.53545 .01472 L
.53548 .01472 L
.53551 .01472 L
.53554 .01472 L
.53556 .01472 L
.53559 .01472 L
.53562 .01472 L
.53564 .01472 L
.53566 .01472 L
.53569 .01472 L
.53572 .01472 L
.53574 .01472 L
.53577 .01472 L
.5358 .01472 L
.53583 .01472 L
.53585 .01472 L
.53588 .01472 L
.53591 .01472 L
.53593 .01472 L
.53596 .01472 L
.53599 .01472 L
.53602 .01472 L
.53604 .01472 L
.53607 .01472 L
.53609 .01472 L
.5361 .01472 L
.53613 .01472 L
.53616 .01472 L
Mistroke
.53619 .01472 L
.53621 .01472 L
.53622 .01472 L
.53625 .01472 L
.53628 .01472 L
.53631 .01472 L
.53633 .01472 L
.53636 .01472 L
.53639 .01472 L
.53642 .01472 L
.53643 .01472 L
.53645 .01472 L
.53648 .01472 L
.5365 .01472 L
.53651 .01472 L
.53654 .01472 L
.53657 .01472 L
.5366 .01472 L
.53663 .01472 L
.53666 .01472 L
.53668 .01472 L
.53671 .01472 L
.53673 .01472 L
.53676 .01472 L
.53679 .01472 L
.53682 .01472 L
.53684 .01472 L
.53687 .01472 L
.5369 .01472 L
.53693 .01472 L
.53695 .01472 L
.53698 .01472 L
.53702 .01472 L
.53704 .01472 L
.53707 .01472 L
.5371 .01472 L
.53713 .01472 L
.53715 .01472 L
.53716 .01472 L
.53718 .01472 L
.5372 .01472 L
.53723 .01472 L
.53726 .01472 L
.53729 .01472 L
.53732 .01472 L
.53734 .01472 L
.53737 .01472 L
.5374 .01472 L
.53742 .01472 L
.53745 .01472 L
Mistroke
.53748 .01472 L
.53751 .01472 L
.53754 .01472 L
.53757 .01472 L
.5376 .01472 L
.53763 .01472 L
.53766 .01472 L
.53769 .01472 L
.53771 .01472 L
.53772 .01472 L
.53775 .01472 L
.53777 .01472 L
.53778 .01472 L
.5378 .01472 L
.53782 .01472 L
.53785 .01472 L
.53787 .01472 L
.53788 .01472 L
.5379 .01472 L
.53792 .01472 L
.53793 .01472 L
.53795 .01472 L
.53797 .01472 L
.53798 .01472 L
.53801 .01472 L
.53804 .01472 L
.53807 .01472 L
.5381 .01472 L
.53813 .01472 L
.53816 .01472 L
.53819 .01472 L
.53821 .01472 L
.53824 .01472 L
.53827 .01472 L
.5383 .01472 L
.53833 .01472 L
.53836 .01472 L
.53839 .01472 L
.53842 .01472 L
.53844 .01472 L
.53845 .01472 L
.53848 .01472 L
.53851 .01472 L
.53854 .01472 L
.53857 .01472 L
.53859 .01472 L
.53862 .01472 L
.53865 .01472 L
.53867 .01472 L
.5387 .01472 L
Mistroke
.53872 .01472 L
.53875 .01472 L
.53878 .01472 L
.53881 .01472 L
.53883 .01472 L
.53886 .01472 L
.53888 .01472 L
.53889 .01472 L
.53892 .01472 L
.53895 .01472 L
.53898 .01472 L
.53901 .01472 L
.53904 .01472 L
.53907 .01472 L
.5391 .01472 L
.53912 .01472 L
.53915 .01472 L
.53918 .01472 L
.53921 .01472 L
.53924 .01472 L
.53927 .01472 L
.5393 .01472 L
.53933 .01472 L
.53935 .01472 L
.53936 .01472 L
.53939 .01472 L
.53942 .01472 L
.53945 .01472 L
.53948 .01472 L
.5395 .01472 L
.53953 .01472 L
.53956 .01472 L
.53958 .01472 L
.53961 .01472 L
.53963 .01472 L
.53966 .01472 L
.53969 .01472 L
.53972 .01472 L
.53974 .01472 L
.53977 .01472 L
.53979 .01472 L
.5398 .01472 L
.53983 .01472 L
.53986 .01472 L
.53989 .01472 L
.53991 .01472 L
.53992 .01472 L
.53995 .01472 L
.53998 .01472 L
.54001 .01472 L
Mistroke
.54003 .01472 L
.54006 .01472 L
.54009 .01472 L
.54012 .01472 L
.54014 .01472 L
.54015 .01472 L
.54018 .01472 L
.5402 .01472 L
.54022 .01472 L
.54025 .01472 L
.54028 .01472 L
.54031 .01472 L
.54033 .01472 L
.54036 .01472 L
.54039 .01472 L
.54041 .01472 L
.54044 .01472 L
.54046 .01472 L
.54049 .01472 L
.54052 .01472 L
.54055 .01472 L
.54058 .01472 L
.5406 .01472 L
.54063 .01472 L
.54066 .01472 L
.54069 .01472 L
.54072 .01472 L
.54074 .01472 L
.54077 .01472 L
.54081 .01472 L
.54083 .01472 L
.54085 .01472 L
.54087 .01472 L
.54088 .01472 L
.5409 .01472 L
.54093 .01472 L
.54096 .01472 L
.54099 .01472 L
.54102 .01472 L
.54105 .01472 L
.54107 .01472 L
.5411 .01472 L
.54113 .01472 L
.54115 .01472 L
.54119 .01472 L
.54122 .01472 L
.54124 .01472 L
.54127 .01472 L
.5413 .01472 L
.54133 .01472 L
Mistroke
.54136 .01472 L
.54139 .01472 L
.54141 .01472 L
.54142 .01472 L
.54145 .01472 L
.54147 .01472 L
.54149 .01472 L
.5415 .01472 L
.54152 .01472 L
.54155 .01472 L
.54157 .01472 L
.54158 .01472 L
.5416 .01472 L
.54162 .01472 L
.54164 .01472 L
.54165 .01472 L
.54167 .01472 L
.54169 .01472 L
.54171 .01472 L
.54175 .01472 L
.54177 .01472 L
.54181 .01472 L
.54184 .01472 L
.54186 .01472 L
.54189 .01472 L
.54192 .01472 L
.54194 .01472 L
.54197 .01472 L
.542 .01472 L
.54203 .01472 L
.54206 .01472 L
.54209 .01472 L
.54212 .01472 L
.54214 .01472 L
.54215 .01472 L
.54218 .01472 L
.54221 .01472 L
.54224 .01472 L
.54227 .01472 L
.5423 .01472 L
.54232 .01472 L
.54235 .01472 L
.54237 .01472 L
.5424 .01472 L
.54243 .01472 L
.54245 .01472 L
.54248 .01472 L
.54251 .01472 L
.54253 .01472 L
.54256 .01472 L
Mistroke
.54258 .01472 L
.5426 .01472 L
.54262 .01472 L
.54265 .01472 L
.54268 .01472 L
.54271 .01472 L
.54274 .01472 L
.54277 .01472 L
.5428 .01472 L
.54282 .01472 L
.54285 .01472 L
.54288 .01472 L
.54291 .01472 L
.54294 .01472 L
.54297 .01472 L
.543 .01472 L
.54303 .01472 L
.54305 .01472 L
.54306 .01472 L
.54309 .01472 L
.54312 .01472 L
.54315 .01472 L
.54318 .01472 L
.54321 .01472 L
.54323 .01472 L
.54326 .01472 L
.54328 .01472 L
.54331 .60332 L
.54333 .60332 L
.54356 .60332 L
.54448 .60332 L
.54546 .60332 L
.54639 .60332 L
.54739 .60332 L
.54835 .60332 L
.54928 .60332 L
.55026 .60332 L
.55121 .60332 L
.55212 .60332 L
.55309 .60332 L
.55403 .60332 L
.55502 .60332 L
.55597 .60332 L
.55689 .60332 L
.55787 .60332 L
.55881 .60332 L
.55972 .60332 L
.56018 .60332 L
.56031 .60332 L
.56045 .60332 L
Mistroke
.5605 .60332 L
.56056 .60332 L
.56058 .60332 L
.56059 .60332 L
.56062 .01472 L
.56065 .01472 L
.56069 .01472 L
.56071 .01472 L
.56074 .01472 L
.56077 .01472 L
.5608 .01472 L
.56083 .01472 L
.56085 .01472 L
.56088 .01472 L
.56091 .01472 L
.56093 .01472 L
.56094 .01472 L
.56096 .01472 L
.56098 .01472 L
.56101 .01472 L
.56103 .01472 L
.56104 .01472 L
.56107 .01472 L
.5611 .01472 L
.56113 .01472 L
.56116 .01472 L
.56119 .01472 L
.56121 .01472 L
.56122 .01472 L
.56125 .01472 L
.56127 .01472 L
.56129 .01472 L
.56131 .01472 L
.56134 .01472 L
.56138 .01472 L
.5614 .01472 L
.56142 .01472 L
.56144 .01472 L
.56146 .01472 L
.56147 .01472 L
.5615 .01472 L
.56153 .01472 L
.56155 .01472 L
.56156 .01472 L
.5616 .01472 L
.56162 .01472 L
.56163 .01472 L
.56165 .01472 L
.56167 .01472 L
.56168 .01472 L
Mistroke
.5617 .01472 L
.56173 .01472 L
.56176 .01472 L
.56178 .01472 L
.5618 .01472 L
.56183 .01472 L
.56185 .01472 L
.56187 .01472 L
.56189 .01472 L
.56192 .01472 L
.56194 .01472 L
.56197 .01472 L
.562 .01472 L
.56203 .01472 L
.56206 .01472 L
.56208 .01472 L
.56211 .01472 L
.56214 .01472 L
.56217 .01472 L
.5622 .01472 L
.56222 .01472 L
.56223 .01472 L
.56227 .01472 L
.5623 .01472 L
.56233 .01472 L
.56235 .01472 L
.56238 .01472 L
.5624 .01472 L
.56242 .01472 L
.56245 .01472 L
.56247 .01472 L
.56248 .01472 L
.5625 .01472 L
.56252 .01472 L
.56255 .01472 L
.56258 .01472 L
.5626 .01472 L
.56261 .01472 L
.56263 .01472 L
.56265 .01472 L
.56267 .01472 L
.56269 .01472 L
.56271 .01472 L
.56274 .01472 L
.56277 .01472 L
.56279 .01472 L
.56282 .01472 L
.56284 .01472 L
.56287 .01472 L
.56291 .01472 L
Mistroke
.56292 .01472 L
.56294 .01472 L
.56297 .01472 L
.56299 .01472 L
.563 .01472 L
.56303 .01472 L
.56306 .01472 L
.56309 .01472 L
.56312 .01472 L
.56314 .01472 L
.56317 .01472 L
.5632 .01472 L
.56322 .01472 L
.56325 .01472 L
.56328 .01472 L
.56331 .01472 L
.56333 .01472 L
.56336 .01472 L
.56339 .01472 L
.56341 .01472 L
.56344 .01472 L
.56347 .01472 L
.5635 .01472 L
.56353 .01472 L
.56356 .01472 L
.56359 .01472 L
.56362 .01472 L
.56364 .01472 L
.56365 .01472 L
.56367 .01472 L
.56369 .01472 L
.56372 .01472 L
.56375 .01472 L
.56376 .01472 L
.56378 .01472 L
.56381 .01472 L
.56384 .01472 L
.56386 .01472 L
.56389 .01472 L
.56392 .01472 L
.56395 .01472 L
.56398 .01472 L
.564 .01472 L
.56403 .01472 L
.56406 .01472 L
.56409 .01472 L
.56411 .01472 L
.56412 .01472 L
.56416 .01472 L
.56419 .01472 L
Mistroke
.56422 .01472 L
.56424 .01472 L
.56427 .01472 L
.56429 .01472 L
.56431 .01472 L
.56434 .01472 L
.56435 .01472 L
.56437 .01472 L
.56439 .01472 L
.56441 .01472 L
.56442 .01472 L
.56444 .01472 L
.56446 .01472 L
.56447 .01472 L
.5645 .01472 L
.56454 .01472 L
.56456 .01472 L
.56458 .01472 L
.5646 .01472 L
.56462 .01472 L
.56465 .01472 L
.56468 .01472 L
.56471 .01472 L
.56473 .01472 L
.56476 .01472 L
.56479 .01472 L
.56481 .01472 L
.56482 .01472 L
.56486 .01472 L
.56487 .01472 L
.56489 .01472 L
.56492 .01472 L
.56495 .01472 L
.56498 .01472 L
.56501 .01472 L
.56503 .01472 L
.56506 .01472 L
.56509 .01472 L
.56511 .01472 L
.56514 .01472 L
.56517 .01472 L
.56519 .01472 L
.56522 .01472 L
.56525 .01472 L
.56528 .01472 L
.5653 .01472 L
.56533 .01472 L
.56536 .01472 L
.56539 .01472 L
.56542 .01472 L
Mistroke
.56545 .01472 L
.56548 .01472 L
.56551 .01472 L
.56552 .01472 L
.56554 .01472 L
.56556 .01472 L
.56557 .01472 L
.5656 .01472 L
.56563 .01472 L
.56566 .01472 L
.56569 .01472 L
.56572 .01472 L
.56575 .01472 L
.56578 .01472 L
.5658 .01472 L
.56583 .01472 L
.56586 .01472 L
.56589 .01472 L
.56592 .01472 L
.56595 .01472 L
.56598 .01472 L
.56601 .01472 L
.56603 .01472 L
.56606 .01472 L
.56608 .01472 L
.5661 .01472 L
.56613 .01472 L
.56614 .01472 L
.56616 .01472 L
.56618 .01472 L
.56619 .01472 L
.56623 .01472 L
.56624 .01472 L
.56626 .01472 L
.56628 .01472 L
.56629 .01472 L
.56631 .01472 L
.56633 .01472 L
.56634 .01472 L
.56636 .01472 L
.56639 .01472 L
.56642 .01472 L
.56645 .01472 L
.56648 .01472 L
.56651 .01472 L
.56654 .01472 L
.56657 .01472 L
.56659 .01472 L
.56662 .01472 L
.56665 .01472 L
Mistroke
.56668 .01472 L
.56671 .01472 L
.56673 .01472 L
.56676 .01472 L
.56679 .01472 L
.56681 .01472 L
.56683 .01472 L
.56686 .01472 L
.56689 .01472 L
.56691 .01472 L
.56694 .01472 L
.56697 .01472 L
.567 .01472 L
.56702 .01472 L
.56705 .01472 L
.56707 .01472 L
.5671 .01472 L
.56713 .01472 L
.56716 .01472 L
.56718 .01472 L
.56721 .01472 L
.56724 .01472 L
.56726 .01472 L
.56727 .01472 L
.5673 .01472 L
.56733 .01472 L
.56736 .01472 L
.56739 .01472 L
.56742 .01472 L
.56745 .01472 L
.56747 .01472 L
.5675 .01472 L
.56753 .01472 L
.56756 .01472 L
.56759 .01472 L
.56762 .01472 L
.56764 .01472 L
.56767 .01472 L
.5677 .01472 L
.56772 .01472 L
.56774 .01472 L
.56777 .01472 L
.5678 .01472 L
.56782 .01472 L
.56785 .01472 L
.56788 .01472 L
.56791 .01472 L
.56793 .01472 L
.56796 .01472 L
.56798 .01472 L
Mistroke
.56801 .01472 L
.56804 .01472 L
.56807 .01472 L
.56809 .01472 L
.56812 .01472 L
.56815 .01472 L
.56817 .01472 L
.56818 .01472 L
.56821 .01472 L
.56824 .01472 L
.56827 .01472 L
.56829 .01472 L
.5683 .01472 L
.56833 .01472 L
.56836 .01472 L
.56838 .01472 L
.56841 .01472 L
.56844 .01472 L
.56847 .01472 L
.5685 .01472 L
.56851 .01472 L
.56853 .01472 L
.56856 .01472 L
.56858 .01472 L
.56859 .01472 L
.56862 .01472 L
.56865 .01472 L
.56868 .01472 L
.56871 .01472 L
.56874 .01472 L
.56876 .01472 L
.56879 .01472 L
.56881 .01472 L
.56884 .01472 L
.56887 .01472 L
.5689 .01472 L
.56892 .01472 L
.56895 .01472 L
.56898 .01472 L
.56901 .01472 L
.56903 .01472 L
.56906 .01472 L
.5691 .01472 L
.56912 .01472 L
.56915 .01472 L
.56918 .01472 L
.56921 .01472 L
.56923 .01472 L
.56924 .01472 L
.56926 .01472 L
Mistroke
.56928 .01472 L
.56931 .01472 L
.56933 .01472 L
.56936 .01472 L
.5694 .01472 L
.56942 .01472 L
.56945 .01472 L
.56948 .01472 L
.5695 .01472 L
.56953 .01472 L
.56956 .01472 L
.56959 .01472 L
.56962 .01472 L
.56965 .01472 L
.56968 .01472 L
.56971 .01472 L
.56974 .01472 L
.56977 .01472 L
.56979 .01472 L
.5698 .01472 L
.56983 .01472 L
.56985 .01472 L
.56986 .01472 L
.56988 .01472 L
.5699 .01472 L
.56993 .01472 L
.56995 .01472 L
.56996 .01472 L
.56998 .01472 L
.57 .01472 L
.57001 .01472 L
.57003 .01472 L
.57005 .01472 L
.57006 .01472 L
.57009 .01472 L
.57012 .01472 L
.57015 .01472 L
.57018 .01472 L
.57021 .01472 L
.57024 .01472 L
.57027 .01472 L
.57029 .01472 L
.57032 .01472 L
.57035 .01472 L
.57038 .01472 L
.57041 .01472 L
.57044 .01472 L
.57047 .01472 L
.5705 .01472 L
.57052 .01472 L
Mistroke
.57053 .01472 L
.57056 .01472 L
.57059 .01472 L
.57062 .01472 L
.57065 .01472 L
.57067 .01472 L
.5707 .01472 L
.57073 .01472 L
.57075 .01472 L
.57078 .01472 L
.5708 .01472 L
.57083 .01472 L
.57086 .01472 L
.57089 .01472 L
.57091 .01472 L
.57094 .01472 L
.57096 .01472 L
.57097 .01472 L
.571 .01472 L
.57103 .01472 L
.57106 .01472 L
.57109 .01472 L
.57112 .01472 L
.57115 .01472 L
.57118 .01472 L
.5712 .01472 L
.57123 .01472 L
.57126 .01472 L
.57129 .01472 L
.57132 .01472 L
.57135 .01472 L
.57138 .01472 L
.57141 .01472 L
.57143 .01472 L
.57144 .01472 L
.57147 .01472 L
.5715 .01472 L
.57153 .01472 L
.57156 .01472 L
.57158 .01472 L
.57161 .01472 L
.57164 .01472 L
.57166 .01472 L
.57169 .01472 L
.57171 .01472 L
.57174 .01472 L
.57177 .01472 L
.5718 .01472 L
.57182 .01472 L
.57185 .01472 L
Mistroke
.57187 .01472 L
.57188 .01472 L
.57191 .01472 L
.57194 .01472 L
.57197 .01472 L
.57199 .01472 L
.572 .01472 L
.57203 .01472 L
.57206 .01472 L
.57209 .01472 L
.57211 .01472 L
.57214 .01472 L
.57217 .01472 L
.5722 .01472 L
.57222 .01472 L
.57223 .01472 L
.57226 .01472 L
.57228 .01472 L
.5723 .01472 L
.57233 .01472 L
.57236 .01472 L
.57239 .01472 L
.57241 .01472 L
.57244 .01472 L
.57247 .01472 L
.57249 .01472 L
.57252 .01472 L
.57254 .01472 L
.57257 .01472 L
.5726 .01472 L
.57263 .01472 L
.57266 .01472 L
.57268 .01472 L
.57271 .01472 L
.57274 .01472 L
.57277 .01472 L
.5728 .01472 L
.57282 .01472 L
.57285 .01472 L
.57289 .01472 L
.57291 .01472 L
.57293 .01472 L
.57295 .01472 L
.57296 .01472 L
.57298 .01472 L
.57301 .01472 L
.57304 .01472 L
.57307 .01472 L
.5731 .01472 L
.57313 .01472 L
Mistroke
.57315 .01472 L
.57318 .01472 L
.57321 .01472 L
.57323 .01472 L
.57327 .01472 L
.5733 .01472 L
.57332 .01472 L
.57335 .01472 L
.57338 .01472 L
.57341 .01472 L
.57344 .01472 L
.57347 .01472 L
.57349 .01472 L
.5735 .01472 L
.57353 .01472 L
.57355 .01472 L
.57357 .01472 L
.57358 .01472 L
.5736 .01472 L
.57363 .01472 L
.57365 .01472 L
.57366 .01472 L
.57368 .01472 L
.5737 .01472 L
.57372 .01472 L
.57373 .01472 L
.57375 .01472 L
.57377 .01472 L
.57379 .01472 L
.57383 .01472 L
.57385 .01472 L
.57389 .01472 L
.57392 .01472 L
.57394 .01472 L
.57397 .01472 L
.574 .01472 L
.57402 .01472 L
.57405 .01472 L
.57408 .01472 L
.57411 .01472 L
.57414 .01472 L
.57417 .01472 L
.5742 .01472 L
.57422 .01472 L
.57423 .01472 L
.57426 .01472 L
.57429 .01472 L
.57432 .01472 L
.57435 .01472 L
.57438 .01472 L
Mistroke
.5744 .01472 L
.57443 .01472 L
.57445 .01472 L
.57448 .01472 L
.57451 .01472 L
.57453 .01472 L
.57456 .01472 L
.57459 .01472 L
.57461 .01472 L
.57464 .01472 L
.57466 .01472 L
.57468 .01472 L
.5747 .01472 L
.57473 .01472 L
.57476 .01472 L
.57479 .01472 L
.57482 .01472 L
.57485 .01472 L
.57488 .01472 L
.5749 .01472 L
.57493 .01472 L
.57496 .01472 L
.57499 .01472 L
.57502 .01472 L
.57505 .01472 L
.57508 .01472 L
.57511 .01472 L
.57513 .01472 L
.57514 .01472 L
.57517 .01472 L
.5752 .01472 L
.57523 .01472 L
.57526 .01472 L
.57529 .01472 L
.57531 .01472 L
.57534 .01472 L
.57536 .01472 L
.57539 .01472 L
.57542 .01472 L
.57544 .01472 L
.57547 .01472 L
.5755 .01472 L
.57552 .01472 L
.57555 .01472 L
.57557 .01472 L
.57559 .01472 L
.57561 .01472 L
.57564 .01472 L
.57567 .01472 L
.57569 .01472 L
Mistroke
.57571 .01472 L
.57573 .01472 L
.57576 .01472 L
.57579 .01472 L
.57581 .01472 L
.57584 .01472 L
.57587 .01472 L
.5759 .01472 L
.57592 .01472 L
.57593 .01472 L
.57596 .01472 L
.57598 .01472 L
.576 .01472 L
.57603 .01472 L
.57606 .01472 L
.57609 .01472 L
.57612 .01472 L
.57614 .01472 L
.57617 .01472 L
.57619 .01472 L
.57622 .01472 L
.57624 .01472 L
.57627 .01472 L
.5763 .01472 L
.57633 .01472 L
.57636 .01472 L
.57639 .01472 L
.57641 .01472 L
.57644 .01472 L
.57647 .01472 L
.5765 .01472 L
.57653 .01472 L
.57656 .01472 L
.57659 .01472 L
.57662 .01472 L
.57663 .01472 L
.57665 .01472 L
.57666 .01472 L
.57668 .01472 L
.57671 .01472 L
.57674 .01472 L
.57677 .01472 L
.5768 .01472 L
.57683 .01472 L
.57686 .01472 L
.57688 .01472 L
.57691 .01472 L
.57694 .01472 L
.57697 .01472 L
.577 .01472 L
Mistroke
.57702 .01472 L
.57705 .01472 L
.57708 .01472 L
.57711 .01472 L
.57714 .01472 L
.57717 .01472 L
.57719 .01472 L
.57721 .01472 L
.57724 .01472 L
.57725 .01472 L
.57727 .01472 L
.57728 .01472 L
.5773 .01472 L
.57733 .01472 L
.57735 .01472 L
.57737 .01472 L
.57738 .01472 L
.5774 .01472 L
.57742 .01472 L
.57744 .01472 L
.57745 .01472 L
.57747 .01472 L
.5775 .01472 L
.57753 .01472 L
.57756 .01472 L
.57759 .01472 L
.57762 .01472 L
.57764 .01472 L
.57767 .01472 L
.5777 .01472 L
.57773 .01472 L
.57775 .01472 L
.57778 .01472 L
.57781 .01472 L
.57784 .01472 L
.57787 .01472 L
.5779 .01472 L
.57792 .01472 L
.57793 .01472 L
.57797 .01472 L
.578 .01472 L
.57802 .01472 L
.57805 .01472 L
.57808 .01472 L
.5781 .01472 L
.57813 .01472 L
.57815 .01472 L
.57818 .01472 L
.57821 .01472 L
.57823 .01472 L
Mistroke
.57826 .01472 L
.57829 .01472 L
.57832 .01472 L
.57834 .01472 L
.57836 .01472 L
.57838 .01472 L
.57841 .01472 L
.57844 .01472 L
.57846 .01472 L
.5785 .01472 L
.57853 .01472 L
.57855 .01472 L
.57858 .01472 L
.57861 .01472 L
.57863 .01472 L
.57866 .01472 L
.57869 .01472 L
.57872 .01472 L
.57875 .01472 L
.57878 .01472 L
.57881 .01472 L
.57883 .01472 L
.57884 .01472 L
.57888 .01472 L
.5789 .01472 L
.57893 .01472 L
.57896 .01472 L
.57899 .01472 L
.57901 .01472 L
.57904 .01472 L
.57906 .01472 L
.57909 .01472 L
.57912 .01472 L
.57914 .01472 L
.57917 .01472 L
.5792 .01472 L
.57923 .01472 L
.57925 .01472 L
.57927 .01472 L
.57929 .01472 L
.57931 .01472 L
.57934 .01472 L
.57937 .01472 L
.57941 .01472 L
.57944 .01472 L
.57946 .01472 L
.57949 .01472 L
.57952 .01472 L
.57954 .01472 L
.57957 .01472 L
Mistroke
.5796 .01472 L
.57963 .01472 L
.57966 .01472 L
.57969 .01472 L
.57972 .01472 L
.57974 .01472 L
.57975 .01472 L
.57979 .01472 L
.57982 .01472 L
.57984 .01472 L
.57987 .01472 L
.5799 .01472 L
.57993 .01472 L
.57995 .01472 L
.57997 .01472 L
.58 .01472 L
.58003 .01472 L
.58005 .01472 L
.58008 .01472 L
.58011 .01472 L
.58014 .01472 L
.58017 .01472 L
.58018 .01472 L
.5802 .01472 L
.58023 .01472 L
.58026 .01472 L
.58028 .01472 L
.5803 .01472 L
.58032 .01472 L
.58034 .01472 L
.58037 .01472 L
.5804 .01472 L
.58043 .01472 L
.58045 .01472 L
.58048 .01472 L
.58051 .01472 L
.58053 .01472 L
.58055 .01472 L
.58058 .01472 L
.58059 .01472 L
.58061 .01472 L
.58064 .01472 L
.58067 .01472 L
.5807 .01472 L
.58073 .01472 L
.58075 .01472 L
.58078 .01472 L
.58081 .01472 L
.58083 .01472 L
.58086 .01472 L
Mistroke
.58089 .01472 L
.58092 .01472 L
.58094 .01472 L
.58097 .01472 L
.581 .01472 L
.58102 .01472 L
.58105 .01472 L
.58108 .01472 L
.58111 .01472 L
.58114 .01472 L
.58117 .01472 L
.5812 .01472 L
.58123 .01472 L
.58124 .01472 L
.58126 .01472 L
.58128 .01472 L
.58129 .01472 L
.58132 .01472 L
.58135 .01472 L
.58138 .01472 L
.58141 .01472 L
.58144 .01472 L
.58147 .01472 L
.5815 .01472 L
.58152 .01472 L
.58155 .01472 L
.58158 .01472 L
.58161 .01472 L
.58164 .01472 L
.58167 .01472 L
.5817 .01472 L
.58173 .01472 L
.58175 .01472 L
.58179 .01472 L
.5818 .01472 L
.58182 .01472 L
.58185 .01472 L
.58186 .01472 L
.58188 .01472 L
.5819 .01472 L
.58192 .01472 L
.58195 .01472 L
.58196 .01472 L
.58198 .01472 L
.582 .01472 L
.58201 .01472 L
.58203 .01472 L
.58205 .01472 L
.58207 .01472 L
.58208 .01472 L
Mistroke
.58211 .01472 L
.58214 .01472 L
.58217 .01472 L
.5822 .01472 L
.58223 .01472 L
.58226 .01472 L
.58229 .01472 L
.58231 .01472 L
.58234 .01472 L
.58237 .01472 L
.5824 .01472 L
.58243 .01472 L
.58245 .01472 L
.58248 .01472 L
.58251 .01472 L
.58253 .01472 L
.58255 .01472 L
.58258 .01472 L
.58261 .01472 L
.58263 .01472 L
.58266 .01472 L
.58269 .01472 L
.58272 .01472 L
.58274 .01472 L
.58277 .01472 L
.58279 .01472 L
.58282 .01472 L
.58285 .01472 L
.58288 .01472 L
.5829 .01472 L
.58293 .01472 L
.58296 .01472 L
.58298 .01472 L
.58299 .01472 L
.58302 .01472 L
.58305 .01472 L
.58308 .01472 L
.58311 .01472 L
.58314 .01472 L
.58317 .01472 L
.5832 .01472 L
.58322 .01472 L
.58325 .01472 L
.58328 .01472 L
.58331 .01472 L
.58334 .01472 L
.58336 .01472 L
.58339 .01472 L
.58343 .01472 L
.58344 .01472 L
Mistroke
.58346 .01472 L
.58349 .01472 L
.58352 .01472 L
.58355 .01472 L
.58357 .01472 L
.5836 .01472 L
.58363 .01472 L
.58366 .01472 L
.58368 .01472 L
.58371 .01472 L
.58373 .01472 L
.58376 .01472 L
.58379 .01472 L
.58382 .01472 L
.58384 .01472 L
.58387 .01472 L
.58389 .01472 L
.5839 .01472 L
.58393 .01472 L
.58396 .01472 L
.58399 .01472 L
.58401 .01472 L
.58402 .01472 L
.58405 .01472 L
.58408 .01472 L
.58411 .01472 L
.58413 .01472 L
.58416 .01472 L
.58419 .01472 L
.58422 .01472 L
.58423 .01472 L
.58425 .01472 L
.58428 .01472 L
.5843 .01472 L
.58431 .01472 L
.58434 .01472 L
.58437 .01472 L
.5844 .01472 L
.58443 .01472 L
.58446 .01472 L
.58448 .01472 L
.58451 .01472 L
.58453 .01472 L
.58456 .01472 L
.58459 .01472 L
.58462 .01472 L
.58465 .01472 L
.58468 .01472 L
.5847 .01472 L
.58473 .01472 L
Mistroke
.58476 .01472 L
.58478 .01472 L
.58482 .01472 L
.58484 .01472 L
.58487 .01472 L
.5849 .01472 L
.58493 .01472 L
.58495 .01472 L
.58496 .01472 L
.58498 .01472 L
.585 .01472 L
.58503 .01472 L
.58506 .01472 L
.58509 .01472 L
.58512 .01472 L
.58514 .01472 L
.58517 .01472 L
.5852 .01472 L
.58522 .01472 L
.58525 .01472 L
.58528 .01472 L
.58531 .01472 L
.58534 .01472 L
.58537 .01472 L
.5854 .01472 L
.58543 .01472 L
.58546 .01472 L
.58549 .01472 L
.58551 .01472 L
.58552 .01472 L
.58555 .01472 L
.58557 .01472 L
.58559 .01472 L
.5856 .01472 L
.58562 .01472 L
.58565 .01472 L
.58567 .01472 L
.58568 .01472 L
.5857 .01472 L
.58572 .01472 L
.58573 .01472 L
.58575 .01472 L
.58577 .01472 L
.58578 .01472 L
.58581 .01472 L
.58584 .01472 L
.58587 .01472 L
.5859 .01472 L
.58593 .01472 L
.58596 .01472 L
Mistroke
.58599 .01472 L
.58601 .01472 L
.58604 .01472 L
.58607 .01472 L
.5861 .01472 L
.58613 .01472 L
.58616 .01472 L
.58619 .01472 L
.58622 .01472 L
.58624 .01472 L
.58625 .01472 L
.58628 .01472 L
.58631 .01472 L
.58634 .01472 L
.58637 .01472 L
.5864 .01472 L
.58642 .01472 L
.58645 .01472 L
.58647 .01472 L
.5865 .01472 L
.58652 .01472 L
.58655 .01472 L
.58658 .01472 L
.58661 .01472 L
.58663 .01472 L
.58666 .01472 L
.58668 .01472 L
.58669 .01472 L
.58672 .01472 L
.58675 .01472 L
.58678 .01472 L
.58681 .01472 L
.58684 .01472 L
.58687 .01472 L
.5869 .01472 L
.58692 .01472 L
.58695 .01472 L
.58698 .01472 L
.58701 .01472 L
.58704 .01472 L
.58707 .01472 L
.5871 .01472 L
.58713 .01472 L
.58715 .01472 L
.58716 .01472 L
.58719 .01472 L
.58722 .01472 L
.58725 .01472 L
.58728 .01472 L
.58731 .01472 L
Mistroke
.58733 .01472 L
.58736 .01472 L
.58738 .01472 L
.58741 .01472 L
.58743 .01472 L
.58746 .01472 L
.58749 .01472 L
.58752 .01472 L
.58754 .01472 L
.58757 .01472 L
.58759 .01472 L
.58761 .01472 L
.58763 .01472 L
.58766 .01472 L
.58769 .01472 L
.58771 .01472 L
.58772 .01472 L
.58775 .01472 L
.58778 .01472 L
.58781 .01472 L
.58783 .01472 L
.58786 .01472 L
.58789 .01472 L
.58792 .01472 L
.58794 .01472 L
.58795 .01472 L
.58798 .01472 L
.588 .01472 L
.58802 .01472 L
.58805 .01472 L
.58808 .01472 L
.58811 .01472 L
.58813 .01472 L
.58816 .01472 L
.58819 .01472 L
.58821 .01472 L
.58824 .01472 L
.58826 .01472 L
.58829 .01472 L
.58832 .01472 L
.58835 .01472 L
.58838 .01472 L
.58841 .01472 L
.58843 .01472 L
.58846 .01472 L
.58849 .01472 L
.58852 .01472 L
.58855 .01472 L
.58857 .01472 L
.58861 .01472 L
Mistroke
.58864 .01472 L
.58865 .01472 L
.58867 .01472 L
.58868 .01472 L
.5887 .01472 L
.58873 .01472 L
.58876 .01472 L
.58879 .01472 L
.58882 .01472 L
.58885 .01472 L
.58888 .01472 L
.5889 .01472 L
.58893 .01472 L
.58896 .01472 L
.58899 .01472 L
.58902 .01472 L
.58904 .01472 L
.58907 .01472 L
.5891 .01472 L
.58913 .01472 L
.58916 .01472 L
.58919 .01472 L
.58921 .01472 L
.58923 .01472 L
.58926 .01472 L
.58927 .01472 L
.58929 .01472 L
.5893 .01472 L
.58932 .01472 L
.58935 .01472 L
.58937 .01472 L
.58939 .01472 L
.5894 .01472 L
.58942 .01472 L
.58944 .01472 L
.58946 .01472 L
.58947 .01472 L
.58949 .01472 L
.58952 .01472 L
.58955 .01472 L
.58958 .01472 L
.58961 .01472 L
.58964 .01472 L
.58966 .01472 L
.58969 .01472 L
.58972 .01472 L
.58975 .01472 L
.58977 .01472 L
.5898 .01472 L
.58983 .01472 L
Mistroke
.58986 .01472 L
.58989 .01472 L
.58992 .01472 L
.58994 .01472 L
.58995 .01472 L
.58999 .01472 L
.59002 .01472 L
.59004 .01472 L
.59007 .01472 L
.5901 .01472 L
.59013 .01472 L
.59015 .01472 L
.59017 .01472 L
.5902 .01472 L
.59023 .01472 L
.59025 .01472 L
.59028 .01472 L
.59031 .01472 L
.59034 .01472 L
.59037 .01472 L
.59038 .01472 L
.5904 .01472 L
.59043 .01472 L
.59046 .01472 L
.59048 .01472 L
.59052 .01472 L
.59055 .01472 L
.59057 .01472 L
.5906 .01472 L
.59063 .01472 L
.59066 .01472 L
.59068 .01472 L
.59071 .01472 L
.59074 .01472 L
.59077 .01472 L
.5908 .01472 L
.59083 .01472 L
.59085 .01472 L
.59086 .01472 L
.5909 .01472 L
.59093 .01472 L
.59095 .01472 L
.59098 .01472 L
.59101 .01472 L
.59104 .01472 L
.59106 .01472 L
.59108 .01472 L
.59111 .01472 L
.59114 .01472 L
.59116 .01472 L
Mistroke
.59119 .01472 L
.59122 .01472 L
.59125 .01472 L
.59128 .01472 L
.59129 .01472 L
.59131 .01472 L
.59134 .01472 L
.59137 .01472 L
.59139 .01472 L
.59141 .01472 L
.59143 .01472 L
.59145 .01472 L
.59148 .01472 L
.59151 .01472 L
.59154 .01472 L
.59156 .01472 L
.59159 .01472 L
.59162 .01472 L
.59164 .01472 L
.59165 .01472 L
.59169 .01472 L
.5917 .01472 L
.59172 .01472 L
.59175 .01472 L
.59178 .01472 L
.59181 .01472 L
.59184 .01472 L
.59186 .01472 L
.59189 .01472 L
.59191 .01472 L
.59194 .01472 L
.59197 .01472 L
.592 .01472 L
.59202 .01472 L
.59205 .01472 L
.59208 .01472 L
.59211 .01472 L
.59213 .01472 L
.59216 .01472 L
.59219 .01472 L
.59222 .01472 L
.59225 .01472 L
.59228 .01472 L
.59231 .01472 L
.59234 .01472 L
.59235 .01472 L
.59237 .01472 L
.59239 .01472 L
.5924 .01472 L
.59243 .01472 L
Mistroke
.59246 .01472 L
.59249 .01472 L
.59252 .01472 L
.59255 .01472 L
.59258 .01472 L
.5926 .01472 L
.59263 .01472 L
.59266 .01472 L
.59269 .01472 L
.59272 .01472 L
.59275 .01472 L
.59277 .01472 L
.59281 .01472 L
.59284 .01472 L
.59286 .01472 L
.59289 .01472 L
.59291 .01472 L
.59293 .01472 L
.59296 .01472 L
.59297 .01472 L
.59299 .01472 L
.59301 .01472 L
.59302 .01472 L
.59305 .01472 L
.59307 .01472 L
.59309 .01472 L
.5931 .01472 L
.59312 .01472 L
.59314 .01472 L
.59316 .01472 L
.59317 .01472 L
.59319 .01472 L
.59322 .01472 L
.59325 .01472 L
.59328 .01472 L
.59331 .01472 L
.59334 .01472 L
.59337 .01472 L
.59339 .01472 L
.59342 .01472 L
.59345 .01472 L
.59347 .01472 L
.5935 .01472 L
.59353 .01472 L
.59356 .01472 L
.59359 .01472 L
.59362 .01472 L
.59364 .01472 L
.59366 .01472 L
.59369 .01472 L
Mistroke
.59372 .01472 L
.59374 .01472 L
.59377 .01472 L
.5938 .01472 L
.59383 .01472 L
.59385 .01472 L
.59388 .01472 L
.5939 .01472 L
.59393 .01472 L
.59396 .01472 L
.59398 .01472 L
.59401 .01472 L
.59404 .01472 L
.59407 .01472 L
.59408 .01472 L
.5941 .01472 L
.59413 .01472 L
.59416 .01472 L
.59419 .01472 L
.59422 .01472 L
.59425 .01472 L
.59427 .01472 L
.5943 .01472 L
.59433 .01472 L
.59436 .01472 L
.59438 .01472 L
.59441 .01472 L
.59444 .01472 L
.59447 .01472 L
.5945 .01472 L
.59453 .01472 L
.59455 .01472 L
.59457 .01472 L
.5946 .01472 L
.59463 .01472 L
.59465 .01472 L
.59468 .01472 L
.59471 .01472 L
.59474 .01472 L
.59476 .01472 L
.59478 .01472 L
.59481 .01472 L
.59484 .01472 L
.59486 .01472 L
.59489 .01472 L
.59492 .01472 L
.59495 .01472 L
.59498 .01472 L
.59499 .01472 L
.59501 .01472 L
Mistroke
.59504 .01472 L
.59507 .01472 L
.5951 .01472 L
.59513 .01472 L
.59516 .01472 L
.59519 .01472 L
.59521 .01472 L
.59524 .01472 L
.59527 .01472 L
.59529 .01472 L
.59532 .01472 L
.59535 .01472 L
.59538 .01472 L
.59541 .01472 L
.59544 .01472 L
.59546 .01472 L
.59548 .01472 L
.59551 .01472 L
.59554 .01472 L
.59556 .01472 L
.59559 .01472 L
.59562 .01472 L
.59565 .01472 L
.59567 .01472 L
.5957 .01472 L
.59572 .01472 L
.59575 .01472 L
.59578 .01472 L
.59581 .01472 L
.59583 .01472 L
.59586 .01472 L
.59589 .01472 L
.5959 .01472 L
.59592 .01472 L
.59595 .01472 L
.59598 .01472 L
.59601 .01472 L
.59602 .01472 L
.59604 .01472 L
.59607 .01472 L
.5961 .01472 L
.59612 .01472 L
.59615 .01472 L
.59618 .01472 L
.59621 .01472 L
.59623 .01472 L
.59625 .01472 L
.59627 .01472 L
.5963 .01472 L
.59632 .01472 L
Mistroke
.59633 .01472 L
.59636 .01472 L
.59639 .01472 L
.59642 .01472 L
.59645 .01472 L
.59647 .01472 L
.5965 .01472 L
.59653 .01472 L
.59655 .01472 L
.59658 .01472 L
.59661 .01472 L
.59664 .01472 L
.59666 .01472 L
.59669 .01472 L
.59672 .01472 L
.59675 .01472 L
.59677 .01472 L
.5968 .01472 L
.59683 .01472 L
.59686 .01472 L
.59689 .01472 L
.59692 .01472 L
.59695 .01472 L
.59697 .01472 L
.59698 .01472 L
.597 .01472 L
.59702 .01472 L
.59705 .01472 L
.59707 .01472 L
.5971 .01472 L
.59714 .01472 L
.59716 .01472 L
.59719 .01472 L
.59722 .01472 L
.59724 .01472 L
.59727 .01472 L
.5973 .01472 L
.59733 .01472 L
.59736 .01472 L
.59739 .01472 L
.59742 .01472 L
.59745 .01472 L
.59748 .01472 L
.59751 .01472 L
.59752 .01472 L
.59754 .01472 L
.59757 .01472 L
.59759 .01472 L
.5976 .01472 L
.59762 .01472 L
Mistroke
.59764 .01472 L
.59767 .01472 L
.59768 .01472 L
.5977 .01472 L
.59772 .01472 L
.59774 .01472 L
.59775 .01472 L
.59777 .01472 L
.59779 .01472 L
.5978 .01472 L
.59783 .01472 L
.59786 .01472 L
.59789 .01472 L
.59792 .01472 L
.59795 .01472 L
.59798 .01472 L
.59801 .01472 L
.59803 .01472 L
.59806 .01472 L
.59809 .01472 L
.59812 .01472 L
.59815 .01472 L
.59818 .01472 L
.59821 .01472 L
.59824 .01472 L
.59825 .01472 L
.59827 .01472 L
.5983 .01472 L
.59833 .01472 L
.59836 .01472 L
.59838 .01472 L
.59841 .01472 L
.59844 .01472 L
.59847 .01472 L
.59849 .01472 L
.59852 .01472 L
.59854 .01472 L
.59857 .01472 L
.5986 .01472 L
.59863 .01472 L
.59865 .01472 L
.59868 .01472 L
.5987 .01472 L
.59871 .01472 L
.59874 .01472 L
.59877 .01472 L
.5988 .01472 L
.59883 .01472 L
.59886 .01472 L
.59889 .01472 L
Mistroke
.59892 .01472 L
.59894 .01472 L
.59897 .01472 L
.599 .01472 L
.59903 .01472 L
.59906 .01472 L
.59909 .01472 L
.59912 .01472 L
.59915 .01472 L
.59916 .01472 L
.59918 .01472 L
.59921 .01472 L
.59924 .01472 L
.59927 .01472 L
.5993 .01472 L
.59932 .01472 L
.59935 .01472 L
.59938 .01472 L
.5994 .01472 L
.59943 .01472 L
.59945 .01472 L
.59948 .01472 L
.59951 .01472 L
.59954 .01472 L
.59956 .01472 L
.59959 .01472 L
.59961 .01472 L
.59962 .01472 L
.59965 .01472 L
.59968 .01472 L
.59971 .01472 L
.59973 .01472 L
.59974 .01472 L
.59977 .01472 L
.5998 .01472 L
.59983 .01472 L
.59985 .01472 L
.59988 .01472 L
.59991 .01472 L
.59994 .01472 L
.59996 .01472 L
.59997 .01472 L
.6 .01472 L
.60002 .01472 L
.60004 .01472 L
.60007 .01472 L
.6001 .01472 L
.60013 .01472 L
.60015 .01472 L
.60018 .01472 L
Mistroke
.60021 .01472 L
.60023 .01472 L
.60026 .01472 L
.60028 .01472 L
.60031 .01472 L
.60034 .01472 L
.60037 .01472 L
.6004 .01472 L
.60043 .01472 L
.60045 .01472 L
.60048 .01472 L
.60051 .01472 L
.60054 .01472 L
.60056 .01472 L
.60059 .01472 L
.60063 .01472 L
.60065 .01472 L
.60067 .01472 L
.60069 .01472 L
.6007 .01472 L
.60072 .01472 L
.60075 .01472 L
.60078 .01472 L
.60081 .01472 L
.60084 .01472 L
.60087 .01472 L
.6009 .01472 L
.60092 .01472 L
.60095 .01472 L
.60098 .01472 L
.60101 .01472 L
.60104 .01472 L
.60106 .01472 L
.60109 .01472 L
.60112 .01472 L
.60115 .01472 L
.60118 .01472 L
.60121 .01472 L
.60123 .01472 L
.60125 .01472 L
.60128 .01472 L
.60129 .01472 L
.60131 .01472 L
.60132 .01472 L
.60134 .01472 L
.60137 .01472 L
.60139 .01472 L
.6014 .01472 L
.60142 .01472 L
.60144 .01472 L
Mistroke
.60146 .01472 L
.60147 .01472 L
.60149 .01472 L
.60151 .01472 L
.60154 .01472 L
.60157 .01472 L
.6016 .01472 L
.60163 .01472 L
.60166 .01472 L
.60168 .01472 L
.60171 .01472 L
.60174 .01472 L
.60177 .01472 L
.60179 .01472 L
.60182 .01472 L
.60185 .01472 L
.60188 .01472 L
.60191 .01472 L
.60194 .01472 L
.60196 .01472 L
.60197 .01472 L
.60201 .01472 L
.60204 .01472 L
.60206 .01472 L
.60209 .01472 L
.60212 .01472 L
.60215 .01472 L
.60217 .01472 L
.60219 .01472 L
.60222 .01472 L
.60225 .01472 L
.60227 .01472 L
.6023 .01472 L
.60233 .01472 L
.60236 .01472 L
.60239 .01472 L
.6024 .01472 L
.60242 .01472 L
.60245 .01472 L
.60248 .01472 L
.6025 .01472 L
.60254 .01472 L
.60257 .01472 L
.60259 .01472 L
.60262 .01472 L
.60265 .01472 L
.60268 .01472 L
.6027 .01472 L
.60273 .01472 L
.60276 .01472 L
Mistroke
.60279 .01472 L
.60282 .01472 L
.60285 .01472 L
.60287 .01472 L
.60288 .01472 L
.60292 .01472 L
.60295 .01472 L
.60297 .01472 L
.603 .01472 L
.60303 .01472 L
.60306 .01472 L
.60308 .01472 L
.6031 .01472 L
.60313 .01472 L
.60316 .01472 L
.60318 .01472 L
.60321 .01472 L
.60324 .01472 L
.60327 .01472 L
.6033 .01472 L
.60331 .01472 L
.60333 .01472 L
.60336 .01472 L
.60339 .01472 L
.60341 .01472 L
.60343 .01472 L
.60345 .01472 L
.60347 .01472 L
.6035 .01472 L
.60353 .01472 L
.60356 .01472 L
.60358 .01472 L
.60361 .01472 L
.60364 .01472 L
.60366 .01472 L
.60368 .01472 L
.60371 .01472 L
.60372 .01472 L
.60374 .01472 L
.60377 .01472 L
.6038 .01472 L
.60383 .01472 L
.60386 .01472 L
.60388 .01472 L
.60391 .01472 L
.60394 .01472 L
.60396 .01472 L
.60399 .01472 L
.60402 .01472 L
.60404 .01472 L
Mistroke
.60407 .01472 L
.6041 .01472 L
.60413 .01472 L
.60415 .01472 L
.60418 .01472 L
.60421 .01472 L
.60424 .01472 L
.60427 .01472 L
.6043 .01472 L
.60433 .01472 L
.60436 .01472 L
.60437 .01472 L
.60439 .01472 L
.60441 .01472 L
.60442 .01472 L
.60445 .01472 L
.60448 .01472 L
.60451 .01472 L
.60454 .01472 L
.60457 .01472 L
.6046 .01472 L
.60463 .01472 L
.60465 .01472 L
.60468 .01472 L
.60471 .01472 L
.60474 .01472 L
.60477 .01472 L
.6048 .01472 L
.60483 .01472 L
.60486 .01472 L
.60488 .01472 L
.60491 .01472 L
.60493 .01472 L
.60495 .01472 L
.60498 .01472 L
.605 .01472 L
.60501 .01472 L
.60503 .01472 L
.60504 .01472 L
.60507 .01472 L
.60509 .01472 L
.60511 .01472 L
.60513 .01472 L
.60514 .01472 L
.60516 .01472 L
.60518 .01472 L
.60519 .01472 L
.60521 .01472 L
.60524 .01472 L
.60527 .01472 L
Mistroke
.6053 .01472 L
.60533 .01472 L
.60536 .01472 L
.60539 .01472 L
.60541 .01472 L
.60544 .01472 L
.60547 .01472 L
.6055 .01472 L
.60552 .01472 L
.60556 .01472 L
.60558 .01472 L
.60561 .01472 L
.60564 .01472 L
.60566 .01472 L
.60568 .01472 L
.60571 .01472 L
.60574 .01472 L
.60576 .01472 L
.60579 .01472 L
.60582 .01472 L
.60585 .01472 L
.60587 .01472 L
.6059 .01472 L
.60592 .01472 L
.60595 .01472 L
.60598 .01472 L
.60601 .01472 L
.60603 .01472 L
.60606 .01472 L
.60609 .01472 L
.6061 .01472 L
.60612 .01472 L
.60615 .01472 L
.60618 .01472 L
.60621 .01472 L
.60624 .01472 L
.60627 .01472 L
.6063 .01472 L
.60632 .01472 L
.60635 .01472 L
.60638 .01472 L
.6064 .01472 L
.60643 .01472 L
.60647 .01472 L
.60649 .01472 L
.60652 .01472 L
.60655 .01472 L
.60657 .01472 L
.60659 .01472 L
.60662 .01472 L
Mistroke
.60665 .01472 L
.60667 .01472 L
.6067 .01472 L
.60673 .01472 L
.60676 .01472 L
.60678 .01472 L
.60681 .01472 L
.60683 .01472 L
.60686 .01472 L
.60689 .01472 L
.60692 .01472 L
.60694 .01472 L
.60697 .01472 L
.607 .01472 L
.60701 .01472 L
.60703 .01472 L
.60706 .01472 L
.60709 .01472 L
.60712 .01472 L
.60713 .01472 L
.60715 .01472 L
.60718 .01472 L
.60721 .01472 L
.60723 .01472 L
.60726 .01472 L
.60729 .01472 L
.60732 .01472 L
.60734 .01472 L
.60736 .01472 L
.60738 .01472 L
.60741 .01472 L
.60743 .01472 L
.60744 .01472 L
.60747 .01472 L
.6075 .01472 L
.60753 .01472 L
.60756 .01472 L
.60758 .01472 L
.60761 .01472 L
.60764 .01472 L
.60766 .01472 L
.60769 .01472 L
.60772 .01472 L
.60775 .01472 L
.60777 .01472 L
.6078 .01472 L
.60783 .01472 L
.60786 .01472 L
.60788 .01472 L
.60791 .01472 L
Mistroke
.60794 .01472 L
.60797 .01472 L
.608 .01472 L
.60803 .01472 L
.60806 .01472 L
.60807 .01472 L
.60809 .01472 L
.60811 .01472 L
.60813 .01472 L
.60816 .01472 L
.60818 .01472 L
.60821 .01472 L
.60824 .01472 L
.60827 .01472 L
.6083 .01472 L
.60833 .01472 L
.60835 .01472 L
.60838 .01472 L
.60841 .01472 L
.60844 .01472 L
.60847 .01472 L
.6085 .01472 L
.60853 .01472 L
.60856 .01472 L
.60858 .01472 L
.60862 .01472 L
.60863 .01472 L
.60865 .01472 L
.60868 .01472 L
.6087 .01472 L
.60871 .01472 L
.60873 .01472 L
.60875 .01472 L
.60878 .01472 L
.60879 .01472 L
.60881 .01472 L
.60883 .01472 L
.60885 .01472 L
.60886 .01472 L
.60888 .01472 L
.6089 .01472 L
.60891 .01472 L
.60894 .01472 L
.60897 .01472 L
.609 .01472 L
.60903 .01472 L
.60906 .01472 L
.60909 .01472 L
.60912 .01472 L
.60914 .01472 L
Mistroke
.60917 .01472 L
.6092 .01472 L
.60923 .01472 L
.60926 .01472 L
.60928 .01472 L
.60931 .01472 L
.60935 .01472 L
.60936 .01472 L
.60938 .01472 L
.60941 .01472 L
.60944 .01472 L
.60947 .01472 L
.60949 .01472 L
.60952 .01472 L
.60955 .01472 L
.60957 .01472 L
.6096 .01472 L
.60962 .01472 L
.60965 .01472 L
.60968 .01472 L
.60971 .01472 L
.60973 .01472 L
.60976 .01472 L
.60979 .01472 L
.60981 .01472 L
.60982 .01472 L
.60985 .01472 L
.60988 .01472 L
.60991 .01472 L
.60994 .01472 L
.60997 .01472 L
.61 .01472 L
.61003 .01472 L
.61005 .01472 L
.61008 .01472 L
.61011 .01472 L
.61014 .01472 L
.61017 .01472 L
.61019 .01472 L
.61022 .01472 L
.61025 .01472 L
.61027 .01472 L
.61029 .01472 L
.61032 .01472 L
.61035 .01472 L
.61037 .01472 L
.6104 .01472 L
.61043 .01472 L
.61046 .01472 L
.61048 .01472 L
Mistroke
.61051 .01472 L
.61053 .01472 L
.61056 .01472 L
.61059 .01472 L
.61062 .01472 L
.61064 .01472 L
.61067 .01472 L
.6107 .01472 L
.61072 .01472 L
.61073 .01472 L
.61076 .01472 L
.61079 .01472 L
.61082 .01472 L
.61085 .01472 L
.61088 .01472 L
.61091 .01472 L
.61093 .01472 L
.61096 .01472 L
.61099 .01472 L
.61102 .01472 L
.61105 .01472 L
.61108 .01472 L
.6111 .01472 L
.61113 .01472 L
.61117 .01472 L
.61118 .01472 L
.6112 .01472 L
.61123 .01472 L
.61126 .01472 L
.61129 .01472 L
.61131 .01472 L
.61134 .01472 L
.61137 .01472 L
.6114 .01472 L
.61142 .01472 L
.61145 .01472 L
.61147 .01472 L
.6115 .01472 L
.61153 .01472 L
.61156 .01472 L
.61158 .01472 L
.61161 .01472 L
.61163 .01472 L
.61164 .01472 L
.61167 .01472 L
.6117 .01472 L
.61173 .01472 L
.61175 .01472 L
.61176 .01472 L
.61179 .01472 L
Mistroke
.61182 .01472 L
.61185 .01472 L
.61187 .01472 L
.6119 .01472 L
.61193 .01472 L
.61196 .01472 L
.61197 .01472 L
.61199 .01472 L
.61202 .01472 L
.61204 .01472 L
.61206 .01472 L
.61208 .01472 L
.61212 .01472 L
.61214 .01472 L
.61217 .01472 L
.6122 .01472 L
.61222 .01472 L
.61225 .01472 L
.61227 .01472 L
.6123 .01472 L
.61233 .01472 L
.61236 .01472 L
.61239 .01472 L
.61242 .01472 L
.61244 .01472 L
.61247 .01472 L
.6125 .01472 L
.61253 .01472 L
.61256 .01472 L
.61258 .01472 L
.61261 .01472 L
.61264 .01472 L
.61267 .01472 L
.61269 .01472 L
.61271 .01472 L
.61272 .01472 L
.61274 .01472 L
.61277 .01472 L
.6128 .01472 L
.61283 .01472 L
.61286 .01472 L
.61289 .01472 L
.61291 .01472 L
.61294 .01472 L
.61297 .01472 L
.61299 .01472 L
.61303 .01472 L
.61306 .01472 L
.61308 .01472 L
.61311 .01472 L
Mistroke
.61314 .01472 L
.61317 .01472 L
.6132 .01472 L
.61323 .01472 L
.61325 .01472 L
.61326 .01472 L
.61329 .01472 L
.61331 .01472 L
.61333 .01472 L
.61334 .01472 L
.61336 .01472 L
.61339 .01472 L
.61341 .01472 L
.61342 .01472 L
.61344 .01472 L
.61346 .01472 L
.61348 .01472 L
.61349 .01472 L
.61351 .01472 L
.61353 .01472 L
.61355 .01472 L
.61359 .01472 L
.61361 .01472 L
.61365 .01472 L
.61368 .01472 L
.6137 .01472 L
.61373 .01472 L
.61376 .01472 L
.61378 .01472 L
.61381 .01472 L
.61384 .01472 L
.61387 .01472 L
.6139 .01472 L
.61393 .01472 L
.61396 .01472 L
.61398 .01472 L
.61399 .01472 L
.61403 .01472 L
.61405 .01472 L
.61408 .01472 L
.61411 .01472 L
.61414 .01472 L
.61416 .01472 L
.61419 .01472 L
.61421 .01472 L
.61424 .01472 L
.61427 .01472 L
.61429 .01472 L
.61432 .01472 L
.61435 .01472 L
Mistroke
.61437 .01472 L
.6144 .01472 L
.61442 .01472 L
.61444 .01472 L
.61446 .01472 L
.61449 .01472 L
.61452 .01472 L
.61456 .01472 L
.61459 .01472 L
.61461 .01472 L
.61464 .01472 L
.61467 .01472 L
.61469 .01472 L
.61472 .01472 L
.61475 .01472 L
.61478 .01472 L
.61481 .01472 L
.61484 .01472 L
.61487 .01472 L
.61489 .01472 L
.6149 .01472 L
.61494 .01472 L
.61497 .01472 L
.61499 .01472 L
.61502 .01472 L
.61505 .01472 L
.61507 .01472 L
.6151 .01472 L
.61512 .01472 L
.61515 .01472 L
.61518 .01472 L
.6152 .01472 L
.61523 .01472 L
.61526 .01472 L
.61529 .01472 L
.61532 .01472 L
.61533 .01472 L
.61535 .01472 L
.61538 .01472 L
.61541 .01472 L
.61543 .01472 L
.61545 .01472 L
.61547 .01472 L
.61549 .01472 L
.61552 .01472 L
.61555 .01472 L
.61558 .01472 L
.6156 .01472 L
.61563 .01472 L
.61566 .01472 L
Mistroke
.61568 .01472 L
.61569 .01472 L
.61573 .01472 L
.61574 .01472 L
.61576 .01472 L
.61579 .01472 L
.61582 .01472 L
.61585 .01472 L
.61588 .01472 L
.6159 .01472 L
.61593 .01472 L
.61596 .01472 L
.61598 .01472 L
.61601 .01472 L
.61604 .01472 L
.61606 .01472 L
.61609 .01472 L
.61612 .01472 L
.61615 .01472 L
.61617 .01472 L
.6162 .01472 L
.61623 .01472 L
.61626 .01472 L
.61629 .01472 L
.61632 .01472 L
.61635 .01472 L
.61638 .01472 L
.61639 .01472 L
.61641 .01472 L
.61643 .01472 L
.61644 .01472 L
.61647 .01472 L
.6165 .01472 L
.61653 .01472 L
.61656 .01472 L
.61659 .01472 L
.61662 .01472 L
.61665 .01472 L
.61667 .01472 L
.6167 .01472 L
.61673 .01472 L
.61676 .01472 L
.61679 .01472 L
.61682 .01472 L
.61685 .01472 L
.61688 .01472 L
.6169 .01472 L
.61693 .01472 L
.61695 .01472 L
.61697 .01472 L
Mistroke
.617 .01472 L
.61701 .01472 L
.61703 .01472 L
.61705 .01472 L
.61706 .01472 L
.6171 .01472 L
.61711 .01472 L
.61713 .01472 L
.61715 .01472 L
.61716 .01472 L
.61718 .01472 L
.6172 .01472 L
.61721 .01472 L
.61723 .01472 L
.61726 .01472 L
.61729 .01472 L
.61732 .01472 L
.61735 .01472 L
.61738 .01472 L
.61741 .01472 L
.61744 .01472 L
.61746 .01472 L
.61749 .01472 L
.61752 .01472 L
.61755 .01472 L
.61758 .01472 L
.6176 .01472 L
.61763 .01472 L
.61766 .01472 L
.61768 .01472 L
.6177 .01472 L
.61773 .01472 L
.61776 .01472 L
.61778 .01472 L
.61781 .01472 L
.61784 .01472 L
.61787 .01472 L
.61789 .01472 L
.61792 .01472 L
.61794 .01472 L
.61797 .01472 L
.618 .01472 L
.61803 .01472 L
.61805 .01472 L
.61808 .01472 L
.61811 .01472 L
.61813 .01472 L
.61814 .01472 L
.61817 .01472 L
.6182 .01472 L
Mistroke
.61823 .01472 L
.61826 .01472 L
.61829 .01472 L
.61832 .01472 L
.61834 .01472 L
.61837 .01472 L
.6184 .01472 L
.61843 .01472 L
.61846 .01472 L
.61849 .01472 L
.61851 .01472 L
.61854 .01472 L
.61857 .01472 L
.61859 .01472 L
.61861 .01472 L
.61864 .01472 L
.61867 .01472 L
.61869 .01472 L
.61872 .01472 L
.61875 .01472 L
.61878 .01472 L
.6188 .01472 L
.61883 .01472 L
.61885 .01472 L
.61888 .01472 L
.61891 .01472 L
.61894 .01472 L
.61896 .01472 L
.61899 .01472 L
.61902 .01472 L
.61904 .01472 L
.61905 .01472 L
.61908 .01472 L
.61911 .01472 L
.61914 .01472 L
.61915 .01472 L
.61917 .01472 L
.6192 .01472 L
.61923 .01472 L
.61925 .01472 L
.61928 .01472 L
.61931 .01472 L
.61934 .01472 L
.61937 .01472 L
.61938 .01472 L
.6194 .01472 L
.61943 .01472 L
.61945 .01472 L
.61946 .01472 L
.61949 .01472 L
Mistroke
.61952 .01472 L
.61955 .01472 L
.61958 .01472 L
.61961 .01472 L
.61963 .01472 L
.61966 .01472 L
.61968 .01472 L
.61971 .01472 L
.61974 .01472 L
.61977 .01472 L
.61979 .01472 L
.61982 .01472 L
.61985 .01472 L
.61988 .01472 L
.6199 .01472 L
.61993 .01472 L
.61996 .01472 L
.61999 .01472 L
.62002 .01472 L
.62005 .01472 L
.62008 .01472 L
.6201 .01472 L
.62011 .01472 L
.62013 .01472 L
.62015 .01472 L
.62018 .01472 L
.6202 .01472 L
.62023 .01472 L
.62027 .01472 L
.62029 .01472 L
.62032 .01472 L
.62035 .01472 L
.62037 .01472 L
.6204 .01472 L
.62043 .01472 L
.62046 .01472 L
.62049 .01472 L
.62052 .01472 L
.62055 .01472 L
.62058 .01472 L
.62061 .01472 L
.62064 .01472 L
.62066 .01472 L
.62067 .01472 L
.6207 .01472 L
.62072 .01472 L
.62073 .01472 L
.62075 .01472 L
.62077 .01472 L
.6208 .01472 L
Mistroke
.62082 .01472 L
.62083 .01472 L
.62085 .01472 L
.62087 .01472 L
.62088 .01472 L
.6209 .01472 L
.62092 .01472 L
.62093 .01472 L
.62096 .01472 L
.62099 .01472 L
.62102 .01472 L
.62105 .01472 L
.62108 .01472 L
.62111 .01472 L
.62114 .01472 L
.62116 .01472 L
.62119 .01472 L
.62122 .01472 L
.62125 .01472 L
.62128 .01472 L
.62131 .01472 L
.62134 .01472 L
.62137 .01472 L
.62138 .01472 L
.6214 .01472 L
.62143 .01472 L
.62146 .01472 L
.62149 .01472 L
.62152 .01472 L
.62154 .01472 L
.62157 .01472 L
.6216 .01472 L
.62162 .01472 L
.62165 .01472 L
.62167 .01472 L
.6217 .01472 L
.62173 .01472 L
.62176 .01472 L
.62178 .01472 L
.62181 .01472 L
.62183 .01472 L
.62184 .01472 L
.62187 .01472 L
.6219 .01472 L
.62193 .01472 L
.62196 .01472 L
.62199 .01472 L
.62202 .01472 L
.62205 .01472 L
.62207 .01472 L
Mistroke
.6221 .01472 L
.62213 .01472 L
.62216 .01472 L
.62219 .01472 L
.62222 .01472 L
.62225 .01472 L
.62228 .01472 L
.62229 .01472 L
.62231 .01472 L
.62234 .01472 L
.62237 .01472 L
.6224 .01472 L
.62243 .01472 L
.62245 .01472 L
.62248 .01472 L
.62251 .01472 L
.62253 .01472 L
.62256 .01472 L
.62258 .01472 L
.62261 .01472 L
.62264 .01472 L
.62267 .01472 L
.62269 .01472 L
.62272 .01472 L
.62274 .01472 L
.62275 .01472 L
.62278 .01472 L
.62281 .01472 L
.62284 .01472 L
.62286 .01472 L
.62287 .01472 L
.6229 .01472 L
.62293 .01472 L
.62296 .01472 L
.62298 .01472 L
.62301 .01472 L
.62304 .01472 L
.62307 .01472 L
.62309 .01472 L
.6231 .01472 L
.62313 .01472 L
.62315 .01472 L
.62317 .01472 L
.6232 .01472 L
.62323 .01472 L
.62326 .01472 L
.62328 .01472 L
.62331 .01472 L
.62334 .01472 L
.62336 .01472 L
Mistroke
.62338 .01472 L
.62341 .01472 L
.62344 .01472 L
.62347 .01472 L
.6235 .01472 L
.62353 .01472 L
.62355 .01472 L
.62358 .01472 L
.62361 .01472 L
.62364 .01472 L
.62367 .01472 L
.62369 .01472 L
.62372 .01472 L
.62375 .01472 L
.62378 .01472 L
.6238 .01472 L
.62382 .01472 L
.62383 .01472 L
.62385 .01472 L
.62388 .01472 L
.62391 .01472 L
.62394 .01472 L
.62397 .01472 L
.624 .01472 L
.62402 .01472 L
.62405 .01472 L
.62408 .01472 L
.6241 .01472 L
.62414 .01472 L
.62417 .01472 L
.62419 .01472 L
.62422 .01472 L
.62425 .01472 L
.62428 .01472 L
.62431 .01472 L
.62434 .01472 L
.62436 .01472 L
.62437 .01472 L
.6244 .01472 L
.62442 .01472 L
.62444 .01472 L
.62445 .01472 L
.62447 .01472 L
.6245 .01472 L
.62452 .01472 L
.62453 .01472 L
.62455 .01472 L
.62457 .01472 L
.62459 .01472 L
.6246 .01472 L
Mistroke
.62462 .01472 L
.62464 .01472 L
.62466 .01472 L
.62469 .01472 L
.62472 .01472 L
.62476 .01472 L
.62479 .01472 L
.62481 .01472 L
.62484 .01472 L
.62487 .01472 L
.62489 .01472 L
.62492 .01472 L
.62495 .01472 L
.62498 .01472 L
.62501 .01472 L
.62504 .01472 L
.62507 .01472 L
.62509 .01472 L
.6251 .01472 L
.62513 .01472 L
.62516 .01472 L
.62519 .01472 L
.62522 .01472 L
.62525 .01472 L
.62527 .01472 L
.6253 .01472 L
.62532 .01472 L
.62535 .01472 L
.62537 .01472 L
.6254 .01472 L
.62543 .01472 L
.62546 .01472 L
.62548 .01472 L
.62551 .01472 L
.62553 .01472 L
.62555 .01472 L
.62557 .01472 L
.6256 .01472 L
.62563 .01472 L
.62566 .01472 L
.62569 .01472 L
.62572 .01472 L
.62575 .01472 L
.62577 .01472 L
.6258 .01472 L
.62583 .01472 L
.62586 .01472 L
.62589 .01472 L
.62592 .01472 L
.62595 .01472 L
Mistroke
.62598 .01472 L
.626 .01472 L
.62601 .01472 L
.62604 .01472 L
.62607 .01472 L
.6261 .01472 L
.62613 .01472 L
.62616 .01472 L
.62618 .01472 L
.62621 .01472 L
.62623 .01472 L
.62626 .01472 L
.62628 .01472 L
.62631 .01472 L
.62634 .01472 L
.62637 .01472 L
.62639 .01472 L
.62642 .01472 L
.62644 .01472 L
.62646 .01472 L
.62648 .01472 L
.62651 .01472 L
.62654 .01472 L
.62657 .01472 L
.6266 .01472 L
.62663 .01472 L
.62666 .01472 L
.62668 .01472 L
.62671 .01472 L
.62674 .01472 L
.62677 .01472 L
.6268 .01472 L
.62683 .01472 L
.62686 .01472 L
.62689 .01472 L
.62691 .01472 L
.62692 .01472 L
.62695 .01472 L
.62698 .01472 L
.62701 .01472 L
.62704 .01472 L
.62707 .01472 L
.62709 .01472 L
.62712 .01472 L
.62714 .01472 L
.62717 .01472 L
.6272 .01472 L
.62722 .01472 L
.62725 .01472 L
.62728 .01472 L
Mistroke
.6273 .01472 L
.62733 .01472 L
.62735 .01472 L
.62737 .01472 L
.62739 .01472 L
.62742 .01472 L
.62745 .01472 L
.62747 .01472 L
.62749 .01472 L
.62751 .01472 L
.62754 .01472 L
.62757 .01472 L
.6276 .01472 L
.62762 .01472 L
.62765 .01472 L
.62768 .01472 L
.6277 .01472 L
.62771 .01472 L
.62775 .01472 L
.62776 .01472 L
.62778 .01472 L
.62781 .01472 L
.62784 .01472 L
.62787 .01472 L
.6279 .01472 L
.62792 .01472 L
.62795 .01472 L
.62797 .01472 L
.628 .01472 L
.62803 .01472 L
.62806 .01472 L
.62808 .01472 L
.62811 .01472 L
.62814 .01472 L
.62817 .01472 L
.62819 .01472 L
.62822 .01472 L
.62825 .01472 L
.62828 .01472 L
.62831 .01472 L
.62834 .01472 L
.62837 .01472 L
.6284 .01472 L
.62841 .01472 L
.62843 .01472 L
.62845 .01472 L
.62846 .01472 L
.62849 .01472 L
.62852 .01472 L
.62855 .01472 L
Mistroke
.62858 .01472 L
.62861 .01472 L
.62864 .01472 L
.62867 .01472 L
.62869 .01472 L
.62872 .01472 L
.62875 .01472 L
.62878 .01472 L
.62881 .01472 L
.62884 .01472 L
.62887 .01472 L
.6289 .01472 L
.62892 .01472 L
.62895 .01472 L
.62897 .01472 L
.62899 .01472 L
.62902 .01472 L
.62903 .01472 L
.62905 .01472 L
.62907 .01472 L
.62908 .01472 L
.62912 .01472 L
.62913 .01472 L
.62915 .01472 L
.62917 .01472 L
.62918 .01472 L
.6292 .01472 L
.62922 .01472 L
.62923 .01472 L
.62925 .01472 L
.62928 .01472 L
.62931 .01472 L
.62934 .01472 L
.62937 .01472 L
.6294 .01472 L
.62943 .01472 L
.62946 .01472 L
.62948 .01472 L
.62951 .01472 L
.62954 .01472 L
.62957 .01472 L
.6296 .01472 L
.62962 .01472 L
.62965 .01472 L
.62968 .01472 L
.6297 .01472 L
.62972 .01472 L
.62975 .01472 L
.62978 .01472 L
.6298 .01472 L
Mistroke
.62983 .01472 L
.62986 .01472 L
.62989 .60332 L
.62991 .60332 L
.62994 .60332 L
.62999 .60332 L
.63022 .60332 L
.63117 .60332 L
.63209 .60332 L
.63306 .60332 L
.634 .60332 L
.635 .60332 L
.63596 .60332 L
.63688 .60332 L
.63787 .60332 L
.63882 .60332 L
.63973 .60332 L
.6407 .60332 L
.64163 .60332 L
.64262 .60332 L
.64358 .60332 L
.6445 .60332 L
.64548 .60332 L
.64642 .60332 L
.64667 .60332 L
.64693 .60332 L
.64706 .60332 L
.64712 .60332 L
.64716 .60332 L
.64719 .60332 L
.64721 .01472 L
.64724 .01472 L
.64727 .01472 L
.6473 .01472 L
.64733 .01472 L
.64734 .01472 L
.64736 .01472 L
.64739 .01472 L
.64742 .01472 L
.64745 .01472 L
.64746 .01472 L
.64748 .01472 L
.64751 .01472 L
.64754 .01472 L
.64755 .01472 L
.64757 .01472 L
.6476 .01472 L
.64762 .01472 L
.64763 .01472 L
.64765 .01472 L
Mistroke
.64767 .01472 L
.6477 .01472 L
.64772 .01472 L
.64773 .01472 L
.64776 .01472 L
.64779 .01472 L
.64782 .01472 L
.64785 .01472 L
.64787 .01472 L
.6479 .01472 L
.64793 .01472 L
.64796 .01472 L
.64799 .01472 L
.64802 .01472 L
.64803 .01472 L
.64805 .01472 L
.64808 .01472 L
.64811 .01472 L
.64814 .01472 L
.64816 .01472 L
.64819 .01472 L
.64821 .01472 L
.64824 .01472 L
.64827 .01472 L
.6483 .01472 L
.64832 .01472 L
.64835 .01472 L
.64837 .01472 L
.64838 .01472 L
.64841 .01472 L
.64844 .01472 L
.64846 .01472 L
.64848 .01472 L
.64851 .01472 L
.64854 .01472 L
.64855 .01472 L
.64857 .01472 L
.6486 .01472 L
.64862 .01472 L
.64865 .01472 L
.64869 .01472 L
.64871 .01472 L
.64874 .01472 L
.64877 .01472 L
.64879 .01472 L
.64882 .01472 L
.64885 .01472 L
.64888 .01472 L
.6489 .01472 L
.64892 .01472 L
Mistroke
.64895 .01472 L
.64898 .01472 L
.64901 .01472 L
.64903 .01472 L
.64906 .01472 L
.64908 .01472 L
.6491 .01472 L
.64913 .01472 L
.64915 .01472 L
.64916 .01472 L
.64918 .01472 L
.6492 .01472 L
.64923 .01472 L
.64926 .01472 L
.64928 .01472 L
.64929 .01472 L
.64931 .01472 L
.64933 .01472 L
.64936 .01472 L
.64937 .01472 L
.64939 .01472 L
.64942 .01472 L
.64945 .01472 L
.64947 .01472 L
.6495 .01472 L
.64953 .01472 L
.64956 .01472 L
.64959 .01472 L
.6496 .01472 L
.64962 .01472 L
.64965 .01472 L
.64967 .01472 L
.64968 .01472 L
.64971 .01472 L
.64974 .01472 L
.64977 .01472 L
.6498 .01472 L
.64983 .01472 L
.64985 .01472 L
.64988 .01472 L
.6499 .01472 L
.64993 .01472 L
.64996 .01472 L
.64999 .01472 L
.65002 .01472 L
.65004 .01472 L
.65007 .01472 L
.65009 .01472 L
.65012 .01472 L
.65015 .01472 L
Mistroke
.65019 .01472 L
.65021 .01472 L
.65024 .01472 L
.65027 .01472 L
.6503 .01472 L
.65032 .01472 L
.65033 .01472 L
.65035 .01472 L
.65037 .01472 L
.6504 .01472 L
.65043 .01472 L
.65044 .01472 L
.65046 .01472 L
.65049 .01472 L
.65052 .01472 L
.65054 .01472 L
.65058 .01472 L
.6506 .01472 L
.65063 .01472 L
.65066 .01472 L
.65068 .01472 L
.65071 .01472 L
.65074 .01472 L
.65077 .01472 L
.65079 .01472 L
.65081 .01472 L
.65084 .01472 L
.65087 .01472 L
.6509 .01472 L
.65092 .01472 L
.65095 .01472 L
.65097 .01472 L
.65099 .01472 L
.65102 .01472 L
.65104 .01472 L
.65105 .01472 L
.65107 .01472 L
.65109 .01472 L
.65111 .01472 L
.65112 .01472 L
.65114 .01472 L
.65116 .01472 L
.65119 .01472 L
.65122 .01472 L
.65125 .01472 L
.65126 .01472 L
.65128 .01472 L
.65131 .01472 L
.65134 .01472 L
.65136 .01472 L
Mistroke
.65139 .01472 L
.65141 .01472 L
.65144 .01472 L
.65147 .01472 L
.65149 .01472 L
.65151 .01472 L
.65154 .01472 L
.65155 .01472 L
.65157 .01472 L
.6516 .01472 L
.65163 .01472 L
.65166 .01472 L
.65169 .01472 L
.65171 .01472 L
.65174 .01472 L
.65177 .01472 L
.65179 .01472 L
.65182 .01472 L
.65185 .01472 L
.65188 .01472 L
.6519 .01472 L
.65193 .01472 L
.65196 .01472 L
.65198 .01472 L
.65201 .01472 L
.65204 .01472 L
.65207 .01472 L
.6521 .01472 L
.65213 .01472 L
.65216 .01472 L
.65219 .01472 L
.6522 .01472 L
.65222 .01472 L
.65224 .01472 L
.65225 .01472 L
.65228 .01472 L
.65231 .01472 L
.65234 .01472 L
.65237 .01472 L
.6524 .01472 L
.65243 .01472 L
.65246 .01472 L
.65248 .01472 L
.65251 .01472 L
.65254 .01472 L
.65257 .01472 L
.6526 .01472 L
.65263 .01472 L
.65266 .01472 L
.65269 .01472 L
Mistroke
.65271 .01472 L
.65275 .01472 L
.65276 .01472 L
.65278 .01472 L
.65281 .01472 L
.65282 .01472 L
.65284 .01472 L
.65286 .01472 L
.65288 .01472 L
.65291 .01472 L
.65292 .01472 L
.65294 .01472 L
.65296 .01472 L
.65297 .01472 L
.65299 .01472 L
.65301 .01472 L
.65303 .01472 L
.65304 .01472 L
.65307 .01472 L
.6531 .01472 L
.65313 .01472 L
.65316 .01472 L
.65319 .01472 L
.65322 .01472 L
.65325 .01472 L
.65327 .01472 L
.6533 .01472 L
.65333 .01472 L
.65336 .01472 L
.65339 .01472 L
.65341 .01472 L
.65344 .01472 L
.65347 .01472 L
.65349 .01472 L
.65351 .01472 L
.65354 .01472 L
.65357 .01472 L
.65359 .01472 L
.65362 .01472 L
.65365 .01472 L
.65368 .01472 L
.6537 .01472 L
.65373 .01472 L
.65375 .01472 L
.65378 .01472 L
.65381 .01472 L
.65384 .01472 L
.65386 .01472 L
.65389 .01472 L
.65392 .01472 L
Mistroke
.65394 .01472 L
.65395 .01472 L
.65398 .01472 L
.65401 .01472 L
.65404 .01472 L
.65407 .01472 L
.6541 .01472 L
.65413 .01472 L
.65415 .01472 L
.65418 .01472 L
.65421 .01472 L
.65424 .01472 L
.65427 .01472 L
.6543 .01472 L
.65432 .01472 L
.65435 .01472 L
.65438 .01472 L
.6544 .01472 L
.65442 .01472 L
.65445 .01472 L
.65448 .01472 L
.6545 .01472 L
.65453 .01472 L
.65456 .01472 L
.65459 .01472 L
.65461 .01472 L
.65464 .01472 L
.65466 .01472 L
.65469 .01472 L
.65472 .01472 L
.65475 .01472 L
.65477 .01472 L
.6548 .01472 L
.65483 .01472 L
.65485 .01472 L
.65486 .01472 L
.65489 .01472 L
.65492 .01472 L
.65495 .01472 L
.65496 .01472 L
.65498 .01472 L
.65501 .01472 L
.65504 .01472 L
.65506 .01472 L
.65509 .01472 L
.65512 .01472 L
.65515 .01472 L
.65518 .01472 L
.65519 .01472 L
.65521 .01472 L
Mistroke
.65524 .01472 L
.65526 .01472 L
.65527 .01472 L
.6553 .01472 L
.65533 .01472 L
.65536 .01472 L
.65539 .01472 L
.65542 .01472 L
.65544 .01472 L
.65547 .01472 L
.65549 .01472 L
.65552 .01472 L
.65555 .01472 L
.65558 .01472 L
.6556 .01472 L
.65563 .01472 L
.65566 .01472 L
.65569 .01472 L
.65571 .01472 L
.65574 .01472 L
.65577 .01472 L
.6558 .01472 L
.65583 .01472 L
.65586 .01472 L
.65589 .01472 L
.65591 .01472 L
.65592 .01472 L
.65594 .01472 L
.65596 .01472 L
.65599 .01472 L
.65601 .01472 L
.65604 .01472 L
.65608 .01472 L
.6561 .01472 L
.65613 .01472 L
.65616 .01472 L
.65618 .01472 L
.65621 .01472 L
.65624 .01472 L
.65627 .01472 L
.6563 .01472 L
.65633 .01472 L
.65636 .01472 L
.65639 .01472 L
.65642 .01472 L
.65645 .01472 L
.65647 .01472 L
.65648 .01472 L
.65651 .01472 L
.65653 .01472 L
Mistroke
.65654 .01472 L
.65656 .01472 L
.65658 .01472 L
.65661 .01472 L
.65663 .01472 L
.65664 .01472 L
.65666 .01472 L
.65668 .01472 L
.65669 .01472 L
.65671 .01472 L
.65673 .01472 L
.65674 .01472 L
.65677 .01472 L
.6568 .01472 L
.65683 .01472 L
.65686 .01472 L
.65689 .01472 L
.65692 .01472 L
.65695 .01472 L
.65697 .01472 L
.657 .01472 L
.65703 .01472 L
.65706 .01472 L
.65709 .01472 L
.65712 .01472 L
.65715 .01472 L
.65718 .01472 L
.65719 .01472 L
.65721 .01472 L
.65724 .01472 L
.65727 .01472 L
.6573 .01472 L
.65732 .01472 L
.65735 .01472 L
.65738 .01472 L
.65741 .01472 L
.65743 .01472 L
.65746 .01472 L
.65748 .01472 L
.65751 .01472 L
.65754 .01472 L
.65757 .01472 L
.65759 .01472 L
.65762 .01472 L
.65764 .01472 L
.65765 .01472 L
.65768 .01472 L
.65771 .01472 L
.65774 .01472 L
.65777 .01472 L
Mistroke
.6578 .01472 L
.65783 .01472 L
.65786 .01472 L
.65788 .01472 L
.65791 .01472 L
.65794 .01472 L
.65797 .01472 L
.658 .01472 L
.65803 .01472 L
.65805 .01472 L
.65809 .01472 L
.6581 .01472 L
.65812 .01472 L
.65815 .01472 L
.65818 .01472 L
.65821 .01472 L
.65823 .01472 L
.65826 .01472 L
.65829 .01472 L
.65832 .01472 L
.65834 .01472 L
.65837 .01472 L
.65839 .01472 L
.65842 .01472 L
.65845 .01472 L
.65848 .01472 L
.6585 .01472 L
.65853 .01472 L
.65855 .01472 L
.65856 .01472 L
.65859 .01472 L
.65862 .01472 L
.65865 .01472 L
.65867 .01472 L
.65868 .01472 L
.65871 .01472 L
.65874 .01472 L
.65877 .01472 L
.65879 .01472 L
.65882 .01472 L
.65885 .01472 L
.65888 .01472 L
.65889 .01472 L
.65891 .01472 L
.65894 .01472 L
.65896 .01472 L
.65898 .01472 L
.659 .01472 L
.65904 .01472 L
.65906 .01472 L
Mistroke
.65909 .01472 L
.65912 .01472 L
.65914 .01472 L
.65917 .01472 L
.65919 .01472 L
.65922 .01472 L
.65925 .01472 L
.65928 .01472 L
.65931 .01472 L
.65934 .01472 L
.65936 .01472 L
.65939 .01472 L
.65942 .01472 L
.65944 .01472 L
.65948 .01472 L
.6595 .01472 L
.65953 .01472 L
.65956 .01472 L
.65959 .01472 L
.65961 .01472 L
.65962 .01472 L
.65964 .01472 L
.65966 .01472 L
.65969 .01472 L
.65972 .01472 L
.65975 .01472 L
.65978 .01472 L
.6598 .01472 L
.65983 .01472 L
.65986 .01472 L
.65988 .01472 L
.65991 .01472 L
.65994 .01472 L
.65997 .01472 L
.66 .01472 L
.66003 .01472 L
.66006 .01472 L
.66009 .01472 L
.66012 .01472 L
.66015 .01472 L
.66017 .01472 L
.66018 .01472 L
.66021 .01472 L
.66023 .01472 L
.66025 .01472 L
.66026 .01472 L
.66028 .01472 L
.66031 .01472 L
.66033 .01472 L
.66034 .01472 L
Mistroke
.66036 .01472 L
.66038 .01472 L
.66039 .01472 L
.66041 .01472 L
.66043 .01472 L
.66044 .01472 L
.66047 .01472 L
.6605 .01472 L
.66053 .01472 L
.66056 .01472 L
.66059 .01472 L
.66062 .01472 L
.66065 .01472 L
.66067 .01472 L
.6607 .01472 L
.66073 .01472 L
.66076 .01472 L
.66079 .01472 L
.66082 .01472 L
.66085 .01472 L
.66088 .01472 L
.6609 .01472 L
.66091 .01472 L
.66094 .01472 L
.66097 .01472 L
.661 .01472 L
.66103 .01472 L
.66105 .01472 L
.66108 .01472 L
.66111 .01472 L
.66113 .01472 L
.66116 .01472 L
.66118 .01472 L
.66121 .01472 L
.66124 .01472 L
.66127 .01472 L
.66129 .01472 L
.66132 .01472 L
.66134 .01472 L
.66135 .01472 L
.66138 .01472 L
.66141 .01472 L
.66144 .01472 L
.66147 .01472 L
.6615 .01472 L
.66153 .01472 L
.66156 .01472 L
.66158 .01472 L
.66161 .01472 L
.66164 .01472 L
Mistroke
.66167 .01472 L
.6617 .01472 L
.66173 .01472 L
.66176 .01472 L
.66179 .01472 L
.6618 .01472 L
.66182 .01472 L
.66185 .01472 L
.66188 .01472 L
.66191 .01472 L
.66193 .01472 L
.66196 .01472 L
.66199 .01472 L
.66202 .01472 L
.66204 .01472 L
.66207 .01472 L
.66209 .01472 L
.66212 .01472 L
.66215 .01472 L
.66218 .01472 L
.6622 .01472 L
.66223 .01472 L
.66225 .01472 L
.66226 .01472 L
.66229 .01472 L
.66232 .01472 L
.66235 .01472 L
.66238 .01472 L
.66241 .01472 L
.66244 .01472 L
.66247 .01472 L
.66249 .01472 L
.66252 .01472 L
.66255 .01472 L
.66258 .01472 L
.66261 .01472 L
.66264 .01472 L
.66267 .01472 L
.6627 .01472 L
.66272 .01472 L
.66273 .01472 L
.66276 .01472 L
.66279 .01472 L
.66282 .01472 L
.66285 .01472 L
.66287 .01472 L
.6629 .01472 L
.66293 .01472 L
.66295 .01472 L
.66298 .01472 L
Mistroke
.663 .01472 L
.66303 .01472 L
.66306 .01472 L
.66309 .01472 L
.66311 .01472 L
.66314 .01472 L
.66316 .01472 L
.66317 .01472 L
.6632 .01472 L
.66323 .01472 L
.66326 .01472 L
.66328 .01472 L
.66329 .01472 L
.66332 .01472 L
.66335 .01472 L
.66338 .01472 L
.6634 .01472 L
.66343 .01472 L
.66346 .01472 L
.66349 .01472 L
.66351 .01472 L
.66352 .01472 L
.66355 .01472 L
.66357 .01472 L
.66359 .01472 L
.66362 .01472 L
.66365 .01472 L
.66368 .01472 L
.6637 .01472 L
.66373 .01472 L
.66376 .01472 L
.66378 .01472 L
.66381 .01472 L
.66383 .01472 L
.66386 .01472 L
.66389 .01472 L
.66392 .01472 L
.66395 .01472 L
.66398 .01472 L
.664 .01472 L
.66403 .01472 L
.66406 .01472 L
.66409 .01472 L
.66412 .01472 L
.66414 .01472 L
.66418 .01472 L
.66421 .01472 L
.66422 .01472 L
.66424 .01472 L
.66425 .01472 L
Mistroke
.66427 .01472 L
.6643 .01472 L
.66433 .01472 L
.66436 .01472 L
.66439 .01472 L
.66442 .01472 L
.66445 .01472 L
.66447 .01472 L
.6645 .01472 L
.66453 .01472 L
.66456 .01472 L
.66459 .01472 L
.66461 .01472 L
.66464 .01472 L
.66467 .01472 L
.6647 .01472 L
.66473 .01472 L
.66476 .01472 L
.66478 .01472 L
.6648 .01472 L
.66483 .01472 L
.66484 .01472 L
.66486 .01472 L
.66487 .01472 L
.66489 .01472 L
.66492 .01472 L
.66494 .01472 L
.66496 .01472 L
.66497 .01472 L
.66499 .01472 L
.66501 .01472 L
.66503 .01472 L
.66504 .01472 L
.66506 .01472 L
.66509 .01472 L
.66512 .01472 L
.66515 .01472 L
.66518 .01472 L
.66521 .01472 L
.66524 .01472 L
.66526 .01472 L
.66529 .01472 L
.66532 .01472 L
.66534 .01472 L
.66537 .01472 L
.6654 .01472 L
.66543 .01472 L
.66546 .01472 L
.66549 .01472 L
.66551 .01472 L
Mistroke
.66553 .01472 L
.66556 .01472 L
.66559 .01472 L
.66561 .01472 L
.66564 .01472 L
.66567 .01472 L
.6657 .01472 L
.66572 .01472 L
.66574 .01472 L
.66577 .01472 L
.6658 .01472 L
.66582 .01472 L
.66585 .01472 L
.66588 .01472 L
.66591 .01472 L
.66594 .01472 L
.66595 .01472 L
.66597 .01472 L
.666 .01472 L
.66603 .01472 L
.66606 .01472 L
.66609 .01472 L
.66612 .01472 L
.66614 .01472 L
.66617 .01472 L
.6662 .01472 L
.66623 .01472 L
.66625 .01472 L
.66628 .01472 L
.66631 .01472 L
.66634 .01472 L
.66637 .01472 L
.6664 .01472 L
.66642 .01472 L
.66644 .01472 L
.66647 .01472 L
.6665 .01472 L
.66652 .01472 L
.66655 .01472 L
.66658 .01472 L
.66661 .01472 L
.66663 .01472 L
.66666 .01472 L
.66668 .01472 L
.66671 .01472 L
.66674 .01472 L
.66676 .01472 L
.66679 .01472 L
.66682 .01472 L
.66685 .01472 L
Mistroke
.66686 .01472 L
.66688 .01472 L
.66691 .01472 L
.66694 .01472 L
.66697 .01472 L
.66698 .01472 L
.667 .01472 L
.66703 .01472 L
.66706 .01472 L
.66708 .01472 L
.66711 .01472 L
.66713 .01472 L
.66716 .01472 L
.66719 .01472 L
.66721 .01472 L
.66723 .01472 L
.66726 .01472 L
.66728 .01472 L
.66729 .01472 L
.66732 .01472 L
.66735 .01472 L
.66738 .01472 L
.66741 .01472 L
.66743 .01472 L
.66746 .01472 L
.66749 .01472 L
.66751 .01472 L
.66754 .01472 L
.66757 .01472 L
.6676 .01472 L
.66762 .01472 L
.66765 .01472 L
.66768 .01472 L
.6677 .01472 L
.66773 .01472 L
.66776 .01472 L
.66779 .01472 L
.66782 .01472 L
.66785 .01472 L
.66788 .01472 L
.66791 .01472 L
.66792 .01472 L
.66794 .01472 L
.66796 .01472 L
.66797 .01472 L
.668 .01472 L
.66803 .01472 L
.66806 .01472 L
.66809 .01472 L
.66812 .01472 L
Mistroke
.66815 .01472 L
.66818 .01472 L
.6682 .01472 L
.66823 .01472 L
.66826 .01472 L
.66829 .01472 L
.66832 .01472 L
.66835 .01472 L
.66838 .01472 L
.66841 .01472 L
.66843 .01472 L
.66847 .01472 L
.66848 .01472 L
.6685 .01472 L
.66853 .01472 L
.66855 .01472 L
.66856 .01472 L
.66858 .01472 L
.6686 .01472 L
.66863 .01472 L
.66864 .01472 L
.66866 .01472 L
.66868 .01472 L
.6687 .01472 L
.66871 .01472 L
.66873 .01472 L
.66875 .01472 L
.66876 .01472 L
.66879 .01472 L
.66882 .01472 L
.66885 .01472 L
.66888 .01472 L
.66891 .01472 L
.66894 .01472 L
.66897 .01472 L
.66899 .01472 L
.66902 .01472 L
.66905 .01472 L
.66908 .01472 L
.66911 .01472 L
.66913 .01472 L
.66916 .01472 L
.6692 .01472 L
.66921 .01472 L
.66923 .01472 L
.66926 .01472 L
.66929 .01472 L
.66932 .01472 L
.66934 .01472 L
.66937 .01472 L
Mistroke
.6694 .01472 L
.66942 .01472 L
.66945 .01472 L
.66947 .01472 L
.6695 .01472 L
.66953 .01472 L
.66956 .01472 L
.66959 .01472 L
.66961 .01472 L
.66964 .01472 L
.66966 .01472 L
.66967 .01472 L
.6697 .01472 L
.66973 .01472 L
.66976 .01472 L
.66979 .01472 L
.66982 .01472 L
.66985 .01472 L
.66988 .01472 L
.6699 .01472 L
.66993 .01472 L
.66996 .01472 L
.66999 .01472 L
.67002 .01472 L
.67004 .01472 L
.67007 .01472 L
.67011 .01472 L
.67012 .01472 L
.67014 .01472 L
.67017 .01472 L
.6702 .01472 L
.67023 .01472 L
.67025 .01472 L
.67028 .01472 L
.67031 .01472 L
.67034 .01472 L
.67036 .01472 L
.67038 .01472 L
.67041 .01472 L
.67044 .01472 L
.67047 .01472 L
.6705 .01472 L
.67052 .01472 L
.67055 .01472 L
.67057 .01472 L
.67058 .01472 L
.67061 .01472 L
.67064 .01472 L
.67067 .01472 L
.67069 .01472 L
Mistroke
.6707 .01472 L
.67073 .01472 L
.67076 .01472 L
.67079 .01472 L
.67081 .01472 L
.67084 .01472 L
.67087 .01472 L
.6709 .01472 L
.67091 .01472 L
.67093 .01472 L
.67096 .01472 L
.67098 .01472 L
.67099 .01472 L
.67102 .01472 L
.67105 .01472 L
.67108 .01472 L
.67111 .01472 L
.67114 .01472 L
.67116 .01472 L
.67119 .01472 L
.67121 .01472 L
.67124 .01472 L
.67127 .01472 L
.6713 .01472 L
.67133 .01472 L
.67135 .01472 L
.67138 .01472 L
.67141 .01472 L
.67143 .01472 L
.67146 .01472 L
.6715 .01472 L
.67152 .01472 L
.67155 .01472 L
.67158 .01472 L
.67161 .01472 L
.67163 .01472 L
.67164 .01472 L
.67166 .01472 L
.67168 .01472 L
.67171 .01472 L
.67174 .01472 L
.67177 .01472 L
.6718 .01472 L
.67182 .01472 L
.67185 .01472 L
.67188 .01472 L
.6719 .01472 L
.67193 .01472 L
.67196 .01472 L
.67199 .01472 L
Mistroke
.67202 .01472 L
.67205 .01472 L
.67208 .01472 L
.67211 .01472 L
.67214 .01472 L
.67217 .01472 L
.67219 .01472 L
.6722 .01472 L
.67223 .01472 L
.67225 .01472 L
.67226 .01472 L
.67228 .01472 L
.6723 .01472 L
.67233 .01472 L
.67235 .01472 L
.67236 .01472 L
.67238 .01472 L
.6724 .01472 L
.67241 .01472 L
.67243 .01472 L
.67245 .01472 L
.67246 .01472 L
.67249 .01472 L
.67252 .01472 L
.67255 .01472 L
.67258 .01472 L
.67261 .01472 L
.67264 .01472 L
.67267 .01472 L
.67269 .01472 L
.67272 .01472 L
.67275 .01472 L
.67278 .01472 L
.67281 .01472 L
.67284 .01472 L
.67287 .01472 L
.6729 .01472 L
.67292 .01472 L
.67293 .01472 L
.67296 .01472 L
.67299 .01472 L
.67302 .01472 L
.67305 .01472 L
.67307 .01472 L
.6731 .01472 L
.67313 .01472 L
.67315 .01472 L
.67318 .01472 L
.6732 .01472 L
.67323 .01472 L
Mistroke
.67326 .01472 L
.67329 .01472 L
.67331 .01472 L
.67334 .01472 L
.67336 .01472 L
.67337 .01472 L
.6734 .01472 L
.67343 .01472 L
.67346 .01472 L
.67349 .01472 L
.67352 .01472 L
.67355 .01472 L
.67358 .01472 L
.6736 .01472 L
.67363 .01472 L
.67366 .01472 L
.67369 .01472 L
.67372 .01472 L
.67375 .01472 L
.67378 .01472 L
.67381 .01472 L
.67383 .01472 L
.67384 .01472 L
.67387 .01472 L
.6739 .01472 L
.67393 .01472 L
.67396 .01472 L
.67398 .01472 L
.67401 .01472 L
.67404 .01472 L
.67406 .01472 L
.67409 .01472 L
.67411 .01472 L
.67414 .01472 L
.67417 .01472 L
.6742 .01472 L
.67422 .01472 L
.67425 .01472 L
.67427 .01472 L
.67428 .01472 L
.67431 .01472 L
.67434 .01472 L
.67437 .01472 L
.67439 .01472 L
.6744 .01472 L
.67443 .01472 L
.67446 .01472 L
.67449 .01472 L
.67451 .01472 L
.67454 .01472 L
Mistroke
.67457 .01472 L
.6746 .01472 L
.67462 .01472 L
.67463 .01472 L
.67466 .01472 L
.67468 .01472 L
.6747 .01472 L
.67473 .01472 L
.67476 .01472 L
.67479 .01472 L
.67481 .01472 L
.67484 .01472 L
.67487 .01472 L
.67489 .01472 L
.67491 .01472 L
.67494 .01472 L
.67497 .01472 L
.675 .01472 L
.67503 .01472 L
.67506 .01472 L
.67508 .01472 L
.67511 .01472 L
.67514 .01472 L
.67517 .01472 L
.6752 .01472 L
.67522 .01472 L
.67525 .01472 L
.67528 .01472 L
.67531 .01472 L
.67533 .01472 L
.67535 .01472 L
.67536 .01472 L
.67538 .01472 L
.67541 .01472 L
.67544 .01472 L
.67547 .01472 L
.6755 .01472 L
.67553 .01472 L
.67555 .01472 L
.67558 .01472 L
.67561 .01472 L
.67563 .01472 L
.67567 .01472 L
.6757 .01472 L
.67572 .01472 L
.67575 .01472 L
.67578 .01472 L
.67581 .01472 L
.67584 .01472 L
.67587 .01472 L
Mistroke
.67589 .01472 L
.6759 .01472 L
.67593 .01472 L
.67595 .01472 L
.67597 .01472 L
.67598 .01472 L
.676 .01472 L
.67603 .01472 L
.67605 .01472 L
.67606 .01472 L
.67608 .01472 L
.6761 .01472 L
.67612 .01472 L
.67613 .01472 L
.67615 .01472 L
.67617 .01472 L
.67619 .01472 L
.67622 .01472 L
.67625 .01472 L
.67629 .01472 L
.67632 .01472 L
.67634 .01472 L
.67637 .01472 L
.67639 .01472 L
.67642 .01472 L
.67645 .01472 L
.67648 .01472 L
.67651 .01472 L
.67654 .01472 L
.67657 .01472 L
.6766 .01472 L
.67662 .01472 L
.67663 .01472 L
.67666 .01472 L
.67669 .01472 L
.67672 .01472 L
.67675 .01472 L
.67678 .01472 L
.6768 .01472 L
.67683 .01472 L
.67685 .01472 L
.67688 .01472 L
.6769 .01472 L
.67693 .01472 L
.67696 .01472 L
.67699 .01472 L
.67701 .01472 L
.67704 .01472 L
.67706 .01472 L
.67708 .01472 L
Mistroke
.6771 .01472 L
.67713 .01472 L
.67716 .01472 L
.67719 .01472 L
.67722 .01472 L
.67725 .01472 L
.67728 .01472 L
.6773 .01472 L
.67733 .01472 L
.67736 .01472 L
.67739 .01472 L
.67742 .01472 L
.67745 .01472 L
.67748 .01472 L
.67751 .01472 L
.67753 .01472 L
.67754 .01472 L
.67757 .01472 L
.6776 .01472 L
.67763 .01472 L
.67766 .01472 L
.67769 .01472 L
.67771 .01472 L
.67774 .01472 L
.67776 .01472 L
.67779 .01472 L
.67781 .01472 L
.67784 .01472 L
.67787 .01472 L
.6779 .01472 L
.67792 .01472 L
.67795 .01472 L
.67797 .01472 L
.67798 .01472 L
.67801 .01472 L
.67804 .01472 L
.67807 .01472 L
.6781 .01472 L
.67813 .01472 L
.67816 .01472 L
.67819 .01472 L
.67821 .01472 L
.67824 .01472 L
.67827 .01472 L
.6783 .01472 L
.67833 .01472 L
.67836 .01472 L
.67839 .01472 L
.67842 .01472 L
.67844 .01472 L
Mistroke
.67845 .01472 L
.67848 .01472 L
.67851 .01472 L
.67854 .01472 L
.67857 .01472 L
.6786 .01472 L
.67862 .01472 L
.67865 .01472 L
.67867 .01472 L
.6787 .01472 L
.67872 .01472 L
.67875 .01472 L
.67878 .01472 L
.67881 .01472 L
.67883 .01472 L
.67886 .01472 L
.67888 .01472 L
.6789 .01472 L
.67892 .01472 L
.67895 .01472 L
.67898 .01472 L
.679 .01472 L
.67902 .01472 L
.67904 .01472 L
.67907 .01472 L
.6791 .01472 L
.67912 .01472 L
.67915 .01472 L
.67918 .01472 L
.67921 .01472 L
.67923 .01472 L
.67924 .01472 L
.67928 .01472 L
.67929 .01472 L
.67931 .01472 L
.67934 .01472 L
.67937 .01472 L
.6794 .01472 L
.67943 .01472 L
.67945 .01472 L
.67948 .01472 L
.6795 .01472 L
.67953 .01472 L
.67956 .01472 L
.67959 .01472 L
.67961 .01472 L
.67964 .01472 L
.67967 .01472 L
.6797 .01472 L
.67972 .01472 L
Mistroke
.67975 .01472 L
.67978 .01472 L
.67981 .01472 L
.67984 .01472 L
.67987 .01472 L
.6799 .01472 L
.67993 .01472 L
.67994 .01472 L
.67996 .01472 L
.67998 .01472 L
.67999 .01472 L
.68002 .01472 L
.68005 .01472 L
.68008 .01472 L
.68011 .01472 L
.68014 .01472 L
.68017 .01472 L
.68019 .01472 L
.68022 .01472 L
.68025 .01472 L
.68028 .01472 L
.68031 .01472 L
.68034 .01472 L
.68036 .01472 L
.6804 .01472 L
.68043 .01472 L
.68045 .01472 L
.68048 .01472 L
.6805 .01472 L
.68052 .01472 L
.68055 .01472 L
.68056 .01472 L
.68058 .01472 L
.6806 .01472 L
.68061 .01472 L
.68064 .01472 L
.68066 .01472 L
.68068 .01472 L
.68069 .01472 L
.68071 .01472 L
.68073 .01472 L
.68075 .01472 L
.68076 .01472 L
.68078 .01472 L
.68081 .01472 L
.68084 .01472 L
.68087 .01472 L
.6809 .01472 L
.68093 .01472 L
.68096 .01472 L
Mistroke
.68098 .01472 L
.68101 .01472 L
.68104 .01472 L
.68106 .01472 L
.68109 .01472 L
.68113 .01472 L
.68115 .01472 L
.68118 .01472 L
.68121 .01472 L
.68123 .01472 L
.68125 .01472 L
.68128 .01472 L
.68131 .01472 L
.68133 .01472 L
.68136 .01472 L
.68139 .01472 L
.68142 .01472 L
.68144 .01472 L
.68147 .01472 L
.68149 .01472 L
.68152 .01472 L
.68155 .01472 L
.68158 .01472 L
.6816 .01472 L
.68163 .01472 L
.68166 .01472 L
.68167 .01472 L
.68169 .01472 L
.68172 .01472 L
.68175 .01472 L
.68178 .01472 L
.68181 .01472 L
.68184 .01472 L
.68187 .01472 L
.68189 .01472 L
.68192 .01472 L
.68195 .01472 L
.68197 .01472 L
.682 .01472 L
.68204 .01472 L
.68206 .01472 L
.68209 .01472 L
.68212 .01472 L
.68214 .01472 L
.68216 .01472 L
.68219 .01472 L
.68222 .01472 L
.68224 .01472 L
.68227 .01472 L
.6823 .01472 L
Mistroke
.68233 .01472 L
.68235 .01472 L
.68238 .01472 L
.6824 .01472 L
.68243 .01472 L
.68246 .01472 L
.68249 .01472 L
.68251 .01472 L
.68254 .01472 L
.68257 .01472 L
.68259 .01472 L
.6826 .01472 L
.68263 .01472 L
.68266 .01472 L
.68269 .01472 L
.6827 .01472 L
.68272 .01472 L
.68275 .01472 L
.68278 .01472 L
.6828 .01472 L
.68283 .01472 L
.68286 .01472 L
.68289 .01472 L
.68292 .01472 L
.68293 .01472 L
.68295 .01472 L
.68298 .01472 L
.683 .01472 L
.68301 .01472 L
.68304 .01472 L
.68307 .01472 L
.6831 .01472 L
.68313 .01472 L
.68316 .01472 L
.68318 .01472 L
.68321 .01472 L
.68323 .01472 L
.68326 .01472 L
.68329 .01472 L
.68332 .01472 L
.68334 .01472 L
.68337 .01472 L
.6834 .01472 L
.68343 .01472 L
.68345 .01472 L
.68348 .01472 L
.68351 .01472 L
.68354 .01472 L
.68357 .01472 L
.6836 .01472 L
Mistroke
.68363 .01472 L
.68365 .01472 L
.68366 .01472 L
.68368 .01472 L
.6837 .01472 L
.68373 .01472 L
.68375 .01472 L
.68378 .01472 L
.68382 .01472 L
.68384 .01472 L
.68387 .01472 L
.6839 .01472 L
.68392 .01472 L
.68395 .01472 L
.68398 .01472 L
.68401 .01472 L
.68404 .01472 L
.68407 .01472 L
.6841 .01472 L
.68413 .01472 L
.68416 .01472 L
.68419 .01472 L
.68421 .01472 L
.68422 .01472 L
.68425 .01472 L
.68427 .01472 L
.68428 .01472 L
.6843 .01472 L
.68432 .01472 L
.68435 .01472 L
.68437 .01472 L
.68438 .01472 L
.6844 .01472 L
.68442 .01472 L
.68443 .01472 L
.68445 .01472 L
.68447 .01472 L
.68448 .01472 L
.68451 .01472 L
.68454 .01472 L
.68457 .01472 L
.6846 .01472 L
.68463 .01472 L
.68466 .01472 L
.68469 .01472 L
.68471 .01472 L
.68474 .01472 L
.68477 .01472 L
.6848 .01472 L
.68483 .01472 L
Mistroke
.68486 .01472 L
.68489 .01472 L
.68492 .01472 L
.68493 .01472 L
.68495 .01472 L
.68498 .01472 L
.68501 .01472 L
.68504 .01472 L
.68507 .01472 L
.68509 .01472 L
.68512 .01472 L
.68515 .01472 L
.68517 .01472 L
.6852 .01472 L
.68522 .01472 L
.68525 .01472 L
.68528 .01472 L
.68531 .01472 L
.68533 .01472 L
.68536 .01472 L
.68538 .01472 L
.68539 .01472 L
.68542 .01472 L
.68545 .01472 L
.68548 .01472 L
.68551 .01472 L
.68554 .01472 L
.68557 .01472 L
.6856 .01472 L
.68562 .01472 L
.68565 .01472 L
.68568 .01472 L
.68571 .01472 L
.68574 .01472 L
.68577 .01472 L
.6858 .01472 L
.68583 .01472 L
.68584 .01472 L
.68586 .01472 L
.68589 .01472 L
.68592 .01472 L
.68595 .01472 L
.68598 .01472 L
.686 .01472 L
.68603 .01472 L
.68606 .01472 L
.68608 .01472 L
.68611 .01472 L
.68613 .01472 L
.68616 .01472 L
Mistroke
.68619 .01472 L
.68622 .01472 L
.68624 .01472 L
.68627 .01472 L
.68629 .01472 L
.6863 .01472 L
.68633 .01472 L
.68636 .01472 L
.68639 .01472 L
.68641 .01472 L
.68642 .01472 L
.68645 .01472 L
.68648 .01472 L
.68651 .01472 L
.68653 .01472 L
.68656 .01472 L
.68659 .01472 L
.68662 .01472 L
.68664 .01472 L
.68665 .01472 L
.68668 .01472 L
.6867 .01472 L
.68672 .01472 L
.68675 .01472 L
.68678 .01472 L
.68681 .01472 L
.68683 .01472 L
.68686 .01472 L
.68689 .01472 L
.68691 .01472 L
.68694 .01472 L
.68696 .01472 L
.68699 .01472 L
.68702 .01472 L
.68705 .01472 L
.68708 .01472 L
.6871 .01472 L
.68713 .01472 L
.68716 .01472 L
.68719 .01472 L
.68722 .01472 L
.68724 .01472 L
.68727 .01472 L
.68731 .01472 L
.68733 .01472 L
.68735 .01472 L
.68737 .01472 L
.68738 .01472 L
.6874 .01472 L
.68743 .01472 L
Mistroke
.68746 .01472 L
.68749 .01472 L
.68752 .01472 L
.68755 .01472 L
.68757 .01472 L
.6876 .01472 L
.68763 .01472 L
.68765 .01472 L
.68769 .01472 L
.68772 .01472 L
.68774 .01472 L
.68777 .01472 L
.6878 .01472 L
.68783 .01472 L
.68786 .01472 L
.68789 .01472 L
.68791 .01472 L
.68792 .01472 L
.68796 .01472 L
.68797 .01472 L
.68799 .01472 L
.688 .01472 L
.68802 .01472 L
.68805 .01472 L
.68807 .01472 L
.68808 .01472 L
.6881 .01472 L
.68812 .01472 L
.68814 .01472 L
.68815 .01472 L
.68817 .01472 L
.68819 .01472 L
.68821 .01472 L
.68825 .01472 L
.68827 .01472 L
.68831 .01472 L
.68834 .01472 L
.68836 .01472 L
.68839 .01472 L
.68842 .01472 L
.68844 .01472 L
.68847 .01472 L
.6885 .01472 L
.68853 .01472 L
.68856 .01472 L
.68859 .01472 L
.68862 .01472 L
.68864 .01472 L
.68865 .01472 L
.68869 .01472 L
Mistroke
.68871 .01472 L
.68874 .01472 L
.68877 .01472 L
.6888 .01472 L
.68882 .01472 L
.68885 .01472 L
.68887 .01472 L
.6889 .01472 L
.68893 .01472 L
.68895 .01472 L
.68898 .01472 L
.68901 .01472 L
.68903 .01472 L
.68906 .01472 L
.68908 .01472 L
.6891 .01472 L
.68912 .01472 L
.68915 .01472 L
.68918 .01472 L
.68922 .01472 L
.68925 .01472 L
.68927 .01472 L
.6893 .01472 L
.68933 .01472 L
.68935 .01472 L
.68938 .01472 L
.68941 .01472 L
.68944 .01472 L
.68947 .01472 L
.6895 .01472 L
.68953 .01472 L
.68955 .01472 L
.68956 .01472 L
.68959 .01472 L
.68962 .01472 L
.68965 .01472 L
.68968 .01472 L
.68971 .01472 L
.68973 .01472 L
.68976 .01472 L
.68978 .01472 L
.68981 .01472 L
.68984 .01472 L
.68986 .01472 L
.68989 .01472 L
.68992 .01472 L
.68994 .01472 L
.68997 .01472 L
.68999 .01472 L
.69001 .01472 L
Mistroke
.69003 .01472 L
.69006 .01472 L
.69009 .01472 L
.69011 .01472 L
.69013 .01472 L
.69015 .01472 L
.69018 .01472 L
.69021 .01472 L
.69023 .01472 L
.69026 .01472 L
.69029 .01472 L
.69032 .01472 L
.69034 .01472 L
.69035 .01472 L
.69039 .01472 L
.6904 .01472 L
.69042 .01472 L
.69045 .01472 L
.69048 .01472 L
.69051 .01472 L
.69054 .01472 L
.69056 .01472 L
.69059 .01472 L
.69061 .01472 L
.69064 .01472 L
.69066 .01472 L
.69069 .01472 L
.69072 .01472 L
.69075 .01472 L
.69078 .01472 L
.69081 .01472 L
.69083 .01472 L
.69086 .01472 L
.69089 .01472 L
.69092 .01472 L
.69095 .01472 L
.69098 .01472 L
.69101 .01472 L
.69104 .01472 L
.69105 .01472 L
.69107 .01472 L
.69109 .01472 L
.6911 .01472 L
.69113 .01472 L
.69116 .01472 L
.69119 .01472 L
.69122 .01472 L
.69125 .01472 L
.69128 .01472 L
.6913 .01472 L
Mistroke
.69133 .01472 L
.69136 .01472 L
.69139 .01472 L
.69142 .01472 L
.69144 .01472 L
.69147 .01472 L
.6915 .01472 L
.69153 .01472 L
.69156 .01472 L
.69159 .01472 L
.69161 .01472 L
.69163 .01472 L
.69166 .01472 L
.69167 .01472 L
.69169 .01472 L
.69171 .01472 L
.69172 .01472 L
.69175 .01472 L
.69177 .01472 L
.69179 .01472 L
.6918 .01472 L
.69182 .01472 L
.69184 .01472 L
.69186 .01472 L
.69187 .01472 L
.69189 .01472 L
.69192 .01472 L
.69195 .01472 L
.69198 .01472 L
.69201 .01472 L
.69204 .01472 L
.69207 .01472 L
.69209 .01472 L
.69212 .01472 L
.69215 .01472 L
.69217 .01472 L
.6922 .01472 L
.69223 .01472 L
.69226 .01472 L
.69229 .01472 L
.69232 .01472 L
.69234 .01472 L
.69236 .01472 L
.69239 .01472 L
.69242 .01472 L
.69244 .01472 L
.69247 .01472 L
.6925 .01472 L
.69253 .01472 L
.69255 .01472 L
Mistroke
.69257 .01472 L
.6926 .01472 L
.69263 .01472 L
.69265 .01472 L
.69268 .01472 L
.69271 .01472 L
.69274 .01472 L
.69277 .01472 L
.69278 .01472 L
.6928 .01472 L
.69283 .01472 L
.69286 .01472 L
.69288 .01472 L
.69292 .01472 L
.69295 .01472 L
.69297 .01472 L
.693 .01472 L
.69303 .01472 L
.69306 .01472 L
.69308 .01472 L
.69311 .01472 L
.69314 .01472 L
.69317 .01472 L
.6932 .01472 L
.69323 .01472 L
.69325 .01472 L
.69326 .01472 L
.6933 .01472 L
.69333 .01472 L
.69335 .01472 L
.69338 .01472 L
.69341 .01472 L
.69344 .01472 L
.69346 .01472 L
.69348 .01472 L
.69351 .01472 L
.69354 .01472 L
.69356 .01472 L
.69359 .01472 L
.69362 .01472 L
.69365 .01472 L
.69368 .01472 L
.69369 .01472 L
.69371 .01472 L
.69374 .01472 L
.69377 .01472 L
.69379 .01472 L
.69383 .01472 L
.69386 .01472 L
.69388 .01472 L
Mistroke
.69391 .01472 L
.69394 .01472 L
.69397 .01472 L
.69399 .01472 L
.69402 .01472 L
.69405 .01472 L
.69408 .01472 L
.69411 .01472 L
.69414 .01472 L
.69416 .01472 L
.69418 .01472 L
.69421 .01472 L
.69424 .01472 L
.69426 .01472 L
.69429 .01472 L
.69432 .01472 L
.69435 .01472 L
.69437 .01472 L
.69439 .01472 L
.69442 .01472 L
.69445 .01472 L
.69447 .01472 L
.6945 .01472 L
.69453 .01472 L
.69456 .01472 L
.69459 .01472 L
.6946 .01472 L
.69462 .01472 L
.69465 .01472 L
.69468 .01472 L
.69471 .01472 L
.69472 .01472 L
.69474 .01472 L
.69477 .01472 L
.6948 .01472 L
.69482 .01472 L
.69485 .01472 L
.69487 .01472 L
.6949 .01472 L
.69493 .01472 L
.69495 .01472 L
.69497 .01472 L
.695 .01472 L
.69502 .01472 L
.69503 .01472 L
.69506 .01472 L
.69509 .01472 L
.69512 .01472 L
.69515 .01472 L
.69517 .01472 L
Mistroke
.6952 .01472 L
.69523 .01472 L
.69525 .01472 L
.69528 .01472 L
.69531 .01472 L
.69534 .01472 L
.69536 .01472 L
.69539 .01472 L
.69542 .01472 L
.69544 .01472 L
.69547 .01472 L
.6955 .01472 L
.69553 .01472 L
.69556 .01472 L
.69559 .01472 L
.69562 .01472 L
.69565 .01472 L
.69566 .01472 L
.69568 .01472 L
.6957 .01472 L
.69572 .01472 L
.69575 .01472 L
.69577 .01472 L
.6958 .01472 L
.69583 .01472 L
.69586 .01472 L
.69589 .01472 L
.69592 .01472 L
.69594 .01472 L
.69597 .01472 L
.696 .01472 L
.69603 .01472 L
.69606 .01472 L
.69609 .01472 L
.69612 .01472 L
.69615 .01472 L
.69617 .01472 L
.69621 .01472 L
.69622 .01472 L
.69624 .01472 L
.69627 .01472 L
.69629 .01472 L
.6963 .01472 L
.69632 .01472 L
.69634 .01472 L
.69637 .01472 L
.69638 .01472 L
.6964 .01472 L
.69642 .01472 L
.69644 .01472 L
Mistroke
.69645 .01472 L
.69647 .01472 L
.69649 .01472 L
.6965 .01472 L
.69653 .01472 L
.69656 .01472 L
.69659 .01472 L
.69662 .01472 L
.69665 .01472 L
.69668 .01472 L
.69671 .01472 L
.69673 .01472 L
.69676 .01472 L
.69679 .01472 L
.69682 .01472 L
.69685 .01472 L
.69688 .01472 L
.6969 .01472 L
.69694 .01472 L
.69695 .01472 L
.69697 .01472 L
.697 .01472 L
.69703 .01472 L
.69706 .01472 L
.69708 .01472 L
.69711 .01472 L
.69714 .01472 L
.69717 .01472 L
.69719 .01472 L
.69721 .01472 L
.69724 .01472 L
.69727 .01472 L
.6973 .01472 L
.69733 .01472 L
.69735 .01472 L
.69738 .01472 L
.6974 .01472 L
.69741 .01472 L
.69744 .01472 L
.69747 .01472 L
.6975 .01472 L
.69753 .01472 L
.69756 .01472 L
.69759 .01472 L
.69762 .01472 L
.69764 .01472 L
.69767 .01472 L
.6977 .01472 L
.69773 .01472 L
.69776 .01472 L
Mistroke
.69779 .01472 L
.69781 .01472 L
.69785 .01472 L
.69786 .01472 L
.69788 .01472 L
.69791 .01472 L
.69794 .01472 L
.69797 .01472 L
.69799 .01472 L
.69802 .01472 L
.69805 .01472 L
.69808 .01472 L
.6981 .01472 L
.69813 .01472 L
.69815 .01472 L
.69818 .01472 L
.69821 .01472 L
.69824 .01472 L
.69826 .01472 L
.69829 .01472 L
.69831 .01472 L
.69832 .01472 L
.69835 .01472 L
.69838 .01472 L
.69841 .01472 L
.69843 .01472 L
.69844 .01472 L
.69847 .01472 L
.6985 .01472 L
.69853 .01472 L
.69855 .01472 L
.69858 .01472 L
.69861 .01472 L
.69864 .01472 L
.69866 .01472 L
.69867 .01472 L
.6987 .01472 L
.69872 .01472 L
.69874 .01472 L
.69877 .01472 L
.6988 .01472 L
.69883 .01472 L
.69885 .01472 L
.69888 .01472 L
.69891 .01472 L
.69893 .01472 L
.69895 .01472 L
.69898 .01472 L
.69901 .01472 L
.69904 .01472 L
Mistroke
.69907 .01472 L
.6991 .01472 L
.69912 .01472 L
.69915 .01472 L
.69918 .01472 L
.69921 .01472 L
.69924 .01472 L
.69926 .01472 L
.69929 .01472 L
.69932 .01472 L
.69935 .01472 L
.69937 .01472 L
.69939 .01472 L
.6994 .01472 L
.69942 .01472 L
.69945 .01472 L
.69948 .01472 L
.69951 .01472 L
.69954 .01472 L
.69957 .01472 L
.69959 .01472 L
.69962 .01472 L
.69965 .01472 L
.69967 .01472 L
.69971 .01472 L
.69974 .01472 L
.69976 .01472 L
.69979 .01472 L
.69982 .01472 L
.69985 .01472 L
.69988 .01472 L
.69991 .01472 L
.69993 .01472 L
.69995 .01472 L
.69998 .01472 L
.69999 .01472 L
.70001 .01472 L
.70002 .01472 L
.70004 .01472 L
.70007 .01472 L
.70009 .01472 L
.7001 .01472 L
.70012 .01472 L
.70014 .01472 L
.70016 .01472 L
.70017 .01472 L
.70019 .01472 L
.70021 .01472 L
.70024 .01472 L
.70027 .01472 L
Mistroke
.70029 .01472 L
.70033 .01472 L
.70036 .01472 L
.70038 .01472 L
.70041 .01472 L
.70044 .01472 L
.70046 .01472 L
.70049 .01472 L
.70052 .01472 L
.70055 .01472 L
.70058 .01472 L
.70061 .01472 L
.70064 .01472 L
.70066 .01472 L
.70067 .01472 L
.70071 .01472 L
.70074 .01472 L
.70076 .01472 L
.70079 .01472 L
.70082 .01472 L
.70084 .01472 L
.70087 .01472 L
.70089 .01472 L
.70092 .01472 L
.70095 .01472 L
.70097 .01472 L
.701 .01472 L
.70103 .01472 L
.70106 .01472 L
.70108 .01472 L
.7011 .01472 L
.70112 .01472 L
.70114 .01472 L
.70117 .01472 L
.7012 .01472 L
.70124 .01472 L
.70127 .01472 L
.70129 .01472 L
.70132 .01472 L
.70135 .01472 L
.70137 .01472 L
.7014 .01472 L
.70143 .01472 L
.70146 .01472 L
.70149 .01472 L
.70152 .01472 L
.70155 .01472 L
.70157 .01472 L
.70158 .01472 L
.70162 .01472 L
Mistroke
.70165 .01472 L
.70167 .01472 L
.7017 .01472 L
.70173 .01472 L
.70175 .01472 L
.70178 .01472 L
.7018 .01472 L
.70183 .01472 L
.70186 .01472 L
.70188 .01472 L
.70191 .01472 L
.70194 .01472 L
.70197 .01472 L
.702 .01472 L
.70201 .01472 L
.70203 .01472 L
.70206 .01472 L
.70209 .01472 L
.70211 .01472 L
.70213 .01472 L
.70215 .01472 L
.70217 .01472 L
.7022 .01472 L
.70223 .01472 L
.70226 .01472 L
.70228 .01472 L
.70231 .01472 L
.70234 .01472 L
.70236 .01472 L
.70237 .01472 L
.70241 .01472 L
.70242 .01472 L
.70244 .01472 L
.70247 .01472 L
.7025 .01472 L
.70253 .01472 L
.70256 .01472 L
.70258 .01472 L
.70261 .01472 L
.70263 .01472 L
.70266 .01472 L
.70269 .01472 L
.70272 .01472 L
.70274 .01472 L
.70277 .01472 L
.7028 .01472 L
.70283 .01472 L
.70285 .01472 L
.70288 .01472 L
.70291 .01472 L
Mistroke
.70294 .01472 L
.70297 .01472 L
.703 .01472 L
.70303 .01472 L
.70306 .01472 L
.70307 .01472 L
.70309 .01472 L
.70311 .01472 L
.70312 .01472 L
.70315 .01472 L
.70318 .01472 L
.70321 .01472 L
.70324 .01472 L
.70327 .01472 L
.7033 .01472 L
.70332 .01472 L
.70335 .01472 L
.70338 .01472 L
.70341 .01472 L
.70344 .01472 L
.70347 .01472 L
.7035 .01472 L
.70353 .01472 L
.70356 .01472 L
.70358 .01472 L
.70361 .01472 L
.70363 .01472 L
.70365 .01472 L
.70368 .01472 L
.7037 .01472 L
.70371 .01472 L
.70373 .01472 L
.70374 .01472 L
.70377 .01472 L
.70379 .01472 L
.70381 .01472 L
.70382 .01472 L
.70384 .01472 L
.70386 .01472 L
.70388 .01472 L
.70389 .01472 L
.70391 .01472 L
.70394 .01472 L
.70397 .01472 L
.704 .01472 L
.70403 .01472 L
.70406 .01472 L
.70409 .01472 L
.70411 .01472 L
.70414 .01472 L
Mistroke
.70417 .01472 L
.70419 .01472 L
.70422 .01472 L
.70426 .01472 L
.70428 .01472 L
.70431 .01472 L
.70434 .01472 L
.70436 .01472 L
.70438 .01472 L
.70441 .01472 L
.70444 .01472 L
.70446 .01472 L
.70449 .01472 L
.70452 .01472 L
.70455 .01472 L
.70457 .01472 L
.7046 .01472 L
.70462 .01472 L
.70465 .01472 L
.70468 .01472 L
.70471 .01472 L
.70473 .01472 L
.70476 .01472 L
.70479 .01472 L
.7048 .01472 L
.70482 .01472 L
.70485 .01472 L
.70488 .01472 L
.70491 .01472 L
.70494 .01472 L
.70497 .01472 L
.705 .01472 L
.70502 .01472 L
.70505 .01472 L
.70508 .01472 L
.7051 .01472 L
.70513 .01472 L
.70517 .01472 L
.70519 .01472 L
.70522 .01472 L
.70525 .01472 L
.70527 .01472 L
.70529 .01472 L
.70532 .01472 L
.70535 .01472 L
.70537 .01472 L
.7054 .01472 L
.70543 .01472 L
.70546 .01472 L
.70548 .01472 L
Mistroke
.70551 .01472 L
.70553 .01472 L
.70556 .01472 L
.70559 .01472 L
.70562 .01472 L
.70564 .01472 L
.70567 .01472 L
.7057 .01472 L
.70571 .01472 L
.70573 .01472 L
.70576 .01472 L
.70579 .01472 L
.70582 .01472 L
.70583 .01472 L
.70585 .01472 L
.70588 .01472 L
.70591 .01472 L
.70593 .01472 L
.70596 .01472 L
.70599 .01472 L
.70602 .01472 L
.70604 .01472 L
.70606 .01472 L
.70608 .01472 L
.70611 .01472 L
.70613 .01472 L
.70614 .01472 L
.70617 .01472 L
.7062 .01472 L
.70623 .01472 L
.70626 .01472 L
.70628 .01472 L
.70631 .01472 L
.70634 .01472 L
.70636 .01472 L
.70639 .01472 L
.70642 .01472 L
.70645 .01472 L
.70647 .01472 L
.7065 .01472 L
.70653 .01472 L
.70656 .01472 L
.70658 .01472 L
.70661 .01472 L
.70664 .01472 L
.70667 .01472 L
.7067 .01472 L
.70673 .01472 L
.70676 .01472 L
.70677 .01472 L
Mistroke
.70679 .01472 L
.70681 .01472 L
.70683 .01472 L
.70686 .01472 L
.70688 .01472 L
.70691 .01472 L
.70694 .01472 L
.70697 .01472 L
.707 .01472 L
.70703 .01472 L
.70705 .01472 L
.70708 .01472 L
.70711 .01472 L
.70714 .01472 L
.70717 .01472 L
.7072 .01472 L
.70723 .01472 L
.70726 .01472 L
.70728 .01472 L
.70732 .01472 L
.70733 .01472 L
.70735 .01472 L
.70738 .01472 L
.7074 .01472 L
.70741 .01472 L
.70743 .01472 L
.70745 .01472 L
.70748 .01472 L
.70749 .01472 L
.70751 .01472 L
.70753 .01472 L
.70755 .01472 L
.70756 .01472 L
.70758 .01472 L
.7076 .01472 L
.70761 .01472 L
.70764 .01472 L
.70767 .01472 L
.7077 .01472 L
.70773 .01472 L
.70776 .01472 L
.70779 .01472 L
.70782 .01472 L
.70784 .01472 L
.70787 .01472 L
.7079 .01472 L
.70793 .01472 L
.70796 .01472 L
.70798 .01472 L
.70801 .01472 L
Mistroke
.70805 .01472 L
.70806 .01472 L
.70808 .01472 L
.70811 .01472 L
.70814 .01472 L
.70817 .01472 L
.70819 .01472 L
.70822 .01472 L
.70825 .01472 L
.70827 .01472 L
.7083 .01472 L
.70832 .01472 L
.70835 .01472 L
.70838 .01472 L
.70841 .01472 L
.70843 .01472 L
.70846 .01472 L
.70849 .01472 L
.70851 .01472 L
.70852 .01472 L
.70855 .01472 L
.70858 .01472 L
.70861 .01472 L
.70864 .01472 L
.70867 .01472 L
.7087 .01472 L
.70873 .01472 L
.70875 .01472 L
.70878 .01472 L
.70881 .01472 L
.70884 .01472 L
.70887 .01472 L
.70889 .01472 L
.70892 .01472 L
.70895 .01472 L
.70897 .01472 L
.70899 .01472 L
.70902 .01472 L
.70905 .01472 L
.70907 .01472 L
.7091 .01472 L
.70913 .01472 L
.70916 .01472 L
.70918 .01472 L
.70921 .01472 L
.70923 .01472 L
.70926 .01472 L
.70929 .01472 L
.70932 .01472 L
.70934 .01472 L
Mistroke
.70937 .01472 L
.7094 .01472 L
.70942 .01472 L
.70943 .01472 L
.70946 .01472 L
.70949 .01472 L
.70952 .01472 L
.70955 .01472 L
.70958 .01472 L
.70961 .01472 L
.70963 .01472 L
.70966 .01472 L
.70969 .01472 L
.70972 .01472 L
.70975 .01472 L
.70978 .01472 L
.7098 .01472 L
.70983 .01472 L
.70987 .01472 L
.70988 .01472 L
.7099 .01472 L
.70993 .01472 L
.70996 .01472 L
.70999 .01472 L
.71001 .01472 L
.71004 .01472 L
.71007 .01472 L
.7101 .01472 L
.71012 .01472 L
.71015 .01472 L
.71017 .01472 L
.7102 .01472 L
.71023 .01472 L
.71026 .01472 L
.71028 .01472 L
.71031 .01472 L
.71033 .01472 L
.71034 .01472 L
.71037 .01472 L
.7104 .01472 L
.71043 .01472 L
.71045 .01472 L
.71046 .01472 L
.71049 .01472 L
.71052 .01472 L
.71055 .01472 L
.71057 .01472 L
.7106 .01472 L
.71063 .01472 L
.71066 .01472 L
Mistroke
.71067 .01472 L
.71069 .01472 L
.71072 .01472 L
.71074 .01472 L
.71076 .01472 L
.71078 .01472 L
.71082 .01472 L
.71085 .01472 L
.71087 .01472 L
.7109 .01472 L
.71092 .01472 L
.71095 .01472 L
.71097 .01472 L
.711 .01472 L
.71103 .01472 L
.71106 .01472 L
.71109 .01472 L
.71112 .01472 L
.71114 .01472 L
.71117 .01472 L
.7112 .01472 L
.71123 .01472 L
.71126 .01472 L
.71128 .01472 L
.71131 .01472 L
.71134 .01472 L
.71137 .01472 L
.71139 .01472 L
.71141 .01472 L
.71142 .01472 L
.71144 .01472 L
.71147 .01472 L
.7115 .01472 L
.71153 .01472 L
.71156 .01472 L
.71159 .01472 L
.71161 .01472 L
.71164 .01472 L
.71167 .01472 L
.71169 .01472 L
.71173 .01472 L
.71176 .01472 L
.71178 .01472 L
.71181 .01472 L
.71184 .01472 L
.71187 .01472 L
.7119 .01472 L
.71193 .01472 L
.71195 .01472 L
.71196 .01472 L
Mistroke
.71199 .01472 L
.71201 .01472 L
.71203 .01472 L
.71204 .01472 L
.71206 .01472 L
.71209 .01472 L
.71211 .01472 L
.71212 .01472 L
.71214 .01472 L
.71216 .01472 L
.71218 .01472 L
.71219 .01472 L
.71221 .01472 L
.71223 .01472 L
.71225 .01472 L
.71229 .01472 L
.71231 .01472 L
.71235 .01472 L
.71238 .01472 L
.7124 .01472 L
.71243 .01472 L
.71246 .01472 L
.71248 .01472 L
.71251 .01472 L
.71254 .01472 L
.71257 .01472 L
.7126 .01472 L
.71263 .01472 L
.71266 .01472 L
.71268 .01472 L
.71269 .01472 L
.71273 .01472 L
.71276 .01472 L
.71278 .01472 L
.71281 .01472 L
.71284 .01472 L
.71286 .01472 L
.71289 .01472 L
.71291 .01472 L
.71294 .01472 L
.71297 .01472 L
.71299 .01472 L
.71302 .01472 L
.71305 .01472 L
.71308 .01472 L
.7131 .01472 L
.71312 .01472 L
.71314 .01472 L
.71316 .01472 L
.71319 .01472 L
Mistroke
.71322 .01472 L
.71326 .01472 L
.71329 .01472 L
.71331 .01472 L
.71334 .01472 L
.71337 .01472 L
.71339 .01472 L
.71342 .01472 L
.71345 .01472 L
.71348 .01472 L
.71351 .01472 L
.71354 .01472 L
.71357 .01472 L
.71359 .01472 L
.7136 .01472 L
.71364 .01472 L
.71367 .01472 L
.71369 .01472 L
.71372 .01472 L
.71375 .01472 L
.71378 .01472 L
.7138 .01472 L
.71382 .01472 L
.71385 .01472 L
.71388 .01472 L
.7139 .01472 L
.71393 .01472 L
.71396 .01472 L
.71399 .01472 L
.71402 .01472 L
.71403 .01472 L
.71405 .01472 L
.71408 .01472 L
.71411 .01472 L
.71413 .01472 L
.71415 .01472 L
.71417 .01472 L
.71419 .01472 L
.71422 .01472 L
.71425 .01472 L
.71428 .01472 L
.7143 .01472 L
.71433 .01472 L
.71436 .01472 L
.71438 .01472 L
.7144 .01472 L
.71443 .01472 L
.71444 .01472 L
.71446 .01472 L
.71449 .01472 L
Mistroke
.71452 .01472 L
.71455 .01472 L
.71458 .01472 L
.7146 .01472 L
.71463 .01472 L
.71466 .01472 L
.71468 .01472 L
.71471 .01472 L
.71474 .01472 L
.71476 .01472 L
.71479 .01472 L
.71482 .01472 L
.71485 .01472 L
.71487 .01472 L
.7149 .01472 L
.71493 .01472 L
.71496 .01472 L
.71499 .01472 L
.71502 .01472 L
.71505 .01472 L
.71508 .01472 L
.71509 .01472 L
.71511 .01472 L
.71513 .01472 L
.71514 .01472 L
.71517 .01472 L
.7152 .01472 L
.71523 .01472 L
.71526 .01472 L
.71529 .01472 L
.71532 .01472 L
.71535 .01472 L
.71537 .01472 L
.7154 .01472 L
.71543 .01472 L
.71546 .01472 L
.71549 .01472 L
.71552 .01472 L
.71555 .01472 L
.71558 .01472 L
.7156 .01472 L
.71564 .01472 L
.71565 .01472 L
.71567 .01472 L
.7157 .01472 L
.71571 .01472 L
.71573 .01472 L
.71575 .01472 L
.71576 .01472 L
.7158 .01472 L
Mistroke
.71581 .01472 L
.71583 .01472 L
.71585 .01472 L
.71586 .01472 L
.71588 .01472 L
.7159 .01472 L
.71592 .01472 L
.71593 .01472 L
.71596 .01472 L
.71599 .01472 L
.71602 .01472 L
.71605 .01472 L
.71608 .01472 L
.71611 .01472 L
.71614 .01472 L
.71616 .01472 L
.71619 .01472 L
.71622 .01472 L
.71625 .01472 L
.71628 .01472 L
.7163 .01472 L
.71633 .01472 L
.71636 .01472 L
.71638 .01472 L
.7164 .01472 L
.71643 .01472 L
.71646 .60332 L
.71648 .60332 L
.71651 .60332 L
.71657 .60332 L
.71667 .60332 L
.7169 .60332 L
.71787 .60332 L
.7188 .60332 L
.71978 .60332 L
.72074 .60332 L
.72165 .60332 L
.72263 .60332 L
.72356 .60332 L
.72456 .60332 L
.72552 .60332 L
.72645 .60332 L
.72743 .60332 L
.72838 .60332 L
.72929 .60332 L
.73026 .60332 L
.73119 .60332 L
.73218 .60332 L
.73268 .60332 L
.73314 .60332 L
Mistroke
.73337 .60332 L
.73358 .60332 L
.73364 .60332 L
.7337 .60332 L
.73373 .60332 L
.73375 .60332 L
.73377 .01472 L
.7338 .01472 L
.73382 .01472 L
.73383 .01472 L
.73386 .01472 L
.73389 .01472 L
.73392 .01472 L
.73395 .01472 L
.73397 .01472 L
.734 .01472 L
.73403 .01472 L
.73406 .01472 L
.73407 .01472 L
.73409 .01472 L
.73412 .01472 L
.73415 .01472 L
.73417 .01472 L
.73418 .01472 L
.73421 .01472 L
.73424 .01472 L
.73427 .01472 L
.7343 .01472 L
.73432 .01472 L
.73433 .01472 L
.73435 .01472 L
.73437 .01472 L
.7344 .01472 L
.73443 .01472 L
.73444 .01472 L
.73446 .01472 L
.73449 .01472 L
.73451 .01472 L
.73453 .01472 L
.73455 .01472 L
.73456 .01472 L
.73458 .01472 L
.7346 .01472 L
.73463 .01472 L
.73466 .01472 L
.73469 .01472 L
.73472 .01472 L
.73473 .01472 L
.73475 .01472 L
.73476 .01472 L
Mistroke
.73478 .01472 L
.7348 .01472 L
.73481 .01472 L
.73484 .01472 L
.73487 .01472 L
.7349 .01472 L
.73493 .01472 L
.73496 .01472 L
.73497 .01472 L
.73499 .01472 L
.73502 .01472 L
.73505 .01472 L
.73508 .01472 L
.73509 .01472 L
.73511 .01472 L
.73514 .01472 L
.73517 .01472 L
.73519 .01472 L
.73522 .01472 L
.73525 .01472 L
.73528 .01472 L
.7353 .01472 L
.73532 .01472 L
.73534 .01472 L
.73537 .01472 L
.73539 .01472 L
.7354 .01472 L
.73543 .01472 L
.73546 .01472 L
.73549 .01472 L
.73552 .01472 L
.73554 .01472 L
.73557 .01472 L
.7356 .01472 L
.73562 .01472 L
.73565 .01472 L
.73568 .01472 L
.73571 .01472 L
.73573 .01472 L
.73576 .01472 L
.73579 .01472 L
.73581 .01472 L
.73584 .01472 L
.73587 .01472 L
.7359 .01472 L
.73593 .01472 L
.73596 .01472 L
.73599 .01472 L
.73602 .01472 L
.73604 .01472 L
Mistroke
.73605 .01472 L
.73607 .01472 L
.73609 .01472 L
.73612 .01472 L
.73614 .01472 L
.73616 .01472 L
.73618 .01472 L
.73621 .01472 L
.73624 .01472 L
.73626 .01472 L
.73629 .01472 L
.73632 .01472 L
.73635 .01472 L
.73637 .01472 L
.7364 .01472 L
.73643 .01472 L
.73646 .01472 L
.73649 .01472 L
.73651 .01472 L
.73652 .01472 L
.73655 .01472 L
.73658 .01472 L
.73661 .01472 L
.73664 .01472 L
.73667 .01472 L
.73669 .01472 L
.7367 .01472 L
.73674 .01472 L
.73675 .01472 L
.73677 .01472 L
.73679 .01472 L
.73681 .01472 L
.73682 .01472 L
.73684 .01472 L
.73686 .01472 L
.73687 .01472 L
.7369 .01472 L
.73693 .01472 L
.73696 .01472 L
.73699 .01472 L
.73702 .01472 L
.73705 .01472 L
.73708 .01472 L
.7371 .01472 L
.73713 .01472 L
.73716 .01472 L
.73719 .01472 L
.73722 .01472 L
.73725 .01472 L
.73728 .01472 L
Mistroke
.73731 .01472 L
.73733 .01472 L
.73734 .01472 L
.73737 .01472 L
.7374 .01472 L
.73743 .01472 L
.73746 .01472 L
.73749 .01472 L
.73751 .01472 L
.73754 .01472 L
.73756 .01472 L
.73759 .01472 L
.73761 .01472 L
.73764 .01472 L
.73767 .01472 L
.7377 .01472 L
.73772 .01472 L
.73775 .01472 L
.73777 .01472 L
.73779 .01472 L
.73781 .01472 L
.73784 .01472 L
.73787 .01472 L
.73789 .01472 L
.7379 .01472 L
.73793 .01472 L
.73796 .01472 L
.73799 .01472 L
.73801 .01472 L
.73804 .01472 L
.73807 .01472 L
.7381 .01472 L
.73812 .01472 L
.73813 .01472 L
.73816 .01472 L
.73818 .01472 L
.7382 .01472 L
.73823 .01472 L
.73826 .01472 L
.73829 .01472 L
.73831 .01472 L
.73834 .01472 L
.73837 .01472 L
.73839 .01472 L
.73842 .01472 L
.73844 .01472 L
.73847 .01472 L
.7385 .01472 L
.73853 .01472 L
.73856 .01472 L
Mistroke
.73859 .01472 L
.73861 .01472 L
.73864 .01472 L
.73867 .01472 L
.7387 .01472 L
.73873 .01472 L
.73875 .01472 L
.73879 .01472 L
.73882 .01472 L
.73883 .01472 L
.73885 .01472 L
.73886 .01472 L
.73888 .01472 L
.73891 .01472 L
.73894 .01472 L
.73897 .01472 L
.739 .01472 L
.73903 .01472 L
.73906 .01472 L
.73908 .01472 L
.73911 .01472 L
.73914 .01472 L
.73917 .01472 L
.7392 .01472 L
.73922 .01472 L
.73925 .01472 L
.73928 .01472 L
.73931 .01472 L
.73934 .01472 L
.73937 .01472 L
.73939 .01472 L
.73941 .01472 L
.73944 .01472 L
.73945 .01472 L
.73947 .01472 L
.73948 .01472 L
.7395 .01472 L
.73953 .01472 L
.73955 .01472 L
.73957 .01472 L
.73958 .01472 L
.7396 .01472 L
.73962 .01472 L
.73964 .01472 L
.73965 .01472 L
.73967 .01472 L
.7397 .01472 L
.73973 .01472 L
.73976 .01472 L
.73979 .01472 L
Mistroke
.73982 .01472 L
.73984 .01472 L
.73987 .01472 L
.7399 .01472 L
.73993 .01472 L
.73995 .01472 L
.73998 .01472 L
.74001 .01472 L
.74004 .01472 L
.74007 .01472 L
.7401 .01472 L
.74012 .01472 L
.74013 .01472 L
.74017 .01472 L
.7402 .01472 L
.74022 .01472 L
.74025 .01472 L
.74028 .01472 L
.7403 .01472 L
.74033 .01472 L
.74035 .01472 L
.74038 .01472 L
.74041 .01472 L
.74043 .01472 L
.74046 .01472 L
.74049 .01472 L
.74052 .01472 L
.74055 .01472 L
.74056 .01472 L
.74058 .01472 L
.74061 .01472 L
.74064 .01472 L
.74066 .01472 L
.7407 .01472 L
.74073 .01472 L
.74075 .01472 L
.74078 .01472 L
.74081 .01472 L
.74083 .01472 L
.74086 .01472 L
.74089 .01472 L
.74092 .01472 L
.74095 .01472 L
.74098 .01472 L
.74101 .01472 L
.74103 .01472 L
.74104 .01472 L
.74108 .01472 L
.74111 .01472 L
.74113 .01472 L
Mistroke
.74116 .01472 L
.74119 .01472 L
.74121 .01472 L
.74124 .01472 L
.74126 .01472 L
.74129 .01472 L
.74132 .01472 L
.74134 .01472 L
.74137 .01472 L
.7414 .01472 L
.74143 .01472 L
.74146 .01472 L
.74147 .01472 L
.74149 .01472 L
.74152 .01472 L
.74155 .01472 L
.74157 .01472 L
.74161 .01472 L
.74164 .01472 L
.74166 .01472 L
.74169 .01472 L
.74172 .01472 L
.74175 .01472 L
.74177 .01472 L
.7418 .01472 L
.74183 .01472 L
.74186 .01472 L
.74189 .01472 L
.74192 .01472 L
.74194 .01472 L
.74196 .01472 L
.74199 .01472 L
.74202 .01472 L
.74204 .01472 L
.74207 .01472 L
.7421 .01472 L
.74213 .01472 L
.74215 .01472 L
.74217 .01472 L
.7422 .01472 L
.74223 .01472 L
.74225 .01472 L
.74228 .01472 L
.74231 .01472 L
.74234 .01472 L
.74237 .01472 L
.74238 .01472 L
.7424 .01472 L
.74243 .01472 L
.74246 .01472 L
Mistroke
.74249 .01472 L
.7425 .01472 L
.74252 .01472 L
.74255 .01472 L
.74258 .01472 L
.7426 .01472 L
.74263 .01472 L
.74265 .01472 L
.74268 .01472 L
.74271 .01472 L
.74273 .01472 L
.74275 .01472 L
.74278 .01472 L
.7428 .01472 L
.74281 .01472 L
.74284 .01472 L
.74287 .01472 L
.7429 .01472 L
.74293 .01472 L
.74295 .01472 L
.74298 .01472 L
.74301 .01472 L
.74303 .01472 L
.74306 .01472 L
.74309 .01472 L
.74312 .01472 L
.74314 .01472 L
.74317 .01472 L
.7432 .01472 L
.74322 .01472 L
.74325 .01472 L
.74328 .01472 L
.74331 .01472 L
.74334 .01472 L
.74337 .01472 L
.7434 .01472 L
.74343 .01472 L
.74344 .01472 L
.74346 .01472 L
.74348 .01472 L
.7435 .01472 L
.74353 .01472 L
.74355 .01472 L
.74358 .01472 L
.74361 .01472 L
.74364 .01472 L
.74367 .01472 L
.7437 .01472 L
.74372 .01472 L
.74375 .01472 L
Mistroke
.74378 .01472 L
.74381 .01472 L
.74384 .01472 L
.74387 .01472 L
.7439 .01472 L
.74393 .01472 L
.74395 .01472 L
.74399 .01472 L
.744 .01472 L
.74402 .01472 L
.74405 .01472 L
.74407 .01472 L
.74408 .01472 L
.7441 .01472 L
.74412 .01472 L
.74415 .01472 L
.74416 .01472 L
.74418 .01472 L
.7442 .01472 L
.74422 .01472 L
.74423 .01472 L
.74425 .01472 L
.74427 .01472 L
.74428 .01472 L
.74431 .01472 L
.74434 .01472 L
.74437 .01472 L
.7444 .01472 L
.74443 .01472 L
.74446 .01472 L
.74449 .01472 L
.74451 .01472 L
.74454 .01472 L
.74457 .01472 L
.7446 .01472 L
.74463 .01472 L
.74466 .01472 L
.74468 .01472 L
.74472 .01472 L
.74473 .01472 L
.74475 .01472 L
.74478 .01472 L
.74481 .01472 L
.74484 .01472 L
.74486 .01472 L
.74489 .01472 L
.74492 .01472 L
.74495 .01472 L
.74497 .01472 L
.74499 .01472 L
Mistroke
.74502 .01472 L
.74505 .01472 L
.74508 .01472 L
.74511 .01472 L
.74513 .01472 L
.74516 .01472 L
.74518 .01472 L
.74519 .01472 L
.74522 .01472 L
.74525 .01472 L
.74528 .01472 L
.74531 .01472 L
.74534 .01472 L
.74537 .01472 L
.7454 .01472 L
.74542 .01472 L
.74545 .01472 L
.74548 .01472 L
.74551 .01472 L
.74554 .01472 L
.74557 .01472 L
.7456 .01472 L
.74563 .01472 L
.74564 .01472 L
.74566 .01472 L
.74569 .01472 L
.74572 .01472 L
.74575 .01472 L
.74577 .01472 L
.7458 .01472 L
.74583 .01472 L
.74586 .01472 L
.74588 .01472 L
.74591 .01472 L
.74593 .01472 L
.74596 .01472 L
.74599 .01472 L
.74602 .01472 L
.74604 .01472 L
.74607 .01472 L
.74609 .01472 L
.7461 .01472 L
.74613 .01472 L
.74616 .01472 L
.74619 .01472 L
.74621 .01472 L
.74622 .01472 L
.74625 .01472 L
.74628 .01472 L
.74631 .01472 L
Mistroke
.74633 .01472 L
.74636 .01472 L
.74639 .01472 L
.74642 .01472 L
.74644 .01472 L
.74645 .01472 L
.74648 .01472 L
.7465 .01472 L
.74652 .01472 L
.74655 .01472 L
.74658 .01472 L
.74661 .01472 L
.74663 .01472 L
.74666 .01472 L
.74669 .01472 L
.74671 .01472 L
.74674 .01472 L
.74676 .01472 L
.74679 .01472 L
.74682 .01472 L
.74685 .01472 L
.74688 .01472 L
.74691 .01472 L
.74693 .01472 L
.74696 .01472 L
.74699 .01472 L
.74702 .01472 L
.74704 .01472 L
.74707 .01472 L
.74711 .01472 L
.74713 .01472 L
.74715 .01472 L
.74717 .01472 L
.74718 .01472 L
.7472 .01472 L
.74723 .01472 L
.74726 .01472 L
.74729 .01472 L
.74732 .01472 L
.74735 .01472 L
.74738 .01472 L
.7474 .01472 L
.74743 .01472 L
.74746 .01472 L
.74749 .01472 L
.74752 .01472 L
.74754 .01472 L
.74757 .01472 L
.7476 .01472 L
.74763 .01472 L
Mistroke
.74766 .01472 L
.74769 .01472 L
.74771 .01472 L
.74773 .01472 L
.74776 .01472 L
.74777 .01472 L
.74779 .01472 L
.7478 .01472 L
.74782 .01472 L
.74785 .01472 L
.74787 .01472 L
.74788 .01472 L
.7479 .01472 L
.74792 .01472 L
.74794 .01472 L
.74795 .01472 L
.74797 .01472 L
.74799 .01472 L
.74802 .01472 L
.74805 .01472 L
.74808 .01472 L
.74811 .01472 L
.74814 .01472 L
.74816 .01472 L
.74819 .01472 L
.74822 .01472 L
.74825 .01472 L
.74827 .01472 L
.7483 .01472 L
.74833 .01472 L
.74836 .01472 L
.74839 .01472 L
.74842 .01472 L
.74844 .01472 L
.74845 .01472 L
.74849 .01472 L
.74852 .01472 L
.74854 .01472 L
.74857 .01472 L
.7486 .01472 L
.74863 .01472 L
.74865 .01472 L
.74867 .01472 L
.7487 .01472 L
.74873 .01472 L
.74875 .01472 L
.74878 .01472 L
.74881 .01472 L
.74884 .01472 L
.74887 .01472 L
Mistroke
.74888 .01472 L
.7489 .01472 L
.74893 .01472 L
.74896 .01472 L
.74898 .01472 L
.74902 .01472 L
.74905 .01472 L
.74907 .01472 L
.7491 .01472 L
.74913 .01472 L
.74916 .01472 L
.74918 .01472 L
.74921 .01472 L
.74924 .01472 L
.74927 .01472 L
.7493 .01472 L
.74933 .01472 L
.74935 .01472 L
.74937 .01472 L
.7494 .01472 L
.74943 .01472 L
.74945 .01472 L
.74948 .01472 L
.74951 .01472 L
.74954 .01472 L
.74956 .01472 L
.74958 .01472 L
.74961 .01472 L
.74964 .01472 L
.74966 .01472 L
.74969 .01472 L
.74972 .01472 L
.74975 .01472 L
.74978 .01472 L
.74979 .01472 L
.74981 .01472 L
.74984 .01472 L
.74987 .01472 L
.7499 .01472 L
.74991 .01472 L
.74993 .01472 L
.74996 .01472 L
.74999 .01472 L
.75001 .01472 L
.75004 .01472 L
.75006 .01472 L
.75009 .01472 L
.75012 .01472 L
.75014 .01472 L
.75016 .01472 L
Mistroke
.75019 .01472 L
.7502 .01472 L
.75022 .01472 L
.75025 .01472 L
.75028 .01472 L
.75031 .01472 L
.75034 .01472 L
.75036 .01472 L
.75039 .01472 L
.75042 .01472 L
.75044 .01472 L
.75047 .01472 L
.7505 .01472 L
.75053 .01472 L
.75055 .01472 L
.75058 .01472 L
.75061 .01472 L
.75063 .01472 L
.75066 .01472 L
.75069 .01472 L
.75072 .01472 L
.75075 .01472 L
.75078 .01472 L
.75081 .01472 L
.75084 .01472 L
.75085 .01472 L
.75087 .01472 L
.75089 .01472 L
.7509 .01472 L
.75093 .01472 L
.75096 .01472 L
.75099 .01472 L
.75102 .01472 L
.75105 .01472 L
.75108 .01472 L
.75111 .01472 L
.75113 .01472 L
.75116 .01472 L
.75119 .01472 L
.75122 .01472 L
.75125 .01472 L
.75128 .01472 L
.75131 .01472 L
.75134 .01472 L
.75136 .01472 L
.7514 .01472 L
.75141 .01472 L
.75143 .01472 L
.75146 .01472 L
.75147 .01472 L
Mistroke
.75149 .01472 L
.75151 .01472 L
.75152 .01472 L
.75156 .01472 L
.75157 .01472 L
.75159 .01472 L
.75161 .01472 L
.75162 .01472 L
.75164 .01472 L
.75166 .01472 L
.75168 .01472 L
.75169 .01472 L
.75172 .01472 L
.75175 .01472 L
.75178 .01472 L
.75181 .01472 L
.75184 .01472 L
.75187 .01472 L
.7519 .01472 L
.75192 .01472 L
.75195 .01472 L
.75198 .01472 L
.75201 .01472 L
.75204 .01472 L
.75206 .01472 L
.75209 .01472 L
.75212 .01472 L
.75214 .01472 L
.75216 .01472 L
.75219 .01472 L
.75222 .01472 L
.75224 .01472 L
.75227 .01472 L
.7523 .01472 L
.75233 .01472 L
.75235 .01472 L
.75238 .01472 L
.7524 .01472 L
.75243 .01472 L
.75246 .01472 L
.75249 .01472 L
.75251 .01472 L
.75254 .01472 L
.75257 .01472 L
.75259 .01472 L
.7526 .01472 L
.75263 .01472 L
.75266 .01472 L
.75269 .01472 L
.75272 .01472 L
Mistroke
.75275 .01472 L
.75278 .01472 L
.75281 .01472 L
.75283 .01472 L
.75286 .01472 L
.75289 .01472 L
.75292 .01472 L
.75295 .01472 L
.75297 .01472 L
.753 .01472 L
.75303 .01472 L
.75305 .01472 L
.75307 .01472 L
.7531 .01472 L
.75313 .01472 L
.75315 .01472 L
.75318 .01472 L
.75321 .01472 L
.75324 .01472 L
.75326 .01472 L
.75329 .01472 L
.75331 .01472 L
.75334 .01472 L
.75337 .01472 L
.7534 .01472 L
.75342 .01472 L
.75345 .01472 L
.75348 .01472 L
.7535 .01472 L
.75351 .01472 L
.75354 .01472 L
.75357 .01472 L
.7536 .01472 L
.75362 .01472 L
.75363 .01472 L
.75366 .01472 L
.75369 .01472 L
.75371 .01472 L
.75374 .01472 L
.75377 .01472 L
.7538 .01472 L
.75383 .01472 L
.75384 .01472 L
.75386 .01472 L
.75389 .01472 L
.75391 .01472 L
.75392 .01472 L
.75395 .01472 L
.75398 .01472 L
.75401 .01472 L
Mistroke
.75404 .01472 L
.75407 .01472 L
.75409 .01472 L
.75412 .01472 L
.75414 .01472 L
.75417 .01472 L
.7542 .01472 L
.75423 .01472 L
.75425 .01472 L
.75428 .01472 L
.75431 .01472 L
.75434 .01472 L
.75436 .01472 L
.75439 .01472 L
.75442 .01472 L
.75445 .01472 L
.75448 .01472 L
.75451 .01472 L
.75454 .01472 L
.75456 .01472 L
.75457 .01472 L
.75459 .01472 L
.75461 .01472 L
.75464 .01472 L
.75466 .01472 L
.75469 .01472 L
.75473 .01472 L
.75475 .01472 L
.75478 .01472 L
.75481 .01472 L
.75483 .01472 L
.75486 .01472 L
.75489 .01472 L
.75492 .01472 L
.75495 .01472 L
.75498 .01472 L
.75501 .01472 L
.75504 .01472 L
.75507 .01472 L
.7551 .01472 L
.75512 .01472 L
.75513 .01472 L
.75516 .01472 L
.75518 .01472 L
.75519 .01472 L
.75521 .01472 L
.75523 .01472 L
.75526 .01472 L
.75528 .01472 L
.75529 .01472 L
Mistroke
.75531 .01472 L
.75533 .01472 L
.75534 .01472 L
.75536 .01472 L
.75538 .01472 L
.75539 .01472 L
.75542 .01472 L
.75545 .01472 L
.75548 .01472 L
.75551 .01472 L
.75554 .01472 L
.75557 .01472 L
.7556 .01472 L
.75562 .01472 L
.75565 .01472 L
.75568 .01472 L
.75571 .01472 L
.75574 .01472 L
.75577 .01472 L
.7558 .01472 L
.75583 .01472 L
.75584 .01472 L
.75586 .01472 L
.75589 .01472 L
.75592 .01472 L
.75595 .01472 L
.75597 .01472 L
.756 .01472 L
.75603 .01472 L
.75606 .01472 L
.75608 .01472 L
.75611 .01472 L
.75613 .01472 L
.75616 .01472 L
.75619 .01472 L
.75622 .01472 L
.75624 .01472 L
.75627 .01472 L
.75629 .01472 L
.7563 .01472 L
.75633 .01472 L
.75636 .01472 L
.75639 .01472 L
.75642 .01472 L
.75645 .01472 L
.75648 .01472 L
.75651 .01472 L
.75653 .01472 L
.75656 .01472 L
.75659 .01472 L
Mistroke
.75662 .01472 L
.75665 .01472 L
.75668 .01472 L
.7567 .01472 L
.75674 .01472 L
.75675 .01472 L
.75677 .01472 L
.7568 .01472 L
.75683 .01472 L
.75686 .01472 L
.75688 .01472 L
.75691 .01472 L
.75694 .01472 L
.75697 .01472 L
.75699 .01472 L
.75702 .01472 L
.75704 .01472 L
.75707 .01472 L
.7571 .01472 L
.75713 .01472 L
.75715 .01472 L
.75718 .01472 L
.7572 .01472 L
.75721 .01472 L
.75724 .01472 L
.75727 .01472 L
.7573 .01472 L
.75732 .01472 L
.75733 .01472 L
.75736 .01472 L
.75739 .01472 L
.75742 .01472 L
.75744 .01472 L
.75747 .01472 L
.7575 .01472 L
.75753 .01472 L
.75754 .01472 L
.75756 .01472 L
.75759 .01472 L
.75761 .01472 L
.75763 .01472 L
.75765 .01472 L
.75769 .01472 L
.75772 .01472 L
.75774 .01472 L
.75777 .01472 L
.75779 .01472 L
.75782 .01472 L
.75784 .01472 L
.75787 .01472 L
Mistroke
.7579 .01472 L
.75793 .01472 L
.75796 .01472 L
.75799 .01472 L
.75801 .01472 L
.75804 .01472 L
.75807 .01472 L
.7581 .01472 L
.75813 .01472 L
.75815 .01472 L
.75818 .01472 L
.75821 .01472 L
.75824 .01472 L
.75826 .01472 L
.75827 .01472 L
.75829 .01472 L
.75831 .01472 L
.75834 .01472 L
.75837 .01472 L
.7584 .01472 L
.75843 .01472 L
.75845 .01472 L
.75848 .01472 L
.75851 .01472 L
.75853 .01472 L
.75856 .01472 L
.75859 .01472 L
.75862 .01472 L
.75865 .01472 L
.75868 .01472 L
.75871 .01472 L
.75874 .01472 L
.75877 .01472 L
.7588 .01472 L
.75882 .01472 L
.75883 .01472 L
.75886 .01472 L
.75888 .01472 L
.7589 .01472 L
.75891 .01472 L
.75893 .01472 L
.75896 .01472 L
.75898 .01472 L
.75899 .01472 L
.75901 .01472 L
.75903 .01472 L
.75904 .01472 L
.75906 .01472 L
.75908 .01472 L
.75909 .01472 L
Mistroke
.75912 .01472 L
.75915 .01472 L
.75918 .01472 L
.75921 .01472 L
.75924 .01472 L
.75927 .01472 L
.7593 .01472 L
.75932 .01472 L
.75935 .01472 L
.75938 .01472 L
.75941 .01472 L
.75944 .01472 L
.75947 .01472 L
.7595 .01472 L
.75953 .01472 L
.75955 .01472 L
.75956 .01472 L
.75959 .01472 L
.75962 .01472 L
.75965 .01472 L
.75968 .01472 L
.7597 .01472 L
.75973 .01472 L
.75976 .01472 L
.75978 .01472 L
.75981 .01472 L
.75983 .01472 L
.75986 .01472 L
.75989 .01472 L
.75992 .01472 L
.75994 .01472 L
.75997 .01472 L
.75999 .01472 L
.76 .01472 L
.76003 .01472 L
.76006 .01472 L
.76009 .01472 L
.76012 .01472 L
.76015 .01472 L
.76018 .01472 L
.76021 .01472 L
.76023 .01472 L
.76026 .01472 L
.76029 .01472 L
.76032 .01472 L
.76035 .01472 L
.76038 .01472 L
.76041 .01472 L
.76044 .01472 L
.76046 .01472 L
Mistroke
.76047 .01472 L
.7605 .01472 L
.76053 .01472 L
.76056 .01472 L
.76059 .01472 L
.76061 .01472 L
.76064 .01472 L
.76067 .01472 L
.76069 .01472 L
.76072 .01472 L
.76074 .01472 L
.76077 .01472 L
.7608 .01472 L
.76083 .01472 L
.76085 .01472 L
.76088 .01472 L
.7609 .01472 L
.76091 .01472 L
.76094 .01472 L
.76097 .01472 L
.761 .01472 L
.76103 .01472 L
.76106 .01472 L
.76109 .01472 L
.76112 .01472 L
.76114 .01472 L
.76117 .01472 L
.7612 .01472 L
.76123 .01472 L
.76126 .01472 L
.76129 .01472 L
.76132 .01472 L
.76135 .01472 L
.76137 .01472 L
.76138 .01472 L
.76141 .01472 L
.76144 .01472 L
.76147 .01472 L
.7615 .01472 L
.76153 .01472 L
.76155 .01472 L
.76158 .01472 L
.7616 .01472 L
.76163 .01472 L
.76165 .01472 L
.76168 .01472 L
.76171 .01472 L
.76174 .01472 L
.76176 .01472 L
.76179 .01472 L
Mistroke
.76181 .01472 L
.76183 .01472 L
.76185 .01472 L
.76188 .01472 L
.76191 .01472 L
.76193 .01472 L
.76194 .01472 L
.76197 .01472 L
.762 .01472 L
.76203 .01472 L
.76205 .01472 L
.76208 .01472 L
.76211 .01472 L
.76214 .01472 L
.76216 .01472 L
.76217 .01472 L
.7622 .01472 L
.76222 .01472 L
.76224 .01472 L
.76227 .01472 L
.7623 .01472 L
.76233 .01472 L
.76235 .01472 L
.76238 .01472 L
.76241 .01472 L
.76243 .01472 L
.76246 .01472 L
.76248 .01472 L
.76251 .01472 L
.76254 .01472 L
.76257 .01472 L
.7626 .01472 L
.76263 .01472 L
.76265 .01472 L
.76268 .01472 L
.76271 .01472 L
.76274 .01472 L
.76277 .01472 L
.7628 .01472 L
.76283 .01472 L
.76286 .01472 L
.76287 .01472 L
.76289 .01472 L
.76291 .01472 L
.76292 .01472 L
.76295 .01472 L
.76298 .01472 L
.76301 .01472 L
.76304 .01472 L
.76307 .01472 L
Mistroke
.7631 .01472 L
.76312 .01472 L
.76315 .01472 L
.76318 .01472 L
.76321 .01472 L
.76324 .01472 L
.76326 .01472 L
.76329 .01472 L
.76333 .01472 L
.76335 .01472 L
.76338 .01472 L
.76341 .01472 L
.76343 .01472 L
.76345 .01472 L
.76348 .01472 L
.76349 .01472 L
.76351 .01472 L
.76353 .01472 L
.76354 .01472 L
.76357 .01472 L
.76359 .01472 L
.76361 .01472 L
.76362 .01472 L
.76364 .01472 L
.76366 .01472 L
.76368 .01472 L
.76369 .01472 L
.76371 .01472 L
.76374 .01472 L
.76377 .01472 L
.7638 .01472 L
.76383 .01472 L
.76386 .01472 L
.76389 .01472 L
.76391 .01472 L
.76394 .01472 L
.76397 .01472 L
.76399 .01472 L
.76402 .01472 L
.76405 .01472 L
.76408 .01472 L
.76411 .01472 L
.76414 .01472 L
.76416 .01472 L
.76418 .01472 L
.76421 .01472 L
.76424 .01472 L
.76426 .01472 L
.76429 .01472 L
.76432 .01472 L
Mistroke
.76435 .01472 L
.76437 .01472 L
.7644 .01472 L
.76442 .01472 L
.76445 .01472 L
.76448 .01472 L
.7645 .01472 L
.76453 .01472 L
.76456 .01472 L
.76459 .01472 L
.7646 .01472 L
.76462 .01472 L
.76465 .01472 L
.76468 .01472 L
.76471 .01472 L
.76474 .01472 L
.76477 .01472 L
.7648 .01472 L
.76482 .01472 L
.76485 .01472 L
.76488 .01472 L
.7649 .01472 L
.76493 .01472 L
.76496 .01472 L
.76499 .01472 L
.76502 .01472 L
.76505 .01472 L
.76507 .01472 L
.76509 .01472 L
.76512 .01472 L
.76515 .01472 L
.76517 .01472 L
.7652 .01472 L
.76523 .01472 L
.76526 .01472 L
.76528 .01472 L
.76531 .01472 L
.76533 .01472 L
.76536 .01472 L
.76539 .01472 L
.76542 .01472 L
.76544 .01472 L
.76547 .01472 L
.7655 .01472 L
.76551 .01472 L
.76553 .01472 L
.76556 .01472 L
.76559 .01472 L
.76562 .01472 L
.76563 .01472 L
Mistroke
.76565 .01472 L
.76568 .01472 L
.76571 .01472 L
.76573 .01472 L
.76576 .01472 L
.76579 .01472 L
.76582 .01472 L
.76584 .01472 L
.76586 .01472 L
.76588 .01472 L
.76591 .01472 L
.76593 .01472 L
.76594 .01472 L
.76597 .01472 L
.766 .01472 L
.76603 .01472 L
.76606 .01472 L
.76608 .01472 L
.76611 .01472 L
.76614 .01472 L
.76616 .01472 L
.76619 .01472 L
.76622 .01472 L
.76625 .01472 L
.76627 .01472 L
.7663 .01472 L
.76633 .01472 L
.76636 .01472 L
.76638 .01472 L
.76641 .01472 L
.76644 .01472 L
.76647 .01472 L
.7665 .01472 L
.76653 .01472 L
.76656 .01472 L
.76658 .01472 L
.76659 .01472 L
.76661 .01472 L
.76663 .01472 L
.76666 .01472 L
.76668 .01472 L
.76671 .01472 L
.76675 .01472 L
.76677 .01472 L
.7668 .01472 L
.76683 .01472 L
.76685 .01472 L
.76688 .01472 L
.76691 .01472 L
.76694 .01472 L
Mistroke
.76697 .01472 L
.767 .01472 L
.76703 .01472 L
.76706 .01472 L
.76709 .01472 L
.76712 .01472 L
.76713 .01472 L
.76715 .01472 L
.76718 .01472 L
.7672 .01472 L
.76721 .01472 L
.76723 .01472 L
.76725 .01472 L
.76728 .01472 L
.76729 .01472 L
.76731 .01472 L
.76733 .01472 L
.76735 .01472 L
.76736 .01472 L
.76738 .01472 L
.7674 .01472 L
.76741 .01472 L
.76744 .01472 L
.76747 .01472 L
.7675 .01472 L
.76753 .01472 L
.76756 .01472 L
.76759 .01472 L
.76762 .01472 L
.76764 .01472 L
.76767 .01472 L
.7677 .01472 L
.76773 .01472 L
.76776 .01472 L
.76779 .01472 L
.76781 .01472 L
.76785 .01472 L
.76786 .01472 L
.76788 .01472 L
.76791 .01472 L
.76794 .01472 L
.76797 .01472 L
.76799 .01472 L
.76802 .01472 L
.76805 .01472 L
.76808 .01472 L
.7681 .01472 L
.76812 .01472 L
.76815 .01472 L
.76818 .01472 L
Mistroke
.76821 .01472 L
.76824 .01472 L
.76826 .01472 L
.76829 .01472 L
.76831 .01472 L
.76832 .01472 L
.76835 .01472 L
.76838 .01472 L
.76841 .01472 L
.76844 .01472 L
.76847 .01472 L
.7685 .01472 L
.76853 .01472 L
.76855 .01472 L
.76858 .01472 L
.76861 .01472 L
.76864 .01472 L
.76867 .01472 L
.7687 .01472 L
.76872 .01472 L
.76876 .01472 L
.76877 .01472 L
.76879 .01472 L
.76882 .01472 L
.76885 .01472 L
.76888 .01472 L
.7689 .01472 L
.76893 .01472 L
.76896 .01472 L
.76899 .01472 L
.76901 .01472 L
.76904 .01472 L
.76906 .01472 L
.76909 .01472 L
.76912 .01472 L
.76915 .01472 L
.76917 .01472 L
.7692 .01472 L
.76922 .01472 L
.76923 .01472 L
.76926 .01472 L
.76929 .01472 L
.76932 .01472 L
.76934 .01472 L
.76935 .01472 L
.76938 .01472 L
.76941 .01472 L
.76944 .01472 L
.76946 .01472 L
.76949 .01472 L
Mistroke
.76952 .01472 L
.76955 .01472 L
.76956 .01472 L
.76958 .01472 L
.76961 .01472 L
.76963 .01472 L
.76965 .01472 L
.76967 .01472 L
.76971 .01472 L
.76974 .01472 L
.76976 .01472 L
.76979 .01472 L
.76981 .01472 L
.76984 .01472 L
.76986 .01472 L
.76989 .01472 L
.76992 .01472 L
.76995 .01472 L
.76998 .01472 L
.77001 .01472 L
.77003 .01472 L
.77006 .01472 L
.77009 .01472 L
.77012 .01472 L
.77015 .01472 L
.77017 .01472 L
.7702 .01472 L
.77023 .01472 L
.77026 .01472 L
.77028 .01472 L
.77029 .01472 L
.77031 .01472 L
.77033 .01472 L
.77036 .01472 L
.77039 .01472 L
.77042 .01472 L
.77045 .01472 L
.77047 .01472 L
.7705 .01472 L
.77053 .01472 L
.77056 .01472 L
.77058 .01472 L
.77062 .01472 L
.77064 .01472 L
.77067 .01472 L
.7707 .01472 L
.77073 .01472 L
.77076 .01472 L
.77079 .01472 L
.77082 .01472 L
Mistroke
.77084 .01472 L
.77085 .01472 L
.77088 .01472 L
.7709 .01472 L
.77092 .01472 L
.77093 .01472 L
.77095 .01472 L
.77098 .01472 L
.771 .01472 L
.77101 .01472 L
.77103 .01472 L
.77105 .01472 L
.77107 .01472 L
.77108 .01472 L
.7711 .01472 L
.77111 .01472 L
.77114 .01472 L
.77117 .01472 L
.7712 .01472 L
.77123 .01472 L
.77126 .01472 L
.77129 .01472 L
.77132 .01472 L
.77134 .01472 L
.77137 .01472 L
.7714 .01472 L
.77143 .01472 L
.77146 .01472 L
.77149 .01472 L
.77152 .01472 L
.77155 .01472 L
.77157 .01472 L
.77158 .01472 L
.77161 .01472 L
.77164 .01472 L
.77167 .01472 L
.7717 .01472 L
.77173 .01472 L
.77175 .01472 L
.77178 .01472 L
.7718 .01472 L
.77183 .01472 L
.77185 .01472 L
.77188 .01472 L
.77191 .01472 L
.77194 .01472 L
.77196 .01472 L
.77199 .01472 L
.77201 .01472 L
.77203 .01472 L
Mistroke
.77205 .01472 L
.77208 .01472 L
.77211 .01472 L
.77214 .01472 L
.77217 .01472 L
.7722 .01472 L
.77223 .01472 L
.77225 .01472 L
.77228 .01472 L
.77231 .01472 L
.77234 .01472 L
.77237 .01472 L
.7724 .01472 L
.77243 .01472 L
.77246 .01472 L
.77248 .01472 L
.77249 .01472 L
.77252 .01472 L
.77255 .01472 L
.77258 .01472 L
.77261 .01472 L
.77264 .01472 L
.77266 .01472 L
.77269 .01472 L
.77271 .01472 L
.77274 .01472 L
.77276 .01472 L
.77279 .01472 L
.77282 .01472 L
.77285 .01472 L
.77287 .01472 L
.7729 .01472 L
.77292 .01472 L
.77294 .01472 L
.77296 .01472 L
.77299 .01472 L
.77302 .01472 L
.77304 .01472 L
.77305 .01472 L
.77308 .01472 L
.77311 .01472 L
.77314 .01472 L
.77316 .01472 L
.77319 .01472 L
.77322 .01472 L
.77325 .01472 L
.77327 .01472 L
.77328 .01472 L
.77331 .01472 L
.77333 .01472 L
Mistroke
.77335 .01472 L
.77338 .01472 L
.77341 .01472 L
.77344 .01472 L
.77346 .01472 L
.77349 .01472 L
.77352 .01472 L
.77354 .01472 L
.77357 .01472 L
.77359 .01472 L
.77362 .01472 L
.77365 .01472 L
.77368 .01472 L
.77371 .01472 L
.77374 .01472 L
.77376 .01472 L
.77379 .01472 L
.77382 .01472 L
.77385 .01472 L
.77388 .01472 L
.7739 .01472 L
.77394 .01472 L
.77396 .01472 L
.77398 .01472 L
.774 .01472 L
.77401 .01472 L
.77403 .01472 L
.77406 .01472 L
.77409 .01472 L
.77412 .01472 L
.77415 .01472 L
.77418 .01472 L
.77421 .01472 L
.77423 .01472 L
.77426 .01472 L
.77429 .01472 L
.77432 .01472 L
.77435 .01472 L
.77437 .01472 L
.7744 .01472 L
.77443 .01472 L
.77446 .01472 L
.77449 .01472 L
.77452 .01472 L
.77454 .01472 L
.77456 .01472 L
.77459 .01472 L
.7746 .01472 L
.77462 .01472 L
.77463 .01472 L
Mistroke
.77465 .01472 L
.77468 .01472 L
.7747 .01472 L
.77471 .01472 L
.77473 .01472 L
.77475 .01472 L
.77477 .01472 L
.77478 .01472 L
.7748 .01472 L
.77482 .01472 L
.77485 .01472 L
.77488 .01472 L
.7749 .01472 L
.77494 .01472 L
.77497 .01472 L
.77499 .01472 L
.77502 .01472 L
.77505 .01472 L
.77507 .01472 L
.7751 .01472 L
.77513 .01472 L
.77516 .01472 L
.77519 .01472 L
.77522 .01472 L
.77525 .01472 L
.77527 .01472 L
.77528 .01472 L
.77532 .01472 L
.77535 .01472 L
.77537 .01472 L
.7754 .01472 L
.77543 .01472 L
.77545 .01472 L
.77548 .01472 L
.7755 .01472 L
.77553 .01472 L
.77556 .01472 L
.77558 .01472 L
.77561 .01472 L
.77564 .01472 L
.77566 .01472 L
.77569 .01472 L
.77571 .01472 L
.77573 .01472 L
.77575 .01472 L
.77578 .01472 L
.77581 .01472 L
.77585 .01472 L
.77588 .01472 L
.7759 .01472 L
Mistroke
.77593 .01472 L
.77596 .01472 L
.77598 .01472 L
.77601 .01472 L
.77604 .01472 L
.77607 .01472 L
.7761 .01472 L
.77613 .01472 L
.77616 .01472 L
.77618 .01472 L
.77619 .01472 L
.77622 .01472 L
.77625 .01472 L
.77628 .01472 L
.77631 .01472 L
.77634 .01472 L
.77636 .01472 L
.77639 .01472 L
.77641 .01472 L
.77644 .01472 L
.77647 .01472 L
.77649 .01472 L
.77652 .01472 L
.77655 .01472 L
.77657 .01472 L
.7766 .01472 L
.77662 .01472 L
.77664 .01472 L
.77666 .01472 L
.77669 .01472 L
.77672 .01472 L
.77676 .01472 L
.77679 .01472 L
.77681 .01472 L
.77684 .01472 L
.77687 .01472 L
.77689 .01472 L
.77692 .01472 L
.77695 .01472 L
.77698 .01472 L
.77701 .01472 L
.77704 .01472 L
.77707 .01472 L
.77709 .01472 L
.7771 .01472 L
.77714 .01472 L
.77717 .01472 L
.77719 .01472 L
.77722 .01472 L
.77725 .01472 L
Mistroke
.77727 .01472 L
.7773 .01472 L
.77732 .01472 L
.77735 .01472 L
.77738 .01472 L
.7774 .01472 L
.77743 .01472 L
.77746 .01472 L
.77749 .01472 L
.77752 .01472 L
.77753 .01472 L
.77755 .01472 L
.77758 .01472 L
.77761 .01472 L
.77763 .01472 L
.77765 .01472 L
.77767 .01472 L
.77769 .01472 L
.77772 .01472 L
.77775 .01472 L
.77778 .01472 L
.7778 .01472 L
.77783 .01472 L
.77786 .01472 L
.77788 .01472 L
.7779 .01472 L
.77793 .01472 L
.77794 .01472 L
.77796 .01472 L
.77799 .01472 L
.77802 .01472 L
.77805 .01472 L
.77808 .01472 L
.7781 .01472 L
.77813 .01472 L
.77816 .01472 L
.77818 .01472 L
.77821 .01472 L
.77824 .01472 L
.77826 .01472 L
.77829 .01472 L
.77832 .01472 L
.77835 .01472 L
.77837 .01472 L
.7784 .01472 L
.77843 .01472 L
.77846 .01472 L
.77849 .01472 L
.77852 .01472 L
.77855 .01472 L
Mistroke
.77858 .01472 L
.77859 .01472 L
.77861 .01472 L
.77863 .01472 L
.77864 .01472 L
.77867 .01472 L
.7787 .01472 L
.77873 .01472 L
.77876 .01472 L
.77879 .01472 L
.77882 .01472 L
.77885 .01472 L
.77887 .01472 L
.7789 .01472 L
.77893 .01472 L
.77896 .01472 L
.77899 .01472 L
.77902 .01472 L
.77905 .01472 L
.77908 .01472 L
.7791 .01472 L
.77914 .01472 L
.77915 .01472 L
.77917 .01472 L
.7792 .01472 L
.77921 .01472 L
.77923 .01472 L
.77925 .01472 L
.77927 .01472 L
.7793 .01472 L
.77931 .01472 L
.77933 .01472 L
.77935 .01472 L
.77936 .01472 L
.77938 .01472 L
.7794 .01472 L
.77942 .01472 L
.77943 .01472 L
.77946 .01472 L
.77949 .01472 L
.77952 .01472 L
.77955 .01472 L
.77958 .01472 L
.77961 .01472 L
.77964 .01472 L
.77966 .01472 L
.77969 .01472 L
.77972 .01472 L
.77975 .01472 L
.77978 .01472 L
Mistroke
.7798 .01472 L
.77983 .01472 L
.77986 .01472 L
.77988 .01472 L
.7799 .01472 L
.77993 .01472 L
.77996 .01472 L
.77999 .01472 L
.78001 .01472 L
.78004 .01472 L
.78007 .01472 L
.78009 .01472 L
.78012 .01472 L
.78014 .01472 L
.78017 .01472 L
.7802 .01472 L
.78023 .01472 L
.78025 .01472 L
.78028 .01472 L
.78031 .01472 L
.78033 .01472 L
.78034 .01472 L
.78037 .01472 L
.7804 .01472 L
.78043 .01472 L
.78046 .01472 L
.78049 .01472 L
.78052 .01472 L
.78055 .01472 L
.78057 .01472 L
.7806 .01472 L
.78063 .01472 L
.78066 .01472 L
.78069 .01472 L
.78071 .01472 L
.78074 .01472 L
.78078 .01472 L
.78079 .01472 L
.78081 .01472 L
.78084 .01472 L
.78087 .01472 L
.7809 .01472 L
.78092 .01472 L
.78095 .01472 L
.78098 .01472 L
.78101 .01472 L
.78103 .01472 L
.78106 .01472 L
.78108 .01472 L
.78111 .01472 L
Mistroke
.78114 .01472 L
.78117 .01472 L
.78119 .01472 L
.78122 .01472 L
.78124 .01472 L
.78125 .01472 L
.78128 .01472 L
.78131 .01472 L
.78134 .01472 L
.78136 .01472 L
.78137 .01472 L
.7814 .01472 L
.78143 .01472 L
.78146 .01472 L
.78148 .01472 L
.78151 .01472 L
.78154 .01472 L
.78157 .01472 L
.78158 .01472 L
.7816 .01472 L
.78163 .01472 L
.78165 .01472 L
.78167 .01472 L
.78169 .01472 L
.78173 .01472 L
.78175 .01472 L
.78178 .01472 L
.78181 .01472 L
.78183 .01472 L
.78186 .01472 L
.78188 .01472 L
.78191 .01472 L
.78194 .01472 L
.78197 .01472 L
.782 .01472 L
.78203 .01472 L
.78205 .01472 L
.78208 .01472 L
.78211 .01472 L
.78214 .01472 L
.78217 .01472 L
.78219 .01472 L
.78222 .01472 L
.78225 .01472 L
.78228 .01472 L
.7823 .01472 L
.78231 .01472 L
.78233 .01472 L
.78235 .01472 L
.78238 .01472 L
Mistroke
.78241 .01472 L
.78244 .01472 L
.78247 .01472 L
.78249 .01472 L
.78252 .01472 L
.78255 .01472 L
.78257 .01472 L
.7826 .01472 L
.78263 .01472 L
.78266 .01472 L
.78269 .01472 L
.78272 .01472 L
.78275 .01472 L
.78278 .01472 L
.78281 .01472 L
.78284 .01472 L
.78286 .01472 L
.78287 .01472 L
.7829 .01472 L
.78292 .01472 L
.78294 .01472 L
.78295 .01472 L
.78297 .01472 L
.783 .01472 L
.78302 .01472 L
.78303 .01472 L
.78305 .01472 L
.78307 .01472 L
.78309 .01472 L
.7831 .01472 L
.78312 .01472 L
.78313 .01472 L
.78316 .01472 L
.78319 .01472 L
.78322 .01472 L
.78325 .01472 L
.78328 .01472 L
.78331 .01472 L
.78334 .01472 L
.78336 .01472 L
.78339 .01472 L
.78342 .01472 L
.78345 .01472 L
.78348 .01472 L
.78351 .01472 L
.78354 .01472 L
.78357 .01472 L
.78359 .01472 L
.7836 .01472 L
.78363 .01472 L
Mistroke
.78366 .01472 L
.78369 .01472 L
.78372 .01472 L
.78375 .01472 L
.78377 .01472 L
.7838 .01472 L
.78382 .01472 L
.78385 .01472 L
.78387 .01472 L
.7839 .01472 L
.78393 .01472 L
.78396 .01472 L
.78398 .01472 L
.78401 .01472 L
.78403 .01472 L
.78405 .01472 L
.78407 .01472 L
.7841 .01472 L
.78413 .01472 L
.78416 .01472 L
.78419 .01472 L
.78422 .01472 L
.78425 .01472 L
.78427 .01472 L
.7843 .01472 L
.78433 .01472 L
.78436 .01472 L
.78439 .01472 L
.78442 .01472 L
.78445 .01472 L
.78448 .01472 L
.7845 .01472 L
.78451 .01472 L
.78454 .01472 L
.78457 .01472 L
.7846 .01472 L
.78463 .01472 L
.78466 .01472 L
.78468 .01472 L
.78471 .01472 L
.78473 .01472 L
.78476 .01472 L
.78478 .01472 L
.78481 .01472 L
.78484 .01472 L
.78487 .01472 L
.78489 .01472 L
.78492 .01472 L
.78494 .01472 L
.78496 .01472 L
Mistroke
.78498 .01472 L
.78501 .01472 L
.78504 .01472 L
.78506 .01472 L
.78508 .01472 L
.7851 .01472 L
.78513 .01472 L
.78516 .01472 L
.78518 .01472 L
.78521 .01472 L
.78524 .01472 L
.78527 .01472 L
.78529 .01472 L
.7853 .01472 L
.78533 .01472 L
.78535 .01472 L
.78537 .01472 L
.7854 .01472 L
.78543 .01472 L
.78546 .01472 L
.78549 .01472 L
.78551 .01472 L
.78554 .01472 L
.78556 .01472 L
.78559 .01472 L
.78561 .01472 L
.78564 .01472 L
.78567 .01472 L
.7857 .01472 L
.78573 .01472 L
.78576 .01472 L
.78578 .01472 L
.78581 .01472 L
.78584 .01472 L
.78587 .01472 L
.7859 .01472 L
.78593 .01472 L
.78596 .01472 L
.78599 .01472 L
.786 .01472 L
.78602 .01472 L
.78604 .01472 L
.78605 .01472 L
.78608 .01472 L
.78611 .01472 L
.78614 .01472 L
.78617 .01472 L
.7862 .01472 L
.78623 .01472 L
.78625 .01472 L
Mistroke
.78628 .01472 L
.78631 .01472 L
.78634 .01472 L
.78637 .01472 L
.78639 .01472 L
.78642 .01472 L
.78646 .01472 L
.78648 .01472 L
.78651 .01472 L
.78654 .01472 L
.78656 .01472 L
.78658 .01472 L
.78661 .01472 L
.78662 .01472 L
.78664 .01472 L
.78666 .01472 L
.78667 .01472 L
.7867 .01472 L
.78672 .01472 L
.78674 .01472 L
.78675 .01472 L
.78677 .01472 L
.78679 .01472 L
.78681 .01472 L
.78682 .01472 L
.78684 .01472 L
.78687 .01472 L
.7869 .01472 L
.78693 .01472 L
.78696 .01472 L
.78699 .01472 L
.78702 .01472 L
.78704 .01472 L
.78707 .01472 L
.7871 .01472 L
.78712 .01472 L
.78715 .01472 L
.78718 .01472 L
.78721 .01472 L
.78724 .01472 L
.78727 .01472 L
.78729 .01472 L
.78731 .01472 L
.78734 .01472 L
.78737 .01472 L
.78739 .01472 L
.78742 .01472 L
.78745 .01472 L
.78748 .01472 L
.7875 .01472 L
Mistroke
.78752 .01472 L
.78755 .01472 L
.78758 .01472 L
.7876 .01472 L
.78763 .01472 L
.78766 .01472 L
.78769 .01472 L
.78772 .01472 L
.78773 .01472 L
.78775 .01472 L
.78778 .01472 L
.78781 .01472 L
.78784 .01472 L
.78787 .01472 L
.7879 .01472 L
.78792 .01472 L
.78795 .01472 L
.78798 .01472 L
.78801 .01472 L
.78803 .01472 L
.78806 .01472 L
.78809 .01472 L
.78812 .01472 L
.78815 .01472 L
.78818 .01472 L
.7882 .01472 L
.78822 .01472 L
.78825 .01472 L
.78828 .01472 L
.7883 .01472 L
.78833 .01472 L
.78836 .01472 L
.78839 .01472 L
.78841 .01472 L
.78843 .01472 L
.78846 .01472 L
.78849 .01472 L
.78851 .01472 L
.78854 .01472 L
.78857 .01472 L
.7886 .01472 L
.78863 .01472 L
.78864 .01472 L
.78866 .01472 L
.78869 .01472 L
.78872 .01472 L
.78875 .01472 L
.78876 .01472 L
.78878 .01472 L
.78881 .01472 L
Mistroke
.78884 .01472 L
.78886 .01472 L
.78889 .01472 L
.78891 .01472 L
.78894 .01472 L
.78897 .01472 L
.78899 .01472 L
.78901 .01472 L
.78904 .01472 L
.78905 .01472 L
.78907 .01472 L
.7891 .01472 L
.78913 .01472 L
.78916 .01472 L
.78919 .01472 L
.78921 .01472 L
.78924 .01472 L
.78927 .01472 L
.78929 .01472 L
.78932 .01472 L
.78935 .01472 L
.78938 .01472 L
.7894 .01472 L
.78943 .01472 L
.78946 .01472 L
.78948 .01472 L
.78951 .01472 L
.78954 .01472 L
.78957 .01472 L
.7896 .01472 L
.78963 .01472 L
.78966 .01472 L
.78969 .01472 L
.7897 .01472 L
.78972 .01472 L
.78974 .01472 L
.78975 .01472 L
.78978 .01472 L
.78981 .01472 L
.78984 .01472 L
.78987 .01472 L
.7899 .01472 L
.78993 .01472 L
.78996 .01472 L
.78998 .01472 L
.79001 .01472 L
.79004 .01472 L
.79007 .01472 L
.7901 .01472 L
.79013 .01472 L
Mistroke
.79016 .01472 L
.79019 .01472 L
.79021 .01472 L
.79024 .01472 L
.79026 .01472 L
.79028 .01472 L
.79031 .01472 L
.79033 .01472 L
.79034 .01472 L
.79036 .01472 L
.79037 .01472 L
.79041 .01472 L
.79042 .01472 L
.79044 .01472 L
.79046 .01472 L
.79047 .01472 L
.79049 .01472 L
.79051 .01472 L
.79052 .01472 L
.79054 .01472 L
.79057 .01472 L
.7906 .01472 L
.79063 .01472 L
.79066 .01472 L
.79069 .01472 L
.79072 .01472 L
.79074 .01472 L
.79077 .01472 L
.7908 .01472 L
.79083 .01472 L
.79085 .01472 L
.79089 .01472 L
.79091 .01472 L
.79094 .01472 L
.79097 .01472 L
.79099 .01472 L
.79101 .01472 L
.79104 .01472 L
.79107 .01472 L
.79109 .01472 L
.79112 .01472 L
.79115 .01472 L
.79118 .01472 L
.7912 .01472 L
.79123 .01472 L
.79125 .01472 L
.79128 .01472 L
.79131 .01472 L
.79134 .01472 L
.79136 .01472 L
Mistroke
.79139 .01472 L
.79142 .01472 L
.79143 .01472 L
.79145 .01472 L
.79148 .01472 L
.79151 .01472 L
.79154 .01472 L
.79157 .01472 L
.7916 .01472 L
.79163 .01472 L
.79165 .01472 L
.79168 .01472 L
.79171 .01472 L
.79173 .01472 L
.79176 .01472 L
.7918 .01472 L
.79182 .01472 L
.79185 .01472 L
.79188 .01472 L
.7919 .01472 L
.79192 .01472 L
.79195 .01472 L
.79198 .01472 L
.792 .01472 L
.79203 .01472 L
.79206 .01472 L
.79209 .01472 L
.79211 .01472 L
.79214 .01472 L
.79216 .01472 L
.79219 .01472 L
.79222 .01472 L
.79225 .01472 L
.79227 .01472 L
.7923 .01472 L
.79233 .01472 L
.79234 .01472 L
.79236 .01472 L
.79239 .01472 L
.79242 .01472 L
.79245 .01472 L
.79248 .01472 L
.79251 .01472 L
.79254 .01472 L
.79256 .01472 L
.79259 .01472 L
.79262 .01472 L
.79264 .01472 L
.79267 .01472 L
.79271 .01472 L
Mistroke
.79273 .01472 L
.79276 .01472 L
.79279 .01472 L
.79281 .01472 L
.79283 .01472 L
.79286 .01472 L
.79289 .01472 L
.79291 .01472 L
.79294 .01472 L
.79297 .01472 L
.793 .01472 L
.79302 .01472 L
.79305 .01472 L
.79307 .01472 L
.7931 .01472 L
.79313 .01472 L
.79316 .01472 L
.79318 .01472 L
.79321 .01472 L
.79324 .01472 L
.79326 .01472 L
.79327 .01472 L
.7933 .01472 L
.79333 .01472 L
.79336 .01472 L
.79337 .01472 L
.79339 .01472 L
.79342 .01472 L
.79345 .01472 L
.79347 .01472 L
.7935 .01472 L
.79353 .01472 L
.79356 .01472 L
.79359 .01472 L
.7936 .01472 L
.79362 .01472 L
.79365 .01472 L
.79367 .01472 L
.79368 .01472 L
.79371 .01472 L
.79374 .01472 L
.79377 .01472 L
.7938 .01472 L
.79383 .01472 L
.79385 .01472 L
.79388 .01472 L
.7939 .01472 L
.79393 .01472 L
.79396 .01472 L
.79399 .01472 L
Mistroke
.79401 .01472 L
.79404 .01472 L
.79407 .01472 L
.7941 .01472 L
.79412 .01472 L
.79415 .01472 L
.79419 .01472 L
.79421 .01472 L
.79424 .01472 L
.79427 .01472 L
.7943 .01472 L
.79432 .01472 L
.79433 .01472 L
.79435 .01472 L
.79437 .01472 L
.7944 .01472 L
.79443 .01472 L
.79446 .01472 L
.79449 .01472 L
.79451 .01472 L
.79454 .01472 L
.79457 .01472 L
.79459 .01472 L
.79462 .01472 L
.79465 .01472 L
.79468 .01472 L
.79471 .01472 L
.79474 .01472 L
.79477 .01472 L
.7948 .01472 L
.79483 .01472 L
.79486 .01472 L
.79488 .01472 L
.79489 .01472 L
.79492 .01472 L
.79494 .01472 L
.79496 .01472 L
.79497 .01472 L
.79499 .01472 L
.79502 .01472 L
.79504 .01472 L
.79505 .01472 L
.79507 .01472 L
.79509 .01472 L
.7951 .01472 L
.79512 .01472 L
.79514 .01472 L
.79515 .01472 L
.79518 .01472 L
.79521 .01472 L
Mistroke
.79524 .01472 L
.79527 .01472 L
.7953 .01472 L
.79533 .01472 L
.79536 .01472 L
.79538 .01472 L
.79541 .01472 L
.79544 .01472 L
.79547 .01472 L
.7955 .01472 L
.79553 .01472 L
.79556 .01472 L
.79559 .01472 L
.79561 .01472 L
.79562 .01472 L
.79565 .01472 L
.79568 .01472 L
.79571 .01472 L
.79574 .01472 L
.79577 .01472 L
.79579 .01472 L
.79582 .01472 L
.79584 .01472 L
.79587 .01472 L
.79589 .01472 L
.79592 .01472 L
.79595 .01472 L
.79598 .01472 L
.796 .01472 L
.79603 .01472 L
.79605 .01472 L
.79607 .01472 L
.79609 .01472 L
.79612 .01472 L
.79615 .01472 L
.79618 .01472 L
.79621 .01472 L
.79624 .01472 L
.79627 .01472 L
.79629 .01472 L
.79632 .01472 L
.79635 .01472 L
.79638 .01472 L
.79641 .01472 L
.79644 .01472 L
.79647 .01472 L
.7965 .01472 L
.79652 .01472 L
.79653 .01472 L
.79656 .01472 L
Mistroke
.79659 .01472 L
.79662 .01472 L
.79665 .01472 L
.79668 .01472 L
.7967 .01472 L
.79673 .01472 L
.79675 .01472 L
.79678 .01472 L
.79681 .01472 L
.79683 .01472 L
.79686 .01472 L
.79689 .01472 L
.79691 .01472 L
.79694 .01472 L
.79696 .01472 L
.79698 .01472 L
.797 .01472 L
.79703 .01472 L
.79706 .01472 L
.79708 .01472 L
.7971 .01472 L
.79712 .01472 L
.79715 .01472 L
.79718 .01472 L
.7972 .01472 L
.79723 .01472 L
.79726 .01472 L
.79729 .01472 L
.79731 .01472 L
.79732 .01472 L
.79736 .01472 L
.79737 .01472 L
.79739 .01472 L
.79742 .01472 L
.79745 .01472 L
.79748 .01472 L
.79751 .01472 L
.79753 .01472 L
.79756 .01472 L
.79758 .01472 L
.79761 .01472 L
.79764 .01472 L
.79767 .01472 L
.79769 .01472 L
.79772 .01472 L
.79775 .01472 L
.79778 .01472 L
.7978 .01472 L
.79783 .01472 L
.79786 .01472 L
Mistroke
.79789 .01472 L
.79792 .01472 L
.79795 .01472 L
.79798 .01472 L
.79801 .01472 L
.79802 .01472 L
.79804 .01472 L
.79806 .01472 L
.79807 .01472 L
.7981 .01472 L
.79813 .01472 L
.79816 .01472 L
.79819 .01472 L
.79822 .01472 L
.79825 .01472 L
.79827 .01472 L
.7983 .01472 L
.79833 .01472 L
.79836 .01472 L
.79839 .01472 L
.79842 .01472 L
.79844 .01472 L
.79848 .01472 L
.79851 .01472 L
.79853 .01472 L
.79856 .01472 L
.79858 .01472 L
.7986 .01472 L
.79863 .01472 L
.79864 .01472 L
.79866 .01472 L
.79868 .01472 L
.79869 .01472 L
.79872 .01472 L
.79874 .01472 L
.79876 .01472 L
.79877 .01472 L
.79879 .01472 L
.79881 .01472 L
.79883 .01472 L
.79884 .01472 L
.79886 .01472 L
.79889 .01472 L
.79892 .01472 L
.79895 .01472 L
.79898 .01472 L
.79901 .01472 L
.79904 .01472 L
.79906 .01472 L
.79909 .01472 L
Mistroke
.79912 .01472 L
.79914 .01472 L
.79917 .01472 L
.79921 .01472 L
.79923 .01472 L
.79926 .01472 L
.79929 .01472 L
.79931 .01472 L
.79933 .01472 L
.79936 .01472 L
.79939 .01472 L
.79941 .01472 L
.79944 .01472 L
.79947 .01472 L
.7995 .01472 L
.79952 .01472 L
.79955 .01472 L
.79957 .01472 L
.7996 .01472 L
.79963 .01472 L
.79966 .01472 L
.79968 .01472 L
.79971 .01472 L
.79974 .01472 L
.79975 .01472 L
.79977 .01472 L
.7998 .01472 L
.79983 .01472 L
.79986 .01472 L
.79989 .01472 L
.79992 .01472 L
.79995 .01472 L
.79997 .01472 L
.8 .01472 L
.80003 .01472 L
.80005 .01472 L
.80008 .01472 L
.80012 .01472 L
.80014 .01472 L
.80017 .01472 L
.8002 .01472 L
.80022 .01472 L
.80024 .01472 L
.80027 .01472 L
.8003 .01472 L
.80032 .01472 L
.80035 .01472 L
.80038 .01472 L
.80041 .01472 L
.80043 .01472 L
Mistroke
.80046 .01472 L
.80048 .01472 L
.80051 .01472 L
.80054 .01472 L
.80057 .01472 L
.80059 .01472 L
.80062 .01472 L
.80065 .01472 L
.80066 .01472 L
.80068 .01472 L
.80071 .01472 L
.80074 .01472 L
.80077 .01472 L
.80078 .01472 L
.8008 .01472 L
.80083 .01472 L
.80086 .01472 L
.80088 .01472 L
.80091 .01472 L
.80094 .01472 L
.80097 .01472 L
.801 .01472 L
.80101 .01472 L
.80103 .01472 L
.80106 .01472 L
.80108 .01472 L
.80109 .01472 L
.80112 .01472 L
.80115 .01472 L
.80118 .01472 L
.80121 .01472 L
.80123 .01472 L
.80126 .01472 L
.80129 .01472 L
.80131 .01472 L
.80134 .01472 L
.80137 .01472 L
.8014 .01472 L
.80142 .01472 L
.80145 .01472 L
.80148 .01472 L
.80151 .01472 L
.80153 .01472 L
.80156 .01472 L
.80159 .01472 L
.80162 .01472 L
.80165 .01472 L
.80168 .01472 L
.80171 .01472 L
.80173 .01472 L
Mistroke
.80174 .01472 L
.80176 .01472 L
.80178 .01472 L
.80181 .01472 L
.80183 .01472 L
.80186 .01472 L
.8019 .01472 L
.80192 .01472 L
.80195 .01472 L
.80198 .01472 L
.802 .01472 L
.80203 .01472 L
.80206 .01472 L
.80209 .01472 L
.80212 .01472 L
.80215 .01472 L
.80218 .01472 L
.80221 .01472 L
.80224 .01472 L
.80227 .01472 L
.80228 .01472 L
.8023 .01472 L
.80233 .01472 L
.80235 .01472 L
.80236 .01472 L
.80238 .01472 L
.8024 .01472 L
.80243 .01472 L
.80244 .01472 L
.80246 .01472 L
.80248 .01472 L
.8025 .01472 L
.80251 .01472 L
.80253 .01472 L
.80255 .01472 L
.80256 .01472 L
.80259 .01472 L
.80262 .01472 L
.80265 .01472 L
.80268 .01472 L
.80271 .01472 L
.80274 .01472 L
.80277 .01472 L
.80279 .01472 L
.80282 .01472 L
.80285 .01472 L
.80288 .01472 L
.80291 .01472 L
.80294 .01472 L
.80296 .01472 L
Mistroke
.803 .01472 L
.80301 .01472 L
.80303 .01472 L
.80306 .60332 L
.80309 .60332 L
.80353 .60332 L
.80445 .60332 L
.80543 .60332 L
.80637 .60332 L
.80728 .60332 L
.80825 .60332 L
.80918 .60332 L
.81017 .60332 L
.81112 .60332 L
.81203 .60332 L
.81301 .60332 L
.81394 .60332 L
.81494 .60332 L
.8159 .60332 L
.81683 .60332 L
.81781 .60332 L
.81876 .60332 L
.81967 .60332 L
.81991 .60332 L
.82013 .60332 L
.82026 .60332 L
.82029 .60332 L
.82031 .60332 L
.82033 .60332 L
.82035 .01472 L
.82036 .01472 L
.8204 .01472 L
.82042 .01472 L
.82044 .01472 L
.82046 .01472 L
.82049 .01472 L
.8205 .01472 L
.82052 .01472 L
.82055 .01472 L
.82058 .01472 L
.82061 .01472 L
.82064 .01472 L
.82066 .01472 L
.82069 .01472 L
.82072 .01472 L
.82075 .01472 L
.82078 .01472 L
.82079 .01472 L
.82081 .01472 L
.82084 .01472 L
Mistroke
.82087 .01472 L
.82089 .01472 L
.82092 .01472 L
.82095 .01472 L
.82097 .01472 L
.821 .01472 L
.82103 .01472 L
.82106 .01472 L
.82108 .01472 L
.82112 .01472 L
.82113 .01472 L
.82115 .01472 L
.82118 .01472 L
.82121 .01472 L
.82122 .01472 L
.82124 .01472 L
.82127 .01472 L
.82129 .01472 L
.8213 .01472 L
.82132 .01472 L
.82134 .01472 L
.82137 .01472 L
.82139 .01472 L
.8214 .01472 L
.82143 .01472 L
.82147 .01472 L
.82149 .01472 L
.82152 .01472 L
.82155 .01472 L
.82158 .01472 L
.8216 .01472 L
.82161 .01472 L
.82164 .01472 L
.82167 .01472 L
.82169 .01472 L
.82171 .01472 L
.82173 .01472 L
.82176 .01472 L
.82179 .01472 L
.82182 .01472 L
.82184 .01472 L
.82186 .01472 L
.82187 .01472 L
.82189 .01472 L
.82192 .01472 L
.82195 .01472 L
.82197 .01472 L
.82198 .01472 L
.82202 .01472 L
.82203 .01472 L
Mistroke
.82205 .01472 L
.82207 .01472 L
.82209 .01472 L
.8221 .01472 L
.82212 .01472 L
.82215 .01472 L
.82218 .01472 L
.82221 .01472 L
.82224 .01472 L
.82226 .01472 L
.82227 .01472 L
.82229 .01472 L
.8223 .01472 L
.82232 .01472 L
.82234 .01472 L
.82237 .01472 L
.8224 .01472 L
.82242 .01472 L
.82245 .01472 L
.82248 .01472 L
.8225 .01472 L
.82251 .01472 L
.82254 .01472 L
.82257 .01472 L
.8226 .01472 L
.82262 .01472 L
.82263 .01472 L
.82266 .01472 L
.82269 .01472 L
.82272 .01472 L
.82274 .01472 L
.82277 .01472 L
.8228 .01472 L
.82283 .01472 L
.82285 .01472 L
.82286 .01472 L
.8229 .01472 L
.82291 .01472 L
.82293 .01472 L
.82296 .01472 L
.82299 .01472 L
.82302 .01472 L
.82304 .01472 L
.82307 .01472 L
.8231 .01472 L
.82312 .01472 L
.82315 .01472 L
.82317 .01472 L
.8232 .01472 L
.82323 .01472 L
Mistroke
.82326 .01472 L
.82329 .01472 L
.82331 .01472 L
.82334 .01472 L
.82337 .01472 L
.8234 .01472 L
.82343 .01472 L
.82346 .01472 L
.82348 .01472 L
.82352 .01472 L
.82355 .01472 L
.82356 .01472 L
.82358 .01472 L
.8236 .01472 L
.82361 .01472 L
.82364 .01472 L
.82367 .01472 L
.82368 .01472 L
.8237 .01472 L
.82373 .01472 L
.82376 .01472 L
.82379 .01472 L
.82382 .01472 L
.82385 .01472 L
.82387 .01472 L
.8239 .01472 L
.82393 .01472 L
.82396 .01472 L
.82399 .01472 L
.82402 .01472 L
.82403 .01472 L
.82405 .01472 L
.82408 .01472 L
.82411 .01472 L
.82414 .01472 L
.82417 .01472 L
.8242 .01472 L
.82421 .01472 L
.82423 .01472 L
.82426 .01472 L
.82428 .01472 L
.82429 .01472 L
.82431 .01472 L
.82433 .01472 L
.82435 .01472 L
.82437 .01472 L
.82438 .01472 L
.8244 .01472 L
.82443 .01472 L
.82446 .01472 L
Mistroke
.82449 .01472 L
.82452 .01472 L
.82455 .01472 L
.82458 .01472 L
.8246 .01472 L
.82463 .01472 L
.82466 .01472 L
.82469 .01472 L
.82472 .01472 L
.82475 .01472 L
.82477 .01472 L
.8248 .01472 L
.82484 .01472 L
.82485 .01472 L
.82487 .01472 L
.8249 .01472 L
.82493 .01472 L
.82496 .01472 L
.82498 .01472 L
.82501 .01472 L
.82504 .01472 L
.82507 .01472 L
.82509 .01472 L
.82512 .01472 L
.82514 .01472 L
.82517 .01472 L
.8252 .01472 L
.82523 .01472 L
.82525 .01472 L
.82528 .01472 L
.8253 .01472 L
.82531 .01472 L
.82534 .01472 L
.82537 .01472 L
.8254 .01472 L
.82542 .01472 L
.82543 .01472 L
.82546 .01472 L
.82549 .01472 L
.82552 .01472 L
.82554 .01472 L
.82557 .01472 L
.8256 .01472 L
.82563 .01472 L
.82564 .01472 L
.82566 .01472 L
.82569 .01472 L
.82571 .01472 L
.82573 .01472 L
.82575 .01472 L
Mistroke
.82579 .01472 L
.82581 .01472 L
.82584 .01472 L
.82587 .01472 L
.82589 .01472 L
.82592 .01472 L
.82594 .01472 L
.82597 .01472 L
.826 .01472 L
.82603 .01472 L
.82606 .01472 L
.82609 .01472 L
.82611 .01472 L
.82614 .01472 L
.82617 .01472 L
.8262 .01472 L
.82623 .01472 L
.82625 .01472 L
.82628 .01472 L
.82631 .01472 L
.82634 .01472 L
.82636 .01472 L
.82638 .01472 L
.82639 .01472 L
.82641 .01472 L
.82644 .01472 L
.82647 .01472 L
.8265 .01472 L
.82653 .01472 L
.82656 .01472 L
.82658 .01472 L
.82661 .01472 L
.82664 .01472 L
.82666 .01472 L
.8267 .01472 L
.82673 .01472 L
.82675 .01472 L
.82678 .01472 L
.82681 .01472 L
.82684 .01472 L
.82687 .01472 L
.8269 .01472 L
.82692 .01472 L
.82693 .01472 L
.82696 .01472 L
.82698 .01472 L
.827 .01472 L
.82701 .01472 L
.82703 .01472 L
.82706 .01472 L
Mistroke
.82708 .01472 L
.82709 .01472 L
.82711 .01472 L
.82713 .01472 L
.82715 .01472 L
.82716 .01472 L
.82718 .01472 L
.8272 .01472 L
.82722 .01472 L
.82726 .01472 L
.82728 .01472 L
.82732 .01472 L
.82735 .01472 L
.82737 .01472 L
.8274 .01472 L
.82743 .01472 L
.82745 .01472 L
.82748 .01472 L
.82751 .01472 L
.82754 .01472 L
.82757 .01472 L
.8276 .01472 L
.82763 .01472 L
.82765 .01472 L
.82766 .01472 L
.8277 .01472 L
.82772 .01472 L
.82775 .01472 L
.82778 .01472 L
.82781 .01472 L
.82783 .01472 L
.82786 .01472 L
.82788 .01472 L
.82791 .01472 L
.82794 .01472 L
.82796 .01472 L
.82799 .01472 L
.82802 .01472 L
.82805 .01472 L
.82807 .01472 L
.82809 .01472 L
.82811 .01472 L
.82813 .01472 L
.82816 .01472 L
.82819 .01472 L
.82823 .01472 L
.82826 .01472 L
.82828 .01472 L
.82831 .01472 L
.82834 .01472 L
Mistroke
.82836 .01472 L
.82839 .01472 L
.82842 .01472 L
.82845 .01472 L
.82848 .01472 L
.82851 .01472 L
.82854 .01472 L
.82856 .01472 L
.82857 .01472 L
.82861 .01472 L
.82864 .01472 L
.82866 .01472 L
.82869 .01472 L
.82872 .01472 L
.82875 .01472 L
.82877 .01472 L
.82879 .01472 L
.82882 .01472 L
.82885 .01472 L
.82887 .01472 L
.8289 .01472 L
.82893 .01472 L
.82896 .01472 L
.82899 .01472 L
.829 .01472 L
.82902 .01472 L
.82905 .01472 L
.82908 .01472 L
.8291 .01472 L
.82912 .01472 L
.82914 .01472 L
.82916 .01472 L
.82919 .01472 L
.82922 .01472 L
.82925 .01472 L
.82927 .01472 L
.8293 .01472 L
.82933 .01472 L
.82935 .01472 L
.82937 .01472 L
.8294 .01472 L
.82941 .01472 L
.82943 .01472 L
.82946 .01472 L
.82949 .01472 L
.82952 .01472 L
.82955 .01472 L
.82957 .01472 L
.8296 .01472 L
.82963 .01472 L
Mistroke
.82965 .01472 L
.82968 .01472 L
.82971 .01472 L
.82973 .01472 L
.82976 .01472 L
.82979 .01472 L
.82982 .01472 L
.82984 .01472 L
.82987 .01472 L
.8299 .01472 L
.82993 .01472 L
.82996 .01472 L
.82999 .01472 L
.83002 .01472 L
.83005 .01472 L
.83006 .01472 L
.83008 .01472 L
.8301 .01472 L
.83011 .01472 L
.83014 .01472 L
.83017 .01472 L
.8302 .01472 L
.83023 .01472 L
.83026 .01472 L
.83029 .01472 L
.83032 .01472 L
.83034 .01472 L
.83037 .01472 L
.8304 .01472 L
.83043 .01472 L
.83046 .01472 L
.83049 .01472 L
.83052 .01472 L
.83055 .01472 L
.83057 .01472 L
.83061 .01472 L
.83062 .01472 L
.83064 .01472 L
.83067 .01472 L
.83068 .01472 L
.8307 .01472 L
.83072 .01472 L
.83074 .01472 L
.83077 .01472 L
.83078 .01472 L
.8308 .01472 L
.83082 .01472 L
.83083 .01472 L
.83085 .01472 L
.83087 .01472 L
Mistroke
.83089 .01472 L
.8309 .01472 L
.83093 .01472 L
.83096 .01472 L
.83099 .01472 L
.83102 .01472 L
.83105 .01472 L
.83108 .01472 L
.83111 .01472 L
.83113 .01472 L
.83116 .01472 L
.83119 .01472 L
.83122 .01472 L
.83125 .01472 L
.83127 .01472 L
.8313 .01472 L
.83133 .01472 L
.83135 .01472 L
.83137 .01472 L
.8314 .01472 L
.83143 .01472 L
.83145 .01472 L
.83148 .01472 L
.83151 .01472 L
.83154 .01472 L
.83156 .01472 L
.83159 .01472 L
.83161 .01472 L
.83164 .01472 L
.83167 .01472 L
.8317 .01472 L
.83172 .01472 L
.83175 .01472 L
.83178 .01472 L
.8318 .01472 L
.83181 .01472 L
.83184 .01472 L
.83187 .01472 L
.8319 .01472 L
.83193 .01472 L
.83196 .01472 L
.83199 .01472 L
.83202 .01472 L
.83204 .01472 L
.83207 .01472 L
.8321 .01472 L
.83213 .01472 L
.83216 .01472 L
.83218 .01472 L
.83221 .01472 L
Mistroke
.83224 .01472 L
.83226 .01472 L
.83228 .01472 L
.83231 .01472 L
.83234 .01472 L
.83237 .01472 L
.83239 .01472 L
.83242 .01472 L
.83245 .01472 L
.83247 .01472 L
.8325 .01472 L
.83253 .01472 L
.83255 .01472 L
.83258 .01472 L
.83261 .01472 L
.83264 .01472 L
.83266 .01472 L
.83269 .01472 L
.83271 .01472 L
.83272 .01472 L
.83275 .01472 L
.83278 .01472 L
.83281 .01472 L
.83283 .01472 L
.83284 .01472 L
.83287 .01472 L
.8329 .01472 L
.83293 .01472 L
.83295 .01472 L
.83298 .01472 L
.83301 .01472 L
.83304 .01472 L
.83305 .01472 L
.83307 .01472 L
.8331 .01472 L
.83312 .01472 L
.83313 .01472 L
.83316 .01472 L
.83319 .01472 L
.83322 .01472 L
.83325 .01472 L
.83328 .01472 L
.8333 .01472 L
.83333 .01472 L
.83335 .01472 L
.83338 .01472 L
.83341 .01472 L
.83344 .01472 L
.83347 .01472 L
.83349 .01472 L
Mistroke
.83352 .01472 L
.83355 .01472 L
.83357 .01472 L
.8336 .01472 L
.83364 .01472 L
.83366 .01472 L
.83369 .01472 L
.83372 .01472 L
.83375 .01472 L
.83377 .01472 L
.83378 .01472 L
.8338 .01472 L
.83382 .01472 L
.83385 .01472 L
.83388 .01472 L
.83391 .01472 L
.83394 .01472 L
.83396 .01472 L
.83399 .01472 L
.83402 .01472 L
.83404 .01472 L
.83407 .01472 L
.8341 .01472 L
.83413 .01472 L
.83416 .01472 L
.83419 .01472 L
.83422 .01472 L
.83425 .01472 L
.83428 .01472 L
.83431 .01472 L
.83433 .01472 L
.83434 .01472 L
.83437 .01472 L
.83439 .01472 L
.83441 .01472 L
.83442 .01472 L
.83444 .01472 L
.83447 .01472 L
.83449 .01472 L
.8345 .01472 L
.83452 .01472 L
.83454 .01472 L
.83455 .01472 L
.83457 .01472 L
.83459 .01472 L
.8346 .01472 L
.83463 .01472 L
.83466 .01472 L
.83469 .01472 L
.83472 .01472 L
Mistroke
.83475 .01472 L
.83478 .01472 L
.83481 .01472 L
.83483 .01472 L
.83486 .01472 L
.83489 .01472 L
.83492 .01472 L
.83495 .01472 L
.83498 .01472 L
.83501 .01472 L
.83504 .01472 L
.83506 .01472 L
.83507 .01472 L
.8351 .01472 L
.83513 .01472 L
.83516 .01472 L
.83519 .01472 L
.83522 .01472 L
.83524 .01472 L
.83527 .01472 L
.83529 .01472 L
.83532 .01472 L
.83534 .01472 L
.83537 .01472 L
.8354 .01472 L
.83543 .01472 L
.83545 .01472 L
.83548 .01472 L
.8355 .01472 L
.83551 .01472 L
.83554 .01472 L
.83557 .01472 L
.8356 .01472 L
.83563 .01472 L
.83566 .01472 L
.83569 .01472 L
.83572 .01472 L
.83574 .01472 L
.83577 .01472 L
.8358 .01472 L
.83583 .01472 L
.83586 .01472 L
.83589 .01472 L
.83592 .01472 L
.83595 .01472 L
.83597 .01472 L
.83598 .01472 L
.83601 .01472 L
.83604 .01472 L
.83607 .01472 L
Mistroke
.8361 .01472 L
.83613 .01472 L
.83615 .01472 L
.83618 .01472 L
.8362 .01472 L
.83623 .01472 L
.83625 .01472 L
.83628 .01472 L
.83631 .01472 L
.83634 .01472 L
.83636 .01472 L
.83639 .01472 L
.83641 .01472 L
.83642 .01472 L
.83645 .01472 L
.83648 .01472 L
.83651 .01472 L
.83653 .01472 L
.83654 .01472 L
.83657 .01472 L
.8366 .01472 L
.83663 .01472 L
.83665 .01472 L
.83668 .01472 L
.83671 .01472 L
.83674 .01472 L
.83676 .01472 L
.83677 .01472 L
.8368 .01472 L
.83682 .01472 L
.83684 .01472 L
.83687 .01472 L
.8369 .01472 L
.83693 .01472 L
.83695 .01472 L
.83698 .01472 L
.83701 .01472 L
.83703 .01472 L
.83706 .01472 L
.83708 .01472 L
.83711 .01472 L
.83714 .01472 L
.83717 .01472 L
.8372 .01472 L
.83723 .01472 L
.83725 .01472 L
.83728 .01472 L
.83731 .01472 L
.83734 .01472 L
.83737 .01472 L
Mistroke
.83739 .01472 L
.83743 .01472 L
.83745 .01472 L
.83747 .01472 L
.83749 .01472 L
.8375 .01472 L
.83752 .01472 L
.83755 .01472 L
.83758 .01472 L
.83761 .01472 L
.83764 .01472 L
.83767 .01472 L
.8377 .01472 L
.83772 .01472 L
.83775 .01472 L
.83778 .01472 L
.83781 .01472 L
.83784 .01472 L
.83786 .01472 L
.83789 .01472 L
.83792 .01472 L
.83795 .01472 L
.83798 .01472 L
.83801 .01472 L
.83803 .01472 L
.83805 .01472 L
.83808 .01472 L
.83809 .01472 L
.83811 .01472 L
.83812 .01472 L
.83814 .01472 L
.83817 .01472 L
.83819 .01472 L
.8382 .01472 L
.83822 .01472 L
.83824 .01472 L
.83826 .01472 L
.83827 .01472 L
.83829 .01472 L
.83831 .01472 L
.83834 .01472 L
.83837 .01472 L
.8384 .01472 L
.83843 .01472 L
.83846 .01472 L
.83848 .01472 L
.83851 .01472 L
.83854 .01472 L
.83857 .01472 L
.83859 .01472 L
Mistroke
.83862 .01472 L
.83865 .01472 L
.83868 .01472 L
.83871 .01472 L
.83874 .01472 L
.83876 .01472 L
.83877 .01472 L
.83881 .01472 L
.83884 .01472 L
.83886 .01472 L
.83889 .01472 L
.83892 .01472 L
.83894 .01472 L
.83897 .01472 L
.83899 .01472 L
.83902 .01472 L
.83905 .01472 L
.83907 .01472 L
.8391 .01472 L
.83913 .01472 L
.83916 .01472 L
.83918 .01472 L
.8392 .01472 L
.83922 .01472 L
.83924 .01472 L
.83927 .01472 L
.8393 .01472 L
.83934 .01472 L
.83937 .01472 L
.83939 .01472 L
.83942 .01472 L
.83945 .01472 L
.83947 .01472 L
.8395 .01472 L
.83953 .01472 L
.83956 .01472 L
.83959 .01472 L
.83962 .01472 L
.83965 .01472 L
.83967 .01472 L
.83968 .01472 L
.83972 .01472 L
.83974 .01472 L
.83977 .01472 L
.8398 .01472 L
.83983 .01472 L
.83985 .01472 L
.83988 .01472 L
.8399 .01472 L
.83993 .01472 L
Mistroke
.83996 .01472 L
.83998 .01472 L
.84001 .01472 L
.84004 .01472 L
.84007 .01472 L
.84009 .01472 L
.84011 .01472 L
.84013 .01472 L
.84016 .01472 L
.84018 .01472 L
.84021 .01472 L
.84023 .01472 L
.84025 .01472 L
.84027 .01472 L
.8403 .01472 L
.84033 .01472 L
.84036 .01472 L
.84038 .01472 L
.84041 .01472 L
.84044 .01472 L
.84046 .01472 L
.84047 .01472 L
.84051 .01472 L
.84052 .01472 L
.84054 .01472 L
.84057 .01472 L
.8406 .01472 L
.84063 .01472 L
.84066 .01472 L
.84068 .01472 L
.84071 .01472 L
.84073 .01472 L
.84076 .01472 L
.84079 .01472 L
.84082 .01472 L
.84084 .01472 L
.84087 .01472 L
.8409 .01472 L
.84093 .01472 L
.84095 .01472 L
.84098 .01472 L
.84101 .01472 L
.84104 .01472 L
.84107 .01472 L
.8411 .01472 L
.84113 .01472 L
.84116 .01472 L
.84117 .01472 L
.84119 .01472 L
.84121 .01472 L
Mistroke
.84122 .01472 L
.84125 .01472 L
.84128 .01472 L
.84131 .01472 L
.84134 .01472 L
.84137 .01472 L
.8414 .01472 L
.84142 .01472 L
.84145 .01472 L
.84148 .01472 L
.84151 .01472 L
.84154 .01472 L
.84156 .01472 L
.84159 .01472 L
.84163 .01472 L
.84165 .01472 L
.84168 .01472 L
.84171 .01472 L
.84173 .01472 L
.84175 .01472 L
.84178 .01472 L
.84179 .01472 L
.84181 .01472 L
.84183 .01472 L
.84184 .01472 L
.84187 .01472 L
.84189 .01472 L
.84191 .01472 L
.84192 .01472 L
.84194 .01472 L
.84196 .01472 L
.84198 .01472 L
.84199 .01472 L
.84201 .01472 L
.84204 .01472 L
.84207 .01472 L
.8421 .01472 L
.84213 .01472 L
.84216 .01472 L
.84219 .01472 L
.84221 .01472 L
.84224 .01472 L
.84227 .01472 L
.84229 .01472 L
.84232 .01472 L
.84235 .01472 L
.84238 .01472 L
.84241 .01472 L
.84244 .01472 L
.84246 .01472 L
Mistroke
.84248 .01472 L
.84251 .01472 L
.84254 .01472 L
.84256 .01472 L
.84259 .01472 L
.84262 .01472 L
.84265 .01472 L
.84267 .01472 L
.84269 .01472 L
.84272 .01472 L
.84275 .01472 L
.84277 .01472 L
.8428 .01472 L
.84283 .01472 L
.84286 .01472 L
.84289 .01472 L
.8429 .01472 L
.84292 .01472 L
.84295 .01472 L
.84298 .01472 L
.843 .01472 L
.84304 .01472 L
.84307 .01472 L
.84309 .01472 L
.84312 .01472 L
.84315 .01472 L
.84318 .01472 L
.8432 .01472 L
.84323 .01472 L
.84326 .01472 L
.84329 .01472 L
.84332 .01472 L
.84335 .01472 L
.84337 .01472 L
.84338 .01472 L
.84342 .01472 L
.84345 .01472 L
.84347 .01472 L
.8435 .01472 L
.84353 .01472 L
.84356 .01472 L
.84358 .01472 L
.8436 .01472 L
.84363 .01472 L
.84366 .01472 L
.84368 .01472 L
.84371 .01472 L
.84374 .01472 L
.84377 .01472 L
.8438 .01472 L
Mistroke
.84381 .01472 L
.84383 .01472 L
.84386 .01472 L
.84389 .01472 L
.84391 .01472 L
.84395 .01472 L
.84398 .01472 L
.844 .01472 L
.84403 .01472 L
.84406 .01472 L
.84409 .01472 L
.84411 .01472 L
.84414 .01472 L
.84417 .01472 L
.8442 .01472 L
.84423 .01472 L
.84426 .01472 L
.84428 .01472 L
.8443 .01472 L
.84433 .01472 L
.84436 .01472 L
.84438 .01472 L
.84441 .01472 L
.84444 .01472 L
.84447 .01472 L
.84449 .01472 L
.84451 .01472 L
.84454 .01472 L
.84457 .01472 L
.84459 .01472 L
.84462 .01472 L
.84465 .01472 L
.84468 .01472 L
.84471 .01472 L
.84472 .01472 L
.84474 .01472 L
.84477 .01472 L
.8448 .01472 L
.84483 .01472 L
.84484 .01472 L
.84486 .01472 L
.84489 .01472 L
.84492 .01472 L
.84494 .01472 L
.84497 .01472 L
.84499 .01472 L
.84502 .01472 L
.84505 .01472 L
.84507 .01472 L
.84509 .01472 L
Mistroke
.84512 .01472 L
.84514 .01472 L
.84515 .01472 L
.84518 .01472 L
.84521 .01472 L
.84524 .01472 L
.84527 .01472 L
.84529 .01472 L
.84532 .01472 L
.84535 .01472 L
.84537 .01472 L
.8454 .01472 L
.84543 .01472 L
.84546 .01472 L
.84548 .01472 L
.84551 .01472 L
.84554 .01472 L
.84556 .01472 L
.84559 .01472 L
.84562 .01472 L
.84565 .01472 L
.84568 .01472 L
.84571 .01472 L
.84574 .01472 L
.84577 .01472 L
.84578 .01472 L
.8458 .01472 L
.84582 .01472 L
.84583 .01472 L
.84587 .01472 L
.84589 .01472 L
.84592 .01472 L
.84595 .01472 L
.84598 .01472 L
.84601 .01472 L
.84604 .01472 L
.84606 .01472 L
.84609 .01472 L
.84612 .01472 L
.84615 .01472 L
.84618 .01472 L
.84621 .01472 L
.84624 .01472 L
.84627 .01472 L
.84629 .01472 L
.84633 .01472 L
.84634 .01472 L
.84636 .01472 L
.84639 .01472 L
.84641 .01472 L
Mistroke
.84642 .01472 L
.84644 .01472 L
.84646 .01472 L
.84649 .01472 L
.8465 .01472 L
.84652 .01472 L
.84654 .01472 L
.84656 .01472 L
.84657 .01472 L
.84659 .01472 L
.84661 .01472 L
.84662 .01472 L
.84665 .01472 L
.84668 .01472 L
.84671 .01472 L
.84674 .01472 L
.84677 .01472 L
.8468 .01472 L
.84683 .01472 L
.84685 .01472 L
.84688 .01472 L
.84691 .01472 L
.84694 .01472 L
.84697 .01472 L
.84699 .01472 L
.84702 .01472 L
.84706 .01472 L
.84707 .01472 L
.84709 .01472 L
.84712 .01472 L
.84715 .01472 L
.84718 .01472 L
.8472 .01472 L
.84723 .01472 L
.84726 .01472 L
.84729 .01472 L
.84731 .01472 L
.84733 .01472 L
.84736 .01472 L
.84739 .01472 L
.84742 .01472 L
.84745 .01472 L
.84747 .01472 L
.8475 .01472 L
.84752 .01472 L
.84753 .01472 L
.84756 .01472 L
.84759 .01472 L
.84762 .01472 L
.84765 .01472 L
Mistroke
.84768 .01472 L
.84771 .01472 L
.84774 .01472 L
.84776 .01472 L
.84779 .01472 L
.84782 .01472 L
.84785 .01472 L
.84788 .01472 L
.84791 .01472 L
.84793 .01472 L
.84797 .01472 L
.84798 .01472 L
.848 .01472 L
.84803 .01472 L
.84806 .01472 L
.84809 .01472 L
.84811 .01472 L
.84814 .01472 L
.84817 .01472 L
.8482 .01472 L
.84822 .01472 L
.84825 .01472 L
.84827 .01472 L
.8483 .01472 L
.84833 .01472 L
.84836 .01472 L
.84838 .01472 L
.84841 .01472 L
.84843 .01472 L
.84844 .01472 L
.84847 .01472 L
.8485 .01472 L
.84853 .01472 L
.84855 .01472 L
.84856 .01472 L
.84859 .01472 L
.84862 .01472 L
.84865 .01472 L
.84867 .01472 L
.8487 .01472 L
.84873 .01472 L
.84876 .01472 L
.84877 .01472 L
.84879 .01472 L
.84882 .01472 L
.84884 .01472 L
.84886 .01472 L
.84888 .01472 L
.84892 .01472 L
.84895 .01472 L
Mistroke
.84897 .01472 L
.849 .01472 L
.84903 .01472 L
.84905 .01472 L
.84907 .01472 L
.8491 .01472 L
.84913 .01472 L
.84916 .01472 L
.84919 .01472 L
.84922 .01472 L
.84924 .01472 L
.84927 .01472 L
.8493 .01472 L
.84933 .01472 L
.84936 .01472 L
.84938 .01472 L
.84941 .01472 L
.84944 .01472 L
.84947 .01472 L
.84949 .01472 L
.84951 .01472 L
.84952 .01472 L
.84954 .01472 L
.84957 .01472 L
.8496 .01472 L
.84963 .01472 L
.84966 .01472 L
.84969 .01472 L
.84971 .01472 L
.84974 .01472 L
.84977 .01472 L
.84979 .01472 L
.84983 .01472 L
.84986 .01472 L
.84988 .01472 L
.84991 .01472 L
.84994 .01472 L
.84997 .01472 L
.85 .01472 L
.85003 .01472 L
.85005 .01472 L
.85006 .01472 L
.85009 .01472 L
.85011 .01472 L
.85013 .01472 L
.85014 .01472 L
.85016 .01472 L
.85019 .01472 L
.85021 .01472 L
.85022 .01472 L
Mistroke
.85024 .01472 L
.85026 .01472 L
.85028 .01472 L
.85029 .01472 L
.85031 .01472 L
.85033 .01472 L
.85035 .01472 L
.85039 .01472 L
.85041 .01472 L
.85045 .01472 L
.85048 .01472 L
.8505 .01472 L
.85053 .01472 L
.85056 .01472 L
.85058 .01472 L
.85061 .01472 L
.85064 .01472 L
.85067 .01472 L
.8507 .01472 L
.85073 .01472 L
.85076 .01472 L
.85078 .01472 L
.85079 .01472 L
.85082 .01472 L
.85085 .01472 L
.85088 .01472 L
.85091 .01472 L
.85094 .01472 L
.85096 .01472 L
.85099 .01472 L
.85101 .01472 L
.85104 .01472 L
.85107 .01472 L
.85109 .01472 L
.85112 .01472 L
.85115 .01472 L
.85117 .01472 L
.8512 .01472 L
.85122 .01472 L
.85124 .01472 L
.85126 .01472 L
.85129 .01472 L
.85132 .01472 L
.85135 .01472 L
.85138 .01472 L
.85141 .01472 L
.85144 .01472 L
.85147 .01472 L
.85149 .01472 L
.85152 .01472 L
Mistroke
.85155 .01472 L
.85158 .01472 L
.85161 .01472 L
.85164 .01472 L
.85167 .01472 L
.85169 .01472 L
.8517 .01472 L
.85173 .01472 L
.85176 .01472 L
.85179 .01472 L
.85182 .01472 L
.85185 .01472 L
.85187 .01472 L
.8519 .01472 L
.85192 .01472 L
.85195 .01472 L
.85198 .01472 L
.852 .01472 L
.85203 .01472 L
.85206 .01472 L
.85208 .01472 L
.85211 .01472 L
.85213 .01472 L
.85215 .01472 L
.85217 .01472 L
.8522 .01472 L
.85223 .01472 L
.85225 .01472 L
.85227 .01472 L
.85229 .01472 L
.85232 .01472 L
.85235 .01472 L
.85237 .01472 L
.8524 .01472 L
.85243 .01472 L
.85246 .01472 L
.85248 .01472 L
.85249 .01472 L
.85253 .01472 L
.85254 .01472 L
.85256 .01472 L
.85259 .01472 L
.85262 .01472 L
.85265 .01472 L
.85268 .01472 L
.8527 .01472 L
.85273 .01472 L
.85275 .01472 L
.85278 .01472 L
.8528 .01472 L
Mistroke
.85283 .01472 L
.85286 .01472 L
.85289 .01472 L
.85292 .01472 L
.85295 .01472 L
.85297 .01472 L
.853 .01472 L
.85303 .01472 L
.85306 .01472 L
.85309 .01472 L
.85312 .01472 L
.85315 .01472 L
.85318 .01472 L
.85319 .01472 L
.85321 .01472 L
.85323 .01472 L
.85324 .01472 L
.85327 .01472 L
.8533 .01472 L
.85333 .01472 L
.85336 .01472 L
.85339 .01472 L
.85342 .01472 L
.85344 .01472 L
.85347 .01472 L
.8535 .01472 L
.85353 .01472 L
.85356 .01472 L
.85359 .01472 L
.85361 .01472 L
.85365 .01472 L
.85367 .01472 L
.8537 .01472 L
.85373 .01472 L
.85375 .01472 L
.85377 .01472 L
.8538 .01472 L
.85381 .01472 L
.85383 .01472 L
.85385 .01472 L
.85386 .01472 L
.85389 .01472 L
.85391 .01472 L
.85393 .01472 L
.85394 .01472 L
.85396 .01472 L
.85398 .01472 L
.854 .01472 L
.85401 .01472 L
.85403 .01472 L
Mistroke
.85406 .01472 L
.85409 .01472 L
.85412 .01472 L
.85415 .01472 L
.85418 .01472 L
.85421 .01472 L
.85423 .01472 L
.85426 .01472 L
.85429 .01472 L
.85431 .01472 L
.85434 .01472 L
.85437 .01472 L
.8544 .01472 L
.85443 .01472 L
.85446 .01472 L
.85448 .01472 L
.8545 .01472 L
.85453 .01472 L
.85456 .01472 L
.85458 .01472 L
.85461 .01472 L
.85464 .01472 L
.85467 .01472 L
.85469 .01472 L
.85471 .01472 L
.85474 .01472 L
.85477 .01472 L
.85479 .01472 L
.85482 .01472 L
.85485 .01472 L
.85488 .01472 L
.85491 .01472 L
.85492 .01472 L
.85494 .01472 L
.85497 .01472 L
.855 .01472 L
.85503 .01472 L
.85506 .01472 L
.85509 .01472 L
.85511 .01472 L
.85514 .01472 L
.85517 .01472 L
.8552 .01472 L
.85522 .01472 L
.85525 .01472 L
.85528 .01472 L
.85531 .01472 L
.85534 .01472 L
.85537 .01472 L
.85539 .01472 L
Mistroke
.85541 .01472 L
.85544 .01472 L
.85547 .01472 L
.85549 .01472 L
.85552 .01472 L
.85555 .01472 L
.85558 .01472 L
.8556 .01472 L
.85563 .01472 L
.85565 .01472 L
.85568 .01472 L
.8557 .01472 L
.85573 .01472 L
.85576 .01472 L
.85579 .01472 L
.85582 .01472 L
.85583 .01472 L
.85585 .01472 L
.85588 .01472 L
.85591 .01472 L
.85594 .01472 L
.85595 .01472 L
.85597 .01472 L
.856 .01472 L
.85603 .01472 L
.85605 .01472 L
.85608 .01472 L
.8561 .01472 L
.85613 .01472 L
.85616 .01472 L
.85618 .01472 L
.8562 .01472 L
.85623 .01472 L
.85624 .01472 L
.85626 .01472 L
.85629 .01472 L
.85632 .01472 L
.85635 .01472 L
.85638 .01472 L
.8564 .01472 L
.85643 .01472 L
.85646 .01472 L
.85648 .01472 L
.85651 .01472 L
.85654 .01472 L
.85657 .01472 L
.85659 .01472 L
.85662 .01472 L
.85665 .01472 L
.85667 .01472 L
Mistroke
.8567 .01472 L
.85673 .01472 L
.85676 .01472 L
.85679 .01472 L
.85682 .01472 L
.85685 .01472 L
.85688 .01472 L
.85689 .01472 L
.85691 .01472 L
.85693 .01472 L
.85694 .01472 L
.85697 .01472 L
.857 .01472 L
.85703 .01472 L
.85706 .01472 L
.85709 .01472 L
.85712 .01472 L
.85715 .01472 L
.85717 .01472 L
.8572 .01472 L
.85723 .01472 L
.85726 .01472 L
.85729 .01472 L
.85732 .01472 L
.85735 .01472 L
.85738 .01472 L
.8574 .01472 L
.85743 .01472 L
.85745 .01472 L
.85747 .01472 L
.8575 .01472 L
.85752 .01472 L
.85753 .01472 L
.85755 .01472 L
.85756 .01472 L
.85759 .01472 L
.85761 .01472 L
.85763 .01472 L
.85765 .01472 L
.85766 .01472 L
.85768 .01472 L
.8577 .01472 L
.85771 .01472 L
.85773 .01472 L
.85776 .01472 L
.85779 .01472 L
.85782 .01472 L
.85785 .01472 L
.85788 .01472 L
.85791 .01472 L
Mistroke
.85793 .01472 L
.85796 .01472 L
.85799 .01472 L
.85802 .01472 L
.85804 .01472 L
.85808 .01472 L
.8581 .01472 L
.85813 .01472 L
.85816 .01472 L
.85818 .01472 L
.8582 .01472 L
.85823 .01472 L
.85826 .01472 L
.85828 .01472 L
.85831 .01472 L
.85834 .01472 L
.85837 .01472 L
.85839 .01472 L
.85842 .01472 L
.85844 .01472 L
.85847 .01472 L
.8585 .01472 L
.85853 .01472 L
.85855 .01472 L
.85858 .01472 L
.85861 .01472 L
.85862 .01472 L
.85864 .01472 L
.85867 .01472 L
.8587 .01472 L
.85873 .01472 L
.85876 .01472 L
.85879 .01472 L
.85882 .01472 L
.85884 .01472 L
.85887 .01472 L
.8589 .01472 L
.85892 .01472 L
.85895 .01472 L
.85899 .01472 L
.85901 .01472 L
.85904 .01472 L
.85907 .01472 L
.85909 .01472 L
.85911 .01472 L
.85914 .01472 L
.85917 .01472 L
.85919 .01472 L
.85922 .01472 L
.85925 .01472 L
Mistroke
.85928 .01472 L
.8593 .01472 L
.85933 .01472 L
.85935 .01472 L
.85938 .01472 L
.85941 .01472 L
.85944 .01472 L
.85946 .01472 L
.85949 .01472 L
.85952 .01472 L
.85953 .01472 L
.85955 .01472 L
.85958 .01472 L
.85961 .01472 L
.85964 .01472 L
.85967 .01472 L
.8597 .01472 L
.85973 .01472 L
.85975 .01472 L
.85978 .01472 L
.85981 .01472 L
.85983 .01472 L
.85986 .01472 L
.8599 .01472 L
.85992 .01472 L
.85995 .01472 L
.85998 .01472 L
.86 .01472 L
.86002 .01472 L
.86005 .01472 L
.86008 .01472 L
.8601 .01472 L
.86013 .01472 L
.86016 .01472 L
.86019 .01472 L
.86021 .01472 L
.86024 .01472 L
.86026 .01472 L
.86029 .01472 L
.86032 .01472 L
.86035 .01472 L
.86037 .01472 L
.8604 .01472 L
.86043 .01472 L
.86045 .01472 L
.86046 .01472 L
.86049 .01472 L
.86052 .01472 L
.86055 .01472 L
.86056 .01472 L
Mistroke
.86058 .01472 L
.86061 .01472 L
.86064 .01472 L
.86066 .01472 L
.86069 .01472 L
.86072 .01472 L
.86075 .01472 L
.86078 .01472 L
.86079 .01472 L
.86081 .01472 L
.86084 .01472 L
.86086 .01472 L
.86087 .01472 L
.8609 .01472 L
.86093 .01472 L
.86096 .01472 L
.86099 .01472 L
.86102 .01472 L
.86104 .01472 L
.86107 .01472 L
.86109 .01472 L
.86112 .01472 L
.86115 .01472 L
.86118 .01472 L
.8612 .01472 L
.86123 .01472 L
.86126 .01472 L
.86129 .01472 L
.86131 .01472 L
.86134 .01472 L
.86137 .01472 L
.8614 .01472 L
.86143 .01472 L
.86146 .01472 L
.86149 .01472 L
.86151 .01472 L
.86152 .01472 L
.86154 .01472 L
.86156 .01472 L
.86159 .01472 L
.86161 .01472 L
.86164 .01472 L
.86168 .01472 L
.8617 .01472 L
.86173 .01472 L
.86176 .01472 L
.86178 .01472 L
.86181 .01472 L
.86184 .01472 L
.86187 .01472 L
Mistroke
.8619 .01472 L
.86193 .01472 L
.86196 .01472 L
.86199 .01472 L
.86202 .01472 L
.86205 .01472 L
.86207 .01472 L
.86208 .01472 L
.86211 .01472 L
.86213 .01472 L
.86214 .01472 L
.86216 .01472 L
.86218 .01472 L
.86221 .01472 L
.86223 .01472 L
.86224 .01472 L
.86226 .01472 L
.86228 .01472 L
.86229 .01472 L
.86231 .01472 L
.86233 .01472 L
.86234 .01472 L
.86237 .01472 L
.8624 .01472 L
.86243 .01472 L
.86246 .01472 L
.86249 .01472 L
.86252 .01472 L
.86255 .01472 L
.86257 .01472 L
.8626 .01472 L
.86263 .01472 L
.86266 .01472 L
.86269 .01472 L
.86272 .01472 L
.86275 .01472 L
.86278 .01472 L
.8628 .01472 L
.86281 .01472 L
.86284 .01472 L
.86287 .01472 L
.8629 .01472 L
.86293 .01472 L
.86296 .01472 L
.86298 .01472 L
.86301 .01472 L
.86303 .01472 L
.86306 .01472 L
.86308 .01472 L
.86311 .01472 L
Mistroke
.86314 .01472 L
.86317 .01472 L
.86319 .01472 L
.86322 .01472 L
.86324 .01472 L
.86325 .01472 L
.86328 .01472 L
.86331 .01472 L
.86334 .01472 L
.86337 .01472 L
.8634 .01472 L
.86343 .01472 L
.86346 .01472 L
.86348 .01472 L
.86351 .01472 L
.86354 .01472 L
.86357 .01472 L
.8636 .01472 L
.86363 .01472 L
.86366 .01472 L
.86369 .01472 L
.86371 .01472 L
.86372 .01472 L
.86375 .01472 L
.86378 .01472 L
.86381 .01472 L
.86384 .01472 L
.86387 .01472 L
.86389 .01472 L
.86392 .01472 L
.86394 .01472 L
.86397 .01472 L
.86399 .01472 L
.86402 .01472 L
.86405 .01472 L
.86408 .01472 L
.8641 .01472 L
.86413 .01472 L
.86415 .01472 L
.86417 .01472 L
.86419 .01472 L
.86422 .01472 L
.86425 .01472 L
.86427 .01472 L
.86428 .01472 L
.86431 .01472 L
.86434 .01472 L
.86437 .01472 L
.86439 .01472 L
.86442 .01472 L
Mistroke
.86445 .01472 L
.86448 .01472 L
.8645 .01472 L
.86451 .01472 L
.86454 .01472 L
.86456 .01472 L
.86458 .01472 L
.86461 .01472 L
.86464 .01472 L
.86467 .01472 L
.86469 .01472 L
.86472 .01472 L
.86475 .01472 L
.86477 .01472 L
.8648 .01472 L
.86482 .01472 L
.86485 .01472 L
.86488 .01472 L
.86491 .01472 L
.86494 .01472 L
.86497 .01472 L
.86499 .01472 L
.86502 .01472 L
.86505 .01472 L
.86508 .01472 L
.86511 .01472 L
.86514 .01472 L
.86517 .01472 L
.8652 .01472 L
.86521 .01472 L
.86523 .01472 L
.86525 .01472 L
.86526 .01472 L
.86529 .01472 L
.86532 .01472 L
.86535 .01472 L
.86538 .01472 L
.86541 .01472 L
.86544 .01472 L
.86546 .01472 L
.86549 .01472 L
.86552 .01472 L
.86555 .01472 L
.86558 .01472 L
.8656 .01472 L
.86563 .01472 L
.86566 .01472 L
.86569 .01472 L
.86572 .01472 L
.86575 .01472 L
Mistroke
.86577 .01472 L
.86579 .01472 L
.86582 .01472 L
.86583 .01472 L
.86585 .01472 L
.86587 .01472 L
.86588 .01472 L
.86591 .01472 L
.86593 .01472 L
.86595 .01472 L
.86596 .01472 L
.86598 .01472 L
.866 .01472 L
.86602 .01472 L
.86603 .01472 L
.86605 .01472 L
.86608 .01472 L
.86611 .01472 L
.86614 .01472 L
.86617 .01472 L
.8662 .01472 L
.86623 .01472 L
.86625 .01472 L
.86628 .01472 L
.86631 .01472 L
.86633 .01472 L
.86636 .01472 L
.86639 .01472 L
.86642 .01472 L
.86645 .01472 L
.86648 .01472 L
.8665 .01472 L
.86652 .01472 L
.86655 .01472 L
.86658 .01472 L
.8666 .01472 L
.86663 .01472 L
.86666 .01472 L
.86669 .01472 L
.86671 .01472 L
.86674 .01472 L
.86676 .01472 L
.86679 .01472 L
.86682 .01472 L
.86684 .01472 L
.86687 .01472 L
.8669 .01472 L
.86693 .01472 L
.86694 .01472 L
.86696 .01472 L
Mistroke
.86699 .01472 L
.86702 .01472 L
.86705 .01472 L
.86708 .01472 L
.86711 .01472 L
.86714 .01472 L
.86716 .01472 L
.86719 .01472 L
.86722 .01472 L
.86724 .01472 L
.86727 .01472 L
.8673 .01472 L
.86733 .01472 L
.86736 .01472 L
.86739 .01472 L
.86741 .01472 L
.86743 .01472 L
.86746 .01472 L
.86749 .01472 L
.86751 .01472 L
.86754 .01472 L
.86757 .01472 L
.8676 .01472 L
.86762 .01472 L
.86765 .01472 L
.86767 .01472 L
.8677 .01472 L
.86773 .01472 L
.86775 .01472 L
.86778 .01472 L
.86781 .01472 L
.86784 .01472 L
.86785 .01472 L
.86787 .01472 L
.8679 .01472 L
.86793 .01472 L
.86796 .01472 L
.86797 .01472 L
.86799 .01472 L
.86802 .01472 L
.86805 .01472 L
.86807 .01472 L
.8681 .01472 L
.86812 .01472 L
.86815 .01472 L
.86818 .01472 L
.8682 .01472 L
.86822 .01472 L
.86825 .01472 L
.86827 .01472 L
Mistroke
.86828 .01472 L
.86831 .01472 L
.86834 .01472 L
.86837 .01472 L
.8684 .01472 L
.86842 .01472 L
.86845 .01472 L
.86848 .01472 L
.8685 .01472 L
.86853 .01472 L
.86856 .01472 L
.86859 .01472 L
.86861 .01472 L
.86864 .01472 L
.86867 .01472 L
.86869 .01472 L
.86872 .01472 L
.86875 .01472 L
.86878 .01472 L
.86881 .01472 L
.86884 .01472 L
.86887 .01472 L
.8689 .01472 L
.86891 .01472 L
.86893 .01472 L
.86895 .01472 L
.86896 .01472 L
.86899 .01472 L
.86902 .01472 L
.86905 .01472 L
.86908 .01472 L
.86911 .01472 L
.86914 .01472 L
.86917 .01472 L
.86919 .01472 L
.86922 .01472 L
.86925 .01472 L
.86928 .01472 L
.86931 .01472 L
.86934 .01472 L
.86937 .01472 L
.8694 .01472 L
.86942 .01472 L
.86946 .01472 L
.86947 .01472 L
.86949 .01472 L
.86952 .01472 L
.86954 .01472 L
.86955 .01472 L
.86957 .01472 L
Mistroke
.86959 .01472 L
.86962 .01472 L
.86963 .01472 L
.86965 .01472 L
.86967 .01472 L
.86969 .01472 L
.8697 .01472 L
.86972 .01472 L
.86974 .01472 L
.86975 .01472 L
.86978 .01472 L
.86981 .01472 L
.86984 .01472 L
.86987 .01472 L
.8699 .01472 L
.86993 .01472 L
.86996 .01472 L
.86998 .01472 L
.87001 .01472 L
.87004 .01472 L
.87007 .01472 L
.8701 .01472 L
.87012 .01472 L
.87015 .01472 L
.87018 .01472 L
.8702 .01472 L
.87022 .01472 L
.87025 .01472 L
.87028 .01472 L
.8703 .01472 L
.87033 .01472 L
.87036 .01472 L
.87039 .01472 L
.87041 .01472 L
.87044 .01472 L
.87046 .01472 L
.87049 .01472 L
.87052 .01472 L
.87055 .01472 L
.87057 .01472 L
.8706 .01472 L
.87063 .01472 L
.87065 .01472 L
.87066 .01472 L
.87069 .01472 L
.87072 .01472 L
.87075 .01472 L
.87078 .01472 L
.87081 .01472 L
.87084 .01472 L
Mistroke
.87087 .01472 L
.87089 .01472 L
.87092 .01472 L
.87095 .01472 L
.87098 .01472 L
.87101 .01472 L
.87103 .01472 L
.87106 .01472 L
.87109 .01472 L
.87111 .01472 L
.87113 .01472 L
.87116 .01472 L
.87119 .01472 L
.87121 .01472 L
.87124 .01472 L
.87127 .01472 L
.8713 .01472 L
.87132 .01472 L
.87135 .01472 L
.87137 .01472 L
.8714 .01472 L
.87143 .01472 L
.87146 .01472 L
.87148 .01472 L
.87151 .01472 L
.87154 .01472 L
.87156 .01472 L
.87157 .01472 L
.8716 .01472 L
.87163 .01472 L
.87166 .01472 L
.87168 .01472 L
.87169 .01472 L
.87172 .01472 L
.87175 .01472 L
.87177 .01472 L
.8718 .01472 L
.87183 .01472 L
.87186 .01472 L
.87189 .01472 L
.8719 .01472 L
.87192 .01472 L
.87195 .01472 L
.87197 .01472 L
.87198 .01472 L
.87201 .01472 L
.87204 .01472 L
.87207 .01472 L
.8721 .01472 L
.87213 .01472 L
Mistroke
.87215 .01472 L
.87218 .01472 L
.8722 .01472 L
.87223 .01472 L
.87226 .01472 L
.87229 .01472 L
.87231 .01472 L
.87234 .01472 L
.87237 .01472 L
.8724 .01472 L
.87242 .01472 L
.87245 .01472 L
.87248 .01472 L
.87251 .01472 L
.87254 .01472 L
.87257 .01472 L
.8726 .01472 L
.87262 .01472 L
.87263 .01472 L
.87265 .01472 L
.87267 .01472 L
.8727 .01472 L
.87272 .01472 L
.87275 .01472 L
.87279 .01472 L
.87281 .01472 L
.87284 .01472 L
.87287 .01472 L
.87289 .01472 L
.87292 .01472 L
.87295 .01472 L
.87298 .01472 L
.87301 .01472 L
.87304 .01472 L
.87307 .01472 L
.8731 .01472 L
.87313 .01472 L
.87316 .01472 L
.87318 .01472 L
.87319 .01472 L
.87322 .01472 L
.87324 .01472 L
.87325 .01472 L
.87327 .01472 L
.87329 .01472 L
.87332 .01472 L
.87334 .01472 L
.87335 .01472 L
.87337 .01472 L
.87339 .01472 L
Mistroke
.8734 .01472 L
.87342 .01472 L
.87344 .01472 L
.87345 .01472 L
.87348 .01472 L
.87351 .01472 L
.87354 .01472 L
.87357 .01472 L
.8736 .01472 L
.87363 .01472 L
.87366 .01472 L
.87368 .01472 L
.87371 .01472 L
.87374 .01472 L
.87377 .01472 L
.8738 .01472 L
.87383 .01472 L
.87386 .01472 L
.87389 .01472 L
.8739 .01472 L
.87392 .01472 L
.87395 .01472 L
.87398 .01472 L
.87401 .01472 L
.87403 .01472 L
.87406 .01472 L
.87409 .01472 L
.87412 .01472 L
.87414 .01472 L
.87416 .01472 L
.87419 .01472 L
.87422 .01472 L
.87425 .01472 L
.87428 .01472 L
.8743 .01472 L
.87433 .01472 L
.87435 .01472 L
.87436 .01472 L
.87439 .01472 L
.87442 .01472 L
.87445 .01472 L
.87448 .01472 L
.87451 .01472 L
.87454 .01472 L
.87457 .01472 L
.87459 .01472 L
.87462 .01472 L
.87465 .01472 L
.87468 .01472 L
.87471 .01472 L
Mistroke
.87474 .01472 L
.87476 .01472 L
.8748 .01472 L
.87481 .01472 L
.87483 .01472 L
.87486 .01472 L
.87489 .01472 L
.87492 .01472 L
.87494 .01472 L
.87497 .01472 L
.875 .01472 L
.87503 .01472 L
.87505 .01472 L
.87507 .01472 L
.8751 .01472 L
.87513 .01472 L
.87516 .01472 L
.87519 .01472 L
.87521 .01472 L
.87524 .01472 L
.87526 .01472 L
.87527 .01472 L
.8753 .01472 L
.87533 .01472 L
.87536 .01472 L
.87539 .01472 L
.87542 .01472 L
.87545 .01472 L
.87547 .01472 L
.8755 .01472 L
.87553 .01472 L
.87556 .01472 L
.87559 .01472 L
.87562 .01472 L
.87565 .01472 L
.87568 .01472 L
.87571 .01472 L
.87572 .01472 L
.87574 .01472 L
.87577 .01472 L
.8758 .01472 L
.87583 .01472 L
.87585 .01472 L
.87588 .01472 L
.87591 .01472 L
.87594 .01472 L
.87596 .01472 L
.87599 .01472 L
.87601 .01472 L
.87604 .01472 L
Mistroke
.87607 .01472 L
.8761 .01472 L
.87612 .01472 L
.87615 .01472 L
.87617 .01472 L
.87618 .01472 L
.87621 .01472 L
.87624 .01472 L
.87627 .01472 L
.87629 .01472 L
.8763 .01472 L
.87633 .01472 L
.87636 .01472 L
.87639 .01472 L
.87641 .01472 L
.87644 .01472 L
.87647 .01472 L
.8765 .01472 L
.87652 .01472 L
.87653 .01472 L
.87656 .01472 L
.87658 .01472 L
.8766 .01472 L
.87663 .01472 L
.87666 .01472 L
.87669 .01472 L
.87671 .01472 L
.87674 .01472 L
.87677 .01472 L
.87679 .01472 L
.87682 .01472 L
.87684 .01472 L
.87687 .01472 L
.8769 .01472 L
.87693 .01472 L
.87696 .01472 L
.87699 .01472 L
.87701 .01472 L
.87704 .01472 L
.87707 .01472 L
.8771 .01472 L
.87712 .01472 L
.87715 .01472 L
.87719 .01472 L
.87721 .01472 L
.87723 .01472 L
.87725 .01472 L
.87726 .01472 L
.87728 .01472 L
.87731 .01472 L
Mistroke
.87734 .01472 L
.87737 .01472 L
.8774 .01472 L
.87743 .01472 L
.87746 .01472 L
.87748 .01472 L
.87751 .01472 L
.87754 .01472 L
.87757 .01472 L
.8776 .01472 L
.87762 .01472 L
.87765 .01472 L
.87768 .01472 L
.87771 .01472 L
.87774 .01472 L
.87777 .01472 L
.87779 .01472 L
.87781 .01472 L
.87784 .01472 L
.87785 .01472 L
.87787 .01472 L
.87788 .01472 L
.8779 .01472 L
.87793 .01472 L
.87795 .01472 L
.87797 .01472 L
.87798 .01472 L
.878 .01472 L
.87802 .01472 L
.87804 .01472 L
.87805 .01472 L
.87807 .01472 L
.8781 .01472 L
.87813 .01472 L
.87816 .01472 L
.87819 .01472 L
.87822 .01472 L
.87824 .01472 L
.87827 .01472 L
.8783 .01472 L
.87833 .01472 L
.87835 .01472 L
.87838 .01472 L
.87841 .01472 L
.87844 .01472 L
.87847 .01472 L
.8785 .01472 L
.87852 .01472 L
.87854 .01472 L
.87857 .01472 L
Mistroke
.8786 .01472 L
.87862 .01472 L
.87865 .01472 L
.87868 .01472 L
.87871 .01472 L
.87873 .01472 L
.87875 .01472 L
.87878 .01472 L
.87881 .01472 L
.87883 .01472 L
.87886 .01472 L
.87889 .01472 L
.87892 .01472 L
.87895 .01472 L
.87896 .01472 L
.87898 .01472 L
.87901 .01472 L
.87904 .01472 L
.87907 .01472 L
.8791 .01472 L
.87913 .01472 L
.87915 .01472 L
.87918 .01472 L
.87921 .01472 L
.87924 .01472 L
.87926 .01472 L
.87929 .01472 L
.87932 .01472 L
.87935 .01472 L
.87938 .01472 L
.87941 .01472 L
.87943 .01472 L
.87945 .01472 L
.87948 .01472 L
.87951 .01472 L
.87953 .01472 L
.87956 .01472 L
.87959 .01472 L
.87962 .01472 L
.87964 .01472 L
.87967 .01472 L
.87969 .01472 L
.87972 .01472 L
.87975 .01472 L
.87977 .01472 L
.8798 .01472 L
.87983 .01472 L
.87986 .01472 L
.87987 .01472 L
.87989 .01472 L
Mistroke
.87992 .01472 L
.87995 .01472 L
.87998 .01472 L
.87999 .01472 L
.88001 .01472 L
.88004 .01472 L
.88007 .01472 L
.88009 .01472 L
.88012 .01472 L
.88015 .01472 L
.88017 .01472 L
.8802 .01472 L
.88022 .01472 L
.88024 .01472 L
.88027 .01472 L
.88029 .01472 L
.8803 .01472 L
.88033 .01472 L
.88036 .01472 L
.88039 .01472 L
.88042 .01472 L
.88044 .01472 L
.88047 .01472 L
.8805 .01472 L
.88052 .01472 L
.88055 .01472 L
.88058 .01472 L
.88061 .01472 L
.88063 .01472 L
.88066 .01472 L
.88069 .01472 L
.88072 .01472 L
.88074 .01472 L
.88077 .01472 L
.8808 .01472 L
.88083 .01472 L
.88086 .01472 L
.88089 .01472 L
.88092 .01472 L
.88093 .01472 L
.88095 .01472 L
.88097 .01472 L
.88099 .01472 L
.88102 .01472 L
.88104 .01472 L
.88107 .01472 L
.8811 .01472 L
.88113 .01472 L
.88116 .01472 L
.88119 .01472 L
Mistroke
.88121 .01472 L
.88124 .01472 L
.88127 .01472 L
.8813 .01472 L
.88133 .01472 L
.88136 .01472 L
.88139 .01472 L
.88142 .01472 L
.88144 .01472 L
.88148 .01472 L
.88149 .01472 L
.88151 .01472 L
.88154 .01472 L
.88156 .01472 L
.88157 .01472 L
.88159 .01472 L
.88161 .01472 L
.88164 .01472 L
.88165 .01472 L
.88167 .01472 L
.88169 .01472 L
.88171 .01472 L
.88172 .01472 L
.88174 .01472 L
.88176 .01472 L
.88177 .01472 L
.8818 .01472 L
.88183 .01472 L
.88186 .01472 L
.88189 .01472 L
.88192 .01472 L
.88195 .01472 L
.88198 .01472 L
.882 .01472 L
.88203 .01472 L
.88206 .01472 L
.88209 .01472 L
.88212 .01472 L
.88215 .01472 L
.88217 .01472 L
.88221 .01472 L
.88222 .01472 L
.88224 .01472 L
.88227 .01472 L
.8823 .01472 L
.88233 .01472 L
.88235 .01472 L
.88238 .01472 L
.88241 .01472 L
.88244 .01472 L
Mistroke
.88246 .01472 L
.88248 .01472 L
.88251 .01472 L
.88254 .01472 L
.88257 .01472 L
.8826 .01472 L
.88262 .01472 L
.88265 .01472 L
.88267 .01472 L
.88268 .01472 L
.88271 .01472 L
.88274 .01472 L
.88277 .01472 L
.8828 .01472 L
.88283 .01472 L
.88286 .01472 L
.88289 .01472 L
.88291 .01472 L
.88294 .01472 L
.88297 .01472 L
.883 .01472 L
.88303 .01472 L
.88306 .01472 L
.88308 .01472 L
.88312 .01472 L
.88313 .01472 L
.88315 .01472 L
.88318 .01472 L
.88321 .01472 L
.88324 .01472 L
.88326 .01472 L
.88329 .01472 L
.88332 .01472 L
.88335 .01472 L
.88337 .01472 L
.8834 .01472 L
.88342 .01472 L
.88345 .01472 L
.88348 .01472 L
.88351 .01472 L
.88353 .01472 L
.88356 .01472 L
.88358 .01472 L
.88359 .01472 L
.88362 .01472 L
.88365 .01472 L
.88368 .01472 L
.8837 .01472 L
.88371 .01472 L
.88374 .01472 L
Mistroke
.88377 .01472 L
.8838 .01472 L
.88382 .01472 L
.88385 .01472 L
.88388 .01472 L
.88391 .01472 L
.88392 .01472 L
.88394 .01472 L
.88397 .01472 L
.88399 .01472 L
.88401 .01472 L
.88403 .01472 L
.88407 .01472 L
.8841 .01472 L
.88412 .01472 L
.88415 .01472 L
.88417 .01472 L
.8842 .01472 L
.88422 .01472 L
.88425 .01472 L
.88428 .01472 L
.88431 .01472 L
.88434 .01472 L
.88437 .01472 L
.88439 .01472 L
.88442 .01472 L
.88445 .01472 L
.88448 .01472 L
.88451 .01472 L
.88453 .01472 L
.88456 .01472 L
.88459 .01472 L
.88462 .01472 L
.88464 .01472 L
.88465 .01472 L
.88467 .01472 L
.88469 .01472 L
.88472 .01472 L
.88475 .01472 L
.88478 .01472 L
.88481 .01472 L
.88483 .01472 L
.88486 .01472 L
.88489 .01472 L
.88492 .01472 L
.88494 .01472 L
.88498 .01472 L
.885 .01472 L
.88503 .01472 L
.88506 .01472 L
Mistroke
.88509 .01472 L
.88512 .01472 L
.88515 .01472 L
.88518 .01472 L
.8852 .01472 L
.88521 .01472 L
.88524 .01472 L
.88526 .01472 L
.88528 .01472 L
.88529 .01472 L
.88531 .01472 L
.88534 .01472 L
.88536 .01472 L
.88537 .01472 L
.88539 .01472 L
.88541 .01472 L
.88543 .01472 L
.88544 .01472 L
.88546 .01472 L
.88547 .01472 L
.8855 .01472 L
.88553 .01472 L
.88556 .01472 L
.8856 .01472 L
.88562 .01472 L
.88565 .01472 L
.88568 .01472 L
.8857 .01472 L
.88573 .01472 L
.88576 .01472 L
.88579 .01472 L
.88582 .01472 L
.88585 .01472 L
.88588 .01472 L
.88591 .01472 L
.88593 .01472 L
.88594 .01472 L
.88597 .01472 L
.886 .01472 L
.88603 .01472 L
.88606 .01472 L
.88609 .01472 L
.88611 .01472 L
.88614 .01472 L
.88616 .01472 L
.88619 .01472 L
.88621 .01472 L
.88624 .01472 L
.88627 .01472 L
.8863 .01472 L
Mistroke
.88632 .01472 L
.88635 .01472 L
.88637 .01472 L
.88639 .01472 L
.88641 .01472 L
.88644 .01472 L
.88647 .01472 L
.8865 .01472 L
.88653 .01472 L
.88656 .01472 L
.88659 .01472 L
.88661 .01472 L
.88664 .01472 L
.88667 .01472 L
.8867 .01472 L
.88673 .01472 L
.88676 .01472 L
.88679 .01472 L
.88682 .01472 L
.88684 .01472 L
.88685 .01472 L
.88688 .01472 L
.88691 .01472 L
.88694 .01472 L
.88697 .01472 L
.887 .01472 L
.88702 .01472 L
.88705 .01472 L
.88707 .01472 L
.8871 .01472 L
.88712 .01472 L
.88715 .01472 L
.88718 .01472 L
.88721 .01472 L
.88723 .01472 L
.88726 .01472 L
.88728 .01472 L
.8873 .01472 L
.88732 .01472 L
.88735 .01472 L
.88738 .01472 L
.8874 .01472 L
.88741 .01472 L
.88744 .01472 L
.88747 .01472 L
.8875 .01472 L
.88752 .01472 L
.88755 .01472 L
.88758 .01472 L
.88761 .01472 L
Mistroke
.88763 .01472 L
.88764 .01472 L
.88767 .01472 L
.88769 .01472 L
.88771 .01472 L
.88774 .01472 L
.88777 .01472 L
.8878 .01472 L
.88782 .01472 L
.88785 .01472 L
.88788 .01472 L
.8879 .01472 L
.88793 .01472 L
.88795 .01472 L
.88798 .01472 L
.88801 .01472 L
.88804 .01472 L
.88807 .01472 L
.8881 .01472 L
.88812 .01472 L
.88815 .01472 L
.88818 .01472 L
.88821 .01472 L
.88824 .01472 L
.88827 .01472 L
.8883 .01472 L
.88833 .01472 L
.88834 .01472 L
.88836 .01472 L
.88837 .01472 L
.88839 .01472 L
.88842 .01472 L
.88845 .01472 L
.88848 .01472 L
.88851 .01472 L
.88854 .01472 L
.88857 .01472 L
.88859 .01472 L
.88862 .01472 L
.88865 .01472 L
.88868 .01472 L
.88871 .01472 L
.88873 .01472 L
.88876 .01472 L
.88879 .01472 L
.88882 .01472 L
.88885 .01472 L
.88888 .01472 L
.8889 .01472 L
.88892 .01472 L
Mistroke
.88895 .01472 L
.88896 .01472 L
.88898 .01472 L
.88899 .01472 L
.88901 .01472 L
.88904 .01472 L
.88906 .01472 L
.88908 .01472 L
.88909 .01472 L
.88911 .01472 L
.88913 .01472 L
.88915 .01472 L
.88916 .01472 L
.88918 .01472 L
.88921 .01472 L
.88924 .01472 L
.88927 .01472 L
.8893 .01472 L
.88933 .01472 L
.88935 .01472 L
.88938 .01472 L
.88941 .01472 L
.88944 .01472 L
.88946 .01472 L
.88949 .01472 L
.88952 .01472 L
.88955 .01472 L
.88958 .01472 L
.88961 .60332 L
.88963 .60332 L
.88964 .60332 L
.88971 .60332 L
.89015 .60332 L
.8911 .60332 L
.89202 .60332 L
.893 .60332 L
.89395 .60332 L
.89485 .60332 L
.89582 .60332 L
.89675 .60332 L
.89773 .60332 L
.89869 .60332 L
.8996 .60332 L
.90058 .60332 L
.90151 .60332 L
.90251 .60332 L
.90347 .60332 L
.90439 .60332 L
.90538 .60332 L
.90587 .60332 L
Mistroke
.90632 .60332 L
.90655 .60332 L
.90676 .60332 L
.90682 .60332 L
.90688 .60332 L
.9069 .60332 L
.90691 .60332 L
.90695 .01472 L
.90698 .01472 L
.90699 .01472 L
.90701 .01472 L
.90703 .01472 L
.90706 .01472 L
.90709 .01472 L
.90712 .01472 L
.90715 .01472 L
.90718 .01472 L
.9072 .01472 L
.90723 .01472 L
.90726 .01472 L
.90729 .01472 L
.90732 .01472 L
.90735 .01472 L
.90738 .01472 L
.9074 .01472 L
.90743 .01472 L
.90746 .01472 L
.90748 .01472 L
.90749 .01472 L
.90751 .01472 L
.90753 .01472 L
.90756 .01472 L
.90757 .01472 L
.90759 .01472 L
.90762 .01472 L
.90765 .01472 L
.90768 .01472 L
.90771 .01472 L
.90774 .01472 L
.90775 .01472 L
.90777 .01472 L
.9078 .01472 L
.90782 .01472 L
.90783 .01472 L
.90786 .01472 L
.90789 .01472 L
.90792 .01472 L
.90795 .01472 L
.90797 .01472 L
.90798 .01472 L
Mistroke
.908 .01472 L
.90802 .01472 L
.90805 .01472 L
.90808 .01472 L
.90809 .01472 L
.90811 .01472 L
.90814 .01472 L
.90816 .01472 L
.90818 .01472 L
.9082 .01472 L
.90821 .01472 L
.90823 .01472 L
.90825 .01472 L
.90827 .01472 L
.90831 .01472 L
.90832 .01472 L
.90834 .01472 L
.90837 .01472 L
.9084 .01472 L
.90841 .01472 L
.90843 .01472 L
.90846 .01472 L
.90849 .01472 L
.90852 .01472 L
.90855 .01472 L
.90858 .01472 L
.90861 .01472 L
.90863 .01472 L
.90866 .01472 L
.90869 .01472 L
.90872 .01472 L
.90875 .01472 L
.90876 .01472 L
.90878 .01472 L
.90881 .01472 L
.90884 .01472 L
.90887 .01472 L
.9089 .01472 L
.90893 .01472 L
.90894 .01472 L
.90896 .01472 L
.90899 .01472 L
.90901 .01472 L
.90903 .01472 L
.90904 .01472 L
.90906 .01472 L
.90908 .01472 L
.9091 .01472 L
.90911 .01472 L
.90913 .01472 L
Mistroke
.90916 .01472 L
.90919 .01472 L
.90922 .01472 L
.90924 .01472 L
.90925 .01472 L
.90928 .01472 L
.90931 .01472 L
.90934 .01472 L
.90936 .01472 L
.90939 .01472 L
.90942 .01472 L
.90945 .01472 L
.90947 .01472 L
.90948 .01472 L
.90951 .01472 L
.90953 .01472 L
.90955 .01472 L
.90957 .01472 L
.90961 .01472 L
.90964 .01472 L
.90966 .01472 L
.90969 .01472 L
.90972 .01472 L
.90974 .01472 L
.90976 .01472 L
.90979 .01472 L
.90982 .01472 L
.90985 .01472 L
.90988 .01472 L
.9099 .01472 L
.90993 .01472 L
.90996 .01472 L
.90999 .01472 L
.91002 .01472 L
.91005 .01472 L
.91007 .01472 L
.9101 .01472 L
.91014 .01472 L
.91016 .01472 L
.91018 .01472 L
.9102 .01472 L
.91021 .01472 L
.91023 .01472 L
.91026 .01472 L
.91029 .01472 L
.9103 .01472 L
.91032 .01472 L
.91035 .01472 L
.91038 .01472 L
.91041 .01472 L
Mistroke
.91044 .01472 L
.91047 .01472 L
.91049 .01472 L
.91052 .01472 L
.91055 .01472 L
.91057 .01472 L
.91061 .01472 L
.91063 .01472 L
.91065 .01472 L
.91067 .01472 L
.9107 .01472 L
.91073 .01472 L
.91076 .01472 L
.91078 .01472 L
.91081 .01472 L
.91083 .01472 L
.91085 .01472 L
.91088 .01472 L
.9109 .01472 L
.91091 .01472 L
.91093 .01472 L
.91095 .01472 L
.91097 .01472 L
.91098 .01472 L
.911 .01472 L
.91102 .01472 L
.91105 .01472 L
.91108 .01472 L
.91111 .01472 L
.91114 .01472 L
.91117 .01472 L
.9112 .01472 L
.91122 .01472 L
.91125 .01472 L
.91128 .01472 L
.9113 .01472 L
.91133 .01472 L
.91137 .01472 L
.91139 .01472 L
.91142 .01472 L
.91145 .01472 L
.91147 .01472 L
.91149 .01472 L
.91152 .01472 L
.91155 .01472 L
.91157 .01472 L
.9116 .01472 L
.91163 .01472 L
.91166 .01472 L
.91168 .01472 L
Mistroke
.91171 .01472 L
.91173 .01472 L
.91176 .01472 L
.91179 .01472 L
.91182 .01472 L
.91184 .01472 L
.91187 .01472 L
.9119 .01472 L
.91191 .01472 L
.91193 .01472 L
.91196 .01472 L
.91199 .01472 L
.91202 .01472 L
.91203 .01472 L
.91205 .01472 L
.91208 .01472 L
.91211 .01472 L
.91213 .01472 L
.91216 .01472 L
.91219 .01472 L
.91222 .01472 L
.91225 .01472 L
.91226 .01472 L
.91228 .01472 L
.91231 .01472 L
.91233 .01472 L
.91234 .01472 L
.91237 .01472 L
.9124 .01472 L
.91243 .01472 L
.91246 .01472 L
.91249 .01472 L
.91251 .01472 L
.91254 .01472 L
.91256 .01472 L
.91259 .01472 L
.91262 .01472 L
.91265 .01472 L
.91267 .01472 L
.9127 .01472 L
.91273 .01472 L
.91276 .01472 L
.91278 .01472 L
.91281 .01472 L
.91284 .01472 L
.91287 .01472 L
.9129 .01472 L
.91293 .01472 L
.91296 .01472 L
.91298 .01472 L
Mistroke
.91299 .01472 L
.91301 .01472 L
.91303 .01472 L
.91306 .01472 L
.91308 .01472 L
.91311 .01472 L
.91315 .01472 L
.91317 .01472 L
.9132 .01472 L
.91323 .01472 L
.91325 .01472 L
.91328 .01472 L
.91331 .01472 L
.91334 .01472 L
.91337 .01472 L
.9134 .01472 L
.91343 .01472 L
.91346 .01472 L
.91349 .01472 L
.91352 .01472 L
.91354 .01472 L
.91355 .01472 L
.91358 .01472 L
.9136 .01472 L
.91361 .01472 L
.91363 .01472 L
.91365 .01472 L
.91368 .01472 L
.9137 .01472 L
.91371 .01472 L
.91373 .01472 L
.91375 .01472 L
.91376 .01472 L
.91378 .01472 L
.9138 .01472 L
.91381 .01472 L
.91384 .01472 L
.91387 .01472 L
.9139 .01472 L
.91393 .01472 L
.91396 .01472 L
.91399 .01472 L
.91402 .01472 L
.91404 .01472 L
.91407 .01472 L
.9141 .01472 L
.91413 .01472 L
.91416 .01472 L
.91419 .01472 L
.91422 .01472 L
Mistroke
.91425 .01472 L
.91426 .01472 L
.91428 .01472 L
.91431 .01472 L
.91434 .01472 L
.91437 .01472 L
.9144 .01472 L
.91442 .01472 L
.91445 .01472 L
.91448 .01472 L
.9145 .01472 L
.91453 .01472 L
.91455 .01472 L
.91458 .01472 L
.91461 .01472 L
.91464 .01472 L
.91466 .01472 L
.91469 .01472 L
.91471 .01472 L
.91472 .01472 L
.91475 .01472 L
.91478 .01472 L
.91481 .01472 L
.91484 .01472 L
.91487 .01472 L
.9149 .01472 L
.91493 .01472 L
.91495 .01472 L
.91498 .01472 L
.91501 .01472 L
.91504 .01472 L
.91507 .01472 L
.9151 .01472 L
.91513 .01472 L
.91516 .01472 L
.91518 .01472 L
.91519 .01472 L
.91522 .01472 L
.91525 .01472 L
.91528 .01472 L
.91531 .01472 L
.91533 .01472 L
.91536 .01472 L
.91539 .01472 L
.91541 .01472 L
.91544 .01472 L
.91546 .01472 L
.91549 .01472 L
.91552 .01472 L
.91555 .01472 L
Mistroke
.91557 .01472 L
.9156 .01472 L
.91562 .01472 L
.91563 .01472 L
.91566 .01472 L
.91569 .01472 L
.91572 .01472 L
.91574 .01472 L
.91575 .01472 L
.91578 .01472 L
.91581 .01472 L
.91584 .01472 L
.91586 .01472 L
.91589 .01472 L
.91592 .01472 L
.91595 .01472 L
.91597 .01472 L
.91598 .01472 L
.91601 .01472 L
.91603 .01472 L
.91605 .01472 L
.91608 .01472 L
.91611 .01472 L
.91614 .01472 L
.91616 .01472 L
.91619 .01472 L
.91622 .01472 L
.91624 .01472 L
.91627 .01472 L
.91629 .01472 L
.91632 .01472 L
.91635 .01472 L
.91638 .01472 L
.91641 .01472 L
.91644 .01472 L
.91646 .01472 L
.91649 .01472 L
.91652 .01472 L
.91655 .01472 L
.91657 .01472 L
.9166 .01472 L
.91664 .01472 L
.91666 .01472 L
.91668 .01472 L
.9167 .01472 L
.91671 .01472 L
.91673 .01472 L
.91676 .01472 L
.91679 .01472 L
.91682 .01472 L
Mistroke
.91685 .01472 L
.91688 .01472 L
.91691 .01472 L
.91693 .01472 L
.91696 .01472 L
.91699 .01472 L
.91702 .01472 L
.91705 .01472 L
.91707 .01472 L
.9171 .01472 L
.91713 .01472 L
.91716 .01472 L
.91719 .01472 L
.91722 .01472 L
.91724 .01472 L
.91726 .01472 L
.91729 .01472 L
.9173 .01472 L
.91732 .01472 L
.91733 .01472 L
.91735 .01472 L
.91738 .01472 L
.9174 .01472 L
.91741 .01472 L
.91743 .01472 L
.91745 .01472 L
.91747 .01472 L
.91748 .01472 L
.9175 .01472 L
.91752 .01472 L
.91755 .01472 L
.91758 .01472 L
.91761 .01472 L
.91764 .01472 L
.91767 .01472 L
.91769 .01472 L
.91772 .01472 L
.91775 .01472 L
.91778 .01472 L
.9178 .01472 L
.91783 .01472 L
.91786 .01472 L
.91789 .01472 L
.91792 .01472 L
.91795 .01472 L
.91797 .01472 L
.91798 .01472 L
.91802 .01472 L
.91805 .01472 L
.91807 .01472 L
Mistroke
.9181 .01472 L
.91813 .01472 L
.91815 .01472 L
.91818 .01472 L
.9182 .01472 L
.91823 .01472 L
.91826 .01472 L
.91828 .01472 L
.91831 .01472 L
.91834 .01472 L
.91837 .01472 L
.9184 .01472 L
.91841 .01472 L
.91843 .01472 L
.91846 .01472 L
.91849 .01472 L
.91851 .01472 L
.91855 .01472 L
.91858 .01472 L
.9186 .01472 L
.91863 .01472 L
.91866 .01472 L
.91868 .01472 L
.91871 .01472 L
.91874 .01472 L
.91877 .01472 L
.9188 .01472 L
.91883 .01472 L
.91886 .01472 L
.91888 .01472 L
.91889 .01472 L
.91893 .01472 L
.91896 .01472 L
.91898 .01472 L
.91901 .01472 L
.91904 .01472 L
.91907 .01472 L
.91909 .01472 L
.91911 .01472 L
.91914 .01472 L
.91917 .01472 L
.91919 .01472 L
.91922 .01472 L
.91925 .01472 L
.91928 .01472 L
.91931 .01472 L
.91932 .01472 L
.91934 .01472 L
.91937 .01472 L
.9194 .01472 L
Mistroke
.91942 .01472 L
.91944 .01472 L
.91946 .01472 L
.91948 .01472 L
.91951 .01472 L
.91954 .01472 L
.91957 .01472 L
.91959 .01472 L
.91962 .01472 L
.91965 .01472 L
.91967 .01472 L
.91968 .01472 L
.91972 .01472 L
.91973 .01472 L
.91975 .01472 L
.91978 .01472 L
.91981 .01472 L
.91984 .01472 L
.91987 .01472 L
.91989 .01472 L
.91992 .01472 L
.91994 .01472 L
.91997 .01472 L
.92 .01472 L
.92003 .01472 L
.92005 .01472 L
.92008 .01472 L
.92011 .01472 L
.92014 .01472 L
.92016 .01472 L
.92019 .01472 L
.92022 .01472 L
.92025 .01472 L
.92028 .01472 L
.92031 .01472 L
.92034 .01472 L
.92037 .01472 L
.92038 .01472 L
.9204 .01472 L
.92042 .01472 L
.92043 .01472 L
.92046 .01472 L
.92049 .01472 L
.92052 .01472 L
.92055 .01472 L
.92058 .01472 L
.92061 .01472 L
.92063 .01472 L
.92066 .01472 L
.92069 .01472 L
Mistroke
.92072 .01472 L
.92075 .01472 L
.92078 .01472 L
.92081 .01472 L
.92084 .01472 L
.92087 .01472 L
.92089 .01472 L
.92092 .01472 L
.92094 .01472 L
.92096 .01472 L
.92099 .01472 L
.921 .01472 L
.92102 .01472 L
.92104 .01472 L
.92105 .01472 L
.92108 .01472 L
.9211 .01472 L
.92112 .01472 L
.92113 .01472 L
.92115 .01472 L
.92117 .01472 L
.92119 .01472 L
.9212 .01472 L
.92122 .01472 L
.92125 .01472 L
.92128 .01472 L
.92131 .01472 L
.92134 .01472 L
.92137 .01472 L
.9214 .01472 L
.92142 .01472 L
.92145 .01472 L
.92148 .01472 L
.9215 .01472 L
.92153 .01472 L
.92157 .01472 L
.92159 .01472 L
.92162 .01472 L
.92165 .01472 L
.92167 .01472 L
.92169 .01472 L
.92172 .01472 L
.92175 .01472 L
.92177 .01472 L
.9218 .01472 L
.92183 .01472 L
.92186 .01472 L
.92188 .01472 L
.92191 .01472 L
.92193 .01472 L
Mistroke
.92196 .01472 L
.92199 .01472 L
.92201 .01472 L
.92204 .01472 L
.92207 .01472 L
.9221 .01472 L
.92211 .01472 L
.92213 .01472 L
.92216 .01472 L
.92219 .01472 L
.92222 .01472 L
.92225 .01472 L
.92228 .01472 L
.92231 .01472 L
.92233 .01472 L
.92236 .01472 L
.92239 .01472 L
.92241 .01472 L
.92244 .01472 L
.92247 .01472 L
.9225 .01472 L
.92253 .01472 L
.92256 .01472 L
.92258 .01472 L
.9226 .01472 L
.92263 .01472 L
.92266 .01472 L
.92268 .01472 L
.92271 .01472 L
.92274 .01472 L
.92277 .01472 L
.92279 .01472 L
.92282 .01472 L
.92284 .01472 L
.92287 .01472 L
.9229 .01472 L
.92292 .01472 L
.92295 .01472 L
.92298 .01472 L
.92301 .01472 L
.92302 .01472 L
.92304 .01472 L
.92307 .01472 L
.9231 .01472 L
.92313 .01472 L
.92314 .01472 L
.92316 .01472 L
.92319 .01472 L
.92322 .01472 L
.92324 .01472 L
Mistroke
.92327 .01472 L
.92329 .01472 L
.92332 .01472 L
.92335 .01472 L
.92337 .01472 L
.92339 .01472 L
.92342 .01472 L
.92344 .01472 L
.92345 .01472 L
.92348 .01472 L
.92351 .01472 L
.92354 .01472 L
.92357 .01472 L
.92359 .01472 L
.92362 .01472 L
.92365 .01472 L
.92367 .01472 L
.9237 .01472 L
.92373 .01472 L
.92376 .01472 L
.92378 .01472 L
.92381 .01472 L
.92384 .01472 L
.92386 .01472 L
.92389 .01472 L
.92392 .01472 L
.92395 .01472 L
.92398 .01472 L
.92401 .01472 L
.92404 .01472 L
.92407 .01472 L
.92408 .01472 L
.9241 .01472 L
.92412 .01472 L
.92413 .01472 L
.92416 .01472 L
.92419 .01472 L
.92422 .01472 L
.92425 .01472 L
.92428 .01472 L
.92431 .01472 L
.92434 .01472 L
.92436 .01472 L
.92439 .01472 L
.92442 .01472 L
.92445 .01472 L
.92448 .01472 L
.92451 .01472 L
.92454 .01472 L
.92457 .01472 L
Mistroke
.92459 .01472 L
.92462 .01472 L
.92464 .01472 L
.92466 .01472 L
.92469 .01472 L
.92471 .01472 L
.92472 .01472 L
.92474 .01472 L
.92475 .01472 L
.92479 .01472 L
.9248 .01472 L
.92482 .01472 L
.92484 .01472 L
.92485 .01472 L
.92487 .01472 L
.92489 .01472 L
.9249 .01472 L
.92492 .01472 L
.92495 .01472 L
.92498 .01472 L
.92501 .01472 L
.92504 .01472 L
.92507 .01472 L
.9251 .01472 L
.92513 .01472 L
.92515 .01472 L
.92518 .01472 L
.92521 .01472 L
.92524 .01472 L
.92527 .01472 L
.92529 .01472 L
.92532 .01472 L
.92535 .01472 L
.92537 .01472 L
.92539 .01472 L
.92542 .01472 L
.92545 .01472 L
.92547 .01472 L
.9255 .01472 L
.92553 .01472 L
.92556 .01472 L
.92558 .01472 L
.92561 .01472 L
.92563 .01472 L
.92566 .01472 L
.92569 .01472 L
.92572 .01472 L
.92574 .01472 L
.92577 .01472 L
.9258 .01472 L
Mistroke
.92581 .01472 L
.92583 .01472 L
.92586 .01472 L
.92589 .01472 L
.92592 .01472 L
.92595 .01472 L
.92598 .01472 L
.92601 .01472 L
.92603 .01472 L
.92606 .01472 L
.92609 .01472 L
.92611 .01472 L
.92614 .01472 L
.92618 .01472 L
.9262 .01472 L
.92623 .01472 L
.92626 .01472 L
.92628 .01472 L
.9263 .01472 L
.92633 .01472 L
.92636 .01472 L
.92638 .01472 L
.92641 .01472 L
.92644 .01472 L
.92647 .01472 L
.92649 .01472 L
.92652 .01472 L
.92654 .01472 L
.92657 .01472 L
.9266 .01472 L
.92663 .01472 L
.92665 .01472 L
.92668 .01472 L
.92671 .01472 L
.92672 .01472 L
.92674 .01472 L
.92677 .01472 L
.9268 .01472 L
.92683 .01472 L
.92686 .01472 L
.92689 .01472 L
.92692 .01472 L
.92694 .01472 L
.92697 .01472 L
.927 .01472 L
.92702 .01472 L
.92705 .01472 L
.92709 .01472 L
.92711 .01472 L
.92714 .01472 L
Mistroke
.92717 .01472 L
.92719 .01472 L
.92721 .01472 L
.92724 .01472 L
.92727 .01472 L
.92729 .01472 L
.92732 .01472 L
.92735 .01472 L
.92738 .01472 L
.9274 .01472 L
.92743 .01472 L
.92745 .01472 L
.92748 .01472 L
.92751 .01472 L
.92754 .01472 L
.92756 .01472 L
.92759 .01472 L
.92762 .01472 L
.92764 .01472 L
.92765 .01472 L
.92768 .01472 L
.92771 .01472 L
.92774 .01472 L
.92775 .01472 L
.92777 .01472 L
.9278 .01472 L
.92783 .01472 L
.92785 .01472 L
.92788 .01472 L
.92791 .01472 L
.92794 .01472 L
.92797 .01472 L
.92798 .01472 L
.928 .01472 L
.92803 .01472 L
.92805 .01472 L
.92806 .01472 L
.92809 .01472 L
.92812 .01472 L
.92815 .01472 L
.92818 .01472 L
.92821 .01472 L
.92823 .01472 L
.92826 .01472 L
.92828 .01472 L
.92831 .01472 L
.92834 .01472 L
.92837 .01472 L
.92839 .01472 L
.92842 .01472 L
Mistroke
.92845 .01472 L
.92848 .01472 L
.9285 .01472 L
.92853 .01472 L
.92857 .01472 L
.92859 .01472 L
.92862 .01472 L
.92865 .01472 L
.92868 .01472 L
.9287 .01472 L
.92871 .01472 L
.92873 .01472 L
.92875 .01472 L
.92878 .01472 L
.9288 .01472 L
.92884 .01472 L
.92887 .01472 L
.92889 .01472 L
.92892 .01472 L
.92895 .01472 L
.92897 .01472 L
.929 .01472 L
.92903 .01472 L
.92906 .01472 L
.92909 .01472 L
.92912 .01472 L
.92915 .01472 L
.92918 .01472 L
.92921 .01472 L
.92924 .01472 L
.92926 .01472 L
.92927 .01472 L
.9293 .01472 L
.92932 .01472 L
.92933 .01472 L
.92935 .01472 L
.92937 .01472 L
.9294 .01472 L
.92942 .01472 L
.92943 .01472 L
.92945 .01472 L
.92947 .01472 L
.92948 .01472 L
.9295 .01472 L
.92952 .01472 L
.92953 .01472 L
.92956 .01472 L
.92959 .01472 L
.92962 .01472 L
.92965 .01472 L
Mistroke
.92968 .01472 L
.92971 .01472 L
.92974 .01472 L
.92976 .01472 L
.92979 .01472 L
.92982 .01472 L
.92985 .01472 L
.92988 .01472 L
.92991 .01472 L
.92994 .01472 L
.92997 .01472 L
.92999 .01472 L
.93 .01472 L
.93003 .01472 L
.93006 .01472 L
.93009 .01472 L
.93012 .01472 L
.93015 .01472 L
.93017 .01472 L
.9302 .01472 L
.93022 .01472 L
.93025 .01472 L
.93027 .01472 L
.9303 .01472 L
.93033 .01472 L
.93036 .01472 L
.93038 .01472 L
.93041 .01472 L
.93043 .01472 L
.93044 .01472 L
.93047 .01472 L
.9305 .01472 L
.93053 .01472 L
.93056 .01472 L
.93059 .01472 L
.93062 .01472 L
.93065 .01472 L
.93067 .01472 L
.9307 .01472 L
.93073 .01472 L
.93076 .01472 L
.93079 .01472 L
.93082 .01472 L
.93085 .01472 L
.93088 .01472 L
.9309 .01472 L
.93091 .01472 L
.93094 .01472 L
.93097 .01472 L
.931 .01472 L
Mistroke
.93103 .01472 L
.93106 .01472 L
.93108 .01472 L
.93111 .01472 L
.93113 .01472 L
.93116 .01472 L
.93118 .01472 L
.93121 .01472 L
.93124 .01472 L
.93127 .01472 L
.93129 .01472 L
.93132 .01472 L
.93134 .01472 L
.93136 .01472 L
.93138 .01472 L
.93141 .01472 L
.93144 .01472 L
.93146 .01472 L
.93147 .01472 L
.9315 .01472 L
.93153 .01472 L
.93156 .01472 L
.93158 .01472 L
.93161 .01472 L
.93164 .01472 L
.93167 .01472 L
.93169 .01472 L
.9317 .01472 L
.93173 .01472 L
.93175 .01472 L
.93177 .01472 L
.9318 .01472 L
.93183 .01472 L
.93186 .01472 L
.93188 .01472 L
.93191 .01472 L
.93194 .01472 L
.93196 .01472 L
.93199 .01472 L
.93201 .01472 L
.93204 .01472 L
.93207 .01472 L
.9321 .01472 L
.93213 .01472 L
.93216 .01472 L
.93218 .01472 L
.93221 .01472 L
.93224 .01472 L
.93227 .01472 L
.9323 .01472 L
Mistroke
.93233 .01472 L
.93236 .01472 L
.93239 .01472 L
.9324 .01472 L
.93242 .01472 L
.93243 .01472 L
.93245 .01472 L
.93248 .01472 L
.93251 .01472 L
.93254 .01472 L
.93257 .01472 L
.9326 .01472 L
.93263 .01472 L
.93265 .01472 L
.93268 .01472 L
.93271 .01472 L
.93274 .01472 L
.93277 .01472 L
.93279 .01472 L
.93282 .01472 L
.93285 .01472 L
.93288 .01472 L
.93291 .01472 L
.93294 .01472 L
.93296 .01472 L
.93298 .01472 L
.93301 .01472 L
.93302 .01472 L
.93304 .01472 L
.93306 .01472 L
.93307 .01472 L
.9331 .01472 L
.93312 .01472 L
.93314 .01472 L
.93315 .01472 L
.93317 .01472 L
.93319 .01472 L
.93321 .01472 L
.93322 .01472 L
.93324 .01472 L
.93327 .01472 L
.9333 .01472 L
.93333 .01472 L
.93336 .01472 L
.93339 .01472 L
.93342 .01472 L
.93344 .01472 L
.93347 .01472 L
.9335 .01472 L
.93352 .01472 L
Mistroke
.93355 .01472 L
.93358 .01472 L
.93361 .01472 L
.93364 .01472 L
.93367 .01472 L
.93369 .01472 L
.93371 .01472 L
.93374 .01472 L
.93377 .01472 L
.93379 .01472 L
.93382 .01472 L
.93385 .01472 L
.93388 .01472 L
.9339 .01472 L
.93392 .01472 L
.93395 .01472 L
.93398 .01472 L
.934 .01472 L
.93403 .01472 L
.93406 .01472 L
.93409 .01472 L
.93412 .01472 L
.93413 .01472 L
.93415 .01472 L
.93418 .01472 L
.93421 .01472 L
.93424 .01472 L
.93427 .01472 L
.9343 .01472 L
.93432 .01472 L
.93435 .01472 L
.93438 .01472 L
.93441 .01472 L
.93443 .01472 L
.93446 .01472 L
.93449 .01472 L
.93452 .01472 L
.93455 .01472 L
.93458 .01472 L
.9346 .01472 L
.93462 .01472 L
.93465 .01472 L
.93468 .01472 L
.9347 .01472 L
.93473 .01472 L
.93476 .01472 L
.93479 .01472 L
.93481 .01472 L
.93484 .01472 L
.93486 .01472 L
Mistroke
.93489 .01472 L
.93491 .01472 L
.93494 .01472 L
.93497 .01472 L
.935 .01472 L
.93503 .01472 L
.93504 .01472 L
.93506 .01472 L
.93509 .01472 L
.93512 .01472 L
.93515 .01472 L
.93516 .01472 L
.93518 .01472 L
.93521 .01472 L
.93524 .01472 L
.93526 .01472 L
.93529 .01472 L
.93531 .01472 L
.93534 .01472 L
.93537 .01472 L
.93539 .01472 L
.93541 .01472 L
.93544 .01472 L
.93546 .01472 L
.93547 .01472 L
.9355 .01472 L
.93553 .01472 L
.93556 .01472 L
.93559 .01472 L
.93561 .01472 L
.93564 .01472 L
.93567 .01472 L
.93569 .01472 L
.93572 .01472 L
.93575 .01472 L
.93578 .01472 L
.9358 .01472 L
.93583 .01472 L
.93586 .01472 L
.93588 .01472 L
.93591 .01472 L
.93594 .01472 L
.93597 .01472 L
.936 .01472 L
.93603 .01472 L
.93606 .01472 L
.93609 .01472 L
.9361 .01472 L
.93612 .01472 L
.93614 .01472 L
Mistroke
.93615 .01472 L
.93618 .01472 L
.93621 .01472 L
.93624 .01472 L
.93627 .01472 L
.9363 .01472 L
.93633 .01472 L
.93636 .01472 L
.93638 .01472 L
.93641 .01472 L
.93644 .01472 L
.93647 .01472 L
.9365 .01472 L
.93653 .01472 L
.93656 .01472 L
.93659 .01472 L
.93661 .01472 L
.93665 .01472 L
.93666 .01472 L
.93668 .01472 L
.93671 .01472 L
.93673 .01472 L
.93674 .01472 L
.93676 .01472 L
.93677 .01472 L
.93681 .01472 L
.93682 .01472 L
.93684 .01472 L
.93686 .01472 L
.93687 .01472 L
.93689 .01472 L
.93691 .01472 L
.93692 .01472 L
.93694 .01472 L
.93697 .01472 L
.937 .01472 L
.93703 .01472 L
.93706 .01472 L
.93709 .01472 L
.93712 .01472 L
.93715 .01472 L
.93717 .01472 L
.9372 .01472 L
.93723 .01472 L
.93726 .01472 L
.93729 .01472 L
.93731 .01472 L
.93734 .01472 L
.93737 .01472 L
.93739 .01472 L
Mistroke
.93741 .01472 L
.93744 .01472 L
.93747 .01472 L
.93749 .01472 L
.93752 .01472 L
.93755 .01472 L
.93758 .01472 L
.9376 .01472 L
.93763 .01472 L
.93765 .01472 L
.93768 .01472 L
.93771 .01472 L
.93774 .01472 L
.93776 .01472 L
.93779 .01472 L
.93782 .01472 L
.93784 .01472 L
.93785 .01472 L
.93788 .01472 L
.93791 .01472 L
.93794 .01472 L
.93797 .01472 L
.938 .01472 L
.93803 .01472 L
.93805 .01472 L
.93808 .01472 L
.93811 .01472 L
.93814 .01472 L
.93816 .01472 L
.9382 .01472 L
.93822 .01472 L
.93825 .01472 L
.93828 .01472 L
.9383 .01472 L
.93832 .01472 L
.93835 .01472 L
.93838 .01472 L
.9384 .01472 L
.93843 .01472 L
.93846 .01472 L
.93849 .01472 L
.93851 .01472 L
.93854 .01472 L
.93856 .01472 L
.93859 .01472 L
.93862 .01472 L
.93865 .01472 L
.93867 .01472 L
.9387 .01472 L
.93873 .01472 L
Mistroke
.93875 .01472 L
.93876 .01472 L
.93879 .01472 L
.93882 .01472 L
.93885 .01472 L
.93886 .01472 L
.93888 .01472 L
.93891 .01472 L
.93894 .01472 L
.93896 .01472 L
.93899 .01472 L
.93902 .01472 L
.93905 .01472 L
.93908 .01472 L
.93909 .01472 L
.93911 .01472 L
.93914 .01472 L
.93916 .01472 L
.93917 .01472 L
.9392 .01472 L
.93923 .01472 L
.93926 .01472 L
.93929 .01472 L
.93932 .01472 L
.93934 .01472 L
.93937 .01472 L
.93939 .01472 L
.93942 .01472 L
.93945 .01472 L
.93948 .01472 L
.9395 .01472 L
.93953 .01472 L
.93956 .01472 L
.93959 .01472 L
.93961 .01472 L
.93964 .01472 L
.93967 .01472 L
.9397 .01472 L
.93973 .01472 L
.93976 .01472 L
.93979 .01472 L
.93981 .01472 L
.93982 .01472 L
.93984 .01472 L
.93986 .01472 L
.93989 .01472 L
.93991 .01472 L
.93994 .01472 L
.93998 .01472 L
.94 .01472 L
Mistroke
.94003 .01472 L
.94006 .01472 L
.94008 .01472 L
.94011 .01472 L
.94014 .01472 L
.94017 .01472 L
.9402 .01472 L
.94023 .01472 L
.94026 .01472 L
.94029 .01472 L
.94032 .01472 L
.94035 .01472 L
.94036 .01472 L
.94038 .01472 L
.94041 .01472 L
.94043 .01472 L
.94044 .01472 L
.94046 .01472 L
.94048 .01472 L
.94051 .01472 L
.94052 .01472 L
.94054 .01472 L
.94056 .01472 L
.94058 .01472 L
.94059 .01472 L
.94061 .01472 L
.94063 .01472 L
.94064 .01472 L
.94067 .01472 L
.9407 .01472 L
.94073 .01472 L
.94076 .01472 L
.94079 .01472 L
.94082 .01472 L
.94085 .01472 L
.94087 .01472 L
.9409 .01472 L
.94093 .01472 L
.94096 .01472 L
.94099 .01472 L
.94101 .01472 L
.94104 .01472 L
.94108 .01472 L
.94109 .01472 L
.94111 .01472 L
.94114 .01472 L
.94117 .01472 L
.9412 .01472 L
.94122 .01472 L
.94125 .01472 L
Mistroke
.94128 .01472 L
.94131 .01472 L
.94133 .01472 L
.94135 .01472 L
.94138 .01472 L
.94141 .01472 L
.94144 .01472 L
.94147 .01472 L
.94149 .01472 L
.94152 .01472 L
.94154 .01472 L
.94155 .01472 L
.94158 .01472 L
.94161 .01472 L
.94164 .01472 L
.94167 .01472 L
.9417 .01472 L
.94173 .01472 L
.94176 .01472 L
.94178 .01472 L
.94181 .01472 L
.94184 .01472 L
.94187 .01472 L
.9419 .01472 L
.94192 .01472 L
.94195 .01472 L
.94198 .01472 L
.942 .01472 L
.94202 .01472 L
.94205 .01472 L
.94208 .01472 L
.94211 .01472 L
.94213 .01472 L
.94216 .01472 L
.94219 .01472 L
.94221 .01472 L
.94224 .01472 L
.94226 .01472 L
.94229 .01472 L
.94232 .01472 L
.94235 .01472 L
.94237 .01472 L
.9424 .01472 L
.94243 .01472 L
.94245 .01472 L
.94246 .01472 L
.94249 .01472 L
.94252 .01472 L
.94255 .01472 L
.94258 .01472 L
Mistroke
.94261 .01472 L
.94264 .01472 L
.94266 .01472 L
.94269 .01472 L
.94272 .01472 L
.94275 .01472 L
.94278 .01472 L
.94281 .01472 L
.94283 .01472 L
.94286 .01472 L
.9429 .01472 L
.94291 .01472 L
.94293 .01472 L
.94296 .01472 L
.94299 .01472 L
.94302 .01472 L
.94304 .01472 L
.94307 .01472 L
.9431 .01472 L
.94313 .01472 L
.94315 .01472 L
.94318 .01472 L
.9432 .01472 L
.94323 .01472 L
.94326 .01472 L
.94329 .01472 L
.94331 .01472 L
.94334 .01472 L
.94336 .01472 L
.94337 .01472 L
.9434 .01472 L
.94343 .01472 L
.94346 .01472 L
.94348 .01472 L
.94349 .01472 L
.94352 .01472 L
.94355 .01472 L
.94358 .01472 L
.9436 .01472 L
.94363 .01472 L
.94366 .01472 L
.94369 .01472 L
.9437 .01472 L
.94372 .01472 L
.94375 .01472 L
.94377 .01472 L
.94379 .01472 L
.94381 .01472 L
.94385 .01472 L
.94388 .01472 L
Mistroke
.9439 .01472 L
.94393 .01472 L
.94396 .01472 L
.94398 .01472 L
.944 .01472 L
.94403 .01472 L
.94406 .01472 L
.94409 .01472 L
.94412 .01472 L
.94415 .01472 L
.94417 .01472 L
.9442 .01472 L
.94423 .01472 L
.94426 .01472 L
.94429 .01472 L
.94431 .01472 L
.94434 .01472 L
.94437 .01472 L
.9444 .01472 L
.94442 .01472 L
.94444 .01472 L
.94445 .01472 L
.94447 .01472 L
.9445 .01472 L
.94453 .01472 L
.94456 .01472 L
.94459 .01472 L
.94462 .01472 L
.94464 .01472 L
.94467 .01472 L
.9447 .01472 L
.94472 .01472 L
.94476 .01472 L
.94479 .01472 L
.94481 .01472 L
.94484 .01472 L
.94487 .01472 L
.9449 .01472 L
.94493 .01472 L
.94496 .01472 L
.94498 .01472 L
.94499 .01472 L
.94502 .01472 L
.94504 .01472 L
.94506 .01472 L
.94507 .01472 L
.94509 .01472 L
.94512 .01472 L
.94514 .01472 L
.94515 .01472 L
Mistroke
.94517 .01472 L
.94519 .01472 L
.94521 .01472 L
.94522 .01472 L
.94524 .01472 L
.94526 .01472 L
.94528 .01472 L
.94532 .01472 L
.94534 .01472 L
.94538 .01472 L
.94541 .01472 L
.94543 .01472 L
.94546 .01472 L
.94549 .01472 L
.94551 .01472 L
.94554 .01472 L
.94557 .01472 L
.9456 .01472 L
.94563 .01472 L
.94566 .01472 L
.94569 .01472 L
.94571 .01472 L
.94572 .01472 L
.94576 .01472 L
.94578 .01472 L
.94581 .01472 L
.94584 .01472 L
.94587 .01472 L
.94589 .01472 L
.94592 .01472 L
.94594 .01472 L
.94597 .01472 L
.946 .01472 L
.94602 .01472 L
.94605 .01472 L
.94608 .01472 L
.94611 .01472 L
.94613 .01472 L
.94615 .01472 L
.94617 .01472 L
.94619 .01472 L
.94622 .01472 L
.94625 .01472 L
.94629 .01472 L
.94632 .01472 L
.94634 .01472 L
.94637 .01472 L
.9464 .01472 L
.94642 .01472 L
.94645 .01472 L
Mistroke
.94648 .01472 L
.94651 .01472 L
.94654 .01472 L
.94657 .01472 L
.9466 .01472 L
.94662 .01472 L
.94663 .01472 L
.94667 .01472 L
.9467 .01472 L
.94672 .01472 L
.94675 .01472 L
.94678 .01472 L
.94681 .01472 L
.94683 .01472 L
.94685 .01472 L
.94688 .01472 L
.94691 .01472 L
.94693 .01472 L
.94696 .01472 L
.94699 .01472 L
.94702 .01472 L
.94705 .01472 L
.94706 .01472 L
.94708 .01472 L
.94711 .01472 L
.94714 .01472 L
.94716 .01472 L
.94718 .01472 L
.9472 .01472 L
.94722 .01472 L
.94725 .01472 L
.94728 .01472 L
.94731 .01472 L
.94733 .01472 L
.94736 .01472 L
.94739 .01472 L
.94741 .01472 L
.94742 .01472 L
.94746 .01472 L
.94747 .01472 L
.94749 .01472 L
.94752 .01472 L
.94755 .01472 L
.94758 .01472 L
.94761 .01472 L
.94763 .01472 L
.94766 .01472 L
.94769 .01472 L
.94771 .01472 L
.94774 .01472 L
Mistroke
.94777 .01472 L
.94779 .01472 L
.94782 .01472 L
.94785 .01472 L
.94788 .01472 L
.9479 .01472 L
.94793 .01472 L
.94796 .01472 L
.94799 .01472 L
.94802 .01472 L
.94805 .01472 L
.94808 .01472 L
.94811 .01472 L
.94812 .01472 L
.94814 .01472 L
.94816 .01472 L
.94817 .01472 L
.9482 .01472 L
.94823 .01472 L
.94826 .01472 L
.94829 .01472 L
.94832 .01472 L
.94835 .01472 L
.94838 .01472 L
.9484 .01472 L
.94843 .01472 L
.94846 .01472 L
.94849 .01472 L
.94852 .01472 L
.94855 .01472 L
.94858 .01472 L
.94861 .01472 L
.94863 .01472 L
.94866 .01472 L
.94868 .01472 L
.9487 .01472 L
.94873 .01472 L
.94874 .01472 L
.94876 .01472 L
.94878 .01472 L
.94879 .01472 L
.94883 .01472 L
.94884 .01472 L
.94886 .01472 L
.94888 .01472 L
.94889 .01472 L
.94891 .01472 L
.94893 .01472 L
.94894 .01472 L
.94896 .01472 L
Mistroke
.94899 .01472 L
.94902 .01472 L
.94905 .01472 L
.94908 .01472 L
.94911 .01472 L
.94914 .01472 L
.94917 .01472 L
.94919 .01472 L
.94922 .01472 L
.94925 .01472 L
.94928 .01472 L
.94931 .01472 L
.94933 .01472 L
.94936 .01472 L
.94939 .01472 L
.94941 .01472 L
.94943 .01472 L
.94946 .01472 L
.94949 .01472 L
.94951 .01472 L
.94954 .01472 L
.94957 .01472 L
.9496 .01472 L
.94962 .01472 L
.94965 .01472 L
.94967 .01472 L
.9497 .01472 L
.94973 .01472 L
.94976 .01472 L
.94978 .01472 L
.94981 .01472 L
.94984 .01472 L
.94986 .01472 L
.94987 .01472 L
.9499 .01472 L
.94993 .01472 L
.94996 .01472 L
.94999 .01472 L
.95002 .01472 L
.95005 .01472 L
.95007 .01472 L
.9501 .01472 L
.95013 .01472 L
.95016 .01472 L
.95019 .01472 L
.95022 .01472 L
.95024 .01472 L
.95027 .01472 L
.9503 .01472 L
.95032 .01472 L
Mistroke
.95034 .01472 L
.95037 .01472 L
.9504 .01472 L
.95042 .01472 L
.95045 .01472 L
.95048 .01472 L
.95051 .01472 L
.95053 .01472 L
.95056 .01472 L
.95058 .01472 L
.95061 .01472 L
.95064 .01472 L
.95067 .01472 L
.95069 .01472 L
.95072 .01472 L
.95075 .01472 L
.95077 .01472 L
.95078 .01472 L
.95081 .01472 L
.95084 .01472 L
.95087 .01472 L
.95088 .01472 L
.9509 .01472 L
.95093 .01472 L
.95096 .01472 L
.95098 .01472 L
.95101 .01472 L
.95104 .01472 L
.95107 .01472 L
.9511 .01472 L
.95111 .01472 L
.95113 .01472 L
.95116 .01472 L
.95118 .01472 L
.95119 .01472 L
.95122 .01472 L
.95125 .01472 L
.95128 .01472 L
.95131 .01472 L
.95134 .01472 L
.95136 .01472 L
.95139 .01472 L
.95141 .01472 L
.95144 .01472 L
.95147 .01472 L
.9515 .01472 L
.95152 .01472 L
.95155 .01472 L
.95158 .01472 L
.95161 .01472 L
Mistroke
.95163 .01472 L
.95166 .01472 L
.95169 .01472 L
.95172 .01472 L
.95175 .01472 L
.95178 .01472 L
.95181 .01472 L
.95183 .01472 L
.95184 .01472 L
.95186 .01472 L
.95188 .01472 L
.95191 .01472 L
.95193 .01472 L
.95196 .01472 L
.952 .01472 L
.95202 .01472 L
.95205 .01472 L
.95208 .01472 L
.9521 .01472 L
.95213 .01472 L
.95216 .01472 L
.95219 .01472 L
.95222 .01472 L
.95225 .01472 L
.95228 .01472 L
.95231 .01472 L
.95234 .01472 L
.95237 .01472 L
.95239 .01472 L
.9524 .01472 L
.95243 .01472 L
.95245 .01472 L
.95246 .01472 L
.95248 .01472 L
.9525 .01472 L
.95253 .01472 L
.95255 .01472 L
.95256 .01472 L
.95258 .01472 L
.9526 .01472 L
.95261 .01472 L
.95263 .01472 L
.95265 .01472 L
.95266 .01472 L
.95269 .01472 L
.95272 .01472 L
.95275 .01472 L
.95278 .01472 L
.95281 .01472 L
.95284 .01472 L
Mistroke
.95287 .01472 L
.95289 .01472 L
.95292 .01472 L
.95295 .01472 L
.95298 .01472 L
.95301 .01472 L
.95304 .01472 L
.95307 .01472 L
.9531 .01472 L
.95311 .01472 L
.95313 .01472 L
.95316 .01472 L
.95319 .01472 L
.95322 .01472 L
.95324 .01472 L
.95327 .01472 L
.9533 .01472 L
.95333 .01472 L
.95335 .01472 L
.95338 .01472 L
.9534 .01472 L
.95343 .01472 L
.95346 .01472 L
.95349 .01472 L
.95351 .01472 L
.95354 .01472 L
.95356 .01472 L
.95357 .01472 L
.9536 .01472 L
.95363 .01472 L
.95366 .01472 L
.95369 .01472 L
.95372 .01472 L
.95375 .01472 L
.95378 .01472 L
.9538 .01472 L
.95383 .01472 L
.95386 .01472 L
.95389 .01472 L
.95392 .01472 L
.95395 .01472 L
.95397 .01472 L
.95401 .01472 L
.95402 .01472 L
.95404 .01472 L
.95407 .01472 L
.9541 .01472 L
.95413 .01472 L
.95415 .01472 L
.95418 .01472 L
Mistroke
.95421 .01472 L
.95424 .01472 L
.95426 .01472 L
.95429 .01472 L
.95431 .01472 L
.95434 .01472 L
.95437 .01472 L
.9544 .01472 L
.95442 .01472 L
.95445 .01472 L
.95447 .01472 L
.95448 .01472 L
.95451 .01472 L
.95454 .01472 L
.95457 .01472 L
.95459 .01472 L
.9546 .01472 L
.95463 .01472 L
.95466 .01472 L
.95469 .01472 L
.95471 .01472 L
.95474 .01472 L
.95477 .01472 L
.9548 .01472 L
.95481 .01472 L
.95483 .01472 L
.95486 .01472 L
.95488 .01472 L
.9549 .01472 L
.95492 .01472 L
.95496 .01472 L
.95499 .01472 L
.95501 .01472 L
.95504 .01472 L
.95507 .01472 L
.95509 .01472 L
.95511 .01472 L
.95514 .01472 L
.95517 .01472 L
.9552 .01472 L
.95523 .01472 L
.95526 .01472 L
.95528 .01472 L
.95531 .01472 L
.95534 .01472 L
.95537 .01472 L
.9554 .01472 L
.95542 .01472 L
.95545 .01472 L
.95548 .01472 L
Mistroke
.95551 .01472 L
.95553 .01472 L
.95554 .01472 L
.95556 .01472 L
.95558 .01472 L
.95561 .01472 L
.95564 .01472 L
.95567 .01472 L
.9557 .01472 L
.95572 .01472 L
.95575 .01472 L
.95578 .01472 L
.9558 .01472 L
.95583 .01472 L
.95586 .01472 L
.95589 .01472 L
.95592 .01472 L
.95595 .01472 L
.95598 .01472 L
.95601 .01472 L
.95604 .01472 L
.95607 .01472 L
.95609 .01472 L
.9561 .01472 L
.95613 .01472 L
.95615 .01472 L
.95617 .01472 L
.95618 .01472 L
.9562 .01472 L
.95623 .01472 L
.95625 .01472 L
.95626 .01472 L
.95628 .01472 L
.9563 .01472 L
.95632 .01472 L
.95633 .01472 L
.95635 .01472 L
.95636 .01472 L
.95639 .01472 L
.95642 .01472 L
.95645 .01472 L
.95648 .01472 L
.95651 .01472 L
.95654 .01472 L
.95657 .01472 L
.95659 .01472 L
.95662 .01472 L
.95665 .01472 L
.95668 .01472 L
.95671 .01472 L
Mistroke
.95674 .01472 L
.95677 .01472 L
.9568 .01472 L
.95682 .01472 L
.95683 .01472 L
.95686 .01472 L
.95689 .01472 L
.95692 .01472 L
.95695 .01472 L
.95698 .01472 L
.957 .01472 L
.95703 .01472 L
.95705 .01472 L
.95708 .01472 L
.9571 .01472 L
.95713 .01472 L
.95716 .01472 L
.95719 .01472 L
.95721 .01472 L
.95724 .01472 L
.95726 .01472 L
.95727 .01472 L
.9573 .01472 L
.95733 .01472 L
.95736 .01472 L
.95739 .01472 L
.95742 .01472 L
.95745 .01472 L
.95748 .01472 L
.9575 .01472 L
.95753 .01472 L
.95756 .01472 L
.95759 .01472 L
.95762 .01472 L
.95765 .01472 L
.95768 .01472 L
.95771 .01472 L
.95773 .01472 L
.95774 .01472 L
.95777 .01472 L
.9578 .01472 L
.95783 .01472 L
.95786 .01472 L
.95788 .01472 L
.95791 .01472 L
.95794 .01472 L
.95796 .01472 L
.95799 .01472 L
.95801 .01472 L
.95804 .01472 L
Mistroke
.95807 .01472 L
.9581 .01472 L
.95812 .01472 L
.95815 .01472 L
.95817 .01472 L
.95818 .01472 L
.95821 .01472 L
.95824 .01472 L
.95827 .01472 L
.9583 .01472 L
.95833 .01472 L
.95836 .01472 L
.95839 .01472 L
.95841 .01472 L
.95844 .01472 L
.95847 .01472 L
.9585 .01472 L
.95853 .01472 L
.95856 .01472 L
.95859 .01472 L
.95862 .01472 L
.95864 .01472 L
.95865 .01472 L
.95868 .01472 L
.95871 .01472 L
.95874 .01472 L
.95877 .01472 L
.9588 .01472 L
.95882 .01472 L
.95885 .01472 L
.95887 .01472 L
.9589 .01472 L
.95892 .01472 L
.95895 .01472 L
.95898 .01472 L
.95901 .01472 L
.95903 .01472 L
.95906 .01472 L
.95908 .01472 L
.9591 .01472 L
.95912 .01472 L
.95915 .01472 L
.95918 .01472 L
.9592 .01472 L
.95921 .01472 L
.95924 .01472 L
.95927 .01472 L
.9593 .01472 L
.95932 .01472 L
.95935 .01472 L
Mistroke
.95938 .01472 L
.95941 .01472 L
.95943 .01472 L
.95944 .01472 L
.95947 .01472 L
.95949 .01472 L
.95951 .01472 L
.95954 .01472 L
.95957 .01472 L
.9596 .01472 L
.95963 .01472 L
.95965 .01472 L
.95968 .01472 L
.9597 .01472 L
.95973 .01472 L
.95975 .01472 L
.95978 .01472 L
.95981 .01472 L
.95984 .01472 L
.95987 .01472 L
.9599 .01472 L
.95992 .01472 L
.95995 .01472 L
.95998 .01472 L
.96001 .01472 L
.96004 .01472 L
.96007 .01472 L
.9601 .01472 L
.96013 .01472 L
.96014 .01472 L
.96016 .01472 L
.96018 .01472 L
.96019 .01472 L
.96022 .01472 L
.96025 .01472 L
.96028 .01472 L
.96031 .01472 L
.96034 .01472 L
.96037 .01472 L
.96039 .01472 L
.96042 .01472 L
.96045 .01472 L
.96048 .01472 L
.96051 .01472 L
.96054 .01472 L
.96056 .01472 L
.9606 .01472 L
.96063 .01472 L
.96065 .01472 L
.96068 .01472 L
Mistroke
.9607 .01472 L
.96072 .01472 L
.96075 .01472 L
.96076 .01472 L
.96078 .01472 L
.9608 .01472 L
.96081 .01472 L
.96084 .01472 L
.96086 .01472 L
.96088 .01472 L
.96089 .01472 L
.96091 .01472 L
.96093 .01472 L
.96095 .01472 L
.96096 .01472 L
.96098 .01472 L
.96101 .01472 L
.96104 .01472 L
.96107 .01472 L
.9611 .01472 L
.96113 .01472 L
.96116 .01472 L
.96118 .01472 L
.96121 .01472 L
.96124 .01472 L
.96126 .01472 L
.96129 .01472 L
.96133 .01472 L
.96135 .01472 L
.96138 .01472 L
.96141 .01472 L
.96143 .01472 L
.96145 .01472 L
.96148 .01472 L
.96151 .01472 L
.96153 .01472 L
.96156 .01472 L
.96159 .01472 L
.96162 .01472 L
.96164 .01472 L
.96167 .01472 L
.96169 .01472 L
.96172 .01472 L
.96175 .01472 L
.96178 .01472 L
.9618 .01472 L
.96183 .01472 L
.96186 .01472 L
.96187 .01472 L
.96189 .01472 L
Mistroke
.96192 .01472 L
.96195 .01472 L
.96198 .01472 L
.96201 .01472 L
.96204 .01472 L
.96207 .01472 L
.96209 .01472 L
.96212 .01472 L
.96215 .01472 L
.96217 .01472 L
.9622 .01472 L
.96224 .01472 L
.96226 .01472 L
.96229 .01472 L
.96232 .01472 L
.96234 .01472 L
.96236 .01472 L
.96239 .01472 L
.96242 .01472 L
.96244 .01472 L
.96247 .01472 L
.9625 .01472 L
.96253 .01472 L
.96255 .01472 L
.96258 .01472 L
.9626 .01472 L
.96263 .01472 L
.96266 .01472 L
.96269 .01472 L
.96271 .01472 L
.96274 .01472 L
.96277 .01472 L
.96279 .01472 L
.9628 .01472 L
.96283 .01472 L
.96286 .01472 L
.96289 .01472 L
.9629 .01472 L
.96292 .01472 L
.96295 .01472 L
.96298 .01472 L
.963 .01472 L
.96303 .01472 L
.96306 .01472 L
.96309 .01472 L
.96312 .01472 L
.96313 .01472 L
.96315 .01472 L
.96318 .01472 L
.9632 .01472 L
Mistroke
.96321 .01472 L
.96324 .01472 L
.96327 .01472 L
.9633 .01472 L
.96333 .01472 L
.96336 .01472 L
.96338 .01472 L
.96341 .01472 L
.96343 .01472 L
.96346 .01472 L
.96349 .01472 L
.96352 .01472 L
.96354 .01472 L
.96357 .01472 L
.9636 .01472 L
.96363 .01472 L
.96365 .01472 L
.96368 .01472 L
.96371 .01472 L
.96374 .01472 L
.96377 .01472 L
.9638 .01472 L
.96383 .01472 L
.96385 .01472 L
.96386 .01472 L
.96388 .01472 L
.9639 .01472 L
.96393 .01472 L
.96395 .01472 L
.96398 .01472 L
.96402 .01472 L
.96404 .01472 L
.96407 .01472 L
.9641 .01472 L
.96412 .01472 L
.96415 .01472 L
.96418 .01472 L
.96421 .01472 L
.96424 .01472 L
.96427 .01472 L
.9643 .01472 L
.96433 .01472 L
.96436 .01472 L
.96439 .01472 L
.96441 .01472 L
.96442 .01472 L
.96445 .01472 L
.96447 .01472 L
.96448 .01472 L
.9645 .01472 L
Mistroke
.96452 .01472 L
.96455 .01472 L
.96457 .01472 L
.96458 .01472 L
.9646 .01472 L
.96462 .01472 L
.96463 .01472 L
.96465 .01472 L
.96467 .01472 L
.96468 .01472 L
.96471 .01472 L
.96474 .01472 L
.96477 .01472 L
.9648 .01472 L
.96483 .01472 L
.96486 .01472 L
.96489 .01472 L
.96491 .01472 L
.96494 .01472 L
.96497 .01472 L
.965 .01472 L
.96503 .01472 L
.96506 .01472 L
.96509 .01472 L
.96512 .01472 L
.96514 .01472 L
.96515 .01472 L
.96518 .01472 L
.96521 .01472 L
.96524 .01472 L
.96527 .01472 L
.96529 .01472 L
.96532 .01472 L
.96535 .01472 L
.96537 .01472 L
.9654 .01472 L
.96542 .01472 L
.96545 .01472 L
.96548 .01472 L
.96551 .01472 L
.96553 .01472 L
.96556 .01472 L
.96558 .01472 L
.96559 .01472 L
.96562 .01472 L
.96565 .01472 L
.96568 .01472 L
.96571 .01472 L
.96574 .01472 L
.96577 .01472 L
Mistroke
.9658 .01472 L
.96582 .01472 L
.96585 .01472 L
.96588 .01472 L
.96591 .01472 L
.96594 .01472 L
.96597 .01472 L
.966 .01472 L
.96603 .01472 L
.96605 .01472 L
.96606 .01472 L
.96609 .01472 L
.96612 .01472 L
.96615 .01472 L
.96618 .01472 L
.9662 .01472 L
.96623 .01472 L
.96626 .01472 L
.96628 .01472 L
.96631 .01472 L
.96633 .01472 L
.96636 .01472 L
.96639 .01472 L
.96642 .01472 L
.96644 .01472 L
.96647 .01472 L
.96649 .01472 L
.9665 .01472 L
.96653 .01472 L
.96656 .01472 L
.96659 .01472 L
.96661 .01472 L
.96662 .01472 L
.96665 .01472 L
.96668 .01472 L
.96671 .01472 L
.96673 .01472 L
.96676 .01472 L
.96679 .01472 L
.96682 .01472 L
.96684 .01472 L
.96685 .01472 L
.96688 .01472 L
.9669 .01472 L
.96692 .01472 L
.96695 .01472 L
.96698 .01472 L
.96701 .01472 L
.96703 .01472 L
.96706 .01472 L
Mistroke
.96709 .01472 L
.96711 .01472 L
.96714 .01472 L
.96716 .01472 L
.96719 .01472 L
.96722 .01472 L
.96725 .01472 L
.96728 .01472 L
.96731 .01472 L
.96733 .01472 L
.96736 .01472 L
.96739 .01472 L
.96742 .01472 L
.96744 .01472 L
.96747 .01472 L
.96751 .01472 L
.96753 .01472 L
.96755 .01472 L
.96757 .01472 L
.96758 .01472 L
.9676 .01472 L
.96763 .01472 L
.96766 .01472 L
.96769 .01472 L
.96772 .01472 L
.96775 .01472 L
.96778 .01472 L
.9678 .01472 L
.96783 .01472 L
.96786 .01472 L
.96789 .01472 L
.96792 .01472 L
.96794 .01472 L
.96797 .01472 L
.968 .01472 L
.96803 .01472 L
.96806 .01472 L
.96809 .01472 L
.96811 .01472 L
.96813 .01472 L
.96816 .01472 L
.96817 .01472 L
.96819 .01472 L
.9682 .01472 L
.96822 .01472 L
.96825 .01472 L
.96827 .01472 L
.96828 .01472 L
.9683 .01472 L
.96832 .01472 L
Mistroke
.96834 .01472 L
.96835 .01472 L
.96837 .01472 L
.96839 .01472 L
.96842 .01472 L
.96845 .01472 L
.96848 .01472 L
.96851 .01472 L
.96854 .01472 L
.96856 .01472 L
.96859 .01472 L
.96862 .01472 L
.96865 .01472 L
.96867 .01472 L
.9687 .01472 L
.96873 .01472 L
.96876 .01472 L
.96879 .01472 L
.96882 .01472 L
.96884 .01472 L
.96885 .01472 L
.96889 .01472 L
.96892 .01472 L
.96894 .01472 L
.96897 .01472 L
.969 .01472 L
.96902 .01472 L
.96905 .01472 L
.96907 .01472 L
.9691 .01472 L
.96913 .01472 L
.96915 .01472 L
.96918 .01472 L
.96921 .01472 L
.96924 .01472 L
.96926 .01472 L
.96928 .01472 L
.9693 .01472 L
.96933 .01472 L
.96936 .01472 L
.96938 .01472 L
.96942 .01472 L
.96945 .01472 L
.96947 .01472 L
.9695 .01472 L
.96953 .01472 L
.96955 .01472 L
.96958 .01472 L
.96961 .01472 L
.96964 .01472 L
Mistroke
.96967 .01472 L
.9697 .01472 L
.96973 .01472 L
.96975 .01472 L
.96976 .01472 L
.9698 .01472 L
.96983 .01472 L
.96985 .01472 L
.96988 .01472 L
.96991 .01472 L
.96993 .01472 L
.96996 .01472 L
.96998 .01472 L
.97001 .01472 L
.97004 .01472 L
.97006 .01472 L
.97009 .01472 L
.97012 .01472 L
.97015 .01472 L
.97018 .01472 L
.97019 .01472 L
.97021 .01472 L
.97024 .01472 L
.97027 .01472 L
.97029 .01472 L
.97031 .01472 L
.97033 .01472 L
.97035 .01472 L
.97038 .01472 L
.97041 .01472 L
.97044 .01472 L
.97046 .01472 L
.97049 .01472 L
.97052 .01472 L
.97054 .01472 L
.97055 .01472 L
.97059 .01472 L
.9706 .01472 L
.97062 .01472 L
.97065 .01472 L
.97068 .01472 L
.97071 .01472 L
.97074 .01472 L
.97076 .01472 L
.97079 .01472 L
.97081 .01472 L
.97084 .01472 L
.97087 .01472 L
.9709 .01472 L
.97092 .01472 L
Mistroke
.97095 .01472 L
.97098 .01472 L
.97101 .01472 L
.97103 .01472 L
.97106 .01472 L
.97109 .01472 L
.97112 .01472 L
.97115 .01472 L
.97118 .01472 L
.97121 .01472 L
.97124 .01472 L
.97125 .01472 L
.97127 .01472 L
.97129 .01472 L
.9713 .01472 L
.97133 .01472 L
.97136 .01472 L
.97139 .01472 L
.97142 .01472 L
.97145 .01472 L
.97148 .01472 L
.9715 .01472 L
.97153 .01472 L
.97156 .01472 L
.97159 .01472 L
.97162 .01472 L
.97165 .01472 L
.97167 .01472 L
.97171 .01472 L
.97174 .01472 L
.97176 .01472 L
.97179 .01472 L
.97181 .01472 L
.97183 .01472 L
.97186 .01472 L
.97187 .01472 L
.97189 .01472 L
.97191 .01472 L
.97192 .01472 L
.97195 .01472 L
.97197 .01472 L
.97199 .01472 L
.972 .01472 L
.97202 .01472 L
.97204 .01472 L
.97206 .01472 L
.97207 .01472 L
.97209 .01472 L
.97212 .01472 L
.97215 .01472 L
Mistroke
.97218 .01472 L
.97221 .01472 L
.97224 .01472 L
.97227 .01472 L
.97229 .01472 L
.97232 .01472 L
.97235 .01472 L
.97237 .01472 L
.9724 .01472 L
.97243 .01472 L
.97246 .01472 L
.97249 .01472 L
.97252 .01472 L
.97254 .01472 L
.97256 .01472 L
.97259 .01472 L
.97262 .01472 L
.97264 .01472 L
.97267 .01472 L
.9727 .01472 L
.97273 .01472 L
.97275 .01472 L
.97278 .01472 L
.9728 .01472 L
.97283 .01472 L
.97286 .01472 L
.97288 .01472 L
.97291 .01472 L
.97294 .01472 L
.97297 .01472 L
.97298 .01472 L
.973 .01472 L
.97303 .01472 L
.97306 .01472 L
.97309 .01472 L
.97312 .01472 L
.97315 .01472 L
.97318 .01472 L
.9732 .01472 L
.97323 .01472 L
.97326 .01472 L
.97328 .01472 L
.97331 .01472 L
.97334 .01472 L
.97337 .01472 L
.9734 .01472 L
.97343 .01472 L
.97345 .01472 L
.97347 .01472 L
.9735 .01472 L
Mistroke
.97353 .01472 L
.97355 .01472 L
.97358 .01472 L
.97361 .01472 L
.97364 .01472 L
.97366 .01472 L
.97369 .01472 L
.97371 .01472 L
.97374 .01472 L
.97377 .01472 L
.97379 .01472 L
.97382 .01472 L
.97385 .01472 L
.97388 .01472 L
.97389 .01472 L
.97391 .01472 L
.97394 .01472 L
.97397 .01472 L
.974 .01472 L
.97403 .01472 L
.97406 .01472 L
.97409 .01472 L
.97411 .01472 L
.97414 .01472 L
.97417 .01472 L
.97419 .01472 L
.97422 .01472 L
.97425 .01472 L
.97428 .01472 L
.97431 .01472 L
.97434 .01472 L
.97436 .01472 L
.97438 .01472 L
.97441 .01472 L
.97444 .01472 L
.97446 .01472 L
.97449 .01472 L
.97452 .01472 L
.97455 .01472 L
.97457 .01472 L
.9746 .01472 L
.97462 .01472 L
.97465 .01472 L
.97468 .01472 L
.97471 .01472 L
.97473 .01472 L
.97476 .01472 L
.97479 .01472 L
.9748 .01472 L
.97482 .01472 L
Mistroke
.97485 .01472 L
.97488 .01472 L
.97491 .01472 L
.97492 .01472 L
.97494 .01472 L
.97497 .01472 L
.975 .01472 L
.97502 .01472 L
.97505 .01472 L
.97508 .01472 L
.97511 .01472 L
.97514 .01472 L
.97515 .01472 L
.97517 .01472 L
.9752 .01472 L
.97522 .01472 L
.97523 .01472 L
.97526 .01472 L
.97529 .01472 L
.97532 .01472 L
.97535 .01472 L
.97538 .01472 L
.9754 .01472 L
.97543 .01472 L
.97545 .01472 L
.97548 .01472 L
.97551 .01472 L
.97554 .01472 L
.97556 .01472 L
.97559 .01472 L
.97562 .01472 L
.97565 .01472 L
.97567 .01472 L
.9757 .01472 L
.97573 .01472 L
.97576 .01472 L
.97579 .01472 L
.97582 .01472 L
.97584 .01472 L
.97587 .01472 L
.97589 .01472 L
.97591 .01472 L
.97594 .01472 L
.97596 .01472 L
.97598 .01472 L
.97601 .01472 L
.97604 .01472 L
.97606 .01472 L
.97608 .01472 L
.97611 .01472 L
Mistroke
.97614 .01472 L
.97617 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[100]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00?`3oool4000000<0oooo0P00000X0?ooo`<000000P3oool2000002H0oooo0`0000040?oo
o`8000009`3oool2000000@0oooo0P00000S0?ooo`D000000P3oool2000000@0oooo0P00000I0?oo
o`00?`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000002P0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0S0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000009@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
02@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool05P3oool00400oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
000U0?ooo`D0000000D0oooo0000003oool0oooo0000000U0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000009@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000002@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool05P3oool00440oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo02<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000U
0?ooo`<000000`3oool010000000oooo0?ooo`00000V0?ooo`8000000`3oool010000000oooo0?oo
o`00000T0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo01H0oooo000o0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000009P3oool00`000000oooo000000020?ooo`040000003oool0oooo000002H0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000U0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000903oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0F0?ooo`00@03oool2000000@0oooo0P00000X
0?ooo`8000000`3oool2000002L0oooo0`0000030?ooo`8000009`3oool2000000@0oooo0P00000T
0?ooo`800000103oool2000000@0oooo0P00000I0?ooo`00o`3ooolQ0?ooo`005@3oool00`000000
oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<0
00000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000?0?oo
ool000004@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?oo
o`3oool0000000L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`005@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo
0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo
0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`05
0000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`000000
4P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0
oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0H0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000
000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?oo
o`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000
003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100
oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo
0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0H0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D0
00000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool20000
00<0oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo
0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo
0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01P0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000E
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3o
ool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003o
ool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000E0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000
000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?oo
o`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01P0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403o
ool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000E0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0
00000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0
oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D0
00000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000E0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3o
ool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01P0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool0
1@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000E0?ooo`80
00000`3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3o
ool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003o
ool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0603oool001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool0
01D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo
0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D00000
0?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403o
ool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0603oool001D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0
00000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0
oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0603oool001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@
0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool001D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?oo
o`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?oo
o`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool0
1@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0603oool001D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool00000
0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo
0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0603oool001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?oo
o`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool001D0oooo
0P0000030?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool00000
0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo
0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D00000
0?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0H0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?oo
o`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3o
ool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@00
0000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@
0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?oo
o`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?oo
o`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0H0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`00
5@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0
oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000
oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?oo
o`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`000P3oool2000000@0oooo0P000003
0?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D00000
0?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403o
ool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`0000D0oooo0000003o
ool0oooo000000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`00
00004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0603oool000050?ooo`000000oooo0?ooo`0000002@3oool00`000000oooo0?ooo`040?ooo`<0
00000P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3o
ool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003o
ool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0603oool000050?ooo`000000oooo0?ooo`0000002P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo
0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`05
0000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00001@3oool000000?ooo`3o
ool0000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000
000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0H0?ooo`000P3oool2000000X0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool00000
0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01P0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000
oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?oo
o`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000E0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`00
00004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3o
ool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@00
0000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01P0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0
oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo
0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`05
0000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000E0?ooo`8000000`3oool0
0`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?oo
o`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0603oool001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`05
0000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool001D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`000000
4P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0
oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000
oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?oo
o`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0603oool001D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`00
00004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0603oool001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000
003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100
oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool001D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo
0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo
0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`05
0000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0603oool001D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`000000
4P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
603oool001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003o
ool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool001D0oooo0P0000030?oo
o`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`000000
4P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0
oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0H0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000
000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?oo
o`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000
003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100
oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo
0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0H0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D0
00000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3o
ool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003o
ool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000
000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0H0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D00000
0?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403o
ool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool2000000<0
oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000
000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?oo
o`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01P0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403o
ool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000E0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0
00000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0
oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D0
00000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000E0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3o
ool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01P0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool0
1@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000E0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool00000
0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo
0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D00000
0?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403o
ool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01P0oooo00020?ooo`800000103oool2000000D0oooo0`00
00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?oo
o`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000
003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100
oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00001@3oool000000?ooo`3oool0
000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?oo
o`0000D0oooo0000003oool0oooo000000080?ooo`D000000`3oool300000080oooo00<000000?oo
o`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0
oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3o
ool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003o
ool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0H0?ooo`0000D0oooo0000003oool0oooo000000090?ooo`03
0000003oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`05
0000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool00080oooo0P00
000;0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D0
00000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3o
ool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003o
ool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000
000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0H0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D00000
0?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403o
ool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0
00000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0
oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D0
00000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool2000000<0oooo00<000000?ooo`3oool0403o
ool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000E0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0
00000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0
oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D0
00000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000E0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3o
ool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01P0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool0
1@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000E0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool00000
0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo
0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D00000
0?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403o
ool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01P0oooo000E0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0
00000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01P0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@00
0000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@
0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000E0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?oo
o`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?oo
o`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool0
1@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01P0oooo000E0?ooo`8000000`3oool00`000000oooo0?ooo`0@
0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool001D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?oo
o`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?oo
o`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool0
1@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0603oool001D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool00000
0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo
0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0603oool001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?oo
o`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool001D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`00
00004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3o
ool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@00
0000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@
0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0603oool001D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?oo
o`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0603oool001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`05
0000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool001D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`000000
4P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0
oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000
oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?oo
o`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0603oool001D0oooo0P0000030?ooo`030000003oool0oooo
0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`00
5@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0
oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000
oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?oo
o`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`00
00004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3o
ool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0H0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100
oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo
0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo
0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`05
0000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`000000
4P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0
oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0H0?ooo`000P3oool2000000@0oooo0P0000030?ooo`<000001@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool00000
0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo
0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D00000
0?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0H0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000
003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100
oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool000050?ooo`000000
oooo0?ooo`000000203oool010000000oooo0?ooo`0000040?ooo`<000000P3oool00`000000oooo
0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603o
ool000050?ooo`000000oooo0?ooo`000000203oool3000000D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool00000
0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo
0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0603oool000050?ooo`000000oooo0?ooo`0000002@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3o
ool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003o
ool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00020?ooo`8000002P3oool3000000@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?oo
o`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?oo
o`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool0
1@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0603oool001D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool00000
0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo
0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0603oool001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?oo
o`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool001D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`00
00004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3o
ool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@00
0000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@
0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0603oool001D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?oo
o`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0603oool001D0oooo0P0000030?ooo`030000003oool0oooo0100oooo00D000000?ooo`3o
ool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@00
0000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@
0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?oo
o`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?oo
o`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0H0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`00
5@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0
oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000
oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?oo
o`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`00
00004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3o
ool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0H0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100
oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo
0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo
0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`05
0000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`000000
4P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0
oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0H0?ooo`005@3oool2000000<0oooo00<000000?ooo`3oool0403oool01@000000oooo
0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`05
0000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000E0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`000000
4P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0
oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000
oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01P0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo
000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?oo
o`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000
003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100
oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000E0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo
0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo
0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01P0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000E
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3o
ool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003o
ool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000E0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000
000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?oo
o`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01P0oooo000E0?ooo`8000000`3oool00`000000oooo0?ooo`0@0?ooo`050000003o
ool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool001D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000
000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?oo
o`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000
003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0603oool001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603o
ool001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0
oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D0
00000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool001D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3o
ool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003o
ool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0603oool001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool0
0080oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`00
00004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0603oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0
00000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0
oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D0
00000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00001@3oool000000?ooo`3oool0000000P0
oooo00@000000?ooo`3oool00000103oool300000080oooo00<000000?ooo`3oool0403oool01@00
0000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@
0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00001@3oool00000
0?ooo`3oool0000000T0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo
00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0
00000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0
oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D0
00000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0H0?ooo`000P3oool2000000X0oooo0P0000050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`00
00004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3o
ool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@00
0000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01P0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0
oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo
0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`05
0000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000E0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`000000
4P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0
oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000
oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01P0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo
000E0?ooo`8000000`3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`000000
4P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0
oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000
oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?oo
o`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0603oool001D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`00
00004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0603oool001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000
003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100
oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool001D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo
0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo
0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`05
0000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0603oool001D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`000000
4P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
603oool001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003o
ool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool001D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000
000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?oo
o`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000
003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0603oool001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603o
ool001D0oooo0P0000030?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000
000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?oo
o`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000
003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100
oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo
0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0H0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D0
00000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3o
ool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003o
ool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000
000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0H0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D00000
0?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403o
ool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0
00000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0
oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D0
00000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0H0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H
0?ooo`005@3oool2000000<0oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0
00000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0
oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D0
00000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000E0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3o
ool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01P0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool0
1@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000E0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool00000
0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo
0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D00000
0?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403o
ool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01P0oooo000E0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0
00000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01P0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@00
0000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@
0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000=0?ooo`D00000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0
oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000
oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?oo
o`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0100oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`003`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3o
ool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003o
ool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0403oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000?0?ooo`030000003oool0oooo00<0
oooo1P00000B0?ooo`D000004P3oool600000180oooo1P00000A0?ooo`H000004P3oool600000140
oooo1P00000B0?ooo`H000004@3oool600000180oooo1P00000A0?ooo`H000006P3oool000l0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000?0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0o`3oool90?ooo`003P3oool2000000D0oooo00<00000
0?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-9.12837, -0.07747, \
0.424797, 0.00624851}}]
}, Open  ]],

Cell[TextData[{
  "The clearance coeffs are",
  Cell[BoxData[
      \({k12 \[Rule] 2, k21 \[Rule] \ 1, k10 \[Rule] \ 0.5, 
        k\_g \[Rule] \ 0.1, k\_a \[Rule] \ 2, 
        k\_\(bilis, gi\) \[Rule] \ h[t, 8, 2]\ }\)]]
}], "Text"],

Cell[BoxData[
    \(matrixhepatic = 
      CompartMatrix[
          4, \ {{1, 2, \ k12}, \ {1, 0, k10}, {2, 1, \ k21}, {1, 3, \ 
              k\_g}, {\ 3, 4, \ k\_\(bilis, gi\)}, \ {4, 1, \ 
              k\_a}}] /. {k12 \[Rule] 2, k21 \[Rule] \ 1, k10 \[Rule] \ 0.5, 
          k\_g \[Rule] \ 0.1, k\_a \[Rule] \ 2, 
          k\_\(bilis, gi\) \[Rule] \ h[t, 8, 2]\ }; \)], "Input",
  CellLabel->"In[101]:="],

Cell["Initial condition and input are", "Text"],

Cell[BoxData[
    \(ip\  = {0, 0, 0, 0}; \)], "Input",
  CellLabel->"In[102]:="],

Cell[BoxData[
    \(ic2\  = {200, 0, 0, 0}; \)], "Input",
  CellLabel->"In[103]:="],

Cell[TextData[{
  "Then, it can be used  ",
  Cell[BoxData[
      ButtonBox[
        StyleBox["SystemNDSolve",
          FontColor->RGBColor[0, 0, 1],
          FontVariations->{"Underline"->True}],
        ButtonFunction:>(Internal`PutInformation[ #, LongForm -> False]&),
        ButtonData:>{"Info3257348699-2143584", 
          "Biokmod`SysModel`SystemNDSolve"},
        ButtonFrame->"None",
        ButtonNote->"Biokmod`SysModel`"]],
    CellMargins->{{20, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
    Background->GrayLevel[0.930022],
    ButtonBoxOptions->{Active->True}],
  "  "
}], "Text"],

Cell[BoxData[
    \("SystemNDSolve[MatrixCoefs, incond, input, {t, tmin,  tmax}, t1, x, \
options]  gives the numeric solution X(t)= {x1(t), ..., xn(t) at time t1 of a \
ODE  system X'(t) = A X(t) + B(t), with initial conditions X(0) = IC , where; \
 MatrixCoefs is the  coeffs matrix A = {{a11,...a1n}, ...,{am1, ..., amn}}; \
incond are IC =  {c1,..,ci,..cn};  B(t) ={b1[t],..., bn[t]};  x is the symbol \
that represents X; options are the  options of NDSolve.  Note:  This function \
apply the Mathematica function NDSolve  for solving the  SODE, it should be \
used when MatrixCoefs included some coeffs that are not  constants or when it \
was not possible obtain the solution of the model using  SystemDSolve."\)], \
"Print",
  CellTags->"Info3257348699-2143584"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol1 = 
      SystemNDSolve[matrixhepatic, \ ic2, ip, {\ t, 0, \ 100}, \ 
        t, \ \ x]\)], "Input",
  CellLabel->"In[104]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{\(x\_1[t]\), "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{0.`, 100.`}}, "<>"]\),
              False,
              Editable->False], "[", "t", "]"}]}], ",", 
        RowBox[{\(x\_2[t]\), "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{0.`, 100.`}}, "<>"]\),
              False,
              Editable->False], "[", "t", "]"}]}], ",", 
        RowBox[{\(x\_3[t]\), "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{0.`, 100.`}}, "<>"]\),
              False,
              Editable->False], "[", "t", "]"}]}], ",", 
        RowBox[{\(x\_4[t]\), "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{0.`, 100.`}}, "<>"]\),
              False,
              Editable->False], "[", "t", "]"}]}]}], "}"}]], "Output",
  CellLabel->"Out[104]="]
}, Open  ]],

Cell["We need increase the number of steps ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol2 = \ 
      SystemNDSolve[matrixhepatic, \ ic2, ip, {\ t, 0, \ 100}, \ t, \ \ x, 
        MaxSteps \[Rule] 5000]\)], "Input",
  CellLabel->"In[105]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{\(x\_1[t]\), "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{0.`, 100.`}}, "<>"]\),
              False,
              Editable->False], "[", "t", "]"}]}], ",", 
        RowBox[{\(x\_2[t]\), "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{0.`, 100.`}}, "<>"]\),
              False,
              Editable->False], "[", "t", "]"}]}], ",", 
        RowBox[{\(x\_3[t]\), "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{0.`, 100.`}}, "<>"]\),
              False,
              Editable->False], "[", "t", "]"}]}], ",", 
        RowBox[{\(x\_4[t]\), "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{0.`, 100.`}}, "<>"]\),
              False,
              Editable->False], "[", "t", "]"}]}]}], "}"}]], "Output",
  CellLabel->"Out[105]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({\ x1[t_], x2[t_], x3[t_], 
        x4[t_]}\  = \ {\ x\_1[t], x\_2[t], x\_3[t], x\_4[t]} /. 
        sol2\)], "Input",
  CellLabel->"In[106]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          TagBox[\(InterpolatingFunction[{{0.`, 100.`}}, "<>"]\),
            False,
            Editable->False], "[", "t", "]"}], ",", 
        RowBox[{
          TagBox[\(InterpolatingFunction[{{0.`, 100.`}}, "<>"]\),
            False,
            Editable->False], "[", "t", "]"}], ",", 
        RowBox[{
          TagBox[\(InterpolatingFunction[{{0.`, 100.`}}, "<>"]\),
            False,
            Editable->False], "[", "t", "]"}], ",", 
        RowBox[{
          TagBox[\(InterpolatingFunction[{{0.`, 100.`}}, "<>"]\),
            False,
            Editable->False], "[", "t", "]"}]}], "}"}]], "Output",
  CellLabel->"Out[106]="]
}, Open  ]],

Cell["Here are ploted the solution ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{x1[t], x2[t], x3[t]}, \ {t, 0, 50}, PlotPoints \[Rule] 1000, 
      PlotRange \[Rule] {0, 100}, \[IndentingNewLine]\ 
      PlotStyle \[Rule] {{AbsoluteThickness[2]}, {AbsoluteThickness[
              0.5]}, {AbsoluteThickness[1.5]}}, \ 
      AxesLabel \[Rule] {"\<days\>", \ "\<r\>"}, 
      PlotLegend \[Rule] {"\<x1\>", "\<x2\>", "\<x3\>"}, 
      LegendPosition \[Rule] {0, \ 0.3}, \ 
      LegendSize \[Rule] {0.3, \ 0.3}]; \)], "Input",
  CellLabel->"In[107]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 1.73472e-017 0.00618034 [
[.21429 -0.0125 -6 -9 ]
[.21429 -0.0125 6 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6.25 ]
[1.025 0 28 6.25 ]
[.01131 .12361 -12 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -12 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -12 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(10)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(20)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(30)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(40)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(50)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(days) show
87.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .12361 m
.03006 .12361 L
s
[(20)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(40)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(60)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(80)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(100)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
2 Mabswid
.02971 .61803 m
.03052 .57182 L
.03148 .52583 L
.0324 .4882 L
.03338 .45417 L
.03433 .42634 L
.03524 .40342 L
.03621 .38253 L
.03714 .36531 L
.03813 .34962 L
.03908 .33665 L
.04 .32584 L
.04098 .31587 L
.04192 .30751 L
.04292 .29977 L
.04388 .29323 L
.0448 .28766 L
.04579 .28239 L
.04674 .27785 L
.04765 .27391 L
.04862 .2701 L
.04956 .26675 L
.05055 .26347 L
.05151 .26055 L
.05243 .25792 L
.05341 .2553 L
.05435 .25291 L
.05526 .25072 L
.05622 .2485 L
.05715 .24644 L
.05814 .24433 L
.05909 .24236 L
.06001 .24052 L
.06098 .23862 L
.06192 .23682 L
.06292 .23488 L
.06388 .23293 L
.0648 .23101 L
.06579 .22892 L
.06673 .22688 L
.06764 .22492 L
.06861 .22282 L
.06954 .2208 L
.07054 .21866 L
.07149 .21661 L
.07241 .21466 L
.07339 .21259 L
.07433 .21063 L
.07533 .20856 L
.07629 .20659 L
Mistroke
.07722 .20472 L
.07821 .20275 L
.07916 .20088 L
.08007 .1991 L
.08104 .19723 L
.08198 .19546 L
.08297 .19359 L
.08393 .19181 L
.08485 .19013 L
.08584 .18835 L
.08678 .18666 L
.08769 .18505 L
.08866 .18336 L
.08959 .18176 L
.09058 .18006 L
.09153 .17845 L
.09245 .17692 L
.09342 .1753 L
.09436 .17377 L
.09536 .17215 L
.09632 .17061 L
.09725 .16914 L
.09823 .16759 L
.09918 .16612 L
.10009 .16472 L
.10106 .16324 L
.10199 .16183 L
.10299 .16034 L
.10394 .15893 L
.10486 .15758 L
.10584 .15615 L
.10678 .1548 L
.10769 .1535 L
.10866 .15214 L
.10958 .15084 L
.11057 .14947 L
.11152 .14816 L
.11244 .14692 L
.11341 .1456 L
.11435 .14435 L
.11535 .14303 L
.1163 .14177 L
.11723 .14057 L
.11821 .1393 L
.11916 .13809 L
.12007 .13694 L
.12103 .13572 L
.12197 .13456 L
.12296 .13334 L
.12391 .13217 L
Mistroke
.12483 .13106 L
.12581 .12988 L
.12675 .12876 L
.12775 .12759 L
.12871 .12646 L
.12964 .12539 L
.13062 .12425 L
.13157 .12317 L
.13248 .12214 L
.13345 .12106 L
.13439 .12002 L
.13538 .11892 L
.13634 .11788 L
.13726 .11689 L
.13824 .11584 L
.13919 .11484 L
.14009 .11388 L
.14106 .11287 L
.14199 .11191 L
.14298 .1109 L
.14393 .10993 L
.14485 .10901 L
.14582 .10803 L
.14676 .10711 L
.14776 .10613 L
.14872 .10519 L
.14964 .1043 L
.15063 .10336 L
.15158 .10247 L
.15249 .10161 L
.15346 .10071 L
.15439 .09985 L
.15538 .09894 L
.15634 .09808 L
.15726 .09725 L
.15823 .09638 L
.15918 .09555 L
.16018 .09467 L
.16114 .09384 L
.16207 .09304 L
.16306 .0922 L
.16401 .0914 L
.16492 .09063 L
.16589 .08982 L
.16683 .08905 L
.16782 .08824 L
.16878 .08747 L
.16971 .08673 L
.17069 .08595 L
.17163 .0852 L
Mistroke
.17254 .0845 L
.17351 .08375 L
.17444 .08303 L
.17543 .08228 L
.17638 .08156 L
.1773 .08088 L
.17828 .08015 L
.17922 .07946 L
.18022 .07874 L
.18118 .07804 L
.1821 .07738 L
.18309 .07668 L
.18404 .07602 L
.18495 .07538 L
.18592 .07471 L
.18685 .07407 L
.18785 .0734 L
.1888 .07276 L
.18972 .07214 L
.1907 .0715 L
.19165 .07088 L
.19255 .07029 L
.19352 .06967 L
.19445 .06908 L
.19544 .06845 L
.19639 .06785 L
.1973 .06729 L
.19828 .06669 L
.19922 .06611 L
.20021 .06551 L
.20117 .06493 L
.2021 .06438 L
.20308 .0638 L
.20403 .06325 L
.20494 .06272 L
.2059 .06217 L
.20684 .06164 L
.20783 .06108 L
.20878 .06054 L
.2097 .06003 L
.21068 .0595 L
.21162 .05898 L
.21262 .05844 L
.21358 .05793 L
.21403 .05769 L
.21428 .05756 L
.2144 .0575 L
.21451 .05745 L
.21462 .05742 L
.21474 .05738 L
Mistroke
.21481 .05737 L
.21487 .05736 L
.21493 .05735 L
.21496 .05735 L
.21499 .05735 L
.21502 .05735 L
.21505 .05734 L
.21508 .05734 L
.2151 .05734 L
.21511 .05734 L
.21514 .05734 L
.21517 .05734 L
.2152 .05734 L
.21523 .05735 L
.21526 .05735 L
.2153 .05735 L
.21536 .05736 L
.21542 .05737 L
.2155 .05738 L
.21562 .05741 L
.21574 .05744 L
.21596 .05752 L
.21647 .05778 L
.21694 .05811 L
.21739 .05847 L
.21833 .0594 L
.21923 .06044 L
.2202 .06163 L
.22113 .06282 L
.22211 .0641 L
.22307 .0653 L
.22398 .06641 L
.22495 .06753 L
.22589 .06854 L
.22689 .06953 L
.22785 .0704 L
.22877 .07115 L
.22975 .07186 L
.2307 .07246 L
.23161 .07296 L
.23257 .07342 L
.2335 .07378 L
.2345 .07409 L
.23545 .07433 L
.23637 .07449 L
.23684 .07456 L
.23734 .07461 L
.23759 .07463 L
.23786 .07465 L
.23811 .07466 L
Mistroke
.23834 .07467 L
.23846 .07467 L
.23858 .07467 L
.23864 .07468 L
.23869 .07468 L
.23874 .07468 L
.2388 .07468 L
.23883 .07468 L
.23886 .07468 L
.23889 .07468 L
.2389 .07468 L
.23892 .07468 L
.23895 .07468 L
.23897 .07468 L
.23901 .07468 L
.23903 .07468 L
.23907 .07468 L
.2391 .07468 L
.23916 .07468 L
.23922 .07468 L
.23929 .07468 L
.23941 .07467 L
.23952 .07467 L
.23977 .07466 L
.24001 .07465 L
.24028 .07463 L
.24078 .07459 L
.24127 .07455 L
.24219 .07443 L
.24316 .07427 L
.24411 .07408 L
.24511 .07385 L
.24607 .0736 L
.247 .07334 L
.24798 .07304 L
.24893 .07273 L
.24985 .07242 L
.25082 .07207 L
.25176 .07172 L
.25275 .07133 L
.25371 .07085 L
.25463 .07031 L
.25561 .06966 L
.25656 .06899 L
.25747 .06831 L
.25843 .06756 L
.25936 .06683 L
.26035 .06604 L
.26131 .06528 L
.26222 .06456 L
Mistroke
.2632 .06379 L
.26414 .06306 L
.26514 .0623 L
.2661 .06158 L
.26703 .0609 L
.26801 .06019 L
.26896 .05953 L
.26987 .0589 L
.27084 .05825 L
.27178 .05763 L
.27277 .05699 L
.27372 .05639 L
.27465 .05582 L
.27562 .05523 L
.27657 .05467 L
.27747 .05414 L
.27844 .0536 L
.27937 .05308 L
.28036 .05254 L
.28131 .05203 L
.28222 .05154 L
.2832 .05104 L
.28413 .05056 L
.28513 .05006 L
.28609 .04959 L
.28701 .04914 L
.28799 .04866 L
.28894 .04822 L
.28985 .04779 L
.29082 .04735 L
.29175 .04692 L
.29274 .04648 L
.2937 .04606 L
.29462 .04566 L
.29559 .04523 L
.29653 .04483 L
.29753 .04441 L
.2985 .04401 L
.29942 .04363 L
.30041 .04323 L
.30136 .04284 L
.30227 .04248 L
.30324 .04209 L
.30418 .04173 L
.30517 .04134 L
.30613 .04098 L
.30705 .04063 L
.30803 .04026 L
.30898 .03991 L
.30988 .03957 L
Mistroke
.31085 .03922 L
.31178 .03888 L
.31277 .03853 L
.31372 .03819 L
.31464 .03787 L
.31561 .03753 L
.31655 .0372 L
.31755 .03686 L
.31851 .03654 L
.31944 .03623 L
.32042 .0359 L
.32137 .03559 L
.32228 .03529 L
.32325 .03497 L
.32418 .03467 L
.32517 .03436 L
.32613 .03406 L
.32705 .03377 L
.32803 .03347 L
.32897 .03318 L
.32997 .03287 L
.33093 .03258 L
.33186 .03231 L
.33285 .03201 L
.3338 .03173 L
.33471 .03147 L
.33569 .03119 L
.33662 .03092 L
.33762 .03064 L
.33858 .03037 L
.3395 .03011 L
.34048 .02984 L
.34143 .02958 L
.34234 .02934 L
.3433 .02908 L
.34424 .02883 L
.34523 .02857 L
.34618 .02832 L
.3471 .02808 L
.34807 .02783 L
.34901 .02759 L
.35001 .02734 L
.35097 .0271 L
.3519 .02687 L
.35289 .02662 L
.35383 .02639 L
.35475 .02617 L
.35572 .02594 L
.35665 .02572 L
.35765 .02548 L
Mistroke
.3586 .02526 L
.35952 .02505 L
.3605 .02482 L
.36145 .02461 L
.36235 .0244 L
.36332 .02419 L
.36425 .02398 L
.36524 .02376 L
.36619 .02356 L
.3671 .02336 L
.36808 .02315 L
.36902 .02295 L
.37001 .02274 L
.37097 .02254 L
.3719 .02235 L
.37288 .02215 L
.37383 .02196 L
.37474 .02178 L
.37571 .02158 L
.37664 .0214 L
.37763 .0212 L
.37858 .02102 L
.3795 .02084 L
.38048 .02066 L
.38142 .02048 L
.38242 .02029 L
.38339 .02011 L
.38431 .01994 L
.3853 .01976 L
.38625 .01959 L
.38716 .01942 L
.38813 .01925 L
.38907 .01909 L
.39007 .01891 L
.39102 .01875 L
.39195 .01859 L
.39293 .01842 L
.39387 .01826 L
.39478 .01811 L
.39575 .01795 L
.39668 .0178 L
.39767 .01764 L
.39862 .01748 L
.39954 .01733 L
.40051 .01718 L
.40145 .01703 L
.40245 .01688 L
.40341 .01673 L
.40434 .01659 L
.40456 .01655 L
Mistroke
.4048 .01651 L
.40488 .01651 L
.40494 .0165 L
.40501 .01649 L
.40507 .01649 L
.40513 .01648 L
.40519 .01648 L
.40522 .01648 L
.40525 .01648 L
.40527 .01648 L
.40528 .01648 L
.4053 .01648 L
.40532 .01648 L
.40535 .01648 L
.40538 .01648 L
.40541 .01648 L
.40543 .01648 L
.40546 .01648 L
.4055 .01648 L
.40555 .01649 L
.40566 .01649 L
.40577 .0165 L
.4059 .01652 L
.40603 .01654 L
.40627 .01658 L
.40678 .0167 L
.40726 .01686 L
.40818 .01724 L
.40915 .01772 L
.41009 .01824 L
.41109 .01882 L
.41206 .01939 L
.41298 .01993 L
.41397 .02049 L
.41492 .02101 L
.41583 .02148 L
.4168 .02195 L
.41774 .02237 L
.41873 .02278 L
.41969 .02313 L
.42061 .02344 L
.42159 .02373 L
.42253 .02398 L
.42344 .02418 L
.42441 .02437 L
.42534 .02453 L
.42632 .02466 L
.42728 .02477 L
.42819 .02484 L
.4287 .02488 L
Mistroke
.42917 .02491 L
.42966 .02493 L
.43011 .02494 L
.43057 .02496 L
.43081 .02496 L
.43094 .02496 L
.43107 .02496 L
.43118 .02496 L
.43129 .02497 L
.43136 .02497 L
.43142 .02497 L
.43148 .02497 L
.43151 .02497 L
.43154 .02497 L
.43156 .02497 L
.43159 .02497 L
.43162 .02497 L
.43165 .02497 L
.43167 .02497 L
.4317 .02497 L
.43173 .02497 L
.43175 .02497 L
.43178 .02497 L
.43181 .02497 L
.43184 .02497 L
.43187 .02497 L
.43192 .02497 L
.43198 .02497 L
.4321 .02497 L
.43222 .02496 L
.43244 .02496 L
.43268 .02496 L
.43294 .02495 L
.43342 .02494 L
.43392 .02493 L
.43492 .02488 L
.43588 .02483 L
.43681 .02477 L
.43779 .02469 L
.43874 .02461 L
.43965 .02452 L
.44062 .02442 L
.44156 .02432 L
.44255 .02421 L
.44351 .02408 L
.44443 .02392 L
.44541 .02372 L
.44635 .0235 L
.44726 .02327 L
.44822 .02301 L
Mistroke
.44915 .02276 L
.45014 .02248 L
.45109 .02221 L
.45201 .02196 L
.45298 .02168 L
.45392 .02143 L
.45491 .02115 L
.45587 .0209 L
.4568 .02066 L
.45778 .0204 L
.45873 .02017 L
.45964 .01994 L
.4606 .01971 L
.46154 .01949 L
.46253 .01927 L
.46348 .01906 L
.4644 .01886 L
.46538 .01865 L
.46632 .01845 L
.46732 .01825 L
.46828 .01806 L
.46921 .01788 L
.4702 .01769 L
.47115 .01752 L
.47206 .01735 L
.47303 .01718 L
.47397 .01701 L
.47496 .01684 L
.47592 .01668 L
.47684 .01653 L
.47782 .01637 L
.47877 .01621 L
.47967 .01607 L
.48064 .01592 L
.48157 .01577 L
.48256 .01562 L
.48351 .01548 L
.48443 .01534 L
.4854 .0152 L
.48634 .01507 L
.48734 .01492 L
.4883 .01479 L
.48923 .01466 L
.49021 .01452 L
.49116 .01439 L
.49207 .01427 L
.49304 .01414 L
.49397 .01402 L
.49496 .01389 L
.49592 .01377 L
Mistroke
.49684 .01365 L
.49782 .01352 L
.49876 .01341 L
.49967 .01329 L
.50063 .01317 L
.50156 .01306 L
.50255 .01294 L
.5035 .01283 L
.50441 .01272 L
.50539 .01261 L
.50632 .0125 L
.50732 .01238 L
.50828 .01227 L
.5092 .01217 L
.51018 .01206 L
.51113 .01196 L
.51204 .01186 L
.513 .01175 L
.51394 .01165 L
.51493 .01154 L
.51588 .01144 L
.5168 .01135 L
.51777 .01124 L
.51871 .01115 L
.51971 .01105 L
.52068 .01095 L
.5216 .01085 L
.52259 .01076 L
.52354 .01066 L
.52445 .01057 L
.52542 .01048 L
.52635 .01039 L
.52735 .0103 L
.52831 .01021 L
.52923 .01012 L
.53021 .01003 L
.53115 .00994 L
.53206 .00986 L
.53302 .00977 L
.53395 .00969 L
.53494 .0096 L
.53589 .00952 L
.53681 .00944 L
.53778 .00935 L
.53872 .00927 L
.53972 .00919 L
.54068 .00911 L
.5416 .00903 L
.54259 .00895 L
.54353 .00887 L
Mistroke
.54444 .0088 L
.54541 .00872 L
.54634 .00864 L
.54734 .00857 L
.54829 .00849 L
.54921 .00842 L
.55019 .00834 L
.55113 .00827 L
.55213 .0082 L
.55309 .00812 L
.55402 .00806 L
.55501 .00798 L
.55596 .00791 L
.55687 .00785 L
.55784 .00778 L
.55878 .00771 L
.55978 .00764 L
.56073 .00757 L
.56166 .00751 L
.56264 .00744 L
.56358 .00738 L
.56449 .00732 L
.56546 .00725 L
.56639 .00719 L
.56738 .00712 L
.56833 .00706 L
.56925 .007 L
.57022 .00694 L
.57116 .00688 L
.57216 .00682 L
.57312 .00676 L
.57405 .0067 L
.57503 .00664 L
.57598 .00658 L
.57689 .00653 L
.57786 .00647 L
.5788 .00641 L
.57979 .00636 L
.58075 .0063 L
.58167 .00625 L
.58265 .00619 L
.58359 .00614 L
.58449 .00609 L
.58546 .00603 L
.58639 .00598 L
.58738 .00593 L
.58833 .00588 L
.58924 .00583 L
.59022 .00577 L
.59115 .00572 L
Mistroke
.59215 .00567 L
.59311 .00562 L
.59403 .00558 L
.5945 .00555 L
.59501 .00552 L
.59525 .00551 L
.59531 .00551 L
.59538 .00551 L
.59544 .00551 L
.5955 .0055 L
.59556 .0055 L
.59559 .0055 L
.59563 .0055 L
.59566 .0055 L
.59569 .0055 L
.59571 .0055 L
.59574 .0055 L
.59577 .0055 L
.5958 .0055 L
.59582 .0055 L
.59585 .0055 L
.59587 .0055 L
.5959 .0055 L
.59596 .0055 L
.59602 .0055 L
.59608 .00551 L
.59619 .00551 L
.59632 .00551 L
.59644 .00552 L
.59668 .00554 L
.59694 .00556 L
.59786 .00566 L
.59883 .00581 L
.59977 .00599 L
.60077 .00619 L
.60173 .0064 L
.60265 .0066 L
.60364 .00681 L
.60458 .007 L
.60549 .00718 L
.60646 .00737 L
.6074 .00753 L
.60839 .00769 L
.60935 .00783 L
.61027 .00795 L
.61124 .00807 L
.61219 .00817 L
.61319 .00827 L
.61415 .00835 L
.61508 .00841 L
Mistroke
.61607 .00847 L
.61702 .00852 L
.61793 .00856 L
.6189 .00859 L
.61984 .00861 L
.62035 .00862 L
.62083 .00863 L
.62107 .00863 L
.62131 .00863 L
.62155 .00863 L
.62176 .00863 L
.62198 .00864 L
.62211 .00864 L
.62223 .00864 L
.62228 .00864 L
.62234 .00864 L
.62238 .00864 L
.62244 .00864 L
.62247 .00864 L
.6225 .00864 L
.62253 .00864 L
.62256 .00864 L
.62258 .00864 L
.62261 .00864 L
.62264 .00864 L
.62267 .00864 L
.6227 .00864 L
.62273 .00864 L
.62279 .00864 L
.62285 .00864 L
.62291 .00864 L
.62304 .00864 L
.62318 .00864 L
.62343 .00863 L
.62366 .00863 L
.62411 .00863 L
.62461 .00862 L
.62559 .00861 L
.62652 .00859 L
.62752 .00857 L
.62848 .00855 L
.6294 .00852 L
.63039 .00849 L
.63133 .00845 L
.63224 .00842 L
.63321 .00838 L
.63414 .00834 L
.63514 .00828 L
.63609 .0082 L
.63701 .00813 L
Mistroke
.63799 .00804 L
.63893 .00795 L
.63993 .00786 L
.64089 .00776 L
.64182 .00767 L
.64281 .00757 L
.64375 .00748 L
.64467 .00739 L
.64564 .0073 L
.64658 .00721 L
.64757 .00712 L
.64853 .00704 L
.64945 .00696 L
.65043 .00688 L
.65138 .0068 L
.65228 .00672 L
.65325 .00665 L
.65418 .00658 L
.65517 .0065 L
.65612 .00643 L
.65704 .00637 L
.65802 .0063 L
.65895 .00623 L
.65995 .00617 L
.66091 .0061 L
.66184 .00604 L
.66282 .00598 L
.66377 .00592 L
.66468 .00587 L
.66565 .00581 L
.66659 .00576 L
.66758 .0057 L
.66853 .00564 L
.66945 .00559 L
.67043 .00554 L
.67138 .00549 L
.67228 .00544 L
.67325 .00539 L
.67418 .00534 L
.67516 .00529 L
.67611 .00524 L
.67703 .0052 L
.678 .00515 L
.67894 .0051 L
.67993 .00506 L
.68089 .00501 L
.68182 .00497 L
.6828 .00492 L
.68374 .00488 L
.68465 .00484 L
Mistroke
.68562 .00479 L
.68655 .00475 L
.68754 .00471 L
.6885 .00467 L
.68942 .00463 L
.69039 .00458 L
.69133 .00454 L
.69233 .0045 L
.6933 .00446 L
.69422 .00442 L
.69521 .00438 L
.69616 .00435 L
.69707 .00431 L
.69804 .00427 L
.69897 .00423 L
.69997 .0042 L
.70093 .00416 L
.70185 .00412 L
.70283 .00409 L
.70377 .00405 L
.70468 .00402 L
.70564 .00398 L
.70657 .00395 L
.70756 .00391 L
.70851 .00388 L
.70943 .00384 L
.71041 .00381 L
.71134 .00378 L
.71234 .00374 L
.7133 .00371 L
.71423 .00368 L
.71521 .00365 L
.71616 .00361 L
.71707 .00358 L
.71804 .00355 L
.71897 .00352 L
.71996 .00349 L
.72092 .00346 L
.72184 .00343 L
.72281 .0034 L
.72375 .00337 L
.72476 .00334 L
.72572 .00331 L
.72665 .00328 L
.72763 .00325 L
.72858 .00322 L
.7295 .0032 L
.73047 .00317 L
.73141 .00314 L
.7324 .00311 L
Mistroke
.73336 .00308 L
.73428 .00306 L
.73526 .00303 L
.73621 .003 L
.73712 .00298 L
.73808 .00295 L
.73902 .00293 L
.74001 .0029 L
.74096 .00288 L
.74188 .00285 L
.74285 .00283 L
.74379 .0028 L
.74479 .00278 L
.74575 .00275 L
.74668 .00273 L
.74766 .0027 L
.74861 .00268 L
.74952 .00266 L
.75049 .00263 L
.75143 .00261 L
.75242 .00259 L
.75338 .00257 L
.7543 .00254 L
.75528 .00252 L
.75622 .0025 L
.75712 .00248 L
.75809 .00246 L
.75902 .00244 L
.76001 .00241 L
.76096 .00239 L
.76187 .00237 L
.76285 .00235 L
.76378 .00233 L
.76478 .00231 L
.76574 .00229 L
.76666 .00227 L
.76765 .00225 L
.76859 .00223 L
.7695 .00221 L
.77047 .00219 L
.7714 .00217 L
.77239 .00215 L
.77335 .00214 L
.77427 .00212 L
.77525 .0021 L
.77619 .00208 L
.77719 .00206 L
.77815 .00204 L
.77908 .00203 L
.78006 .00201 L
Mistroke
.78101 .00199 L
.78192 .00197 L
.7829 .00196 L
.78383 .00194 L
.78483 .00192 L
.78532 .00191 L
.78554 .00191 L
.78566 .00191 L
.78578 .0019 L
.78584 .0019 L
.7859 .0019 L
.78596 .0019 L
.78601 .0019 L
.78606 .0019 L
.78609 .0019 L
.78612 .0019 L
.78615 .0019 L
.78618 .0019 L
.7862 .0019 L
.78623 .0019 L
.78626 .0019 L
.78629 .0019 L
.78632 .0019 L
.78634 .0019 L
.7864 .0019 L
.78646 .0019 L
.78658 .0019 L
.78671 .0019 L
.78695 .00191 L
.78718 .00191 L
.78768 .00193 L
.78815 .00195 L
.78865 .00197 L
.78964 .00203 L
.79059 .0021 L
.7915 .00216 L
.79247 .00224 L
.79341 .00231 L
.79441 .00238 L
.79536 .00245 L
.79629 .00252 L
.79727 .00258 L
.79821 .00264 L
.79912 .00269 L
.80009 .00274 L
.80102 .00278 L
.80201 .00282 L
.80297 .00285 L
.80388 .00288 L
.80486 .00291 L
Mistroke
.8058 .00293 L
.8068 .00295 L
.80776 .00297 L
.80869 .00298 L
.80967 .00299 L
.81016 .003 L
.81062 .003 L
.81109 .003 L
.81153 .003 L
.81177 .00301 L
.81202 .00301 L
.81225 .00301 L
.81247 .00301 L
.81259 .00301 L
.81269 .00301 L
.81281 .00301 L
.81288 .00301 L
.81294 .00301 L
.813 .00301 L
.81304 .00301 L
.81307 .00301 L
.8131 .00301 L
.81313 .00301 L
.81316 .00301 L
.81319 .00301 L
.81322 .00301 L
.81325 .00301 L
.81328 .00301 L
.81331 .00301 L
.81338 .00301 L
.81345 .00301 L
.81356 .00301 L
.81369 .00301 L
.81391 .00301 L
.81417 .00301 L
.8144 .00301 L
.81487 .003 L
.81537 .003 L
.81635 .003 L
.8173 .00299 L
.81822 .00298 L
.81919 .00297 L
.82013 .00296 L
.82112 .00295 L
.82208 .00294 L
.823 .00293 L
.82398 .00292 L
.82493 .0029 L
.82583 .00288 L
.8268 .00285 L
Mistroke
.82773 .00282 L
.82872 .00279 L
.82968 .00276 L
.83059 .00273 L
.83157 .0027 L
.83251 .00266 L
.8335 .00263 L
.83447 .0026 L
.83539 .00257 L
.83638 .00253 L
.83732 .0025 L
.83824 .00247 L
.83921 .00245 L
.84014 .00242 L
.84113 .00239 L
.84209 .00236 L
.84301 .00233 L
.84399 .00231 L
.84493 .00228 L
.84584 .00226 L
.8468 .00223 L
.84773 .00221 L
.84872 .00219 L
.84967 .00216 L
.85058 .00214 L
.85156 .00212 L
.85249 .0021 L
.85349 .00208 L
.85445 .00206 L
.85537 .00204 L
.85636 .00202 L
.8573 .002 L
.85821 .00198 L
.85918 .00196 L
.86011 .00194 L
.8611 .00193 L
.86206 .00191 L
.86297 .00189 L
.86395 .00187 L
.86489 .00186 L
.86589 .00184 L
.86685 .00182 L
.86778 .0018 L
.86877 .00179 L
.86972 .00177 L
.87063 .00176 L
.8716 .00174 L
.87253 .00173 L
.87353 .00171 L
.87449 .00169 L
Mistroke
.87541 .00168 L
.87639 .00166 L
.87733 .00165 L
.87824 .00164 L
.87921 .00162 L
.88014 .00161 L
.88112 .00159 L
.88208 .00158 L
.88299 .00156 L
.88397 .00155 L
.88491 .00154 L
.8859 .00152 L
.88686 .00151 L
.88779 .0015 L
.88877 .00148 L
.88972 .00147 L
.89063 .00146 L
.8916 .00144 L
.89253 .00143 L
.89352 .00142 L
.89448 .00141 L
.8954 .0014 L
.89638 .00138 L
.89732 .00137 L
.89832 .00136 L
.89928 .00135 L
.90021 .00133 L
.9012 .00132 L
.90215 .00131 L
.90306 .0013 L
.90404 .00129 L
.90497 .00128 L
.90597 .00127 L
.90693 .00125 L
.90785 .00124 L
.90883 .00123 L
.90978 .00122 L
.91068 .00121 L
.91165 .0012 L
.91258 .00119 L
.91357 .00118 L
.91453 .00117 L
.91544 .00116 L
.91642 .00115 L
.91736 .00114 L
.91836 .00113 L
.91932 .00112 L
.92025 .00111 L
.92123 .0011 L
.92218 .00109 L
Mistroke
.92309 .00108 L
.92406 .00107 L
.925 .00106 L
.92599 .00105 L
.92695 .00104 L
.92787 .00103 L
.92885 .00103 L
.92979 .00102 L
.9307 .00101 L
.93166 .001 L
.93259 .00099 L
.93358 .00098 L
.93453 .00097 L
.93545 .00097 L
.93642 .00096 L
.93736 .00095 L
.93835 .00094 L
.93931 .00093 L
.94024 .00092 L
.94122 .00092 L
.94217 .00091 L
.94308 .0009 L
.94405 .00089 L
.94498 .00088 L
.94597 .00088 L
.94692 .00087 L
.94784 .00086 L
.94882 .00085 L
.94976 .00085 L
.95076 .00084 L
.95172 .00083 L
.95265 .00082 L
.95364 .00082 L
.95459 .00081 L
.9555 .0008 L
.95647 .0008 L
.95741 .00079 L
.9584 .00078 L
.95936 .00077 L
.96028 .00077 L
.96126 .00076 L
.96221 .00075 L
.96311 .00075 L
.96408 .00074 L
.96501 .00074 L
.966 .00073 L
.96695 .00072 L
.96787 .00072 L
.96885 .00071 L
.96978 .0007 L
Mistroke
.97078 .0007 L
.97174 .00069 L
.97267 .00069 L
.97365 .00068 L
.9746 .00067 L
.97551 .00067 L
.97619 .00066 L
Mfstroke
.5 Mabswid
.02381 0 m
.02474 .11046 L
.02575 .21061 L
.0267 .28844 L
.02761 .35082 L
.02859 .40591 L
.02952 .44965 L
.03052 .48777 L
.03148 .51764 L
.0324 .54106 L
.03338 .56116 L
.03433 .57657 L
.03524 .58833 L
.03621 .59809 L
.03714 .60521 L
.03761 .60809 L
.03813 .61074 L
.03908 .61441 L
.03956 .61571 L
.04006 .61676 L
.04031 .61716 L
.04057 .61751 L
.04083 .61777 L
.04106 .61794 L
.04117 .61801 L
s
.04117 .61801 m
.04122 .61803 L
s
.04226 .61803 m
.04247 .61792 L
.04271 .61775 L
.04298 .61752 L
.04345 .61697 L
.04395 .61623 L
.04495 .61435 L
.04592 .61208 L
.04684 .60956 L
.04783 .60658 L
.04878 .60347 L
.04969 .60029 L
.05067 .59676 L
.0516 .59324 L
.0526 .58939 L
.05356 .58561 L
.05448 .58192 L
.05546 .57794 L
.0564 .57409 L
.05731 .57037 L
.05828 .5664 L
.05921 .56257 L
.0602 .5585 L
.06115 .55459 L
.06207 .55084 L
.06305 .54687 L
.06398 .54304 L
.06498 .53897 L
.06594 .53504 L
.06687 .53125 L
.06785 .52721 L
.0688 .52331 L
.06971 .51955 L
.07068 .51554 L
.07162 .51167 L
.07261 .50755 L
.07357 .50357 L
.07449 .49975 L
.07547 .49568 L
.07641 .49177 L
.07731 .48801 L
.07828 .48402 L
.07921 .48018 L
.0802 .47611 L
.08115 .4722 L
.08206 .46845 L
.08304 .46448 L
.08397 .46068 L
.08497 .45665 L
.08593 .45279 L
Mistroke
.08685 .44909 L
.08783 .44518 L
.08878 .44144 L
.08969 .43786 L
.09066 .43408 L
.09159 .43046 L
.09258 .42663 L
.09354 .42298 L
.09445 .41948 L
.09543 .41579 L
.09637 .41226 L
.09737 .40854 L
.09833 .40498 L
.09926 .40158 L
.10025 .39799 L
.10119 .39457 L
.10211 .3913 L
.10308 .38784 L
.10401 .38455 L
.10501 .38107 L
.10597 .37775 L
.10689 .37458 L
.10787 .37123 L
.10881 .36804 L
.10972 .36499 L
.11069 .36177 L
.11162 .3587 L
.1126 .35547 L
.11356 .35238 L
.11447 .34943 L
.11545 .34632 L
.11639 .34335 L
.11738 .34022 L
.11834 .33723 L
.11927 .33438 L
.12025 .33137 L
.1212 .3285 L
.12211 .32576 L
.12308 .32288 L
.12401 .32012 L
.125 .31721 L
.12596 .31444 L
.12688 .3118 L
.12786 .309 L
.1288 .30634 L
.1298 .30354 L
.13076 .30086 L
.13169 .2983 L
.13268 .29561 L
.13363 .29304 L
Mistroke
.13454 .29059 L
.13552 .288 L
.13645 .28553 L
.13745 .28293 L
.13841 .28044 L
.13933 .27807 L
.14031 .27558 L
.14126 .27319 L
.14217 .27092 L
.14313 .26852 L
.14406 .26623 L
.14505 .26382 L
.14601 .26151 L
.14693 .25932 L
.1479 .257 L
.14884 .25479 L
.14984 .25246 L
.1508 .25023 L
.15173 .24811 L
.15271 .24587 L
.15366 .24374 L
.15457 .2417 L
.15554 .23955 L
.15648 .2375 L
.15747 .23534 L
.15843 .23328 L
.15935 .23132 L
.16033 .22924 L
.16127 .22726 L
.16218 .22537 L
.16314 .22338 L
.16407 .22148 L
.16506 .21948 L
.16601 .21756 L
.16693 .21574 L
.1679 .21382 L
.16884 .21198 L
.16984 .21005 L
.1708 .2082 L
.17172 .20644 L
.1727 .20458 L
.17365 .20281 L
.17456 .20112 L
.17553 .19933 L
.17646 .19763 L
.17745 .19584 L
.17841 .19412 L
.17933 .19249 L
.1803 .19077 L
.18124 .18912 L
Mistroke
.18224 .18739 L
.18321 .18574 L
.18413 .18416 L
.18512 .1825 L
.18607 .18091 L
.18698 .1794 L
.18796 .1778 L
.18889 .17628 L
.18989 .17467 L
.19084 .17314 L
.19177 .17168 L
.19275 .17014 L
.19369 .16867 L
.1946 .16726 L
.19557 .16578 L
.1965 .16437 L
.19748 .16288 L
.19844 .16146 L
.19935 .16011 L
.20033 .15868 L
.20127 .15731 L
.20227 .15587 L
.20323 .1545 L
.20415 .15319 L
.20514 .15181 L
.20608 .15049 L
.207 .14924 L
.20797 .14791 L
.2089 .14665 L
.20989 .14532 L
.21085 .14404 L
.21177 .14283 L
.21275 .14155 L
.21369 .14033 L
.21459 .13916 L
.21556 .13796 L
.21649 .13687 L
.21748 .13583 L
.21843 .13497 L
.21934 .13427 L
.22031 .13367 L
.22125 .13325 L
.22176 .13307 L
.22225 .13294 L
.22248 .13289 L
.22273 .13285 L
.22296 .13281 L
.22317 .13279 L
.2234 .13277 L
.22352 .13276 L
Mistroke
.22358 .13276 L
.22364 .13276 L
.2237 .13275 L
.22375 .13275 L
.2238 .13275 L
.22382 .13275 L
.22385 .13275 L
.22388 .13275 L
.22391 .13275 L
.22393 .13275 L
.22396 .13275 L
.22399 .13275 L
.22402 .13275 L
.22405 .13275 L
.22408 .13275 L
.22414 .13275 L
.22419 .13275 L
.22431 .13276 L
.22443 .13276 L
.22456 .13277 L
.22479 .13279 L
.225 .13282 L
.22545 .13288 L
.22595 .13298 L
.22693 .13324 L
.22786 .13357 L
.22886 .13398 L
.22982 .13443 L
.23075 .1349 L
.23173 .13544 L
.23268 .13598 L
.23359 .1365 L
.23456 .13707 L
.23549 .13761 L
.23648 .13818 L
.23744 .13872 L
.23836 .13922 L
.23933 .13973 L
.24028 .14019 L
.24128 .14065 L
.24224 .14106 L
.24317 .14142 L
.24415 .14177 L
.2451 .14207 L
.24602 .14232 L
.24699 .14255 L
.24793 .14274 L
.24892 .14289 L
.24942 .14296 L
.24988 .143 L
Mistroke
.25036 .14304 L
.2508 .14307 L
.25104 .14309 L
.25125 .1431 L
.25149 .1431 L
.25162 .14311 L
.25175 .14311 L
.25181 .14311 L
.25187 .14311 L
.25192 .14311 L
.25198 .14311 L
.25201 .14311 L
.25204 .14311 L
.25207 .14311 L
.25209 .14311 L
.25211 .14311 L
.25213 .14311 L
.25214 .14311 L
.25216 .14311 L
.25218 .14311 L
.25219 .14311 L
.25222 .14311 L
.25225 .14311 L
.25227 .14311 L
.2523 .14311 L
.25233 .14311 L
.25238 .14311 L
.25243 .14311 L
.25255 .14311 L
.25266 .14311 L
.25279 .14311 L
.25292 .1431 L
.25316 .14309 L
.25339 .14308 L
.2536 .14307 L
.25405 .14303 L
.25455 .14298 L
.25552 .14284 L
.25645 .14265 L
.25744 .14238 L
.25839 .14206 L
.25931 .14171 L
.26029 .14127 L
.26123 .1408 L
.26223 .14024 L
.26319 .13965 L
.26412 .13904 L
.26511 .13836 L
.26605 .13766 L
.26697 .13695 L
Mistroke
.26794 .13616 L
.26887 .13538 L
.26987 .13452 L
.27083 .13367 L
.27175 .13283 L
.27273 .13192 L
.27367 .13102 L
.27458 .13015 L
.27555 .12921 L
.27648 .12829 L
.27747 .12731 L
.27842 .12636 L
.27933 .12543 L
.28031 .12445 L
.28125 .12349 L
.28225 .12248 L
.28321 .1215 L
.28413 .12055 L
.28512 .11955 L
.28606 .11858 L
.28697 .11766 L
.28794 .11667 L
.28888 .11573 L
.28987 .11473 L
.29083 .11377 L
.29174 .11285 L
.29272 .11188 L
.29367 .11095 L
.29467 .10996 L
.29563 .10902 L
.29656 .10811 L
.29755 .10716 L
.2985 .10625 L
.29941 .10538 L
.30038 .10445 L
.30132 .10357 L
.30232 .10264 L
.30327 .10175 L
.3042 .1009 L
.30518 .10001 L
.30612 .09915 L
.30703 .09833 L
.308 .09747 L
.30893 .09665 L
.30992 .09578 L
.31088 .09494 L
.31179 .09415 L
.31277 .09331 L
.31371 .09252 L
.31471 .09167 L
Mistroke
.31567 .09087 L
.3166 .0901 L
.31758 .08929 L
.31853 .08852 L
.31944 .08778 L
.32041 .087 L
.32135 .08626 L
.32234 .08548 L
.3233 .08473 L
.32422 .08402 L
.3252 .08326 L
.32614 .08255 L
.32705 .08186 L
.32802 .08114 L
.32894 .08045 L
.32993 .07972 L
.33088 .07903 L
.3318 .07836 L
.33277 .07767 L
.33371 .077 L
.33471 .0763 L
.33567 .07563 L
.33659 .07499 L
.33758 .07431 L
.33852 .07367 L
.33943 .07306 L
.3404 .07241 L
.34133 .07179 L
.34233 .07114 L
.34328 .07052 L
.3442 .06992 L
.34518 .0693 L
.34612 .0687 L
.34712 .06807 L
.34808 .06747 L
.34901 .0669 L
.35 .06629 L
.35095 .06572 L
.35186 .06517 L
.35283 .06459 L
.35377 .06403 L
.35476 .06345 L
.35572 .06289 L
.35664 .06236 L
.35762 .0618 L
.35857 .06127 L
.35948 .06076 L
.36044 .06022 L
.36137 .05971 L
.36236 .05917 L
Mistroke
.36332 .05865 L
.36423 .05816 L
.36521 .05764 L
.36615 .05714 L
.36715 .05662 L
.36811 .05612 L
.36903 .05565 L
.37002 .05514 L
.37096 .05467 L
.37188 .05421 L
.37285 .05373 L
.37378 .05327 L
.37477 .05278 L
.37573 .05232 L
.37665 .05188 L
.37763 .05142 L
.37857 .05097 L
.37948 .05055 L
.38044 .0501 L
.38137 .04968 L
.38236 .04923 L
.38331 .0488 L
.38422 .04839 L
.3852 .04796 L
.38613 .04755 L
.38713 .04711 L
.38809 .0467 L
.38901 .0463 L
.38999 .04589 L
.39094 .04549 L
.39185 .04511 L
.39282 .04471 L
.39375 .04433 L
.39474 .04393 L
.3957 .04354 L
.39661 .04318 L
.39759 .04279 L
.39853 .04242 L
.39953 .04204 L
.40049 .04166 L
.40142 .04131 L
.4024 .04094 L
.40335 .04058 L
.40427 .04024 L
.40524 .03989 L
.40617 .03956 L
.40717 .03924 L
.40812 .03899 L
.40905 .03879 L
.40951 .03871 L
Mistroke
.41003 .03865 L
.41026 .03862 L
.41051 .0386 L
.41075 .03858 L
.41097 .03856 L
.4112 .03855 L
.41132 .03855 L
.41145 .03854 L
.41152 .03854 L
.41159 .03854 L
.41165 .03854 L
.41169 .03854 L
.41172 .03854 L
.41175 .03854 L
.41177 .03854 L
.4118 .03854 L
.41182 .03854 L
.41183 .03854 L
.41186 .03854 L
.41189 .03854 L
.41192 .03854 L
.41194 .03854 L
.41196 .03854 L
.41201 .03854 L
.41205 .03854 L
.41208 .03854 L
.4122 .03854 L
.41231 .03854 L
.41242 .03855 L
.41268 .03856 L
.41292 .03857 L
.41338 .03861 L
.41388 .03866 L
.41486 .0388 L
.41581 .03898 L
.41672 .03918 L
.41768 .03943 L
.41861 .0397 L
.4196 .04001 L
.42056 .04033 L
.42148 .04065 L
.42245 .041 L
.42339 .04135 L
.42439 .04171 L
.42535 .04207 L
.42628 .04241 L
.42726 .04276 L
.42821 .04309 L
.42912 .0434 L
.43009 .04372 L
Mistroke
.43103 .04402 L
.43202 .04432 L
.43298 .04459 L
.4339 .04484 L
.43488 .04509 L
.43582 .04532 L
.43673 .04552 L
.43769 .04571 L
.43862 .04588 L
.43961 .04605 L
.44056 .04619 L
.44148 .04631 L
.44245 .04642 L
.44339 .04651 L
.44438 .04659 L
.44488 .04662 L
.44534 .04664 L
.44579 .04666 L
.44602 .04667 L
.44627 .04667 L
.44639 .04667 L
.44651 .04668 L
.44662 .04668 L
.44668 .04668 L
.44673 .04668 L
.44677 .04668 L
.4468 .04668 L
.44683 .04668 L
.44686 .04668 L
.44689 .04668 L
.44691 .04668 L
.44693 .04668 L
.44696 .04668 L
.44698 .04668 L
.44699 .04668 L
.44703 .04668 L
.44705 .04668 L
.44709 .04668 L
.44712 .04668 L
.44717 .04668 L
.44724 .04668 L
.44735 .04668 L
.44748 .04668 L
.4477 .04667 L
.44794 .04667 L
.4482 .04666 L
.44867 .04664 L
.44918 .04661 L
.45018 .04654 L
.45114 .04645 L
Mistroke
.45206 .04634 L
.45305 .0462 L
.45399 .04605 L
.4549 .04589 L
.45587 .0457 L
.45681 .0455 L
.4578 .04527 L
.45876 .04504 L
.45968 .04481 L
.46065 .04455 L
.4616 .04429 L
.4625 .04403 L
.46347 .04375 L
.4644 .04347 L
.46538 .04317 L
.46633 .04288 L
.46725 .04259 L
.46822 .04228 L
.46916 .04197 L
.47015 .04165 L
.47111 .04133 L
.47204 .04103 L
.47302 .0407 L
.47396 .04039 L
.47487 .04008 L
.47584 .03976 L
.47677 .03945 L
.47776 .03912 L
.47872 .0388 L
.47963 .03849 L
.48061 .03817 L
.48155 .03786 L
.48255 .03753 L
.48351 .03721 L
.48444 .03691 L
.48542 .03659 L
.48637 .03628 L
.48728 .03598 L
.48826 .03567 L
.48919 .03538 L
.49018 .03506 L
.49114 .03476 L
.49206 .03447 L
.49304 .03417 L
.49399 .03388 L
.49489 .0336 L
.49586 .03331 L
.49679 .03303 L
.49778 .03273 L
.49873 .03245 L
Mistroke
.49964 .03218 L
.50062 .0319 L
.50156 .03162 L
.50255 .03134 L
.50351 .03106 L
.50444 .0308 L
.50542 .03053 L
.50637 .03026 L
.50728 .03001 L
.50825 .02975 L
.50918 .02949 L
.51017 .02923 L
.51113 .02897 L
.51205 .02873 L
.51302 .02847 L
.51397 .02823 L
.51497 .02797 L
.51593 .02772 L
.51686 .02749 L
.51784 .02724 L
.51879 .027 L
.51971 .02678 L
.52068 .02654 L
.52162 .02631 L
.52261 .02607 L
.52357 .02584 L
.52449 .02563 L
.52547 .0254 L
.52642 .02518 L
.52733 .02497 L
.52829 .02475 L
.52922 .02453 L
.53021 .02431 L
.53117 .0241 L
.53208 .0239 L
.53306 .02368 L
.534 .02348 L
.535 .02327 L
.53596 .02306 L
.53688 .02287 L
.53787 .02266 L
.53882 .02246 L
.53973 .02228 L
.5407 .02208 L
.54163 .02189 L
.54263 .02169 L
.54358 .0215 L
.5445 .02132 L
.54548 .02113 L
.54642 .02095 L
Mistroke
.54733 .02077 L
.54829 .02059 L
.54922 .02041 L
.55021 .02023 L
.55116 .02005 L
.55208 .01988 L
.55305 .01971 L
.55399 .01954 L
.55498 .01936 L
.55594 .01919 L
.55687 .01903 L
.55785 .01886 L
.5588 .01869 L
.55971 .01854 L
.56067 .01837 L
.56161 .01822 L
.5626 .01805 L
.56355 .01789 L
.56447 .01774 L
.56545 .01758 L
.56639 .01743 L
.56739 .01727 L
.56835 .01712 L
.56928 .01698 L
.57026 .01682 L
.57121 .01668 L
.57212 .01654 L
.5731 .01639 L
.57403 .01625 L
.57503 .0161 L
.57598 .01596 L
.5769 .01583 L
.57788 .01568 L
.57883 .01555 L
.57974 .01542 L
.5807 .01528 L
.58163 .01515 L
.58262 .01501 L
.58357 .01488 L
.58449 .01476 L
.58546 .01463 L
.5864 .0145 L
.5874 .01437 L
.58836 .01424 L
.58929 .01412 L
.59027 .01399 L
.59122 .01387 L
.59213 .01376 L
.5931 .01364 L
.59403 .01352 L
Mistroke
.59502 .0134 L
.59598 .01328 L
.5969 .01317 L
.59788 .01308 L
.59882 .013 L
.5993 .01297 L
.59982 .01294 L
.60032 .01292 L
.60056 .01291 L
.60078 .0129 L
.60102 .0129 L
.60124 .01289 L
.60135 .01289 L
.60148 .01289 L
.60155 .01289 L
.60161 .01289 L
.60167 .01289 L
.60173 .01289 L
.60176 .01289 L
.60179 .01289 L
.60182 .01289 L
.60185 .01289 L
.60188 .01289 L
.60189 .01289 L
.60191 .01289 L
.60194 .01289 L
.60197 .01289 L
.60199 .01289 L
.60202 .01289 L
.60205 .01289 L
.60208 .01289 L
.60213 .01289 L
.60218 .01289 L
.60225 .01289 L
.60232 .01289 L
.60244 .01289 L
.60268 .01289 L
.6029 .0129 L
.60315 .0129 L
.60366 .01292 L
.60412 .01294 L
.60462 .01296 L
.60561 .01303 L
.60656 .0131 L
.60748 .01319 L
.60845 .01329 L
.60939 .0134 L
.61039 .01352 L
.61135 .01365 L
.61227 .01377 L
Mistroke
.61326 .01391 L
.6142 .01404 L
.61511 .01417 L
.61608 .0143 L
.61701 .01443 L
.618 .01456 L
.61896 .01469 L
.61988 .01481 L
.62086 .01493 L
.6218 .01504 L
.6228 .01516 L
.62376 .01526 L
.62469 .01536 L
.62567 .01545 L
.62662 .01554 L
.62754 .01561 L
.62851 .01569 L
.62944 .01575 L
.63044 .01582 L
.6314 .01587 L
.63232 .01592 L
.6333 .01596 L
.63424 .016 L
.63515 .01603 L
.63566 .01604 L
.63612 .01605 L
.63657 .01606 L
.6368 .01606 L
.63705 .01606 L
.6373 .01606 L
.63752 .01607 L
.63763 .01607 L
.63769 .01607 L
.63775 .01607 L
.6378 .01607 L
.63786 .01607 L
.63789 .01607 L
.63792 .01607 L
.63794 .01607 L
.63797 .01607 L
.638 .01607 L
.63801 .01607 L
.63803 .01607 L
.63804 .01607 L
.63806 .01607 L
.63809 .01607 L
.63812 .01607 L
.63815 .01607 L
.63818 .01607 L
.63821 .01607 L
Mistroke
.63828 .01607 L
.63835 .01607 L
.63848 .01607 L
.6386 .01607 L
.63871 .01607 L
.63896 .01606 L
.63919 .01606 L
.63941 .01606 L
.6399 .01605 L
.64039 .01604 L
.64084 .01603 L
.64179 .016 L
.64271 .01597 L
.64368 .01592 L
.64462 .01587 L
.64562 .01581 L
.64659 .01575 L
.64751 .01568 L
.6485 .01561 L
.64945 .01553 L
.65036 .01545 L
.65133 .01536 L
.65227 .01527 L
.65326 .01518 L
.65422 .01508 L
.65514 .01499 L
.65612 .01488 L
.65706 .01478 L
.65797 .01468 L
.65894 .01458 L
.65987 .01447 L
.66085 .01436 L
.66181 .01425 L
.66272 .01415 L
.6637 .01404 L
.66463 .01393 L
.66563 .01382 L
.66659 .01371 L
.66752 .0136 L
.6685 .01349 L
.66945 .01338 L
.67036 .01327 L
.67133 .01316 L
.67226 .01306 L
.67325 .01294 L
.67421 .01283 L
.67513 .01273 L
.6761 .01262 L
.67705 .01252 L
.67805 .0124 L
Mistroke
.67901 .0123 L
.67994 .0122 L
.68092 .01209 L
.68188 .01199 L
.68279 .01189 L
.68376 .01178 L
.6847 .01168 L
.68569 .01158 L
.68665 .01148 L
.68757 .01138 L
.68856 .01128 L
.6895 .01118 L
.69041 .01109 L
.69138 .011 L
.69231 .0109 L
.6933 .0108 L
.69425 .01071 L
.69517 .01062 L
.69614 .01053 L
.69708 .01044 L
.69808 .01034 L
.69904 .01025 L
.69997 .01016 L
.70095 .01007 L
.7019 .00999 L
.70281 .0099 L
.70378 .00981 L
.70472 .00973 L
.70571 .00964 L
.70667 .00956 L
.70759 .00948 L
.70857 .00939 L
.70951 .00931 L
.71042 .00924 L
.71138 .00915 L
.71231 .00908 L
.7133 .00899 L
.71425 .00892 L
.71517 .00884 L
.71614 .00876 L
.71708 .00869 L
.71807 .00861 L
.71903 .00853 L
.71996 .00846 L
.72094 .00838 L
.72189 .00831 L
.72279 .00824 L
.72376 .00817 L
.7247 .0081 L
.72569 .00803 L
Mistroke
.72664 .00796 L
.72756 .00789 L
.72854 .00782 L
.72948 .00775 L
.73048 .00768 L
.73144 .00761 L
.73237 .00755 L
.73335 .00748 L
.7343 .00741 L
.73522 .00735 L
.73619 .00729 L
.73712 .00722 L
.73812 .00716 L
.73908 .0071 L
.74 .00704 L
.74098 .00697 L
.74192 .00691 L
.74283 .00686 L
.7438 .00679 L
.74473 .00674 L
.74571 .00668 L
.74667 .00662 L
.74758 .00656 L
.74856 .0065 L
.7495 .00645 L
.7505 .00639 L
.75146 .00633 L
.75238 .00628 L
.75337 .00622 L
.75431 .00617 L
.75522 .00612 L
.75619 .00606 L
.75713 .00601 L
.75812 .00596 L
.75908 .0059 L
.75999 .00585 L
.76097 .0058 L
.76192 .00575 L
.76292 .0057 L
.76388 .00565 L
.76481 .0056 L
.7658 .00555 L
.76675 .0055 L
.76766 .00546 L
.76863 .00541 L
.76957 .00536 L
.77057 .00531 L
.77153 .00526 L
.77245 .00522 L
.77343 .00517 L
Mistroke
.77438 .00513 L
.77528 .00509 L
.77625 .00504 L
.77718 .005 L
.77817 .00495 L
.77913 .00491 L
.78005 .00487 L
.78102 .00482 L
.78196 .00478 L
.78296 .00474 L
.78392 .0047 L
.78485 .00466 L
.78583 .00462 L
.78678 .00458 L
.7877 .00454 L
.78867 .00451 L
.7896 .00449 L
.79008 .00448 L
.79059 .00447 L
.79084 .00446 L
.79109 .00446 L
.79133 .00446 L
.79155 .00446 L
.79178 .00446 L
.7919 .00446 L
.79196 .00446 L
.79202 .00446 L
.79208 .00446 L
.79213 .00446 L
.79218 .00446 L
.79223 .00446 L
.79226 .00446 L
.79229 .00446 L
.79231 .00446 L
.79234 .00446 L
.79237 .00446 L
.79239 .00446 L
.7924 .00446 L
.79243 .00446 L
.79246 .00446 L
.79249 .00446 L
.79252 .00446 L
.79258 .00446 L
.79269 .00446 L
.79282 .00446 L
.79294 .00446 L
.79315 .00446 L
.79338 .00446 L
.79385 .00446 L
.79429 .00447 L
Mistroke
.79523 .00449 L
.79622 .00451 L
.79718 .00454 L
.7981 .00457 L
.79908 .00461 L
.80003 .00465 L
.80094 .00469 L
.8019 .00473 L
.80283 .00478 L
.80382 .00482 L
.80478 .00487 L
.80569 .00492 L
.80667 .00497 L
.80761 .00501 L
.80861 .00506 L
.80957 .0051 L
.81049 .00515 L
.81148 .00519 L
.81243 .00523 L
.81334 .00527 L
.81431 .0053 L
.81524 .00534 L
.81623 .00537 L
.81719 .0054 L
.81811 .00543 L
.81909 .00545 L
.82003 .00548 L
.82094 .0055 L
.8219 .00552 L
.82283 .00554 L
.82382 .00555 L
.82477 .00556 L
.82568 .00557 L
.82619 .00558 L
.82666 .00558 L
.82714 .00559 L
.8276 .00559 L
.82783 .00559 L
.82796 .00559 L
.82808 .00559 L
.82819 .00559 L
.82829 .00559 L
.8284 .00559 L
.82846 .00559 L
.82852 .00559 L
.82855 .00559 L
.82856 .00559 L
.82858 .00559 L
.82861 .00559 L
.82864 .00559 L
Mistroke
.82867 .00559 L
.82869 .00559 L
.82872 .00559 L
.82875 .00559 L
.82878 .00559 L
.82882 .00559 L
.82888 .00559 L
.82894 .00559 L
.82899 .00559 L
.8291 .00559 L
.82921 .00559 L
.82944 .00559 L
.82968 .00559 L
.8299 .00559 L
.8304 .00558 L
.83086 .00558 L
.83136 .00558 L
.83233 .00557 L
.83327 .00555 L
.83427 .00554 L
.83523 .00552 L
.83615 .0055 L
.83713 .00548 L
.83808 .00546 L
.83899 .00543 L
.83996 .0054 L
.8409 .00538 L
.84189 .00534 L
.84284 .00531 L
.84376 .00528 L
.84474 .00525 L
.84568 .00521 L
.84668 .00518 L
.84765 .00514 L
.84857 .00511 L
.84956 .00507 L
.85051 .00503 L
.85143 .005 L
.8524 .00496 L
.85334 .00492 L
.85433 .00488 L
.85529 .00484 L
.85621 .00481 L
.85719 .00477 L
.85814 .00473 L
.85905 .00469 L
.86001 .00465 L
.86095 .00462 L
.86194 .00458 L
.86289 .00454 L
Mistroke
.86381 .0045 L
.86478 .00446 L
.86572 .00443 L
.86672 .00439 L
.86768 .00435 L
.86861 .00432 L
.86959 .00428 L
.87054 .00424 L
.87145 .00421 L
.87242 .00417 L
.87336 .00413 L
.87435 .0041 L
.87531 .00406 L
.87623 .00403 L
.87721 .00399 L
.87815 .00396 L
.87906 .00393 L
.88002 .00389 L
.88095 .00386 L
.88194 .00382 L
.88289 .00379 L
.88381 .00376 L
.88478 .00373 L
.88572 .0037 L
.88672 .00366 L
.88768 .00363 L
.8886 .0036 L
.88958 .00357 L
.89053 .00354 L
.89144 .00351 L
.89241 .00348 L
.89334 .00345 L
.89433 .00341 L
.89529 .00338 L
.89621 .00336 L
.89718 .00333 L
.89812 .0033 L
.89912 .00327 L
.90009 .00324 L
.90101 .00321 L
.902 .00318 L
.90295 .00315 L
.90386 .00313 L
.90483 .0031 L
.90577 .00307 L
.90677 .00305 L
.90772 .00302 L
.90864 .00299 L
.90963 .00297 L
.91057 .00294 L
Mistroke
.91148 .00292 L
.91244 .00289 L
.91337 .00287 L
.91436 .00284 L
.91532 .00282 L
.91623 .00279 L
.91721 .00277 L
.91815 .00274 L
.91915 .00272 L
.92011 .00269 L
.92103 .00267 L
.92202 .00265 L
.92296 .00262 L
.92387 .0026 L
.92484 .00258 L
.92578 .00256 L
.92677 .00253 L
.92773 .00251 L
.92865 .00249 L
.92963 .00247 L
.93057 .00245 L
.93147 .00243 L
.93244 .00241 L
.93337 .00239 L
.93435 .00236 L
.9353 .00234 L
.93622 .00232 L
.93719 .0023 L
.93813 .00228 L
.93912 .00226 L
.94008 .00224 L
.94101 .00222 L
.94199 .0022 L
.94293 .00218 L
.94384 .00217 L
.94481 .00215 L
.94574 .00213 L
.94673 .00211 L
.94769 .00209 L
.94861 .00207 L
.94958 .00205 L
.95052 .00204 L
.95152 .00202 L
.95248 .002 L
.95341 .00198 L
.9544 .00197 L
.95534 .00195 L
.95626 .00193 L
.95723 .00192 L
.95816 .0019 L
Mistroke
.95916 .00188 L
.96011 .00187 L
.96104 .00185 L
.96202 .00183 L
.96296 .00182 L
.96387 .0018 L
.96483 .00179 L
.96576 .00177 L
.96675 .00175 L
.9677 .00174 L
.96862 .00172 L
.96959 .00171 L
.97053 .00169 L
.97153 .00168 L
.97249 .00166 L
.97341 .00165 L
.9744 .00164 L
.97534 .00162 L
.97619 .00161 L
Mfstroke
1.5 Mabswid
.02381 0 m
.02474 .00552 L
.02575 .01053 L
.0267 .01442 L
.02761 .01754 L
.02859 .0203 L
.02952 .02248 L
.03052 .02439 L
.03148 .02588 L
.0324 .02705 L
.03338 .02806 L
.03433 .02883 L
.03524 .02942 L
.03621 .0299 L
.03714 .03026 L
.03761 .0304 L
.03813 .03054 L
.03908 .03072 L
.03956 .03079 L
.04006 .03084 L
.04031 .03086 L
.04057 .03088 L
.04083 .03089 L
.04106 .0309 L
.04117 .0309 L
.04129 .0309 L
.04141 .03091 L
.04146 .03091 L
.04151 .03091 L
.04154 .03091 L
.04157 .03091 L
.0416 .03091 L
.04163 .03091 L
.04165 .03091 L
.04167 .03091 L
.04168 .03091 L
.0417 .03091 L
.04172 .03091 L
.04173 .03091 L
.04177 .03091 L
.0418 .03091 L
.04181 .03091 L
.04183 .03091 L
.04186 .03091 L
.04189 .03091 L
.04195 .03091 L
.04201 .03091 L
.04213 .0309 L
.04225 .0309 L
.04247 .0309 L
Mistroke
.04271 .03089 L
.04298 .03088 L
.04345 .03085 L
.04395 .03081 L
.04495 .03072 L
.04592 .0306 L
.04684 .03048 L
.04783 .03033 L
.04878 .03017 L
.04969 .03001 L
.05067 .02984 L
.0516 .02966 L
.0526 .02947 L
.05356 .02928 L
.05448 .0291 L
.05546 .0289 L
.0564 .0287 L
.05731 .02852 L
.05828 .02832 L
.05921 .02813 L
.0602 .02793 L
.06069 .02782 L
.06115 .02773 L
.0616 .02764 L
.06172 .02761 L
.06179 .0276 L
.06184 .02759 L
.06187 .02758 L
.0619 .02758 L
.06192 .0276 L
.06195 .02764 L
.06207 .02778 L
.063 .02894 L
.064 .03015 L
.06495 .03132 L
.06587 .03243 L
.06685 .0336 L
.06779 .03471 L
.0687 .03578 L
.06967 .0369 L
.07059 .03797 L
.07158 .0391 L
.07253 .04017 L
.07345 .0412 L
.07442 .04228 L
.07536 .04331 L
.07635 .0444 L
.07731 .04543 L
.07824 .04642 L
.07922 .04746 L
Mistroke
.08017 .04845 L
.08108 .0494 L
.08204 .05039 L
.08298 .05135 L
.08397 .05235 L
.08492 .0533 L
.08584 .05422 L
.08682 .05518 L
.08776 .05609 L
.08876 .05706 L
.08972 .05798 L
.09065 .05886 L
.09163 .05979 L
.09258 .06067 L
.09349 .06152 L
.09446 .06241 L
.0954 .06325 L
.09639 .06415 L
.09735 .065 L
.09827 .06581 L
.09925 .06667 L
.1002 .06749 L
.1011 .06827 L
.10207 .0691 L
.103 .06988 L
.10399 .07071 L
.10494 .0715 L
.10586 .07226 L
.10683 .07305 L
.10777 .07381 L
.10877 .07461 L
.10973 .07537 L
.11065 .0761 L
.11164 .07687 L
.11259 .0776 L
.1135 .0783 L
.11447 .07904 L
.1154 .07974 L
.11639 .08048 L
.11735 .08119 L
.11827 .08186 L
.11924 .08258 L
.12019 .08326 L
.12119 .08397 L
.12215 .08465 L
.12308 .08531 L
.12407 .08599 L
.12502 .08665 L
.12593 .08727 L
.1269 .08793 L
Mistroke
.12784 .08856 L
.12883 .08923 L
.12979 .08986 L
.13072 .09046 L
.1317 .0911 L
.13264 .09171 L
.13355 .09229 L
.13452 .0929 L
.13545 .09348 L
.13644 .0941 L
.13739 .09468 L
.13831 .09524 L
.13929 .09583 L
.14023 .0964 L
.14123 .09699 L
.14219 .09756 L
.14311 .0981 L
.1441 .09867 L
.14505 .09921 L
.14596 .09973 L
.14693 .10028 L
.14786 .1008 L
.14886 .10135 L
.14981 .10188 L
.15073 .10238 L
.15171 .10291 L
.15266 .10341 L
.15356 .10389 L
.15453 .1044 L
.15546 .10489 L
.15645 .1054 L
.1574 .10588 L
.15831 .10635 L
.15929 .10684 L
.16023 .10731 L
.16122 .1078 L
.16218 .10827 L
.16311 .10872 L
.16409 .10919 L
.16504 .10964 L
.16594 .11007 L
.16691 .11053 L
.16785 .11096 L
.16884 .11142 L
.16979 .11186 L
.17071 .11227 L
.17169 .11271 L
.17263 .11313 L
.17363 .11357 L
.17459 .11399 L
Mistroke
.17552 .11439 L
.17651 .11482 L
.17746 .11522 L
.17837 .11561 L
.17934 .11602 L
.18028 .1164 L
.18127 .11681 L
.18223 .1172 L
.18315 .11758 L
.18413 .11797 L
.18508 .11834 L
.18598 .1187 L
.18695 .11908 L
.18788 .11944 L
.18887 .11982 L
.18982 .12018 L
.19074 .12052 L
.19172 .12089 L
.19265 .12124 L
.19365 .1216 L
.19461 .12195 L
.19554 .12229 L
.19652 .12264 L
.19747 .12297 L
.19838 .12329 L
.19935 .12363 L
.20029 .12395 L
.20128 .12429 L
.20223 .12462 L
.20315 .12493 L
.20413 .12525 L
.20507 .12556 L
.20598 .12586 L
.20695 .12617 L
.20787 .12647 L
.20886 .12679 L
.20981 .12709 L
.21073 .12738 L
.2117 .12768 L
.21264 .12797 L
.21311 .12811 L
.21363 .12827 L
.21387 .12834 L
.21401 .12838 L
.21413 .12842 L
.21419 .12844 L
.21424 .12845 L
.21427 .12846 L
.2143 .1284 L
.21432 .12822 L
Mistroke
.21435 .12805 L
.21459 .12651 L
.21553 .12069 L
.21653 .11482 L
.21749 .10945 L
.21842 .10453 L
.21941 .09957 L
.22035 .09503 L
.22127 .09087 L
.22224 .08667 L
.22317 .08283 L
.22417 .07896 L
.22512 .07541 L
.22605 .07218 L
.22703 .0689 L
.22797 .06591 L
.22888 .06318 L
.22984 .06041 L
.23077 .05787 L
.23176 .05531 L
.23271 .05297 L
.23363 .05083 L
.2346 .04867 L
.23554 .04669 L
.23654 .04468 L
.2375 .04285 L
.23842 .04118 L
.23941 .03948 L
.24035 .03793 L
.24126 .03651 L
.24223 .03506 L
.24317 .03374 L
.24416 .03241 L
.24511 .03118 L
.24603 .03006 L
.24701 .02893 L
.24795 .02788 L
.24895 .02683 L
.24992 .02586 L
.25084 .02498 L
.25131 .02454 L
.25183 .02408 L
.25207 .02387 L
.2522 .02376 L
.25226 .0237 L
.25232 .02365 L
.25235 .02362 L
.25238 .0236 L
.25241 .02361 L
.25244 .02362 L
Mistroke
.25256 .02367 L
.25278 .02375 L
.25371 .02409 L
.2547 .02446 L
.25565 .02481 L
.25657 .02514 L
.25755 .0255 L
.25849 .02583 L
.25948 .02618 L
.26045 .02652 L
.26137 .02684 L
.26236 .02717 L
.2633 .02749 L
.26422 .02779 L
.26519 .02811 L
.26612 .02842 L
.26711 .02874 L
.26807 .02904 L
.26899 .02933 L
.26997 .02963 L
.27091 .02992 L
.27182 .0302 L
.27278 .03049 L
.27371 .03077 L
.2747 .03106 L
.27565 .03133 L
.27657 .0316 L
.27754 .03188 L
.27848 .03214 L
.27947 .03242 L
.28043 .03268 L
.28136 .03294 L
.28234 .0332 L
.28329 .03346 L
.2842 .0337 L
.28516 .03396 L
.2861 .0342 L
.28709 .03446 L
.28804 .0347 L
.28896 .03494 L
.28994 .03518 L
.29088 .03542 L
.29188 .03566 L
.29284 .0359 L
.29377 .03613 L
.29475 .03636 L
.2957 .03659 L
.29662 .0368 L
.29759 .03703 L
.29852 .03725 L
Mistroke
.29952 .03748 L
.30048 .0377 L
.3014 .0379 L
.30238 .03812 L
.30332 .03833 L
.30423 .03853 L
.3052 .03874 L
.30613 .03894 L
.30711 .03916 L
.30807 .03936 L
.30898 .03955 L
.30996 .03975 L
.3109 .03995 L
.31189 .04015 L
.31286 .04035 L
.31378 .04053 L
.31476 .04073 L
.31571 .04092 L
.31662 .0411 L
.31759 .04128 L
.31853 .04146 L
.31952 .04165 L
.32047 .04183 L
.32139 .04201 L
.32237 .04219 L
.32331 .04236 L
.32431 .04254 L
.32528 .04272 L
.32621 .04289 L
.32719 .04306 L
.32814 .04323 L
.32906 .04339 L
.33003 .04356 L
.33097 .04372 L
.33196 .04389 L
.33292 .04405 L
.33385 .0442 L
.33483 .04437 L
.33577 .04452 L
.33668 .04467 L
.33765 .04483 L
.33858 .04498 L
.33957 .04513 L
.34053 .04528 L
.34144 .04543 L
.34242 .04558 L
.34336 .04572 L
.34436 .04587 L
.34532 .04602 L
.34625 .04616 L
Mistroke
.34723 .0463 L
.34818 .04644 L
.34909 .04657 L
.35006 .04671 L
.351 .04685 L
.35199 .04699 L
.35295 .04712 L
.35387 .04725 L
.35485 .04738 L
.35579 .04751 L
.3567 .04764 L
.35766 .04777 L
.35859 .04789 L
.35958 .04802 L
.36053 .04814 L
.36145 .04826 L
.36242 .04839 L
.36336 .04851 L
.36436 .04863 L
.36532 .04875 L
.36624 .04887 L
.36723 .04899 L
.36817 .04911 L
.36908 .04922 L
.37005 .04933 L
.37098 .04944 L
.37198 .04956 L
.37293 .04967 L
.37385 .04978 L
.37483 .04989 L
.37577 .05 L
.37677 .05011 L
.37773 .05022 L
.37866 .05032 L
.37965 .05043 L
.38059 .05053 L
.38151 .05063 L
.38248 .05073 L
.38342 .05083 L
.38441 .05094 L
.38537 .05104 L
.38629 .05113 L
.38727 .05123 L
.38822 .05133 L
.38912 .05142 L
.39009 .05152 L
.39102 .05161 L
.39201 .05171 L
.39297 .0518 L
.39388 .05189 L
Mistroke
.39486 .05198 L
.3958 .05207 L
.39679 .05216 L
.39776 .05225 L
.39868 .05234 L
.39967 .05243 L
.40061 .05251 L
.40152 .05259 L
.4025 .05268 L
.40343 .05276 L
.4039 .0528 L
.40415 .05283 L
.40442 .05285 L
.40454 .05286 L
.40466 .05287 L
.40469 .05287 L
.40473 .05288 L
.40476 .05288 L
.40478 .05284 L
.40479 .0528 L
.40492 .05246 L
.40538 .05125 L
.40632 .04887 L
.40731 .04646 L
.40827 .04426 L
.40919 .04225 L
.41018 .04022 L
.41112 .03836 L
.41203 .03666 L
.413 .03494 L
.41393 .03337 L
.41492 .03178 L
.41588 .03033 L
.41679 .02901 L
.41777 .02767 L
.41871 .02645 L
.41971 .02521 L
.42067 .02408 L
.4216 .02305 L
.42259 .02201 L
.42353 .02106 L
.42445 .02019 L
.42542 .0193 L
.42635 .0185 L
.42735 .01768 L
.42831 .01694 L
.42923 .01625 L
.43021 .01556 L
.43115 .01493 L
.43206 .01435 L
Mistroke
.43302 .01377 L
.43395 .01323 L
.43494 .01269 L
.43589 .01219 L
.43681 .01173 L
.43779 .01127 L
.43872 .01085 L
.43972 .01042 L
.44068 .01003 L
.44161 .00967 L
.44208 .00949 L
.44232 .0094 L
.44259 .0093 L
.44272 .00926 L
.44279 .00923 L
.44282 .00922 L
.44285 .00921 L
.44287 .00921 L
.4429 .00921 L
.44296 .00922 L
.44308 .00924 L
.44354 .00929 L
.44446 .00941 L
.44545 .00953 L
.4464 .00965 L
.44732 .00976 L
.44829 .00988 L
.44922 .01 L
.45022 .01011 L
.45118 .01023 L
.4521 .01033 L
.45308 .01044 L
.45403 .01055 L
.45494 .01065 L
.4559 .01076 L
.45683 .01086 L
.45782 .01097 L
.45878 .01107 L
.4597 .01117 L
.46067 .01127 L
.46161 .01136 L
.46261 .01147 L
.46357 .01156 L
.4645 .01165 L
.46548 .01175 L
.46643 .01184 L
.46734 .01193 L
.46831 .01202 L
.46925 .01211 L
.47024 .0122 L
Mistroke
.4712 .01229 L
.47212 .01238 L
.4731 .01247 L
.47404 .01255 L
.47495 .01263 L
.47591 .01272 L
.47684 .0128 L
.47783 .01288 L
.47878 .01296 L
.4797 .01304 L
.48067 .01312 L
.48161 .0132 L
.4826 .01328 L
.48356 .01336 L
.48449 .01344 L
.48547 .01351 L
.48642 .01359 L
.48733 .01366 L
.48829 .01374 L
.48923 .01381 L
.49022 .01388 L
.49117 .01396 L
.49209 .01403 L
.49307 .0141 L
.49401 .01417 L
.49501 .01424 L
.49597 .01431 L
.4969 .01438 L
.49789 .01445 L
.49884 .01452 L
.49975 .01458 L
.50072 .01465 L
.50166 .01471 L
.50265 .01478 L
.50361 .01484 L
.50453 .01491 L
.50551 .01497 L
.50646 .01503 L
.50736 .01509 L
.50833 .01516 L
.50926 .01521 L
.51025 .01528 L
.5112 .01534 L
.51212 .01539 L
.51309 .01546 L
.51403 .01551 L
.51503 .01557 L
.51599 .01563 L
.51692 .01569 L
.5179 .01575 L
Mistroke
.51885 .0158 L
.51976 .01585 L
.52073 .01591 L
.52166 .01596 L
.52265 .01602 L
.52361 .01607 L
.52453 .01612 L
.52551 .01618 L
.52645 .01623 L
.52736 .01628 L
.52832 .01633 L
.52925 .01638 L
.53024 .01643 L
.53119 .01648 L
.5321 .01653 L
.53308 .01658 L
.53401 .01663 L
.53501 .01668 L
.53597 .01673 L
.53689 .01677 L
.53787 .01682 L
.53882 .01687 L
.53973 .01691 L
.54069 .01696 L
.54163 .017 L
.54262 .01705 L
.54357 .01709 L
.54449 .01714 L
.54546 .01718 L
.5464 .01722 L
.5474 .01727 L
.54837 .01731 L
.54929 .01735 L
.55028 .0174 L
.55123 .01744 L
.55214 .01748 L
.55311 .01752 L
.55404 .01756 L
.55504 .0176 L
.556 .01764 L
.55692 .01768 L
.5579 .01772 L
.55884 .01776 L
.55975 .01779 L
.56071 .01783 L
.56164 .01787 L
.56263 .01791 L
.56358 .01794 L
.5645 .01798 L
.56547 .01802 L
Mistroke
.56641 .01805 L
.56741 .01809 L
.56837 .01813 L
.56929 .01816 L
.57028 .0182 L
.57122 .01823 L
.57213 .01826 L
.5731 .0183 L
.57403 .01833 L
.57503 .01836 L
.57598 .0184 L
.5769 .01843 L
.57788 .01846 L
.57882 .01849 L
.57982 .01853 L
.58078 .01856 L
.58171 .01859 L
.5827 .01862 L
.58365 .01865 L
.58456 .01868 L
.58553 .01871 L
.58647 .01874 L
.58747 .01877 L
.58842 .0188 L
.58935 .01883 L
.59033 .01886 L
.59127 .01889 L
.59218 .01892 L
.59315 .01895 L
.59408 .01897 L
.59455 .01899 L
.5948 .019 L
.59494 .019 L
.59507 .019 L
.59513 .019 L
.59519 .01901 L
.59521 .01901 L
.59523 .01901 L
.59524 .019 L
.59526 .01898 L
.59533 .01892 L
.59556 .0187 L
.59602 .01826 L
.59701 .01737 L
.59797 .01654 L
.59889 .01579 L
.59987 .01503 L
.60081 .01433 L
.60172 .0137 L
.60268 .01305 L
Mistroke
.60361 .01246 L
.6046 .01187 L
.60555 .01132 L
.60647 .01083 L
.60744 .01032 L
.60838 .00986 L
.60937 .0094 L
.61033 .00898 L
.61126 .00859 L
.61224 .0082 L
.61318 .00784 L
.61409 .00752 L
.61506 .00719 L
.61599 .00688 L
.61699 .00658 L
.61794 .0063 L
.61886 .00604 L
.61983 .00578 L
.62078 .00554 L
.62178 .00531 L
.62274 .00509 L
.62366 .00489 L
.62465 .00468 L
.6256 .0045 L
.62651 .00433 L
.62748 .00415 L
.62842 .004 L
.62941 .00384 L
.63037 .00369 L
.63129 .00356 L
.63227 .00342 L
.63276 .00335 L
.633 .00332 L
.6331 .00331 L
.63322 .0033 L
.63327 .00329 L
.6333 .00328 L
.63333 .00328 L
.63335 .00328 L
.63338 .00328 L
.63343 .00328 L
.63365 .00329 L
.63412 .00331 L
.63511 .00336 L
.63606 .0034 L
.63697 .00344 L
.63794 .00348 L
.63887 .00352 L
.63986 .00356 L
.64082 .0036 L
Mistroke
.64174 .00364 L
.64271 .00368 L
.64366 .00371 L
.64466 .00375 L
.64562 .00379 L
.64655 .00382 L
.64754 .00386 L
.64849 .0039 L
.6494 .00393 L
.65037 .00397 L
.65131 .004 L
.65231 .00403 L
.65326 .00407 L
.65419 .0041 L
.65517 .00413 L
.65611 .00417 L
.65702 .0042 L
.65799 .00423 L
.65892 .00426 L
.65991 .00429 L
.66087 .00432 L
.66178 .00435 L
.66276 .00438 L
.6637 .00441 L
.6647 .00444 L
.66566 .00447 L
.66659 .0045 L
.66757 .00453 L
.66852 .00456 L
.66943 .00459 L
.6704 .00461 L
.67134 .00464 L
.67233 .00467 L
.67329 .0047 L
.67421 .00472 L
.67519 .00475 L
.67613 .00478 L
.67704 .0048 L
.678 .00483 L
.67893 .00485 L
.67992 .00488 L
.68087 .0049 L
.68179 .00493 L
.68276 .00495 L
.6837 .00498 L
.6847 .005 L
.68566 .00503 L
.68658 .00505 L
.68756 .00507 L
.68851 .0051 L
Mistroke
.68942 .00512 L
.69039 .00514 L
.69132 .00517 L
.69231 .00519 L
.69327 .00521 L
.69419 .00523 L
.69516 .00526 L
.6961 .00528 L
.6971 .0053 L
.69807 .00532 L
.69899 .00534 L
.69998 .00536 L
.70093 .00538 L
.70184 .0054 L
.70282 .00543 L
.70375 .00545 L
.70475 .00547 L
.7057 .00549 L
.70663 .00551 L
.70761 .00553 L
.70855 .00555 L
.70946 .00556 L
.71043 .00558 L
.71136 .0056 L
.71235 .00562 L
.7133 .00564 L
.71422 .00566 L
.71519 .00568 L
.71613 .00569 L
.71713 .00571 L
.71809 .00573 L
.71902 .00575 L
.72 .00577 L
.72095 .00578 L
.72186 .0058 L
.72283 .00582 L
.72376 .00583 L
.72475 .00585 L
.72571 .00587 L
.72663 .00588 L
.72761 .0059 L
.72855 .00592 L
.72946 .00593 L
.73042 .00595 L
.73135 .00596 L
.73234 .00598 L
.73329 .006 L
.7342 .00601 L
.73518 .00603 L
.73611 .00604 L
Mistroke
.73711 .00606 L
.73807 .00607 L
.73899 .00609 L
.73997 .0061 L
.74092 .00611 L
.74183 .00613 L
.7428 .00614 L
.74373 .00616 L
.74472 .00617 L
.74567 .00618 L
.74659 .0062 L
.74757 .00621 L
.74851 .00623 L
.74951 .00624 L
.75047 .00625 L
.7514 .00627 L
.75238 .00628 L
.75333 .00629 L
.75424 .0063 L
.75522 .00632 L
.75615 .00633 L
.75714 .00634 L
.7581 .00635 L
.75902 .00637 L
.76 .00638 L
.76095 .00639 L
.76185 .0064 L
.76282 .00641 L
.76375 .00643 L
.76474 .00644 L
.76569 .00645 L
.76661 .00646 L
.76758 .00647 L
.76852 .00648 L
.76952 .00649 L
.77048 .00651 L
.7714 .00652 L
.77238 .00653 L
.77333 .00654 L
.77424 .00655 L
.77521 .00656 L
.77614 .00657 L
.77714 .00658 L
.77809 .00659 L
.77901 .0066 L
.77999 .00661 L
.78093 .00662 L
.78193 .00663 L
.78289 .00664 L
.78382 .00665 L
Mistroke
.78429 .00665 L
.78481 .00666 L
.78505 .00666 L
.7853 .00667 L
.78542 .00667 L
.78554 .00667 L
.78565 .00667 L
.78567 .00667 L
.7857 .00667 L
.78573 .00666 L
.78576 .00665 L
.78673 .00633 L
.78766 .00604 L
.78865 .00574 L
.7896 .00547 L
.79052 .00523 L
.79149 .00498 L
.79243 .00475 L
.79343 .00452 L
.79439 .00431 L
.79532 .00411 L
.7963 .00392 L
.79725 .00374 L
.79816 .00358 L
.79913 .00341 L
.80007 .00326 L
.80106 .00311 L
.80202 .00297 L
.80294 .00285 L
.80392 .00272 L
.80486 .0026 L
.80577 .00249 L
.80673 .00238 L
.80766 .00228 L
.80865 .00218 L
.8096 .00209 L
.81052 .00201 L
.81149 .00192 L
.81243 .00185 L
.81342 .00177 L
.81438 .00169 L
.81531 .00163 L
.81629 .00156 L
.81724 .0015 L
.81815 .00144 L
.81911 .00139 L
.82005 .00134 L
.82104 .00128 L
.82199 .00123 L
.82291 .00119 L
Mistroke
.82342 .00117 L
.82354 .00116 L
.82367 .00116 L
.82372 .00115 L
.82377 .00115 L
.8238 .00115 L
.82383 .00115 L
.82386 .00115 L
.82389 .00115 L
.82412 .00115 L
.82437 .00116 L
.82483 .00116 L
.82575 .00118 L
.82673 .00119 L
.82767 .00121 L
.82858 .00122 L
.82955 .00123 L
.83048 .00125 L
.83147 .00126 L
.83242 .00128 L
.83334 .00129 L
.83431 .0013 L
.83525 .00131 L
.83625 .00133 L
.83721 .00134 L
.83813 .00135 L
.83912 .00137 L
.84007 .00138 L
.84098 .00139 L
.84195 .0014 L
.84288 .00141 L
.84387 .00142 L
.84483 .00144 L
.84575 .00145 L
.84673 .00146 L
.84767 .00147 L
.84867 .00148 L
.84963 .00149 L
.85056 .0015 L
.85155 .00151 L
.8525 .00152 L
.85341 .00153 L
.85439 .00155 L
.85532 .00156 L
.85632 .00157 L
.85728 .00158 L
.8582 .00159 L
.85918 .0016 L
.86013 .00161 L
.86104 .00161 L
Mistroke
.86201 .00162 L
.86294 .00163 L
.86393 .00164 L
.86488 .00165 L
.8658 .00166 L
.86677 .00167 L
.86771 .00168 L
.86871 .00169 L
.86968 .0017 L
.8706 .00171 L
.87159 .00172 L
.87254 .00172 L
.87345 .00173 L
.87442 .00174 L
.87535 .00175 L
.87635 .00176 L
.8773 .00177 L
.87823 .00178 L
.87921 .00178 L
.88015 .00179 L
.88106 .0018 L
.88202 .00181 L
.88295 .00181 L
.88394 .00182 L
.88489 .00183 L
.88581 .00184 L
.88678 .00185 L
.88772 .00185 L
.88872 .00186 L
.88968 .00187 L
.8906 .00188 L
.89158 .00188 L
.89253 .00189 L
.89344 .0019 L
.89441 .0019 L
.89534 .00191 L
.89633 .00192 L
.89729 .00193 L
.89821 .00193 L
.89918 .00194 L
.90013 .00195 L
.90113 .00195 L
.90209 .00196 L
.90302 .00197 L
.904 .00197 L
.90495 .00198 L
.90587 .00198 L
.90684 .00199 L
.90778 .002 L
.90877 .002 L
Mistroke
.90973 .00201 L
.91065 .00202 L
.91163 .00202 L
.91258 .00203 L
.91348 .00203 L
.91445 .00204 L
.91538 .00205 L
.91637 .00205 L
.91732 .00206 L
.91824 .00206 L
.91922 .00207 L
.92016 .00207 L
.92115 .00208 L
.92212 .00208 L
.92304 .00209 L
.92403 .0021 L
.92497 .0021 L
.92588 .00211 L
.92686 .00211 L
.92779 .00212 L
.92878 .00212 L
.92974 .00213 L
.93066 .00213 L
.93164 .00214 L
.93258 .00214 L
.93349 .00215 L
.93445 .00215 L
.93538 .00216 L
.93637 .00216 L
.93732 .00217 L
.93823 .00217 L
.93921 .00218 L
.94014 .00218 L
.94114 .00218 L
.9421 .00219 L
.94302 .00219 L
.94401 .0022 L
.94495 .0022 L
.94586 .00221 L
.94683 .00221 L
.94776 .00222 L
.94875 .00222 L
.94971 .00222 L
.95062 .00223 L
.9516 .00223 L
.95254 .00224 L
.95354 .00224 L
.9545 .00225 L
.95543 .00225 L
.95642 .00225 L
Mistroke
.95736 .00226 L
.95828 .00226 L
.95925 .00227 L
.96018 .00227 L
.96118 .00227 L
.96214 .00228 L
.96306 .00228 L
.96404 .00228 L
.96498 .00229 L
.96589 .00229 L
.96685 .00229 L
.96778 .0023 L
.96877 .0023 L
.96973 .00231 L
.97064 .00231 L
.97162 .00231 L
.97256 .00232 L
.97355 .00232 L
.97451 .00232 L
.97544 .00233 L
.97619 .00233 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.52381 .42806 m
.52381 .57092 L
.66667 .57092 L
.66667 .42806 L
F
1 g
.5 .45187 m
.5 .59473 L
.64286 .59473 L
.64286 .45187 L
F
0 g
.001 w
[ ] 0 setdash
.5 .45187 m
.64286 .45187 L
.64286 .59473 L
.5 .59473 L
.5 .45187 L
s
% Start of sub-graphic
p
0.5 0.451874 0.642857 0.594731 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0271739 0.271739 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.048913 0.35119 0.320652 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
1.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .18478 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x3) show
75.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.36413 0.35119 0.63587 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .5 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x2) show
75.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.679348 0.35119 0.951087 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
2 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .81522 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x1) show
75.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[107]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00@@3oool5
00000080oooo0P00000R0?ooo`@000000`3oool200000280oooo0P0000040?ooo`800000903oool3
00000080oooo0P00000R0?ooo`800000103oool2000002`0oooo00130?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool00000803oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002@0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0N0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000:`3oool004<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`00000R0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0O0?ooo`D0
000000D0oooo0000003oool0oooo0000000S0?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0:@3oool004<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0240oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0240oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0O0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000008@3oool2000000<0oooo00@000000?ooo`3oool00000:`3oool0
04<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01l0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`00000P0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000008P3oool00`000000oooo000000020?ooo`040000003oool0oooo
00000240oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000[0?ooo`00@P3oool2
000000@0oooo0P00000S0?ooo`800000103oool200000280oooo0P0000040?ooo`800000903oool2
000000<0oooo0P00000R0?ooo`<000000`3oool2000002`0oooo003o0?ooob40oooo003o0?ooo`/0
oooo0P00000D0?ooo`00o`3oool<0?ooo`030000003oool0oooo0180oooo003o0?ooo`@0000000<0
oooo0000000000000`0000030?ooo`040000003oool0oooo0?ooo`<000003@3oool00?h0oooo00@0
00000?ooo`3oool000000P3oool4000000<0oooo00<000000?ooo`0000001@3oool00`000000oooo
0?ooo`0:0?ooo`005P3ooooQ000000L0oooo00@000000?ooo`3oool000001@3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00<000003@3oool001/0oooo0P0000070?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00H0ooooGP00000>0?ooo`<000000`3oool3000000050?ooo`00000000000000003o
ool00P0000000`3oool0000000000002000000`0oooo000K0?ooo`800000F`3oool8000000L0oooo
=00000160?ooo`030000003oool0oooo01`0oooo000K0?ooo`800000D`3oool00`000000oooo0?oo
o`030?ooo`<000001P3ooolE00000080oooo6@00001A0?ooo`8000007P3oool001/0oooo0P00000a
0?ooo`030000003oool0oooo01T0oooo2P0000000`3oool00000000000040?ooo`h00000103oool@
000008<0oooo000K0?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool09`3oool20000
01D0oooo7@00000:0?ooo`D00000S`3oool001/0oooo00<000000?ooo`0000000P0000000`3oool0
000000000002000002P0oooo0P000000103oool0000000000000000>0?ooo`/000001P3oool;0000
00/0oooo1000002D0?ooo`006`3oool2000000030?ooo`0000000000008000000P3oool2000002H0
oooo0P0000050?ooo`@000001`3oool9000000`0oooo00<000000?ooo`3oool03P3oool5000009L0
oooo000K0?ooo`030000003oool0oooo00L0oooo0P00000U0?ooo`030000003oool0oooo00L0oooo
3@00000?0?ooo`8000003@3oool4000009/0oooo000K0?ooo`030000003oool0oooo00P0oooo0P00
000S0?ooo`8000002`3oool8000000l0oooo200000070?ooo`@00000WP3oool001/0oooo00<00000
0?ooo`3oool02@3oool200000280oooo00<000000?ooo`3oool0203oool7000000<0oooo1`000005
0?ooo`@0000000<0oooo0000003oool00`3oool900000:40oooo000K0?ooo`030000003oool0oooo
00X0oooo0P00000P0?ooo`800000203oool6000000`0oooo3000002^0?ooo`006`3oool00`000000
oooo0?ooo`0;0?ooo`8000006`3oool01@000000oooo0?ooo`3oool0000000L0oooo1P00000@0?oo
o`<00000103oool300000:h0oooo000K0?ooo`8000003@3oool2000001P0oooo100000000`3oool0
0000000000060?ooo`D00000403oool300000;L0oooo000K0?ooo`8000003P3oool2000001D0oooo
200000060?ooo`@000004@3oool200000;T0oooo000K0?ooo`8000003`3oool200000180oooo1@00
00000`3oool0000000000002000000@0oooo1@00000@0?ooo`<00000^P3oool001/0oooo0P00000@
0?ooo`800000403oool5000000<0oooo2P00000A0?ooo`800000_03oool001/0oooo0P00000B0?oo
o`800000303oool5000000H0oooo2000000@0?ooo`800000_P3oool001/0oooo0P00000C0?ooo`80
00002P3oool5000000L0oooo00<000000?ooo`0000000P00000B0?ooo`800000_`3oool001/0oooo
0P00000D0?ooo`800000203oool4000000T0oooo00<000000?ooo`3oool04`3oool200000<00oooo
000K0?ooo`8000005P3oool2000000D0oooo1000000:0?ooo`030000003oool0oooo0140oooo0P00
00320?ooo`006`3oool2000001L0oooo0`0000000`3oool0000000000003000000X0oooo00<00000
0?ooo`3oool04@3oool200000<<0oooo000K0?ooo`8000006@3oool5000000`0oooo00<000000?oo
o`3oool0403oool200000<@0oooo000K0?ooo`8000006@3oool4000000d0oooo00<000000?ooo`3o
ool03`3oool200000<D0oooo000K0?ooo`800000603oool4000000030?ooo`000000000000/0oooo
00<000000?ooo`3oool03P3oool200000<H0oooo000>0?ooo`@000000`3oool2000000@0oooo0P00
000G0?ooo`@000000`3oool4000000P0oooo00<000000?ooo`3oool03@3oool200000<L0oooo000>
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool2000001H0oooo1000
00070?ooo`<000001@3oool00`000000oooo0?ooo`0=0?ooo`800000b03oool000l0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`<000005@3oool3000000X0oooo1000
00020?ooo`030000003oool0oooo00`0oooo0P0000390?ooo`00403oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool0oooo0P00000E0?ooo`<000003P3oool4000000d0oooo
0P00003:0?ooo`003P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0
oooo0P00000D0?ooo`<000004P3oool010000000oooo0000000000090?ooo`800000b`3oool000l0
oooo0P0000040?ooo`800000103oool2000001<0oooo0`00000D0?ooo`D000001P3oool200000<`0
oooo000K0?ooo`8000004P3oool4000001<0oooo00<000000?ooo`3oool00P3oool2000000<0oooo
0`00003=0?ooo`006`3oool200000140oooo1000000C0?ooo`030000003oool0oooo00D0oooo1000
003?0?ooo`006`3oool200000140oooo0`00000C0?ooo`800000fP3oool001/0oooo0P00000@0?oo
o`<00000503oool00`000000oooo0?ooo`3I0?ooo`006`3oool2000000l0oooo1000000C0?ooo`03
0000003oool0oooo0=X0oooo000K0?ooo`8000003`3oool3000001<0oooo0P00003L0?ooo`006`3o
ool2000000h0oooo0`00000D0?ooo`030000003oool0oooo0=/0oooo000K0?ooo`8000003@3oool3
000001@0oooo00<000000?ooo`3oool0g03oool001/0oooo0P00000=0?ooo`<000004`3oool20000
0=h0oooo000K0?ooo`800000303oool3000001@0oooo00<000000?ooo`3oool0g@3oool001/0oooo
0P00000<0?ooo`<000004`3oool00`000000oooo0?ooo`3N0?ooo`006`3oool2000000/0oooo0`00
000C0?ooo`800000h03oool001/0oooo0P00000;0?ooo`<000004`3oool00`000000oooo0?ooo`3O
0?ooo`006`3oool2000000X0oooo0`00000C0?ooo`800000h@3oool001/0oooo0P00000:0?ooo`80
0000503oool00`000000oooo0?ooo`3P0?ooo`006`3oool2000000T0oooo0`00000C0?ooo`800000
hP3oool001/0oooo0P0000090?ooo`800000503oool00`000000oooo0?ooo`3Q0?ooo`006`3oool2
000000P0oooo0`00000C0?ooo`800000h`3oool001/0oooo0P0000080?ooo`800000503oool00`00
0000oooo0?ooo`3R0?ooo`006`3oool2000000L0oooo0`00000C0?ooo`800000i03oool001/0oooo
0P0000070?ooo`800000503oool00`000000oooo0?ooo`3S0?ooo`006`3oool2000000H0oooo0`00
000C0?ooo`800000i@3oool00100oooo0`0000020?ooo`800000103oool2000000H0oooo0P00000D
0?ooo`030000003oool0oooo0>@0oooo000A0?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool0oooo0P0000050?ooo`<000004`3oool200000>H0oooo000>0?ooo`D0000000D0oooo
0000003oool0oooo000000030?ooo`<00000103oool3000001<0oooo00<000000?ooo`3oool0i@3o
ool000h0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000
103oool3000001@0oooo00<000000?ooo`3oool0i@3oool000l0oooo00<000000?ooo`0000000P3o
ool010000000oooo0?ooo`0000030?ooo`800000103oool2000001@0oooo00<000000?ooo`3oool0
iP3oool00100oooo0P0000030?ooo`800000103oool2000000@0oooo0P00000D0?ooo`030000003o
ool0oooo0>H0oooo000K0?ooo`8000000`3oool3000001<0oooo0P00003X0?ooo`006`3oool20000
00<0oooo0P00000D0?ooo`030000003oool0oooo0>L0oooo000K0?ooo`8000000`3oool2000001<0
oooo0P00003Y0?ooo`006`3oool2000000<0oooo0P00000C0?ooo`030000003oool0oooo0>P0oooo
000K0?ooo`8000000P3oool3000001<0oooo00<000000?ooo`3oool0j03oool001/0oooo0P000002
0?ooo`8000004`3oool200000>X0oooo000K0?ooo`8000000P3oool2000001<0oooo00<000000?oo
o`3oool0j@3oool001/0oooo0P0000020?ooo`8000004`3oool00`000000oooo0?ooo`3Y0?ooo`00
6`3oool200000080oooo0P00000B0?ooo`800000j`3oool001/0oooo0P0000020?ooo`8000004P3o
ool00`000000oooo0?ooo`3Z0?ooo`006`3oool200000080oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`3Z0?ooo`006`3oool2000000030?ooo`00000000000180oooo00<000000?oo
o`3oool0j`3oool001/0oooo0P0000000`3oool000000000000B0?ooo`030000003oool0oooo0>/0
oooo000K0?ooo`80000000<0oooo0000000000004P3oool00`000000oooo0?ooo`3[0?ooo`006`3o
ool2000000030?ooo`00000000000140oooo00<000000?ooo`3oool0k03oool001/0oooo0P000000
0`3oool000000000000A0?ooo`030000003oool0oooo0>`0oooo000K0?ooo`80000000<0oooo0000
000000004@3oool00`000000oooo0?ooo`3/0?ooo`006`3oool2000000030?ooo`00000000000100
oooo00<000000?ooo`3oool0k@3oool001/0oooo0P0000000`3oool000000000000@0?ooo`030000
003oool0oooo0>d0oooo000K0?ooo`80000000<0oooo000000000000403oool00`000000oooo0?oo
o`3]0?ooo`006`3oool2000000030?ooo`000000000000l0oooo00<000000?ooo`3oool0kP3oool0
01/0oooo0P0000000`3oool000000000000?0?ooo`030000003oool0oooo0>h0oooo000>0?ooo`<0
0000103oool2000000@0oooo0P0000000`3oool000000000000?0?ooo`030000003oool0oooo0>h0
oooo000>0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool50000
00h0oooo00<000000?ooo`3oool0k`3oool000h0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000030?ooo`@000003`3oool00`000000oooo0?ooo`3_0?ooo`003P3oool30000
00<0oooo00@000000?ooo`3oool000000`3oool4000000l0oooo00<000000?ooo`3oool0k`3oool0
00l0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`@000003`3oool0
0`000000oooo0?ooo`3_0?ooo`003`3oool3000000<0oooo0P0000040?ooo`@000003P3oool00`00
0000oooo0?ooo`3`0?ooo`006`3oool4000000h0oooo00<000000?ooo`3oool0l03oool001/0oooo
1000000>0?ooo`030000003oool0oooo0?00oooo000K0?ooo`@000003P3oool00`000000oooo0?oo
o`3`0?ooo`006`3oool4000000d0oooo00<000000?ooo`3oool0l@3oool001/0oooo1000000=0?oo
o`030000003oool0oooo0?40oooo000K0?ooo`@000003@3oool00`000000oooo0?ooo`3a0?ooo`00
6`3oool4000000`0oooo00<000000?ooo`3oool0lP3oool001/0oooo1000000<0?ooo`030000003o
ool0oooo0?80oooo000K0?ooo`@00000303oool00`000000oooo0?ooo`3b0?ooo`006`3oool01000
0000oooo00000000000<0?ooo`030000003oool0oooo0?80oooo000K0?ooo`@000002`3oool00`00
0000oooo0?ooo`3c0?ooo`006`3oool010000000oooo00000000000;0?ooo`030000003oool0oooo
0?<0oooo000K0?ooo`040000003oool00000000000/0oooo00<000000?ooo`3oool0l`3oool001/0
oooo00@000000?ooo`00000000002`3oool00`000000oooo0?ooo`3c0?ooo`006`3oool010000000
oooo00000000000:0?ooo`030000003oool0oooo0?@0oooo000K0?ooo`040000003oool000000000
00X0oooo00<000000?ooo`3oool0m03oool001/0oooo1000000:0?ooo`030000003oool0oooo0?@0
oooo000K0?ooo`040000003oool00000000000X0oooo00<000000?ooo`3oool0m03oool001/0oooo
00@000000?ooo`00000000002@3oool00`000000oooo0?ooo`3e0?ooo`006`3oool010000000oooo
0000000000090?ooo`030000003oool0oooo0?D0oooo000K0?ooo`040000003oool00000000000T0
oooo00<000000?ooo`3oool0J`3ooolY00000640oooo000?0?ooo`800000103oool2000000@0oooo
00@000000?ooo`00000000002@3oool00`000000oooo0?ooo`1[0?ooobT00000H@3oool000h0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`<000002@3oool00`00
0000oooo0?ooo`1/0?ooobT00000H@3oool000h0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000030?ooo`<000002@3oool00`000000oooo0?ooo`1/0?ooobT00000H@3oool0
00l0oooo0P0000030?ooo`040000003oool0oooo000000<0oooo0`0000090?ooo`030000003oool0
oooo06`0oooo:@00001Q0?ooo`003P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0`0000090?ooo`030000003oool0oooo06`0oooo:@00001Q0?ooo`003`3oool2
000000@0oooo0P0000040?ooo`<00000203oool00`000000oooo0?ooo`1V0?oooc000000H@3oool0
01/0oooo0`0000080?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool09P3oool70000
0640oooo000K0?ooo`<00000203oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo02H0
oooo1`00001Q0?ooo`006`3oool3000000P0oooo00<000000?ooo`3oool0IP3oool00`000000oooo
0?ooo`0V0?ooo`L00000H@3oool001/0oooo0`0000070?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool09P3oool700000640oooo000K0?ooo`<000001`3oool00`000000oooo0?ooo`1W
0?ooo`030000003oool0oooo02H0oooo1`00001Q0?ooo`006`3oool3000000L0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`0?0?ooo`80000000<0oooo0000000000000`3oool20000
00d0oooo1`00001Q0?ooo`006`3oool3000000L0oooo00<000000?ooo`3oool0I`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool00000303oool70000
0640oooo000K0?ooo`<000001P3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0000000`0
00001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo1`00001Q0?ooo`00
6`3oool3000000H0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0?0?ooo`800000
00<0oooo0000000000001@3oool00`000000oooo0?ooo`0:0?ooo`L00000H@3oool001/0oooo0`00
00060?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool05P3oool010000000oooo0?oo
o`00000<0?ooo`L00000H@3oool001/0oooo100000050?ooo`030000003oool0oooo06P0oooo00<0
00000?ooo`3oool05`3oool2000000d0oooo1`00001Q0?ooo`006`3oool4000000D0oooo00<00000
0?ooo`3oool0J03oool00`000000oooo0?ooo`0V0?ooo`L00000H@3oool001/0oooo100000040?oo
o`030000003oool0oooo06T0oooo00<000000?ooo`3oool09P3oool700000640oooo000K0?ooo`@0
0000103oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo02H0oooo1`00001Q0?ooo`00
6`3oool4000000@0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0V0?ooo`L00000
H@3oool001/0oooo100000040?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool09P3o
ool700000640oooo000K0?ooo`@000000`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0
oooo02H0oooo1`00001Q0?ooo`006`3oool4000000<0oooo00<000000?ooo`3oool0JP3oool00`00
0000oooo0?ooo`0V0?ooo`L00000H@3oool001/0oooo100000030?ooo`030000003oool0oooo06X0
oooo00<000000?ooo`3oool03`3oool2000000030?ooo`00000000000080oooo1000000<0?ooo`L0
0000H@3oool001/0oooo100000020?ooo`030000003oool0oooo06/0oooo00<000000?ooo`000000
300000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool03@3oool700000640oooo
000K0?ooo`@000000P3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`L00000H@3oool001/0oooo10000002
0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool03`3oool2000000030?ooo`000000
000000@0oooo00<000000?ooo`3oool02`3oool700000640oooo00080?ooo`D000000P3oool20000
00@0oooo0P0000040?ooo`<0000000@0oooo0000003oool00000K@3oool00`000000oooo0?ooo`0F
0?ooo`040000003oool0oooo000000`0oooo1`00001Q0?ooo`002P3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`3oool300000003
0?ooo`000000000006h0oooo00<000000?ooo`3oool05`3oool2000000d0oooo1`00001Q0?ooo`00
2P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`3oool3000000030?ooo`000000000006h0oooo00<000000?ooo`3oool09P3oool7
00000640oooo000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool09P3oool700000640oooo000:
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo07D0oooo00<000000?ooo`3oool09P3oool700000640oooo00090?ooo`800000103o
ool2000000@0oooo0P00001h0?ooo`030000003oool0oooo02H0oooo1`00001Q0?ooo`00S`3oool0
0`000000oooo0?ooo`0V0?ooo`L00000H@3oool008l0oooo00<000000?ooo`3oool09P3oool70000
0640oooo002?0?ooo`030000003oool0oooo02H0oooo1`00001Q0?ooo`00S`3oool00`000000oooo
0?ooo`0?0?ooo`80000000<0oooo0000000000000P3oool5000000/0oooo1`00001Q0?ooo`00S`3o
ool00`000000oooo0000000<000000@0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`0;0?ooo`L00000H@3oool008l0oooo00<000000?ooo`000000300000050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool02`3oool700000640oooo000I0?ooo`@00000LP3oool00`00
0000oooo0?ooo`0?0?ooo`80000000<0oooo000000000000103oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo06D0oooo000J0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo06D0oooo000J0?ooo`030000
003oool0oooo0780oooo00<000000?ooo`3oool05`3oool2000000d0oooo00<000000?ooo`3oool0
I@3oool001T0oooo1000001b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0I@3o
ool008l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1U0?ooo`00S`3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo06D0oooo002?0?ooobX00000I`3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.05261, -0.648943, \
0.00733523, 0.00733523}, {{7.125, 279.813}, {172.688, 4.1875}} -> {-6.55507, \
-11.7572, 0.234769, 0.723552}, {{143.5, 184.375}, {47.5625, 6.625}} -> \
{-11.8961, -11.7507, 0.0822027, 0.0900315}, {{145.688, 157.813}, {45.5, \
34.375}} -> {-12.6414, -38.3928, 0.0865988, 0.28024}, {{145.688, 157.813}, \
{32.625, 21.5}} -> {-12.6414, -42.0009, 0.0865988, 0.28024}, {{145.688, \
157.813}, {19.75, 8.625}} -> {-12.6414, -45.609, 0.0865988, 0.28024}}]
}, Open  ]],

Cell["Here are shown the numerical values  ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[{t, \ x1[t], \ x2[t], \ x3[t], \ x4[t]}, \ {t, \ 1, \ 100, \ 5}] // 
      TableForm\)], "Input",
  CellLabel->"In[108]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "48.57202270463162`", "99.93431770904097`", 
            "4.996715885452028`", "1.9361571738162373`"},
          {"6", "18.768398934164505`", "45.50715696606199`", 
            "15.389587458346252`", "0.0007654939834365429`"},
          {"11", "11.927930631553087`", "22.062687390878132`", 
            "8.334747917515596`", "5.041446856508821`"},
          {"16", "5.387964688265681`", "13.06151817259504`", 
            "7.006673172596372`", "0.0009593778862005479`"},
          {"21", "3.925172669077867`", "6.71480660284464`", 
            "3.3640531793926947`", "2.053491116848357`"},
          {"26", "1.7981803429230032`", "4.358941701025341`", 
            "2.5585132549252414`", "0.000382513014332083`"},
          {"31", "1.3525812641897588`", "2.2734070274596303`", 
            "1.2053089643527626`", "0.7368760605275262`"},
          {"36", "0.6215025245257223`", "1.5065593625234566`", 
            "0.9003931673285243`", "0.0001367635308450717`"},
          {"41", "0.4706059122171747`", "0.7881245733516329`", 
            "0.4226295819652502`", "0.25845513977291656`"},
          {"46", "0.21637252817558958`", "0.5244988770390641`", 
            "0.31460354640635724`", "0.000047936313342756896`"},
          {"51", "0.16405872366977178`", "0.2745484010634006`", 
            "0.14756264717791756`", "0.09024590160233481`"},
          {"56", "0.07543926785941715`", "0.18286884470394463`", 
            "0.10976765136702578`", "0.00001673578998121505`"},
          {"61", "0.057215238596922575`", "0.09573428039783677`", 
            "0.0514782976734024`", "0.031483310793381736`"},
          {"66", "0.026309983568870574`", "0.06377681125314391`", 
            "0.03828784005656782`", "5.838066303898102`*^-6"},
          {"71", "0.01995530487676212`", "0.0333888363741175`", 
            "0.0179555157413881`", "0.010981337037217384`"},
          {"76", "0.00917633646591293`", "0.02224393167204066`", 
            "0.013354338848870197`", "2.0362286344738747`*^-6"},
          {"81", "0.006960044247283955`", "0.01164534677459971`", 
            "0.006262628688260001`", "0.003830138090170335`"},
          {"86", "0.0032005434329115496`", "0.007758288263029781`", 
            "0.004657763742892909`", "7.096442716688101`*^-7"},
          {"91", "0.0024275385162888926`", "0.004061677352724006`", 
            "0.0021843109565519605`", "0.0013358883433798655`"},
          {"96", "0.0011162934611880762`", "0.0027059528243378894`", 
            "0.0016245500329952862`", "2.4841867708992273`*^-7"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[108]//TableForm="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Michaelis-Menten ", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["One compartmental with impulsive input", "SubsubsectionIcon"],

Cell["\<\
The one compartmental  Michaeles-Menten model is given by equation \
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(\(x\& . \)\_1\)]],
  "(t) = - ",
  Cell[BoxData[
      \(\(V\_m\ x\_1[t]\)\/\(k\_m + x\_1[t]\)\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`b\_1\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`u\_1\)]],
  "[t]"
}], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      RowBox[{
        RowBox[{\(b\_1\), " ", 
          RowBox[{
            FormBox[\(u\_1\),
              "TraditionalForm"], "[", "t", "]"}]}], "=", 
        " ", \(\(D\_1\) \[Delta][t]\)}]]],
  ", this mean that the initial condion is   ",
  Cell[BoxData[
      \(x\_1[0] = \ D\_1\)]],
  ". Here is the solution when",
  Cell[BoxData[
      \({D\_1 \[Rule] \ 1, k\_m\  \[Rule] \ 1.2, \ V\_m\  \[Rule] \ 15}\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m[t_] = \ \(\(x\_1[
          t]\)\(/.\)\(DSolve[{\(x\_1'\)[
                  t] + \(15\ x\_1[t]\)\/\(1.2 + x\_1[t]\) == 0, \ 
            x\_1[0]\  \[Equal] 1}, x\_1[t], \ t]\)\(\ \ \)\)\)], "Input",
  CellLabel->"In[109]:="],

Cell[BoxData[
    \({1.2000000000000002`\ ProductLog[
          0.8333333333333333`\ \[ExponentialE]\^\(\(\(0.8333333333333334`\)\(\
\[InvisibleSpace]\)\) - 12.5`\ t\)]}\)], "Output",
  CellLabel->"Out[109]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[m[t], \ {t, \ 0, 1}, \ PlotRange \[Rule] \ All]\)], "Input",
  CellLabel->"In[110]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.01471 0.588609 [
[.21429 .00221 -9 -9 ]
[.21429 .00221 9 0 ]
[.40476 .00221 -9 -9 ]
[.40476 .00221 9 0 ]
[.59524 .00221 -9 -9 ]
[.59524 .00221 9 0 ]
[.78571 .00221 -9 -9 ]
[.78571 .00221 9 0 ]
[.97619 .00221 -3 -9 ]
[.97619 .00221 3 0 ]
[.01131 .13243 -18 -4.5 ]
[.01131 .13243 0 4.5 ]
[.01131 .25015 -18 -4.5 ]
[.01131 .25015 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01471 m
.21429 .02096 L
s
[(0.2)] .21429 .00221 0 1 Mshowa
.40476 .01471 m
.40476 .02096 L
s
[(0.4)] .40476 .00221 0 1 Mshowa
.59524 .01471 m
.59524 .02096 L
s
[(0.6)] .59524 .00221 0 1 Mshowa
.78571 .01471 m
.78571 .02096 L
s
[(0.8)] .78571 .00221 0 1 Mshowa
.97619 .01471 m
.97619 .02096 L
s
[(1)] .97619 .00221 0 1 Mshowa
.125 Mabswid
.07143 .01471 m
.07143 .01846 L
s
.11905 .01471 m
.11905 .01846 L
s
.16667 .01471 m
.16667 .01846 L
s
.2619 .01471 m
.2619 .01846 L
s
.30952 .01471 m
.30952 .01846 L
s
.35714 .01471 m
.35714 .01846 L
s
.45238 .01471 m
.45238 .01846 L
s
.5 .01471 m
.5 .01846 L
s
.54762 .01471 m
.54762 .01846 L
s
.64286 .01471 m
.64286 .01846 L
s
.69048 .01471 m
.69048 .01846 L
s
.7381 .01471 m
.7381 .01846 L
s
.83333 .01471 m
.83333 .01846 L
s
.88095 .01471 m
.88095 .01846 L
s
.92857 .01471 m
.92857 .01846 L
s
.25 Mabswid
0 .01471 m
1 .01471 L
s
.02381 .13243 m
.03006 .13243 L
s
[(0.2)] .01131 .13243 1 0 Mshowa
.02381 .25015 m
.03006 .25015 L
s
[(0.4)] .01131 .25015 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .16186 m
.02756 .16186 L
s
.02381 .19129 m
.02756 .19129 L
s
.02381 .22072 m
.02756 .22072 L
s
.02381 .27958 m
.02756 .27958 L
s
.02381 .30901 m
.02756 .30901 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .60332 m
.06244 .45317 L
.10458 .31947 L
.14415 .22264 L
.18221 .15381 L
.20178 .12653 L
.22272 .10259 L
.24259 .0842 L
.26416 .06826 L
.28316 .05711 L
.30409 .04737 L
.32393 .04014 L
.34496 .03417 L
.36437 .02989 L
.38525 .02631 L
.40638 .02353 L
.42647 .02151 L
.44628 .01996 L
.46466 .01884 L
.48519 .01787 L
.50379 .01719 L
.52304 .01664 L
.54386 .01618 L
.5638 .01584 L
.58486 .01557 L
.6045 .01537 L
.62283 .01523 L
.64319 .01511 L
.66174 .01502 L
.68083 .01495 L
.70159 .0149 L
.72136 .01485 L
.74237 .01482 L
.76184 .01479 L
.78012 .01478 L
.8003 .01476 L
.81881 .01475 L
.83773 .01474 L
.85843 .01473 L
.87804 .01473 L
.89899 .01472 L
.92034 .01472 L
.94049 .01472 L
.95907 .01472 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[110]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00@P3oool2000000@0oooo0P0000030?ooo`@000009@3oool2000000@0oooo0P0000050?oo
o`<000008`3oool2000000@0oooo0P0000030?ooo`<000009P3oool2000000@0oooo0P0000040?oo
o`800000:`3oool5000000D0oooo00110?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool09@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0240oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000T0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000;03oool00`000000oooo0?ooo`050?ooo`00@@3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo02@0oooo00@000000?ooo`3oool00000203oool5
00000280oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000T0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000;03oool00`000000oooo0?ooo`050?oo
o`00@@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo02<0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000S0?ooo`040000003oool0oooo000000P0oooo
0`00000U0?ooo`040000003oool0oooo000000T0oooo0P00000]0?ooo`030000003oool0oooo00D0
oooo00110?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000903oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0000002<0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`0T0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000;03oool00`000000oooo0?ooo`050?ooo`00@P3oool2000000X0oooo0P00000V0?ooo`800000
2`3oool2000002@0oooo0P00000:0?ooo`<000009@3oool2000000X0oooo0P00000/0?ooo`800000
1`3oool00?l0oooo8@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`00
0000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo
00<000000?ooo`3oool0o`3oool90?ooo`003`3ooooo0000014000000@3oool001D0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo5@000008
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool0;`3oool;000002X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo05d0oooo1P00002U0?ooo`00
5@3oool00`000000oooo0?ooo`1H0?ooo`D00000Z`3oool001D0oooo00<000000?ooo`3oool0D`3o
ool500000;00oooo000E0?ooo`030000003oool0oooo0540oooo0P00002e0?ooo`005@3oool00`00
0000oooo0?ooo`1>0?ooo`<00000]`3oool001D0oooo0P00001<0?ooo`<00000^P3oool001D0oooo
00<000000?ooo`3oool0B03oool300000;d0oooo000E0?ooo`030000003oool0oooo04H0oooo0P00
00300?ooo`005@3oool00`000000oooo0?ooo`140?ooo`800000`P3oool001D0oooo00<000000?oo
o`3oool0@P3oool200000<@0oooo000E0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0a03oool001D0oooo00<000000?ooo`3oool0?`3oool200000<L0oooo000E0?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool0a`3oool001D0oooo0P00000m0?ooo`800000bP3oool0
01D0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3:0?ooo`005@3oool00`000000
oooo0?ooo`0i0?ooo`800000c@3oool001D0oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`3=0?ooo`005@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0<h0oooo000E
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0c`3oool001D0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`3@0?ooo`005@3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo0=40oooo000E0?ooo`800000=03oool00`000000oooo0?ooo`3B0?ooo`005@3o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0=<0oooo000E0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool0e03oool001D0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`3E0?ooo`005@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0=H0
oooo000E0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0e`3oool00080oooo0P00
00040?ooo`8000000`3oool4000000@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`3H0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`3I0?ooo`0000D0oooo0000003oool0oooo0000
00090?ooo`030000003oool0oooo00@0oooo0`00000/0?ooo`030000003oool0oooo0=T0oooo0000
1@3oool000000?ooo`3oool0000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo0=X0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0=/0oooo
00020?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`3K0?ooo`005@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0=`0oooo000E0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0g03oool001D0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`3M0?ooo`005@3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo0=h0oooo000E0?ooo`800000:03oool00`000000oooo0?ooo`3N0?ooo`005@3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0=l0oooo000E0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0g`3oool001D0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`3P0?ooo`005@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0>00oooo
000E0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0h@3oool001D0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`3Q0?ooo`005@3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0>80oooo000E0?ooo`8000008`3oool00`000000oooo0?ooo`3S0?ooo`00
5@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0><0oooo000E0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool0i03oool001D0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`3T0?ooo`005@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
0>D0oooo000E0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0i@3oool001D0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3V0?ooo`005@3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo0>H0oooo000E0?ooo`8000007`3oool00`000000oooo0?ooo`3W
0?ooo`005@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0>L0oooo000E0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0j03oool001D0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`3X0?ooo`005@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0>T0oooo000E0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0j@3oool0
0080oooo0P0000040?ooo`8000001@3oool3000000<0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`3Y0?ooo`0000D0oooo0000003oool0oooo0000000;0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`3Z0?ooo`0000D0oooo0000003o
ool0oooo000000080?ooo`D000000`3oool3000001/0oooo00<000000?ooo`3oool0jP3oool00005
0?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0j`3oool000050?ooo`000000oooo0?ooo`0000002@3oool0
0`000000oooo000000040?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0j`3oool0
0080oooo0P00000;0?ooo`800000103oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
0>/0oooo000E0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0k03oool001D0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3/0?ooo`005@3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo0>d0oooo000E0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0k@3oool001D0oooo0P00000H0?ooo`030000003oool0oooo0>h0oooo000E0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0kP3oool001D0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`3^0?ooo`005@3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo0>l0oooo000E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0k`3oool0
01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3`0?ooo`005@3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo0?00oooo000E0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0l03oool001D0oooo0P00000E0?ooo`030000003oool0oooo0?40oooo000E
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0l@3oool001D0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`3b0?ooo`005@3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0?80oooo000E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
lP3oool001D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3c0?ooo`005@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?<0oooo000E0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0l`3oool001D0oooo0P00000B0?ooo`030000003oool0oooo0?@0
oooo000E0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0m03oool001D0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`3d0?ooo`005@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0?D0oooo000E0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0m@3oool001D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3e0?ooo`00
0P3oool2000000@0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0?H0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?H0oooo00001@3oool00000
0?ooo`3oool0000000P0oooo00@000000?ooo`3oool00000103oool3000000l0oooo00<000000?oo
o`3oool0mP3oool000050?ooo`000000oooo0?ooo`000000203oool3000000D0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`3g0?ooo`0000D0oooo0000003oool0oooo000000090?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3g0?oo
o`000P3oool2000000X0oooo0`0000040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0m`3oool001D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3h0?ooo`005@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?P0oooo000E0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0n03oool001D0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`3i0?ooo`005@3oool2000000d0oooo00<000000?ooo`3oool0n@3oool001D0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3i0?ooo`005@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0?X0oooo000E0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0nP3oool001D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3j0?oo
o`005@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?/0oooo000E0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0n`3oool001D0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`3k0?ooo`005@3oool2000000X0oooo00<000000?ooo`3oool0o03oool0
01D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3l0?ooo`005@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0?`0oooo000E0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0o@3oool001D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`3m0?ooo`005@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?d0oooo000E0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0oP3oool001D0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`3n0?ooo`005@3oool2000000P0oooo00<000000?ooo`3oool0
oP3oool001D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3n0?ooo`005@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo000E0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0o`3oool001D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`3o0?ooo`005@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo
00020?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0o`3oool10?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`40oooo
00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool00000103oool3000000D0
oooo00<000000?ooo`3oool0o`3oool10?ooo`0000D0oooo0000003oool0oooo000000090?ooo`80
00001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo0@3oool000050?oo
o`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0o`3oool20?ooo`000P3oool2000000X0oooo0P0000050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3oool20?ooo`005@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0?l0oooo0P3oool001D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`3o0?ooo`80oooo000E0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0o`3oool30?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0?l0oooo0`3oool001D0oooo0P0000040?ooo`030000003oool0oooo0?l0oooo0`3oool001D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000E0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0o`3oool40?ooo`005@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0?l0oooo103oool001D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`3o0?ooo`@0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0o`3oool40?ooo`005@3oool01@000000oooo0?ooo`3oool000000?l0oooo1`3oool001D0oooo
00D000000?ooo`3oool0oooo0000003o0?ooo`L0oooo000E0?ooo`8000000P3oool00`000000oooo
0?ooo`3o0?ooo`D0oooo000E0?ooo`050000003oool0oooo0?ooo`000000o`3oool70?ooo`005@3o
ool010000000oooo0?ooo`00003o0?ooo`P0oooo000E0?ooo`040000003oool0oooo00000?l0oooo
203oool001D0oooo00@000000?ooo`3oool00000o`3oool80?ooo`005@3oool010000000oooo0?oo
o`00003o0?ooo`P0oooo000E0?ooo`030000003oool000000?l0oooo2@3oool001D0oooo00<00000
0?ooo`000000o`3oool90?ooo`005@3oool300000?l0oooo2@3oool001D0oooo00<000000?ooo`00
0000o`3oool90?ooo`005@3oool200000?l0oooo2P3oool001D0oooo0P00003o0?ooo`X0oooo000E
0?ooo`800000o`3oool:0?ooo`005@3oool200000?l0oooo2P3oool000d0oooo1@0000030?ooo`03
0000003oool0oooo0?l0oooo2@3oool000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo000?0?ooo`030000003oool0oooo00<0oooo0`00003o0?ooo`T0oooo000?
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool90?ooo`003`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo2@3oool000h0oooo0P0000050?ooo`03
0000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.082995, -0.0774786, \
0.00386185, 0.00624856}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[110]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Bicompartmental with impulsive input", "SubsubsectionIcon"],

Cell[BoxData[
    \(Clear[x1, x2]\)], "Input",
  CellLabel->"In[111]:="],

Cell["\<\
The bicompartmental  Michaeles-Menten model given by equation \
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(\(x\& . \)\_1\)]],
  "(t) =  - ",
  Cell[BoxData[
      \(k\_21\)]],
  " ",
  Cell[BoxData[
      \(x\_1\)]],
  "(t)  + ",
  Cell[BoxData[
      \(k\_12\)]],
  " ",
  Cell[BoxData[
      \(x\_2\)]],
  "(t) -  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(k\_1\)\(\ \)\(\(x\_1\)(t)\)\(\ \
\)\)\)\/\(k\_2 + \ \(x\_1\)(t)\)\)]],
  " \n",
  Cell[BoxData[
      \(\(x\& . \)\_2\)]],
  "(t) = ",
  Cell[BoxData[
      \(k\_21\)]],
  " ",
  Cell[BoxData[
      \(x\_1\)]],
  "(t)  -  ",
  Cell[BoxData[
      \(k\_12\)]],
  " ",
  Cell[BoxData[
      \(x\_2\)]],
  "(t) \n",
  Cell[BoxData[
      \(x\_1\)]],
  "(0) = ",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  " , ",
  Cell[BoxData[
      \(x\_2\)]],
  "(0) = 0"
}], "NumberedEquation"],

Cell["with clearance coeffs: ", "Text"],

Cell[BoxData[
    \(k\_1\  = \ 0.2; \ k\_2\  = \ 0.3; k\_12\  = \ 0.03; 
    k\_21\  = \ 0.02; \)], "Input",
  CellLabel->"In[112]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq1\  = \ \(x1'\)[t] + k\_21\ x1[t] - 
          k\_12\ x2[t] + \(k\_1\ x1[t]\)\/\(k\_2 + x1[t]\) == 0\)], "Input",
  CellLabel->"In[113]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{\(0.02`\ x1[t]\), 
        "+", \(\(0.2`\ x1[t]\)\/\(\(\(0.3`\)\(\[InvisibleSpace]\)\) + 
              x1[t]\)\), "-", \(0.03`\ x2[t]\), "+", 
        RowBox[{
          SuperscriptBox["x1", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
      "0"}]], "Output",
  CellLabel->"Out[113]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq2\  = \ \(x2'\)[t] - k\_21\ x1[t] + k\_12\ x2[t] == 0\)], "Input",
  CellLabel->"In[114]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\(-0.02`\)\ x1[t]\), "+", \(0.03`\ x2[t]\), "+", 
        RowBox[{
          SuperscriptBox["x2", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
      "0"}]], "Output",
  CellLabel->"Out[114]="]
}, Open  ]],

Cell["It can be solved using NDSolve", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(NDSolve[{eq1, \ eq2, x1[0]\  == \ 1, x2[0]\  == \ 0}, {x1[t], 
        x2[t]}, \ {t, 0, 10}]\)\(\ \ \ \)\)\)], "Input",
  CellLabel->"In[115]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{\(x1[t]\), "\[Rule]", 
            RowBox[{
              TagBox[\(InterpolatingFunction[{{0.`, 10.`}}, "<>"]\),
                False,
                Editable->False], "[", "t", "]"}]}], ",", 
          RowBox[{\(x2[t]\), "\[Rule]", 
            RowBox[{
              TagBox[\(InterpolatingFunction[{{0.`, 10.`}}, "<>"]\),
                False,
                Editable->False], "[", "t", "]"}]}]}], "}"}], "}"}]], "Output",\

  CellLabel->"Out[115]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[Evaluate[{x1[t], x2[t]} /. %], {t, 0, 10}, PlotPoints \[Rule] 100, 
      PlotRange \[Rule] 
        All, \ \ PlotStyle \[Rule] {{AbsoluteThickness[
              2]}, {AbsoluteThickness[0.5]}}, 
      PlotLegend \[Rule] {"\<x1\>", "\<x2\>"}, 
      LegendPosition \[Rule] {0, \ 0.2}]\)], "Input",
  CellLabel->"In[116]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .80902 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.313564 0.47619 [
[ 0 0 0 0 ]
[ 1 .80902 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0192623 0.97619 0.607866 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.588604 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
2 Mabswid
.02381 .60332 m
.03318 .59328 L
.04339 .58241 L
.05298 .57226 L
.06221 .56256 L
.07203 .5523 L
.08148 .54248 L
.09153 .53212 L
.10121 .5222 L
.11052 .51273 L
.12043 .50272 L
.12997 .49315 L
.13914 .48401 L
.14891 .47435 L
.15831 .46513 L
.1683 .45539 L
.17793 .44609 L
.18719 .43721 L
.19704 .42784 L
.20653 .41889 L
.21661 .40946 L
.22632 .40046 L
.23566 .39188 L
.2456 .38283 L
.25518 .3742 L
.26438 .36597 L
.27418 .3573 L
.28361 .34904 L
.29364 .34035 L
.3033 .33207 L
.31259 .32418 L
.32248 .31589 L
.332 .30799 L
.34115 .30048 L
.3509 .29259 L
.36028 .28508 L
.37025 .27719 L
.37985 .2697 L
.38909 .26259 L
.39893 .25513 L
.40839 .24804 L
.41845 .24063 L
.42814 .23359 L
.43747 .22692 L
.44739 .21994 L
.45694 .21334 L
.46613 .20709 L
.47591 .20055 L
.48532 .19437 L
.49532 .18792 L
Mistroke
.50496 .18183 L
.51423 .17608 L
.5241 .17009 L
.5336 .16445 L
.54369 .15858 L
.55342 .15306 L
.56278 .14787 L
.57273 .14248 L
.58231 .13741 L
.59153 .13266 L
.60135 .12774 L
.61079 .12313 L
.62083 .11836 L
.6305 .1139 L
.63981 .10973 L
.64971 .10543 L
.65924 .10142 L
.6684 .09769 L
.67816 .09384 L
.68755 .09025 L
.69754 .08658 L
.70716 .08317 L
.71641 .08 L
.72625 .07675 L
.73573 .07375 L
.7458 .07069 L
.75551 .06785 L
.76485 .06524 L
.77478 .06257 L
.78434 .06012 L
.79354 .05786 L
.80333 .05556 L
.81276 .05344 L
.82278 .0513 L
.83243 .04934 L
.84171 .04754 L
.85159 .04571 L
.8611 .04404 L
.87025 .04252 L
.87999 .04097 L
.88936 .03956 L
.89932 .03814 L
.90892 .03685 L
.91815 .03567 L
.92798 .03448 L
.93743 .0334 L
.94749 .03232 L
.95717 .03133 L
.96649 .03044 L
.97619 .02956 L
Mistroke
Mfstroke
.5 Mabswid
.02381 .01472 m
.03318 .01586 L
.04339 .01708 L
.05298 .01821 L
.06221 .01927 L
.07203 .02037 L
.08148 .02141 L
.09153 .02249 L
.10121 .02351 L
.11052 .02446 L
.12043 .02546 L
.12997 .02639 L
.13914 .02727 L
.14891 .02818 L
.15831 .02904 L
.1683 .02993 L
.17793 .03076 L
.18719 .03154 L
.19704 .03235 L
.20653 .03311 L
.21661 .0339 L
.22632 .03464 L
.23566 .03533 L
.2456 .03604 L
.25518 .0367 L
.26438 .03733 L
.27418 .03797 L
.28361 .03857 L
.29364 .03919 L
.3033 .03976 L
.31259 .0403 L
.32248 .04086 L
.332 .04137 L
.34115 .04185 L
.3509 .04234 L
.36028 .0428 L
.37025 .04327 L
.37985 .0437 L
.38909 .04411 L
.39893 .04452 L
.40839 .0449 L
.41845 .04529 L
.42814 .04565 L
.43747 .04598 L
.44739 .04632 L
.45694 .04662 L
.46613 .04691 L
.47591 .0472 L
.48532 .04746 L
.49532 .04773 L
Mistroke
.50496 .04797 L
.51423 .0482 L
.5241 .04842 L
.5336 .04862 L
.54369 .04883 L
.55342 .04901 L
.56278 .04917 L
.57273 .04934 L
.58231 .04949 L
.59153 .04962 L
.60135 .04975 L
.61079 .04986 L
.62083 .04997 L
.6305 .05007 L
.63981 .05016 L
.64971 .05024 L
.65924 .05031 L
.6684 .05037 L
.67816 .05043 L
.68755 .05048 L
.69754 .05052 L
.70716 .05055 L
.71641 .05058 L
.72157 .05059 L
.72625 .0506 L
.73119 .0506 L
.73573 .05061 L
.74039 .05061 L
.74284 .05062 L
.74544 .05062 L
.74773 .05062 L
.74902 .05062 L
.74963 .05062 L
.75019 .05062 L
.75071 .05062 L
.75128 .05062 L
.75156 .05062 L
.75186 .05062 L
.75218 .05062 L
.75247 .05062 L
.75273 .05062 L
.75302 .05062 L
.75332 .05062 L
.7536 .05062 L
.75386 .05062 L
.7541 .05062 L
.75463 .05062 L
.75519 .05062 L
.75581 .05062 L
.75705 .05062 L
Mistroke
.7582 .05062 L
.75928 .05062 L
.76171 .05062 L
.76432 .05062 L
.76945 .05061 L
.77432 .05061 L
.78358 .05059 L
.79344 .05057 L
.80293 .05055 L
.81302 .05052 L
.82273 .05049 L
.83208 .05045 L
.84203 .05041 L
.85161 .05037 L
.86082 .05032 L
.87062 .05027 L
.88006 .05022 L
.89009 .05016 L
.89975 .0501 L
.90905 .05004 L
.91894 .04998 L
.92847 .04991 L
.93762 .04985 L
.94737 .04978 L
.95676 .04971 L
.96674 .04963 L
.97619 .04956 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 g
.52381 .38499 m
.52381 .76595 L
.87164 .76595 L
.87164 .38499 L
F
1 g
.5 .4088 m
.5 .78975 L
.84783 .78975 L
.84783 .4088 L
F
0 g
.001 w
[ ] 0 setdash
.5 .4088 m
.84783 .4088 L
.84783 .78975 L
.5 .78975 L
.5 .4088 L
s
% Start of sub-graphic
p
0.5 0.408802 0.847826 0.789755 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0297619 0.297619 [
[ 0 0 0 0 ]
[ 1 1.09524 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.09524 L
0 1.09524 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0535714 0.35119 0.35119 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
2 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .20238 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x1) show
75.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.39881 0.35119 0.696429 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .54762 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x2) show
75.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.744048 0.35119 1.04167 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
2 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .89286 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x1) show
75.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .80902 L
0 .80902 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[116]:=",
  ImageSize->{288, 232.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000j2000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00B`3oool4000002l0oooo0`00000/0?ooo`<00000;`3oool2000002/0oooo1@0000020?oo
o`8000002`3oool004/0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0[0?ooo`04
0000003oool0oooo000002d0oooo00@000000?ooo`3oool00000;03oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool0;@3oool5
000002`0oooo00@000000?ooo`3oool00000;@3oool010000000oooo0?ooo`00000/0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`00C@3oool00`000000oooo
0?ooo`0/0?ooo`040000003oool0oooo000002d0oooo0`00000_0?ooo`800000;@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool004/0oooo00@000000?ooo`3o
ool00000;P3oool00`000000oooo0000000^0?ooo`030000003oool0oooo02d0oooo00@000000?oo
o`3oool00000;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203o
ool004`0oooo0P00000`0?ooo`800000;P3oool3000002h0oooo0P00000/0?ooo`800000103oool2
000000/0oooo003o0?ooob40oooo003o0?ooob40oooo000L0?ooo`030000003oool0oooo0?l0oooo
0P3oool001`0oooo00<000000?ooo`3oool0o`3oool20?ooo`00703oool00`000000oooo0?ooo`3o
0?ooo`80oooo000F0?ooool00000100000070?ooo`00703oool9000000<0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0<0?ooo`00703oool00`000000oooo0?ooo`060?ooo`X00000
7P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00`0oooo000L0?ooo`030000003o
ool0oooo0100oooo2@00003X0?ooo`00703oool00`000000oooo0?ooo`0I0?ooo`X00000bP3oool6
000000h0oooo000L0?ooo`030000003oool0oooo02<0oooo3@00002f0?ooo`d000003P3oool001`0
oooo00<000000?ooo`3oool0<03oool?000009d0oooo4P00000C0?ooo`00703oool00`000000oooo
0?ooo`0o0?oooa400000Q`3oool@000001X0oooo000L0?ooo`800000D@3ooolF000006X0oooo3@00
000T0?ooo`00703oool00`000000oooo0?ooo`1V0?ooobd00000>03oool=00000180oooo2@00000>
0?ooo`00703oool00`000000oooo0?ooo`2C0?oooeL000005`3oool001`0oooo00<000000?ooo`3o
ool0``3oool9000003D0oooo000L0?ooo`030000003oool0oooo0;h0oooo2@00000j0?ooo`00703o
ool00`000000oooo0?ooo`2i0?ooo`/00000?@3oool001`0oooo00<000000?ooo`3oool0]`3oool8
00000480oooo000L0?ooo`030000003oool0oooo0;@0oooo1P0000170?ooo`00703oool200000;00
oooo2@0000190?ooo`00703oool00`000000oooo0?ooo`2]0?ooo`P00000C03oool001`0oooo00<0
00000?ooo`3oool0ZP3oool600000540oooo000L0?ooo`030000003oool0oooo0:P0oooo1P00001C
0?ooo`00703oool00`000000oooo0?ooo`2U0?ooo`H00000EP3oool001`0oooo00<000000?ooo`3o
ool0X`3oool6000005P0oooo000L0?ooo`030000003oool0oooo0:40oooo1@00001K0?ooo`00703o
ool2000009l0oooo1P00001M0?ooo`00703oool00`000000oooo0?ooo`2L0?ooo`H00000G`3oool0
01`0oooo00<000000?ooo`3oool0V@3oool600000680oooo000L0?ooo`030000003oool0oooo09L0
oooo1P00001T0?ooo`00703oool00`000000oooo0?ooo`2D0?ooo`H00000I`3oool001`0oooo00<0
00000?ooo`3oool0T`3oool5000006T0oooo00080?ooo`800000103oool2000000<0oooo10000005
0?ooo`030000003oool0oooo0980oooo0`00001/0?ooo`001`3oool010000000oooo0?ooo`000008
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool5000006d0oooo00070?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool01@3oool2000008h0oooo1P00001^
0?ooo`001`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0RP3oool600000740oooo00070?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`290?ooo`D00000L`3oool000P0oooo0P00000:
0?ooo`8000001P3oool00`000000oooo0?ooo`280?ooo`<00000MP3oool001`0oooo00<000000?oo
o`3oool0Q@3oool5000007L0oooo000L0?ooo`030000003oool0oooo08@0oooo1@00001h0?ooo`00
703oool00`000000oooo0?ooo`230?ooo`<00000N`3oool001`0oooo0P0000210?ooo`D00000O03o
ool001`0oooo00<000000?ooo`3oool0O`3oool5000007d0oooo000L0?ooo`030000003oool0oooo
07h0oooo0`0000200?ooo`00703oool00`000000oooo0?ooo`1k0?ooo`D00000P@3oool001`0oooo
00<000000?ooo`3oool0NP3oool500000880oooo000L0?ooo`030000003oool0oooo07T0oooo0`00
00250?ooo`00703oool00`000000oooo0?ooo`1f0?ooo`D00000QP3oool001`0oooo00<000000?oo
o`3oool0M@3oool5000008L0oooo000L0?ooo`800000M@3oool3000008X0oooo000L0?ooo`030000
003oool0oooo0740oooo1@00002;0?ooo`00703oool00`000000oooo0?ooo`1`0?ooo`D00000S03o
ool001`0oooo00<000000?ooo`3oool0K`3oool3000008l0oooo000L0?ooo`030000003oool0oooo
06d0oooo1000002@0?ooo`00703oool00`000000oooo0?ooo`1/0?ooo`@00000T@3oool001`0oooo
00<000000?ooo`3oool0JP3oool4000009<0oooo000L0?ooo`030000003oool0oooo06P0oooo1@00
002D0?ooo`00703oool2000006P0oooo1000002F0?ooo`00703oool00`000000oooo0?ooo`1V0?oo
o`<00000V03oool001`0oooo00<000000?ooo`3oool0I@3oool3000009T0oooo000L0?ooo`030000
003oool0oooo06<0oooo1000002J0?ooo`00703oool00`000000oooo0?ooo`1R0?ooo`@00000V`3o
ool000P0oooo0P0000040?ooo`8000001@3oool3000000@0oooo00<000000?ooo`3oool0H@3oool3
000009d0oooo00070?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`1P0?ooo`<00000WP3oool000L0oooo00@000000?ooo`3oool00000203oool5
000000@0oooo0P00001N0?ooo`D00000W`3oool000L0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo05`0oooo1@00002P0?ooo`001`3oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0F`3o
ool300000:<0oooo00080?ooo`8000002`3oool2000000D0oooo00<000000?ooo`3oool0FP3oool3
00000:@0oooo000L0?ooo`030000003oool0oooo05T0oooo0`00002U0?ooo`00703oool00`000000
oooo0?ooo`1G0?ooo`@00000YP3oool001`0oooo00<000000?ooo`3oool0EP3oool400000:L0oooo
000L0?ooo`030000003oool0oooo05@0oooo1000002Y0?ooo`00703oool2000005@0oooo1000002Z
0?ooo`00703oool00`000000oooo0?ooo`1B0?ooo`<00000[03oool001`0oooo00<000000?ooo`3o
ool0D@3oool300000:d0oooo000L0?ooo`030000003oool0oooo0500oooo0`00002^0?ooo`00703o
ool00`000000oooo0?ooo`1?0?ooo`<00000[`3oool001`0oooo00<000000?ooo`3oool0C@3oool4
00000;00oooo000L0?ooo`030000003oool0oooo04`0oooo1000002a0?ooo`00703oool2000004`0
oooo0`00002c0?ooo`00703oool00`000000oooo0?ooo`1:0?ooo`<00000]03oool001`0oooo00<0
00000?ooo`3oool0B03oool400000;D0oooo000L0?ooo`030000003oool0oooo04L0oooo1000002f
0?ooo`00703oool00`000000oooo0?ooo`160?ooo`<00000^03oool001`0oooo00<000000?ooo`3o
ool0A@3oool300000;T0oooo000L0?ooo`030000003oool0oooo04<0oooo1000002j0?ooo`00703o
ool00`000000oooo0?ooo`120?ooo`@00000^`3oool001`0oooo0P0000130?ooo`800000_@3oool0
01`0oooo00<000000?ooo`3oool0@@3oool200000;h0oooo000L0?ooo`030000003oool0oooo0400
oooo0P00002o0?ooo`00703oool00`000000oooo0?ooo`0n0?ooo`<00000`03oool001`0oooo00<0
00000?ooo`3oool0?@3oool400000<00oooo000L0?ooo`030000003oool0oooo03`0oooo0`000032
0?ooo`00203oool2000000@0oooo0P0000030?ooo`<000001P3oool00`000000oooo0?ooo`0k0?oo
o`<00000``3oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo03T0oooo100000340?ooo`001`3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000D0oooo0P00000i0?ooo`@00000a@3oool000L0oooo00@00000
0?ooo`3oool00000203oool3000000H0oooo00<000000?ooo`3oool0=`3oool300000<L0oooo0007
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0f0?ooo`<00000?P3ooomT000002H0oooo00080?ooo`8000002P3oool3000000D0oooo00<00000
0?ooo`3oool0=@3oool3000003l0ooooI000000V0?ooo`00703oool00`000000oooo0?ooo`0d0?oo
o`<00000@03ooomT000002H0oooo000L0?ooo`030000003oool0oooo03<0oooo0`0000110?ooof@0
00009P3oool001`0oooo00<000000?ooo`3oool0<P3oool300000480ooooI000000V0?ooo`00703o
ool200000380oooo0`0000130?ooof@000009P3oool001`0oooo00<000000?ooo`3oool0;`3oool4
000003d0ooooJ`00000V0?ooo`00703oool00`000000oooo0?ooo`0^0?ooo`@00000?P3oool00`00
0000oooo0?ooo`1Q0?ooo`L000009P3oool001`0oooo00<000000?ooo`3oool0;P3oool200000400
oooo00<000000?ooo`3oool0H@3oool7000002H0oooo000L0?ooo`030000003oool0oooo02d0oooo
0P0000110?ooo`030000003oool0oooo0640oooo1`00000V0?ooo`00703oool00`000000oooo0?oo
o`0/0?ooo`800000@P3oool00`000000oooo0?ooo`1Q0?ooo`L000009P3oool001`0oooo00<00000
0?ooo`3oool0:P3oool3000004<0oooo00<000000?ooo`3oool0H@3oool7000002H0oooo000L0?oo
o`030000003oool0oooo02T0oooo100000130?ooo`030000003oool0oooo0640oooo1`00000V0?oo
o`00703oool2000002T0oooo0`0000150?ooo`030000003oool0oooo0640oooo1`00000V0?ooo`00
703oool00`000000oooo0?ooo`0W0?ooo`<00000AP3oool00`000000oooo0?ooo`1Q0?ooo`L00000
9P3oool001`0oooo00<000000?ooo`3oool09P3oool3000004L0oooo00<000000?ooo`3oool0H@3o
ool7000002H0oooo000L0?ooo`030000003oool0oooo02D0oooo0`0000180?ooo`030000003oool0
oooo0640oooo1`00000V0?ooo`00703oool00`000000oooo0?ooo`0T0?ooo`<00000B@3oool00`00
0000oooo0?ooo`1Q0?ooo`L000009P3oool001`0oooo00<000000?ooo`3oool08`3oool3000004X0
oooo00<000000?ooo`3oool0H@3oool7000002H0oooo000L0?ooo`030000003oool0oooo0280oooo
0`00001;0?ooo`030000003oool0oooo0640oooo1`00000V0?ooo`00703oool200000280oooo0`00
001<0?ooo`030000003oool0oooo0640oooo1`00000V0?ooo`00703oool00`000000oooo0?ooo`0P
0?ooo`<00000C@3oool00`000000oooo0?ooo`1Q0?ooo`L000009P3oool001`0oooo00<000000?oo
o`3oool07`3oool3000004h0oooo00<000000?ooo`3oool0H@3oool7000002H0oooo000L0?ooo`03
0000003oool0oooo01h0oooo0`00001?0?ooo`030000003oool0oooo0640oooo1`00000V0?ooo`00
703oool00`000000oooo0?ooo`0M0?ooo`<00000D03oool00`000000oooo0?ooo`0V0?ooo`800000
00<0oooo0000000000000P3oool5000002l0oooo1`00000V0?ooo`00703oool00`000000oooo0?oo
o`0L0?ooo`<00000D@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0000000D0oooo00<0
00000?ooo`3oool0;`3oool7000002H0oooo00080?ooo`800000103oool2000000@0oooo0P000006
0?ooo`030000003oool0oooo01/0oooo0`00001B0?ooo`030000003oool0oooo0080oooo7P000008
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0;`3oool7000002H0oooo00070?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`0J0?ooo`<00000D`3oool00`000000oooo0?ooo`020?oooah000001P3oool2000000030?ooo`00
0000000000@0oooo00<000000?ooo`3oool0;`3oool7000002H0oooo00070?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000001@3oool2000001X0oooo0`00001D0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool0;`3oool7000002H0oooo00070?ooo`040000003o
ool0oooo000000T0oooo0P0000060?ooo`030000003oool0oooo01P0oooo0`00001E0?ooo`030000
003oool0oooo02h0oooo0P00000a0?ooo`L000009P3oool000L0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo01L0oooo0`00001F0?ooo`03
0000003oool0oooo0640oooo1`00000V0?ooo`00203oool2000000X0oooo0P0000060?ooo`030000
003oool0oooo01H0oooo0`00001G0?ooo`030000003oool0oooo0640oooo1`00000V0?ooo`00703o
ool00`000000oooo0?ooo`0E0?ooo`<00000F03oool00`000000oooo0?ooo`1Q0?ooo`L000009P3o
ool001`0oooo00<000000?ooo`3oool0503oool3000005T0oooo00<000000?ooo`3oool0H@3oool7
000002H0oooo000L0?ooo`030000003oool0oooo01<0oooo0`00001J0?ooo`030000003oool0oooo
0640oooo1`00000V0?ooo`00703oool00`000000oooo0?ooo`0B0?ooo`<00000F`3oool00`000000
oooo0?ooo`1Q0?ooo`L000009P3oool001`0oooo0P00000B0?ooo`<00000G03oool00`000000oooo
0?ooo`1Q0?ooo`L000009P3oool001`0oooo00<000000?ooo`3oool0403oool3000005d0oooo00<0
00000?ooo`3oool0H@3oool7000002H0oooo000L0?ooo`030000003oool0oooo00l0oooo0`00001N
0?ooo`030000003oool0oooo0640oooo1`00000V0?ooo`00703oool00`000000oooo0?ooo`0>0?oo
o`<00000G`3oool00`000000oooo0?ooo`1Q0?ooo`L000009P3oool001`0oooo00<000000?ooo`3o
ool03P3oool200000600oooo00<000000?ooo`3oool0H@3oool7000002H0oooo000L0?ooo`030000
003oool0oooo00d0oooo0P00001Q0?ooo`030000003oool0oooo0640oooo1`00000V0?ooo`00703o
ool00`000000oooo0?ooo`0<0?ooo`800000HP3oool00`000000oooo0?ooo`1Q0?ooo`L000009P3o
ool001`0oooo0P00000;0?ooo`<00000H`3oool00`000000oooo0?ooo`1Q0?ooo`L000009P3oool0
01`0oooo00<000000?ooo`3oool02@3oool4000006<0oooo00<000000?ooo`3oool0H@3oool70000
02H0oooo000L0?ooo`030000003oool0oooo00T0oooo0P00001U0?ooo`030000003oool0oooo0640
oooo1`00000V0?ooo`00703oool00`000000oooo0?ooo`080?ooo`800000IP3oool00`000000oooo
0?ooo`1Q0?ooo`L000009P3oool001`0oooo00<000000?ooo`3oool01`3oool2000006L0oooo00<0
00000?ooo`3oool0H@3oool7000002H0oooo000L0?ooo`030000003oool0oooo00D0oooo0`00001X
0?ooo`030000003oool0oooo0640oooo1`00000V0?ooo`00703oool00`000000oooo0?ooo`040?oo
o`@00000J03oool00`000000oooo0?ooo`1Q0?ooo`L000009P3oool001`0oooo00<000000?ooo`3o
ool0103oool2000006X0oooo00<000000?ooo`3oool0H@3oool7000002H0oooo000L0?ooo`800000
103oool2000006/0oooo00<000000?ooo`3oool0H@3oool7000002H0oooo000L0?ooo`030000003o
ool0oooo0080oooo0P00001/0?ooo`030000003oool0oooo0640oooo1`00000V0?ooo`00703oool0
10000000oooo0?ooo`3oool2000006d0oooo00<000000?ooo`3oool0H@3oool7000002H0oooo000L
0?ooo`030000003oool0oooo00<00000K@3oool00`000000oooo0?ooo`1Q0?ooo`L000009P3oool0
01`0oooo00<000000?ooo`0000000P00001^0?ooo`030000003oool0oooo0640oooo1`00000V0?oo
o`004`3oool5000000@0oooo1000001_0?ooo`030000003oool0oooo0640oooo1`00000V0?ooo`00
5@3oool00`000000oooo0?ooo`040?ooo`<00000L03oool00`000000oooo0?ooo`1Q0?ooo`L00000
9P3oool001D0oooo00<000000?ooo`3oool00`3oool300000740oooo00<000000?ooo`3oool0H@3o
ool7000002H0oooo000E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0L03oool0
0`000000oooo0?ooo`0V0?ooo`80000000<0oooo0000000000000P3oool400000300oooo1`00000V
0?ooo`005@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0700oooo00<000000?oo
o`3oool00`3ooolM000000L0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0a0?oo
o`L000009P3oool001@0oooo0P0000060?ooo`030000003oool0oooo0700oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0300oooo1`00000V0?ooo`00
703oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo02H0oooo0P0000000`3oool00000
000000040?ooo`030000003oool0oooo02l0oooo1`00000V0?ooo`00S`3oool00`000000oooo0?oo
o`0]0?ooo`040000003oool0oooo00000300oooo1`00000V0?ooo`00S`3oool00`000000oooo0?oo
o`0^0?ooo`800000<@3oool7000002H0oooo002?0?ooo`030000003oool0oooo0640oooo1`00000V
0?ooo`00S`3oool00`000000oooo0?ooo`1Q0?ooo`L000009P3oool008l0oooo00<000000?ooo`3o
ool0H@3oool7000002H0oooo002?0?ooo`030000003oool0oooo0640oooo1`00000V0?ooo`00S`3o
ool00`000000oooo0?ooo`1Q0?ooo`L000009P3oool008l0oooo00<000000?ooo`3oool0H@3oool7
000002H0oooo002?0?ooo`030000003oool0oooo0640oooo1`00000V0?ooo`00S`3oool00`000000
oooo0?ooo`1Q0?ooo`L000009P3oool008l0oooo00<000000?ooo`3oool0H@3oool7000002H0oooo
002?0?ooo`030000003oool0oooo0640oooo1`00000V0?ooo`00S`3oool00`000000oooo0?ooo`1Q
0?ooo`L000009P3oool008l0oooo00<000000?ooo`3oool0H@3oool7000002H0oooo002?0?ooo`03
0000003oool0oooo0640oooo1`00000V0?ooo`00S`3oool00`000000oooo0?ooo`1Q0?ooo`L00000
9P3oool008l0oooo00<000000?ooo`3oool0H@3oool7000002H0oooo002?0?ooo`030000003oool0
oooo0640oooo1`00000V0?ooo`00S`3oool00`000000oooo0?ooo`1Q0?ooo`L000009P3oool008l0
oooo00<000000?ooo`3oool0H@3oool7000002H0oooo002?0?ooo`030000003oool0oooo0640oooo
1`00000V0?ooo`00S`3oool00`000000oooo0?ooo`1Q0?ooo`L000009P3oool008l0oooo00<00000
0?ooo`3oool0H@3oool7000002H0oooo002?0?ooo`030000003oool0oooo0640oooo1`00000V0?oo
o`00S`3oool00`000000oooo0?ooo`1Q0?ooo`L000009P3oool008l0oooo00<000000?ooo`3oool0
H@3oool7000002H0oooo002?0?ooo`030000003oool0oooo0640oooo1`00000V0?ooo`00S`3oool0
0`000000oooo0?ooo`1Q0?ooo`L000009P3oool008l0oooo00<000000?ooo`3oool0H@3oool70000
02H0oooo002?0?ooo`030000003oool0oooo0640oooo1`00000V0?ooo`00S`3oool00`000000oooo
0?ooo`0V0?ooo`80000000<0oooo0000000000000P3oool5000002l0oooo1`00000V0?ooo`00S`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0;`3o
ool7000002H0oooo002?0?ooo`030000003oool0oooo0080oooo7P0000080?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0;`3oool7000002H0oooo002?0?ooo`030000003oool0oooo
0080oooo7P0000060?ooo`80000000<0oooo000000000000103oool00`000000oooo0?ooo`0_0?oo
o`L000009P3oool008l0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0_0?ooo`L0
00009P3oool008l0oooo00<000000?ooo`3oool0;P3oool200000340oooo1`00000V0?ooo`00S`3o
ool00`000000oooo0?ooo`1Q0?ooo`L000009P3oool008l0oooo00<000000?ooo`3oool0H@3oool7
000002H0oooo002?0?ooo`030000003oool0oooo0640oooo1`00000V0?ooo`00S`3oool00`000000
oooo0?ooo`1Q0?ooo`L000009P3oool008l0oooo00<000000?ooo`3oool0H@3oool7000002H0oooo
002?0?ooo`030000003oool0oooo0640oooo1`00000V0?ooo`00S`3oool00`000000oooo0?ooo`1Q
0?ooo`L000009P3oool008l0oooo00<000000?ooo`3oool0H@3oool7000002H0oooo002?0?ooo`03
0000003oool0oooo0640oooo1`00000V0?ooo`00S`3oool00`000000oooo0?ooo`1Q0?ooo`L00000
9P3oool008l0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0Z0?ooo`00S`3oool0
0`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo02X0oooo002?0?ooo`030000003oool0oooo
0640oooo00<000000?ooo`3oool0:P3oool008l0oooo00<000000?ooo`3oool0H@3oool00`000000
oooo0?ooo`0Z0?ooo`00S`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo02X0oooo
002?0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0:P3oool008l0ooooI@00000/
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {231.938, 0}} -> {-1.05115, -0.658494, \
0.00732508, 0.00732508}, {{6.9375, 280}, {226.375, 57.625}} -> {-1.14628, \
-0.117722, 0.0407012, 0.00658559}, {{143.5, 243.188}, {114.688, 5.5}} -> \
{-4.93678, -4.05211, 0.0337057, 0.0337057}, {{148.813, 178.5}, {109.313, \
79.625}} -> {-5.28832, -15.7341, 0.0353688, 0.114456}, {{148.813, 178.5}, \
{74.875, 45.25}} -> {-5.28832, -19.6721, 0.0353688, 0.114456}, {{148.813, \
178.5}, {40.5, 10.8125}} -> {-5.28832, -23.6101, 0.0353688, 0.114456}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[116]="]
}, Open  ]],

Cell[BoxData[
    \(k\  =. \)], "Input",
  CellLabel->"In[117]:="],

Cell[BoxData[
    \(Clear[eq1, eq2]\)], "Input",
  CellLabel->"In[118]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Roberts-Rowland equation (J. Pharmacokim.Biopharm 14: 227-260 (1986) )\
\>", "SubsectionIcon"],

Cell["\<\
Here is solved eq. (1) by Roberts-Rowland J. Pharmacokim.Biopharm 14: 227-260 \
(1986) \
\>", "Abstract"],

Cell[BoxData[
    \(\[PartialD]\^2 c\/\[PartialD]z\^2 - \(1\/d\_n\) \[PartialD]c\/\
\[PartialD]z - \(r\_n\/d\_n\) c = \(1\/d\_n\) \[PartialD]c\/\[PartialD]z, 
    where\ c = \(\(c\) \((z, t)\)\(\ \)\)\)], "NumberedEquation"],

Cell[TextData[{
  "Note: Roberts-Rowland paper use capital letters. (i.e: C in place of c, ",
  Cell[BoxData[
      \(TraditionalForm\`R\_n\)]],
  " in place of ",
  Cell[BoxData[
      \(TraditionalForm\`r\_n\)]],
  ", etc.) "
}], "Commentary"],

Cell["Here is solved the case with \"mixed\" boundary conditions", "Text"],

Cell[TextData[{
  "Initial condition (IC): t =0, c= 0, 0\[LessEqual]z\[LessEqual]1\nBoundary \
conditions (BC): (The \"mixed\" boundary conditions): For z=0: c \
=\[Delta](z), for z=\[Infinity]: c=0, in other notation: ",
  Cell[BoxData[
      \(TraditionalForm\`c(0) = \[Delta](t)\)]],
  " y ",
  Cell[BoxData[
      \(TraditionalForm\`c(\[Infinity])\  = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Eq(17) in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notation can be wrote "
}], "Text"],

Cell[BoxData[
    \(D[c[z, t], t] == 
      d\_n\ D[c[z, t], z, z] - \ D[c[z, t], z] - 
        r\_n\ \(d\_n\) c[z, t] \((2)\)\)], "NumberedEquation"],

Cell["IC: c[z,0]\[Rule]0", "Text"],

Cell["\<\
Here is solved eq.(18) using Laplace Transform. (The right side terms of eq. \
18 are denoted by eq1 and the left by eq2)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq1 = LaplaceTransform[D[c[z, t], t], \ t, s]\)], "Input",
  CellLabel->"In[119]:="],

Cell[BoxData[
    \(\(-c[z, 0]\) + s\ LaplaceTransform[c[z, t], t, s]\)], "Output",
  CellLabel->"Out[119]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq2 = 
      LaplaceTransform[
        d\_n\ D[c[z, t], z, z] - \ D[c[z, t], z] - r\_n\ d\_n\ c[z, t], \ t, 
        s]\)], "Input",
  CellLabel->"In[120]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{"-", 
        RowBox[{"LaplaceTransform", "[", 
          RowBox[{
            RowBox[{
              SuperscriptBox["c", 
                TagBox[\((1, 0)\),
                  Derivative],
                MultilineFunction->None], "[", \(z, t\), "]"}], ",", "t", ",",
             "s"}], "]"}]}], "+", 
      RowBox[{
        RowBox[{"LaplaceTransform", "[", 
          RowBox[{
            RowBox[{
              SuperscriptBox["c", 
                TagBox[\((2, 0)\),
                  Derivative],
                MultilineFunction->None], "[", \(z, t\), "]"}], ",", "t", ",",
             "s"}], "]"}], " ", \(d\_n\)}], 
      "-", \(LaplaceTransform[c[z, t], t, s]\ d\_n\ r\_n\)}]], "Output",
  CellLabel->"Out[120]="]
}, Open  ]],

Cell["\<\
Now we calculate their Laplace Transforms. The are denoted in capital letters \
(i.e: for c[z,0] the LT is C[z,s] ). BC and IC are applied.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq1LT\  = \ 
      eq1 /. {LaplaceTransform[c[z, t], t, s] \[Rule] C[z, s]}\)], "Input",
  CellLabel->"In[121]:="],

Cell[BoxData[
    \(\(-c[z, 0]\) + s\ C[z, s]\)], "Output",
  CellLabel->"Out[121]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"eq2LT", " ", "=", " ", 
      RowBox[{"eq2", "/.", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{"LaplaceTransform", "[", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["c", 
                      TagBox[\((1, 0)\),
                        Derivative],
                      MultilineFunction->None], "[", \(z, t\), "]"}], ",", 
                  "t", ",", "s"}], "]"}], "\[Rule]", 
              RowBox[{
                SuperscriptBox["C", 
                  TagBox[\((1, 0)\),
                    Derivative],
                  MultilineFunction->None], "[", \(z, s\), "]"}]}], ",", 
            RowBox[{
              RowBox[{"LaplaceTransform", "[", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["c", 
                      TagBox[\((2, 0)\),
                        Derivative],
                      MultilineFunction->None], "[", \(z, t\), "]"}], ",", 
                  "t", ",", "s"}], "]"}], "\[Rule]", 
              RowBox[{
                SuperscriptBox["C", 
                  TagBox[\((2, 0)\),
                    Derivative],
                  MultilineFunction->None], "[", \(z, s\), "]"}]}], 
            ",", \(LaplaceTransform[c[z, t], t, s] \[Rule] C[z, s]\)}], 
          "}"}]}]}]], "Input",
  CellLabel->"In[122]:="],

Cell[BoxData[
    RowBox[{\(\(-C[z, s]\)\ d\_n\ r\_n\), "-", 
      RowBox[{
        SuperscriptBox["C", 
          TagBox[\((1, 0)\),
            Derivative],
          MultilineFunction->None], "[", \(z, s\), "]"}], "+", 
      RowBox[{\(d\_n\), " ", 
        RowBox[{
          SuperscriptBox["C", 
            TagBox[\((2, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(z, s\), "]"}]}]}]], "Output",
  CellLabel->"Out[122]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(A26 = eq1LT\  == eq2LT /. {c[z, 0] \[Rule] 0}\)], "Input",
  CellLabel->"In[123]:="],

Cell[BoxData[
    RowBox[{\(s\ C[z, s]\), "\[Equal]", 
      RowBox[{\(\(-C[z, s]\)\ d\_n\ r\_n\), "-", 
        RowBox[{
          SuperscriptBox["C", 
            TagBox[\((1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(z, s\), "]"}], "+", 
        RowBox[{\(d\_n\), " ", 
          RowBox[{
            SuperscriptBox["C", 
              TagBox[\((2, 0)\),
                Derivative],
              MultilineFunction->None], "[", \(z, s\), "]"}]}]}]}]], "Output",\

  CellLabel->"Out[123]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LaplaceTransform[DiracDelta[z], z, s]\)], "Input",
  CellLabel->"In[124]:="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[124]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq26b = 
      DSolve[{s\ C[z] == \(-C[z]\)\ d\_n\ r\_n - \(C'\)[z] + 
              d\_n\ \(C''\)[z], C[0] \[Equal] 1}, C[z], z]\)], "Input",
  CellLabel->"In[125]:="],

Cell[BoxData[
    \({{C[
            z] \[Rule] \[ExponentialE]\^\(\(z\ \((1 - \@\(1 + 4\ s\ d\_n + 4\ \
d\_n\%2\ r\_n\))\)\)\/\(2\ d\_n\)\) - \[ExponentialE]\^\(\(z\ \((1 - \@\(1 + \
4\ s\ d\_n + 4\ d\_n\%2\ r\_n\))\)\)\/\(2\ d\_n\)\)\ C[
                2] + \[ExponentialE]\^\(\(z\ \((1 + \@\(1 + 4\ s\ d\_n + 4\ d\
\_n\%2\ r\_n\))\)\)\/\(2\ d\_n\)\)\ C[2]}}\)], "Output",
  CellLabel->"Out[125]="]
}, Open  ]],

Cell[TextData[{
  "  The integration constant C[2] can be calculated using the BC: ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_b\)(\[Infinity])\  = 0\)]],
  " "
}], "Text"],

Cell[BoxData[
    \(Solve[\(eq26b[\([\)\(1\)\(]\)]\)[\([\)\(1, 2\)\(]\)] \[Equal] 0, \ 
      C[2]]; \)], "Input",
  CellLabel->"In[126]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(c = C[2] /. %[\([\)\(1\)\(]\)] // Simplify\)], "Input",
  CellLabel->"In[127]:="],

Cell[BoxData[
    \(1\/\(1 - \[ExponentialE]\^\(\(z\ \@\(1 + 4\ s\ d\_n + 4\ d\_n\%2\ \
r\_n\)\)\/d\_n\)\)\)], "Output",
  CellLabel->"Out[127]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq26b /. {C[2] \[Rule] 0} // FullSimplify\)], "Input",
  CellLabel->"In[128]:="],

Cell[BoxData[
    \({{C[
            z] \[Rule] \[ExponentialE]\^\(\(z - z\ \@\(1 + 4\ d\_n\ \((s + \
d\_n\ r\_n)\)\)\)\/\(2\ d\_n\)\)}}\)], "Output",
  CellLabel->"Out[128]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cout[s_] = C[z] /. %[\([\)\(1\)\(]\)]\)], "Input",
  CellLabel->"In[129]:="],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(z - z\ \@\(1 + 4\ d\_n\ \((s + d\_n\ r\_n)\)\)\)\/\
\(2\ d\_n\)\)\)], "Output",
  CellLabel->"Out[129]="]
}, Open  ]],

Cell[TextData[{
  "Now it can be evaluated ",
  Cell[BoxData[
      \(\(\(\ \)\(\(C\_out\) \((z, t)\)\(\ \)\)\)\)]],
  " taken the inverse laplace transform "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cOut[z_, t_] = 
      InverseLaplaceTransform[Cout[s], s, t] // FullSimplify\)], "Input",
  CellLabel->"In[130]:="],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(\((t - z)\)\^2\/\(4\ t\ d\_n\)\)\) - t\ d\_n\ \
r\_n\)\ z\)\/\(2\ \@\[Pi]\ \@\(t\^3\/d\_n\%3\)\ d\_n\%2\)\)], "Output",
  CellLabel->"Out[130]="]
}, Open  ]],

Cell["When  z=1 the solution is:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cOut[1, t]\)], "Input",
  CellLabel->"In[131]:="],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-\(\((\(-1\) + t)\)\^2\/\(4\ t\ d\_n\)\)\) - t\ \
d\_n\ r\_n\)\/\(2\ \@\[Pi]\ \@\(t\^3\/d\_n\%3\)\ d\_n\%2\)\)], "Output",
  CellLabel->"Out[131]="]
}, Open  ]],

Cell[TextData[{
  "This solution has a little difference with  eq.(49) Roberts-Rowland J. \
Pharmacokim.Biopharm 14: 227-260 (1986): ",
  Cell[BoxData[
      \(r\_n\)]],
  " was removed of the exponent. This mistake has not consequences when ",
  Cell[BoxData[
      \(r\_n\)]],
  "=0. as happen in  Fig 3.(B) of Roberts-Rowland paper"
}], "Text"],

Cell[TextData[{
  "Here is shown this Fig 3.(B) obtain with our method ",
  Cell[BoxData[
      \({d\_n \[Rule] {0.01, 0.1, 0.2, 1, 2}, r\_n \[Rule] 0\)]],
  " "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[
      Evaluate[cOut[1, t] /. {d\_n \[Rule] {0.01, 0.1, 0.2, 1, 2}, 
            r\_n \[Rule] 0}], {t, 0.01, 4}, \ 
      PlotRange \[Rule] {0, 4}]\)], "Input",
  CellLabel->"In[132]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.154508 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -18 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -6 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -18 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(1.5)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(2.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(3.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02619 0 m
.02736 0 L
.02843 0 L
.02966 0 L
.03083 0 L
.0319 0 L
.0329 0 L
.03399 0 L
.03514 0 L
.0363 0 L
.03755 0 L
.03873 0 L
.03981 0 L
.04107 0 L
.04178 0 L
.04245 0 L
.04366 0 L
.04495 0 L
.0456 0 L
.04629 0 L
.04752 0 L
.0482 0 L
.04884 0 L
.04954 0 L
.05029 0 L
.05094 0 L
.05164 0 L
.05292 0 L
.05417 0 L
.05532 0 L
.05644 0 L
.05749 0 L
.05864 0 L
.05988 0 L
.06112 0 L
.06241 0 L
.06352 0 L
.06473 0 L
.06544 0 L
.06609 0 L
.06681 0 L
.06757 0 L
.06884 0 L
.06957 0 L
.07024 0 L
.07151 0 L
.07266 0 L
.0733 0 L
.07399 0 L
.07526 0 L
Mistroke
.07602 0 L
.07674 0 L
.07738 0 L
.07808 0 L
.07885 0 L
.07965 0 L
.08034 0 L
.08109 0 L
.0818 0 L
.08244 0 L
.08319 0 L
.08389 0 L
.08514 0 L
.08585 0 L
.0865 0 L
.08766 0 L
.08891 0 L
.0901 0 L
.09118 0 L
.09238 0 L
.09369 0 L
.09435 0 L
.09506 0 L
.09633 0 L
.09703 0 L
.09768 0 L
.09839 0 L
.09914 0 L
.10041 0 L
.10113 0 L
.1018 0 L
.10305 0 L
.10419 0 L
.10551 0 L
.10676 0 L
.10789 0 L
.10911 0 L
.11027 0 L
.11133 0 L
.1125 0 L
.11378 0 L
.11443 0 L
.11512 0 L
.11637 0 L
.11706 0 L
.11769 0 L
.11839 0 L
.11913 0 L
.12036 0 L
.12107 0 L
Mistroke
.12173 0 L
.12295 0 L
.12407 0 L
.12537 0 L
.12659 0 L
.12775 0 L
.1288 0 L
.13001 0 L
.13115 0 L
.13221 0 L
.13318 0 L
.13425 0 L
.13538 0 L
.13652 0 L
.13774 0 L
.1389 0 L
.13995 0 L
.14118 0 L
.14188 0 L
.14252 0 L
.1437 1e-005 L
.14496 1e-005 L
.1461 1e-005 L
.14734 2e-005 L
.14864 2e-005 L
.14984 3e-005 L
.15098 4e-005 L
.15201 6e-005 L
.1532 7e-005 L
.15432 .0001 L
.15554 .00013 L
.15683 .00017 L
.15794 .00022 L
.15916 .00028 L
.16046 .00037 L
.16186 .00049 L
.16318 .00063 L
.1644 .00079 L
.16674 .00121 L
.16797 .0015 L
.16929 .00187 L
.17173 .00277 L
.17393 .00388 L
.17609 .00531 L
.17842 .00733 L
.18062 .00977 L
.18264 .01256 L
.18735 .02157 L
.18998 .02845 L
.19238 .03605 L
Mistroke
.19705 .05488 L
.20147 .07807 L
.21136 .14913 L
.2221 .2478 L
.23231 .34216 L
.2373 .38117 L
.24188 .40992 L
.24417 .42141 L
.24668 .4315 L
.24806 .4359 L
.24933 .43927 L
.25055 .44183 L
.25185 .44386 L
.2526 .44469 L
.25328 .44525 L
.25403 .44563 L
.25482 .44578 L
.25551 .44569 L
.25616 .44543 L
.25686 .44496 L
.25762 .44422 L
.25829 .44337 L
.25902 .44225 L
.26036 .43968 L
.26285 .43311 L
.26517 .42505 L
.26768 .41447 L
.27222 .39101 L
.28257 .32353 L
.29257 .2517 L
.30352 .1787 L
.31318 .12532 L
.3235 .0817 L
.32921 .06321 L
.3344 .0495 L
.33932 .03887 L
.34454 .02981 L
.34928 .02323 L
.35449 .01751 L
.35923 .01344 L
.36367 .01042 L
.36889 .00767 L
.37367 .00576 L
.37918 .00411 L
.38441 .00296 L
.38944 .00214 L
.39399 .00159 L
.39925 .00113 L
.4042 .00081 L
.40879 .00059 L
Mistroke
.41302 .00044 L
.41765 .00032 L
.42255 .00022 L
.42751 .00016 L
.43202 .00011 L
.43452 9e-005 L
.43723 8e-005 L
.44217 5e-005 L
.44678 4e-005 L
.45168 3e-005 L
.45586 2e-005 L
.46047 1e-005 L
.46281 1e-005 L
.46538 1e-005 L
.46788 1e-005 L
.47055 1e-005 L
.47306 1e-005 L
.47534 0 L
.47979 0 L
.48247 0 L
.48494 0 L
.48759 0 L
.49051 0 L
.49542 0 L
.4981 0 L
.50061 0 L
.50559 0 L
.5084 0 L
.51101 0 L
.51579 0 L
.51821 0 L
.52088 0 L
.52546 0 L
.52804 0 L
.53041 0 L
.53478 0 L
.53697 0 L
.53937 0 L
.5419 0 L
.54463 0 L
.54704 0 L
.5496 0 L
.5519 0 L
.55444 0 L
.5589 0 L
.56162 0 L
.5641 0 L
.56677 0 L
.56969 0 L
.57237 0 L
Mistroke
.57487 0 L
.57979 0 L
.58243 0 L
.58486 0 L
.58747 0 L
.59033 0 L
.59516 0 L
.5978 0 L
.60027 0 L
.60267 0 L
.60495 0 L
.60923 0 L
.61162 0 L
.61383 0 L
.61644 0 L
.61883 0 L
.62345 0 L
.62588 0 L
.62844 0 L
.63274 0 L
.63518 0 L
.63745 0 L
.64013 0 L
.64266 0 L
.64739 0 L
.65004 0 L
.65248 0 L
.65517 0 L
.65801 0 L
.66053 0 L
.66293 0 L
.66742 0 L
.66993 0 L
.67226 0 L
.67498 0 L
.67754 0 L
.67977 0 L
.68218 0 L
.68639 0 L
.68877 0 L
.6913 0 L
.69581 0 L
.69836 0 L
.70077 0 L
.70529 0 L
.70782 0 L
.71015 0 L
.71288 0 L
.71544 0 L
.71966 0 L
Mistroke
.72191 0 L
.72432 0 L
.72684 0 L
.72924 0 L
.73374 0 L
.73632 0 L
.73875 0 L
.74329 0 L
.74584 0 L
.74818 0 L
.75076 0 L
.75348 0 L
.75566 0 L
.758 0 L
.76222 0 L
.76479 0 L
.76724 0 L
.7696 0 L
.77181 0 L
.77638 0 L
.77881 0 L
.78143 0 L
.78403 0 L
.78676 0 L
.7891 0 L
.79166 0 L
.79402 0 L
.79625 0 L
.79883 0 L
.80117 0 L
.80542 0 L
.80781 0 L
.81002 0 L
.81241 0 L
.81468 0 L
.81729 0 L
.81968 0 L
.82401 0 L
.82645 0 L
.82872 0 L
.83142 0 L
.83395 0 L
.83625 0 L
.83869 0 L
.84135 0 L
.84379 0 L
.84642 0 L
.8493 0 L
.85181 0 L
.85454 0 L
Mistroke
.85712 0 L
.8595 0 L
.864 0 L
.86628 0 L
.86878 0 L
.87149 0 L
.87397 0 L
.87669 0 L
.87955 0 L
.88205 0 L
.88438 0 L
.88693 0 L
.88965 0 L
.89224 0 L
.89498 0 L
.89732 0 L
.89989 0 L
.90265 0 L
.90561 0 L
.90841 0 L
.91097 0 L
.91353 0 L
.91591 0 L
.91851 0 L
.92129 0 L
.92394 0 L
.92643 0 L
.92867 0 L
.93108 0 L
.93349 0 L
.93574 0 L
.93842 0 L
.94085 0 L
.9434 0 L
.94615 0 L
.94876 0 L
.95116 0 L
.95542 0 L
.95785 0 L
.96012 0 L
.96246 0 L
.96469 0 L
.96726 0 L
.96961 0 L
.97302 0 L
.97619 0 L
Mfstroke
.02619 0 m
.02736 0 L
.02843 0 L
.02966 0 L
.03083 0 L
.0319 0 L
.0329 0 L
.03399 0 L
.03514 0 L
.0363 0 L
.03755 0 L
.03873 0 L
.03981 0 L
.04107 0 L
.04178 0 L
.04245 0 L
.04366 0 L
.04495 0 L
.0456 0 L
.04629 0 L
.04752 0 L
.0482 0 L
.04884 0 L
.04954 0 L
.05029 0 L
.05094 0 L
.05164 0 L
.05292 0 L
.05417 0 L
.05532 0 L
.05644 0 L
.05749 1e-005 L
.05864 1e-005 L
.05988 2e-005 L
.06112 3e-005 L
.06241 4e-005 L
.06352 6e-005 L
.06473 9e-005 L
.06609 .00013 L
.06757 .0002 L
.06896 .00029 L
.07024 .0004 L
.07268 .00068 L
.07391 .00087 L
.07526 .00112 L
.07806 .00183 L
.07963 .00234 L
.08107 .00291 L
.08389 .00428 L
.0865 .0059 L
Mistroke
.09147 .01003 L
.09689 .01621 L
.10676 .03184 L
.14584 .11787 L
.15613 .13691 L
.16154 .14535 L
.16724 .15297 L
.17225 .15857 L
.17773 .16354 L
.18272 .16704 L
.18737 .16946 L
.18998 .17048 L
.19238 .17122 L
.19502 .1718 L
.19636 .17201 L
.19707 .1721 L
.19783 .17218 L
.19911 .17228 L
.20028 .17232 L
.20155 .17232 L
.20226 .1723 L
.20293 .17227 L
.20414 .17218 L
.20524 .17207 L
.20652 .1719 L
.20771 .1717 L
.20996 .17123 L
.21234 .1706 L
.21661 .16916 L
.22624 .16459 L
.23567 .1587 L
.2458 .15123 L
.26408 .13593 L
.30531 .09994 L
.34502 .07018 L
.38322 .04834 L
.40253 .03971 L
.42387 .03179 L
.46301 .02092 L
.48228 .01696 L
.50308 .0135 L
.52265 .01086 L
.54408 .00856 L
.58357 .00549 L
.60311 .0044 L
.624 .00347 L
.64384 .00277 L
.66536 .00217 L
.70521 .00138 L
.72502 .0011 L
Mistroke
.746 .00086 L
.78376 .00056 L
.80313 .00045 L
.82396 .00035 L
.84364 .00028 L
.86511 .00022 L
.90473 .00014 L
.92437 .00011 L
.9453 9e-005 L
.97619 6e-005 L
Mfstroke
.02619 0 m
.02736 0 L
.02843 0 L
.02966 0 L
.03083 0 L
.0319 0 L
.0329 0 L
.03399 0 L
.03514 0 L
.0363 0 L
.03755 0 L
.03873 0 L
.03981 0 L
.04107 0 L
.04178 0 L
.04245 1e-005 L
.04366 1e-005 L
.04495 3e-005 L
.0456 4e-005 L
.04629 6e-005 L
.04752 .00012 L
.0482 .00016 L
.04884 .00021 L
.04959 .00028 L
.05029 .00037 L
.05156 .00057 L
.05272 .00082 L
.05397 .00116 L
.05532 .00165 L
.05769 .00284 L
.06021 .00461 L
.06236 .0066 L
.06473 .00933 L
.07017 .01765 L
.07516 .02753 L
.08641 .05461 L
.09695 .08119 L
.10676 .1033 L
.11665 .12139 L
.12564 .13377 L
.13077 .13917 L
.13562 .14323 L
.14074 .14649 L
.14362 .1479 L
.14628 .14894 L
.14872 .1497 L
.15095 .15023 L
.15217 .15046 L
.15351 .15066 L
.15478 .15081 L
Mistroke
.15595 .1509 L
.15714 .15096 L
.15825 .15099 L
.15925 .15099 L
.16034 .15096 L
.16152 .15089 L
.16277 .15079 L
.16383 .15068 L
.165 .15052 L
.16769 .15007 L
.17015 .14954 L
.17565 .14796 L
.18559 .14404 L
.20466 .13386 L
.22539 .12084 L
.26612 .09489 L
.30534 .07318 L
.34305 .05633 L
.3832 .04239 L
.42184 .03218 L
.46293 .024 L
.50251 .01812 L
.54058 .01385 L
.58109 .01042 L
.62009 .00795 L
.66153 .00597 L
.70147 .00454 L
.73989 .0035 L
.78076 .00266 L
.82011 .00204 L
.85796 .00159 L
.89825 .00122 L
.93703 .00094 L
.97619 .00073 L
Mfstroke
.02619 0 m
.02736 0 L
.02843 7e-005 L
.02966 .00071 L
.03083 .00292 L
.0319 .00727 L
.0329 .01365 L
.03399 .02321 L
.03514 .03582 L
.04021 .10363 L
.04268 .13478 L
.04495 .15905 L
.04712 .1781 L
.04949 .19445 L
.05078 .20162 L
.05199 .20724 L
.05436 .21578 L
.05572 .21931 L
.05699 .22186 L
.05814 .22359 L
.05938 .22491 L
.06003 .2254 L
.06073 .22579 L
.06148 .22605 L
.06217 .22616 L
.0634 .22606 L
.0641 .22586 L
.06473 .22559 L
.06597 .22485 L
.06733 .22374 L
.0701 .22071 L
.07507 .21344 L
.08631 .19305 L
.10676 .15629 L
.12768 .12608 L
.14686 .10478 L
.16566 .0885 L
.18545 .07502 L
.22347 .05632 L
.24303 .04925 L
.26392 .04304 L
.30532 .03367 L
.3452 .02717 L
.38357 .02247 L
.42439 .01864 L
.46369 .01575 L
.50148 .01352 L
.54172 .01159 L
.58045 .01007 L
.62162 .00873 L
Mistroke
.66129 .00765 L
.69943 .00677 L
.74003 .00598 L
.77911 .00532 L
.82064 .00472 L
.86066 .00422 L
.89917 .0038 L
.94012 .00341 L
.97619 .0031 L
Mfstroke
.02619 .00015 m
.02736 .00499 L
.02843 .02328 L
.02966 .06332 L
.03083 .11209 L
.03292 .20071 L
.03514 .27415 L
.03631 .30215 L
.03759 .32548 L
.03875 .34081 L
.03985 .35093 L
.04113 .35851 L
.04231 .36214 L
.04295 .36304 L
.04366 .36325 L
.04495 .36193 L
.0456 .36059 L
.04629 .3587 L
.04755 .35434 L
.04992 .34384 L
.05521 .31503 L
.06473 .26268 L
.07537 .21458 L
.08662 .17595 L
.09622 .1506 L
.10676 .1287 L
.12622 .09942 L
.13713 .08733 L
.14708 .07821 L
.16612 .06448 L
.18683 .05342 L
.20655 .04543 L
.22751 .03883 L
.26516 .0302 L
.28446 .02688 L
.30527 .0239 L
.3463 .01933 L
.38583 .01608 L
.42384 .01367 L
.4643 .01166 L
.50325 .01012 L
.54464 .00879 L
.58453 .00774 L
.6229 .00689 L
.66371 .00613 L
.70302 .0055 L
.74081 .00499 L
.78105 .00451 L
.81977 .00411 L
.86095 .00373 L
Mistroke
.90061 .00342 L
.93876 .00315 L
.97619 .00291 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[132]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[132]="]
}, Open  ]],

Cell["Here is the 3-D representation as function of z and t", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[
      Evaluate[cOut[z, t] /. {d\_n \[Rule] 0.01, r\_n \[Rule] 0}], {z, 1, 
        2}, {t, 0.1, 4}, \ PlotRange \[Rule] {0, 4}]\)], "Input",
  CellLabel->"In[133]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6343 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.77714 .11187 0 -6.14746 ]
[.77714 .11187 6 2.85254 ]
[.85293 .22792 0 -6.03643 ]
[.85293 .22792 6 2.96357 ]
[.92079 .33185 0 -5.93942 ]
[.92079 .33185 6 3.06058 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02494 .25992 -6 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -6 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -6 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(1)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(1.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(1.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(1.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(1.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(2)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.76482 .11638 m
.75866 .11864 L
s
[(1)] .77714 .11187 -1 .3661 Mshowa
.84051 .23216 m
.8343 .23428 L
s
[(2)] .85293 .22792 -1 .34143 Mshowa
.90829 .33584 m
.90204 .33784 L
s
[(3)] .92079 .33185 -1 .31987 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(4)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.78066 .14061 m
.77695 .14194 L
s
.79613 .16428 m
.79242 .1656 L
s
.81126 .18741 m
.80754 .18872 L
s
.82605 .21004 m
.82233 .21132 L
s
.85466 .2538 m
.85093 .25506 L
s
.8685 .27497 m
.86476 .27622 L
s
.88205 .2957 m
.87831 .29692 L
s
.89531 .31598 m
.89156 .3172 L
s
.92101 .3553 m
.91725 .35648 L
s
.93346 .37435 m
.92971 .37552 L
s
.94567 .39302 m
.94191 .39417 L
s
.95763 .41131 m
.95386 .41246 L
s
.74861 .09159 m
.74492 .09296 L
s
.73201 .0662 m
.72833 .06759 L
s
.71502 .0402 m
.71134 .04161 L
s
.6976 .01356 m
.69393 .01499 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(0)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(1)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(2)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(3)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(4)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.664 .741 .907 r
.39254 .58705 .40529 .59895 .42665 .59252 .41401 .58053 Metetra
.664 .741 .907 r
.41401 .58053 .42665 .59252 .44817 .58605 .43564 .57395 Metetra
.664 .741 .907 r
.43564 .57395 .44817 .58605 .46987 .57952 .45745 .56733 Metetra
.664 .741 .907 r
.45745 .56733 .46987 .57952 .49174 .57294 .47944 .56065 Metetra
.664 .741 .907 r
.47944 .56065 .49174 .57294 .5138 .5663 .50161 .55391 Metetra
.664 .741 .907 r
.50161 .55391 .5138 .5663 .53602 .55961 .52395 .54712 Metetra
.664 .741 .907 r
.52395 .54712 .53602 .55961 .55843 .55287 .54648 .54028 Metetra
.664 .741 .907 r
.54648 .54028 .55843 .55287 .58103 .54607 .5692 .53338 Metetra
.664 .741 .907 r
.5692 .53338 .58103 .54607 .6038 .53922 .5921 .52642 Metetra
.664 .741 .907 r
.5921 .52642 .6038 .53922 .62677 .53231 .61519 .5194 Metetra
.664 .741 .907 r
.61519 .5194 .62677 .53231 .64992 .52534 .63848 .51233 Metetra
.664 .741 .907 r
.63848 .51233 .64992 .52534 .67327 .51832 .66196 .5052 Metetra
.664 .741 .907 r
.66196 .5052 .67327 .51832 .69681 .51124 .68563 .498 Metetra
.664 .741 .907 r
.68563 .498 .69681 .51124 .72055 .50409 .70951 .49075 Metetra
.664 .741 .907 r
.70951 .49075 .72055 .50409 .74449 .49689 .73359 .48343 Metetra
.664 .741 .907 r
.73359 .48343 .74449 .49689 .76863 .48963 .75787 .47606 Metetra
.664 .741 .907 r
.75787 .47606 .76863 .48963 .79298 .4823 .78236 .46862 Metetra
.664 .741 .907 r
.78236 .46862 .79298 .4823 .81753 .47492 .80706 .46111 Metetra
.664 .741 .907 r
.80706 .46111 .81753 .47492 .84229 .46747 .83198 .45354 Metetra
.664 .741 .907 r
.83198 .45354 .84229 .46747 .86727 .45995 .85711 .44591 Metetra
.664 .741 .907 r
.85711 .44591 .86727 .45995 .89246 .45237 .88246 .43821 Metetra
.664 .741 .907 r
.88246 .43821 .89246 .45237 .91786 .44473 .90803 .43044 Metetra
.664 .741 .907 r
.90803 .43044 .91786 .44473 .94349 .43702 .93382 .4226 Metetra
.664 .741 .907 r
.93382 .4226 .94349 .43702 .96935 .42924 .95984 .4147 Metetra
.664 .741 .907 r
.37961 .57497 .39254 .58705 .41401 .58053 .40118 .56835 Metetra
.664 .741 .907 r
.40118 .56835 .41401 .58053 .43564 .57395 .42293 .56168 Metetra
.664 .741 .907 r
.42293 .56168 .43564 .57395 .45745 .56733 .44485 .55495 Metetra
.664 .741 .907 r
.44485 .55495 .45745 .56733 .47944 .56065 .46695 .54817 Metetra
.664 .741 .907 r
.46695 .54817 .47944 .56065 .50161 .55391 .48923 .54134 Metetra
.664 .741 .907 r
.48923 .54134 .50161 .55391 .52395 .54712 .5117 .53444 Metetra
.664 .741 .907 r
.5117 .53444 .52395 .54712 .54648 .54028 .53435 .52749 Metetra
.664 .741 .907 r
.53435 .52749 .54648 .54028 .5692 .53338 .55719 .52049 Metetra
.664 .741 .907 r
.55719 .52049 .5692 .53338 .5921 .52642 .58021 .51342 Metetra
.664 .741 .907 r
.58021 .51342 .5921 .52642 .61519 .5194 .60344 .5063 Metetra
.664 .741 .907 r
.60344 .5063 .61519 .5194 .63848 .51233 .62685 .49911 Metetra
.664 .741 .907 r
.62685 .49911 .63848 .51233 .66196 .5052 .65046 .49187 Metetra
.664 .741 .907 r
.65046 .49187 .66196 .5052 .68563 .498 .67428 .48456 Metetra
.664 .741 .907 r
.67428 .48456 .68563 .498 .70951 .49075 .69829 .4772 Metetra
.664 .741 .907 r
.69829 .4772 .70951 .49075 .73359 .48343 .72251 .46977 Metetra
.664 .741 .907 r
.72251 .46977 .73359 .48343 .75787 .47606 .74694 .46227 Metetra
.664 .741 .907 r
.74694 .46227 .75787 .47606 .78236 .46862 .77158 .45471 Metetra
.664 .741 .907 r
.77158 .45471 .78236 .46862 .80706 .46111 .79643 .44709 Metetra
.664 .741 .907 r
.79643 .44709 .80706 .46111 .83198 .45354 .8215 .4394 Metetra
.664 .741 .907 r
.8215 .4394 .83198 .45354 .85711 .44591 .84679 .43164 Metetra
.664 .741 .907 r
.84679 .43164 .85711 .44591 .88246 .43821 .8723 .42381 Metetra
.664 .741 .907 r
.8723 .42381 .88246 .43821 .90803 .43044 .89803 .41592 Metetra
.664 .741 .907 r
.89803 .41592 .90803 .43044 .93382 .4226 .92399 .40795 Metetra
.664 .741 .907 r
.92399 .40795 .93382 .4226 .95984 .4147 .95018 .39992 Metetra
.664 .741 .907 r
.36648 .56271 .37961 .57497 .40118 .56835 .38816 .55599 Metetra
.664 .741 .907 r
.38816 .55599 .40118 .56835 .42293 .56168 .41002 .54922 Metetra
.664 .741 .907 r
.41002 .54922 .42293 .56168 .44485 .55495 .43205 .54239 Metetra
.664 .741 .907 r
.43205 .54239 .44485 .55495 .46695 .54817 .45427 .53551 Metetra
.664 .741 .907 r
.45427 .53551 .46695 .54817 .48923 .54134 .47667 .52857 Metetra
.664 .741 .907 r
.47667 .52857 .48923 .54134 .5117 .53444 .49925 .52157 Metetra
.664 .741 .907 r
.49925 .52157 .5117 .53444 .53435 .52749 .52203 .51451 Metetra
.664 .741 .907 r
.52203 .51451 .53435 .52749 .55719 .52049 .54499 .5074 Metetra
.664 .741 .907 r
.54499 .5074 .55719 .52049 .58021 .51342 .56815 .50022 Metetra
.664 .741 .907 r
.56815 .50022 .58021 .51342 .60344 .5063 .5915 .49299 Metetra
.664 .741 .907 r
.5915 .49299 .60344 .5063 .62685 .49911 .61504 .48569 Metetra
.664 .741 .907 r
.61504 .48569 .62685 .49911 .65046 .49187 .63879 .47833 Metetra
.664 .741 .907 r
.63879 .47833 .65046 .49187 .67428 .48456 .66274 .47091 Metetra
.664 .741 .907 r
.66274 .47091 .67428 .48456 .69829 .4772 .6869 .46343 Metetra
.664 .741 .907 r
.6869 .46343 .69829 .4772 .72251 .46977 .71126 .45588 Metetra
.664 .741 .907 r
.71126 .45588 .72251 .46977 .74694 .46227 .73584 .44826 Metetra
.664 .741 .907 r
.73584 .44826 .74694 .46227 .77158 .45471 .76063 .44058 Metetra
.664 .741 .907 r
.76063 .44058 .77158 .45471 .79643 .44709 .78563 .43284 Metetra
.664 .741 .907 r
.78563 .43284 .79643 .44709 .8215 .4394 .81086 .42502 Metetra
.664 .741 .907 r
.81086 .42502 .8215 .4394 .84679 .43164 .8363 .41714 Metetra
.664 .741 .907 r
.8363 .41714 .84679 .43164 .8723 .42381 .86197 .40918 Metetra
.664 .741 .907 r
.86197 .40918 .8723 .42381 .89803 .41592 .88787 .40116 Metetra
.664 .741 .907 r
.88787 .40116 .89803 .41592 .92399 .40795 .914 .39306 Metetra
.664 .741 .907 r
.914 .39306 .92399 .40795 .95018 .39992 .94036 .3849 Metetra
.664 .741 .907 r
.35316 .55026 .36648 .56271 .38816 .55599 .37495 .54345 Metetra
.664 .741 .907 r
.37495 .54345 .38816 .55599 .41002 .54922 .39692 .53657 Metetra
.664 .741 .907 r
.39692 .53657 .41002 .54922 .43205 .54239 .41906 .52964 Metetra
.664 .741 .907 r
.41906 .52964 .43205 .54239 .45427 .53551 .4414 .52265 Metetra
.664 .741 .907 r
.4414 .52265 .45427 .53551 .47667 .52857 .46391 .5156 Metetra
.664 .741 .907 r
.46391 .5156 .47667 .52857 .49925 .52157 .48662 .5085 Metetra
.664 .741 .907 r
.48662 .5085 .49925 .52157 .52203 .51451 .50952 .50133 Metetra
.664 .741 .907 r
.50952 .50133 .52203 .51451 .54499 .5074 .5326 .49411 Metetra
.664 .741 .907 r
.5326 .49411 .54499 .5074 .56815 .50022 .55589 .48682 Metetra
.664 .741 .907 r
.55589 .48682 .56815 .50022 .5915 .49299 .57937 .47947 Metetra
.664 .741 .907 r
.57937 .47947 .5915 .49299 .61504 .48569 .60305 .47206 Metetra
.664 .741 .907 r
.60305 .47206 .61504 .48569 .63879 .47833 .62694 .46458 Metetra
.664 .741 .907 r
.62694 .46458 .63879 .47833 .66274 .47091 .65103 .45704 Metetra
.664 .741 .907 r
.65103 .45704 .66274 .47091 .6869 .46343 .67533 .44944 Metetra
.664 .741 .907 r
.67533 .44944 .6869 .46343 .71126 .45588 .69983 .44177 Metetra
.664 .741 .907 r
.69983 .44177 .71126 .45588 .73584 .44826 .72456 .43403 Metetra
.664 .741 .907 r
.72456 .43403 .73584 .44826 .76063 .44058 .7495 .42623 Metetra
.664 .741 .907 r
.7495 .42623 .76063 .44058 .78563 .43284 .77465 .41835 Metetra
.664 .741 .907 r
.77465 .41835 .78563 .43284 .81086 .42502 .80004 .41041 Metetra
.664 .741 .907 r
.80004 .41041 .81086 .42502 .8363 .41714 .82564 .4024 Metetra
.664 .741 .907 r
.82564 .4024 .8363 .41714 .86197 .40918 .85147 .39431 Metetra
.664 .741 .907 r
.85147 .39431 .86197 .40918 .88787 .40116 .87754 .38616 Metetra
.664 .741 .907 r
.87754 .38616 .88787 .40116 .914 .39306 .90384 .37793 Metetra
.664 .741 .907 r
.90384 .37793 .914 .39306 .94036 .3849 .93037 .36962 Metetra
.664 .741 .907 r
.33963 .53763 .35316 .55026 .37495 .54345 .36153 .53071 Metetra
.664 .741 .907 r
.36153 .53071 .37495 .54345 .39692 .53657 .38361 .52373 Metetra
.664 .741 .907 r
.38361 .52373 .39692 .53657 .41906 .52964 .40588 .51669 Metetra
.664 .741 .907 r
.40588 .51669 .41906 .52964 .4414 .52265 .42832 .50959 Metetra
.664 .741 .907 r
.42832 .50959 .4414 .52265 .46391 .5156 .45096 .50244 Metetra
.664 .741 .907 r
.45096 .50244 .46391 .5156 .48662 .5085 .47379 .49522 Metetra
.664 .741 .907 r
.47379 .49522 .48662 .5085 .50952 .50133 .49681 .48794 Metetra
.664 .741 .907 r
.49681 .48794 .50952 .50133 .5326 .49411 .52003 .4806 Metetra
.664 .741 .907 r
.52003 .4806 .5326 .49411 .55589 .48682 .54344 .4732 Metetra
.664 .741 .907 r
.54344 .4732 .55589 .48682 .57937 .47947 .56705 .46574 Metetra
.664 .741 .907 r
.56705 .46574 .57937 .47947 .60305 .47206 .59087 .45821 Metetra
.664 .741 .907 r
.59087 .45821 .60305 .47206 .62694 .46458 .61489 .45061 Metetra
.664 .741 .907 r
.61489 .45061 .62694 .46458 .65103 .45704 .63912 .44295 Metetra
.664 .741 .907 r
.63912 .44295 .65103 .45704 .67533 .44944 .66357 .43523 Metetra
.664 .741 .907 r
.66357 .43523 .67533 .44944 .69983 .44177 .68822 .42743 Metetra
.664 .741 .907 r
.68822 .42743 .69983 .44177 .72456 .43403 .71309 .41957 Metetra
.664 .741 .907 r
.71309 .41957 .72456 .43403 .7495 .42623 .73818 .41164 Metetra
.664 .741 .907 r
.73818 .41164 .7495 .42623 .77465 .41835 .7635 .40364 Metetra
.664 .741 .907 r
.7635 .40364 .77465 .41835 .80004 .41041 .78904 .39556 Metetra
.664 .741 .907 r
.78904 .39556 .80004 .41041 .82564 .4024 .8148 .38742 Metetra
.664 .741 .907 r
.8148 .38742 .82564 .4024 .85147 .39431 .8408 .3792 Metetra
.664 .741 .907 r
.8408 .3792 .85147 .39431 .87754 .38616 .86704 .3709 Metetra
.664 .741 .907 r
.86704 .3709 .87754 .38616 .90384 .37793 .89351 .36254 Metetra
.664 .741 .907 r
.89351 .36254 .90384 .37793 .93037 .36962 .92022 .35409 Metetra
.664 .741 .907 r
.3259 .52481 .33963 .53763 .36153 .53071 .34791 .51778 Metetra
.664 .741 .907 r
.34791 .51778 .36153 .53071 .38361 .52373 .3701 .51069 Metetra
.664 .741 .907 r
.3701 .51069 .38361 .52373 .40588 .51669 .39248 .50354 Metetra
.664 .741 .907 r
.39248 .50354 .40588 .51669 .42832 .50959 .41505 .49634 Metetra
.664 .741 .907 r
.41505 .49634 .42832 .50959 .45096 .50244 .43781 .48907 Metetra
.664 .741 .907 r
.43781 .48907 .45096 .50244 .47379 .49522 .46076 .48174 Metetra
.664 .741 .907 r
.46076 .48174 .47379 .49522 .49681 .48794 .4839 .47435 Metetra
.664 .741 .907 r
.4839 .47435 .49681 .48794 .52003 .4806 .50725 .46689 Metetra
.664 .741 .907 r
.50725 .46689 .52003 .4806 .54344 .4732 .53079 .45937 Metetra
.664 .741 .907 r
.53079 .45937 .54344 .4732 .56705 .46574 .55454 .45179 Metetra
.664 .741 .907 r
.55454 .45179 .56705 .46574 .59087 .45821 .57849 .44414 Metetra
.664 .741 .907 r
.57849 .44414 .59087 .45821 .61489 .45061 .60265 .43642 Metetra
.664 .741 .907 r
.60265 .43642 .61489 .45061 .63912 .44295 .62703 .42864 Metetra
.664 .741 .907 r
.62703 .42864 .63912 .44295 .66357 .43523 .65161 .42078 Metetra
.664 .741 .907 r
.65161 .42078 .66357 .43523 .68822 .42743 .67642 .41286 Metetra
.664 .741 .907 r
.67642 .41286 .68822 .42743 .71309 .41957 .70144 .40487 Metetra
.664 .741 .907 r
.70144 .40487 .71309 .41957 .73818 .41164 .72669 .39681 Metetra
.664 .741 .907 r
.72669 .39681 .73818 .41164 .7635 .40364 .75216 .38867 Metetra
.664 .741 .907 r
.75216 .38867 .7635 .40364 .78904 .39556 .77786 .38047 Metetra
.664 .741 .907 r
.77786 .38047 .78904 .39556 .8148 .38742 .80379 .37219 Metetra
.664 .741 .907 r
.80379 .37219 .8148 .38742 .8408 .3792 .82996 .36383 Metetra
.664 .741 .907 r
.82996 .36383 .8408 .3792 .86704 .3709 .85636 .3554 Metetra
.664 .741 .907 r
.85636 .3554 .86704 .3709 .89351 .36254 .88301 .34689 Metetra
.664 .741 .907 r
.88301 .34689 .89351 .36254 .92022 .35409 .9099 .33831 Metetra
.664 .741 .907 r
.31196 .51178 .3259 .52481 .34791 .51778 .33408 .50465 Metetra
.664 .741 .907 r
.33408 .50465 .34791 .51778 .3701 .51069 .35639 .49745 Metetra
.664 .741 .907 r
.35639 .49745 .3701 .51069 .39248 .50354 .37888 .49019 Metetra
.664 .741 .907 r
.37888 .49019 .39248 .50354 .41505 .49634 .40157 .48287 Metetra
.664 .741 .907 r
.40157 .48287 .41505 .49634 .43781 .48907 .42445 .47549 Metetra
.664 .741 .907 r
.42445 .47549 .43781 .48907 .46076 .48174 .44752 .46804 Metetra
.664 .741 .907 r
.44752 .46804 .46076 .48174 .4839 .47435 .47079 .46053 Metetra
.664 .741 .907 r
.47079 .46053 .4839 .47435 .50725 .46689 .49427 .45296 Metetra
.664 .741 .907 r
.49427 .45296 .50725 .46689 .53079 .45937 .51794 .44532 Metetra
.664 .741 .907 r
.51794 .44532 .53079 .45937 .55454 .45179 .54182 .43761 Metetra
.664 .741 .907 r
.54182 .43761 .55454 .45179 .57849 .44414 .56592 .42984 Metetra
.664 .741 .907 r
.56592 .42984 .57849 .44414 .60265 .43642 .59022 .422 Metetra
.664 .741 .907 r
.59022 .422 .60265 .43642 .62703 .42864 .61473 .41409 Metetra
.664 .741 .907 r
.61473 .41409 .62703 .42864 .65161 .42078 .63947 .40611 Metetra
.664 .741 .907 r
.63947 .40611 .65161 .42078 .67642 .41286 .66442 .39805 Metetra
.664 .741 .907 r
.66442 .39805 .67642 .41286 .70144 .40487 .6896 .38993 Metetra
.664 .741 .907 r
.6896 .38993 .70144 .40487 .72669 .39681 .715 .38173 Metetra
.664 .741 .907 r
.715 .38173 .72669 .39681 .75216 .38867 .74063 .37347 Metetra
.664 .741 .907 r
.74063 .37347 .75216 .38867 .77786 .38047 .76649 .36512 Metetra
.664 .741 .907 r
.76649 .36512 .77786 .38047 .80379 .37219 .79259 .3567 Metetra
.664 .741 .907 r
.79259 .3567 .80379 .37219 .82996 .36383 .81893 .34821 Metetra
.664 .741 .907 r
.81893 .34821 .82996 .36383 .85636 .3554 .8455 .33965 Metetra
.664 .741 .908 r
.8455 .33965 .85636 .3554 .88301 .34689 .87233 .33102 Metetra
.663 .741 .908 r
.87233 .33102 .88301 .34689 .9099 .33831 .89941 .32233 Metetra
.664 .741 .907 r
.2978 .49856 .31196 .51178 .33408 .50465 .32003 .49131 Metetra
.664 .741 .907 r
.32003 .49131 .33408 .50465 .35639 .49745 .34245 .484 Metetra
.664 .741 .907 r
.34245 .484 .35639 .49745 .37888 .49019 .36507 .47663 Metetra
.664 .741 .907 r
.36507 .47663 .37888 .49019 .40157 .48287 .38787 .46919 Metetra
.664 .741 .907 r
.38787 .46919 .40157 .48287 .42445 .47549 .41087 .46169 Metetra
.664 .741 .907 r
.41087 .46169 .42445 .47549 .44752 .46804 .43407 .45413 Metetra
.664 .741 .907 r
.43407 .45413 .44752 .46804 .47079 .46053 .45747 .4465 Metetra
.664 .741 .907 r
.45747 .4465 .47079 .46053 .49427 .45296 .48108 .4388 Metetra
.664 .741 .907 r
.48108 .4388 .49427 .45296 .51794 .44532 .50489 .43104 Metetra
.664 .741 .907 r
.50489 .43104 .51794 .44532 .54182 .43761 .5289 .42321 Metetra
.664 .741 .907 r
.5289 .42321 .54182 .43761 .56592 .42984 .55313 .41531 Metetra
.664 .741 .907 r
.55313 .41531 .56592 .42984 .59022 .422 .57758 .40734 Metetra
.664 .741 .907 r
.57758 .40734 .59022 .422 .61473 .41409 .60224 .3993 Metetra
.664 .741 .907 r
.60224 .3993 .61473 .41409 .63947 .40611 .62712 .39119 Metetra
.664 .741 .907 r
.62712 .39119 .63947 .40611 .66442 .39805 .65222 .383 Metetra
.664 .741 .907 r
.65222 .383 .66442 .39805 .6896 .38993 .67755 .37474 Metetra
.664 .741 .907 r
.67755 .37474 .6896 .38993 .715 .38173 .70311 .36641 Metetra
.664 .741 .907 r
.70311 .36641 .715 .38173 .74063 .37347 .72891 .35801 Metetra
.664 .741 .908 r
.72891 .35801 .74063 .37347 .76649 .36512 .75493 .34954 Metetra
.663 .741 .908 r
.75493 .34954 .76649 .36512 .79259 .3567 .7812 .34101 Metetra
.663 .741 .908 r
.7812 .34101 .79259 .3567 .81893 .34821 .80772 .33242 Metetra
.662 .742 .909 r
.80772 .33242 .81893 .34821 .8455 .33965 .83448 .32381 Metetra
.661 .743 .91 r
.83448 .32381 .8455 .33965 .87233 .33102 .8615 .31519 Metetra
.659 .744 .913 r
.8615 .31519 .87233 .33102 .89941 .32233 .8888 .30663 Metetra
.664 .741 .907 r
.28342 .48513 .2978 .49856 .32003 .49131 .30576 .47777 Metetra
.664 .741 .907 r
.30576 .47777 .32003 .49131 .34245 .484 .3283 .47034 Metetra
.664 .741 .907 r
.3283 .47034 .34245 .484 .36507 .47663 .35103 .46285 Metetra
.664 .741 .907 r
.35103 .46285 .36507 .47663 .38787 .46919 .37396 .4553 Metetra
.664 .741 .907 r
.37396 .4553 .38787 .46919 .41087 .46169 .39708 .44768 Metetra
.664 .741 .907 r
.39708 .44768 .41087 .46169 .43407 .45413 .42041 .43999 Metetra
.664 .741 .907 r
.42041 .43999 .43407 .45413 .45747 .4465 .44394 .43224 Metetra
.664 .741 .907 r
.44394 .43224 .45747 .4465 .48108 .4388 .46767 .42442 Metetra
.664 .741 .907 r
.46767 .42442 .48108 .4388 .50489 .43104 .49162 .41653 Metetra
.664 .741 .907 r
.49162 .41653 .50489 .43104 .5289 .42321 .51577 .40857 Metetra
.664 .741 .907 r
.51577 .40857 .5289 .42321 .55313 .41531 .54014 .40054 Metetra
.664 .741 .907 r
.54014 .40054 .55313 .41531 .57758 .40734 .56473 .39244 Metetra
.664 .741 .907 r
.56473 .39244 .57758 .40734 .60224 .3993 .58954 .38427 Metetra
.664 .741 .907 r
.58954 .38427 .60224 .3993 .62712 .39119 .61457 .37602 Metetra
.664 .741 .907 r
.61457 .37602 .62712 .39119 .65222 .383 .63983 .36771 Metetra
.664 .741 .908 r
.63983 .36771 .65222 .383 .67755 .37474 .66531 .35933 Metetra
.663 .741 .908 r
.66531 .35933 .67755 .37474 .70311 .36641 .69103 .3509 Metetra
.663 .741 .908 r
.69103 .3509 .70311 .36641 .72891 .35801 .71699 .34242 Metetra
.662 .742 .909 r
.71699 .34242 .72891 .35801 .75493 .34954 .7432 .33392 Metetra
.66 .743 .911 r
.7432 .33392 .75493 .34954 .7812 .34101 .76965 .32545 Metetra
.658 .745 .914 r
.76965 .32545 .7812 .34101 .80772 .33242 .79637 .31707 Metetra
.653 .748 .92 r
.79637 .31707 .80772 .33242 .83448 .32381 .82338 .30888 Metetra
.646 .754 .928 r
.82338 .30888 .83448 .32381 .8615 .31519 .85069 .30102 Metetra
.634 .763 .941 r
.85069 .30102 .8615 .31519 .8888 .30663 .87834 .29366 Metetra
.664 .741 .907 r
.26881 .47149 .28342 .48513 .30576 .47777 .29127 .46401 Metetra
.664 .741 .907 r
.29127 .46401 .30576 .47777 .3283 .47034 .31393 .45646 Metetra
.664 .741 .907 r
.31393 .45646 .3283 .47034 .35103 .46285 .33678 .44885 Metetra
.664 .741 .907 r
.33678 .44885 .35103 .46285 .37396 .4553 .35982 .44118 Metetra
.664 .741 .907 r
.35982 .44118 .37396 .4553 .39708 .44768 .38307 .43344 Metetra
.664 .741 .907 r
.38307 .43344 .39708 .44768 .42041 .43999 .40653 .42563 Metetra
.664 .741 .907 r
.40653 .42563 .42041 .43999 .44394 .43224 .43018 .41775 Metetra
.664 .741 .907 r
.43018 .41775 .44394 .43224 .46767 .42442 .45405 .4098 Metetra
.664 .741 .907 r
.45405 .4098 .46767 .42442 .49162 .41653 .47813 .40178 Metetra
.664 .741 .907 r
.47813 .40178 .49162 .41653 .51577 .40857 .50243 .39369 Metetra
.664 .741 .907 r
.50243 .39369 .51577 .40857 .54014 .40054 .52694 .38553 Metetra
.664 .741 .907 r
.52694 .38553 .54014 .40054 .56473 .39244 .55167 .37731 Metetra
.664 .741 .908 r
.55167 .37731 .56473 .39244 .58954 .38427 .57663 .36902 Metetra
.663 .741 .908 r
.57663 .36902 .58954 .38427 .61457 .37602 .60181 .36068 Metetra
.663 .741 .909 r
.60181 .36068 .61457 .37602 .63983 .36771 .62722 .35231 Metetra
.661 .742 .91 r
.62722 .35231 .63983 .36771 .66531 .35933 .65288 .34394 Metetra
.659 .744 .912 r
.65288 .34394 .66531 .35933 .69103 .3509 .67877 .33563 Metetra
.656 .746 .916 r
.67877 .33563 .69103 .3509 .71699 .34242 .70493 .32746 Metetra
.65 .751 .923 r
.70493 .32746 .71699 .34242 .7432 .33392 .73136 .31957 Metetra
.64 .758 .934 r
.73136 .31957 .7432 .33392 .76965 .32545 .75809 .31211 Metetra
.623 .77 .951 r
.75809 .31211 .76965 .32545 .79637 .31707 .78515 .30532 Metetra
.593 .787 .973 r
.78515 .30532 .79637 .31707 .82338 .30888 .8126 .29945 Metetra
.534 .806 .996 r
.8126 .29945 .82338 .30888 .85069 .30102 .8405 .29476 Metetra
.41 .803 .987 r
.8405 .29476 .85069 .30102 .87834 .29366 .8689 .29152 Metetra
.664 .741 .907 r
.25397 .45763 .26881 .47149 .29127 .46401 .27655 .45003 Metetra
.664 .741 .907 r
.27655 .45003 .29127 .46401 .31393 .45646 .29932 .44236 Metetra
.664 .741 .907 r
.29932 .44236 .31393 .45646 .33678 .44885 .32229 .43463 Metetra
.664 .741 .907 r
.32229 .43463 .33678 .44885 .35982 .44118 .34546 .42683 Metetra
.664 .741 .907 r
.34546 .42683 .35982 .44118 .38307 .43344 .36883 .41896 Metetra
.664 .741 .907 r
.36883 .41896 .38307 .43344 .40653 .42563 .39242 .41103 Metetra
.664 .741 .907 r
.39242 .41103 .40653 .42563 .43018 .41775 .41621 .40302 Metetra
.664 .741 .907 r
.41621 .40302 .43018 .41775 .45405 .4098 .44021 .39495 Metetra
.664 .741 .907 r
.44021 .39495 .45405 .4098 .47813 .40178 .46442 .38681 Metetra
.663 .741 .908 r
.46442 .38681 .47813 .40178 .50243 .39369 .48886 .37861 Metetra
.663 .741 .908 r
.48886 .37861 .50243 .39369 .52694 .38553 .51351 .37037 Metetra
.662 .742 .909 r
.51351 .37037 .52694 .38553 .55167 .37731 .53839 .36211 Metetra
.661 .743 .911 r
.53839 .36211 .55167 .37731 .57663 .36902 .5635 .35388 Metetra
.658 .744 .914 r
.5635 .35388 .57663 .36902 .60181 .36068 .58885 .34574 Metetra
.653 .748 .919 r
.58885 .34574 .60181 .36068 .62722 .35231 .61444 .33782 Metetra
.645 .754 .928 r
.61444 .33782 .62722 .35231 .65288 .34394 .6403 .33027 Metetra
.631 .763 .942 r
.6403 .33027 .65288 .34394 .67877 .33563 .66644 .32332 Metetra
.606 .778 .963 r
.66644 .32332 .67877 .33563 .70493 .32746 .69291 .31723 Metetra
.557 .798 .989 r
.69291 .31723 .70493 .32746 .73136 .31957 .71976 .31232 Metetra
.452 .806 .997 r
.71976 .31232 .73136 .31957 .75809 .31211 .74703 .3089 Metetra
.232 .734 .901 r
.74703 .3089 .75809 .31211 .78515 .30532 .77481 .30719 Metetra
.089 0 0 r
.77481 .30719 .78515 .30532 .8126 .29945 .80315 .30731 Metetra
.328 0 0 r
.80315 .30731 .8126 .29945 .8405 .29476 .83209 .30913 Metetra
.441 0 0 r
.83209 .30913 .8405 .29476 .8689 .29152 .86167 .31224 Metetra
.664 .741 .907 r
.23889 .44355 .25397 .45763 .27655 .45003 .26159 .43582 Metetra
.664 .741 .907 r
.26159 .43582 .27655 .45003 .29932 .44236 .28448 .42804 Metetra
.664 .741 .907 r
.28448 .42804 .29932 .44236 .32229 .43463 .30757 .42018 Metetra
.664 .741 .907 r
.30757 .42018 .32229 .43463 .34546 .42683 .33086 .41226 Metetra
.664 .741 .907 r
.33086 .41226 .34546 .42683 .36883 .41896 .35436 .40426 Metetra
.664 .741 .908 r
.35436 .40426 .36883 .41896 .39242 .41103 .37807 .39621 Metetra
.663 .741 .908 r
.37807 .39621 .39242 .41103 .41621 .40302 .40199 .3881 Metetra
.663 .741 .908 r
.40199 .3881 .41621 .40302 .44021 .39495 .42613 .37996 Metetra
.662 .742 .909 r
.42613 .37996 .44021 .39495 .46442 .38681 .45048 .37182 Metetra
.66 .743 .912 r
.45048 .37182 .46442 .38681 .48886 .37861 .47505 .36373 Metetra
.656 .745 .916 r
.47505 .36373 .48886 .37861 .51351 .37037 .49985 .35579 Metetra
.649 .75 .923 r
.49985 .35579 .51351 .37037 .53839 .36211 .52489 .34816 Metetra
.638 .757 .935 r
.52489 .34816 .53839 .36211 .5635 .35388 .55017 .34104 Metetra
.617 .77 .953 r
.55017 .34104 .5635 .35388 .58885 .34574 .57572 .33471 Metetra
.577 .788 .979 r
.57572 .33471 .58885 .34574 .61444 .33782 .60158 .32952 Metetra
.492 .803 1 r
.60158 .32952 .61444 .33782 .6403 .33027 .62779 .32582 Metetra
.299 .762 .946 r
.62779 .32582 .6403 .33027 .66644 .32332 .65441 .32394 Metetra
.036 0 0 r
.65441 .32394 .66644 .32332 .69291 .31723 .68151 .3241 Metetra
.319 0 0 r
.68151 .3241 .69291 .31723 .71976 .31232 .70914 .32626 Metetra
.451 0 0 r
.70914 .32626 .71976 .31232 .74703 .3089 .73734 .33009 Metetra
.501 .062 .136 r
.73734 .33009 .74703 .3089 .77481 .30719 .76612 .33487 Metetra
.514 .109 .211 r
.76612 .33487 .77481 .30719 .80315 .30731 .79542 .33952 Metetra
.507 .121 .244 r
.79542 .33952 .80315 .30731 .83209 .30913 .82513 .3427 Metetra
.483 .105 .245 r
.82513 .3427 .83209 .30913 .86167 .31224 .85507 .34301 Metetra
.664 .741 .907 r
.22357 .42924 .23889 .44355 .26159 .43582 .24638 .4214 Metetra
.664 .741 .907 r
.24638 .4214 .26159 .43582 .28448 .42804 .26939 .41349 Metetra
.664 .741 .908 r
.26939 .41349 .28448 .42804 .30757 .42018 .2926 .40552 Metetra
.663 .741 .908 r
.2926 .40552 .30757 .42018 .33086 .41226 .31602 .3975 Metetra
.663 .741 .909 r
.31602 .3975 .33086 .41226 .35436 .40426 .33964 .38946 Metetra
.661 .742 .91 r
.33964 .38946 .35436 .40426 .37807 .39621 .36348 .38143 Metetra
.658 .744 .913 r
.36348 .38143 .37807 .39621 .40199 .3881 .38752 .3735 Metetra
.653 .746 .918 r
.38752 .3735 .40199 .3881 .42613 .37996 .41178 .3658 Metetra
.644 .752 .927 r
.41178 .3658 .42613 .37996 .45048 .37182 .43625 .35851 Metetra
.628 .762 .943 r
.43625 .35851 .45048 .37182 .47505 .36373 .46095 .35192 Metetra
.596 .778 .967 r
.46095 .35192 .47505 .36373 .49985 .35579 .48589 .34639 Metetra
.528 .796 .995 r
.48589 .34639 .49985 .35579 .52489 .34816 .5111 .34233 Metetra
.368 .782 .979 r
.5111 .34233 .52489 .34816 .55017 .34104 .53663 .34016 Metetra
.038 .607 .755 r
.53663 .34016 .55017 .34104 .57572 .33471 .56253 .34022 Metetra
.299 0 0 r
.56253 .34022 .57572 .33471 .60158 .32952 .58887 .3426 Metetra
.459 0 0 r
.58887 .3426 .60158 .32952 .62779 .32582 .61571 .34708 Metetra
.516 .079 .147 r
.61571 .34708 .62779 .32582 .65441 .32394 .64309 .35298 Metetra
.531 .132 .23 r
.64309 .35298 .65441 .32394 .68151 .3241 .671 .35915 Metetra
.525 .148 .268 r
.671 .35915 .68151 .3241 .70914 .32626 .69939 .36409 Metetra
.503 .136 .276 r
.69939 .36409 .70914 .32626 .73734 .33009 .72812 .36613 Metetra
.46 .091 .25 r
.72812 .36613 .73734 .33009 .76612 .33487 .75701 .36378 Metetra
.371 0 .162 r
.75701 .36378 .76612 .33487 .79542 .33952 .78588 .35602 Metetra
.115 0 0 r
.78588 .35602 .79542 .33952 .82513 .3427 .81456 .34261 Metetra
.653 .97 .858 r
.81456 .34261 .82513 .3427 .85507 .34301 .84296 .32409 Metetra
.663 .741 .908 r
.208 .41473 .22357 .42924 .24638 .4214 .23092 .4068 Metetra
.662 .741 .909 r
.23092 .4068 .24638 .4214 .26939 .41349 .25405 .39886 Metetra
.66 .742 .911 r
.25405 .39886 .26939 .41349 .2926 .40552 .27737 .39096 Metetra
.657 .744 .914 r
.27737 .39096 .2926 .40552 .31602 .3975 .30088 .38321 Metetra
.65 .748 .921 r
.30088 .38321 .31602 .3975 .33964 .38946 .32459 .37577 Metetra
.637 .755 .934 r
.32459 .37577 .33964 .38946 .36348 .38143 .3485 .36892 Metetra
.613 .768 .954 r
.3485 .36892 .36348 .38143 .38752 .3735 .37259 .363 Metetra
.561 .786 .983 r
.37259 .363 .38752 .3735 .41178 .3658 .39688 .35849 Metetra
.435 .791 .997 r
.39688 .35849 .41178 .3658 .43625 .35851 .4214 .3559 Metetra
.135 .672 .85 r
.4214 .3559 .43625 .35851 .46095 .35192 .44617 .35568 Metetra
.26 0 0 r
.44617 .35568 .46095 .35192 .48589 .34639 .47127 .35812 Metetra
.463 0 0 r
.47127 .35812 .48589 .34639 .5111 .34233 .49675 .36314 Metetra
.531 .093 .154 r
.49675 .36314 .5111 .34233 .53663 .34016 .5227 .37015 Metetra
.548 .154 .247 r
.5227 .37015 .53663 .34016 .56253 .34022 .54917 .37797 Metetra
.542 .173 .29 r
.54917 .37797 .56253 .34022 .58887 .3426 .57615 .38492 Metetra
.521 .165 .303 r
.57615 .38492 .58887 .3426 .61571 .34708 .6036 .389 Metetra
.483 .127 .286 r
.6036 .389 .61571 .34708 .64309 .35298 .63139 .38835 Metetra
.406 .036 .219 r
.63139 .38835 .64309 .35298 .671 .35915 .65935 .38166 Metetra
.2 0 .002 r
.65935 .38166 .671 .35915 .69939 .36409 .6873 .3685 Metetra
.557 .92 .747 r
.6873 .3685 .69939 .36409 .72812 .36613 .71512 .34947 Metetra
.809 .802 .845 r
.71512 .34947 .72812 .36613 .75701 .36378 .74275 .32602 Metetra
.736 .623 .733 r
.74275 .32602 .75701 .36378 .78588 .35602 .77021 .30006 Metetra
.692 .545 .683 r
.77021 .30006 .78588 .35602 .81456 .34261 .79761 .27354 Metetra
.664 .506 .659 r
.79761 .27354 .81456 .34261 .84296 .32409 .82508 .24808 Metetra
.655 .745 .916 r
.19213 .4004 .208 .41473 .23092 .4068 .21513 .39285 Metetra
.645 .75 .925 r
.21513 .39285 .23092 .4068 .25405 .39886 .23829 .38574 Metetra
.627 .759 .942 r
.23829 .38574 .25405 .39886 .27737 .39096 .2616 .37942 Metetra
.588 .775 .969 r
.2616 .37942 .27737 .39096 .30088 .38321 .28506 .37438 Metetra
.495 .79 .998 r
.28506 .37438 .30088 .38321 .32459 .37577 .30864 .37121 Metetra
.249 .729 .933 r
.30864 .37121 .32459 .37577 .3485 .36892 .33237 .37052 Metetra
.192 0 0 r
.33237 .37052 .3485 .36892 .37259 .363 .35628 .3728 Metetra
.461 0 0 r
.35628 .3728 .37259 .363 .39688 .35849 .38043 .37819 Metetra
.546 .105 .154 r
.38043 .37819 .39688 .35849 .4214 .3559 .40493 .38626 Metetra
.565 .175 .261 r
.40493 .38626 .4214 .3559 .44617 .35568 .42988 .39585 Metetra
.56 .198 .311 r
.42988 .39585 .44617 .35568 .47127 .35812 .45538 .40508 Metetra
.539 .192 .328 r
.45538 .40508 .47127 .35812 .49675 .36314 .48144 .4116 Metetra
.503 .16 .318 r
.48144 .4116 .49675 .36314 .5227 .37015 .50804 .41305 Metetra
.436 .083 .267 r
.50804 .41305 .5227 .37015 .54917 .37797 .53505 .40767 Metetra
.268 0 .102 r
.53505 .40767 .54917 .37797 .57615 .38492 .56231 .39481 Metetra
.418 .809 .578 r
.56231 .39481 .57615 .38492 .6036 .389 .58963 .3751 Metetra
.829 .827 .846 r
.58963 .3751 .6036 .389 .63139 .38835 .61689 .35029 Metetra
.743 .623 .726 r
.61689 .35029 .63139 .38835 .65935 .38166 .64406 .32273 Metetra
.692 .539 .674 r
.64406 .32273 .65935 .38166 .6873 .3685 .67115 .29478 Metetra
.662 .497 .651 r
.67115 .29478 .6873 .3685 .71512 .34947 .69828 .26831 Metetra
.643 .476 .642 r
.69828 .26831 .71512 .34947 .74275 .32602 .72555 .24448 Metetra
.631 .468 .643 r
.72555 .24448 .74275 .32602 .77021 .30006 .75307 .22373 Metetra
.625 .47 .652 r
.75307 .22373 .77021 .30006 .79761 .27354 .78093 .20593 Metetra
.623 .481 .667 r
.78093 .20593 .79761 .27354 .82508 .24808 .80915 .19058 Metetra
.546 .78 .985 r
.17553 .39009 .19213 .4004 .21513 .39285 .19829 .3862 Metetra
.365 .766 .985 r
.19829 .3862 .21513 .39285 .23829 .38574 .22107 .3848 Metetra
.076 0 0 r
.22107 .3848 .23829 .38574 .2616 .37942 .24388 .38664 Metetra
.446 0 0 r
.24388 .38664 .2616 .37942 .28506 .37438 .26675 .39214 Metetra
.56 .113 .146 r
.26675 .39214 .28506 .37438 .30864 .37121 .28979 .40113 Metetra
.584 .195 .272 r
.28979 .40113 .30864 .37121 .33237 .37052 .31315 .41258 Metetra
.578 .222 .329 r
.31315 .41258 .33237 .37052 .35628 .3728 .33701 .42443 Metetra
.558 .219 .351 r
.33701 .42443 .35628 .3728 .38043 .37819 .36155 .4339 Metetra
.523 .191 .346 r
.36155 .4339 .38043 .37819 .40493 .38626 .38683 .43798 Metetra
.462 .124 .307 r
.38683 .43798 .40493 .38626 .42988 .39585 .41284 .43429 Metetra
.322 0 .182 r
.41284 .43429 .42988 .39585 .45538 .40508 .43941 .42179 Metetra
.43941 .42179 .45538 .40508 .48144 .4116 .46633 .40116 Metetra
.852 .857 .845 r
.46633 .40116 .48144 .4116 .50804 .41305 .49337 .37458 Metetra
.75 .623 .719 r
.49337 .37458 .50804 .41305 .53505 .40767 .52039 .34499 Metetra
.692 .532 .665 r
.52039 .34499 .53505 .40767 .56231 .39481 .54733 .31527 Metetra
.659 .488 .642 r
.54733 .31527 .56231 .39481 .58963 .3751 .57421 .28763 Metetra
.638 .466 .634 r
.57421 .28763 .58963 .3751 .61689 .35029 .60112 .26333 Metetra
.626 .458 .635 r
.60112 .26333 .61689 .35029 .64406 .32273 .62816 .24269 Metetra
.619 .461 .645 r
.62816 .24269 .64406 .32273 .67115 .29478 .65541 .22537 Metetra
.618 .474 .663 r
.65541 .22537 .67115 .29478 .69828 .26831 .68294 .21067 Metetra
.622 .497 .689 r
.68294 .21067 .69828 .26831 .72555 .24448 .71078 .19785 Metetra
.629 .531 .724 r
.71078 .19785 .72555 .24448 .75307 .22373 .73893 .1862 Metetra
.639 .574 .765 r
.73893 .1862 .75307 .22373 .78093 .20593 .76739 .17523 Metetra
.649 .619 .806 r
.76739 .17523 .78093 .20593 .80915 .19058 .79616 .16458 Metetra
.572 .112 .124 r
.15571 .40489 .17553 .39009 .19829 .3862 .1773 .41455 Metetra
.604 .215 .279 r
.1773 .41455 .19829 .3862 .22107 .3848 .19899 .42787 Metetra
.598 .247 .346 r
.19899 .42787 .22107 .3848 .24388 .38664 .22106 .44274 Metetra
.577 .246 .372 r
.22106 .44274 .24388 .38664 .26675 .39214 .24385 .45585 Metetra
.542 .22 .372 r
.24385 .45585 .26675 .39214 .28979 .40113 .26763 .46332 Metetra
.485 .161 .343 r
.26763 .46332 .28979 .40113 .31315 .41258 .29251 .46184 Metetra
.364 .023 .247 r
.29251 .46184 .31315 .41258 .33701 .42443 .31841 .44981 Metetra
.31841 .44981 .33701 .42443 .36155 .4339 .34505 .42794 Metetra
.878 .892 .839 r
.34505 .42794 .36155 .4339 .38683 .43798 .37207 .39899 Metetra
.758 .623 .711 r
.37207 .39899 .38683 .43798 .41284 .43429 .39914 .36675 Metetra
.691 .524 .655 r
.39914 .36675 .41284 .43429 .43941 .42179 .42608 .33485 Metetra
.654 .478 .633 r
.42608 .33485 .43941 .42179 .46633 .40116 .45283 .3059 Metetra
.632 .455 .625 r
.45283 .3059 .46633 .40116 .49337 .37458 .47944 .2812 Metetra
.619 .447 .627 r
.47944 .2812 .49337 .37458 .52039 .34499 .50602 .26084 Metetra
.613 .451 .638 r
.50602 .26084 .52039 .34499 .54733 .31527 .53268 .24419 Metetra
.613 .466 .659 r
.53268 .24419 .54733 .31527 .57421 .28763 .5595 .23029 Metetra
.618 .494 .689 r
.5595 .23029 .57421 .28763 .60112 .26333 .58655 .2182 Metetra
.628 .533 .728 r
.58655 .2182 .60112 .26333 .62816 .24269 .61386 .20716 Metetra
.639 .582 .774 r
.61386 .20716 .62816 .24269 .65541 .22537 .64144 .19666 Metetra
.65 .631 .818 r
.64144 .19666 .65541 .22537 .68294 .21067 .6693 .18638 Metetra
.657 .673 .854 r
.6693 .18638 .68294 .21067 .71078 .19785 .69744 .17615 Metetra
.661 .703 .878 r
.69744 .17615 .71078 .19785 .73893 .1862 .72587 .16588 Metetra
.663 .722 .893 r
.72587 .16588 .73893 .1862 .76739 .17523 .75458 .15553 Metetra
.663 .732 .901 r
.75458 .15553 .76739 .17523 .79616 .16458 .78359 .14509 Metetra
.562 .249 .396 r
.12831 .47724 .15571 .40489 .1773 .41455 .15027 .48922 Metetra
.506 .195 .373 r
.15027 .48922 .1773 .41455 .19899 .42787 .17383 .49081 Metetra
.399 .077 .299 r
.17383 .49081 .19899 .42787 .22106 .44274 .19906 .47944 Metetra
.026 0 0 r
.19906 .47944 .22106 .44274 .24385 .45585 .22558 .45583 Metetra
.903 .93 .823 r
.22558 .45583 .24385 .45585 .26763 .46332 .25285 .42361 Metetra
.767 .624 .701 r
.25285 .42361 .26763 .46332 .29251 .46184 .28026 .38785 Metetra
.69 .515 .645 r
.28026 .38785 .29251 .46184 .31841 .44981 .30741 .35325 Metetra
.649 .466 .622 r
.30741 .35325 .31841 .44981 .34505 .42794 .33415 .32288 Metetra
.625 .442 .615 r
.33415 .32288 .34505 .42794 .37207 .39899 .3605 .29795 Metetra
.611 .435 .619 r
.3605 .29795 .37207 .39899 .39914 .36675 .38661 .27818 Metetra
.605 .44 .632 r
.38661 .27818 .39914 .36675 .42608 .33485 .41264 .26247 Metetra
.606 .459 .655 r
.41264 .26247 .42608 .33485 .45283 .3059 .43874 .24952 Metetra
.614 .492 .69 r
.43874 .24952 .45283 .3059 .47944 .2812 .46499 .23822 Metetra
.627 .539 .736 r
.46499 .23822 .47944 .2812 .50602 .26084 .49146 .22779 Metetra
.641 .594 .786 r
.49146 .22779 .50602 .26084 .53268 .24419 .51817 .21772 Metetra
.652 .647 .832 r
.51817 .21772 .53268 .24419 .5595 .23029 .54514 .20777 Metetra
.659 .688 .866 r
.54514 .20777 .5595 .23029 .58655 .2182 .57237 .19781 Metetra
.662 .714 .887 r
.57237 .19781 .58655 .2182 .61386 .20716 .59988 .18778 Metetra
.663 .728 .898 r
.59988 .18778 .61386 .20716 .64144 .19666 .62765 .17766 Metetra
.664 .736 .903 r
.62765 .17766 .64144 .19666 .6693 .18638 .65571 .16744 Metetra
.664 .739 .906 r
.65571 .16744 .6693 .18638 .69744 .17615 .68405 .15712 Metetra
.664 .74 .907 r
.68405 .15712 .69744 .17615 .72587 .16588 .71267 .1467 Metetra
.664 .741 .907 r
.71267 .1467 .72587 .16588 .75458 .15553 .74159 .13617 Metetra
.664 .741 .907 r
.74159 .13617 .75458 .15553 .78359 .14509 .7708 .12553 Metetra
.921 .962 .786 r
.10765 .48541 .12831 .47724 .15027 .48922 .13558 .44851 Metetra
.776 .624 .691 r
.13558 .44851 .15027 .48922 .17383 .49081 .16373 .40798 Metetra
.687 .504 .634 r
.16373 .40798 .17383 .49081 .19906 .47944 .19138 .37003 Metetra
.642 .452 .612 r
.19138 .37003 .19906 .47944 .22558 .45583 .21821 .33825 Metetra
.615 .428 .605 r
.21821 .33825 .22558 .45583 .25285 .42361 .2443 .31349 Metetra
.601 .421 .61 r
.2443 .31349 .25285 .42361 .28026 .38785 .26989 .29477 Metetra
.596 .429 .625 r
.26989 .29477 .28026 .38785 .30741 .35325 .29523 .28032 Metetra
.6 .452 .653 r
.29523 .28032 .30741 .35325 .33415 .32288 .32055 .26848 Metetra
.611 .493 .694 r
.32055 .26848 .33415 .32288 .3605 .29795 .34599 .258 Metetra
.628 .55 .747 r
.34599 .258 .3605 .29795 .38661 .27818 .37162 .24811 Metetra
.644 .612 .803 r
.37162 .24811 .38661 .27818 .41264 .26247 .39748 .23842 Metetra
.655 .666 .849 r
.39748 .23842 .41264 .26247 .43874 .24952 .42358 .22876 Metetra
.66 .703 .878 r
.42358 .22876 .43874 .24952 .46499 .23822 .44993 .21903 Metetra
.663 .724 .895 r
.44993 .21903 .46499 .23822 .49146 .22779 .47655 .20922 Metetra
.663 .734 .902 r
.47655 .20922 .49146 .22779 .51817 .21772 .50342 .19932 Metetra
.664 .738 .905 r
.50342 .19932 .51817 .21772 .54514 .20777 .53056 .18932 Metetra
.664 .74 .907 r
.53056 .18932 .54514 .20777 .57237 .19781 .55798 .17922 Metetra
.664 .741 .907 r
.55798 .17922 .57237 .19781 .59988 .18778 .58566 .16902 Metetra
.664 .741 .907 r
.58566 .16902 .59988 .18778 .62765 .17766 .61363 .15872 Metetra
.664 .741 .907 r
.61363 .15872 .62765 .17766 .65571 .16744 .64187 .14831 Metetra
.664 .741 .907 r
.64187 .14831 .65571 .16744 .68405 .15712 .67041 .1378 Metetra
.664 .741 .907 r
.67041 .1378 .68405 .15712 .71267 .1467 .69923 .12718 Metetra
.664 .741 .907 r
.69923 .12718 .71267 .1467 .74159 .13617 .72835 .11645 Metetra
.664 .741 .907 r
.72835 .11645 .74159 .13617 .7708 .12553 .75778 .10561 Metetra
.603 .41 .594 r
.10512 .35158 .10765 .48541 .13558 .44851 .13085 .32778 Metetra
.589 .404 .6 r
.13085 .32778 .13558 .44851 .16373 .40798 .15578 .31078 Metetra
.586 .417 .619 r
.15578 .31078 .16373 .40798 .19138 .37003 .18034 .29797 Metetra
.594 .448 .653 r
.18034 .29797 .19138 .37003 .21821 .33825 .20484 .28731 Metetra
.61 .5 .703 r
.20484 .28731 .21821 .33825 .2443 .31349 .22945 .27758 Metetra
.631 .568 .766 r
.22945 .27758 .2443 .31349 .26989 .29477 .25425 .26815 Metetra
.648 .637 .825 r
.25425 .26815 .26989 .29477 .29523 .28032 .27928 .25877 Metetra
.658 .688 .867 r
.27928 .25877 .29523 .28032 .32055 .26848 .30454 .24933 Metetra
.662 .718 .89 r
.30454 .24933 .32055 .26848 .34599 .258 .33004 .23982 Metetra
.663 .732 .901 r
.33004 .23982 .34599 .258 .37162 .24811 .3558 .23022 Metetra
.664 .738 .905 r
.3558 .23022 .37162 .24811 .39748 .23842 .3818 .22052 Metetra
.664 .74 .907 r
.3818 .22052 .39748 .23842 .42358 .22876 .40806 .21073 Metetra
.664 .741 .907 r
.40806 .21073 .42358 .22876 .44993 .21903 .43458 .20085 Metetra
.664 .741 .907 r
.43458 .20085 .44993 .21903 .47655 .20922 .46136 .19086 Metetra
.664 .741 .907 r
.46136 .19086 .47655 .20922 .50342 .19932 .4884 .18078 Metetra
.664 .741 .907 r
.4884 .18078 .50342 .19932 .53056 .18932 .51572 .17059 Metetra
.664 .741 .907 r
.51572 .17059 .53056 .18932 .55798 .17922 .54331 .16031 Metetra
.664 .741 .907 r
.54331 .16031 .55798 .17922 .58566 .16902 .57118 .14992 Metetra
.664 .741 .907 r
.57118 .14992 .58566 .16902 .61363 .15872 .59933 .13942 Metetra
.664 .741 .907 r
.59933 .13942 .61363 .15872 .64187 .14831 .62778 .12882 Metetra
.664 .741 .907 r
.62778 .12882 .64187 .14831 .67041 .1378 .65651 .1181 Metetra
.664 .741 .907 r
.65651 .1181 .67041 .1378 .69923 .12718 .68554 .10728 Metetra
.664 .741 .907 r
.68554 .10728 .69923 .12718 .72835 .11645 .71486 .09635 Metetra
.664 .741 .907 r
.71486 .09635 .72835 .11645 .75778 .10561 .7445 .0853 Metetra
.613 .517 .721 r
.09147 .30614 .10512 .35158 .13085 .32778 .11527 .29698 Metetra
.638 .599 .793 r
.11527 .29698 .13085 .32778 .15578 .31078 .13927 .28788 Metetra
.654 .668 .852 r
.13927 .28788 .15578 .31078 .18034 .29797 .16349 .27873 Metetra
.661 .711 .885 r
.16349 .27873 .18034 .29797 .20484 .28731 .18794 .2695 Metetra
.663 .73 .899 r
.18794 .2695 .20484 .28731 .22945 .27758 .21263 .26019 Metetra
.664 .737 .905 r
.21263 .26019 .22945 .27758 .25425 .26815 .23755 .25079 Metetra
.664 .74 .907 r
.23755 .25079 .25425 .26815 .27928 .25877 .26271 .24129 Metetra
.664 .741 .907 r
.26271 .24129 .27928 .25877 .30454 .24933 .28812 .2317 Metetra
.664 .741 .907 r
.28812 .2317 .30454 .24933 .33004 .23982 .31377 .22202 Metetra
.664 .741 .907 r
.31377 .22202 .33004 .23982 .3558 .23022 .33968 .21225 Metetra
.664 .741 .907 r
.33968 .21225 .3558 .23022 .3818 .22052 .36584 .20238 Metetra
.664 .741 .907 r
.36584 .20238 .3818 .22052 .40806 .21073 .39226 .19241 Metetra
.664 .741 .907 r
.39226 .19241 .40806 .21073 .43458 .20085 .41894 .18234 Metetra
.664 .741 .907 r
.41894 .18234 .43458 .20085 .46136 .19086 .44589 .17217 Metetra
.664 .741 .907 r
.44589 .17217 .46136 .19086 .4884 .18078 .47311 .1619 Metetra
.664 .741 .907 r
.47311 .1619 .4884 .18078 .51572 .17059 .5006 .15152 Metetra
.664 .741 .907 r
.5006 .15152 .51572 .17059 .54331 .16031 .52837 .14104 Metetra
.664 .741 .907 r
.52837 .14104 .54331 .16031 .57118 .14992 .55643 .13045 Metetra
.664 .741 .907 r
.55643 .13045 .57118 .14992 .59933 .13942 .58477 .11976 Metetra
.664 .741 .907 r
.58477 .11976 .59933 .13942 .62778 .12882 .61341 .10895 Metetra
.664 .741 .907 r
.61341 .10895 .62778 .12882 .65651 .1181 .64234 .09804 Metetra
.664 .741 .907 r
.64234 .09804 .65651 .1181 .68554 .10728 .67158 .087 Metetra
.664 .741 .907 r
.67158 .087 .68554 .10728 .71486 .09635 .70111 .07586 Metetra
.664 .741 .907 r
.70111 .07586 .71486 .09635 .7445 .0853 .73096 .06459 Metetra
.664 .738 .905 r
.07371 .28927 .09147 .30614 .11527 .29698 .0976 .28014 Metetra
.664 .74 .907 r
.0976 .28014 .11527 .29698 .13927 .28788 .12172 .27093 Metetra
.664 .741 .907 r
.12172 .27093 .13927 .28788 .16349 .27873 .14607 .26163 Metetra
.664 .741 .907 r
.14607 .26163 .16349 .27873 .18794 .2695 .17065 .25224 Metetra
.664 .741 .907 r
.17065 .25224 .18794 .2695 .21263 .26019 .19547 .24276 Metetra
.664 .741 .907 r
.19547 .24276 .21263 .26019 .23755 .25079 .22054 .23318 Metetra
.664 .741 .907 r
.22054 .23318 .23755 .25079 .26271 .24129 .24584 .22352 Metetra
.664 .741 .907 r
.24584 .22352 .26271 .24129 .28812 .2317 .2714 .21376 Metetra
.664 .741 .907 r
.2714 .21376 .28812 .2317 .31377 .22202 .2972 .2039 Metetra
.664 .741 .907 r
.2972 .2039 .31377 .22202 .33968 .21225 .32326 .19395 Metetra
.664 .741 .907 r
.32326 .19395 .33968 .21225 .36584 .20238 .34958 .18389 Metetra
.664 .741 .907 r
.34958 .18389 .36584 .20238 .39226 .19241 .37616 .17374 Metetra
.664 .741 .907 r
.37616 .17374 .39226 .19241 .41894 .18234 .40301 .16348 Metetra
.664 .741 .907 r
.40301 .16348 .41894 .18234 .44589 .17217 .43013 .15312 Metetra
.664 .741 .907 r
.43013 .15312 .44589 .17217 .47311 .1619 .45752 .14266 Metetra
.664 .741 .907 r
.45752 .14266 .47311 .1619 .5006 .15152 .4852 .13209 Metetra
.664 .741 .907 r
.4852 .13209 .5006 .15152 .52837 .14104 .51315 .12141 Metetra
.664 .741 .907 r
.51315 .12141 .52837 .14104 .55643 .13045 .5414 .11062 Metetra
.664 .741 .907 r
.5414 .11062 .55643 .13045 .58477 .11976 .56993 .09972 Metetra
.664 .741 .907 r
.56993 .09972 .58477 .11976 .61341 .10895 .59877 .08871 Metetra
.664 .741 .907 r
.59877 .08871 .61341 .10895 .64234 .09804 .6279 .07758 Metetra
.664 .741 .907 r
.6279 .07758 .64234 .09804 .67158 .087 .65734 .06633 Metetra
.664 .741 .907 r
.65734 .06633 .67158 .087 .70111 .07586 .6871 .05497 Metetra
.664 .741 .907 r
.6871 .05497 .70111 .07586 .73096 .06459 .71716 .04348 Metetra
.664 .741 .907 r
.05559 .27235 .07371 .28927 .0976 .28014 .07961 .26307 Metetra
.664 .741 .907 r
.07961 .26307 .0976 .28014 .12172 .27093 .10386 .25369 Metetra
.664 .741 .907 r
.10386 .25369 .12172 .27093 .14607 .26163 .12834 .24422 Metetra
.664 .741 .907 r
.12834 .24422 .14607 .26163 .17065 .25224 .15306 .23466 Metetra
.664 .741 .907 r
.15306 .23466 .17065 .25224 .19547 .24276 .17801 .22501 Metetra
.664 .741 .907 r
.17801 .22501 .19547 .24276 .22054 .23318 .20322 .21527 Metetra
.664 .741 .907 r
.20322 .21527 .22054 .23318 .24584 .22352 .22867 .20542 Metetra
.664 .741 .907 r
.22867 .20542 .24584 .22352 .2714 .21376 .25437 .19548 Metetra
.664 .741 .907 r
.25437 .19548 .2714 .21376 .2972 .2039 .28033 .18545 Metetra
.664 .741 .907 r
.28033 .18545 .2972 .2039 .32326 .19395 .30654 .17531 Metetra
.664 .741 .907 r
.30654 .17531 .32326 .19395 .34958 .18389 .33302 .16507 Metetra
.664 .741 .907 r
.33302 .16507 .34958 .18389 .37616 .17374 .35977 .15473 Metetra
.664 .741 .907 r
.35977 .15473 .37616 .17374 .40301 .16348 .38678 .14428 Metetra
.664 .741 .907 r
.38678 .14428 .40301 .16348 .43013 .15312 .41408 .13372 Metetra
.664 .741 .907 r
.41408 .13372 .43013 .15312 .45752 .14266 .44165 .12306 Metetra
.664 .741 .907 r
.44165 .12306 .45752 .14266 .4852 .13209 .4695 .11229 Metetra
.664 .741 .907 r
.4695 .11229 .4852 .13209 .51315 .12141 .49764 .10141 Metetra
.664 .741 .907 r
.49764 .10141 .51315 .12141 .5414 .11062 .52608 .09041 Metetra
.664 .741 .907 r
.52608 .09041 .5414 .11062 .56993 .09972 .55481 .0793 Metetra
.664 .741 .907 r
.55481 .0793 .56993 .09972 .59877 .08871 .58384 .06807 Metetra
.664 .741 .907 r
.58384 .06807 .59877 .08871 .6279 .07758 .61318 .05673 Metetra
.664 .741 .907 r
.61318 .05673 .6279 .07758 .65734 .06633 .64283 .04526 Metetra
.664 .741 .907 r
.64283 .04526 .65734 .06633 .6871 .05497 .6728 .03367 Metetra
.664 .741 .907 r
.6728 .03367 .6871 .05497 .71716 .04348 .70309 .02196 Metetra
.664 .741 .907 r
.03716 .25514 .05559 .27235 .07961 .26307 .0613 .24568 Metetra
.664 .741 .907 r
.0613 .24568 .07961 .26307 .10386 .25369 .08568 .23614 Metetra
.664 .741 .907 r
.08568 .23614 .10386 .25369 .12834 .24422 .11029 .2265 Metetra
.664 .741 .907 r
.11029 .2265 .12834 .24422 .15306 .23466 .13514 .21677 Metetra
.664 .741 .907 r
.13514 .21677 .15306 .23466 .17801 .22501 .16024 .20694 Metetra
.664 .741 .907 r
.16024 .20694 .17801 .22501 .20322 .21527 .18558 .19702 Metetra
.664 .741 .907 r
.18558 .19702 .20322 .21527 .22867 .20542 .21118 .187 Metetra
.664 .741 .907 r
.21118 .187 .22867 .20542 .25437 .19548 .23703 .17687 Metetra
.664 .741 .907 r
.23703 .17687 .25437 .19548 .28033 .18545 .26314 .16665 Metetra
.664 .741 .907 r
.26314 .16665 .28033 .18545 .30654 .17531 .28951 .15632 Metetra
.664 .741 .907 r
.28951 .15632 .30654 .17531 .33302 .16507 .31615 .14589 Metetra
.664 .741 .907 r
.31615 .14589 .33302 .16507 .35977 .15473 .34306 .13535 Metetra
.664 .741 .907 r
.34306 .13535 .35977 .15473 .38678 .14428 .37025 .12471 Metetra
.664 .741 .907 r
.37025 .12471 .38678 .14428 .41408 .13372 .39772 .11395 Metetra
.664 .741 .907 r
.39772 .11395 .41408 .13372 .44165 .12306 .42547 .10309 Metetra
.664 .741 .907 r
.42547 .10309 .44165 .12306 .4695 .11229 .4535 .09211 Metetra
.664 .741 .907 r
.4535 .09211 .4695 .11229 .49764 .10141 .48183 .08102 Metetra
.664 .741 .907 r
.48183 .08102 .49764 .10141 .52608 .09041 .51046 .06981 Metetra
.664 .741 .907 r
.51046 .06981 .52608 .09041 .55481 .0793 .53939 .05848 Metetra
.664 .741 .907 r
.53939 .05848 .55481 .0793 .58384 .06807 .56863 .04703 Metetra
.664 .741 .907 r
.56863 .04703 .58384 .06807 .61318 .05673 .59817 .03546 Metetra
.664 .741 .907 r
.59817 .03546 .61318 .05673 .64283 .04526 .62804 .02377 Metetra
.664 .741 .907 r
.62804 .02377 .64283 .04526 .6728 .03367 .65822 .01195 Metetra
.664 .741 .907 r
.65822 .01195 .6728 .03367 .70309 .02196 .68874 0 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(1)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(1.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(1.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(1.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(1.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(2)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[133]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[133]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[
      Evaluate[cOut[z, t] /. {d\_n \[Rule] 0.1, r\_n \[Rule] 0}], {z, 0.1, 
        2}, {t, 0.1, 4}, \ PlotRange \[Rule] {0, 4}]\)], "Input",
  CellLabel->"In[134]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.15237 .19707 -17.8465 -9 ]
[.15237 .19707 .15354 0 ]
[.31741 .13214 -5.61962 -9 ]
[.31741 .13214 .38038 0 ]
[.49342 .06293 -15.8713 -9 ]
[.49342 .06293 2.12873 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.77714 .11187 0 -6.14746 ]
[.77714 .11187 6 2.85254 ]
[.85293 .22792 0 -6.03643 ]
[.85293 .22792 6 2.96357 ]
[.92079 .33185 0 -5.93942 ]
[.92079 .33185 6 3.06058 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02494 .25992 -6 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -6 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -6 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.16157 .20642 m
.16617 .2111 L
s
[(0.5)] .15237 .19707 .98294 1 Mshowa
.32604 .14202 m
.33035 .14696 L
s
[(1)] .31741 .13214 .87321 1 Mshowa
.50139 .07336 m
.50537 .07857 L
s
[(1.5)] .49342 .06293 .76347 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(2)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.19364 .19386 m
.19637 .1967 L
s
.22611 .18115 m
.22881 .18402 L
s
.259 .16827 m
.26166 .17117 L
s
.29231 .15523 m
.29493 .15816 L
s
.3602 .12864 m
.36275 .13164 L
s
.39481 .11509 m
.39732 .11812 L
s
.42987 .10136 m
.43235 .10443 L
s
.4654 .08745 m
.46783 .09055 L
s
.53786 .05908 m
.5402 .06224 L
s
.57482 .04461 m
.57712 .0478 L
s
.61228 .02994 m
.61453 .03317 L
s
.65025 .01507 m
.65245 .01833 L
s
.12989 .21883 m
.13268 .2216 L
s
.0986 .23108 m
.10142 .23383 L
s
.06769 .24318 m
.07054 .2459 L
s
.03716 .25514 m
.04004 .25782 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.76482 .11638 m
.75866 .11864 L
s
[(1)] .77714 .11187 -1 .3661 Mshowa
.84051 .23216 m
.8343 .23428 L
s
[(2)] .85293 .22792 -1 .34143 Mshowa
.90829 .33584 m
.90204 .33784 L
s
[(3)] .92079 .33185 -1 .31987 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(4)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.78066 .14061 m
.77695 .14194 L
s
.79613 .16428 m
.79242 .1656 L
s
.81126 .18741 m
.80754 .18872 L
s
.82605 .21004 m
.82233 .21132 L
s
.85466 .2538 m
.85093 .25506 L
s
.8685 .27497 m
.86476 .27622 L
s
.88205 .2957 m
.87831 .29692 L
s
.89531 .31598 m
.89156 .3172 L
s
.92101 .3553 m
.91725 .35648 L
s
.93346 .37435 m
.92971 .37552 L
s
.94567 .39302 m
.94191 .39417 L
s
.95763 .41131 m
.95386 .41246 L
s
.74861 .09159 m
.74492 .09296 L
s
.73201 .0662 m
.72833 .06759 L
s
.71502 .0402 m
.71134 .04161 L
s
.6976 .01356 m
.69393 .01499 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(0)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(1)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(2)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(3)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(4)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.664 .741 .907 r
.39254 .58705 .40529 .59895 .42665 .59252 .41401 .58053 Metetra
.664 .741 .907 r
.41401 .58053 .42665 .59252 .44817 .58605 .43564 .57395 Metetra
.664 .741 .907 r
.43564 .57395 .44817 .58605 .46987 .57952 .45745 .56733 Metetra
.664 .741 .907 r
.45745 .56733 .46987 .57952 .49174 .57294 .47944 .56065 Metetra
.664 .741 .907 r
.47944 .56065 .49174 .57294 .5138 .5663 .50161 .55391 Metetra
.664 .741 .907 r
.50161 .55391 .5138 .5663 .53602 .55962 .52395 .54713 Metetra
.664 .741 .907 r
.52395 .54713 .53602 .55962 .55843 .55288 .54648 .54028 Metetra
.664 .741 .907 r
.54648 .54028 .55843 .55288 .58103 .54608 .5692 .53339 Metetra
.664 .741 .907 r
.5692 .53339 .58103 .54608 .6038 .53923 .5921 .52643 Metetra
.664 .741 .907 r
.5921 .52643 .6038 .53923 .62677 .53232 .61519 .51942 Metetra
.664 .741 .907 r
.61519 .51942 .62677 .53232 .64992 .52536 .63848 .51236 Metetra
.664 .741 .908 r
.63848 .51236 .64992 .52536 .67327 .51835 .66196 .50524 Metetra
.664 .741 .908 r
.66196 .50524 .67327 .51835 .69681 .51127 .68564 .49806 Metetra
.664 .741 .908 r
.68564 .49806 .69681 .51127 .72055 .50415 .70951 .49083 Metetra
.663 .741 .908 r
.70951 .49083 .72055 .50415 .74449 .49697 .7336 .48355 Metetra
.663 .741 .908 r
.7336 .48355 .74449 .49697 .76864 .48973 .75788 .47621 Metetra
.663 .741 .908 r
.75788 .47621 .76864 .48973 .79299 .48245 .78238 .46883 Metetra
.663 .742 .909 r
.78238 .46883 .79299 .48245 .81755 .47511 .80709 .4614 Metetra
.662 .742 .909 r
.80709 .4614 .81755 .47511 .84232 .46772 .83201 .45393 Metetra
.662 .742 .91 r
.83201 .45393 .84232 .46772 .8673 .46029 .85716 .44642 Metetra
.661 .742 .91 r
.85716 .44642 .8673 .46029 .89251 .45282 .88253 .43887 Metetra
.661 .743 .911 r
.88253 .43887 .89251 .45282 .91793 .44531 .90813 .43129 Metetra
.66 .744 .912 r
.90813 .43129 .91793 .44531 .94359 .43777 .93396 .4237 Metetra
.659 .744 .913 r
.93396 .4237 .94359 .43777 .96948 .4302 .96003 .41608 Metetra
.664 .741 .907 r
.37961 .57497 .39254 .58705 .41401 .58053 .40118 .56835 Metetra
.664 .741 .907 r
.40118 .56835 .41401 .58053 .43564 .57395 .42293 .56168 Metetra
.664 .741 .907 r
.42293 .56168 .43564 .57395 .45745 .56733 .44485 .55495 Metetra
.664 .741 .907 r
.44485 .55495 .45745 .56733 .47944 .56065 .46695 .54817 Metetra
.664 .741 .907 r
.46695 .54817 .47944 .56065 .50161 .55391 .48923 .54134 Metetra
.664 .741 .907 r
.48923 .54134 .50161 .55391 .52395 .54713 .5117 .53445 Metetra
.664 .741 .907 r
.5117 .53445 .52395 .54713 .54648 .54028 .53435 .5275 Metetra
.664 .741 .907 r
.53435 .5275 .54648 .54028 .5692 .53339 .55719 .5205 Metetra
.664 .741 .907 r
.55719 .5205 .5692 .53339 .5921 .52643 .58021 .51344 Metetra
.664 .741 .907 r
.58021 .51344 .5921 .52643 .61519 .51942 .60344 .50633 Metetra
.664 .741 .908 r
.60344 .50633 .61519 .51942 .63848 .51236 .62685 .49916 Metetra
.664 .741 .908 r
.62685 .49916 .63848 .51236 .66196 .50524 .65047 .49193 Metetra
.663 .741 .908 r
.65047 .49193 .66196 .50524 .68564 .49806 .67428 .48465 Metetra
.663 .741 .908 r
.67428 .48465 .68564 .49806 .70951 .49083 .6983 .47732 Metetra
.663 .741 .908 r
.6983 .47732 .70951 .49083 .7336 .48355 .72252 .46994 Metetra
.663 .741 .908 r
.72252 .46994 .7336 .48355 .75788 .47621 .74696 .46251 Metetra
.663 .742 .909 r
.74696 .46251 .75788 .47621 .78238 .46883 .77161 .45504 Metetra
.662 .742 .909 r
.77161 .45504 .78238 .46883 .80709 .4614 .79647 .44752 Metetra
.662 .742 .91 r
.79647 .44752 .80709 .4614 .83201 .45393 .82155 .43997 Metetra
.661 .743 .911 r
.82155 .43997 .83201 .45393 .85716 .44642 .84686 .43239 Metetra
.66 .743 .911 r
.84686 .43239 .85716 .44642 .88253 .43887 .8724 .42479 Metetra
.66 .744 .912 r
.8724 .42479 .88253 .43887 .90813 .43129 .89817 .41717 Metetra
.659 .745 .914 r
.89817 .41717 .90813 .43129 .93396 .4237 .92418 .40954 Metetra
.657 .746 .915 r
.92418 .40954 .93396 .4237 .96003 .41608 .95044 .4019 Metetra
.664 .741 .907 r
.36648 .56271 .37961 .57497 .40118 .56835 .38816 .55599 Metetra
.664 .741 .907 r
.38816 .55599 .40118 .56835 .42293 .56168 .41002 .54922 Metetra
.664 .741 .907 r
.41002 .54922 .42293 .56168 .44485 .55495 .43205 .54239 Metetra
.664 .741 .907 r
.43205 .54239 .44485 .55495 .46695 .54817 .45427 .53551 Metetra
.664 .741 .907 r
.45427 .53551 .46695 .54817 .48923 .54134 .47667 .52857 Metetra
.664 .741 .907 r
.47667 .52857 .48923 .54134 .5117 .53445 .49925 .52158 Metetra
.664 .741 .907 r
.49925 .52158 .5117 .53445 .53435 .5275 .52203 .51453 Metetra
.664 .741 .907 r
.52203 .51453 .53435 .5275 .55719 .5205 .54499 .50742 Metetra
.664 .741 .907 r
.54499 .50742 .55719 .5205 .58021 .51344 .56815 .50026 Metetra
.664 .741 .908 r
.56815 .50026 .58021 .51344 .60344 .50633 .5915 .49304 Metetra
.664 .741 .908 r
.5915 .49304 .60344 .50633 .62685 .49916 .61505 .48576 Metetra
.663 .741 .908 r
.61505 .48576 .62685 .49916 .65047 .49193 .6388 .47843 Metetra
.663 .741 .908 r
.6388 .47843 .65047 .49193 .67428 .48465 .66275 .47105 Metetra
.663 .741 .908 r
.66275 .47105 .67428 .48465 .6983 .47732 .68691 .46362 Metetra
.663 .741 .909 r
.68691 .46362 .6983 .47732 .72252 .46994 .71128 .45615 Metetra
.662 .742 .909 r
.71128 .45615 .72252 .46994 .74696 .46251 .73586 .44863 Metetra
.662 .742 .91 r
.73586 .44863 .74696 .46251 .77161 .45504 .76066 .44107 Metetra
.661 .742 .91 r
.76066 .44107 .77161 .45504 .79647 .44752 .78568 .43349 Metetra
.661 .743 .911 r
.78568 .43349 .79647 .44752 .82155 .43997 .81093 .42588 Metetra
.66 .744 .912 r
.81093 .42588 .82155 .43997 .84686 .43239 .83641 .41825 Metetra
.659 .744 .913 r
.83641 .41825 .84686 .43239 .8724 .42479 .86212 .41061 Metetra
.658 .745 .915 r
.86212 .41061 .8724 .42479 .89817 .41717 .88807 .40297 Metetra
.656 .747 .916 r
.88807 .40297 .89817 .41717 .92418 .40954 .91427 .39533 Metetra
.655 .748 .918 r
.91427 .39533 .92418 .40954 .95044 .4019 .94072 .38772 Metetra
.664 .741 .907 r
.35316 .55026 .36648 .56271 .38816 .55599 .37495 .54345 Metetra
.664 .741 .907 r
.37495 .54345 .38816 .55599 .41002 .54922 .39692 .53657 Metetra
.664 .741 .907 r
.39692 .53657 .41002 .54922 .43205 .54239 .41906 .52964 Metetra
.664 .741 .907 r
.41906 .52964 .43205 .54239 .45427 .53551 .4414 .52265 Metetra
.664 .741 .907 r
.4414 .52265 .45427 .53551 .47667 .52857 .46391 .51561 Metetra
.664 .741 .907 r
.46391 .51561 .47667 .52857 .49925 .52158 .48662 .50851 Metetra
.664 .741 .907 r
.48662 .50851 .49925 .52158 .52203 .51453 .50952 .50135 Metetra
.664 .741 .907 r
.50952 .50135 .52203 .51453 .54499 .50742 .5326 .49414 Metetra
.664 .741 .908 r
.5326 .49414 .54499 .50742 .56815 .50026 .55589 .48687 Metetra
.664 .741 .908 r
.55589 .48687 .56815 .50026 .5915 .49304 .57937 .47954 Metetra
.663 .741 .908 r
.57937 .47954 .5915 .49304 .61505 .48576 .60306 .47217 Metetra
.663 .741 .908 r
.60306 .47217 .61505 .48576 .6388 .47843 .62694 .46474 Metetra
.663 .741 .908 r
.62694 .46474 .6388 .47843 .66275 .47105 .65104 .45726 Metetra
.663 .742 .909 r
.65104 .45726 .66275 .47105 .68691 .46362 .67534 .44974 Metetra
.662 .742 .909 r
.67534 .44974 .68691 .46362 .71128 .45615 .69986 .44218 Metetra
.662 .742 .91 r
.69986 .44218 .71128 .45615 .73586 .44863 .72459 .43459 Metetra
.661 .743 .911 r
.72459 .43459 .73586 .44863 .76066 .44107 .74955 .42697 Metetra
.66 .743 .912 r
.74955 .42697 .76066 .44107 .78568 .43349 .77473 .41933 Metetra
.659 .744 .913 r
.77473 .41933 .78568 .43349 .81093 .42588 .80014 .41168 Metetra
.658 .745 .914 r
.80014 .41168 .81093 .42588 .83641 .41825 .82579 .40403 Metetra
.657 .746 .916 r
.82579 .40403 .83641 .41825 .86212 .41061 .85168 .39638 Metetra
.655 .747 .918 r
.85168 .39638 .86212 .41061 .88807 .40297 .87782 .38876 Metetra
.654 .749 .92 r
.87782 .38876 .88807 .40297 .91427 .39533 .90422 .38116 Metetra
.652 .751 .922 r
.90422 .38116 .91427 .39533 .94072 .38772 .93088 .3736 Metetra
.664 .741 .907 r
.33963 .53763 .35316 .55026 .37495 .54345 .36153 .53071 Metetra
.664 .741 .907 r
.36153 .53071 .37495 .54345 .39692 .53657 .38361 .52373 Metetra
.664 .741 .907 r
.38361 .52373 .39692 .53657 .41906 .52964 .40588 .5167 Metetra
.664 .741 .907 r
.40588 .5167 .41906 .52964 .4414 .52265 .42832 .5096 Metetra
.664 .741 .907 r
.42832 .5096 .4414 .52265 .46391 .51561 .45096 .50245 Metetra
.664 .741 .907 r
.45096 .50245 .46391 .51561 .48662 .50851 .47379 .49524 Metetra
.664 .741 .907 r
.47379 .49524 .48662 .50851 .50952 .50135 .49681 .48798 Metetra
.664 .741 .908 r
.49681 .48798 .50952 .50135 .5326 .49414 .52003 .48066 Metetra
.663 .741 .908 r
.52003 .48066 .5326 .49414 .55589 .48687 .54344 .47328 Metetra
.663 .741 .908 r
.54344 .47328 .55589 .48687 .57937 .47954 .56705 .46585 Metetra
.663 .741 .908 r
.56705 .46585 .57937 .47954 .60306 .47217 .59087 .45838 Metetra
.663 .741 .908 r
.59087 .45838 .60306 .47217 .62694 .46474 .6149 .45085 Metetra
.662 .742 .909 r
.6149 .45085 .62694 .46474 .65104 .45726 .63913 .44329 Metetra
.662 .742 .909 r
.63913 .44329 .65104 .45726 .67534 .44974 .66358 .43569 Metetra
.661 .742 .91 r
.66358 .43569 .67534 .44974 .69986 .44218 .68825 .42806 Metetra
.661 .743 .911 r
.68825 .42806 .69986 .44218 .72459 .43459 .71314 .42041 Metetra
.66 .744 .912 r
.71314 .42041 .72459 .43459 .74955 .42697 .73826 .41274 Metetra
.658 .744 .913 r
.73826 .41274 .74955 .42697 .77473 .41933 .76361 .40508 Metetra
.657 .746 .915 r
.76361 .40508 .77473 .41933 .80014 .41168 .78919 .39742 Metetra
.656 .747 .917 r
.78919 .39742 .80014 .41168 .82579 .40403 .81502 .38979 Metetra
.654 .748 .919 r
.81502 .38979 .82579 .40403 .85168 .39638 .8411 .38218 Metetra
.652 .75 .922 r
.8411 .38218 .85168 .39638 .87782 .38876 .86744 .37462 Metetra
.65 .752 .925 r
.86744 .37462 .87782 .38876 .90422 .38116 .89404 .3671 Metetra
.647 .755 .928 r
.89404 .3671 .90422 .38116 .93088 .3736 .92091 .35964 Metetra
.664 .741 .907 r
.3259 .52481 .33963 .53763 .36153 .53071 .34791 .51778 Metetra
.664 .741 .907 r
.34791 .51778 .36153 .53071 .38361 .52373 .3701 .51069 Metetra
.664 .741 .907 r
.3701 .51069 .38361 .52373 .40588 .5167 .39248 .50355 Metetra
.664 .741 .907 r
.39248 .50355 .40588 .5167 .42832 .5096 .41505 .49635 Metetra
.664 .741 .907 r
.41505 .49635 .42832 .5096 .45096 .50245 .43781 .48909 Metetra
.664 .741 .907 r
.43781 .48909 .45096 .50245 .47379 .49524 .46076 .48177 Metetra
.664 .741 .908 r
.46076 .48177 .47379 .49524 .49681 .48798 .4839 .4744 Metetra
.663 .741 .908 r
.4839 .4744 .49681 .48798 .52003 .48066 .50725 .46697 Metetra
.663 .741 .908 r
.50725 .46697 .52003 .48066 .54344 .47328 .53079 .4595 Metetra
.663 .741 .908 r
.53079 .4595 .54344 .47328 .56705 .46585 .55454 .45197 Metetra
.663 .741 .909 r
.55454 .45197 .56705 .46585 .59087 .45838 .5785 .4444 Metetra
.662 .742 .909 r
.5785 .4444 .59087 .45838 .6149 .45085 .60266 .43679 Metetra
.662 .742 .91 r
.60266 .43679 .6149 .45085 .63913 .44329 .62704 .42915 Metetra
.661 .743 .911 r
.62704 .42915 .63913 .44329 .66358 .43569 .65164 .42149 Metetra
.66 .743 .912 r
.65164 .42149 .66358 .43569 .68825 .42806 .67646 .41381 Metetra
.659 .744 .913 r
.67646 .41381 .68825 .42806 .71314 .42041 .70151 .40613 Metetra
.658 .745 .914 r
.70151 .40613 .71314 .42041 .73826 .41274 .72679 .39846 Metetra
.656 .746 .916 r
.72679 .39846 .73826 .41274 .76361 .40508 .75231 .39081 Metetra
.654 .748 .918 r
.75231 .39081 .76361 .40508 .78919 .39742 .77807 .38319 Metetra
.652 .75 .921 r
.77807 .38319 .78919 .39742 .81502 .38979 .80409 .37562 Metetra
.65 .752 .924 r
.80409 .37562 .81502 .38979 .8411 .38218 .83036 .3681 Metetra
.647 .754 .927 r
.83036 .3681 .8411 .38218 .86744 .37462 .85691 .36064 Metetra
.645 .757 .931 r
.85691 .36064 .86744 .37462 .89404 .3671 .88373 .35326 Metetra
.642 .76 .934 r
.88373 .35326 .89404 .3671 .92091 .35964 .91083 .34594 Metetra
.664 .741 .907 r
.31196 .51179 .3259 .52481 .34791 .51778 .33408 .50465 Metetra
.664 .741 .907 r
.33408 .50465 .34791 .51778 .3701 .51069 .35639 .49745 Metetra
.664 .741 .907 r
.35639 .49745 .3701 .51069 .39248 .50355 .37888 .4902 Metetra
.664 .741 .907 r
.37888 .4902 .39248 .50355 .41505 .49635 .40157 .48289 Metetra
.664 .741 .907 r
.40157 .48289 .41505 .49635 .43781 .48909 .42445 .47552 Metetra
.664 .741 .908 r
.42445 .47552 .43781 .48909 .46076 .48177 .44752 .4681 Metetra
.663 .741 .908 r
.44752 .4681 .46076 .48177 .4839 .4744 .47079 .46062 Metetra
.663 .741 .908 r
.47079 .46062 .4839 .4744 .50725 .46697 .49427 .45309 Metetra
.663 .741 .908 r
.49427 .45309 .50725 .46697 .53079 .4595 .51794 .44552 Metetra
.662 .741 .909 r
.51794 .44552 .53079 .4595 .55454 .45197 .54183 .4379 Metetra
.662 .742 .909 r
.54183 .4379 .55454 .45197 .5785 .4444 .56592 .43025 Metetra
.661 .742 .91 r
.56592 .43025 .5785 .4444 .60266 .43679 .59023 .42257 Metetra
.66 .743 .911 r
.59023 .42257 .60266 .43679 .62704 .42915 .61476 .41488 Metetra
.659 .743 .912 r
.61476 .41488 .62704 .42915 .65164 .42149 .63951 .40718 Metetra
.658 .744 .914 r
.63951 .40718 .65164 .42149 .67646 .41381 .66448 .39949 Metetra
.657 .746 .915 r
.66448 .39949 .67646 .41381 .70151 .40613 .68969 .39182 Metetra
.655 .747 .918 r
.68969 .39182 .70151 .40613 .72679 .39846 .71514 .38418 Metetra
.653 .749 .92 r
.71514 .38418 .72679 .39846 .75231 .39081 .74084 .3766 Metetra
.65 .751 .923 r
.74084 .3766 .75231 .39081 .77807 .38319 .76679 .36907 Metetra
.648 .753 .926 r
.76679 .36907 .77807 .38319 .80409 .37562 .793 .36162 Metetra
.645 .756 .93 r
.793 .36162 .80409 .37562 .83036 .3681 .81948 .35424 Metetra
.641 .759 .934 r
.81948 .35424 .83036 .3681 .85691 .36064 .84624 .34695 Metetra
.638 .763 .938 r
.84624 .34695 .85691 .36064 .88373 .35326 .87329 .33974 Metetra
.634 .766 .943 r
.87329 .33974 .88373 .35326 .91083 .34594 .90063 .33261 Metetra
.664 .741 .907 r
.2978 .49856 .31196 .51179 .33408 .50465 .32003 .49132 Metetra
.664 .741 .907 r
.32003 .49132 .33408 .50465 .35639 .49745 .34245 .48401 Metetra
.664 .741 .907 r
.34245 .48401 .35639 .49745 .37888 .4902 .36507 .47665 Metetra
.664 .741 .907 r
.36507 .47665 .37888 .4902 .40157 .48289 .38787 .46923 Metetra
.664 .741 .908 r
.38787 .46923 .40157 .48289 .42445 .47552 .41087 .46175 Metetra
.663 .741 .908 r
.41087 .46175 .42445 .47552 .44752 .4681 .43407 .45422 Metetra
.663 .741 .908 r
.43407 .45422 .44752 .4681 .47079 .46062 .45747 .44664 Metetra
.663 .741 .908 r
.45747 .44664 .47079 .46062 .49427 .45309 .48107 .43902 Metetra
.662 .742 .909 r
.48107 .43902 .49427 .45309 .51794 .44552 .50488 .43136 Metetra
.662 .742 .91 r
.50488 .43136 .51794 .44552 .54183 .4379 .52891 .42366 Metetra
.661 .742 .91 r
.52891 .42366 .54183 .4379 .56592 .43025 .55314 .41595 Metetra
.66 .743 .911 r
.55314 .41595 .56592 .43025 .59023 .42257 .57759 .40823 Metetra
.659 .744 .913 r
.57759 .40823 .59023 .42257 .61476 .41488 .60227 .40052 Metetra
.657 .745 .915 r
.60227 .40052 .61476 .41488 .63951 .40718 .62717 .39282 Metetra
.655 .746 .917 r
.62717 .39282 .63951 .40718 .66448 .39949 .65231 .38517 Metetra
.653 .748 .919 r
.65231 .38517 .66448 .39949 .68969 .39182 .67769 .37756 Metetra
.651 .75 .922 r
.67769 .37756 .68969 .39182 .71514 .38418 .70332 .37002 Metetra
.648 .753 .926 r
.70332 .37002 .71514 .38418 .74084 .3766 .7292 .36256 Metetra
.645 .755 .93 r
.7292 .36256 .74084 .3766 .76679 .36907 .75534 .35519 Metetra
.641 .759 .934 r
.75534 .35519 .76679 .36907 .793 .36162 .78176 .34792 Metetra
.637 .762 .938 r
.78176 .34792 .793 .36162 .81948 .35424 .80846 .34075 Metetra
.633 .766 .943 r
.80846 .34075 .81948 .35424 .84624 .34695 .83545 .33368 Metetra
.629 .77 .948 r
.83545 .33368 .84624 .34695 .87329 .33974 .86274 .32668 Metetra
.626 .775 .952 r
.86274 .32668 .87329 .33974 .90063 .33261 .89032 .31973 Metetra
.664 .741 .907 r
.28342 .48513 .2978 .49856 .32003 .49132 .30576 .47777 Metetra
.664 .741 .907 r
.30576 .47777 .32003 .49132 .34245 .48401 .3283 .47036 Metetra
.664 .741 .907 r
.3283 .47036 .34245 .48401 .36507 .47665 .35103 .46288 Metetra
.663 .741 .908 r
.35103 .46288 .36507 .47665 .38787 .46923 .37396 .45535 Metetra
.663 .741 .908 r
.37396 .45535 .38787 .46923 .41087 .46175 .39708 .44777 Metetra
.663 .741 .908 r
.39708 .44777 .41087 .46175 .43407 .45422 .42041 .44014 Metetra
.663 .741 .908 r
.42041 .44014 .43407 .45422 .45747 .44664 .44393 .43247 Metetra
.662 .742 .909 r
.44393 .43247 .45747 .44664 .48107 .43902 .46767 .42476 Metetra
.661 .742 .91 r
.46767 .42476 .48107 .43902 .50488 .43136 .49161 .41703 Metetra
.66 .742 .911 r
.49161 .41703 .50488 .43136 .52891 .42366 .51577 .40929 Metetra
.659 .743 .912 r
.51577 .40929 .52891 .42366 .55314 .41595 .54015 .40155 Metetra
.658 .744 .914 r
.54015 .40155 .55314 .41595 .57759 .40823 .56475 .39382 Metetra
.656 .745 .916 r
.56475 .39382 .57759 .40823 .60227 .40052 .58958 .38614 Metetra
.654 .747 .918 r
.58958 .38614 .60227 .40052 .62717 .39282 .61464 .3785 Metetra
.651 .749 .921 r
.61464 .3785 .62717 .39282 .65231 .38517 .63994 .37094 Metetra
.648 .752 .925 r
.63994 .37094 .65231 .38517 .67769 .37756 .6655 .36347 Metetra
.645 .754 .929 r
.6655 .36347 .67769 .37756 .70332 .37002 .69131 .3561 Metetra
.641 .758 .933 r
.69131 .3561 .70332 .37002 .7292 .36256 .71738 .34885 Metetra
.637 .762 .938 r
.71738 .34885 .7292 .36256 .75534 .35519 .74374 .34171 Metetra
.633 .766 .943 r
.74374 .34171 .75534 .35519 .78176 .34792 .77037 .33469 Metetra
.628 .77 .948 r
.77037 .33469 .78176 .34792 .80846 .34075 .7973 .32777 Metetra
.624 .775 .953 r
.7973 .32777 .80846 .34075 .83545 .33368 .82453 .32093 Metetra
.619 .78 .958 r
.82453 .32093 .83545 .33368 .86274 .32668 .85206 .31413 Metetra
.616 .784 .962 r
.85206 .31413 .86274 .32668 .89032 .31973 .87989 .30734 Metetra
.664 .741 .907 r
.26881 .47149 .28342 .48513 .30576 .47777 .29127 .46402 Metetra
.664 .741 .907 r
.29127 .46402 .30576 .47777 .3283 .47036 .31392 .45649 Metetra
.663 .741 .908 r
.31392 .45649 .3283 .47036 .35103 .46288 .33677 .44891 Metetra
.663 .741 .908 r
.33677 .44891 .35103 .46288 .37396 .45535 .35982 .44127 Metetra
.663 .741 .908 r
.35982 .44127 .37396 .45535 .39708 .44777 .38307 .43359 Metetra
.662 .741 .909 r
.38307 .43359 .39708 .44777 .42041 .44014 .40652 .42587 Metetra
.662 .742 .909 r
.40652 .42587 .42041 .44014 .44393 .43247 .43017 .41812 Metetra
.661 .742 .91 r
.43017 .41812 .44393 .43247 .46767 .42476 .45404 .41035 Metetra
.66 .743 .911 r
.45404 .41035 .46767 .42476 .49161 .41703 .47812 .40258 Metetra
.659 .743 .913 r
.47812 .40258 .49161 .41703 .51577 .40929 .50242 .39482 Metetra
.657 .745 .915 r
.50242 .39482 .51577 .40929 .54015 .40155 .52694 .3871 Metetra
.655 .746 .917 r
.52694 .3871 .54015 .40155 .56475 .39382 .55169 .37943 Metetra
.652 .748 .92 r
.55169 .37943 .56475 .39382 .58958 .38614 .57667 .37184 Metetra
.649 .75 .924 r
.57667 .37184 .58958 .38614 .61464 .3785 .6019 .36435 Metetra
.645 .753 .928 r
.6019 .36435 .61464 .3785 .63994 .37094 .62737 .35697 Metetra
.641 .757 .932 r
.62737 .35697 .63994 .37094 .6655 .36347 .65311 .34972 Metetra
.637 .761 .937 r
.65311 .34972 .6655 .36347 .69131 .3561 .67911 .34261 Metetra
.632 .765 .943 r
.67911 .34261 .69131 .3561 .71738 .34885 .7054 .33563 Metetra
.627 .77 .949 r
.7054 .33563 .71738 .34885 .74374 .34171 .73196 .32879 Metetra
.621 .775 .954 r
.73196 .32879 .74374 .34171 .77037 .33469 .75883 .32206 Metetra
.616 .78 .96 r
.75883 .32206 .77037 .33469 .7973 .32777 .78599 .3154 Metetra
.612 .785 .964 r
.78599 .3154 .7973 .32777 .82453 .32093 .81346 .30877 Metetra
.609 .79 .968 r
.81346 .30877 .82453 .32093 .85206 .31413 .84124 .30211 Metetra
.608 .794 .97 r
.84124 .30211 .85206 .31413 .87989 .30734 .86933 .29535 Metetra
.664 .741 .907 r
.25397 .45764 .26881 .47149 .29127 .46402 .27655 .45005 Metetra
.663 .741 .908 r
.27655 .45005 .29127 .46402 .31392 .45649 .29932 .44241 Metetra
.663 .741 .908 r
.29932 .44241 .31392 .45649 .33677 .44891 .32228 .43472 Metetra
.663 .741 .908 r
.32228 .43472 .33677 .44891 .35982 .44127 .34545 .42699 Metetra
.662 .741 .909 r
.34545 .42699 .35982 .44127 .38307 .43359 .36882 .41922 Metetra
.662 .742 .909 r
.36882 .41922 .38307 .43359 .40652 .42587 .3924 .41142 Metetra
.661 .742 .91 r
.3924 .41142 .40652 .42587 .43017 .41812 .41619 .40362 Metetra
.659 .743 .912 r
.41619 .40362 .43017 .41812 .45404 .41035 .44018 .39583 Metetra
.658 .744 .913 r
.44018 .39583 .45404 .41035 .47812 .40258 .4644 .38806 Metetra
.656 .745 .916 r
.4644 .38806 .47812 .40258 .50242 .39482 .48884 .38035 Metetra
.653 .747 .919 r
.48884 .38035 .50242 .39482 .52694 .3871 .5135 .37272 Metetra
.65 .749 .922 r
.5135 .37272 .52694 .3871 .55169 .37943 .5384 .36519 Metetra
.646 .752 .926 r
.5384 .36519 .55169 .37943 .57667 .37184 .56355 .35778 Metetra
.642 .755 .931 r
.56355 .35778 .57667 .37184 .6019 .36435 .58894 .35053 Metetra
.637 .759 .937 r
.58894 .35053 .6019 .36435 .62737 .35697 .6146 .34343 Metetra
.631 .764 .943 r
.6146 .34343 .62737 .35697 .65311 .34972 .64052 .33651 Metetra
.625 .769 .949 r
.64052 .33651 .65311 .34972 .67911 .34261 .66673 .32974 Metetra
.619 .775 .955 r
.66673 .32974 .67911 .34261 .7054 .33563 .69323 .32312 Metetra
.613 .781 .961 r
.69323 .32312 .7054 .33563 .73196 .32879 .72002 .31661 Metetra
.608 .786 .967 r
.72002 .31661 .73196 .32879 .75883 .32206 .74712 .31015 Metetra
.604 .792 .971 r
.74712 .31015 .75883 .32206 .78599 .3154 .77453 .30369 Metetra
.601 .797 .974 r
.77453 .30369 .78599 .3154 .81346 .30877 .80224 .29715 Metetra
.602 .801 .976 r
.80224 .29715 .81346 .30877 .84124 .30211 .83026 .29043 Metetra
.605 .804 .976 r
.83026 .29043 .84124 .30211 .86933 .29535 .85857 .28346 Metetra
.663 .741 .908 r
.23889 .44356 .25397 .45764 .27655 .45005 .26158 .43586 Metetra
.663 .741 .908 r
.26158 .43586 .27655 .45005 .29932 .44241 .28447 .42812 Metetra
.663 .741 .908 r
.28447 .42812 .29932 .44241 .32228 .43472 .30756 .42033 Metetra
.662 .741 .909 r
.30756 .42033 .32228 .43472 .34545 .42699 .33085 .41251 Metetra
.661 .742 .91 r
.33085 .41251 .34545 .42699 .36882 .41922 .35434 .40467 Metetra
.66 .742 .911 r
.35434 .40467 .36882 .41922 .3924 .41142 .37804 .39684 Metetra
.659 .743 .912 r
.37804 .39684 .3924 .41142 .41619 .40362 .40196 .38902 Metetra
.657 .744 .914 r
.40196 .38902 .41619 .40362 .44018 .39583 .42609 .38126 Metetra
.654 .746 .917 r
.42609 .38126 .44018 .39583 .4644 .38806 .45044 .37357 Metetra
.651 .748 .92 r
.45044 .37357 .4644 .38806 .48884 .38035 .47502 .366 Metetra
.647 .75 .925 r
.47502 .366 .48884 .38035 .5135 .37272 .49983 .35855 Metetra
.643 .754 .93 r
.49983 .35855 .5135 .37272 .5384 .36519 .52489 .35128 Metetra
.637 .758 .935 r
.52489 .35128 .5384 .36519 .56355 .35778 .55019 .34419 Metetra
.631 .763 .942 r
.55019 .34419 .56355 .35778 .58894 .35053 .57576 .33729 Metetra
.624 .768 .949 r
.57576 .33729 .58894 .35053 .6146 .34343 .60161 .3306 Metetra
.617 .774 .956 r
.60161 .3306 .6146 .34343 .64052 .33651 .62774 .32409 Metetra
.61 .781 .963 r
.62774 .32409 .64052 .33651 .66673 .32974 .65416 .31773 Metetra
.603 .787 .969 r
.65416 .31773 .66673 .32974 .69323 .32312 .68088 .31146 Metetra
.597 .793 .974 r
.68088 .31146 .69323 .32312 .72002 .31661 .7079 .30523 Metetra
.594 .799 .978 r
.7079 .30523 .72002 .31661 .74712 .31015 .73524 .29894 Metetra
.593 .804 .98 r
.73524 .29894 .74712 .31015 .77453 .30369 .76288 .29249 Metetra
.596 .808 .981 r
.76288 .29249 .77453 .30369 .80224 .29715 .79083 .28577 Metetra
.603 .81 .979 r
.79083 .28577 .80224 .29715 .83026 .29043 .81906 .27867 Metetra
.614 .81 .976 r
.81906 .27867 .83026 .29043 .85857 .28346 .84757 .27109 Metetra
.663 .741 .908 r
.22357 .42926 .23889 .44356 .26158 .43586 .24638 .42146 Metetra
.663 .741 .908 r
.24638 .42146 .26158 .43586 .28447 .42812 .26938 .41361 Metetra
.662 .741 .909 r
.26938 .41361 .28447 .42812 .30756 .42033 .29259 .40574 Metetra
.661 .742 .91 r
.29259 .40574 .30756 .42033 .33085 .41251 .316 .39786 Metetra
.66 .742 .911 r
.316 .39786 .33085 .41251 .35434 .40467 .33961 .39 Metetra
.658 .743 .913 r
.33961 .39 .35434 .40467 .37804 .39684 .36344 .38217 Metetra
.655 .744 .915 r
.36344 .38217 .37804 .39684 .40196 .38902 .38748 .37442 Metetra
.652 .746 .919 r
.38748 .37442 .40196 .38902 .42609 .38126 .41174 .36678 Metetra
.648 .749 .923 r
.41174 .36678 .42609 .38126 .45044 .37357 .43623 .35928 Metetra
.644 .752 .928 r
.43623 .35928 .45044 .37357 .47502 .366 .46095 .35196 Metetra
.638 .756 .934 r
.46095 .35196 .47502 .366 .49983 .35855 .48591 .34485 Metetra
.631 .761 .941 r
.48591 .34485 .49983 .35855 .52489 .35128 .51112 .33797 Metetra
.623 .767 .948 r
.51112 .33797 .52489 .35128 .55019 .34419 .5366 .33134 Metetra
.615 .773 .956 r
.5366 .33134 .55019 .34419 .57576 .33729 .56235 .32494 Metetra
.606 .78 .964 r
.56235 .32494 .57576 .33729 .60161 .3306 .58839 .31874 Metetra
.597 .787 .971 r
.58839 .31874 .60161 .3306 .62774 .32409 .61473 .31269 Metetra
.589 .794 .978 r
.61473 .31269 .62774 .32409 .65416 .31773 .64137 .30671 Metetra
.584 .801 .982 r
.64137 .30671 .65416 .31773 .68088 .31146 .66832 .30071 Metetra
.582 .807 .985 r
.66832 .30071 .68088 .31146 .7079 .30523 .69558 .29457 Metetra
.585 .812 .986 r
.69558 .29457 .7079 .30523 .73524 .29894 .72315 .28815 Metetra
.592 .815 .985 r
.72315 .28815 .73524 .29894 .76288 .29249 .75101 .28134 Metetra
.604 .816 .981 r
.75101 .28134 .76288 .29249 .79083 .28577 .77915 .274 Metetra
.62 .814 .975 r
.77915 .274 .79083 .28577 .81906 .27867 .80756 .26602 Metetra
.636 .809 .966 r
.80756 .26602 .81906 .27867 .84757 .27109 .83621 .25732 Metetra
.663 .741 .908 r
.208 .41474 .22357 .42926 .24638 .42146 .23092 .40684 Metetra
.662 .741 .909 r
.23092 .40684 .24638 .42146 .26938 .41361 .25404 .39891 Metetra
.661 .741 .91 r
.25404 .39891 .26938 .41361 .29259 .40574 .27736 .39099 Metetra
.659 .742 .911 r
.27736 .39099 .29259 .40574 .316 .39786 .30089 .3831 Metetra
.657 .743 .913 r
.30089 .3831 .316 .39786 .33961 .39 .32463 .37526 Metetra
.654 .745 .916 r
.32463 .37526 .33961 .39 .36344 .38217 .34857 .36754 Metetra
.65 .747 .92 r
.34857 .36754 .36344 .38217 .38748 .37442 .37274 .35996 Metetra
.645 .75 .925 r
.37274 .35996 .38748 .37442 .41174 .36678 .39712 .35257 Metetra
.639 .754 .931 r
.39712 .35257 .41174 .36678 .43623 .35928 .42174 .34542 Metetra
.632 .759 .939 r
.42174 .34542 .43623 .35928 .46095 .35196 .4466 .33854 Metetra
.623 .765 .947 r
.4466 .33854 .46095 .35196 .48591 .34485 .47171 .33195 Metetra
.613 .771 .956 r
.47171 .33195 .48591 .34485 .51112 .33797 .49708 .32564 Metetra
.602 .779 .965 r
.49708 .32564 .51112 .33797 .5366 .33134 .52274 .31961 Metetra
.591 .787 .974 r
.52274 .31961 .5366 .33134 .56235 .32494 .54868 .31379 Metetra
.58 .795 .981 r
.54868 .31379 .56235 .32494 .58839 .31874 .57493 .30811 Metetra
.572 .803 .986 r
.57493 .30811 .58839 .31874 .61473 .31269 .60148 .30245 Metetra
.568 .81 .99 r
.60148 .30245 .61473 .31269 .64137 .30671 .62835 .29667 Metetra
.569 .816 .991 r
.62835 .29667 .64137 .30671 .66832 .30071 .65553 .29062 Metetra
.578 .821 .991 r
.65553 .29062 .66832 .30071 .69558 .29457 .68301 .28415 Metetra
.592 .823 .988 r
.68301 .28415 .69558 .29457 .72315 .28815 .71078 .2771 Metetra
.611 .822 .981 r
.71078 .2771 .72315 .28815 .75101 .28134 .73882 .26933 Metetra
.632 .817 .971 r
.73882 .26933 .75101 .28134 .77915 .274 .76712 .26074 Metetra
.651 .806 .958 r
.76712 .26074 .77915 .274 .80756 .26602 .79564 .25128 Metetra
.668 .792 .941 r
.79564 .25128 .80756 .26602 .83621 .25732 .82438 .24092 Metetra
.662 .741 .909 r
.19217 .4 .208 .41474 .23092 .40684 .21521 .39201 Metetra
.661 .741 .91 r
.21521 .39201 .23092 .40684 .25404 .39891 .23844 .38404 Metetra
.659 .742 .911 r
.23844 .38404 .25404 .39891 .27736 .39099 .26187 .37612 Metetra
.656 .743 .914 r
.26187 .37612 .27736 .39099 .30089 .3831 .28551 .36829 Metetra
.652 .745 .918 r
.28551 .36829 .30089 .3831 .32463 .37526 .30936 .36061 Metetra
.647 .747 .922 r
.30936 .36061 .32463 .37526 .34857 .36754 .33342 .35312 Metetra
.641 .751 .928 r
.33342 .35312 .34857 .36754 .37274 .35996 .3577 .34589 Metetra
.633 .756 .936 r
.3577 .34589 .37274 .35996 .39712 .35257 .3822 .33896 Metetra
.624 .762 .945 r
.3822 .33896 .39712 .35257 .42174 .34542 .40695 .33239 Metetra
.612 .769 .955 r
.40695 .33239 .42174 .34542 .4466 .33854 .43194 .32617 Metetra
.599 .777 .966 r
.43194 .32617 .4466 .33854 .47171 .33195 .4572 .3203 Metetra
.584 .786 .976 r
.4572 .3203 .47171 .33195 .49708 .32564 .48274 .31473 Metetra
.57 .795 .984 r
.48274 .31473 .49708 .32564 .52274 .31961 .50858 .30938 Metetra
.557 .804 .991 r
.50858 .30938 .52274 .31961 .54868 .31379 .53473 .30412 Metetra
.549 .812 .995 r
.53473 .30412 .54868 .31379 .57493 .30811 .56119 .29878 Metetra
.549 .82 .996 r
.56119 .29878 .57493 .30811 .60148 .30245 .58797 .29319 Metetra
.557 .826 .996 r
.58797 .29319 .60148 .30245 .62835 .29667 .61506 .28714 Metetra
.574 .831 .994 r
.61506 .28714 .62835 .29667 .65553 .29062 .64245 .28045 Metetra
.598 .831 .988 r
.64245 .28045 .65553 .29062 .68301 .28415 .67013 .27294 Metetra
.625 .827 .978 r
.67013 .27294 .68301 .28415 .71078 .2771 .69807 .26449 Metetra
.65 .815 .963 r
.69807 .26449 .71078 .2771 .73882 .26933 .72624 .25502 Metetra
.67 .798 .943 r
.72624 .25502 .73882 .26933 .76712 .26074 .75463 .24451 Metetra
.684 .778 .922 r
.75463 .24451 .76712 .26074 .79564 .25128 .78322 .23303 Metetra
.693 .757 .9 r
.78322 .23303 .79564 .25128 .82438 .24092 .81199 .22067 Metetra
.66 .741 .91 r
.17608 .38503 .19217 .4 .21521 .39201 .19922 .37701 Metetra
.658 .741 .911 r
.19922 .37701 .21521 .39201 .23844 .38404 .22256 .36906 Metetra
.655 .743 .914 r
.22256 .36906 .23844 .38404 .26187 .37612 .2461 .36124 Metetra
.65 .745 .919 r
.2461 .36124 .26187 .37612 .28551 .36829 .26984 .35361 Metetra
.644 .748 .925 r
.26984 .35361 .28551 .36829 .30936 .36061 .29379 .34625 Metetra
.635 .752 .932 r
.29379 .34625 .30936 .36061 .33342 .35312 .31795 .33924 Metetra
.625 .758 .942 r
.31795 .33924 .33342 .35312 .3577 .34589 .34233 .33263 Metetra
.612 .765 .953 r
.34233 .33263 .3577 .34589 .3822 .33896 .36694 .32646 Metetra
.596 .774 .965 r
.36694 .32646 .3822 .33896 .40695 .33239 .3918 .32074 Metetra
.578 .784 .977 r
.3918 .32074 .40695 .33239 .43194 .32617 .41693 .31544 Metetra
.558 .794 .987 r
.41693 .31544 .43194 .32617 .4572 .3203 .44234 .31046 Metetra
.539 .803 .994 r
.44234 .31046 .4572 .3203 .48274 .31473 .46806 .30567 Metetra
.525 .812 .998 r
.46806 .30567 .48274 .31473 .50858 .30938 .4941 .30088 Metetra
.519 .821 1 r
.4941 .30088 .50858 .30938 .53473 .30412 .52046 .29586 Metetra
.527 .83 1 r
.52046 .29586 .53473 .30412 .56119 .29878 .54715 .29035 Metetra
.548 .838 .998 r
.54715 .29035 .56119 .29878 .58797 .29319 .57415 .28412 Metetra
.579 .842 .995 r
.57415 .28412 .58797 .29319 .61506 .28714 .60145 .27694 Metetra
.615 .839 .985 r
.60145 .27694 .61506 .28714 .64245 .28045 .62903 .26865 Metetra
.648 .826 .969 r
.62903 .26865 .64245 .28045 .67013 .27294 .65686 .25916 Metetra
.673 .806 .946 r
.65686 .25916 .67013 .27294 .69807 .26449 .68491 .24845 Metetra
.69 .782 .921 r
.68491 .24845 .69807 .26449 .72624 .25502 .71316 .23661 Metetra
.699 .756 .896 r
.71316 .23661 .72624 .25502 .75463 .24451 .7416 .22377 Metetra
.702 .732 .874 r
.7416 .22377 .75463 .24451 .78322 .23303 .77021 .21013 Metetra
.702 .711 .855 r
.77021 .21013 .78322 .23303 .81199 .22067 .79901 .19593 Metetra
.658 .741 .911 r
.15971 .36987 .17608 .38503 .19922 .37701 .18296 .36189 Metetra
.653 .742 .915 r
.18296 .36189 .19922 .37701 .22256 .36906 .20639 .35407 Metetra
.647 .744 .92 r
.20639 .35407 .22256 .36906 .2461 .36124 .23002 .34653 Metetra
.639 .748 .927 r
.23002 .34653 .2461 .36124 .26984 .35361 .25384 .33935 Metetra
.628 .753 .937 r
.25384 .33935 .26984 .35361 .29379 .34625 .27786 .33264 Metetra
.613 .76 .949 r
.27786 .33264 .29379 .34625 .31795 .33924 .30209 .32646 Metetra
.595 .769 .963 r
.30209 .32646 .31795 .33924 .34233 .33263 .32655 .32085 Metetra
.572 .78 .977 r
.32655 .32085 .34233 .33263 .36694 .32646 .35125 .31582 Metetra
.545 .79 .989 r
.35125 .31582 .36694 .32646 .3918 .32074 .37623 .31126 Metetra
.516 .8 .997 r
.37623 .31126 .3918 .32074 .41693 .31544 .4015 .30704 Metetra
.491 .809 1 r
.4015 .30704 .41693 .31544 .44234 .31046 .42708 .30293 Metetra
.476 .818 .999 r
.42708 .30293 .44234 .31046 .46806 .30567 .453 .29864 Metetra
.48 .828 .997 r
.453 .29864 .46806 .30567 .4941 .30088 .47926 .29384 Metetra
.505 .841 .998 r
.47926 .29384 .4941 .30088 .52046 .29586 .50585 .28821 Metetra
.548 .851 .998 r
.50585 .28821 .52046 .29586 .54715 .29035 .53277 .28146 Metetra
.599 .853 .992 r
.53277 .28146 .54715 .29035 .57415 .28412 .55999 .27338 Metetra
.644 .841 .976 r
.55999 .27338 .57415 .28412 .60145 .27694 .58748 .26384 Metetra
.678 .817 .95 r
.58748 .26384 .60145 .27694 .62903 .26865 .6152 .25284 Metetra
.698 .786 .919 r
.6152 .25284 .62903 .26865 .65686 .25916 .64313 .24049 Metetra
.707 .755 .89 r
.64313 .24049 .65686 .25916 .68491 .24845 .67125 .22701 Metetra
.708 .726 .864 r
.67125 .22701 .68491 .24845 .71316 .23661 .69954 .21267 Metetra
.706 .702 .844 r
.69954 .21267 .71316 .23661 .7416 .22377 .72801 .19776 Metetra
.702 .684 .83 r
.72801 .19776 .7416 .22377 .77021 .21013 .75667 .18261 Metetra
.697 .671 .821 r
.75667 .18261 .77021 .21013 .79901 .19593 .78554 .16746 Metetra
.652 .741 .915 r
.14306 .35456 .15971 .36987 .18296 .36189 .16638 .34676 Metetra
.644 .743 .921 r
.16638 .34676 .18296 .36189 .20639 .35407 .18989 .33932 Metetra
.633 .747 .93 r
.18989 .33932 .20639 .35407 .23002 .34653 .21357 .33239 Metetra
.618 .754 .943 r
.21357 .33239 .23002 .34653 .25384 .33935 .23743 .32609 Metetra
.596 .762 .958 r
.23743 .32609 .25384 .33935 .27786 .33264 .26148 .32052 Metetra
.568 .773 .975 r
.26148 .32052 .27786 .33264 .30209 .32646 .28575 .31572 Metetra
.531 .784 .99 r
.28575 .31572 .30209 .32646 .32655 .32085 .31026 .31163 Metetra
.488 .793 .999 r
.31026 .31163 .32655 .32085 .35125 .31582 .33505 .30809 Metetra
.444 .799 .997 r
.33505 .30809 .35125 .31582 .37623 .31126 .36014 .30485 Metetra
.412 .803 .988 r
.36014 .30485 .37623 .31126 .4015 .30704 .38557 .30152 Metetra
.405 .812 .979 r
.38557 .30152 .4015 .30704 .42708 .30293 .41136 .29769 Metetra
.433 .831 .981 r
.41136 .29769 .42708 .30293 .453 .29864 .43752 .29289 Metetra
.494 .854 .99 r
.43752 .29289 .453 .29864 .47926 .29384 .46404 .28673 Metetra
.57 .868 .995 r
.46404 .28673 .47926 .29384 .50585 .28821 .4909 .27891 Metetra
.638 .86 .983 r
.4909 .27891 .50585 .28821 .53277 .28146 .51806 .26926 Metetra
.685 .831 .954 r
.51806 .26926 .53277 .28146 .55999 .27338 .54547 .25782 Metetra
.708 .792 .916 r
.54547 .25782 .55999 .27338 .58748 .26384 .57311 .24475 Metetra
.716 .752 .88 r
.57311 .24475 .58748 .26384 .6152 .25284 .60094 .23037 Metetra
.715 .717 .851 r
.60094 .23037 .6152 .25284 .64313 .24049 .62893 .21507 Metetra
.71 .69 .829 r
.62893 .21507 .64313 .24049 .67125 .22701 .6571 .19927 Metetra
.703 .67 .815 r
.6571 .19927 .67125 .22701 .69954 .21267 .68545 .18337 Metetra
.696 .657 .807 r
.68545 .18337 .69954 .21267 .72801 .19776 .714 .16768 Metetra
.69 .649 .805 r
.714 .16768 .72801 .19776 .75667 .18261 .74278 .15243 Metetra
.684 .647 .807 r
.74278 .15243 .75667 .18261 .78554 .16746 .77182 .13776 Metetra
.641 .741 .921 r
.12609 .3392 .14306 .35456 .16638 .34676 .14946 .33189 Metetra
.625 .745 .933 r
.14946 .33189 .16638 .34676 .18989 .33932 .17298 .32529 Metetra
.602 .753 .95 r
.17298 .32529 .18989 .33932 .21357 .33239 .19664 .31959 Metetra
.569 .763 .97 r
.19664 .31959 .21357 .33239 .23743 .32609 .22048 .31492 Metetra
.521 .773 .989 r
.22048 .31492 .23743 .32609 .26148 .32052 .2445 .31129 Metetra
.456 .78 .998 r
.2445 .31129 .26148 .32052 .28575 .31572 .26876 .30857 Metetra
.38 .776 .987 r
.26876 .30857 .28575 .31572 .31026 .31163 .2933 .30646 Metetra
.311 .765 .955 r
.2933 .30646 .31026 .31163 .33505 .30809 .31818 .30446 Metetra
.279 .761 .923 r
.31818 .30446 .33505 .30809 .36014 .30485 .34344 .302 Metetra
.304 .783 .918 r
.34344 .302 .36014 .30485 .38557 .30152 .36911 .29841 Metetra
.39 .831 .946 r
.36911 .29841 .38557 .30152 .41136 .29769 .3952 .2931 Metetra
.514 .877 .982 r
.3952 .2931 .41136 .29769 .43752 .29289 .42169 .28562 Metetra
.627 .885 .988 r
.42169 .28562 .43752 .29289 .46404 .28673 .44854 .27577 Metetra
.695 .851 .957 r
.44854 .27577 .46404 .28673 .4909 .27891 .47568 .26361 Metetra
.723 .798 .91 r
.47568 .26361 .4909 .27891 .51806 .26926 .50307 .24944 Metetra
.728 .746 .867 r
.50307 .24944 .51806 .26926 .54547 .25782 .53065 .23376 Metetra
.722 .705 .833 r
.53065 .23376 .54547 .25782 .57311 .24475 .55839 .21715 Metetra
.713 .673 .81 r
.55839 .21715 .57311 .24475 .60094 .23037 .58629 .2002 Metetra
.703 .652 .796 r
.58629 .2002 .60094 .23037 .62893 .21507 .61436 .18342 Metetra
.694 .639 .791 r
.61436 .18342 .62893 .21507 .6571 .19927 .64262 .16718 Metetra
.686 .634 .792 r
.64262 .16718 .6571 .19927 .68545 .18337 .67109 .1517 Metetra
.68 .635 .798 r
.67109 .1517 .68545 .18337 .714 .16768 .69982 .13705 Metetra
.675 .641 .808 r
.69982 .13705 .714 .16768 .74278 .15243 .72882 .12322 Metetra
.672 .651 .821 r
.72882 .12322 .74278 .15243 .77182 .13776 .75813 .11008 Metetra
.615 .74 .935 r
.10876 .32404 .12609 .3392 .14946 .33189 .13209 .3179 Metetra
.578 .748 .957 r
.13209 .3179 .14946 .33189 .17298 .32529 .15551 .31309 Metetra
.52 .757 .983 r
.15551 .31309 .17298 .32529 .19664 .31959 .17903 .30981 Metetra
.427 .759 .996 r
.17903 .30981 .19664 .31959 .22048 .31492 .20271 .30801 Metetra
.296 .735 .965 r
.20271 .30801 .22048 .31492 .2445 .31129 .22661 .30739 Metetra
.157 .68 .878 r
.22661 .30739 .2445 .31129 .26876 .30857 .25082 .30732 Metetra
.071 .632 .78 r
.25082 .30732 .26876 .30857 .2933 .30646 .27544 .30692 Metetra
.078 .639 .742 r
.27544 .30692 .2933 .30646 .31818 .30446 .30053 .3052 Metetra
.189 .721 .794 r
.30053 .3052 .31818 .30446 .34344 .302 .32614 .30119 Metetra
.392 .845 .906 r
.32614 .30119 .34344 .302 .36911 .29841 .35225 .29421 Metetra
.599 .913 .979 r
.35225 .29421 .36911 .29841 .3952 .2931 .37882 .28394 Metetra
.713 .878 .958 r
.37882 .28394 .3952 .2931 .42169 .28562 .40576 .27054 Metetra
.745 .804 .899 r
.40576 .27054 .42169 .28562 .44854 .27577 .43297 .2546 Metetra
.742 .735 .845 r
.43297 .2546 .44854 .27577 .47568 .26361 .46039 .23694 Metetra
.728 .685 .808 r
.46039 .23694 .47568 .26361 .50307 .24944 .48795 .21849 Metetra
.713 .65 .785 r
.48795 .21849 .50307 .24944 .53065 .23376 .51563 .20008 Metetra
.699 .629 .774 r
.51563 .20008 .53065 .23376 .55839 .21715 .54345 .18235 Metetra
.688 .618 .772 r
.54345 .18235 .55839 .21715 .58629 .2002 .57143 .16568 Metetra
.679 .616 .778 r
.57143 .16568 .58629 .2002 .61436 .18342 .59961 .15021 Metetra
.673 .621 .789 r
.59961 .15021 .61436 .18342 .64262 .16718 .62802 .13588 Metetra
.669 .633 .805 r
.62802 .13588 .64262 .16718 .67109 .1517 .65671 .12253 Metetra
.666 .649 .823 r
.65671 .12253 .67109 .1517 .69982 .13705 .68568 .10994 Metetra
.665 .667 .842 r
.68568 .10994 .69982 .13705 .72882 .12322 .71496 .09787 Metetra
.664 .684 .859 r
.71496 .09787 .72882 .12322 .75813 .11008 .74456 .08614 Metetra
.539 .733 .964 r
.09097 .30979 .10876 .32404 .13209 .3179 .11403 .30639 Metetra
.42 .729 .99 r
.11403 .30639 .13209 .3179 .15551 .31309 .13709 .30544 Metetra
.204 .673 .94 r
.13709 .30544 .15551 .31309 .17903 .30981 .16022 .30677 Metetra
0 .523 .736 r
.16022 .30677 .17903 .30981 .20271 .30801 .18357 .30962 Metetra
.216 0 0 r
.18357 .30962 .20271 .30801 .22661 .30739 .20731 .31264 Metetra
.233 0 0 r
.20731 .31264 .22661 .30739 .25082 .30732 .23163 .31412 Metetra
.126 0 0 r
.23163 .31412 .25082 .30732 .27544 .30692 .25663 .31234 Metetra
.25663 .31234 .27544 .30692 .30053 .3052 .28235 .30606 Metetra
.525 .917 .907 r
.28235 .30606 .30053 .3052 .32614 .30119 .30872 .29483 Metetra
.745 .917 .95 r
.30872 .29483 .32614 .30119 .35225 .29421 .3356 .27909 Metetra
.776 .805 .876 r
.3356 .27909 .35225 .29421 .37882 .28394 .36281 .26003 Metetra
.756 .714 .812 r
.36281 .26003 .37882 .28394 .40576 .27054 .3902 .23922 Metetra
.73 .654 .774 r
.3902 .23922 .40576 .27054 .43297 .2546 .41768 .21816 Metetra
.707 .617 .754 r
.41768 .21816 .43297 .2546 .46039 .23694 .4452 .19804 Metetra
.689 .597 .748 r
.4452 .19804 .46039 .23694 .48795 .21849 .4728 .17954 Metetra
.676 .591 .752 r
.4728 .17954 .48795 .21849 .51563 .20008 .50051 .1629 Metetra
.668 .596 .765 r
.50051 .1629 .51563 .20008 .54345 .18235 .52838 .14797 Metetra
.663 .609 .785 r
.52838 .14797 .54345 .18235 .57143 .16568 .55647 .13445 Metetra
.661 .63 .808 r
.55647 .13445 .57143 .16568 .59961 .15021 .58482 .12194 Metetra
.661 .653 .832 r
.58482 .12194 .59961 .15021 .62802 .13588 .61344 .11008 Metetra
.662 .677 .854 r
.61344 .11008 .62802 .13588 .65671 .12253 .64236 .09858 Metetra
.662 .697 .872 r
.64236 .09858 .65671 .12253 .68568 .10994 .67159 .08726 Metetra
.663 .713 .885 r
.67159 .08726 .68568 .10994 .71496 .09787 .70112 .07597 Metetra
.663 .724 .894 r
.70112 .07597 .71496 .09787 .74456 .08614 .73097 .06464 Metetra
.173 .608 .94 r
.07234 .29866 .09097 .30979 .11403 .30639 .09456 .30222 Metetra
.302 0 0 r
.09456 .30222 .11403 .30639 .13709 .30544 .11666 .30978 Metetra
.503 0 0 r
.11666 .30978 .13709 .30544 .16022 .30677 .139 .3192 Metetra
.504 0 0 r
.139 .3192 .16022 .30677 .18357 .30962 .16203 .3271 Metetra
.414 0 0 r
.16203 .3271 .18357 .30962 .20731 .31264 .18612 .32978 Metetra
.196 0 0 r
.18612 .32978 .20731 .31264 .23163 .31412 .21144 .32453 Metetra
.336 .786 .634 r
.21144 .32453 .23163 .31412 .25663 .31234 .23786 .31066 Metetra
.805 .963 .911 r
.23786 .31066 .25663 .31234 .28235 .30606 .26506 .28967 Metetra
.815 .79 .829 r
.26506 .28967 .28235 .30606 .30872 .29483 .29264 .26454 Metetra
.763 .671 .761 r
.29264 .26454 .30872 .29483 .3356 .27909 .32028 .23849 Metetra
.72 .605 .727 r
.32028 .23849 .3356 .27909 .36281 .26003 .34782 .21407 Metetra
.689 .569 .715 r
.34782 .21407 .36281 .26003 .3902 .23922 .37522 .19262 Metetra
.668 .556 .719 r
.37522 .19262 .3902 .23922 .41768 .21816 .40256 .17441 Metetra
.656 .56 .734 r
.40256 .17441 .41768 .21816 .4452 .19804 .42994 .15897 Metetra
.651 .578 .759 r
.42994 .15897 .4452 .19804 .4728 .17954 .45746 .14556 Metetra
.652 .606 .79 r
.45746 .14556 .4728 .17954 .50051 .1629 .48518 .13342 Metetra
.654 .639 .823 r
.48518 .13342 .50051 .1629 .52838 .14797 .51315 .12198 Metetra
.658 .671 .851 r
.51315 .12198 .52838 .14797 .55647 .13445 .5414 .11084 Metetra
.66 .697 .873 r
.5414 .11084 .55647 .13445 .58482 .12194 .56994 .0998 Metetra
.662 .716 .888 r
.56994 .0998 .58482 .12194 .61344 .11008 .59877 .08874 Metetra
.663 .728 .897 r
.59877 .08874 .61344 .11008 .64236 .09858 .6279 .07759 Metetra
.663 .734 .902 r
.6279 .07759 .64236 .09858 .67159 .08726 .65734 .06634 Metetra
.664 .738 .905 r
.65734 .06634 .67159 .08726 .70112 .07597 .6871 .05497 Metetra
.664 .739 .906 r
.6871 .05497 .70112 .07597 .73097 .06464 .71716 .04349 Metetra
.745 .264 .1 r
.05131 .30061 .07234 .29866 .09456 .30222 .0707 .32478 Metetra
.689 .282 .27 r
.0707 .32478 .09456 .30222 .11666 .30978 .09068 .34996 Metetra
.58 .201 .287 r
.09068 .34996 .11666 .30978 .139 .3192 .11278 .36458 Metetra
.393 .015 .199 r
.11278 .36458 .139 .3192 .16203 .3271 .1378 .3601 Metetra
.1378 .3601 .16203 .3271 .18612 .32978 .16536 .33617 Metetra
.91 .973 .794 r
.16536 .33617 .18612 .32978 .21144 .32453 .19423 .30012 Metetra
.833 .721 .741 r
.19423 .30012 .21144 .32453 .23786 .31066 .22316 .26177 Metetra
.737 .588 .689 r
.22316 .26177 .23786 .31066 .26506 .28967 .25143 .22825 Metetra
.678 .525 .67 r
.25143 .22825 .26506 .28967 .29264 .26454 .27896 .2022 Metetra
.644 .501 .673 r
.27896 .2022 .29264 .26454 .32028 .23849 .30599 .18286 Metetra
.629 .506 .694 r
.30599 .18286 .32028 .23849 .34782 .21407 .33283 .16807 Metetra
.629 .535 .729 r
.33283 .16807 .34782 .21407 .37522 .19262 .35971 .15578 Metetra
.637 .581 .775 r
.35971 .15578 .37522 .19262 .40256 .17441 .38677 .1446 Metetra
.647 .632 .821 r
.38677 .1446 .40256 .17441 .42994 .15897 .41407 .13381 Metetra
.656 .676 .858 r
.41407 .13381 .42994 .15897 .45746 .14556 .44165 .12308 Metetra
.66 .707 .882 r
.44165 .12308 .45746 .14556 .48518 .13342 .4695 .11229 Metetra
.662 .725 .896 r
.4695 .11229 .48518 .13342 .51315 .12198 .49764 .10141 Metetra
.663 .734 .902 r
.49764 .10141 .51315 .12198 .5414 .11084 .52608 .09041 Metetra
.664 .738 .905 r
.52608 .09041 .5414 .11084 .56994 .0998 .55481 .0793 Metetra
.664 .74 .907 r
.55481 .0793 .56994 .0998 .59877 .08874 .58384 .06807 Metetra
.664 .74 .907 r
.58384 .06807 .59877 .08874 .6279 .07759 .61318 .05673 Metetra
.664 .741 .907 r
.61318 .05673 .6279 .07759 .65734 .06634 .64283 .04526 Metetra
.664 .741 .907 r
.64283 .04526 .65734 .06634 .6871 .05497 .6728 .03367 Metetra
.664 .741 .907 r
.6728 .03367 .6871 .05497 .71716 .04349 .70309 .02196 Metetra
.665 .363 .452 r
.01153 .41688 .05131 .30061 .0707 .32478 .0258 .48067 Metetra
.426 .144 .379 r
.0258 .48067 .0707 .32478 .09068 .34996 .05283 .4649 Metetra
.05283 .4649 .09068 .34996 .11278 .36458 .09223 .35929 Metetra
.942 .78 .652 r
.09223 .35929 .11278 .36458 .1378 .3601 .12828 .27024 Metetra
.703 .508 .621 r
.12828 .27024 .1378 .3601 .16536 .33617 .15839 .22231 Metetra
.6 .413 .601 r
.15839 .22231 .16536 .33617 .19423 .30012 .18523 .20019 Metetra
.573 .403 .613 r
.18523 .20019 .19423 .30012 .22316 .26177 .21113 .18747 Metetra
.581 .437 .651 r
.21113 .18747 .22316 .26177 .25143 .22825 .23703 .17692 Metetra
.604 .502 .711 r
.23703 .17692 .25143 .22825 .27896 .2022 .26314 .16665 Metetra
.631 .584 .783 r
.26314 .16665 .27896 .2022 .30599 .18286 .28951 .15632 Metetra
.651 .658 .844 r
.28951 .15632 .30599 .18286 .33283 .16807 .31615 .14589 Metetra
.66 .705 .881 r
.31615 .14589 .33283 .16807 .35971 .15578 .34306 .13535 Metetra
.663 .728 .898 r
.34306 .13535 .35971 .15578 .38677 .1446 .37025 .12471 Metetra
.664 .737 .904 r
.37025 .12471 .38677 .1446 .41407 .13381 .39772 .11395 Metetra
.664 .74 .907 r
.39772 .11395 .41407 .13381 .44165 .12308 .42547 .10309 Metetra
.664 .741 .907 r
.42547 .10309 .44165 .12308 .4695 .11229 .4535 .09211 Metetra
.664 .741 .907 r
.4535 .09211 .4695 .11229 .49764 .10141 .48183 .08102 Metetra
.664 .741 .907 r
.48183 .08102 .49764 .10141 .52608 .09041 .51046 .06981 Metetra
.664 .741 .907 r
.51046 .06981 .52608 .09041 .55481 .0793 .53939 .05848 Metetra
.664 .741 .907 r
.53939 .05848 .55481 .0793 .58384 .06807 .56863 .04703 Metetra
.664 .741 .907 r
.56863 .04703 .58384 .06807 .61318 .05673 .59817 .03546 Metetra
.664 .741 .907 r
.59817 .03546 .61318 .05673 .64283 .04526 .62804 .02377 Metetra
.664 .741 .907 r
.62804 .02377 .64283 .04526 .6728 .03367 .65822 .01195 Metetra
.664 .741 .907 r
.65822 .01195 .6728 .03367 .70309 .02196 .68874 0 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.16157 .20642 m
.16617 .2111 L
s
[(0.5)] .15237 .19707 .98294 1 Mshowa
.32604 .14202 m
.33035 .14696 L
s
[(1)] .31741 .13214 .87321 1 Mshowa
.50139 .07336 m
.50537 .07857 L
s
[(1.5)] .49342 .06293 .76347 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(2)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.19364 .19386 m
.19637 .1967 L
s
.22611 .18115 m
.22881 .18402 L
s
.259 .16827 m
.26166 .17117 L
s
.29231 .15523 m
.29493 .15816 L
s
.3602 .12864 m
.36275 .13164 L
s
.39481 .11509 m
.39732 .11812 L
s
.42987 .10136 m
.43235 .10443 L
s
.4654 .08745 m
.46783 .09055 L
s
.53786 .05908 m
.5402 .06224 L
s
.57482 .04461 m
.57712 .0478 L
s
.61228 .02994 m
.61453 .03317 L
s
.65025 .01507 m
.65245 .01833 L
s
.12989 .21883 m
.13268 .2216 L
s
.0986 .23108 m
.10142 .23383 L
s
.06769 .24318 m
.07054 .2459 L
s
.03716 .25514 m
.04004 .25782 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[134]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[134]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[c]\)], "Input",
  CellLabel->"In[135]:="],

Cell[TextData[{
  "Here is shown that the solution obtained with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is right "
}], "Text"],

Cell[BoxData[
    \(c[z_, 
        t_] = \(\[ExponentialE]\^\(\(-\(\((t - z)\)\^2\/\(4\ t\ d\_n\)\)\) - \
t\ d\_n\ r\_n\)\ z\)\/\(2\ \@\[Pi]\ \@\(t\^3\/d\_n\%3\)\ d\_n\%2\); \)], \
"Input",
  CellLabel->"In[136]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[c[z, t], t] == 
        d\_n\ D[c[z, t], z, z] - \ D[c[z, t], z] - r\_n\ \(d\_n\) c[z, t] // 
      Simplify\)], "Input",
  CellLabel->"In[137]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[137]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "SubsectionIcon"],

Cell[TextData[{
  "[1]\[ThickSpace]\[MediumSpace]J. A. Jacquez, ",
  StyleBox["\[NonBreakingSpace]Compartmental Analysis in Biology and \
Medicine", "SO"],
  ", The University of Michigan Press, 1985."
}], "Text",
  CellTags->"ref 1"],

Cell["\<\
[2] ICRP 78 (1997). Individual Monitoring for Internal Exposure of Workers. \
ICRP Publication 78. Pergamon.\
\>", "Text",
  CellTags->"ref 4"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{914, 638},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PageFooters->{{Inherited, Cell[ 
        TextData[ {
          "\[Copyright]2005 Guillermo Sanchez. All rights reserved."}], 
        "PageFooter"], Inherited}, {Inherited, Cell[ 
        TextData[ {
          "\[Copyright]2005 Guillermo Sanchez. All rights reserved."}], 
        "PageFooter"], Inherited}},
ShowSelection->True,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "fig 2"->{
    Cell[38856, 1144, 69, 1, 70, "Text",
      CellTags->"fig 2"],
    Cell[339228, 5657, 142, 4, 70, "NumberedFigureCaption",
      CellTags->"fig 2"]},
  "eq 1"->{
    Cell[344893, 5832, 1295, 41, 70, "NumberedEquation",
      CellTags->"eq 1"]},
  "Solve"->{
    Cell[365359, 6500, 137, 3, 70, "Input",
      CellTags->"Solve"]},
  "Info3257348699-2143584"->{
    Cell[2607406, 73876, 770, 11, 70, "Print",
      CellTags->"Info3257348699-2143584"]},
  "ref 1"->{
    Cell[2882363, 84753, 234, 6, 70, "Text",
      CellTags->"ref 1"]},
  "ref 4"->{
    Cell[2882600, 84761, 153, 4, 70, "Text",
      CellTags->"ref 4"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"fig 2", 2883765, 84794},
  {"eq 1", 2883931, 84799},
  {"Solve", 2884027, 84802},
  {"Info3257348699-2143584", 2884128, 84805},
  {"ref 1", 2884232, 84808},
  {"ref 4", 2884317, 84811}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 95, 2, 126, "Chapter"],
Cell[1874, 57, 358, 11, 25, "Text"],
Cell[2235, 70, 62, 0, 33, "Commentary"],

Cell[CellGroupData[{
Cell[2322, 74, 65, 2, 29, "Input"],
Cell[2390, 78, 104, 2, 27, "Output"]
}, Open  ]],
Cell[2509, 83, 296, 6, 25, "Text"],

Cell[CellGroupData[{
Cell[2830, 93, 39, 0, 39, "SubsectionIcon"],
Cell[2872, 95, 214, 5, 70, "Text"],
Cell[3089, 102, 52, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[3166, 106, 87, 2, 70, "Input"],
Cell[3256, 110, 118, 2, 70, "Print"]
}, Open  ]],
Cell[3389, 115, 264, 5, 70, "Input"],
Cell[3656, 122, 60, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[3741, 126, 86, 2, 70, "Input"],
Cell[3830, 130, 5603, 139, 70, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[9482, 275, 60, 0, 29, "SubsectionIcon"],
Cell[9545, 277, 602, 9, 70, "Text"],
Cell[10150, 288, 2261, 70, 70, "Text"],
Cell[12414, 360, 1120, 42, 70, "Text"],
Cell[13537, 404, 25316, 738, 70, 12703, 578, "GraphicsData", "PostScript", \
"NumberedFigure"],
Cell[38856, 1144, 69, 1, 70, "Text",
  CellTags->"fig 2"],
Cell[38928, 1147, 912, 26, 70, "Text"],
Cell[39843, 1175, 358, 9, 70, "Text"],
Cell[40204, 1186, 37, 0, 70, "Text"],
Cell[40244, 1188, 665, 20, 70, "Text"],
Cell[40912, 1210, 121, 3, 70, "Text"],
Cell[41036, 1215, 1772, 65, 70, "Text"],
Cell[42811, 1282, 188, 5, 70, "Text"],
Cell[43002, 1289, 296223, 4366, 70, 21672, 972, "GraphicsData", "PostScript", \
"GraphicsOnly"],
Cell[339228, 5657, 142, 4, 70, "NumberedFigureCaption",
  CellTags->"fig 2"],
Cell[339373, 5663, 74, 0, 70, "Text"],
Cell[339450, 5665, 1049, 30, 70, "Text"],
Cell[340502, 5697, 35, 0, 70, "Text"],
Cell[340540, 5699, 919, 28, 70, "Text"],
Cell[341462, 5729, 20, 0, 70, "Text"],
Cell[341485, 5731, 419, 14, 70, "Text"],
Cell[341907, 5747, 155, 7, 70, "DisplayFormula"],
Cell[342065, 5756, 291, 8, 70, "Text"],
Cell[342359, 5766, 20, 0, 70, "Text"],
Cell[342382, 5768, 401, 9, 70, "Text"],
Cell[342786, 5779, 410, 7, 70, "Text"],
Cell[343199, 5788, 456, 10, 70, "Text"],
Cell[343658, 5800, 854, 16, 70, "Text"],
Cell[344515, 5818, 375, 12, 70, "Text"],
Cell[344893, 5832, 1295, 41, 70, "NumberedEquation",
  CellTags->"eq 1"],
Cell[346191, 5875, 69, 2, 70, "Text"],
Cell[346263, 5879, 426, 15, 70, "Text"],
Cell[346692, 5896, 206, 7, 70, "Text"],
Cell[346901, 5905, 442, 13, 70, "Text"],
Cell[347346, 5920, 1080, 34, 70, "Text"],
Cell[348429, 5956, 340, 6, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[348806, 5967, 51, 0, 29, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[348882, 5971, 58, 0, 25, "SubsubsectionIcon"],
Cell[348943, 5973, 114, 3, 25, "Text"],
Cell[349060, 5978, 9510, 272, 133, "NumberedFigure"],
Cell[358573, 6252, 703, 24, 42, "Text"],
Cell[359279, 6278, 133, 2, 46, "NumberedEquation"],
Cell[359415, 6282, 319, 11, 17, "Caption"],

Cell[CellGroupData[{
Cell[359759, 6297, 469, 12, 29, "Input"],
Cell[360231, 6311, 109, 2, 27, "Output"]
}, Open  ]],
Cell[360355, 6316, 483, 17, 25, "Text"],
Cell[360841, 6335, 297, 10, 17, "Caption"],

Cell[CellGroupData[{
Cell[361163, 6349, 97, 2, 29, "Input"],
Cell[361263, 6353, 113, 2, 27, "Output"]
}, Open  ]],
Cell[361391, 6358, 345, 12, 25, "Text"],

Cell[CellGroupData[{
Cell[361761, 6374, 109, 2, 29, "Input"],
Cell[361873, 6378, 93, 2, 27, "Output"]
}, Open  ]],
Cell[361981, 6383, 299, 11, 25, "Text"],

Cell[CellGroupData[{
Cell[362305, 6398, 72, 2, 29, "Input"],
Cell[362380, 6402, 97, 2, 27, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[362526, 6410, 58, 0, 21, "SubsubsectionIcon"],
Cell[362587, 6412, 606, 12, 70, "Text"],
Cell[363196, 6426, 929, 30, 70, "Text"],
Cell[364128, 6458, 118, 4, 70, "Caption"],

Cell[CellGroupData[{
Cell[364271, 6466, 116, 2, 70, "Input"],
Cell[364390, 6470, 398, 7, 70, "Message"],
Cell[364791, 6479, 82, 2, 70, "Output"],
Cell[364876, 6483, 241, 6, 70, "Message"]
}, Open  ]],
Cell[365132, 6492, 224, 6, 70, "Caption"],
Cell[365359, 6500, 137, 3, 70, "Input",
  CellTags->"Solve"],
Cell[365499, 6505, 240, 9, 70, "Text"],
Cell[365742, 6516, 203, 7, 70, "Text"],
Cell[365948, 6525, 99, 2, 70, "Caption"],

Cell[CellGroupData[{
Cell[366072, 6531, 99, 2, 70, "Input"],
Cell[366174, 6535, 68, 2, 70, "Output"]
}, Open  ]],
Cell[366257, 6540, 142, 5, 70, "Caption"],

Cell[CellGroupData[{
Cell[366424, 6549, 97, 2, 70, "Input"],
Cell[366524, 6553, 78, 2, 70, "Output"]
}, Open  ]],
Cell[366617, 6558, 328, 11, 70, "Text"],
Cell[366948, 6571, 125, 3, 70, "Caption"],

Cell[CellGroupData[{
Cell[367098, 6578, 93, 2, 70, "Input"],
Cell[367194, 6582, 15250, 377, 70, 3165, 223, "GraphicsData", "PostScript", \
"Graphics"],
Cell[382447, 6961, 155, 4, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[382651, 6971, 47, 0, 21, "SubsubsectionIcon"],
Cell[382701, 6973, 198, 4, 70, "Text"],
Cell[382902, 6979, 608, 20, 70, "Text"],
Cell[383513, 7001, 56, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[383594, 7005, 96, 2, 70, "Input"],
Cell[383693, 7009, 79, 2, 70, "Output"]
}, Open  ]],
Cell[383787, 7014, 248, 11, 70, "Caption"],

Cell[CellGroupData[{
Cell[384060, 7029, 136, 3, 70, "Input"],
Cell[384199, 7034, 92, 2, 70, "Output"]
}, Open  ]],
Cell[384306, 7039, 53, 0, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[384396, 7044, 72, 0, 21, "SubsubsectionIcon"],
Cell[384471, 7046, 603, 21, 70, "Text"],
Cell[385077, 7069, 451, 17, 70, "Text"],

Cell[CellGroupData[{
Cell[385553, 7090, 136, 3, 70, "Input"],
Cell[385692, 7095, 98, 2, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[385839, 7103, 43, 0, 21, "SubsubsectionIcon"],
Cell[385885, 7105, 309, 9, 70, "Text",
  Evaluatable->False],
Cell[386197, 7116, 10126, 339, 70, 5577, 278, "GraphicsData", "PostScript", \
"NumberedFigure"],
Cell[396326, 7457, 1558, 49, 70, "Text"],
Cell[397887, 7508, 122, 2, 70, "NumberedEquation"],
Cell[398012, 7512, 651, 23, 70, "Text"],
Cell[398666, 7537, 110, 2, 70, "Input"],
Cell[398779, 7541, 350, 14, 70, "Text"],

Cell[CellGroupData[{
Cell[399154, 7559, 104, 2, 70, "Input"],
Cell[399261, 7563, 210, 5, 70, "Output"]
}, Open  ]],
Cell[399486, 7571, 79, 0, 70, "Caption"],

Cell[CellGroupData[{
Cell[399590, 7575, 111, 2, 70, "Input"],
Cell[399704, 7579, 136, 3, 70, "Output"]
}, Open  ]],
Cell[399855, 7585, 557, 21, 70, "Text"],
Cell[400415, 7608, 233, 8, 70, "Caption"],
Cell[400651, 7618, 257, 8, 70, "Caption"],

Cell[CellGroupData[{
Cell[400933, 7630, 212, 5, 70, "Input"],
Cell[401148, 7637, 16205, 404, 70, 3420, 241, "GraphicsData", "PostScript", \
"Graphics"],
Cell[417356, 8043, 231, 6, 70, "Output"]
}, Open  ]],
Cell[417602, 8052, 488, 13, 70, "Text"],
Cell[418093, 8067, 110, 5, 70, "Caption"],
Cell[418206, 8074, 98, 2, 70, "Input"],
Cell[418307, 8078, 115, 3, 70, "Caption"],

Cell[CellGroupData[{
Cell[418447, 8085, 104, 2, 70, "Input"],
Cell[418554, 8089, 134, 3, 70, "Output"]
}, Open  ]],
Cell[418703, 8095, 452, 16, 70, "Caption"],

Cell[CellGroupData[{
Cell[419180, 8115, 168, 4, 70, "Input"],
Cell[419351, 8121, 201, 4, 70, "Output"]
}, Open  ]],
Cell[419567, 8128, 389, 14, 70, "Text"],
Cell[419959, 8144, 640, 23, 70, "Caption"],
Cell[420602, 8169, 169, 3, 70, "Input"],
Cell[420774, 8174, 174, 8, 70, "Caption"],

Cell[CellGroupData[{
Cell[420973, 8186, 178, 4, 70, "Input"],
Cell[421154, 8192, 19915, 450, 70, 3436, 241, "GraphicsData", "PostScript", \
"Graphics"],
Cell[441072, 8644, 155, 4, 70, "Output"]
}, Open  ]],
Cell[441242, 8651, 469, 17, 70, "Text"],
Cell[441714, 8670, 128, 3, 70, "Caption"],
Cell[441845, 8675, 186, 3, 70, "Input"],
Cell[442034, 8680, 95, 2, 70, "Input"],
Cell[442132, 8684, 154, 3, 70, "Input"],
Cell[442289, 8689, 170, 4, 70, "Input"],
Cell[442462, 8695, 169, 3, 70, "Input"],

Cell[CellGroupData[{
Cell[442656, 8702, 222, 5, 70, "Input"],
Cell[442881, 8709, 21742, 528, 70, 4465, 310, "GraphicsData", "PostScript", \
"Graphics"],
Cell[464626, 9239, 155, 4, 70, "Output"]
}, Open  ]],
Cell[464796, 9246, 129, 3, 70, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[464974, 9255, 53, 0, 39, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[465052, 9259, 72, 0, 25, "SubsubsectionIcon"],
Cell[465127, 9261, 372, 6, 70, "Text"],
Cell[465502, 9269, 25858, 629, 70, "Text"],
Cell[491363, 9900, 594, 19, 70, "Text"],
Cell[491960, 9921, 186, 3, 70, "NumberedEquation"],
Cell[492149, 9926, 186, 3, 70, "NumberedEquation"],
Cell[492338, 9931, 358, 9, 70, "Text"],
Cell[492699, 9942, 132, 2, 70, "NumberedEquation"],
Cell[492834, 9946, 174, 3, 70, "NumberedEquation"],
Cell[493011, 9951, 675, 18, 70, "Text"],
Cell[493689, 9971, 628, 20, 70, "NumberedEquation"],
Cell[494320, 9993, 265, 5, 70, "MathCaption"],
Cell[494588, 10000, 64, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[494677, 10004, 131, 3, 70, "Input"],
Cell[494811, 10009, 95, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[494943, 10016, 161, 3, 70, "Input"],
Cell[495107, 10021, 190, 3, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[495334, 10029, 418, 8, 70, "Input"],
Cell[495755, 10039, 29723, 909, 70, 12719, 694, "GraphicsData", "PostScript", \
"Graphics"],
Cell[525481, 10950, 155, 4, 70, "Output"]
}, Open  ]],
Cell[525651, 10957, 79, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[525767, 10964, 46, 0, 21, "SubsubsectionIcon"],
Cell[525816, 10966, 732, 27, 70, "Text"],
Cell[526551, 10995, 24032, 677, 70, 11072, 513, "GraphicsData", "PostScript", \
"NumberedFigure"],
Cell[550586, 11674, 65, 0, 70, "Text"],
Cell[550654, 11676, 1113, 38, 70, "NumberedEquation"],
Cell[551770, 11716, 659, 29, 70, "Text"],
Cell[552432, 11747, 64, 0, 70, "Text"],
Cell[552499, 11749, 137, 4, 70, "Input"],
Cell[552639, 11755, 128, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[552792, 11765, 116, 2, 70, "Input"],
Cell[552911, 11769, 1320, 41, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[554268, 11815, 148, 4, 70, "Input"],
Cell[554419, 11821, 516, 8, 70, "Output"]
}, Open  ]],
Cell[554950, 11832, 141, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[555116, 11842, 178, 4, 70, "Input"],
Cell[555297, 11848, 1376, 41, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[556710, 11894, 128, 3, 70, "Input"],
Cell[556841, 11899, 906, 19, 70, "Output"]
}, Open  ]],
Cell[557762, 11921, 294, 9, 70, "Text"],
Cell[558059, 11932, 119, 3, 70, "Input"],
Cell[558181, 11937, 62, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[558268, 11941, 126, 3, 70, "Input"],
Cell[558397, 11946, 6741, 175, 70, "Output"]
}, Open  ]],
Cell[565153, 12124, 54, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[565232, 12128, 107, 2, 70, "Input"],
Cell[565342, 12132, 20776, 519, 70, 4432, 312, "GraphicsData", "PostScript", \
"Graphics"],
Cell[586121, 12653, 155, 4, 70, "Output"]
}, Open  ]],
Cell[586291, 12660, 100, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[586428, 12667, 66, 0, 21, "SubsubsectionIcon"],
Cell[586497, 12669, 67, 0, 70, "Text"],
Cell[586567, 12671, 27838, 784, 70, 13090, 597, "GraphicsData", "PostScript", \
"NumberedFigure"],
Cell[614408, 13457, 47, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[614480, 13461, 199, 4, 70, "Input"],
Cell[614682, 13467, 105, 2, 70, "Output"]
}, Open  ]],
Cell[614802, 13472, 34, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[614861, 13476, 116, 2, 70, "Input"],
Cell[614980, 13480, 1592, 50, 70, "Output"]
}, Open  ]],
Cell[616587, 13533, 56, 0, 70, "Text"],
Cell[616646, 13535, 865, 26, 70, "EquationNumber"],
Cell[617514, 13563, 21, 0, 70, "Text"],
Cell[617538, 13565, 1508, 45, 70, "Text"],
Cell[619049, 13612, 396, 13, 70, "Text"],
Cell[619448, 13627, 718, 29, 70, "Text"],

Cell[CellGroupData[{
Cell[620191, 13660, 305, 6, 70, "Input"],
Cell[620499, 13668, 479, 8, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[621015, 13681, 95, 2, 70, "Input"],
Cell[621113, 13685, 18754, 482, 70, 4221, 297, "GraphicsData", "PostScript", \
"Graphics"],
Cell[639870, 14169, 155, 4, 70, "Output"]
}, Open  ]],
Cell[640040, 14176, 81, 2, 70, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[640170, 14184, 50, 0, 29, "SubsectionIcon"],
Cell[640223, 14186, 397, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[640645, 14196, 64, 0, 70, "SubsubsectionIcon"],
Cell[640712, 14198, 446, 12, 70, "Text"],
Cell[641161, 14212, 16231, 533, 70, 9457, 444, "GraphicsData", "PostScript", \
"NumberedFigure"],
Cell[657395, 14747, 279, 9, 70, "Text"],
Cell[657677, 14758, 779, 49, 70, "NumberedEquation"],
Cell[658459, 14809, 873, 30, 70, "Text"],

Cell[CellGroupData[{
Cell[659357, 14843, 177, 5, 70, "Input"],
Cell[659537, 14850, 132, 3, 70, "Output"]
}, Open  ]],
Cell[659684, 14856, 45, 0, 70, "Text"],
Cell[659732, 14858, 115, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[659872, 14864, 97, 2, 70, "Input"],
Cell[659972, 14868, 2250, 64, 70, "Output"]
}, Open  ]],
Cell[662237, 14935, 41, 0, 70, "Text"],
Cell[662281, 14937, 172, 3, 70, "Input"],
Cell[662456, 14942, 844, 31, 70, "Text"],
Cell[663303, 14975, 173, 4, 70, "Caption"],

Cell[CellGroupData[{
Cell[663501, 14983, 623, 12, 70, "Input"],
Cell[664127, 14997, 43516, 1857, 70, 28430, 1666, "GraphicsData", \
"PostScript", "Graphics"],
Cell[707646, 16856, 155, 4, 70, "Output"]
}, Open  ]],
Cell[707816, 16863, 92, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[707945, 16870, 71, 0, 70, "SubsubsectionIcon"],
Cell[708019, 16872, 389, 8, 70, "Text"],
Cell[708411, 16882, 21494, 701, 70, 12691, 588, "GraphicsData", "PostScript", \
"NumberedFigure"],
Cell[729908, 17585, 52, 0, 70, "Text"],
Cell[729963, 17587, 619, 17, 70, "NumberedEquation"],
Cell[730585, 17606, 544, 17, 70, "Text"],

Cell[CellGroupData[{
Cell[731154, 17627, 241, 6, 70, "Input"],
Cell[731398, 17635, 70, 2, 70, "Output"],
Cell[731471, 17639, 122, 4, 70, "Output"]
}, Open  ]],
Cell[731608, 17646, 244, 10, 70, "Text"],

Cell[CellGroupData[{
Cell[731877, 17660, 165, 4, 70, "Input"],
Cell[732045, 17666, 18326, 442, 70, 3705, 256, "GraphicsData", "PostScript", \
"Graphics"],
Cell[750374, 18110, 155, 4, 70, "Output"]
}, Open  ]],
Cell[750544, 18117, 574, 20, 70, "Text"],
Cell[751121, 18139, 114, 5, 70, "Caption"],

Cell[CellGroupData[{
Cell[751260, 18148, 88, 2, 70, "Input"],
Cell[751351, 18152, 80, 2, 70, "Output"]
}, Open  ]],
Cell[751446, 18157, 61, 0, 70, "Text"],
Cell[751510, 18159, 212, 7, 70, "Text"],
Cell[751725, 18168, 535, 14, 70, "NumberedEquation"],
Cell[752263, 18184, 254, 11, 70, "Text"],
Cell[752520, 18197, 232, 11, 70, "Text"],
Cell[752755, 18210, 540, 14, 70, "NumberedEquation"],
Cell[753298, 18226, 740, 32, 70, "Text"],
Cell[754041, 18260, 422, 18, 70, "Text"],
Cell[754466, 18280, 616, 21, 70, "Caption"],
Cell[755085, 18303, 216, 4, 70, "Input"],
Cell[755304, 18309, 53, 0, 70, "MathCaption"],
Cell[755360, 18311, 286, 6, 70, "Input"],

Cell[CellGroupData[{
Cell[755671, 18321, 330, 7, 70, "Input"],
Cell[756004, 18330, 557, 9, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[756598, 18344, 132, 3, 70, "Input"],
Cell[756733, 18349, 21244, 635, 70, 6680, 450, "GraphicsData", "PostScript", \
"Graphics"],
Cell[777980, 18986, 155, 4, 70, "Output"]
}, Open  ]],
Cell[778150, 18993, 872, 35, 70, "Caption"],
Cell[779025, 19030, 388, 7, 70, "Input"],
Cell[779416, 19039, 299, 6, 70, "Input"],
Cell[779718, 19047, 1170, 42, 70, "Text"],
Cell[780891, 19091, 265, 6, 70, "Caption"],
Cell[781159, 19099, 142, 4, 70, "Input"],
Cell[781304, 19105, 142, 4, 70, "Input"],
Cell[781449, 19111, 142, 4, 70, "Input"],
Cell[781594, 19117, 73, 0, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[781692, 19121, 142, 3, 70, "Input"],
Cell[781837, 19126, 35715, 1264, 70, 15488, 1009, "GraphicsData", \
"PostScript", "Graphics"],
Cell[817555, 20392, 155, 4, 70, "Output"]
}, Open  ]],
Cell[817725, 20399, 99, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[817861, 20406, 55, 0, 70, "SubsubsectionIcon"],
Cell[817919, 20408, 447, 7, 70, "Text"],
Cell[818369, 20417, 23798, 776, 70, 14097, 650, "GraphicsData", "PostScript", \
"NumberedFigure"],

Cell[CellGroupData[{
Cell[842192, 21197, 197, 5, 70, "Input"],
Cell[842392, 21204, 148, 3, 70, "Output"],
Cell[842543, 21209, 200, 5, 70, "Output"]
}, Open  ]],
Cell[842758, 21217, 75, 0, 70, "Text"],
Cell[842836, 21219, 119, 3, 70, "Input"],

Cell[CellGroupData[{
Cell[842980, 21226, 97, 2, 70, "Input"],
Cell[843080, 21230, 2582, 74, 70, "Output"]
}, Open  ]],
Cell[845677, 21307, 590, 20, 70, "Text",
  Evaluatable->False],
Cell[846270, 21329, 76, 0, 70, "Text"],
Cell[846349, 21331, 865, 26, 70, "DisplayFormula"],
Cell[847217, 21359, 20, 0, 70, "Text"],
Cell[847240, 21361, 1457, 46, 70, "DisplayFormula"],
Cell[848700, 21409, 176, 8, 70, "Text"],
Cell[848879, 21419, 246, 4, 70, "DisplayFormula"],
Cell[849128, 21425, 697, 23, 70, "Text"],
Cell[849828, 21450, 1359, 45, 70, "Text"],
Cell[851190, 21497, 335, 8, 70, "Text",
  Evaluatable->False],
Cell[851528, 21507, 276, 5, 70, "Text"],
Cell[851807, 21514, 228, 5, 70, "Input"],

Cell[CellGroupData[{
Cell[852060, 21523, 203, 4, 70, "Input"],
Cell[852266, 21529, 933, 14, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[853236, 21548, 597, 11, 70, "Input"],
Cell[853836, 21561, 35818, 1090, 70, 17161, 855, "GraphicsData", \
"PostScript", "Graphics"],
Cell[889657, 22653, 155, 4, 70, "Output"]
}, Open  ]],
Cell[889827, 22660, 103, 2, 70, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[889979, 22668, 58, 0, 29, "SubsectionIcon"],
Cell[890040, 22670, 117, 3, 25, "Text"],
Cell[890160, 22675, 49308, 1318, 324, 21674, 972, "GraphicsData", \
"PostScript", "NumberedFigure"],
Cell[939471, 23995, 67, 0, 70, "Text"],
Cell[939541, 23997, 993, 28, 70, "NumberedEquation"],
Cell[940537, 24027, 35, 0, 70, "Text"],
Cell[940575, 24029, 912, 28, 70, "DisplayFormula"],
Cell[941490, 24059, 20, 0, 70, "Text"],
Cell[941513, 24061, 497, 18, 70, "DisplayFormula"],
Cell[942013, 24081, 284, 6, 70, "Input"],

Cell[CellGroupData[{
Cell[942322, 24091, 77, 2, 70, "Input"],
Cell[942402, 24095, 511, 12, 70, "Output"]
}, Open  ]],
Cell[942928, 24110, 48, 0, 70, "Text"],
Cell[942979, 24112, 92, 2, 70, "Input"],
Cell[943074, 24116, 28, 0, 70, "Text"],
Cell[943105, 24118, 90, 2, 70, "Input"],
Cell[943198, 24122, 75, 0, 70, "Text"],
Cell[943276, 24124, 103, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[943404, 24130, 97, 2, 70, "Input"],
Cell[943504, 24134, 3763, 107, 70, "Output"]
}, Open  ]],
Cell[947282, 24244, 647, 20, 70, "Text"],
Cell[947932, 24266, 234, 4, 70, "Input"],
Cell[948169, 24272, 36, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[948230, 24276, 243, 5, 70, "Input"],
Cell[948476, 24283, 1414, 22, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[949927, 24310, 433, 8, 70, "Input"],
Cell[950363, 24320, 65583, 2948, 70, 44151, 2678, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1015949, 27270, 155, 4, 70, "Output"]
}, Open  ]],
Cell[1016119, 27277, 103, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1016259, 27284, 54, 0, 29, "SubsectionIcon"],
Cell[1016316, 27286, 87, 2, 70, "Text"],
Cell[1016406, 27290, 940225, 12720, 70, 789209, 10851, "GraphicsData", \
"PostScript", "Text"],
Cell[1956634, 40012, 62, 0, 70, "Text"],
Cell[1956699, 40014, 988, 28, 70, "Text"],
Cell[1957690, 40044, 152, 3, 70, "Text"],
Cell[1957845, 40049, 2833, 55, 70, "Text"],
Cell[1960681, 40106, 456, 11, 70, "Text"],
Cell[1961140, 40119, 76, 0, 70, "Text"],
Cell[1961219, 40121, 782, 12, 70, "Input"],
Cell[1962004, 40135, 136, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[1962165, 40142, 237, 5, 70, "Input"],
Cell[1962405, 40149, 2949, 52, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1965391, 40206, 120, 3, 70, "Input"],
Cell[1965514, 40211, 23620, 704, 70, 11267, 546, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1989137, 40917, 155, 4, 70, "Output"]
}, Open  ]],
Cell[1989307, 40924, 141, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[1989473, 40931, 275, 5, 70, "Input"],
Cell[1989751, 40938, 2415, 38, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1992203, 40981, 134, 3, 70, "Input"],
Cell[1992340, 40986, 22116, 707, 70, 11666, 573, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2014459, 41695, 155, 4, 70, "Output"]
}, Open  ]],
Cell[2014629, 41702, 152, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2014818, 41710, 45, 0, 29, "SubsectionIcon"],
Cell[2014866, 41712, 16074, 204, 295, "Text"],
Cell[2030943, 41918, 184, 5, 70, "Text"],
Cell[2031130, 41925, 686, 21, 70, "Input"],

Cell[CellGroupData[{
Cell[2031841, 41950, 142, 3, 70, "Input"],
Cell[2031986, 41955, 573856, 31870, 70, 484250, 30759, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2605857, 73828, 234, 6, 70, "Text"],
Cell[2606094, 73836, 410, 8, 70, "Input"],
Cell[2606507, 73846, 47, 0, 70, "Text"],
Cell[2606557, 73848, 80, 2, 70, "Input"],
Cell[2606640, 73852, 83, 2, 70, "Input"],
Cell[2606726, 73856, 677, 18, 70, "Text"],
Cell[2607406, 73876, 770, 11, 70, "Print",
  CellTags->"Info3257348699-2143584"],

Cell[CellGroupData[{
Cell[2608201, 73891, 150, 4, 70, "Input"],
Cell[2608354, 73897, 910, 23, 70, "Output"]
}, Open  ]],
Cell[2609279, 73923, 53, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[2609357, 73927, 175, 4, 70, "Input"],
Cell[2609535, 73933, 910, 23, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2610482, 73961, 164, 4, 70, "Input"],
Cell[2610649, 73967, 706, 19, 70, "Output"]
}, Open  ]],
Cell[2611370, 73989, 45, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[2611440, 73993, 495, 9, 70, "Input"],
Cell[2611938, 74004, 85928, 4495, 70, 69100, 4282, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2697881, 78502, 53, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[2697959, 78506, 149, 3, 70, "Input"],
Cell[2698111, 78511, 2813, 49, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2700973, 78566, 43, 0, 29, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[2701041, 78570, 67, 0, 70, "SubsubsectionIcon"],
Cell[2701111, 78572, 91, 2, 70, "Text"],
Cell[2701205, 78576, 288, 13, 70, "NumberedEquation"],
Cell[2701496, 78591, 460, 14, 70, "Text"],

Cell[CellGroupData[{
Cell[2701981, 78609, 247, 5, 70, "Input"],
Cell[2702231, 78616, 209, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2702477, 78625, 111, 2, 70, "Input"],
Cell[2702591, 78629, 17061, 417, 70, 3586, 246, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2719655, 79048, 156, 4, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2719860, 79058, 65, 0, 70, "SubsubsectionIcon"],
Cell[2719928, 79060, 72, 2, 70, "Input"],
Cell[2720003, 79064, 86, 2, 70, "Text"],
Cell[2720092, 79068, 793, 44, 70, "NumberedEquation"],
Cell[2720888, 79114, 39, 0, 70, "Text"],
Cell[2720930, 79116, 134, 3, 70, "Input"],

Cell[CellGroupData[{
Cell[2721089, 79123, 161, 3, 70, "Input"],
Cell[2721253, 79128, 364, 9, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2721654, 79142, 114, 2, 70, "Input"],
Cell[2721771, 79146, 272, 7, 70, "Output"]
}, Open  ]],
Cell[2722058, 79156, 46, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[2722129, 79160, 169, 3, 70, "Input"],
Cell[2722301, 79165, 543, 15, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2722881, 79185, 348, 7, 70, "Input"],
Cell[2723232, 79194, 30372, 970, 70, 12979, 750, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2753607, 80166, 156, 4, 70, "Output"]
}, Open  ]],
Cell[2753778, 80173, 66, 2, 70, "Input"],
Cell[2753847, 80177, 74, 2, 70, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2753970, 80185, 104, 2, 29, "SubsectionIcon"],
Cell[2754077, 80189, 115, 3, 25, "Abstract"],
Cell[2754195, 80194, 224, 3, 49, "NumberedEquation"],
Cell[2754422, 80199, 245, 8, 33, "Commentary"],
Cell[2754670, 80209, 74, 0, 25, "Text"],
Cell[2754747, 80211, 380, 10, 50, "Text"],
Cell[2755130, 80223, 123, 5, 70, "Text"],
Cell[2755256, 80230, 150, 3, 70, "NumberedEquation"],
Cell[2755409, 80235, 34, 0, 70, "Text"],
Cell[2755446, 80237, 145, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[2755616, 80244, 104, 2, 70, "Input"],
Cell[2755723, 80248, 109, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2755869, 80255, 178, 5, 70, "Input"],
Cell[2756050, 80262, 764, 21, 70, "Output"]
}, Open  ]],
Cell[2756829, 80286, 163, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[2757017, 80293, 134, 3, 70, "Input"],
Cell[2757154, 80298, 85, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2757276, 80305, 1392, 35, 70, "Input"],
Cell[2758671, 80342, 460, 13, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2759168, 80360, 104, 2, 70, "Input"],
Cell[2759275, 80364, 529, 15, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2759841, 80384, 96, 2, 70, "Input"],
Cell[2759940, 80388, 61, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2760038, 80395, 188, 4, 70, "Input"],
Cell[2760229, 80401, 401, 7, 70, "Output"]
}, Open  ]],
Cell[2760645, 80411, 177, 5, 70, "Text"],
Cell[2760825, 80418, 140, 3, 70, "Input"],

Cell[CellGroupData[{
Cell[2760990, 80425, 101, 2, 70, "Input"],
Cell[2761094, 80429, 146, 3, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2761277, 80437, 100, 2, 70, "Input"],
Cell[2761380, 80441, 176, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2761593, 80450, 96, 2, 70, "Input"],
Cell[2761692, 80454, 146, 3, 70, "Output"]
}, Open  ]],
Cell[2761853, 80460, 170, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[2762048, 80469, 135, 3, 70, "Input"],
Cell[2762186, 80474, 191, 3, 70, "Output"]
}, Open  ]],
Cell[2762392, 80480, 42, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[2762459, 80484, 69, 2, 70, "Input"],
Cell[2762531, 80488, 189, 3, 70, "Output"]
}, Open  ]],
Cell[2762735, 80494, 347, 9, 70, "Text"],
Cell[2763085, 80505, 173, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[2763283, 80514, 211, 5, 70, "Input"],
Cell[2763497, 80521, 13277, 990, 70, 13124, 985, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[2776777, 81513, 156, 4, 70, "Output"]
}, Open  ]],
Cell[2776948, 81520, 69, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[2777042, 81524, 194, 4, 70, "Input"],
Cell[2777239, 81530, 52034, 1588, 70, 51881, 1583, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[2829276, 83120, 163, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2829476, 83129, 195, 4, 70, "Input"],
Cell[2829674, 83135, 51725, 1573, 70, 51572, 1568, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[2881402, 84710, 163, 4, 70, "Output"]
}, Open  ]],
Cell[2881580, 84717, 67, 2, 70, "Input"],
Cell[2881650, 84721, 146, 5, 70, "Text"],
Cell[2881799, 84728, 215, 5, 70, "Input"],

Cell[CellGroupData[{
Cell[2882039, 84737, 169, 4, 70, "Input"],
Cell[2882211, 84743, 64, 2, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2882324, 84751, 36, 0, 29, "SubsectionIcon"],
Cell[2882363, 84753, 234, 6, 70, "Text",
  CellTags->"ref 1"],
Cell[2882600, 84761, 153, 4, 70, "Text",
  CellTags->"ref 4"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

