(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    263854,       6479]*)
(*NotebookOutlinePosition[    265463,       6531]*)
(*  CellTagsIndexPosition[    265334,       6523]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Model Fitting", "Chapter"],

Cell[TextData[{
  StyleBox["Author",
    FontWeight->"Bold"],
  ": Guillermo Sanchez:  ",
  StyleBox["guillermo@usal.es, ",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  StyleBox[ButtonBox["http://web.usal.es/~guillerm/",
    ButtonData:>{
      URL[ "http://web.usal.es/~guillerm/"], None}],
    ButtonBoxOptions -> {DefaultStyle -> "Hyperlink"}]
}], "Text"],

Cell["Last update of this help:  \t 2005-08-22", "Commentary"],

Cell[CellGroupData[{

Cell[BoxData[
    \($Version\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("5.1 for Microsoft Windows (January 28, 2005)"\)], "Output",
  CellLabel->"Out[1]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Sometime they are ",
    FontFamily->"Times New Roman"],
  "given a set of experimental data and the system model, what values for the \
parameters of the model best fit the data. ",
  StyleBox["We will show how the package ",
    FontFamily->"Times New Roman"],
  StyleBox["SysModel ", "Input",
    FontFamily->"Times New Roman"],
  StyleBox["can be used ",
    FontFamily->"Times New Roman"],
  "for model fitting",
  StyleBox[". ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell["INICIALIZATION", "SubsubsectionIcon"],

Cell["Load the Biokmod packages ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Needs["\<Biokmod`SysModel`\>"]\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \("SysModel, guillermo@usal.es, version 1.3.   2005-07-15"\)], "Print",
  CellLabel->"From In[2]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Needs["\<Biokmod`Fitmodel`\>"]\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \("Fitmodel, guillermo@usal.es, version 0.2   2005-07-15"\)], "Print",
  CellLabel->"From In[3]:="]
}, Open  ]],

Cell[TextData[{
  "We will also need the following  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " packages"
}], "Text"],

Cell[BoxData[
    \(Needs["\<Statistics`NonlinearFit`\>"]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(Needs["\<Statistics`ContinuousDistributions`\>"]\)], "Input",
  CellLabel->"In[5]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["The package Fitmodel functions", "Subsection"],

Cell[TextData[{
  "In biokinetic model we can find situations where we have two or more \
response functions with some parameters to be fitted using experimental data, \
 that is  ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\_1\)(a, b, c,  .. , x\_1, x\_2,  ... )\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\_2\)(a, b, c,  .. , x\_1, x\_2,  ... )\)]],
  ", .... The package ",
  StyleBox["Fitmodel", "Input"],
  " has some funtions for fitting parameters in these cases Multiple Response \
Fit."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?"\<Biokmod`Fitmodel`*\>"\)\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[GridBox[{
        {
          StyleBox["Biokmod`Fitmodel`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["MLFit",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703641-9120687", 
                    "Biokmod`Fitmodel`MLFit"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Fitmodel`"], 
                ButtonBox[
                  StyleBox["X2Fit",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703641-9120687", 
                    "Biokmod`Fitmodel`X2Fit"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Fitmodel`"], 
                ButtonBox[
                  StyleBox["X2FitE",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703641-9120687", 
                    "Biokmod`Fitmodel`X2FitE"},
                  ButtonFrame->"None",
                  ButtonNote->"Biokmod`Fitmodel`"], "", "", "", "", "", "", 
                "", ""}
              },
            RowMinHeight->1.05]}
        },
      RowSpacings->{2, 3},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->RGBColor[0.964706, 0.929412, 0.839216],
  ButtonBoxOptions->{Active->True},
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Open  ]],

Cell[TextData[{
  " ",
  Cell[BoxData[
      ButtonBox[
        StyleBox["X2FitE",
          "Hyperlink"],
        ButtonFunction:>(Internal`PutInformation[ #, LongForm -> False]&),
        ButtonData:>{"Info3330766015-1352080", "Biokmod`Fitmodel`X2FitE"},
        ButtonFrame->"None",
        ButtonNote->"Biokmod`Fitmodel`"]],
    CellMargins->{{20, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    ButtonBoxOptions->{Active->True},
    GridBoxOptions->{ColumnAlignments->{Left}}],
  "[",
  StyleBox["pars",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["data",
            FontSlant->"Italic"], "1"], TraditionalForm]]],
  StyleBox[",", "MR"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["model",
            FontSlant->"Italic"], "1"], TraditionalForm]]],
  StyleBox[",", "MR"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["data",
            FontSlant->"Italic"], "2"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["model",
            FontSlant->"Italic"], "2"], TraditionalForm]]],
  ", ...",
  StyleBox[",", "MR"],
  " ",
  StyleBox["t", "TI"],
  " ] using ",
  StyleBox["FindMinimun", "Input"],
  " or ",
  StyleBox["NMinimize", "Input"],
  " finds numerical values of the parameters ",
  StyleBox["pars", "TI"],
  " that make ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["model",
            FontSlant->"Italic"], "i"], TraditionalForm]]],
  " give a best fit to ",
  StyleBox["data", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`\_i\)]],
  " as a function of ",
  StyleBox["t, ", "TI"],
  StyleBox["when in data the experimental uncertainty is included", "TI",
    FontSlant->"Plain",
    FontVariations->{"CompatibilityType"->0}]
}], "DefinitionBox"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      ButtonBox[
        StyleBox["X2Fit",
          "Hyperlink"],
        ButtonFunction:>(Internal`PutInformation[ #, LongForm -> False]&),
        ButtonData:>{"Info3330766015-1352080", "Biokmod`Fitmodel`X2FitE"},
        ButtonFrame->"None",
        ButtonNote->"Biokmod`Fitmodel`"]],
    CellMargins->{{20, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    ButtonBoxOptions->{Active->True},
    GridBoxOptions->{ColumnAlignments->{Left}}],
  "[",
  StyleBox["pars",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["data",
            FontSlant->"Italic"], "1"], TraditionalForm]]],
  StyleBox[",", "MR"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["model",
            FontSlant->"Italic"], "1"], TraditionalForm]]],
  StyleBox[",", "MR"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["data",
            FontSlant->"Italic"], "2"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["model",
            FontSlant->"Italic"], "2"], TraditionalForm]]],
  ", ...",
  StyleBox[",", "MR"],
  " ",
  StyleBox["t", "TI"],
  " ] using ",
  StyleBox["FindMinimun", "Input"],
  " or ",
  StyleBox["NMinimize", "Input"],
  " finds numerical values of the parameters ",
  StyleBox["pars", "TI"],
  " that make ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["model",
            FontSlant->"Italic"], "i"], TraditionalForm]]],
  " give a best fit to ",
  StyleBox["data", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`\_i\)]],
  " as a function of ",
  StyleBox["t", "TI"],
  ". "
}], "DefinitionBox"],

Cell[TextData[{
  " ",
  StyleBox["MLFit", "MR"],
  "[",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["data",
            FontSlant->"Italic"], "1"], TraditionalForm]]],
  StyleBox[",", "MR"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["model",
            FontSlant->"Italic"], "1"], TraditionalForm]]],
  StyleBox[",", "MR"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["data",
            FontSlant->"Italic"], "2"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["model",
            FontSlant->"Italic"], "2"], TraditionalForm]]],
  ", ... ] finds numerical values of the input of to a ",
  Cell[BoxData[
      FormBox[
        StyleBox["model",
          FontSlant->"Italic"], TraditionalForm]]],
  " that make the best fit to ",
  StyleBox["data", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`\_i\)]],
  ". "
}], "DefinitionBox"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox[\(data\_i\),
          FontSlant->"Italic"], " ", "=", " ", 
        RowBox[{Cell[TextData[{
            StyleBox["{{", "MR"],
            Cell[BoxData[
                \(TraditionalForm\`t\_i1\)], "InlineFormula"],
            StyleBox[",", "MR"],
            " ",
            Cell[BoxData[
                \(TraditionalForm\`Y\_i1\)], "InlineFormula"],
            StyleBox["},", "MR"],
            " ",
            StyleBox["{", "MR"],
            Cell[BoxData[
                \(TraditionalForm\`t\_i2\)], "InlineFormula"],
            StyleBox[",", "MR"],
            " ",
            Cell[BoxData[
                \(TraditionalForm\`Y\_i2\)], "InlineFormula"],
            StyleBox["},", "MR"],
            " \[Ellipsis] ",
            StyleBox["}", "MR"],
            " "
          }]], "in", " ", 
          StyleBox["FX2FitE",
            "MR"], " ", "represents", " ", "the", " ", "experimental", " ", 
          "data", "  ", "including", " ", "the", " ", "uncertainties", " ", 
          "of", " ", "the", " ", \(\(measured\)\(.\)\)}]}], 
      TraditionalForm]], "DefinitionBox",
  GridBoxOptions->{RowSpacings->0.4,
  RowLines->False},
  CellTags->"S3.8.2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox[\(data\_i\),
          FontSlant->"Italic"], " ", "=", " ", 
        RowBox[{Cell[TextData[{
            StyleBox["{{", "MR"],
            Cell[BoxData[
                \(TraditionalForm\`t\_i1\)], "InlineFormula"],
            StyleBox[",", "MR"],
            " ",
            Cell[BoxData[
                \(TraditionalForm\`Y\_i1, \ u\_i1\)], "InlineFormula"],
            StyleBox["},", "MR"],
            " ",
            StyleBox["{", "MR"],
            Cell[BoxData[
                \(TraditionalForm\`t\_i2\)], "InlineFormula"],
            StyleBox[",", "MR"],
            " ",
            Cell[BoxData[
                \(TraditionalForm\`Y\_i2\)], "InlineFormula"],
            ", ",
            Cell[BoxData[
                \(TraditionalForm\`\(\(\ \)\(u\_i2\)\)\)]],
            StyleBox["},", "MR"],
            " \[Ellipsis] ",
            StyleBox["}", "MR"],
            " in"
          }]], " ", 
          StyleBox["X2Fit",
            "MR"], " ", "and", " ", "in", " ", 
          StyleBox["MLFitE",
            "MR"], "  ", "represents", " ", "the", " ", "experimental", " ", 
          "data", "  ", "including", " ", "the", " ", "uncertainties", " ", 
          "of", " ", "the", " ", \(\(measured\)\(.\)\)}]}], 
      TraditionalForm]], "DefinitionBox",
  GridBoxOptions->{RowSpacings->0.4,
  RowLines->False},
  CellTags->"S3.8.2"],

Cell[TextData[{
  "The  ",
  StyleBox["X2FitE", "MR"],
  " function minimize",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(i = \ 1\)\%N\((F\_i\  - \ Y\_i)\)\^2\/s\_i\
\%2\)]],
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`F\_i\)]],
  " denotes the values of the  functions",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[\(F\_i\),
              "TraditionalForm"], "(", \(a, \ t\), ")"}], " "}], 
        TraditionalForm]]],
  " associated with mesurement ",
  Cell[BoxData[
      \(TraditionalForm\`Y\_i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`s\_i\)]],
  " is the uncertainty (1 s) of ",
  Cell[BoxData[
      \(TraditionalForm\`Y\_i\)]],
  "."
}], "Text"],

Cell[TextData[{
  "The  ",
  StyleBox["X2Fit", "MR"],
  " function minimize",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(i = \ 1\)\%N\((F\_i\  - \ Y\_i)\)\^2\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`F\_i\)]],
  " denotes the values of the  functions",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[\(F\_i\),
              "TraditionalForm"], "(", \(a, \ t\), ")"}], " "}], 
        TraditionalForm]]],
  " associated with mesurement ",
  Cell[BoxData[
      \(TraditionalForm\`Y\_i\)]],
  "."
}], "Text"],

Cell[TextData[{
  "The ",
  " ",
  StyleBox["MLFit", "MR"],
  " function applies the following equations where ",
  Cell[BoxData[
      \(TraditionalForm\`F\_i\)]],
  " denotes the values of the  functions",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[\(F\_i\),
              "TraditionalForm"], "(", \(I, \ t\), ")"}], " "}], 
        TraditionalForm]]],
  " associated with mesurement ",
  Cell[BoxData[
      \(TraditionalForm\`Y\_i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`s\_i\)]],
  " is the uncertainty (1 s) of ",
  Cell[BoxData[
      \(TraditionalForm\`Y\_i\)]],
  ".\n"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(I\&^\)\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Sum]\+\(i = \ 1\)\%N\( F\_i\ Y\_i\)\/s\_i\%2\)\/\
\(\[Sum]\+\(i = \ 1\)\%N\(\( F\_i\%2\)\(\ \)\)\/s\_i\%2\)\)]],
  "; ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[Sigma]\&^\)\_I\)\(\ \)\(=\)\(1\/\@\(\[Sum]\+\
\(i = \ 1\)\%N\(\( F\_i\%2\)\(\ \)\)\/s\_i\%2\)\)\(\ \)\)\)]]
}], "Text"],

Cell[TextData[{
  "The package can also be applied for single response fit problems. If the \
uncertainties of measured is not given  usually is better to apply the \
functions included in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  \nIn this notebook are includes some examples for fitting model using \
the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions and the Fitmodel funtions."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 1", "SubsectionIcon"],

Cell[TextData[{
  "We have the model of the bellow figure. The rate transfer from compartment \
2 to environment is known and its value is ",
  Cell[BoxData[
      \(TraditionalForm\`k\_20\)]],
  "= 0.05 ",
  Cell[BoxData[
      \(TraditionalForm\`d\^\(-1\)\)]],
  ". The transfer coefficients  ",
  Cell[BoxData[
      \(TraditionalForm\`k\_12\)]],
  " and  ",
  Cell[BoxData[
      \(TraditionalForm\`k\_21\)]],
  " are unknown. The experiment consists of an instantaneous injection  ",
  Cell[BoxData[
      \(TraditionalForm\`b\_1\)]],
  "= 1 in compartment 1 and  ",
  Cell[BoxData[
      \(TraditionalForm\`b\_2\)]],
  "= 0.5 in compartment 2 at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  " of the model. I"
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .66667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.12963 0.21164 0.333333 0.21164 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125  moveto 0 0 lineto 
-0.05 -0.0125  lineto stroke
} ifelse
grestore
} def
/MAarrowhead2 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.12963 .65079 m
.12963 .43915 L
s
% Start of user PostScript
0 1.5 0 0.5 MAarrowhead1
% End of user PostScript
gsave
.17196 .54497 -68.3438 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
73.688 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.87037 .65079 m
.87037 .43915 L
s
% Start of user PostScript
3.5 1.5 3.5 0.5 MAarrowhead1
% End of user PostScript
gsave
.9127 .54497 -68.3438 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
73.688 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.12963 .33333 .10582 0 365.73 arc
s
gsave
.12963 .33333 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .41799 -70.4375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23545 .37566 m
.76455 .37566 L
s
% Start of user PostScript
0.5 0.2 3. 0.2 MAarrowhead2
% End of user PostScript
gsave
.5 .24868 -70.4375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.76455 .29101 m
.23545 .29101 L
s
% Start of user PostScript
3. -0.2 0.5 -0.2 MAarrowhead2
% End of user PostScript
newpath
.87037 .33333 .10582 0 365.73 arc
s
.87037 .22751 m
.87037 .01587 L
s
% Start of user PostScript
3.5 -0.5 3.5 -1.5 MAarrowhead2
% End of user PostScript
gsave
.87037 .33333 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.9127 .12169 -70.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 192},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000`2000`400?l00000o`00003oo`3FcjdQ
0=K?[@00o`3FcjdQ0=K?[@00o`3FcjdQ0=K?[@00o`3FcjdQ0=K?[@00o`3FcjdQ0=K?[@00n@3Fcjd0
0`001000e/n]0=K?[@0T0=K?[@00n@3Fcjd00`001000e/n]0=K?[@0T0=K?[@00n03Fcjd3000402D0
e/n]003h0=K?[@<000@09@3Fcjd00?P0e/n]0`00100U0=K?[@00n03Fcjd3000402D0e/n]003g0=K?
[@D000@0903Fcjd00?L0e/n]1@00100T0=K?[@00m`3Fcjd5000402@0e/n]003f0=K?[@L000@08`3F
cjd00?H0e/n]1`00100S0=K?[@00mP3Fcjd7000402<0e/n]003f0=K?[@L000@08`3Fcjd00?D0e/n]
2@00100R0=K?[@00m@3Fcjd900040280e/n]003i0=K?[@030004003Fcjd0e/n]02@0e/n]003i0=K?
[@030004003Fcjd0e/n]02@0e/n]003i0=K?[@030004003Fcjd0e/n]02@0e/n]003i0=K?[@030004
003Fcjd0e/n]02@0e/n]003i0=K?[@030004003Fcjd0e/n]02@0e/n]003i0=K?[@030004003Fcjd0
e/n]02@0e/n]003i0=K?[@030004003Fcjd0e/n]02@0e/n]003i0=K?[@030004003Fcjd0e/n]02@0
e/n]003i0=K?[@030004003Fcjd0e/n]02@0e/n]003i0=K?[@030004003Fcjd0e/n]02@0e/n]003i
0=K?[@030004003Fcjd0e/n]02@0e/n]003i0=K?[@030004003Fcjd0e/n]02@0e/n]003i0=K?[@03
0004003Fcjd0e/n]02@0e/n]003i0=K?[@030004003Fcjd0e/n]02@0e/n]003i0=K?[@030004003F
cjd0e/n]02@0e/n]003i0=K?[@030004003Fcjd0e/n]02@0e/n]003i0=K?[@030004003Fcjd0e/n]
02@0e/n]003i0=K?[@030004003Fcjd0e/n]02@0e/n]003i0=K?[@030004003Fcjd0e/n]02@0e/n]
003i0=K?[@030004003Fcjd0e/n]00T0e/n]0P0010020=K?[@8000@05@3Fcjd00?T0e/n]00<000@0
0=K?[@3Fcjd00P3Fcjd2000400030=K?[@00100000@00080e/n]00@000@00=K?[@3Fcjd0e/n]0P00
100E0=K?[@00n@3Fcjd00`001000e/n]0=K?[@030=K?[@030004003Fcjd000@000@0e/n]00<000@0
0=K?[@3Fcjd00P00100E0=K?[@00n@3Fcjd00`001000e/n]0=K?[@030=K?[@<000@00`3Fcjd20004
0080e/n]0P00100E0=K?[@00n@3Fcjd00`001000e/n]0=K?[@030=K?[@040004003Fcjd000@00004
01d0e/n]003i0=K?[@030004003Fcjd0e/n]00<0e/n]00<000@00=K?[@3Fcjd07P3Fcjd00?T0e/n]
00<000@00=K?[@3Fcjd00P3Fcjd200040200e/n]003i0=K?[@030004003Fcjd0e/n]02@0e/n]003i
0=K?[@030004003Fcjd0e/n]02@0e/n]003i0=K?[@030004003Fcjd0e/n]02@0e/n]003i0=K?[@03
0004003Fcjd0e/n]02@0e/n]003i0=K?[@030004003Fcjd0e/n]02@0e/n]003i0=K?[@030004003F
cjd0e/n]02@0e/n]003i0=K?[@030004003Fcjd0e/n]02@0e/n]003i0=K?[@030004003Fcjd0e/n]
02@0e/n]003i0=K?[@030004003Fcjd0e/n]02@0e/n]003i0=K?[@030004003Fcjd0e/n]02@0e/n]
003i0=K?[@030004003Fcjd0e/n]02@0e/n]003i0=K?[@030004003Fcjd0e/n]02@0e/n]003i0=K?
[@030004003Fcjd0e/n]02@0e/n]003i0=K?[@030004003Fcjd0e/n]02@0e/n]003i0=K?[@030004
003Fcjd0e/n]02@0e/n]003i0=K?[@030004003Fcjd0e/n]02@0e/n]003i0=K?[@030004003Fcjd0
e/n]02@0e/n]003i0=K?[@030004003Fcjd0e/n]02@0e/n]003i0=K?[@030004003Fcjd0e/n]02@0
e/n]003i0=K?[@030004003Fcjd0e/n]02@0e/n]000M0=K?[@l000@0a@3Fcjd?00040200e/n]000J
0=K?[@<000@03`3Fcjd300040<00e/n]0P00100?0=K?[@<000@07@3Fcjd001P0e/n]0P00100E0=K?
[@<000@0^`3Fcjd2000401@0e/n]0`00100J0=K?[@005`3Fcjd00`001000e/n]0=K?[@0H0=K?[@80
00@0F`3Fcjd200040080e/n]0P00101F0=K?[@8000@06@3Fcjd2000401P0e/n]000E0=K?[@8000@0
7@3Fcjd00`001000e/n]0=K?[@1A0=K?[@8000@000<0e/n]0004000010000P3Fcjd00`001000e/n]
0=K?[@020=K?[@030004003Fcjd0e/n]0580e/n]0P00100M0=K?[@8000@05P3Fcjd001<0e/n]0P00
100P0=K?[@8000@0DP3Fcjd00`001000e/n]000400040=K?[@050004003Fcjd0e/n]0=K?[@001000
DP3Fcjd200040240e/n]00<000@00=K?[@3Fcjd04`3Fcjd00180e/n]00<000@00=K?[@3Fcjd08P3F
cjd200040500e/n]0`0010030=K?[@8000@00P3Fcjd200040540e/n]00<000@00=K?[@3Fcjd08P3F
cjd2000401<0e/n]000A0=K?[@030004003Fcjd0e/n]02D0e/n]00<000@00=K?[@3Fcjd0C@3Fcjd0
10001000e/n]00040000101H0=K?[@030004003Fcjd0e/n]02D0e/n]00<000@00=K?[@3Fcjd0403F
cjd00100e/n]00<000@00=K?[@3Fcjd09`3Fcjd00`001000e/n]0=K?[@1<0=K?[@030004003Fcjd0
e/n]05P0e/n]00<000@00=K?[@3Fcjd09`3Fcjd00`001000e/n]0=K?[@0?0=K?[@003`3Fcjd00`00
1000e/n]0=K?[@0Y0=K?[@030004003Fcjd0e/n]04X0e/n]0P00101I0=K?[@030004003Fcjd0e/n]
02T0e/n]00<000@00=K?[@3Fcjd03P3Fcjd000h0e/n]00<000@00=K?[@3Fcjd0:P3Fcjd00`001000
e/n]0=K?[@2T0=K?[@030004003Fcjd0e/n]02X0e/n]00<000@00=K?[@3Fcjd03P3Fcjd000h0e/n]
00<000@00=K?[@3Fcjd0:`3Fcjd00`001000e/n]0=K?[@2S0=K?[@030004003Fcjd0e/n]02/0e/n]
00<000@00=K?[@3Fcjd03@3Fcjd000d0e/n]00<000@00=K?[@3Fcjd0;@3Fcjd00`001000e/n]0=K?
[@2Q0=K?[@030004003Fcjd0e/n]02d0e/n]00<000@00=K?[@3Fcjd0303Fcjd000`0e/n]00<000@0
0=K?[@3Fcjd0;`3Fcjd00`001000e/n]0=K?[@2O0=K?[@030004003Fcjd0e/n]02l0e/n]00<000@0
0=K?[@3Fcjd02`3Fcjd000/0e/n]00<000@00=K?[@3Fcjd0<@3Fcjd00`001000e/n]0=K?[@0?0=K?
[@8000@0S03Fcjd00`001000e/n]0=K?[@0a0=K?[@030004003Fcjd0e/n]00X0e/n]000;0=K?[@03
0004003Fcjd0e/n]0340e/n]00<000@00=K?[@3Fcjd02`3Fcjd6000408`0e/n]00<000@00=K?[@3F
cjd0<@3Fcjd00`001000e/n]0=K?[@0:0=K?[@002P3Fcjd00`001000e/n]0=K?[@0c0=K?[@030004
003Fcjd0e/n]00H0e/n]2P00102;0=K?[@030004003Fcjd0e/n]03<0e/n]00<000@00=K?[@3Fcjd0
2@3Fcjd000X0e/n]00<000@00=K?[@3Fcjd0<`3Fcjd00`001000e/n]0=K?[@020=K?[@h000@0R`3F
cjd00`001000e/n]0=K?[@0c0=K?[@030004003Fcjd0e/n]00T0e/n]00090=K?[@030004003Fcjd0
e/n]03D0e/n]00<000@00=K?[@001000V00010020=K?[@030004003Fcjd0e/n]03@0e/n]00<000@0
0=K?[@3Fcjd0203Fcjd000T0e/n]00<000@00=K?[@3Fcjd0=@3Fcjd00`001000e/n]0=K?[@020=K?
[@d000@0RP3Fcjd00`001000e/n]0=K?[@0e0=K?[@030004003Fcjd0e/n]00P0e/n]00080=K?[@03
0004003Fcjd0e/n]03L0e/n]00<000@00=K?[@3Fcjd01P3Fcjd8000408X0e/n]00<000@00=K?[@3F
cjd0=P3Fcjd00`001000e/n]0=K?[@070=K?[@00203Fcjd00`001000e/n]0=K?[@0g0=K?[@030004
003Fcjd0e/n]00/0e/n]0`00102:0=K?[@030004003Fcjd0e/n]03H0e/n]00<000@00=K?[@3Fcjd0
1`3Fcjd000P0e/n]00<000@00=K?[@3Fcjd0=`3Fcjd00`001000e/n]0=K?[@2G0=K?[@030004003F
cjd0e/n]03L0e/n]00<000@00=K?[@3Fcjd01`3Fcjd000P0e/n]00<000@00=K?[@3Fcjd0>03Fcjd0
0`001000e/n]0=K?[@2F0=K?[@030004003Fcjd0e/n]03P0e/n]00<000@00=K?[@3Fcjd01P3Fcjd0
00L0e/n]00<000@00=K?[@3Fcjd0>@3Fcjd00`001000e/n]0=K?[@2E0=K?[@030004003Fcjd0e/n]
03T0e/n]00<000@00=K?[@3Fcjd01P3Fcjd000L0e/n]00<000@00=K?[@3Fcjd0>@3Fcjd00`001000
e/n]0=K?[@2E0=K?[@030004003Fcjd0e/n]03T0e/n]00<000@00=K?[@3Fcjd01P3Fcjd000L0e/n]
00<000@00=K?[@3Fcjd0>@3Fcjd00`001000e/n]0=K?[@2E0=K?[@030004003Fcjd0e/n]03T0e/n]
00<000@00=K?[@3Fcjd01P3Fcjd000L0e/n]00<000@00=K?[@3Fcjd0>@3Fcjd00`001000e/n]0=K?
[@2E0=K?[@030004003Fcjd0e/n]03T0e/n]00<000@00=K?[@3Fcjd01P3Fcjd000L0e/n]00<000@0
0=K?[@3Fcjd06@3Fcjd5000401/0e/n]00<000@00=K?[@3Fcjd0U@3Fcjd00`001000e/n]0=K?[@0I
0=K?[@@000@0703Fcjd00`001000e/n]0=K?[@060=K?[@001`3Fcjd00`001000e/n]0=K?[@0K0=K?
[@030004003Fcjd0e/n]01/0e/n]00<000@00=K?[@3Fcjd0U@3Fcjd00`001000e/n]0=K?[@0I0=K?
[@030004003Fcjd0e/n]01d0e/n]00<000@00=K?[@3Fcjd01P3Fcjd000L0e/n]00<000@00=K?[@3F
cjd06`3Fcjd00`001000e/n]0=K?[@0K0=K?[@030004003Fcjd0e/n]09D0e/n]00<000@00=K?[@3F
cjd06P3Fcjd00`001000e/n]0=K?[@0L0=K?[@030004003Fcjd0e/n]00H0e/n]00070=K?[@030004
003Fcjd0e/n]01/0e/n]00<000@00=K?[@3Fcjd06`3Fcjd00`001000e/n]0=K?[@2E0=K?[@030004
003Fcjd0e/n]01/0e/n]00<000@00=K?[@3Fcjd06`3Fcjd00`001000e/n]0=K?[@060=K?[@001`3F
cjd00`001000e/n]0=K?[@0K0=K?[@030004003Fcjd0e/n]01/0e/n]00<000@00=K?[@3Fcjd0U@3F
cjd00`001000e/n]0=K?[@0I0=K?[@040004003Fcjd0e/n]000401`0e/n]00<000@00=K?[@3Fcjd0
1P3Fcjd000L0e/n]00<000@00=K?[@3Fcjd06P3Fcjd2000401d0e/n]00<000@00=K?[@3Fcjd0U@3F
cjd00`001000e/n]0=K?[@0J0=K?[@8000@07@3Fcjd00`001000e/n]0=K?[@060=K?[@001`3Fcjd0
0`001000e/n]0=K?[@0i0=K?[@030004003Fcjd0e/n]09D0e/n]00<000@00=K?[@3Fcjd0>@3Fcjd0
0`001000e/n]0=K?[@060=K?[@001`3Fcjd00`001000e/n]0=K?[@0i0=K?[@030004003Fcjd0e/n]
09D0e/n]00<000@00=K?[@3Fcjd0>@3Fcjd00`001000e/n]0=K?[@060=K?[@001`3Fcjd00`001000
e/n]0=K?[@0i0=K?[@030004003Fcjd0e/n]09D0e/n]00<000@00=K?[@3Fcjd0>@3Fcjd00`001000
e/n]0=K?[@060=K?[@00203Fcjd00`001000e/n]0=K?[@0h0=K?[@030004003Fcjd0e/n]09H0e/n]
00<000@00=K?[@3Fcjd0>03Fcjd00`001000e/n]0=K?[@060=K?[@00203Fcjd00`001000e/n]0=K?
[@0g0=K?[@030004003Fcjd0e/n]09L0e/n]00<000@00=K?[@3Fcjd0=`3Fcjd00`001000e/n]0=K?
[@070=K?[@00203Fcjd00`001000e/n]0=K?[@0g0=K?[@030004003Fcjd0e/n]08L0e/n]0`00100>
0=K?[@030004003Fcjd0e/n]03H0e/n]00<000@00=K?[@3Fcjd01`3Fcjd000P0e/n]00<000@00=K?
[@3Fcjd0=`3Fcjd00`001000e/n]0=K?[@270=K?[@P000@02@3Fcjd00`001000e/n]0=K?[@0f0=K?
[@030004003Fcjd0e/n]00L0e/n]00090=K?[@030004003Fcjd0e/n]03D0e/n]00<000@00=K?[@3F
cjd0R03Fcjd=000400@0e/n]00<000@00=K?[@3Fcjd0=@3Fcjd00`001000e/n]0=K?[@080=K?[@00
2@3Fcjd00`001000e/n]0=K?[@0e0=K?[@030004003Fcjd000@009P000@00P3Fcjd00`001000e/n]
0=K?[@0d0=K?[@030004003Fcjd0e/n]00P0e/n]000:0=K?[@030004003Fcjd0e/n]03<0e/n]00<0
00@00=K?[@3Fcjd0R@3Fcjd>000400@0e/n]00<000@00=K?[@3Fcjd0<`3Fcjd00`001000e/n]0=K?
[@090=K?[@002P3Fcjd00`001000e/n]0=K?[@0c0=K?[@030004003Fcjd0e/n]08T0e/n]2P001008
0=K?[@030004003Fcjd0e/n]03<0e/n]00<000@00=K?[@3Fcjd02@3Fcjd000/0e/n]00<000@00=K?
[@3Fcjd0<@3Fcjd00`001000e/n]0=K?[@2:0=K?[@H000@03@3Fcjd00`001000e/n]0=K?[@0a0=K?
[@030004003Fcjd0e/n]00X0e/n]000;0=K?[@030004003Fcjd0e/n]0340e/n]00<000@00=K?[@3F
cjd0RP3Fcjd200040140e/n]00<000@00=K?[@3Fcjd0<@3Fcjd00`001000e/n]0=K?[@0:0=K?[@00
303Fcjd00`001000e/n]0=K?[@0_0=K?[@030004003Fcjd0e/n]09l0e/n]00<000@00=K?[@3Fcjd0
;`3Fcjd00`001000e/n]0=K?[@0;0=K?[@003@3Fcjd00`001000e/n]0=K?[@0]0=K?[@030004003F
cjd0e/n]0:40e/n]00<000@00=K?[@3Fcjd0;@3Fcjd00`001000e/n]0=K?[@0<0=K?[@003P3Fcjd0
0`001000e/n]0=K?[@0[0=K?[@030004003Fcjd0e/n]0:<0e/n]00<000@00=K?[@3Fcjd0:`3Fcjd0
0`001000e/n]0=K?[@0=0=K?[@003P3Fcjd00`001000e/n]0=K?[@0Z0=K?[@030004003Fcjd0e/n]
0:@0e/n]00<000@00=K?[@3Fcjd0:P3Fcjd00`001000e/n]0=K?[@0>0=K?[@003`3Fcjd00`001000
e/n]0=K?[@0Y0=K?[@030004003Fcjd0e/n]0540e/n]0P0010020=K?[@8000@0CP3Fcjd00`001000
e/n]0=K?[@0Y0=K?[@030004003Fcjd0e/n]00h0e/n]000@0=K?[@030004003Fcjd0e/n]02L0e/n]
00<000@00=K?[@3Fcjd0D`3Fcjd010001000e/n]0=K?[@00101@0=K?[@030004003Fcjd0e/n]02L0
e/n]00<000@00=K?[@3Fcjd03`3Fcjd00140e/n]00<000@00=K?[@3Fcjd09@3Fcjd00`001000e/n]
0=K?[@1<0=K?[@8000@000<0e/n]0004000010000`3Fcjd01@001000e/n]0=K?[@3Fcjd000@00500
e/n]00<000@00=K?[@3Fcjd09@3Fcjd00`001000e/n]0=K?[@0@0=K?[@004P3Fcjd00`001000e/n]
0=K?[@0R0=K?[@8000@0D03Fcjd00`001000e/n]000400030=K?[@8000@00P3Fcjd200040540e/n]
00<000@00=K?[@3Fcjd08`3Fcjd00`001000e/n]0=K?[@0A0=K?[@004`3Fcjd200040200e/n]0P00
101B0=K?[@<000@0F`3Fcjd200040240e/n]0P00100D0=K?[@005@3Fcjd2000401d0e/n]00<000@0
0=K?[@3Fcjd0DP3Fcjd010001000e/n]00040000101L0=K?[@8000@07@3Fcjd2000401H0e/n]000G
0=K?[@030004003Fcjd0e/n]01P0e/n]0P00101E0=K?[@030004003Fcjd0e/n]05l0e/n]0P00100I
0=K?[@8000@0603Fcjd001P0e/n]0P00100E0=K?[@<000@0EP3Fcjd2000406<0e/n]00<000@00=K?
[@3Fcjd04`3Fcjd3000401X0e/n]000J0=K?[@<000@03`3Fcjd300040;l0e/n]0`00100?0=K?[@<0
00@07@3Fcjd001d0e/n]3`0010350=K?[@l000@0803Fcjd002D0e/n]00<000@00=K?[@3Fcjd0d@3F
cjd00`001000e/n]0=K?[@0T0=K?[@00903Fcjd200040=80e/n]0`00100U0=K?[@00903Fcjd30004
0=40e/n]0`00100U0=K?[@00903Fcjd300040=40e/n]0`00100U0=K?[@00903Fcjd300040=40e/n]
0`00100U0=K?[@008`3Fcjd010001000e/n]00040000103@0=K?[@050004003Fcjd000@00=K?[@00
1000903Fcjd002<0e/n]00@000@00=K?[@00100000@0d03Fcjd01@001000e/n]0004003Fcjd000@0
02@0e/n]000S0=K?[@050004003Fcjd000@00=K?[@001000c`3Fcjd01@001000e/n]0004003Fcjd0
00@002@0e/n]000S0=K?[@050004003Fcjd000@00=K?[@001000c`3Fcjd01@001000e/n]0004003F
cjd000@002@0e/n]000R0=K?[@060004003Fcjd0e/n]0004003Fcjd000@0cP3Fcjd010001000e/n]
0=K?[@0010020=K?[@030004003Fcjd0e/n]0240e/n]000R0=K?[@060004003Fcjd0e/n]0004003F
cjd000@0cP3Fcjd010001000e/n]0=K?[@0010020=K?[@030004003Fcjd0e/n]0240e/n]000R0=K?
[@060004003Fcjd0e/n]0004003Fcjd000@0cP3Fcjd010001000e/n]0=K?[@0010020=K?[@030004
003Fcjd0e/n]0240e/n]000R0=K?[@040004003Fcjd0e/n]00040080e/n]00<000@00=K?[@3Fcjd0
b`3Fcjd010001000e/n]0=K?[@0010020=K?[@030004003Fcjd0e/n]0240e/n]000Q0=K?[@050004
003Fcjd0e/n]0=K?[@0010000P3Fcjd00`001000e/n]0=K?[@3:0=K?[@050004003Fcjd0e/n]0=K?
[@0010000`3Fcjd00`001000e/n]0=K?[@0P0=K?[@008@3Fcjd01@001000e/n]0=K?[@3Fcjd000@0
0080e/n]00<000@00=K?[@3Fcjd0bP3Fcjd01@001000e/n]0=K?[@3Fcjd000@000<0e/n]00<000@0
0=K?[@3Fcjd0803Fcjd002D0e/n]00<000@00=K?[@3Fcjd0d@3Fcjd00`001000e/n]0=K?[@0T0=K?
[@009@3Fcjd00`001000e/n]0=K?[@3A0=K?[@030004003Fcjd0e/n]02@0e/n]000U0=K?[@030004
003Fcjd0e/n]0=40e/n]00<000@00=K?[@3Fcjd0903Fcjd002D0e/n]00<000@00=K?[@3Fcjd0d@3F
cjd00`001000e/n]0=K?[@0T0=K?[@009@3Fcjd00`001000e/n]0=K?[@3A0=K?[@030004003Fcjd0
e/n]02@0e/n]000U0=K?[@030004003Fcjd0e/n]0=40e/n]00<000@00=K?[@3Fcjd0903Fcjd002D0
e/n]00<000@00=K?[@3Fcjd0d@3Fcjd00`001000e/n]0=K?[@0T0=K?[@009@3Fcjd00`001000e/n]
0=K?[@3A0=K?[@030004003Fcjd0e/n]02@0e/n]000U0=K?[@030004003Fcjd0e/n]0=40e/n]00<0
00@00=K?[@3Fcjd0903Fcjd002D0e/n]00<000@00=K?[@3Fcjd0d@3Fcjd00`001000e/n]0=K?[@0T
0=K?[@009@3Fcjd00`001000e/n]0=K?[@3A0=K?[@030004003Fcjd0e/n]02@0e/n]000U0=K?[@03
0004003Fcjd0e/n]0=40e/n]00<000@00=K?[@3Fcjd0903Fcjd002D0e/n]00<000@00=K?[@3Fcjd0
2`3Fcjd200040<@0e/n]00<000@00=K?[@3Fcjd02`3Fcjd2000401L0e/n]000U0=K?[@030004003F
cjd0e/n]00@0e/n]100010040=K?[@030004003Fcjd0e/n]0<80e/n]00<000@00=K?[@3Fcjd0103F
cjd4000400<0e/n]00<000@00=K?[@3Fcjd05P3Fcjd002D0e/n]00<000@00=K?[@3Fcjd01@3Fcjd0
10001000e/n]0=K?[@0010030=K?[@030004003Fcjd0e/n]0<80e/n]00<000@00=K?[@3Fcjd01@3F
cjd010001000e/n]0=K?[@0010030=K?[@030004003Fcjd0e/n]01D0e/n]000U0=K?[@030004003F
cjd0e/n]00D0e/n]00@000@00=K?[@3Fcjd000@00P3Fcjd200040<@0e/n]00<000@00=K?[@3Fcjd0
1@3Fcjd010001000e/n]0=K?[@0010020=K?[@8000@05`3Fcjd002D0e/n]00<000@00=K?[@3Fcjd0
1@3Fcjd300040<T0e/n]00<000@00=K?[@3Fcjd01@3Fcjd3000401`0e/n]000U0=K?[@030004003F
cjd0e/n]00D0e/n]00<000@00=K?[@3Fcjd0b@3Fcjd00`001000e/n]0=K?[@050=K?[@030004003F
cjd0e/n]01`0e/n]000U0=K?[@030004003Fcjd0e/n]00@0e/n]0P00103;0=K?[@030004003Fcjd0
e/n]00@0e/n]0P00100N0=K?[@009@3Fcjd00`001000e/n]0=K?[@3A0=K?[@030004003Fcjd0e/n]
02@0e/n]000U0=K?[@030004003Fcjd0e/n]0=40e/n]00<000@00=K?[@3Fcjd0903Fcjd002D0e/n]
00<000@00=K?[@3Fcjd0d@3Fcjd00`001000e/n]0=K?[@0T0=K?[@009@3Fcjd00`001000e/n]0=K?
[@3A0=K?[@030004003Fcjd0e/n]02@0e/n]000U0=K?[@030004003Fcjd0e/n]0=40e/n]00<000@0
0=K?[@3Fcjd0903Fcjd002D0e/n]00<000@00=K?[@3Fcjd0d@3Fcjd00`001000e/n]0=K?[@0T0=K?
[@009@3Fcjd00`001000e/n]0=K?[@3A0=K?[@030004003Fcjd0e/n]02@0e/n]000U0=K?[@030004
003Fcjd0e/n]0=40e/n]00<000@00=K?[@3Fcjd0903Fcjd002D0e/n]00<000@00=K?[@3Fcjd0d@3F
cjd00`001000e/n]0=K?[@0T0=K?[@009@3Fcjd00`001000e/n]0=K?[@3A0=K?[@030004003Fcjd0
e/n]02@0e/n]000U0=K?[@030004003Fcjd0e/n]0=40e/n]00<000@00=K?[@3Fcjd0903Fcjd002D0
e/n]00<000@00=K?[@3Fcjd0d@3Fcjd00`001000e/n]0=K?[@0T0=K?[@009@3Fcjd00`001000e/n]
0=K?[@3A0=K?[@030004003Fcjd0e/n]02@0e/n]000U0=K?[@030004003Fcjd0e/n]0=40e/n]00<0
00@00=K?[@3Fcjd0903Fcjd002D0e/n]00<000@00=K?[@3Fcjd0d@3Fcjd00`001000e/n]0=K?[@0T
0=K?[@009@3Fcjd00`001000e/n]0=K?[@3A0=K?[@030004003Fcjd0e/n]02@0e/n]000U0=K?[@03
0004003Fcjd0e/n]0=40e/n]00<000@00=K?[@3Fcjd0903Fcjd002D0e/n]00<000@00=K?[@3Fcjd0
d@3Fcjd00`001000e/n]0=K?[@0T0=K?[@009@3Fcjd00`001000e/n]0=K?[@3A0=K?[@030004003F
cjd0e/n]02@0e/n]000U0=K?[@030004003Fcjd0e/n]0=40e/n]00<000@00=K?[@3Fcjd0903Fcjd0
02D0e/n]00<000@00=K?[@3Fcjd0d@3Fcjd00`001000e/n]0=K?[@0T0=K?[@009@3Fcjd00`001000
e/n]0=K?[@3A0=K?[@030004003Fcjd0e/n]02@0e/n]000U0=K?[@030004003Fcjd0e/n]0=40e/n]
00<000@00=K?[@3Fcjd0903Fcjd002D0e/n]00<000@00=K?[@3Fcjd0d@3Fcjd00`001000e/n]0=K?
[@0T0=K?[@009@3Fcjd00`001000e/n]0=K?[@3A0=K?[@030004003Fcjd0e/n]02@0e/n]000U0=K?
[@030004003Fcjd0e/n]0=40e/n]00<000@00=K?[@3Fcjd0903Fcjd002D0e/n]00<000@00=K?[@3F
cjd0d@3Fcjd00`001000e/n]0=K?[@0T0=K?[@00o`3FcjdQ0=K?[@00o`3FcjdQ0=K?[@00o`3FcjdQ
0=K?[@00o`3FcjdQ0=K?[@00\
\>"],
  ImageRangeCache->{{{137.875, 424.875}, {415.375, 224.375}} -> {-2.89055, \
2.12547, 0.0164924, 0.0164924}}],

Cell[TextData[{
  "It supposed that in ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  " the amount of substance in all compartment is \"0\". The amount in \
compartment 2 in different times (in days) was measured. Here are the data ",
  Cell[BoxData[
      \(TraditionalForm\`{t, \ x}\)]],
  " (These data are been obtained by simulation)"
}], "Text"],

Cell[BoxData[
    \(list1 = {{0, 0.5}, {10, 0.30}, {20, 0.26}, {30, 0.24}, {40, 0.21}, {50, 
          0.19}, {60, 0.17}, {70, 0.15}, {80, 0.135}, {90, 0.12}, {100, 
          0.11}}; \)], "Input",
  CellLabel->"In[7]:="],

Cell[TextData[{
  "We intend to estimate the parameters ",
  Cell[BoxData[
      \(TraditionalForm\`k\_12\)]],
  " and  ",
  Cell[BoxData[
      \(TraditionalForm\`k\_21\)]],
  " by adjusting our model to the experimental data given in list1. We will \
proceed as follows"
}], "Text"],

Cell["\<\
Step 1:  The compartmental matrix of the model is defined as a function of \
parameters to be fitted\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(modelTwoCompart = \ 
      CompartMatrix[2, {{1, 2, k12}, {2, 1, k21}, {2, 0, 0.05}}]\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \({{\(-k12\), k21}, {k12, \(-0.05`\) - k21}}\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell[TextData[{
  "Step 2: The model is built by choosing the function of retention in \
compartment 2. In this case, how is a single-impulsive input,",
  Cell[BoxData[
      ButtonBox[
        RowBox[{" ", 
          StyleBox["AcuteInput",
            FontColor->RGBColor[0, 0, 1],
            FontVariations->{"Underline"->True}]}],
        ButtonFunction:>(Internal`PutInformation[ #, LongForm -> False]&),
        ButtonData:>{"Info3227552928-2607283", 
          "Biokmod`SysModelLite`AcuteInput"},
        ButtonFrame->"None",
        ButtonNote->"Biokmod`SysModelLite`"]],
    CellMargins->{{20, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
    Background->GrayLevel[0.930022],
    ButtonBoxOptions->{Active->True}],
  "  is used."
}], "Text"],

Cell[BoxData[
    \(x2[t_, k12_, k21_] = 
      x\_2[t] /. AcuteInput[modelTwoCompart, {1, 0.5}, t, x]; \)], "Input",
  CellLabel->"In[9]:="],

Cell[TextData[{
  "Step 3: Now it is fitted the coefficients  ",
  Cell[BoxData[
      \(TraditionalForm\`k\_12\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\_21\)]],
  " with the experimental dada. Because ",
  StyleBox["x2[t,k12,k21]", "Input"],
  " is an analytic expression ",
  StyleBox[ButtonBox["NonlinearRegress"],
    ButtonBoxOptions -> {DefaultStyle -> "AddOnsLink"}],
  " can used."
}], "Text"],

Cell[TextData[{
  "We will need the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package ",
  StyleBox[ButtonBox["NonlinearFit"],
    ButtonBoxOptions -> {DefaultStyle -> "AddOnsLink"}],
  ". "
}], "Text"],

Cell[BoxData[
    \(Needs["\<Statistics`NonlinearFit`\>"]\)], "Input",
  CellLabel->"In[10]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(NonlinearRegress[list1, 
      x2[t, k12, k21], {t}, {{k12, 0, 0.5}, {k21, 1, 5}}]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(BestFitParameters \[Rule] {k12 \[Rule] 0.08109694414299105`, 
            k21 \[Rule] 0.24315547701062384`}\), ",", 
        RowBox[{"ParameterCITable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"Asymptotic SE\"\>", "\<\
\"CI\"\>"},
                {"k12", "0.08109694414299105`", 
                  "0.012226768406987994`", \({0.05343807241324837`, 
                    0.10875581587273374`}\)},
                {"k21", "0.24315547701062384`", 
                  "0.042271101794143645`", \({0.14753160130762977`, 
                    0.3387793527136179`}\)}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            Function[ BoxForm`e$, 
              TableForm[ 
              BoxForm`e$, TableDepth -> 2, TableHeadings -> {{k12, k21}, {
                "Estimate", "Asymptotic SE", "CI"}}]]]}], 
        ",", \(EstimatedVariance \[Rule] 4.667792926775219`*^-6\), ",", 
        RowBox[{"ANOVATable", "\[Rule]", 
          InterpretationBox[GridBox[{
                {"\<\"\"\>", "\<\"DF\"\>", "\<\"SumOfSq\"\>", \
"\<\"MeanSq\"\>"},
                {"\<\"Model\"\>", "2", "0.6414829898636589`", 
                  "0.32074149493182946`"},
                {"\<\"Error\"\>", "9", "0.00004201013634097697`", 
                  "4.667792926775219`*^-6"},
                {"\<\"Uncorrected Total\"\>", "11", 
                  "0.6415249999999999`", "\<\"\"\>"},
                {"\<\"Corrected Total\"\>", "10", 
                  "0.12441363636363637`", "\<\"\"\>"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            
            TableForm[ {{2, .64148298986365893, .32074149493182946}, {
              9, .000042010136340976973, .46677929267752194*^-5}, {
              11, .6415249999999999}, {10, .12441363636363637}}, 
              TableHeadings -> {{"Model", "Error", "Uncorrected Total", 
              "Corrected Total"}, {"DF", "SumOfSq", "MeanSq"}}]]}], ",", 
        RowBox[{"AsymptoticCorrelationMatrix", "\[Rule]", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1.`", "0.9990570837505811`"},
                  {"0.9990570837505812`", "1.`"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]]}], ",", 
        RowBox[{"FitCurvatureTable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Curvature\"\>"},
                {"\<\"Max Intrinsic\"\>", "0.07262789001008822`"},
                {"\<\"Max Parameter-Effects\"\>", "0.7722899133073851`"},
                {"\<\"95. % Confidence Region\"\>", "0.4847010382866134`"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            Function[ BoxForm`e$, 
              TableForm[ 
              BoxForm`e$, TableDepth -> 2, TableHeadings -> {{"Max Intrinsic",
                 "Max Parameter-Effects", "95. % Confidence Region"}, {
                "Curvature"}}]]]}]}], "}"}]], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell["\<\
Here the fitted function and the experimental data are shown:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[x2[t, 0.081, 0.2431], \ {t, 0, 100}, \ 
      Epilog \[Rule] \ {Hue[0], \ PointSize[0.02], 
          Map[Point, \ list1]}]\)], "Input",
  CellLabel->"In[12]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 -0.147376 1.50139 [
[.21429 -0.00974 -6 -9 ]
[.21429 -0.00974 6 0 ]
[.40476 -0.00974 -6 -9 ]
[.40476 -0.00974 6 0 ]
[.59524 -0.00974 -6 -9 ]
[.59524 -0.00974 6 0 ]
[.78571 -0.00974 -6 -9 ]
[.78571 -0.00974 6 0 ]
[.97619 -0.00974 -9 -9 ]
[.97619 -0.00974 9 0 ]
[.01131 .1529 -18 -4.5 ]
[.01131 .1529 0 4.5 ]
[.01131 .30304 -18 -4.5 ]
[.01131 .30304 0 4.5 ]
[.01131 .45318 -18 -4.5 ]
[.01131 .45318 0 4.5 ]
[.01131 .60332 -18 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .00276 m
.21429 .00901 L
s
[(20)] .21429 -0.00974 0 1 Mshowa
.40476 .00276 m
.40476 .00901 L
s
[(40)] .40476 -0.00974 0 1 Mshowa
.59524 .00276 m
.59524 .00901 L
s
[(60)] .59524 -0.00974 0 1 Mshowa
.78571 .00276 m
.78571 .00901 L
s
[(80)] .78571 -0.00974 0 1 Mshowa
.97619 .00276 m
.97619 .00901 L
s
[(100)] .97619 -0.00974 0 1 Mshowa
.125 Mabswid
.07143 .00276 m
.07143 .00651 L
s
.11905 .00276 m
.11905 .00651 L
s
.16667 .00276 m
.16667 .00651 L
s
.2619 .00276 m
.2619 .00651 L
s
.30952 .00276 m
.30952 .00651 L
s
.35714 .00276 m
.35714 .00651 L
s
.45238 .00276 m
.45238 .00651 L
s
.5 .00276 m
.5 .00651 L
s
.54762 .00276 m
.54762 .00651 L
s
.64286 .00276 m
.64286 .00651 L
s
.69048 .00276 m
.69048 .00651 L
s
.7381 .00276 m
.7381 .00651 L
s
.83333 .00276 m
.83333 .00651 L
s
.88095 .00276 m
.88095 .00651 L
s
.92857 .00276 m
.92857 .00651 L
s
.25 Mabswid
0 .00276 m
1 .00276 L
s
.02381 .1529 m
.03006 .1529 L
s
[(0.2)] .01131 .1529 1 0 Mshowa
.02381 .30304 m
.03006 .30304 L
s
[(0.3)] .01131 .30304 1 0 Mshowa
.02381 .45318 m
.03006 .45318 L
s
[(0.4)] .01131 .45318 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(0.5)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .03279 m
.02756 .03279 L
s
.02381 .06282 m
.02756 .06282 L
s
.02381 .09285 m
.02756 .09285 L
s
.02381 .12287 m
.02756 .12287 L
s
.02381 .18293 m
.02756 .18293 L
s
.02381 .21296 m
.02756 .21296 L
s
.02381 .24299 m
.02756 .24299 L
s
.02381 .27301 m
.02756 .27301 L
s
.02381 .33307 m
.02756 .33307 L
s
.02381 .3631 m
.02756 .3631 L
s
.02381 .39312 m
.02756 .39312 L
s
.02381 .42315 m
.02756 .42315 L
s
.02381 .48321 m
.02756 .48321 L
s
.02381 .51324 m
.02756 .51324 L
s
.02381 .54326 m
.02756 .54326 L
s
.02381 .57329 m
.02756 .57329 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.03279 .52399 L
.04262 .46158 L
.05288 .41533 L
.06244 .38418 L
.0731 .35871 L
.0828 .34135 L
.094 .32595 L
.10458 .31448 L
.12455 .29779 L
.14299 .28561 L
.18234 .26411 L
.22018 .24583 L
.26047 .22759 L
.29924 .21091 L
.34046 .19401 L
.38017 .17849 L
.41837 .16423 L
.45901 .14974 L
.49814 .13643 L
.53972 .12293 L
.57979 .11053 L
.61834 .09914 L
.65934 .08758 L
.69883 .07696 L
.7368 .0672 L
.77723 .05727 L
.81613 .04815 L
.8575 .0389 L
.89734 .0304 L
.93567 .0226 L
.97619 .01472 L
s
1 0 0 r
.02 w
.02381 .60332 Mdot
.11905 .30304 Mdot
.21429 .24299 Mdot
.30952 .21296 Mdot
.40476 .16792 Mdot
.5 .13789 Mdot
.59524 .10786 Mdot
.69048 .07783 Mdot
.78571 .05531 Mdot
.88095 .03279 Mdot
.97619 .01778 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[12]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00IP3oool6000000@0oooo100000100?ooo`@00000103oool400000400oooo100000040?oo
o`@00000@03oool4000000D0oooo1000000j0?ooo`L000000`3oool4000000D0oooo100000060?oo
o`00IP3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`00I`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool006P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03/0oooo1P0000030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0?03oool2000000<0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`030?ooo`00J@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0?03oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0?03oool00`000000oooo00000002000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0m0?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`00JP3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?03oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool00`3oool006H0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo000000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool00`3oool006H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo000000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0h0?ooo`<000001@3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`00
I`3oool4000000D0oooo100000110?ooo`8000001@3oool400000480oooo0`0000030?ooo`@00000
@03oool4000000D0oooo1000000m0?ooo`030000003oool0oooo00@0oooo100000050?ooo`@00000
1P3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00240oooo00<000000?ooo`3oool0o`3ooon=0?oo
o`00603ooooo000009<000001P3oool00240oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00h0oooo000Q0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0>0?ooo`008@3oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo04T0oooo0P3o000?0?ooo`008@3oool00`000000oooo0?ooo`3o0?oo
ogX0oooo1P3o000=0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooogX0oooo1P3o000=0?ooo`00
8@3oool00`000000oooo0?ooo`3o0?ooogD0oooo100000080?l000`0oooo000Q0?ooo`030000003o
ool0oooo0?l0ooooK`3oool6000000@0oooo203o000<0?ooo`008@3oool00`000000oooo0?ooo`3o
0?ooofX0oooo1@00000;0?ooo`H0o`003@3oool00240oooo00<000000?ooo`3oool0o`3ooomE0?oo
o`80o`003P3oool500000100oooo1P3o000=0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooe<0
oooo1P3o00060?ooo`H000005`3oool20?l000l0oooo000Q0?ooo`030000003oool0oooo0?l0oooo
D`3oool60?l00080oooo1000000^0?ooo`008@3oool300000?l0ooooDP3oool80?l000030000003o
ool0oooo0300oooo000Q0?ooo`030000003oool0oooo0?l0ooooDP3oool80?l003<0oooo000Q0?oo
o`030000003oool0oooo0?l0ooooC`3oool4000000H0o`00=03oool00240oooo00<000000?ooo`3o
ool0o`3ooom:0?ooo`D00000103oool60?l003@0oooo000Q0?ooo`030000003oool0oooo0?l0oooo
A@3oool5000000/0oooo0P3o000f0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooocl0oooo1P00
00180?ooo`008@3oool00`000000oooo0?ooo`3o0?ooobl0oooo0P3o000:0?ooo`@00000CP3oool0
0240oooo00<000000?ooo`3oool0o`3oool]0?ooo`H0o`00103oool400000580oooo000Q0?ooo`03
0000003oool0oooo0?l0oooo;@3oool60?l000@00000EP3oool00240oooo00<000000?ooo`3oool0
o`3oool/0?ooo`P0o`00F@3oool00240oooo00<000000?ooo`3oool0o`3oool[0?ooo`030000003o
0000o`0000H0o`00F@3oool00240oooo00<000000?ooo`3oool0o`3ooolW0?ooo`@000000P3oool6
0?l005X0oooo000Q0?ooo`<00000o`3ooolS0?ooo`@000001P3oool60?l005X0oooo000Q0?ooo`03
0000003oool0oooo0?l0oooo7`3oool4000000`0oooo0P3o001L0?ooo`008@3oool00`000000oooo
0?ooo`3o0?oooa/0oooo1000001^0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo0P3o
000<0?ooo`@00000LP3oool00240oooo00<000000?ooo`3oool0o`3oool70?ooo`H0o`001P3oool4
000007H0oooo000Q0?ooo`030000003oool0oooo0?l0oooo1`3oool60?l00080oooo1000001j0?oo
o`008@3oool00`000000oooo0?ooo`3o0?ooo`H0oooo203o00000`000000oooo0?ooo`1l0?ooo`00
8@3oool00`000000oooo0?ooo`3o0?ooo`H0oooo203o001o0?ooo`008@3oool00`000000oooo0?oo
o`3o0?ooo`@0oooo0`0000060?l00800oooo000Q0?ooo`030000003oool0oooo0?l0oooo10000003
0?ooo`H0o`00P03oool00240oooo00<000000?ooo`3oool0n`3oool4000000T0oooo0P3o00220?oo
o`008@3oool00`000000oooo0?ooo`3h0?ooo`<00000T@3oool00240oooo0`00003e0?ooo`<00000
U03oool00240oooo00<000000?ooo`3oool0l@3oool4000009L0oooo000Q0?ooo`030000003oool0
oooo0>h0oooo0`00002K0?ooo`008@3oool00`000000oooo0?ooo`3R0?ooo`80o`001`3oool30000
09h0oooo000Q0?ooo`030000003oool0oooo0>00oooo1P3o00000`3oool000000000000200000:40
oooo000Q0?ooo`030000003oool0oooo0>00oooo1P3o00000`000000oooo0?ooo`2S0?ooo`008@3o
ool00`000000oooo0?ooo`3O0?ooo`P0o`00Y@3oool00240oooo00<000000?ooo`3oool0f`3oool4
000000P0o`00Y@3oool00240oooo00<000000?ooo`3oool0f03oool3000000D0oooo1P3o002V0?oo
o`008@3oool00`000000oooo0?ooo`3E0?ooo`<00000203oool60?l00:H0oooo000Q0?ooo`030000
003oool0oooo0=40oooo1000000=0?ooo`80o`00Z03oool00240oooo00<000000?ooo`3oool0cP3o
ool300000;/0oooo000Q0?ooo`<00000b`3oool300000;h0oooo000Q0?ooo`030000003oool0oooo
0<T0oooo0P0000310?ooo`008@3oool00`000000oooo0?ooo`360?ooo`<00000``3oool00240oooo
00<000000?ooo`3oool0_03oool20?l000D0oooo0`0000360?ooo`008@3oool00`000000oooo0?oo
o`2j0?ooo`H0o`0000<0oooo000000000000b@3oool00240oooo00<000000?ooo`3oool0^P3oool6
0?l000030000003oool0oooo0<T0oooo000Q0?ooo`030000003oool0oooo0;T0oooo203o003;0?oo
o`008@3oool00`000000oooo0?ooo`2h0?ooo`030000003o0000o`0000H0o`00b`3oool00240oooo
00<000000?ooo`3oool0]@3oool300000080oooo1P3o003<0?ooo`000`3oool4000000H0oooo0P00
00050?ooo`H000001`3oool00`000000oooo0?ooo`2a0?ooo`@000001@3oool60?l00<`0oooo0002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0:h0oooo0`00000;
0?ooo`80o`00cP3oool00080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0Z`3oool300000=h0oooo00020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`@0
0000Z03oool200000>40oooo00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0:H0oooo0`00003S0?ooo`000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`2S0?ooo`<00000iP3oool00080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`2F0?ooo`80o`002@3oool200000>T0oooo00020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0U03oool60?l000@0oooo0`00003[0?ooo`000`3oool4000000h0
oooo100000080?ooo`030000003oool0oooo09@0oooo1P3o0000103oool0000000000000003^0?oo
o`008@3oool00`000000oooo0?ooo`2C0?ooo`P0o`00l@3oool00240oooo00<000000?ooo`3oool0
T`3oool80?l00?40oooo000Q0?ooo`030000003oool0oooo09<0oooo00<000000?l0003o0000103o
003b0?ooo`008@3oool00`000000oooo0?ooo`2A0?ooo`80000000<0oooo0?l0003o0000103o003b
0?ooo`008@3oool00`000000oooo0?ooo`2>0?ooo`<000001@3oool20?l00?@0oooo000Q0?ooo`03
0000003oool0oooo08/0oooo0`00003n0?ooo`008@3oool3000008T0oooo0P00003o0?ooo`80oooo
000Q0?ooo`030000003oool0oooo08H0oooo0`00003o0?ooo`@0oooo000Q0?ooo`030000003oool0
oooo08<0oooo0`00003o0?ooo`L0oooo000Q0?ooo`030000003oool0oooo0840oooo0P00003o0?oo
o`X0oooo000Q0?ooo`030000003oool0oooo07h0oooo0`00003o0?ooo``0oooo000Q0?ooo`030000
003oool0oooo07/0oooo0`00003o0?ooo`l0oooo000Q0?ooo`030000003oool0oooo07T0oooo0P00
003o0?oooa80oooo000Q0?ooo`030000003oool0oooo07L0oooo0P00003o0?oooa@0oooo000Q0?oo
o`030000003oool0oooo07D0oooo0P00003o0?oooaH0oooo000Q0?ooo`030000003oool0oooo06l0
oooo0P3o0000103oool0000000000000003o0?oooaP0oooo000Q0?ooo`030000003oool0oooo06d0
oooo1P3o003o0?oooaX0oooo000Q0?ooo`030000003oool0oooo06d0oooo1P3o003o0?oooaX0oooo
000Q0?ooo`<00000J`3oool00`000000o`000?l000060?l00?l0oooo6@3oool00240oooo00<00000
0?ooo`3oool0J@3oool2000000030?ooo`3o0000o`0000H0o`00o`3ooolI0?ooo`008@3oool00`00
0000oooo0?ooo`1V0?ooo`<00000103oool60?l00?l0oooo6P3oool00240oooo00<000000?ooo`3o
ool0H`3oool3000000L0oooo1P3o003o0?oooaX0oooo000Q0?ooo`030000003oool0oooo0640oooo
0P00000<0?ooo`80o`00o`3ooolL0?ooo`008@3oool00`000000oooo0?ooo`1N0?ooo`<00000o`3o
ool/0?ooo`008@3oool00`000000oooo0?ooo`1L0?ooo`800000o`3oool_0?ooo`008@3oool00`00
0000oooo0?ooo`1J0?ooo`800000o`3ooola0?ooo`008@3oool00`000000oooo0?ooo`1H0?ooo`80
0000o`3ooolc0?ooo`008@3oool00`000000oooo0?ooo`190?ooo`80o`002`3oool200000?l0oooo
=@3oool00240oooo00<000000?ooo`3oool0A`3oool60?l000L0oooo0P00003o0?ooocL0oooo000Q
0?ooo`030000003oool0oooo04L0oooo1P3o00050?ooo`800000o`3oooli0?ooo`008@3oool30000
04H0oooo203o00020?ooo`800000o`3ooolk0?ooo`008@3oool00`000000oooo0?ooo`160?ooo`P0
o`000P00003o0?ooocd0oooo000Q0?ooo`030000003oool0oooo04L0oooo1P3o00000`000000oooo
0?ooo`3o0?ooocd0oooo000Q0?ooo`030000003oool0oooo04L0oooo1P3o003o0?oood00oooo000Q
0?ooo`030000003oool0oooo04L0oooo0P0000020?l00?l0oooo@P3oool00240oooo00<000000?oo
o`3oool0A@3oool200000?l0ooooAP3oool00240oooo00<000000?ooo`3oool0@`3oool200000?l0
ooooB03oool00240oooo00<000000?ooo`3oool0@@3oool200000?l0ooooBP3oool00240oooo00<0
00000?ooo`3oool0?`3oool200000?l0ooooC03oool00240oooo00<000000?ooo`3oool0?@3oool2
00000?l0ooooCP3oool00240oooo00<000000?ooo`3oool0>`3oool200000?l0ooooD03oool00240
oooo00<000000?ooo`3oool0>@3oool200000?l0ooooDP3oool00240oooo0`00000g0?ooo`800000
o`3ooomD0?ooo`008@3oool00`000000oooo0?ooo`0e0?ooo`800000o`3ooomF0?ooo`008@3oool0
0`000000oooo0?ooo`0c0?ooo`800000o`3ooomH0?ooo`008@3oool00`000000oooo0?ooo`0a0?oo
o`800000o`3ooomJ0?ooo`008@3oool00`000000oooo0?ooo`0_0?ooo`800000o`3ooomL0?ooo`00
8@3oool00`000000oooo0?ooo`0]0?ooo`800000o`3ooomN0?ooo`008@3oool00`000000oooo0?oo
o`0[0?ooo`800000o`3ooomP0?ooo`008@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo0?l0ooooH03oool00240oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?oo
of40oooo00030?ooo`@000001P3oool2000000H0oooo100000080?ooo`030000003oool0oooo02<0
oooo0P3o00020?ooo`800000o`3ooomT0?ooo`000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0Q0?ooo`H0o`00o`3ooomV0?ooo`000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0Q0?ooo`H0o`00o`3ooomV0?ooo`000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool01@3oool4000001l0oooo203o003o0?ooofD0oooo00020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool2000000P0oooo00<000000?oo
o`3oool0803oool80?l00?l0ooooI@3oool00080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool60?l00?l0
ooooIP3oool00080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0803oool00`000000o`000?l000040?l00?l0oooo
IP3oool00080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0O0?ooo`040000003o
ool0oooo0?ooo`80o`00o`3ooomX0?ooo`000`3oool4000000h0oooo100000080?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0o`3ooom/0?ooo`008@3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo0?l0ooooK@3oool00240oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`3o0?ooofh0oooo000Q0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0o`3ooom^0?ooo`008@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0?l0oooo
K`3oool00240oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`3o0?ooog00oooo000Q
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3oooma0?ooo`008@3oool30000
01P0oooo00<000000?ooo`3oool0o`3ooomb0?ooo`008@3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo0?l0ooooL`3oool00240oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`3o0?ooog<0oooo000Q0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3o
oomd0?ooo`008@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0ooooM@3oool0
0240oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?ooogH0oooo000Q0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3ooomf0?ooo`008@3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0?l0ooooM`3oool00240oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`3o0?ooogL0oooo000Q0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0o`3ooomh0?ooo`008@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0?l0ooooN03oool00240oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooogT0
oooo000Q0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooomi0?ooo`008@3o
ool300000100oooo00<000000?ooo`3oool0o`3ooomj0?ooo`008@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0?l0ooooNP3oool00240oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`3o0?ooog/0oooo000Q0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0o`3ooomk0?ooo`008@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo
N`3oool00240oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?ooog`0oooo000Q
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3oooml0?ooo`008@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooO@3oool00240oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`3o0?ooogd0oooo000Q0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0o`3ooomm0?ooo`008@3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0?l0ooooOP3oool00240oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o
0?ooogh0oooo000Q0?ooo`<00000303oool00`000000oooo0?ooo`3o0?ooogh0oooo000Q0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`008@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooO`3oool00240oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`3o0?ooogl0oooo000Q0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0o`3ooon00?ooo`008@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0?l0ooooP03oool00240oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oooh00
oooo000Q0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooon10?ooo`008@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0ooooP@3oool00240oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oooh40oooo000Q0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0o`3ooon10?ooo`008@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0?l0ooooPP3oool00240oooo0`0000080?ooo`030000003oool0oooo0?l0oooo
PP3oool00240oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oooh80oooo000Q
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooon20?ooo`008@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooPP3oool00240oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`3o0?oooh<0oooo000Q0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0o`3ooon30?ooo`008@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0?l0ooooP`3oool00240oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o
0?oooh<0oooo00030?ooo`@000001P3oool2000000L0oooo100000070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0o`3ooon40?ooo`000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo0P0000090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`3o0?oooh@0oooo00020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0o`3ooon40?ooo`000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00X0oooo1P0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3o
oon40?ooo`000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00@00000
0?ooo`3oool00000203oool4000000D0oooo00<000000?ooo`3oool0o`3ooon40?ooo`000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool00000203o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooQ@3oool00080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000000P0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooohD0oooo00020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0303oool00`000000oooo000000080?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0o`3ooon50?ooo`000`3oool400000100oooo0P0000080?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooon50?ooo`008@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0?l0ooooQ@3oool00240oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`3o0?ooohD0oooo000Q0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0o`3ooon60?ooo`008@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0?l0ooooQP3oool00240oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooohH0
oooo000Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooon60?ooo`008@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooQP3oool00240oooo0`000004
0?ooo`030000003oool0oooo0?l0ooooQP3oool00240oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`3o0?ooohL0oooo000Q0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0o`3ooon70?ooo`008@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo
Q`3oool00240oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooohL0oooo000Q
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooon70?ooo`008@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooQ`3oool00240oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`3o0?ooohP0oooo000Q0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0o`3ooon80?ooo`008@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0?l0ooooR03oool00240oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o
0?ooohP0oooo000Q0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooon80?oo
o`008@3oool300000080oooo00<000000?ooo`3oool0o`3ooon80?ooo`008@3oool01@000000oooo
0?ooo`3oool000000?l0ooooR`3oool00240oooo00D000000?ooo`3oool0oooo0000003o0?oooh/0
oooo000Q0?ooo`050000003oool0oooo0?ooo`000000o`3ooon;0?ooo`008@3oool01@000000oooo
0?ooo`3oool000000?l0ooooR`3oool00240oooo00D000000?ooo`3oool0oooo0000003o0?oooh/0
oooo000Q0?ooo`050000003oool0oooo0?ooo`000000o`3ooon;0?ooo`008@3oool01@000000oooo
0?ooo`3oool000000?l0ooooR`3oool00240oooo00@000000?ooo`3oool00000o`3ooon<0?ooo`00
8@3oool010000000oooo0?ooo`00003o0?oooh`0oooo000Q0?ooo`040000003oool0oooo00000?l0
ooooS03oool00240oooo00@000000?ooo`3oool00000o`3ooon<0?ooo`008@3oool400000?l0oooo
S03oool00240oooo00@000000?ooo`3oool00000o`3ooon<0?ooo`008@3oool010000000oooo0?oo
o`00003o0?oooh`0oooo000Q0?ooo`040000003oool0oooo00000?l0ooooS03oool00240oooo00<0
00000?ooo`000000o`3ooon=0?ooo`008@3oool00`000000oooo0000003o0?ooohd0oooo000Q0?oo
o`030000003oool000000?l0ooooS@3oool00240oooo00<000000?ooo`000000o`3ooon=0?ooo`00
8@3oool00`000000oooo0000003o0?ooohd0oooo000Q0?ooo`030000003oool000000?l0ooooS@3o
ool00240oooo00<000000?ooo`000000o`3ooon=0?ooo`008@3oool00`000000oooo0000003o0?oo
ohd0oooo000Q0?ooo`<00000o`3ooon=0?ooo`008@3oool200000?l0ooooSP3oool00240oooo0P00
003o0?ooohh0oooo000Q0?ooo`800000o`3ooon>0?ooo`008@3oool200000?l0ooooSP3oool00240
oooo0P00003o0?ooohh0oooo000Q0?ooo`800000o`3ooon>0?ooo`008@3oool200000?l0ooooSP3o
ool000<0oooo100000060?ooo`8000001P3oool4000000P0oooo0P3o003o0?ooohh0oooo00020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`H0o`00o`3ooon<0?ooo`000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool60?l00?l0
ooooS03oool00080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0080oooo203o003o0?oooh/0oooo00020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`P0o`00o`3ooon;0?ooo`000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo100000060?ooo`H0o`00o`3ooon<
0?ooo`000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01`3oool60?l00?l0ooooS03oool00080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo0P3o003o0?ooohh0oooo00030?ooo`@00000
3P3oool5000000L0oooo00<000000?ooo`3oool0o`3ooon=0?ooo`008@3oool00`000000oooo0?oo
o`3o0?ooohd0oooo000Q0?ooo`030000003oool0oooo0?l0ooooS@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-8.90221, 0.0692276, \
0.393111, 0.00249363}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[list1, modelTwoCompart, x2]\)], "Input",
  CellLabel->"In[13]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2", "SubsectionIcon"],

Cell[TextData[{
  "A usual problem in biokinetic modeling consist in fitting parameters in \
differential equations. Here is an example provided by Wolfram support. \nWe \
have the differential equation:  ",
  Cell[BoxData[
      \(TraditionalForm\`\(f'\)[t] \[Equal] If[t < p, 10 - f[t], \(-f[t]\)], 
      f[0] \[Equal] q\)]],
  ", where ",
  StyleBox["p",
    FontSlant->"Italic"],
  " an ",
  StyleBox["q",
    FontSlant->"Italic"],
  " are unknown, but we have the some experimental values (data) of ",
  Cell[BoxData[
      \(TraditionalForm\`f[t]\)]],
  " . "
}], "Text"],

Cell[BoxData[
    \(data = {{0.5, 6.2}, {1.1, 8.1}, {1.5, 8.8}, {2.1, 8.3}, {2.3, 
          6.8}, {3.1, 2.9}}; \)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \(\(\(sol[p_?NumericQ, 
        q_?NumericQ]\)\(:=\)\((f /. \(NDSolve[{\(f'\)[t] \[Equal] 
                  If[t < p, 10 - f[t], \(-f[t]\)], f[0] \[Equal] q}, 
              f, {t, 0, 5}]\)[\([\)\(1\)\(]\)])\)\(\ \)\)\)], "Input",
  CellLabel->"In[15]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(myfit = 
      FindFit[data, \(sol[p, q]\)[t], {{p, 2, 3}, {q, 4, 5}}, t]\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \({p \[Rule] 1.9961859244492166`, 
      q \[Rule] 3.935485289840691`}\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(fitsol = sol[p, q] /. myfit; 
    Plot[fitsol[tt], {tt, 0, 5}, 
      Epilog \[RuleDelayed] 
        Map[{Orange, PointSize[ .02], Point[##]} &, data]]\)], "Input",
  CellLabel->"In[17]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0147151 0.0641521 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .14302 -6 -4.5 ]
[.01131 .14302 0 4.5 ]
[.01131 .27132 -6 -4.5 ]
[.01131 .27132 0 4.5 ]
[.01131 .39963 -6 -4.5 ]
[.01131 .39963 0 4.5 ]
[.01131 .52793 -6 -4.5 ]
[.01131 .52793 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(1)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(2)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(3)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(4)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(5)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .14302 m
.03006 .14302 L
s
[(2)] .01131 .14302 1 0 Mshowa
.02381 .27132 m
.03006 .27132 L
s
[(4)] .01131 .27132 1 0 Mshowa
.02381 .39963 m
.03006 .39963 L
s
[(6)] .01131 .39963 1 0 Mshowa
.02381 .52793 m
.03006 .52793 L
s
[(8)] .01131 .52793 1 0 Mshowa
.125 Mabswid
.02381 .04679 m
.02756 .04679 L
s
.02381 .07887 m
.02756 .07887 L
s
.02381 .11094 m
.02756 .11094 L
s
.02381 .1751 m
.02756 .1751 L
s
.02381 .20717 m
.02756 .20717 L
s
.02381 .23925 m
.02756 .23925 L
s
.02381 .3034 m
.02756 .3034 L
s
.02381 .33548 m
.02756 .33548 L
s
.02381 .36755 m
.02756 .36755 L
s
.02381 .4317 m
.02756 .4317 L
s
.02381 .46378 m
.02756 .46378 L
s
.02381 .49586 m
.02756 .49586 L
s
.02381 .56001 m
.02756 .56001 L
s
.02381 .59208 m
.02756 .59208 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26718 m
.06244 .33861 L
.10458 .40164 L
.14415 .4494 L
.18221 .48686 L
.22272 .51931 L
.26171 .54466 L
.30316 .56648 L
.34309 .58345 L
.3815 .59674 L
.39174 .59986 L
.39675 .60132 L
.40134 .60263 L
.40252 .60296 L
.40381 .60332 L
.40503 .60033 L
.40616 .59686 L
.41134 .58122 L
.42237 .54937 L
.4615 .45008 L
.50308 .3647 L
.54314 .29831 L
.58169 .24635 L
.6227 .20149 L
.66219 .16652 L
.70016 .13908 L
.74058 .1153 L
.77949 .09672 L
.82085 .08071 L
.8607 .06825 L
.89903 .05849 L
.93981 .05006 L
.97619 .04391 L
s
1 .5 0 r
.02 w
.11905 .41246 Mdot
.23333 .53435 Mdot
.30952 .57925 Mdot
.42381 .54718 Mdot
.4619 .45095 Mdot
.61429 .20076 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[17]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00H@3oool7000004L0oooo1P0000190?ooo`@00000B`3oool4000004T0oooo1000000B0?oo
o`00I03oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo001T0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo04`0oooo00<000000?ooo`3oool03`3oool006@0oooo00<000000?ooo`3oool0BP3o
ool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04H0oooo1P00001=0?ooo`030000003o
ool0oooo00l0oooo001T0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool2
000004X0oooo00@000000?ooo`3oool00000CP3oool00`000000oooo0?ooo`0?0?ooo`00I03oool0
0`000000oooo0?ooo`1<0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0A`3oool0
10000000oooo0?ooo`00001:0?ooo`@000004P3oool006@0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0000001:0?ooo`030000003oool0oooo01<0oooo001R0?ooo`<00000BP3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`180?ooo`030000003oool0000004X0oooo00<000000?ooo`3oool04`3oool006@0
oooo00<000000?ooo`3oool0B@3oool4000004X0oooo1000001<0?ooo`800000BP3oool500000140
oooo003o0?oook40oooo003o0?oook40oooo000F0?ooo`030000003oool0oooo0?l0ooooV03oool0
01H0oooo00<000000?ooo`3oool0o`3ooonH0?ooo`005P3oool00`000000oooo0?ooo`3o0?oooiP0
oooo000F0?ooo`030000003oool0oooo0?l0ooooV03oool001H0oooo00<000000?ooo`3oool0o`3o
oonH0?ooo`005P3oool00`000000oooo0?ooo`3o0?oooiP0oooo000<0?ooool00000W00000090?oo
o`005P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0140oooo000F0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool04@3oool001H0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0140oooo000F0?ooo`030000003oool0
oooo0?l0ooooV03oool001H0oooo00<000000?ooo`3oool0o`3ooonH0?ooo`005P3oool00`000000
oooo0?ooo`3o0?oooiP0oooo000F0?ooo`030000003oool0oooo0?l0ooooV03oool001H0oooo00<0
00000?ooo`3oool0o`3ooonH0?ooo`005P3oool00`000000oooo0?ooo`3o0?oooiP0oooo000F0?oo
o`030000003oool0oooo0?l0ooooV03oool001H0oooo00<000000?ooo`3oool0o`3ooonH0?ooo`00
5P3oool00`000000oooo0?ooo`3o0?oooh80oooo0`00000C0?ooo`005P3oool300000?l0ooooO@3o
ool5000001H0oooo000F0?ooo`030000003oool0oooo0?l0ooooN03oool5000001/0oooo000F0?oo
o`030000003oool0oooo0?l0ooooL`3oool500000200oooo000F0?ooo`030000003oool0oooo0?l0
ooooKP3oool5000002D0oooo000F0?ooo`030000003oool0oooo0?l0ooooJ03oool6000002X0oooo
000F0?ooo`030000003oool0oooo0?l0ooooI03oool400000300oooo000F0?ooo`030000003oool0
oooo0?l0ooooH03oool4000003@0oooo000F0?ooo`030000003oool0oooo0?l0ooooG03oool40000
03P0oooo000F0?ooo`030000003oool0oooo0?l0ooooF03oool4000003`0oooo000F0?ooo`030000
003oool0oooo0?l0ooooE03oool400000400oooo000F0?ooo`030000003oool0oooo0?l0ooooD@3o
ool3000004@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool3000004L0oooo000F0?oo
o`030000003oool0oooo0?l0ooooBP3oool4000004X0oooo000F0?ooo`030000003oool0oooo0?l0
ooooA`3oool3000004h0oooo000F0?ooo`<00000o`3ooom40?ooo`<00000D@3oool001H0oooo00<0
00000?ooo`3oool0o`3ooom20?ooo`800000E03oool001H0oooo00<000000?ooo`3oool0o`3ooolo
0?ooo`<00000EP3oool001H0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`800000F@3oool001H0
oooo00<000000?ooo`3oool0o`3ooolk0?ooo`800000F`3oool001H0oooo00<000000?ooo`3oool0
o`3ooolh0?ooo`<00000G@3oool001H0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`800000H03o
ool001H0oooo00<000000?ooo`3oool0o`3ooolc0?ooo`<00000HP3oool001H0oooo00<000000?oo
o`3oool0o`3ooola0?ooo`800000I@3oool001H0oooo00<000000?ooo`3oool0o`3oool_0?ooo`80
0000I`3oool001H0oooo00<000000?ooo`3oool0o`3oool]0?ooo`800000J@3oool001H0oooo00<0
00000?ooo`3oool0o`3ooolZ0?ooo`<00000J`3oool001H0oooo00<000000?ooo`3oool0o`3ooolX
0?ooo`800000KP3oool001H0oooo0`00003o0?ooobH0oooo0P00001`0?ooo`005P3oool00`000000
oooo0?ooo`3o0?ooob@0oooo0P00001b0?ooo`005P3oool00`000000oooo0?ooo`3o0?ooob80oooo
0P00001d0?ooo`005P3oool00`000000oooo0?ooo`3o0?ooob00oooo0P00001f0?ooo`005P3oool0
0`000000oooo0?ooo`3o0?oooal0oooo00<000000?ooo`3oool0MP3oool001H0oooo00<000000?oo
o`3oool0o`3ooolM0?ooo`800000N@3oool001H0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`80
0000N`3oool001H0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`800000O@3oool001H0oooo00<0
00000?ooo`3oool0o`3ooolH0?ooo`030000003oool0oooo07d0oooo00090?ooo`H000001`3oool0
0`000000oooo0?ooo`3o0?oooaH0oooo0P0000200?ooo`002@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`800000PP3oool000X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oooa<0oooo00<000000?ooo`3o
ool0PP3oool000/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oooa40oooo
0P0000250?ooo`00303oool00`000000oooo0?ooo`070?ooo`@00000o`3oool?0?ooo`030000003o
ool0oooo08D0oooo000=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3oool?
0?ooo`030000003oool0oooo08H0oooo00090?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`d0oooo0P0000290?ooo`002@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3oool<0?ooo`03
0000003oool0oooo08T0oooo000:0?ooo`@00000203oool00`000000oooo0?ooo`3o0?ooo`/0oooo
00<000000?ooo`3oool0RP3oool001H0oooo00<000000?ooo`3oool0o`3oool90?ooo`800000S@3o
ool001H0oooo00<000000?ooo`3oool0o`3oool80?ooo`030000003oool0oooo08d0oooo000F0?oo
o`030000003oool0oooo0?l0oooo1`3oool00`000000oooo0?ooo`2>0?ooo`005P3oool00`000000
oooo0?ooo`3o0?ooo`D0oooo0P00002A0?ooo`005P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo
00<000000?ooo`3oool0T@3oool001H0oooo00<000000?ooo`3oool0o`3oool30?ooo`030000003o
ool0oooo0980oooo000F0?ooo`030000003oool0oooo0?l0oooo0P3oool00`000000oooo0?ooo`2C
0?ooo`005P3oool00`000000oooo0?ooo`3o0?ooo`40oooo00<000000?ooo`3oool0U03oool001H0
oooo0`00003n0?ooo`800000U`3oool001H0oooo00<000000?ooo`3oool0o@3oool00`000000oooo
0?ooo`2G0?ooo`005P3oool00`000000oooo0?ooo`3l0?ooo`030000003oool0oooo09P0oooo000F
0?ooo`030000003oool0oooo0?/0oooo00<000000?ooo`3oool0V@3oool001H0oooo00<000000?oo
o`3oool0nP3oool00`000000oooo0?ooo`2J0?ooo`005P3oool00`000000oooo0?ooo`3i0?ooo`03
0000003oool0oooo09/0oooo000F0?ooo`030000003oool0oooo0?P0oooo00<000000?ooo`3oool0
W03oool001H0oooo00<000000?ooo`3oool0kP3oool20?mo00H0oooo0P00002O0?ooo`005P3oool0
0`000000oooo0?ooo`3/0?ooo`H0ogl00`3oool00`000000oooo0?ooo`2O0?ooo`005P3oool00`00
0000oooo0?ooo`3/0?ooo`H0ogl00P3oool00`000000oooo0?ooo`2P0?ooo`005P3oool00`000000
oooo0?ooo`3[0?ooo`P0ogl000<000000?ooo`3oool0X@3oool001H0oooo00<000000?ooo`3oool0
j`3oool80?mo0:@0oooo000F0?ooo`030000003oool0oooo0>`0oooo1P3oO`2U0?ooo`005P3oool3
00000>`0oooo1P3oO`2U0?ooo`005P3oool00`000000oooo0?ooo`3^0?ooo`80ogl0Y`3oool001H0
oooo00<000000?ooo`3oool0kP3oool00`000000oooo0?ooo`2V0?ooo`005P3oool00`000000oooo
0?ooo`3^0?ooo`030000003oool0oooo0:H0oooo000F0?ooo`030000003oool0oooo0>d0oooo00<0
00000?ooo`3oool0Y`3oool001H0oooo00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`2X
0?ooo`005P3oool00`000000oooo0?ooo`3[0?ooo`030000003oool0oooo0:T0oooo000F0?ooo`03
0000003oool0oooo0>X0oooo00<000000?ooo`3oool0ZP3oool001H0oooo00<000000?ooo`3oool0
j@3oool00`000000oooo0?ooo`2[0?ooo`005P3oool00`000000oooo0?ooo`3X0?ooo`030000003o
ool0oooo0:`0oooo000F0?ooo`030000003oool0oooo0>L0oooo00<000000?ooo`3oool0[@3oool0
01H0oooo00<000000?ooo`3oool0iP3oool00`000000oooo0?ooo`2^0?ooo`005P3oool00`000000
oooo0?ooo`3V0?ooo`030000003oool0oooo0:h0oooo000F0?ooo`<00000i@3oool00`000000oooo
0?ooo`2_0?ooo`005P3oool00`000000oooo0?ooo`3T0?ooo`030000003oool0oooo0;00oooo000F
0?ooo`030000003oool0oooo0><0oooo00<000000?ooo`3oool0/@3oool001H0oooo00<000000?oo
o`3oool0hP3oool00`000000oooo0?ooo`2b0?ooo`005P3oool00`000000oooo0?ooo`3Q0?ooo`03
0000003oool0oooo0;<0oooo000F0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool0
]03oool001H0oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`2d0?ooo`005P3oool0
0`000000oooo0?ooo`3O0?ooo`030000003oool0oooo0;D0oooo000F0?ooo`030000003oool0oooo
0=h0oooo00<000000?ooo`3oool0]P3oool001H0oooo00<000000?ooo`3oool0g@3oool00`000000
oooo0?ooo`2g0?ooo`002`3oool4000000L0oooo00<000000?ooo`3oool0g@3oool00`000000oooo
0?ooo`2g0?ooo`003@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0=`0oooo00<0
00000?ooo`3oool0^03oool000d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3K
0?ooo`030000003oool0oooo0;T0oooo00090?ooo`H000001`3oool400000=T0oooo00<000000?oo
o`3oool0^P3oool000X0oooo00@000000?ooo`3oool00000203oool200000=/0oooo00<000000?oo
o`3oool0^P3oool000X0oooo00@000000?ooo`3oool00000203oool00`000000oooo0000003I0?oo
o`030000003oool0oooo0;/0oooo000;0?ooo`030000003oool0000000P0oooo00<000000?ooo`00
0000f03oool00`000000oooo0?ooo`2l0?ooo`002`3oool00`000000oooo000000080?ooo`040000
003oool0oooo00000=H0oooo00<000000?ooo`3oool0_@3oool000`0oooo0P0000080?ooo`040000
003oool0oooo00000=H0oooo00<000000?ooo`3oool0_@3oool001H0oooo00D000000?ooo`3oool0
oooo0000003D0?ooo`030000003oool0oooo0;h0oooo000F0?ooo`050000003oool0oooo0?ooo`00
0000d`3oool00`000000oooo0?ooo`2o0?ooo`005P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0<l0oooo00<000000?ooo`3oool0`03oool001H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0<00oooo000F0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`310?ooo`005P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool0`P3oool001H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo0<<0
oooo000F0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0b@3oool00`000000oooo
0?ooo`330?ooo`005P3oool3000000D0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?oo
o`340?ooo`005P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0<L0oooo00<00000
0?ooo`3oool0a03oool001H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`360?oo
o`030000003oool0oooo0<D0oooo000F0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0a03oool00`000000oooo0?ooo`360?ooo`005P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0<@0oooo00<000000?ooo`3oool0aP3oool001H0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0<L0oooo000F0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`370?ooo`005P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0b03oool001H0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo0<T0
oooo000F0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo
0?ooo`390?ooo`005P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0;`0oooo00<0
00000?ooo`3oool0bP3oool001H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2k
0?ooo`030000003oool0oooo0</0oooo000F0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0^P3oool00`000000oooo0?ooo`3;0?ooo`005P3oool3000000`0oooo00<000000?ooo`3o
ool0^@3oool00`000000oooo0?ooo`3<0?ooo`005P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo0;P0oooo00<000000?ooo`3oool0c03oool001H0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo0<d0oooo000F0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`3>0?ooo`005P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0cP3oool001H0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo0<l0
oooo000F0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0/P3oool00`000000oooo
0?ooo`3?0?ooo`005P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0;00oooo00<0
00000?ooo`3oool0d03oool001H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`2^
0?ooo`030000003oool0oooo0=40oooo000F0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0[P3oool00`000000oooo0?ooo`3A0?ooo`005P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0:`0oooo00<000000?ooo`3oool0dP3oool001H0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0=80oooo000F0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`3C0?ooo`005P3oool3
000001D0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`3C0?ooo`005P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0e03oool001H0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo0=@0
oooo000F0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo
0?ooo`3E0?ooo`005P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0:D0oooo00<0
00000?ooo`3oool0e@3oool001H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`2S
0?ooo`030000003oool0oooo0=H0oooo000F0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0XP3oool00`000000oooo0?ooo`3F0?ooo`005P3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo0:40oooo00<000000?ooo`3oool0e`3oool001H0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo0=L0oooo000;0?ooo`@000001`3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0f03o
ool000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`3H0?ooo`002P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`2L0?ooo`030000003oool0oooo0=T0oooo000:0?ooo`8000000`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0V`3oool00`000000
oooo0?ooo`3I0?ooo`002P3oool00`000000oooo00000002000000L0oooo1000000L0?ooo`030000
003oool0oooo09X0oooo00<000000?ooo`3oool0fP3oool000X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0fP3o
ool000/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo0080oooo0P3oO`2C0?ooo`030000003oool0oooo0=/0oooo000<0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?mo00050?mo0940oooo00<000000?oo
o`3oool0f`3oool000d0oooo0`0000060?ooo`030000003oool0oooo0240oooo00<000000?mo003o
O`00103oO`2@0?ooo`030000003oool0oooo0=`0oooo000F0?ooo`030000003oool0oooo0240oooo
203oO`2?0?ooo`030000003oool0oooo0=`0oooo000F0?ooo`030000003oool0oooo0240oooo203o
O`2>0?ooo`030000003oool0oooo0=d0oooo000F0?ooo`030000003oool0oooo0280oooo1P3oO`2?
0?ooo`030000003oool0oooo0=d0oooo000F0?ooo`030000003oool0oooo0280oooo1P3oO`2>0?oo
o`030000003oool0oooo0=h0oooo000F0?ooo`030000003oool0oooo02@0oooo0P3oO`2@0?ooo`03
0000003oool0oooo0=h0oooo000F0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`3O0?ooo`005P3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool0g`3oool001H0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0>00oooo000F0?ooo`<00000:03oool00`00
0000oooo0?ooo`290?ooo`030000003oool0oooo0>00oooo000F0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`3Q0?ooo`005P3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0h@3oool001H0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0>80oooo000F
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`3R
0?ooo`005P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0840oooo0P3oO`3U0?oo
o`005P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo07h0oooo1P3oO`3S0?ooo`00
5P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo07d0oooo1P3oO`3S0?ooo`005P3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo07/0oooo203oO`3R0?ooo`005P3oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo07X0oooo203oO`3R0?ooo`005P3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo07X0oooo1P3oO`3S0?ooo`005P3oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo07T0oooo1P3oO`3S0?ooo`005P3oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo07P0oooo00@000000?ooo`3oO`00ogl0i@3oool001H0oooo
0`00000d0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0iP3oool001H0oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0>H0oooo000F
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`3W
0?ooo`005P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool0i`3oool001H0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1a0?ooo`03
0000003oool0oooo0>P0oooo000F0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
L03oool00`000000oooo0?ooo`3X0?ooo`005P3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo06l0oooo00<000000?ooo`3oool0j03oool001H0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0>T0oooo000F0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`3Y0?ooo`005P3oool00`000000
oooo0?ooo`0m0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0jP3oool001H0oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0>X0oooo
000F0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?oo
o`3Z0?ooo`005P3oool00`000000oooo0?ooo`100?ooo`800000I`3oool00`000000oooo0?ooo`3[
0?ooo`005P3oool300000480oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`3[0?oo
o`005P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0680oooo00<000000?ooo`3o
ool0k03oool001H0oooo00<000000?ooo`3oool0A03oool200000680oooo00<000000?ooo`3oool0
k03oool001H0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1O0?ooo`030000003o
ool0oooo0>`0oooo000F0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0G@3oool0
0`000000oooo0?ooo`3]0?ooo`005P3oool00`000000oooo0?ooo`180?ooo`800000G@3oool00`00
0000oooo0?ooo`3]0?ooo`005P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo05T0
oooo00<000000?ooo`3oool0kP3oool001H0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo0>h0oooo000F0?ooo`030000003oool0oooo04`0oooo0P00
001H0?ooo`030000003oool0oooo0>h0oooo000F0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`3_0?ooo`002P3oool4000000P0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0>l0oooo00090?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1@0?ooo`80
0000DP3oool00`000000oooo0?ooo`3`0?ooo`002@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo0?00oooo00090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`1B0?ooo`80ogl000<000000?ooo`3oool0C@3oool00`000000oooo0?oo
o`3`0?ooo`002P3oool4000000P0oooo1000001?0?ooo`H0ogl000<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`3a0?ooo`002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0D03oool60?mo00030?ooo`000000oooo04X0oooo00<000000?oo
o`3oool0l@3oool000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo04l0oooo203oO`000`3oool00000000000180?ooo`030000003oool0oooo0?80
oooo00090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1?0?ooo`P0ogl00`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0?80oooo
000:0?ooo`@00000203oool00`000000oooo0?ooo`1@0?ooo`H0ogl01@3oool2000004<0oooo0P3o
O`000`000000oooo0?ooo`3b0?ooo`005P3oool00`000000oooo0?ooo`1@0?ooo`H0ogl01`3oool2
000003l0oooo1P3oO`3c0?ooo`005P3oool00`000000oooo0?ooo`1B0?ooo`80ogl02`3oool00`00
0000oooo0?ooo`0l0?ooo`H0ogl0l`3oool001H0oooo00<000000?ooo`3oool0H03oool2000003/0
oooo203oO`3b0?ooo`005P3oool00`000000oooo0?ooo`1R0?ooo`800000>@3oool80?mo0?80oooo
000F0?ooo`030000003oool0oooo06@0oooo0P00000h0?ooo`H0ogl0l`3oool001H0oooo00<00000
0?ooo`3oool0IP3oool2000003H0oooo1P3oO`3c0?ooo`005P3oool00`000000oooo0?ooo`1X0?oo
o`800000=@3oool00`000000ogl00?mo003e0?ooo`005P3oool00`000000oooo0?ooo`1Z0?ooo`80
0000<`3oool00`000000oooo0?ooo`3e0?ooo`005P3oool3000006`0oooo0P00000`0?ooo`030000
003oool0oooo0?H0oooo000F0?ooo`030000003oool0oooo06h0oooo0P00000^0?ooo`030000003o
ool0oooo0?H0oooo000F0?ooo`030000003oool0oooo0700oooo0P00000/0?ooo`030000003oool0
oooo0?H0oooo000F0?ooo`030000003oool0oooo0780oooo0P00000Z0?ooo`030000003oool0oooo
0?H0oooo000F0?ooo`030000003oool0oooo0780oooo0P3oO`02000002L0oooo00<000000?ooo`3o
ool0m`3oool001H0oooo00<000000?ooo`3oool0L03oool60?mo008000009@3oool00`000000oooo
0?ooo`3g0?ooo`005P3oool00`000000oooo0?ooo`1`0?ooo`H0ogl00P3oool300000280oooo00<0
00000?ooo`3oool0m`3oool001H0oooo00<000000?ooo`3oool0K`3oool80?mo00@0oooo0P00000O
0?ooo`030000003oool0oooo0?P0oooo000F0?ooo`030000003oool0oooo06l0oooo203oO`060?oo
o`8000007@3oool00`000000oooo0?ooo`3h0?ooo`005P3oool00`000000oooo0?ooo`1`0?ooo`H0
ogl02@3oool3000001X0oooo00<000000?ooo`3oool0n03oool001H0oooo00<000000?ooo`3oool0
L03oool60?mo00`0oooo0P00000G0?ooo`030000003oool0oooo0?T0oooo000F0?ooo`030000003o
ool0oooo0780oooo0P3oO`0@0?ooo`<00000503oool00`000000oooo0?ooo`3i0?ooo`005P3oool0
0`000000oooo0?ooo`270?ooo`<000004@3oool00`000000oooo0?ooo`3i0?ooo`005P3oool30000
08X0oooo0P00000?0?ooo`030000003oool0oooo0?T0oooo000F0?ooo`030000003oool0oooo08`0
oooo0`00000;0?ooo`030000003oool0oooo0?X0oooo000F0?ooo`030000003oool0oooo08l0oooo
0`0000080?ooo`030000003oool0oooo0?X0oooo000F0?ooo`030000003oool0oooo0980oooo0`00
00040?ooo`030000003oool0oooo0?/0oooo000F0?ooo`030000003oool0oooo09D0oooo1@00003m
0?ooo`005P3oool00`000000oooo0?ooo`3o0?oooiP0oooo000F0?ooo`030000003oool0oooo0?l0
ooooV03oool001H0oooo00<000000?ooo`3oool0o`3ooonH0?ooo`005P3oool00`000000oooo0?oo
o`3o0?oooiP0oooo000F0?ooo`030000003oool0oooo0?l0ooooV03oool001H0oooo00<000000?oo
o`3oool0o`3ooonH0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.288608, -0.708306, \
0.0192157, 0.0570539}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[17]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[data, sol, myfit, fitsol]\)], "Input",
  CellLabel->"In[18]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 3", "SubsectionIcon"],

Cell[TextData[{
  "We want to estimate the values , ",
  Cell[BoxData[
      \(TraditionalForm\`k\_off\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\_on\)]],
  "  for the physiological model given by the system of linear diferential \
equations:"
}], "Text"],

Cell[BoxData[{
    \(\(x\& . \)\_1[t] = \(-\((Q\/V\_p + \ PS\/V\_p)\)\) x\_1[t]\  + 
        PS\/V\_p\ x\_2[t] + Q\/V\_p\ b[t]\), "\n", 
    \(\(x\& . \)\_2[
        t]\  = \(+\(PS\/V\_Tu\)\) x\_1[t] - \((PS\/V\_Tu\  + k\_on\ )\) 
          x\_2[t] + \(k\_off\) \(V\_Tb\/V\_Tu\) x\_3[t]\), "\n", 
    \(\(x\& . \)\_3[
        t] = \(+\ k\_on\) \(V\_Tu\/V\_Tb\) x\_2[t] - \(k\_off\) 
          x\_3[t]\)}], "NumberedEquation",
  TextAlignment->Left,
  TextJustification->0,
  CellTags->"eq 2"],

Cell[TextData[{
  "It was made an experiment (the model and the experimental data was \
provided by Amparo Sanchez. Pharmacology Dpt. Universidad de Salamanca)  \
where the input function  ",
  Cell[BoxData[
      \(TraditionalForm\`b(t)\)]],
  " is given by  the best fit of the input function to experimental data {{",
  Cell[BoxData[
      \(TraditionalForm\`t\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b\_1\)]],
  "}, ..., {",
  Cell[BoxData[
      \(TraditionalForm\`t\_n\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b\_n\)]],
  "}} obtained via sampling from an arterial catheter. Here are the \
experimental data:"
}], "Text"],

Cell[BoxData[
    \(dataCateter = {{0.0, 3.048}, {0.05, 286.435}, {0.10, 534.718}, {0.15, 
          370.241}, {0.20, 240.302`}, {0.25, 170.005`}, {0.30, 128.6}, {0.35, 
          84.36}, {0.40, 66.58}, {0.45`, 52.32}, {0.50`, 40.30`}, {0.55, 
          28.78`}, {0.60, 20.75}, {0.65, 16.226`}, {0.70, 14.19`}, {0.75, 
          13.14`}, {0.80, 10.63`}, {0.85, 7.57`}, {0.90, 7.414`}, {0.95, 
          5.026`}, {1.00, 3.69`}, {1.05, 4.39`}, {1.10, 3.17`}, {1.15, 
          3.16`}, {1.20, 2.55`}, {1.25, 2.334`}, {1.30`, 2.164`}, {1.35, 
          2.1`}, {1.40, 1.63`}, {1.45, 1.445`}, {1.50, 0.513`}, {1.55, 
          1.14`}, {1.60, 0.852`}, {1.65, 0.761`}, {1.70, 0.734`}, {1.75, 
          0.775`}, {1.80, 0.473`}, {1.85, 0.389`}, {1.90, 0.514`}, {1.9767\ , 
          0.347`}, {2.077, 0.274`}, {2.177\ , 0.14`}, {2.277, 
          0.088`}, {2.377, 0.013}}; \)], "Input",
  CellLabel->"In[19]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[dataCateter, \ PlotJoined \[Rule] \ True, \ 
      PlotRange \[Rule] \ All]\)], "Input",
  CellLabel->"In[20]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.400665 0.0147008 0.0011008 [
[.22414 .0022 -9 -9 ]
[.22414 .0022 9 0 ]
[.42447 .0022 -3 -9 ]
[.42447 .0022 3 0 ]
[.62481 .0022 -9 -9 ]
[.62481 .0022 9 0 ]
[.82514 .0022 -3 -9 ]
[.82514 .0022 3 0 ]
[.01131 .12478 -18 -4.5 ]
[.01131 .12478 0 4.5 ]
[.01131 .23486 -18 -4.5 ]
[.01131 .23486 0 4.5 ]
[.01131 .34494 -18 -4.5 ]
[.01131 .34494 0 4.5 ]
[.01131 .45502 -18 -4.5 ]
[.01131 .45502 0 4.5 ]
[.01131 .5651 -18 -4.5 ]
[.01131 .5651 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.22414 .0147 m
.22414 .02095 L
s
[(0.5)] .22414 .0022 0 1 Mshowa
.42447 .0147 m
.42447 .02095 L
s
[(1)] .42447 .0022 0 1 Mshowa
.62481 .0147 m
.62481 .02095 L
s
[(1.5)] .62481 .0022 0 1 Mshowa
.82514 .0147 m
.82514 .02095 L
s
[(2)] .82514 .0022 0 1 Mshowa
.125 Mabswid
.06388 .0147 m
.06388 .01845 L
s
.10394 .0147 m
.10394 .01845 L
s
.14401 .0147 m
.14401 .01845 L
s
.18408 .0147 m
.18408 .01845 L
s
.26421 .0147 m
.26421 .01845 L
s
.30428 .0147 m
.30428 .01845 L
s
.34434 .0147 m
.34434 .01845 L
s
.38441 .0147 m
.38441 .01845 L
s
.46454 .0147 m
.46454 .01845 L
s
.50461 .0147 m
.50461 .01845 L
s
.54467 .0147 m
.54467 .01845 L
s
.58474 .0147 m
.58474 .01845 L
s
.66487 .0147 m
.66487 .01845 L
s
.70494 .0147 m
.70494 .01845 L
s
.74501 .0147 m
.74501 .01845 L
s
.78507 .0147 m
.78507 .01845 L
s
.86521 .0147 m
.86521 .01845 L
s
.90527 .0147 m
.90527 .01845 L
s
.94534 .0147 m
.94534 .01845 L
s
.98541 .0147 m
.98541 .01845 L
s
.25 Mabswid
0 .0147 m
1 .0147 L
s
.02381 .12478 m
.03006 .12478 L
s
[(100)] .01131 .12478 1 0 Mshowa
.02381 .23486 m
.03006 .23486 L
s
[(200)] .01131 .23486 1 0 Mshowa
.02381 .34494 m
.03006 .34494 L
s
[(300)] .01131 .34494 1 0 Mshowa
.02381 .45502 m
.03006 .45502 L
s
[(400)] .01131 .45502 1 0 Mshowa
.02381 .5651 m
.03006 .5651 L
s
[(500)] .01131 .5651 1 0 Mshowa
.125 Mabswid
.02381 .03672 m
.02756 .03672 L
s
.02381 .05873 m
.02756 .05873 L
s
.02381 .08075 m
.02756 .08075 L
s
.02381 .10276 m
.02756 .10276 L
s
.02381 .1468 m
.02756 .1468 L
s
.02381 .16881 m
.02756 .16881 L
s
.02381 .19083 m
.02756 .19083 L
s
.02381 .21284 m
.02756 .21284 L
s
.02381 .25688 m
.02756 .25688 L
s
.02381 .27889 m
.02756 .27889 L
s
.02381 .30091 m
.02756 .30091 L
s
.02381 .32293 m
.02756 .32293 L
s
.02381 .36696 m
.02756 .36696 L
s
.02381 .38897 m
.02756 .38897 L
s
.02381 .41099 m
.02756 .41099 L
s
.02381 .43301 m
.02756 .43301 L
s
.02381 .47704 m
.02756 .47704 L
s
.02381 .49905 m
.02756 .49905 L
s
.02381 .52107 m
.02756 .52107 L
s
.02381 .54309 m
.02756 .54309 L
s
.02381 .58712 m
.02756 .58712 L
s
.02381 .60913 m
.02756 .60913 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .01806 m
.04384 .33001 L
.06388 .60332 L
.08391 .42226 L
.10394 .27923 L
.12398 .20184 L
.14401 .15626 L
.16404 .10756 L
.18408 .08799 L
.20411 .07229 L
.22414 .05906 L
.24418 .04638 L
.26421 .03754 L
.28424 .03256 L
.30428 .03032 L
.32431 .02917 L
.34434 .0264 L
.36437 .02303 L
.38441 .02286 L
.40444 .02023 L
.42447 .01876 L
.44451 .01953 L
.46454 .01819 L
.48457 .01818 L
.50461 .01751 L
.52464 .01727 L
.54467 .01708 L
.56471 .01701 L
.58474 .0165 L
.60477 .01629 L
.62481 .01527 L
.64484 .01596 L
.66487 .01564 L
.68491 .01554 L
.70494 .01551 L
.72497 .01555 L
.74501 .01522 L
.76504 .01513 L
.78507 .01527 L
.8158 .01508 L
.85599 .015 L
.89606 .01485 L
.93612 .0148 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[20]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00IP3oool4000000H0oooo0P0000060?ooo`@00000A03oool700000480oooo1`0000040?oo
o`8000001P3oool4000004@0oooo1P0000160?ooo`00I@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00D0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo04@0oooo001U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo04P0oooo001U0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`130?ooo`030000003o
ool0oooo04L0oooo001U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo04H0oooo001U0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02`3oool4000004L0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0=0?ooo`@00000B03oool00`000000oooo0?ooo`150?ooo`00I@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo04@0oooo001U0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`160?ooo`<00000AP3oool3000000l0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04@0oooo
001V0?ooo`@000003P3oool5000004H0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`0=0?ooo`D00000A03oool4000004L0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3oool00200oooo00<000000?ooo`3oool0o`3o
oon>0?ooo`00803oool00`000000oooo0?ooo`3o0?ooohh0oooo000P0?ooo`030000003oool0oooo
0?l0ooooSP3oool00200oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00803oool00`000000oooo
0?ooo`3o0?ooohh0oooo000F0?ooool00000VP0000010?ooo`00803oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:
0?ooo`P000002@3ooola000000<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`04
0?ooo`00803oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04@0oooo200000030?oo
o`030000003oool0oooo0080oooo2@0000140?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool0AP3oool00200oooo00<000000?ooo`3oool0Q@3oool@00000?P0oooo000P0?ooo`030000
003oool0oooo07h0oooo1`00003o0?ooo`T0oooo000P0?ooo`030000003oool0oooo07X0oooo1000
003o0?oooa00oooo000P0?ooo`030000003oool0oooo06`0oooo3P00003o0?oooa@0oooo000P0?oo
o`030000003oool0oooo06H0oooo1P00003o0?ooob80oooo000P0?ooo`030000003oool0oooo0680
oooo1000003o0?ooobP0oooo000P0?ooo`800000H03oool300000?l0oooo;03oool00200oooo0P00
001N0?ooo`800000o`3oool_0?ooo`00803oool2000005`0oooo0P00003o0?oooc40oooo000P0?oo
o`800000FP3oool200000?l0oooo<`3oool00200oooo0P00001H0?ooo`800000o`3ooole0?ooo`00
803oool2000005H0oooo0P00003o0?ooocL0oooo000P0?ooo`800000E03oool200000?l0oooo>@3o
ool00200oooo0P00001B0?ooo`800000o`3ooolk0?ooo`00803oool200000500oooo0P00003o0?oo
ocd0oooo000P0?ooo`800000C`3oool00`000000oooo0?ooo`3o0?ooocd0oooo000P0?ooo`800000
C@3oool200000?l0oooo@03oool00200oooo0P00001<0?ooo`030000003oool0oooo0?l0oooo@03o
ool00200oooo0P00001:0?ooo`800000o`3ooom30?ooo`00803oool2000004P0oooo0P00003o0?oo
odD0oooo000P0?ooo`800000A`3oool00`000000oooo0?ooo`3o0?ooodD0oooo000P0?ooo`800000
AP3oool00`000000oooo0?ooo`3o0?ooodH0oooo000P0?ooo`030000003oool0000004@0oooo00<0
00000?ooo`3oool0o`3ooom70?ooo`00803oool00`000000oooo000000130?ooo`030000003oool0
oooo0?l0ooooB03oool00200oooo0`0000110?ooo`800000o`3ooom;0?ooo`00803oool00`000000
oooo000000100?ooo`030000003oool0oooo0?l0ooooB`3oool00200oooo00<000000?ooo`000000
?`3oool00`000000oooo0?ooo`3o0?oood`0oooo000P0?ooo`030000003oool0000003h0oooo00<0
00000?ooo`3oool0o`3ooom=0?ooo`00803oool00`000000oooo0000000m0?ooo`030000003oool0
oooo0?l0ooooCP3oool00200oooo00<000000?ooo`000000?03oool00`000000oooo0?ooo`3o0?oo
odl0oooo000P0?ooo`030000003oool0000003/0oooo00<000000?ooo`3oool0o`3ooom@0?ooo`00
803oool00`000000oooo0000000j0?ooo`030000003oool0oooo0?l0ooooD@3oool00200oooo00<0
00000?ooo`000000>@3oool00`000000oooo0?ooo`3o0?oooe80oooo000P0?ooo`<00000>03oool0
0`000000oooo0?ooo`3o0?oooe<0oooo000P0?ooo`030000003oool0000003L0oooo00<000000?oo
o`3oool0o`3ooomD0?ooo`00803oool00`000000oooo0000000f0?ooo`030000003oool0oooo0?l0
ooooE@3oool00200oooo00<000000?ooo`000000=P3oool00`000000oooo0?ooo`3o0?oooeD0oooo
000P0?ooo`030000003oool0000003D0oooo00<000000?ooo`3oool0o`3ooomF0?ooo`0000<0oooo
0000000000001@0000030?ooo`@000001@3oool4000000P0oooo00@000000?ooo`3oool00000=03o
ool00`000000oooo0?ooo`3o0?oooeH0oooo00040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3o
ool010000000oooo0?ooo`00000c0?ooo`030000003oool0oooo0?l0ooooE`3oool000@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000003<0oooo00<000000?ooo`3o
ool0o`3ooomG0?ooo`00103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3o
ool00000<P3oool00`000000oooo0?ooo`3o0?oooeP0oooo00040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool01@3oool400000380oooo00<000000?ooo`3oool0o`3ooomH0?ooo`00103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000<P3oool00`000000oooo0?ooo`3o
0?oooeP0oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`00
000a0?ooo`030000003oool0oooo0?l0ooooF@3oool00080oooo0`0000050?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00@0
00000?ooo`3oool00000<@3oool00`000000oooo0?ooo`3o0?oooeT0oooo00040?ooo`030000003o
ool0oooo00@0oooo100000050?ooo`@00000203oool010000000oooo0?ooo`00000`0?ooo`030000
003oool0oooo0?l0ooooFP3oool00200oooo00@000000?ooo`3oool00000<03oool00`000000oooo
0?ooo`3o0?oooeX0oooo000P0?ooo`040000003oool0oooo00000300oooo00<000000?ooo`3oool0
o`3ooomJ0?ooo`00803oool010000000oooo0?ooo`00000_0?ooo`030000003oool0oooo0?l0oooo
F`3oool00200oooo00@000000?ooo`3oool00000;`3oool00`000000oooo0?ooo`3o0?oooe/0oooo
000P0?ooo`80000000<0oooo0000003oool0;@3oool00`000000oooo0?ooo`3o0?oooe`0oooo000P
0?ooo`040000003oool0oooo000002h0oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00803oool0
10000000oooo0?ooo`00000]0?ooo`030000003oool0oooo0?l0ooooG@3oool00200oooo00D00000
0?ooo`3oool0oooo0000000/0?ooo`030000003oool0oooo0?l0ooooG@3oool00200oooo00D00000
0?ooo`3oool0oooo0000000/0?ooo`030000003oool0oooo0?l0ooooG@3oool00200oooo00D00000
0?ooo`3oool0oooo0000000[0?ooo`030000003oool0oooo0?l0ooooGP3oool00200oooo00D00000
0?ooo`3oool0oooo0000000[0?ooo`030000003oool0oooo0?l0ooooGP3oool00200oooo00D00000
0?ooo`3oool0oooo0000000Z0?ooo`030000003oool0oooo0?l0ooooG`3oool00200oooo00D00000
0?ooo`3oool0oooo0000000Z0?ooo`030000003oool0oooo0?l0ooooG`3oool00200oooo0P000002
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`00803oool01@00
0000oooo0?ooo`3oool0000002T0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`00803oool01@00
0000oooo0?ooo`3oool0000002T0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`00803oool01@00
0000oooo0?ooo`3oool0000002P0oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`00803oool01@00
0000oooo0?ooo`3oool0000002P0oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`00803oool01@00
0000oooo0?ooo`3oool0000002L0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`00803oool01@00
0000oooo0?ooo`3oool0000002L0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`00803oool01@00
0000oooo0?ooo`3oool0000002L0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`00803oool01@00
0000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool0o`3ooomS0?ooo`00803oool20000
0080oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`3o0?ooof<0oooo000P0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?ooof@0
oooo000P0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`3o0?ooof@0oooo000P0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`3o0?ooofD0oooo000P0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?ooofD0oooo000P0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?ooofD0oooo000P0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`3o0?ooofH0
oooo000P0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`3o0?ooofH0oooo000P0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`3o0?ooofH0oooo000P0?ooo`8000000`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo0?l0ooooIP3oool00200oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0ooooI`3oool00200oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0ooooI`3oool00200oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0oooo
I`3oool00200oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo0?l0ooooJ03oool000030?ooo`000000000000@00000103oool4000000D0oooo10000008
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3o
0?ooofP0oooo00000`3oool000000?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0o`3ooomX0?ooo`000P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo0?l0ooooJ03oool000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`3o0?ooofT0oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool3000000<0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`3o0?ooofT0oooo00050?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0o`3ooomY0?ooo`0000<0oooo0000003oool00`3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0?l0oooo
JP3oool000030?ooo`000000oooo00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`3o0?ooofX0oooo00020?ooo`@00000
1@3oool4000000D0oooo100000080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`3o0?ooofX0oooo000P0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`3o0?ooofX0oooo000P0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`3o0?ooof/0oooo000P0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`3o0?oo
of/0oooo000P0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`3o0?ooof/0oooo000P0?ooo`800000103oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo0?l0ooooJ`3oool00200oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo0?l0ooooK03oool00200oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0ooooK03oool00200oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0ooooK03oool00200
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0?l0
ooooK@3oool00200oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo0?l0ooooK@3oool00200oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo0?l0ooooK@3oool00200oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0ooooK@3oool00200oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0ooooKP3oool00200
oooo0P0000050?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`00
803oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
o`3ooom^0?ooo`00803oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0o`3ooom^0?ooo`00803oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`00803oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooom_0?ooo`00803oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooom_0?ooo`00
803oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
o`3ooom_0?ooo`00803oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0o`3ooom_0?ooo`00803oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0o`3ooom_0?ooo`00803oool2000000D0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`3o0?ooofl0oooo000P0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3o0?ooofl0oooo000P0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?ooog00oooo
000P0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`3o0?ooog00oooo000P0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`3o0?ooog00oooo000P0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`3o0?ooog00oooo000P0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?ooog00oooo000P0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?ooog00oooo
000P0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`3o0?ooog00oooo000P0?ooo`8000001P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo0?l0ooooL03oool00200oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo0?l0ooooL@3oool00200oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0ooooL@3oool00200oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0ooooL@3oool00200oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0ooooL@3o
ool00080oooo100000050?ooo`@000001@3oool4000000P0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0ooooL@3oool000030?ooo`000000oooo
00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`3o0?ooog40oooo00060?ooo`050000003oool0oooo0?ooo`000000103o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0o`3oooma0?ooo`001P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0?l0ooooLP3oool000@0oooo0P0000040?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo0`0000050?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooomb0?ooo`001P3oool01@000000oooo
0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0?l0ooooLP3oool000H0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`3o0?ooog80oooo00000`3oool000000?ooo`030?oo
o`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0o`3ooomb0?ooo`000P3oool4000000D0oooo100000050?ooo`@00000203oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0o`3ooomb
0?ooo`00803oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0o`3ooomb0?ooo`00803oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0o`3ooomc0?ooo`00803oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`00803oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`00803oool2
000000L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooog<0oooo000P0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?oo
og<0oooo000P0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`3o0?ooog<0oooo000P0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`3o0?ooog<0oooo000P0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?ooog@0oooo000P0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?ooog@0oooo000P0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?oo
og@0oooo000P0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`3o0?ooog@0oooo000P0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`3o0?ooog@0oooo000P0?ooo`800000203oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0?l0ooooM03oool00200oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooM03oool00200oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooM03oool00200
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0
ooooM@3oool00200oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0?l0ooooM@3oool00200oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0?l0ooooM@3oool00200oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooM@3oool00200oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooM@3oool00200
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0
ooooM@3oool00200oooo0P0000080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
o`3ooome0?ooo`00803oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0o`3ooomf0?ooo`00803oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0o`3ooomf0?ooo`00803oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooomf0?ooo`00803oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooomf0?ooo`00
803oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
o`3ooomf0?ooo`00803oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0o`3ooomf0?ooo`00803oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0o`3ooomf0?ooo`00803oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooomf0?ooo`00803oool2000000T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooogL0oooo000P0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooogL0oooo
000P0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`3o0?ooogL0oooo000P0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`3o0?ooogL0oooo000P0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`3o0?ooogL0oooo00030?ooo`@00000103oool4000000D0
oooo100000080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`3o0?ooogL0oooo00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooomg0?ooo`00
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooM`3oool000030?ooo`000000000000@00000
0`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`3o0?ooogL0oooo00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool30000
00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooogP0oooo00020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0o`3ooomh0?ooo`000`3oool00`000000oooo000000040?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0?l0ooooN03oool000<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooogP0oooo00040?oo
o`8000001@3oool4000000D0oooo100000080?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`3o0?ooogP0oooo000P0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooogP0oooo000P0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooogP0oooo
000P0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`3o0?ooogP0oooo000P0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`3o0?ooogP0oooo000P0?ooo`8000002P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0?l0ooooN03oool00200oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooN@3oool00200oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooN@3oool00200oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooN@3o
ool00200oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0?l0ooooN@3oool00200oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0?l0ooooN@3oool00200oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooN@3oool00200oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooN@3oool00200oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooN@3o
ool00200oooo0P00000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooomi
0?ooo`00803oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0o`3ooomj0?ooo`00803oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0o`3ooomj0?ooo`00803oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooomj0?ooo`00803oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooomj0?ooo`00803oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooomj
0?ooo`00803oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0o`3ooomj0?ooo`00803oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0o`3ooomj0?ooo`00803oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooomj0?ooo`00803oool2000000`0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooogX0oooo000P0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooog/0oooo000P0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?oo
og/0oooo000P0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`3o0?ooog/0oooo000P0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`3o0?ooog/0oooo000P0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooog/0oooo000P0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooog/0oooo000P0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?oo
og/0oooo000P0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`3o0?ooog/0oooo000P0?ooo`800000303oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0?l0ooooN`3oool00200oooo00<000000?ooo`3oool02`3oool01@000000oooo0?oo
o`3oool000000?l0ooooOP3oool00200oooo00<000000?ooo`3oool02`3oool01@000000oooo0?oo
o`3oool000000?l0ooooOP3oool00200oooo00<000000?ooo`3oool02`3oool01@000000oooo0?oo
o`3oool000000?l0ooooOP3oool00200oooo00<000000?ooo`3oool0303oool010000000oooo0?oo
o`00003o0?ooogh0oooo00020?ooo`@000001@3oool4000000D0oooo100000080?ooo`030000003o
ool0oooo00`0oooo00@000000?ooo`3oool00000o`3ooomn0?ooo`0000<0oooo0000003oool00`3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00003o0?oo
ogh0oooo00060?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0
oooo00000?l0ooooOP3oool000H0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo
00@000000?ooo`3oool00000o`3ooomn0?ooo`001P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo0`00000<0?oo
o`040000003oool0oooo00000?l0ooooOP3oool00080oooo100000040?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0303oool010000000oooo0?ooo`00003o0?ooogh0oooo00020?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool000000?l0ooooO`3o
ool00080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`000000o`3ooomo0?ooo`000P3oool5000000@0oooo100000050?ooo`@00000203oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool000000?l0ooooO`3oool00200oooo00<000000?oo
o`3oool0303oool00`000000oooo0000003o0?ooogl0oooo000P0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`000000o`3ooomo0?ooo`00803oool00`000000oooo0?ooo`0<0?ooo`030000
003oool000000?l0ooooO`3oool00200oooo0P00000=0?ooo`030000003oool000000?l0ooooO`3o
ool00200oooo00<000000?ooo`3oool03@3oool200000?l0ooooO`3oool00200oooo00<000000?oo
o`3oool03@3oool200000?l0ooooO`3oool00200oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`3o0?ooogh0oooo000P0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
o`3ooomn0?ooo`00803oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooOP3o
ool00200oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooogh0oooo000P0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooomn0?ooo`00803oool00`000000
oooo0?ooo`3o0?ooohh0oooo000P0?ooo`800000o`3ooon?0?ooo`00803oool00`000000oooo0?oo
o`3o0?ooohh0oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3oool00200oooo00<000000?oo
o`3oool0o`3ooon>0?ooo`00803oool00`000000oooo0?ooo`3o0?ooohh0oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.196126, -42.1873, \
0.00916206, 3.33477}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["\<\
The graphic form suggests that the bellow function could be appropriated  to \
fit the data\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(b[t_] = 
      a\ t\ Exp[b\ t]\  /. 
        FindFit[dataCateter, a\ t\ Exp[b\ t]\ , {a, \ b}, t]\)], "Input",
  CellLabel->"In[21]:=",
  CellTags->"FindFit"],

Cell[BoxData[
    \(12973.659983634852`\ \[ExponentialE]\^\(\(-11.151767794865503`\)\ t\)\ \
t\)], "Output",
  CellLabel->"Out[21]=",
  CellTags->"FindFit"]
}, Open  ]],

Cell["\<\
Here they are shown experimental data and the fitted function\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[b[t]\ , \ {t, 0, 5}, \ 
      Epilog \[Rule] \ Map[Point, \ dataCateter], \ 
      PlotRange -> \ {0, 550}]; \)], "Input",
  CellLabel->"In[22]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 2.81893e-017 0.0011237 [
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .11237 -18 -4.5 ]
[.01131 .11237 0 4.5 ]
[.01131 .22474 -18 -4.5 ]
[.01131 .22474 0 4.5 ]
[.01131 .33711 -18 -4.5 ]
[.01131 .33711 0 4.5 ]
[.01131 .44948 -18 -4.5 ]
[.01131 .44948 0 4.5 ]
[.01131 .56185 -18 -4.5 ]
[.01131 .56185 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(1)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(2)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(3)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(4)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(5)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .11237 m
.03006 .11237 L
s
[(100)] .01131 .11237 1 0 Mshowa
.02381 .22474 m
.03006 .22474 L
s
[(200)] .01131 .22474 1 0 Mshowa
.02381 .33711 m
.03006 .33711 L
s
[(300)] .01131 .33711 1 0 Mshowa
.02381 .44948 m
.03006 .44948 L
s
[(400)] .01131 .44948 1 0 Mshowa
.02381 .56185 m
.03006 .56185 L
s
[(500)] .01131 .56185 1 0 Mshowa
.125 Mabswid
.02381 .02247 m
.02756 .02247 L
s
.02381 .04495 m
.02756 .04495 L
s
.02381 .06742 m
.02756 .06742 L
s
.02381 .0899 m
.02756 .0899 L
s
.02381 .13484 m
.02756 .13484 L
s
.02381 .15732 m
.02756 .15732 L
s
.02381 .17979 m
.02756 .17979 L
s
.02381 .20227 m
.02756 .20227 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26969 m
.02756 .26969 L
s
.02381 .29216 m
.02756 .29216 L
s
.02381 .31464 m
.02756 .31464 L
s
.02381 .35958 m
.02756 .35958 L
s
.02381 .38206 m
.02756 .38206 L
s
.02381 .40453 m
.02756 .40453 L
s
.02381 .42701 m
.02756 .42701 L
s
.02381 .47195 m
.02756 .47195 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .5169 m
.02756 .5169 L
s
.02381 .53938 m
.02756 .53938 L
s
.02381 .58432 m
.02756 .58432 L
s
.02381 .6068 m
.02756 .6068 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02605 .15068 L
.02846 .27095 L
.03072 .35301 L
.03279 .40619 L
.03405 .43027 L
.03521 .44762 L
.03649 .4619 L
.03713 .46741 L
.03784 .47228 L
.03903 .47785 L
.04031 .48063 L
.04151 .48061 L
.04262 .47862 L
.04384 .47453 L
.04514 .4683 L
.04748 .45315 L
.05278 .40662 L
.06244 .30796 L
.07382 .20478 L
.07941 .16417 L
.08454 .13276 L
.09417 .08754 L
.09923 .06977 L
.10458 .05463 L
.11406 .03504 L
.11937 .02719 L
.12422 .02151 L
.12873 .01726 L
.13363 .01356 L
.14255 .0087 L
.1474 .00681 L
.15195 .00541 L
.15694 .0042 L
.16233 .00319 L
.16766 .00242 L
.17329 .00181 L
.17808 .00141 L
.18333 .00107 L
.18862 .00081 L
.19361 .00063 L
.19809 .00049 L
.20294 .00038 L
.20824 .00029 L
.21384 .00021 L
.21863 .00017 L
.22389 .00013 L
.22911 9e-005 L
.23406 7e-005 L
.2385 6e-005 L
Mistroke
.24334 4e-005 L
.24859 3e-005 L
.25418 2e-005 L
.25946 2e-005 L
.26423 1e-005 L
.26912 1e-005 L
.27428 1e-005 L
.27869 1e-005 L
.28352 0 L
.28873 0 L
.2943 0 L
.29956 0 L
.30435 0 L
.30918 0 L
.31429 0 L
.31866 0 L
.32348 0 L
.32864 0 L
.3342 0 L
.33945 0 L
.34425 0 L
.34901 0 L
.35408 0 L
.35887 0 L
.36321 0 L
.36833 0 L
.37387 0 L
.37911 0 L
.38393 0 L
.38862 0 L
.39365 0 L
.3984 0 L
.40273 0 L
.4078 0 L
.41333 0 L
.41855 0 L
.42338 0 L
.42801 0 L
.43299 0 L
.4377 0 L
.44202 0 L
.44681 0 L
.45205 0 L
.45752 0 L
.46262 0 L
.46766 0 L
.47312 0 L
.47828 0 L
.48305 0 L
.48734 0 L
Mistroke
.49207 0 L
.49701 0 L
.50163 0 L
.5066 0 L
.51202 0 L
.51714 0 L
.52189 0 L
.5266 0 L
.53086 0 L
.53579 0 L
.54042 0 L
.54508 0 L
.55019 0 L
.55553 0 L
.56051 0 L
.56518 0 L
.56943 0 L
.57434 0 L
.57899 0 L
.58359 0 L
.58866 0 L
.59395 0 L
.59892 0 L
.60354 0 L
.60779 0 L
.61244 0 L
.61734 0 L
.62235 0 L
.6269 0 L
.63214 0 L
.6371 0 L
.64169 0 L
.64592 0 L
.65056 0 L
.65547 0 L
.66041 0 L
.66492 0 L
.67012 0 L
.67506 0 L
.67961 0 L
.68383 0 L
.68845 0 L
.69338 0 L
.69876 0 L
.7037 0 L
.70912 0 L
.71484 0 L
.71983 0 L
.72448 0 L
.72958 0 L
Mistroke
.73503 0 L
.74034 0 L
.74524 0 L
.75062 0 L
.75633 0 L
.76127 0 L
.76591 0 L
.77099 0 L
.77646 0 L
.7817 0 L
.78656 0 L
.7919 0 L
.79759 0 L
.80301 0 L
.80812 0 L
.81271 0 L
.81768 0 L
.82259 0 L
.82718 0 L
.83221 0 L
.83761 0 L
.84326 0 L
.84862 0 L
.85343 0 L
.85867 0 L
.86351 0 L
.86806 0 L
.87305 0 L
.87843 0 L
.88377 0 L
.88939 0 L
.89419 0 L
.89944 0 L
.90472 0 L
.90971 0 L
.91418 0 L
.91904 0 L
.92433 0 L
.92994 0 L
.93472 0 L
.93999 0 L
.94466 0 L
.9491 0 L
.95309 0 L
.95744 0 L
.96215 0 L
.96717 0 L
.9719 0 L
.97619 0 L
Mfstroke
.008 w
.02381 .00343 Mdot
.03333 .32187 Mdot
.04286 .60086 Mdot
.05238 .41604 Mdot
.0619 .27003 Mdot
.07143 .19103 Mdot
.08095 .14451 Mdot
.09048 .0948 Mdot
.1 .07482 Mdot
.10952 .05879 Mdot
.11905 .04529 Mdot
.12857 .03234 Mdot
.1381 .02332 Mdot
.14762 .01823 Mdot
.15714 .01595 Mdot
.16667 .01477 Mdot
.17619 .01194 Mdot
.18571 .00851 Mdot
.19524 .00833 Mdot
.20476 .00565 Mdot
.21429 .00415 Mdot
.22381 .00493 Mdot
.23333 .00356 Mdot
.24286 .00355 Mdot
.25238 .00287 Mdot
.2619 .00262 Mdot
.27143 .00243 Mdot
.28095 .00236 Mdot
.29048 .00183 Mdot
.3 .00162 Mdot
.30952 .00058 Mdot
.31905 .00128 Mdot
.32857 .00096 Mdot
.3381 .00086 Mdot
.34762 .00082 Mdot
.35714 .00087 Mdot
.36667 .00053 Mdot
.37619 .00044 Mdot
.38571 .00058 Mdot
.40032 .00039 Mdot
.41943 .00031 Mdot
.43848 .00016 Mdot
.45752 .0001 Mdot
.47657 1e-005 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[22]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00K03oool7000004H0oooo1P0000170?ooo`@00000B@3oool4000004L0oooo1000000>0?oo
o`00K`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo001_0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`180?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool02`3oool006l0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo04@0oooo1P00001;0?ooo`030000003o
ool0oooo00/0oooo001_0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0B@3oool2
000004P0oooo00@000000?ooo`3oool00000C03oool00`000000oooo0?ooo`0;0?ooo`00K`3oool0
0`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0A@3oool0
10000000oooo0?ooo`0000180?ooo`@000003P3oool006l0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo000000180?ooo`030000003oool0oooo00l0oooo001]0?ooo`<00000B@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`160?ooo`030000003oool0000004P0oooo00<000000?ooo`3oool03`3oool006l0
oooo00<000000?ooo`3oool0B03oool4000004P0oooo1000001:0?ooo`800000B03oool5000000d0
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo000J0?ooool00000TP0000050?oo
o`00903oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`070?ooo`X000001`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`03000000050?ooo`000000
00000000003oool00`0000000`3oool0000000000004000000040?ooo`000000000000000080oooo
00<000000?ooo`3oool00`0000000`3oool0000000000004000000050?ooo`00000000000000003o
ool00`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0000000D0oooo00<000000?ooo`3oool01@3oool2000000D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0000000>0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo000S0?ooo`<0
00003@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00`3oool4000000H0oooo00<000000?ooo`3oool01`3oool3000000050?ooo`00000000000000
003oool01P000000103oool000000000000000020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000070?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo0000000>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo000T0?ooo`030000003oool0
oooo02h0oooo0P00000=0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo00`0oooo000T0?ooo`030000003oool0oooo02`0oooo0P00000<0?ooo`030000
003oool000000080000000@0oooo0000000000000000o`3ooom70?ooo`00903oool00`000000oooo
0?ooo`0Z0?ooo`8000002P3oool00`000000oooo0?ooo`03000000030?ooo`000000oooo0080oooo
00<000000?ooo`3oool0o`3ooom60?ooo`00903oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`<000000P3oool00`000000oooo
0?ooo`3o0?ooodd0oooo000T0?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`<0000000@0
oooo00000000000000000P3oool00`000000oooo0?ooo`3o0?oooe40oooo000T0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool000000?l0oooo
E`3oool002@0oooo0P00000V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3o
oomM0?ooo`00903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo0`00003o
0?oooeh0oooo000T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`3o0?oooed0oooo000T0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`3o0?ooof00oooo000T0?ooo`030000003oool0oooo0280oooo
00@000000?ooo`3oool0oooo0`00003o0?ooof40oooo000T0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooof00oooo000T0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool0o`3ooomW0?ooo`00903oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo0?l0ooooI`3oool002@0oooo00<000000?ooo`3oool07`3oool01@00
0000oooo0?ooo`3oool000000?l0ooooIP3oool002@0oooo0P00000P0?ooo`030000003oool0oooo
00<00000o`3ooomU0?ooo`00903oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0o`3ooomT0?ooo`00903oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo0?l0ooooJ@3oool002@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`3o0?ooofX0oooo000T0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0o`3ooomZ
0?ooo`00903oool00`000000oooo0?ooo`0M0?ooo`030000003oool000000?l0ooooJP3oool002@0
oooo00<000000?ooo`3oool0703oool00`000000oooo0000000200000?l0ooooJ@3oool002@0oooo
00<000000?ooo`3oool0703oool010000000oooo0?ooo`00003o0?ooofX0oooo000T0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0o`3ooom[0?ooo`00903oool2000001`0oooo00<0
00000?ooo`3oool0o`3ooom/0?ooo`00903oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo0?l0ooooK03oool002@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`3o0?oo
of`0oooo000T0?ooo`030000003oool0oooo01X0oooo0`00003o0?ooofd0oooo000T0?ooo`800000
6`3oool200000?l0ooooKP3oool002@0oooo0P00000K0?ooo`030000003oool0oooo0?l0ooooK@3o
ool002@0oooo0P00000K0?ooo`030000003oool0oooo0?l0ooooK@3oool002@0oooo0P00000J0?oo
o`030000003oool0oooo0?l0ooooKP3oool002@0oooo0P00000J0?ooo`030000003oool0oooo0?l0
ooooKP3oool002@0oooo0P00000J0?ooo`030000003oool0oooo0?l0ooooKP3oool002@0oooo0P00
000H0?ooo`030000003oool000000?l0ooooL03oool002@0oooo0P00000G0?ooo`<00000o`3oooma
0?ooo`00903oool2000001P0oooo0P00003o0?ooog40oooo000T0?ooo`8000006@3oool00`000000
oooo0?ooo`3o0?ooofl0oooo000T0?ooo`8000006@3oool00`000000oooo0?ooo`3o0?ooofl0oooo
00050?ooo`L000000`3oool4000000D0oooo100000080?ooo`800000603oool00`000000oooo0?oo
o`3o0?ooog00oooo00080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool2000001P0oooo00<0
00000?ooo`3oool0o`3ooom`0?ooo`00203oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo0P00
000H0?ooo`030000003oool0oooo0?l0ooooL03oool000P0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`050?ooo`<000005`3oool00`000000oooo0?ooo`3o0?ooog00oooo00080?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool01@3oool2000001P0oooo00<000000?ooo`3oool0o`3ooom`0?ooo`00203oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo00D0oooo0P00000G0?ooo`030000003oool0oooo0?l0ooooL@3o
ool000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`8000005`3oool00`000000oooo0?oo
o`3o0?ooog40oooo00060?ooo`<000001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`8000005`3oool00`000000oooo0?oo
o`3o0?ooog40oooo00080?ooo`030000003oool0oooo00@0oooo100000050?ooo`@00000203oool2
000001L0oooo00<000000?ooo`3oool0o`3oooma0?ooo`00903oool2000001H0oooo00<000000?oo
o`3oool0o`3ooomb0?ooo`00903oool2000001H0oooo00<000000?ooo`3oool0o`3ooomb0?ooo`00
903oool2000001H0oooo00<000000?ooo`3oool0o`3ooomb0?ooo`00903oool2000001H0oooo00<0
00000?ooo`3oool0o`3ooomb0?ooo`00903oool2000001H0oooo00<000000?ooo`3oool0o`3ooomb
0?ooo`00903oool2000001H0oooo00<000000?ooo`3oool0o`3ooomb0?ooo`00903oool2000001@0
oooo0P00003o0?ooogD0oooo000T0?ooo`8000004`3oool300000?l0ooooM@3oool002@0oooo0P00
000D0?ooo`800000o`3ooome0?ooo`00903oool2000001D0oooo00<000000?ooo`3oool0o`3ooomc
0?ooo`00903oool2000001D0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`00903oool2000001D0
oooo00<000000?ooo`3oool0o`3ooomc0?ooo`00903oool2000001@0oooo00<000000?ooo`3oool0
o`3ooomd0?ooo`00903oool2000001@0oooo00<000000?ooo`3oool0o`3ooomd0?ooo`00903oool2
000001@0oooo00<000000?ooo`3oool0o`3ooomd0?ooo`00903oool2000001@0oooo00<000000?oo
o`3oool0o`3ooomd0?ooo`00903oool2000001@0oooo00<000000?ooo`3oool0o`3ooomd0?ooo`00
903oool2000001@0oooo00<000000?ooo`3oool0o`3ooomd0?ooo`00903oool2000001@0oooo00<0
00000?ooo`3oool0o`3ooomd0?ooo`00903oool2000001<0oooo00<000000?ooo`3oool0o`3ooome
0?ooo`00903oool2000001<0oooo00<000000?ooo`3oool0o`3ooome0?ooo`00903oool2000001<0
oooo00<000000?ooo`3oool0o`3ooome0?ooo`00903oool2000001<0oooo00<000000?ooo`3oool0
o`3ooome0?ooo`00903oool2000001<0oooo00<000000?ooo`3oool0o`3ooome0?ooo`00903oool2
000001<0oooo00<000000?ooo`3oool0o`3ooome0?ooo`00903oool200000140oooo00<000000?oo
o`000000o`3ooomg0?ooo`00903oool200000100oooo1000003o0?ooogL0oooo000T0?ooo`800000
4@3oool200000?l0ooooN03oool002@0oooo0P00000B0?ooo`030000003oool0oooo0?l0ooooMP3o
ool002@0oooo0P00000B0?ooo`030000003oool0oooo0?l0ooooMP3oool002@0oooo0P00000B0?oo
o`030000003oool0oooo0?l0ooooMP3oool002@0oooo0P00000B0?ooo`030000003oool0oooo0?l0
ooooMP3oool002@0oooo0P00000B0?ooo`030000003oool0oooo0?l0ooooMP3oool002@0oooo0P00
000B0?ooo`030000003oool0oooo0?l0ooooMP3oool002@0oooo00<000000?ooo`0000004@3oool0
0`000000oooo0?ooo`3o0?ooogH0oooo000T0?ooo`030000003oool000000140oooo00<000000?oo
o`3oool0o`3ooomf0?ooo`001@3oool6000000@0oooo100000050?ooo`@00000203oool00`000000
oooo0000000@0?ooo`030000003oool0oooo0?l0ooooM`3oool000D0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`3o0?oo
ogL0oooo00060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000000@0?oo
o`030000003oool0oooo0?l0ooooM`3oool000L0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?oo
o`<00000403oool00`000000oooo0?ooo`3o0?ooogL0oooo00080?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0000000@0?ooo`030000003oool0oooo0?l0ooooM`3oool000T0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`050?ooo`030000003oool000000100oooo00<000000?oo
o`3oool0o`3ooomg0?ooo`001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0000000@0?ooo`030000003oool0oooo0?l0ooooM`3oool000D0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000403oool00`000000oooo0?oo
o`3o0?ooogL0oooo00060?ooo`@000001@3oool4000000D0oooo100000080?ooo`030000003oool0
000000l0oooo00<000000?ooo`3oool0o`3ooomh0?ooo`00903oool00`000000oooo0000000?0?oo
o`030000003oool0oooo0?l0ooooN03oool002@0oooo00<000000?ooo`0000003`3oool00`000000
oooo0?ooo`3o0?ooogP0oooo000T0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool0
o`3ooomh0?ooo`00903oool3000000l0oooo00<000000?ooo`3oool0o`3ooomh0?ooo`00903oool0
0`000000oooo0000000?0?ooo`030000003oool0oooo0?l0ooooN03oool002@0oooo00<000000?oo
o`0000003`3oool00`000000oooo0?ooo`3o0?ooogP0oooo000T0?ooo`030000003oool0000000l0
oooo00<000000?ooo`3oool0o`3ooomh0?ooo`00903oool00`000000oooo0000000>0?ooo`030000
003oool0oooo0?l0ooooN@3oool002@0oooo00<000000?ooo`0000003P3oool00`000000oooo0?oo
o`3o0?ooogT0oooo000T0?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool0o`3ooomi
0?ooo`00903oool00`000000oooo0000000>0?ooo`030000003oool0oooo0?l0ooooN@3oool002@0
oooo00<000000?ooo`000000303oool00`000000oooo0000003o0?ooog/0oooo000T0?ooo`<00000
2`3oool400000?l0ooooN`3oool002@0oooo00<000000?ooo`000000303oool00`000000oooo0000
003o0?ooog/0oooo000T0?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool0o`3ooomi
0?ooo`00903oool00`000000oooo0000000=0?ooo`030000003oool0oooo0?l0ooooNP3oool002@0
oooo00<000000?ooo`0000003@3oool00`000000oooo0?ooo`3o0?ooogX0oooo000T0?ooo`030000
003oool0000000d0oooo00<000000?ooo`3oool0o`3ooomj0?ooo`00903oool00`000000oooo0000
000=0?ooo`030000003oool0oooo0?l0ooooNP3oool002@0oooo00<000000?ooo`0000003@3oool0
0`000000oooo0?ooo`3o0?ooogX0oooo000T0?ooo`030000003oool0000000d0oooo00<000000?oo
o`3oool0o`3ooomj0?ooo`00903oool3000000d0oooo00<000000?ooo`3oool0o`3ooomj0?ooo`00
903oool00`000000oooo0000000=0?ooo`030000003oool0oooo0?l0ooooNP3oool002@0oooo00<0
00000?ooo`000000303oool00`000000oooo0?ooo`3o0?ooog/0oooo000T0?ooo`030000003oool0
000000`0oooo00<000000?ooo`3oool0o`3ooomk0?ooo`00903oool00`000000oooo0000000<0?oo
o`030000003oool0oooo0?l0ooooN`3oool002@0oooo00<000000?ooo`000000303oool00`000000
oooo0?ooo`3o0?ooog/0oooo000T0?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0
o`3ooomk0?ooo`00903oool00`000000oooo0000000<0?ooo`030000003oool0oooo0?l0ooooN`3o
ool002@0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`3o0?ooog/0oooo000T0?oo
o`<00000303oool00`000000oooo0?ooo`3o0?ooog/0oooo000T0?ooo`030000003oool0000000`0
oooo00<000000?ooo`3oool0o`3ooomk0?ooo`00903oool010000000oooo00000000000:0?ooo`03
0000003oool0oooo0?l0ooooO03oool002@0oooo00<000000?ooo`0000000P0000090?ooo`030000
003oool0oooo0?l0ooooO03oool002@0oooo00@000000?ooo`00000000002P3oool00`000000oooo
0?ooo`3o0?ooog`0oooo000T0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool0o`3o
ooml0?ooo`001P3oool4000000D0oooo100000050?ooo`@00000203oool00`000000oooo0000000;
0?ooo`030000003oool0oooo0?l0ooooO03oool000D0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`3o0?ooog`0oooo000:
0?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo0?l0oooo
O03oool000X0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`050?ooo`<000002`3oool00`000000oooo0?ooo`3o0?ooog`0
oooo00080?ooo`800000103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`050?ooo`030000003oool0000000/0oooo00<000000?ooo`3o
ool0o`3oooml0?ooo`002P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000002`3oool00`00
0000oooo0?ooo`3o0?ooog`0oooo000:0?ooo`050000003oool0oooo0?ooo`000000103oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000000:
0?ooo`030000003oool0oooo0?l0ooooO@3oool000D0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`3o0?ooogd0oooo0006
0?ooo`@000001@3oool4000000D0oooo100000080?ooo`030000003oool0000000X0oooo00<00000
0?ooo`3oool0o`3ooomm0?ooo`00903oool00`000000oooo0000000:0?ooo`030000003oool0oooo
0?l0ooooO@3oool002@0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`3o0?ooogd0
oooo000T0?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00903o
ool3000000X0oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00903oool00`000000oooo0000000:
0?ooo`030000003oool0oooo0?l0ooooO@3oool002@0oooo00<000000?ooo`0000002P3oool00`00
0000oooo0?ooo`3o0?ooogd0oooo000T0?ooo`030000003oool0000000X0oooo00<000000?ooo`3o
ool0o`3ooomm0?ooo`00903oool00`000000oooo000000090?ooo`030000003oool0oooo0?l0oooo
OP3oool002@0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`3o0?ooogh0oooo000T
0?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0o`3ooomn0?ooo`00903oool00`00
0000oooo000000090?ooo`030000003oool0oooo0?l0ooooOP3oool002@0oooo00<000000?ooo`00
00002@3oool00`000000oooo0?ooo`3o0?ooogh0oooo000T0?ooo`80000000<0oooo0000003oool0
1`3oool00`000000oooo0?ooo`3o0?ooogh0oooo000T0?ooo`040000003oool0oooo000000P0oooo
00<000000?ooo`3oool0o`3ooomn0?ooo`00903oool010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo0?l0ooooOP3oool002@0oooo00@000000?ooo`3oool00000203oool00`000000oooo
0?ooo`3o0?ooogh0oooo000T0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0
o`3ooomn0?ooo`00903oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0?l0oooo
O`3oool002@0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`3o0?ooogl0oooo
000T0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00903o
ool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0?l0ooooO`3oool002@0oooo0P00
00000`3oool000000?ooo`060?ooo`030000003oool0oooo0?l0ooooO`3oool002@0oooo00@00000
0?ooo`3oool000001`3oool00`000000oooo0?ooo`3o0?ooogl0oooo000T0?ooo`040000003oool0
oooo000000L0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00903oool010000000oooo0?ooo`00
00070?ooo`030000003oool0oooo0?l0ooooO`3oool002@0oooo00@000000?ooo`3oool000001`3o
ool00`000000oooo0?ooo`3o0?ooogl0oooo000T0?ooo`040000003oool0oooo000000H0oooo0`00
003o0?oooh00oooo000T0?ooo`050000003oool0oooo0?ooo`0000001@3oool200000?l0ooooP@3o
ool002@0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0?l0ooooP03o
ool002@0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0?l0ooooP03o
ool002@0oooo0P0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooon0
0?ooo`00903oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0o`3ooon0
0?ooo`00903oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0o`3ooon0
0?ooo`00903oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0o`3ooon0
0?ooo`00903oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0o`3ooon0
0?ooo`00903oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0o`3ooon0
0?ooo`001`3oool4000000@0oooo100000050?ooo`@00000203oool01@000000oooo0?ooo`3oool0
000000D0oooo00<000000?ooo`3oool0o`3ooon00?ooo`002@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00D0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0?l0ooooP@3o
ool000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`3o0?oooh40oooo00050?ooo`H000000`3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`<00000
00<0oooo0000003oool00`3oool00`000000oooo0?ooo`3o0?oooh40oooo00060?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool0o`3ooon10?ooo`001P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0?l0ooooP@3oool000L0oooo00<00000
0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
0000003o0?oooh<0oooo00070?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000o`3ooon30?ooo`00203oool2000000D0oooo
100000050?ooo`@00000203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000?l0
ooooQ03oool002@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00003o0?oooh@0
oooo000T0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000o`3ooon40?ooo`00
903oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000?l0ooooQ03oool002@0oooo
0P0000030?ooo`040000003oool0oooo00000?l0ooooQ03oool002@0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`00003o0?oooh@0oooo000T0?ooo`030000003oool0oooo00<0oooo
0P00003o0?ooohD0oooo000T0?ooo`030000003oool0oooo00<0oooo0P00003o0?ooohD0oooo000T
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooon40?ooo`00903oool00`00
0000oooo0?ooo`3o0?ooohX0oooo000T0?ooo`030000003oool0oooo0?l0ooooRP3oool002@0oooo
00<000000?ooo`3oool0o`3ooon:0?ooo`00903oool00`000000oooo0?ooo`3o0?ooohX0oooo000T
0?ooo`800000o`3ooon;0?ooo`00903oool00`000000oooo0?ooo`3o0?ooohX0oooo000T0?ooo`03
0000003oool0oooo0?l0ooooRP3oool002@0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`00903o
ool00`000000oooo0?ooo`3o0?ooohX0oooo000T0?ooo`030000003oool0oooo0?l0ooooRP3oool0
02@0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`00903oool00`000000oooo0?ooo`3o0?ooohX0
oooo000T0?ooo`030000003oool0oooo0?l0ooooRP3oool002@0oooo0P00003o0?oooh/0oooo000T
0?ooo`030000003oool0oooo0?l0ooooRP3oool002@0oooo00<000000?ooo`3oool0o`3ooon:0?oo
o`00903oool00`000000oooo0?ooo`3o0?ooohX0oooo000T0?ooo`030000003oool0oooo0?l0oooo
RP3oool002@0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`00903oool00`000000oooo0?ooo`3o
0?ooohX0oooo000T0?ooo`030000003oool0oooo0?l0ooooRP3oool002@0oooo00<000000?ooo`3o
ool0o`3ooon:0?ooo`00903oool200000?l0ooooR`3oool002@0oooo00<000000?ooo`3oool0o`3o
oon:0?ooo`00903oool00`000000oooo0?ooo`3o0?ooohX0oooo000T0?ooo`030000003oool0oooo
0?l0ooooRP3oool002@0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`00903oool00`000000oooo
0?ooo`3o0?ooohX0oooo00060?ooo`@000001@3oool4000000D0oooo100000080?ooo`030000003o
ool0oooo0?l0ooooRP3oool000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0o`3ooon:0?ooo`002P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0o`3ooon:0?ooo`002P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo00D0oooo0`00003o0?ooohX0oooo000:0?ooo`05
0000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooohX0oooo00060?ooo`@00000103oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0?l0ooooRP3oool000H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0?l0ooooRP3oool000H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0?l0ooooRP3oool000H0oooo1@0000040?ooo`@000001@3oool40000
00P0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`00903oool00`000000oooo0?ooo`3o0?ooohX0
oooo000T0?ooo`030000003oool0oooo0?l0ooooRP3oool002@0oooo00<000000?ooo`3oool0o`3o
oon:0?ooo`00903oool200000?l0ooooR`3oool002@0oooo00<000000?ooo`3oool0o`3ooon:0?oo
o`00903oool00`000000oooo0?ooo`3o0?ooohX0oooo000T0?ooo`030000003oool0oooo0?l0oooo
RP3oool002@0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`00903oool00`000000oooo0?ooo`3o
0?ooohX0oooo000T0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooon30?oo
o`00903oool00`000000oooo0?ooo`030?ooo`<00000o`3ooon40?ooo`00903oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0?l0ooooP`3oool002@0oooo0P00003o0?oooh/0oooo000T
0?ooo`030000003oool0oooo0?l0ooooRP3oool002@0oooo00<000000?ooo`3oool0o`3ooon:0?oo
o`00903oool00`000000oooo0?ooo`3o0?ooohX0oooo000T0?ooo`030000003oool0oooo0?l0oooo
RP3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.474025, -41.1424, \
0.019675, 3.33507}}]
}, Open  ]],

Cell[TextData[{
  "Also it has been measured the experimental data by measuring ",
  Cell[BoxData[
      \(x\_1[t]\)],
    TextAlignment->Left,
    TextJustification->0],
  ". Here is the list {{",
  Cell[BoxData[
      \(TraditionalForm\`t\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1[t\_1]\)]],
  "}, ..., {",
  Cell[BoxData[
      \(TraditionalForm\`t\_n\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1[t\_n]\)]],
  "}}."
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(dataPhysio\  = {{0.03`, 27.5`}, {0.08`, 48.61`}, {0.28`, 
          133.39`}, {0.33`, 106.18`}, {0.38`, 92.11`}, {0.48`, 
          60.47`}, {0.55`, 56.54`}, {0.65`, 27.73`}, {0.75`, 23.25`}, {0.85`, 
          15.83`}, {0.95`, 13.82`}, {1.05`, 10.58`}, {1.15`, 7.83`}, {1.25`, 
          7.35`}, {1.35`, 6.08`}, {1.45`, 5.21`}, {1.6`, 4.18`}, {1.8`, 
          3.48`}, {2.`, 2.86`}, {2.2`, 2.42`}, {2.4`, 2.11`}, {2.6`, 
          2.01`}, {2.8`, 1.7`}, {3.`, 1.58`}, {3.4`, 1.58`}, {3.75`, 
          1.44`}, {4.25`, 1.35`}, {4.75`, 1.3`}, {5.25`, 1.29`}, {6.75`, 
          0.81`}, {7.25`, 0.78`}, {7.75`, 0.73`}, {8.25`, 0.75`}, {11.`, 
          0.68`}}; \)], "Input",
  CellLabel->"In[23]:="],

Cell[TextData[{
  "Now we can build the model. It is assumed that in eq.(1) ",
  Cell[BoxData[
      \(TraditionalForm\`V\_Tb\)]],
  " and Q are known"
}], "Text"],

Cell[BoxData[
    \(\(\(\ \)\(Q\  = \ 3; VTb = 1; \)\)\)], "Input",
  CellLabel->"In[24]:="],

Cell["\<\
Step 1: It is obtained the coefficients matrix using the package function \
CoefMatrix . \
\>", "Text"],

Cell[BoxData[
    \(physiomodel = 
      CoefMatrix[
        3, {{1, 1, \ \(-\((Q\/Vp + \ PS\/Vp)\)\)\ }, {1, 2, \ PS\/Vp}, {2, 
            1, \ PS\/VTu}, {2, 2, \ \(-\((PS\/VTu\  + kon\ )\)\)}, {2, 3, 
            koff\ VTb\/VTu}, {3, 2, \ kon  VTu\/VTb}\ , \ \ {3, 
            3, \ \(-koff\)}}]; \)], "Input",
  CellLabel->"In[25]:="],

Cell[TextData[{
  "Step 2: The input function ",
  Cell[BoxData[
      \(TraditionalForm\`b \((t)\)\)]],
  " in eq. (1) is given by"
}], "Text"],

Cell[BoxData[
    \(inputcatheter = {\(Q\/Vp\) b[t]\ , 0, 0}; \)], "Input",
  CellLabel->"In[26]:="],

Cell[TextData[{
  "In this example are given  ",
  Cell[BoxData[
      \(TraditionalForm\`V\_Tu\)]],
  "= 6.411,",
  Cell[BoxData[
      \(TraditionalForm\`V\_p\)]],
  "=0.973,  PS= 2.714. "
}], "Text"],

Cell[BoxData[
    \(physiomodel1 = 
      physiomodel /. {VTu \[Rule] 6.411, Vp \[Rule] 0.973, 
          PS \[Rule] 2.714}; \)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(inputcatheter1 = inputcatheter /. {Vp \[Rule] 0.973}; \)], "Input",
  CellLabel->"In[28]:="],

Cell[TextData[{
  "Now we want  obtained  ",
  Cell[BoxData[
      \(TraditionalForm\`k\_off\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\_on\)]],
  " for fitting ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\)(t)\)]],
  ". Here they are shown some methods."
}], "Text"],

Cell[CellGroupData[{

Cell["Method 1", "SubsubsectionIcon"],

Cell[TextData[{
  "It is obtained the laplace transform of { ",
  Cell[BoxData[
      \(x\_1[t], x\_2[t], x\_3[t]\)]],
  "} denoted as {",
  Cell[BoxData[
      \(X\_1[s], X\_2[s], X\_3[s]\)]],
  "}. The  initial condition are ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  "(0) =  ",
  Cell[BoxData[
      \(TraditionalForm\`x\_2\)]],
  "(0)  = ",
  Cell[BoxData[
      \(TraditionalForm\`x\_3\)]],
  "(0) = 0. We only will need ",
  Cell[BoxData[
      \(X\_1[s]\)]],
  ".  Thus, the model is specified as follows:"
}], "Text"],

Cell[BoxData[
    \(X1[s_] = 
      X\_1[s] /. SystemLTSolve[physiomodel1, {0, 0, 0}, inputcatheter1, \ t, 
          s, \ X]; \)], "Input",
  CellLabel->"In[29]:="],

Cell[TextData[{
  "Now,   ",
  Cell[BoxData[
      \(x\_1[t]\)], "NumberedEquation",
    TextAlignment->Left,
    TextJustification->0],
  " can be obtained applyind the InverseLaplaceTransform as function of  ",
  Cell[BoxData[
      \(TraditionalForm\`k\_off\)]],
  " and, ",
  Cell[BoxData[
      \(TraditionalForm\`k\_on\)]]
}], "Text"],

Cell[BoxData[
    \(x1[t_, \ off_, \ on_] = 
      InverseLaplaceTransform[X1[s], \ s, \ t] /. {koff -> off\ , \ 
          kon -> on}\ ; \)], "Input",
  CellLabel->"In[30]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(x1bestfit[t_]\)\(=\)\(FindFit[dataPhysio, \ 
        x1[t, \ koff, \ kon], \ {koff, \ kon}, \ t]\)\(\ \)\)\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \({koff \[Rule] 0.10193638680443405`, 
      kon \[Rule] 0.6870935100910409`}\)], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell[TextData[{
  "Here they are compared x1[t]",
  StyleBox[" ", "Input"],
  "and the experimental data"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[Evaluate[x1[t, \ koff, \ kon] /. x1bestfit[t]], \ {t, 0, 11}, \ 
      PlotRange -> \ {0, \ 140}, 
      Epilog :> \ Map[{\ Orange, \ PointSize[ .02], \ Point[##]}\  &, \ 
          dataPhysio]]\)], "Input",
  CellLabel->"In[32]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0865801 -8.67362e-018 0.00441453 [
[.19697 -0.0125 -3 -9 ]
[.19697 -0.0125 3 0 ]
[.37013 -0.0125 -3 -9 ]
[.37013 -0.0125 3 0 ]
[.54329 -0.0125 -3 -9 ]
[.54329 -0.0125 3 0 ]
[.71645 -0.0125 -3 -9 ]
[.71645 -0.0125 3 0 ]
[.88961 -0.0125 -6 -9 ]
[.88961 -0.0125 6 0 ]
[.01131 .08829 -12 -4.5 ]
[.01131 .08829 0 4.5 ]
[.01131 .17658 -12 -4.5 ]
[.01131 .17658 0 4.5 ]
[.01131 .26487 -12 -4.5 ]
[.01131 .26487 0 4.5 ]
[.01131 .35316 -12 -4.5 ]
[.01131 .35316 0 4.5 ]
[.01131 .44145 -18 -4.5 ]
[.01131 .44145 0 4.5 ]
[.01131 .52974 -18 -4.5 ]
[.01131 .52974 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.19697 0 m
.19697 .00625 L
s
[(2)] .19697 -0.0125 0 1 Mshowa
.37013 0 m
.37013 .00625 L
s
[(4)] .37013 -0.0125 0 1 Mshowa
.54329 0 m
.54329 .00625 L
s
[(6)] .54329 -0.0125 0 1 Mshowa
.71645 0 m
.71645 .00625 L
s
[(8)] .71645 -0.0125 0 1 Mshowa
.88961 0 m
.88961 .00625 L
s
[(10)] .88961 -0.0125 0 1 Mshowa
.125 Mabswid
.0671 0 m
.0671 .00375 L
s
.11039 0 m
.11039 .00375 L
s
.15368 0 m
.15368 .00375 L
s
.24026 0 m
.24026 .00375 L
s
.28355 0 m
.28355 .00375 L
s
.32684 0 m
.32684 .00375 L
s
.41342 0 m
.41342 .00375 L
s
.45671 0 m
.45671 .00375 L
s
.5 0 m
.5 .00375 L
s
.58658 0 m
.58658 .00375 L
s
.62987 0 m
.62987 .00375 L
s
.67316 0 m
.67316 .00375 L
s
.75974 0 m
.75974 .00375 L
s
.80303 0 m
.80303 .00375 L
s
.84632 0 m
.84632 .00375 L
s
.9329 0 m
.9329 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .08829 m
.03006 .08829 L
s
[(20)] .01131 .08829 1 0 Mshowa
.02381 .17658 m
.03006 .17658 L
s
[(40)] .01131 .17658 1 0 Mshowa
.02381 .26487 m
.03006 .26487 L
s
[(60)] .01131 .26487 1 0 Mshowa
.02381 .35316 m
.03006 .35316 L
s
[(80)] .01131 .35316 1 0 Mshowa
.02381 .44145 m
.03006 .44145 L
s
[(100)] .01131 .44145 1 0 Mshowa
.02381 .52974 m
.03006 .52974 L
s
[(120)] .01131 .52974 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(140)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02207 m
.02756 .02207 L
s
.02381 .04415 m
.02756 .04415 L
s
.02381 .06622 m
.02756 .06622 L
s
.02381 .11036 m
.02756 .11036 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .19865 m
.02756 .19865 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .2428 m
.02756 .2428 L
s
.02381 .28694 m
.02756 .28694 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33109 m
.02756 .33109 L
s
.02381 .37523 m
.02756 .37523 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .41938 m
.02756 .41938 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .50767 m
.02756 .50767 L
s
.02381 .55182 m
.02756 .55182 L
s
.02381 .57389 m
.02756 .57389 L
s
.02381 .59596 m
.02756 .59596 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 .01433 L
.02605 .04657 L
.02729 .09793 L
.02846 .15404 L
.03279 .36197 L
.03524 .45256 L
.0375 .51194 L
.03868 .53383 L
.03998 .5512 L
.04064 .55744 L
.04134 .56242 L
.04262 .5672 L
.04393 .567 L
.04516 .56278 L
.04586 .5588 L
.0465 .55432 L
.04793 .54167 L
.05052 .5114 L
.05297 .47724 L
.06244 .33367 L
.06757 .26538 L
.07299 .20595 L
.07767 .16501 L
.08269 .13058 L
.08808 .10254 L
.09312 .08296 L
.09912 .06591 L
.10458 .05469 L
.10939 .04727 L
.11449 .04125 L
.11885 .03722 L
.12366 .03366 L
.12882 .03063 L
.13437 .028 L
.14443 .02439 L
.154 .02182 L
.16447 .01958 L
.18557 .01612 L
.20518 .01368 L
.22613 .01162 L
.24604 .01006 L
.26762 .00871 L
.30761 .00691 L
.32748 .00627 L
.34852 .00572 L
.38641 .00499 L
.40586 .00472 L
.42675 .00447 L
.4465 .00429 L
Mistroke
.46803 .00412 L
.50779 .00389 L
.5275 .0038 L
.54849 .00373 L
.59012 .0036 L
.63024 .00352 L
.66884 .00345 L
.7099 .00339 L
.74944 .00334 L
.78746 .0033 L
.82794 .00326 L
.8669 .00323 L
.90831 .00319 L
.94821 .00315 L
.97619 .00313 L
Mfstroke
1 .5 0 r
.02 w
.02641 .1214 Mdot
.03074 .21459 Mdot
.04805 .58885 Mdot
.05238 .46873 Mdot
.05671 .40662 Mdot
.06537 .26695 Mdot
.07143 .2496 Mdot
.08009 .12241 Mdot
.08874 .10264 Mdot
.0974 .06988 Mdot
.10606 .06101 Mdot
.11472 .04671 Mdot
.12338 .03457 Mdot
.13203 .03245 Mdot
.14069 .02684 Mdot
.14935 .023 Mdot
.16234 .01845 Mdot
.17965 .01536 Mdot
.19697 .01263 Mdot
.21429 .01068 Mdot
.2316 .00931 Mdot
.24892 .00887 Mdot
.26623 .0075 Mdot
.28355 .00697 Mdot
.31818 .00697 Mdot
.34848 .00636 Mdot
.39177 .00596 Mdot
.43506 .00574 Mdot
.47835 .00569 Mdot
.60823 .00358 Mdot
.65152 .00344 Mdot
.69481 .00322 Mdot
.7381 .00331 Mdot
.97619 .003 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[32]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00J@3oool6000003l0oooo100000100?ooo`@00000?P3oool4000003X0oooo1`0000030?oo
o`@00000<03oool006T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0;@3oool006X0oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
>P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02d0oooo001[0?ooo`030000003o
ool0oooo03h0oooo1P00000o0?ooo`8000000`3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0;@3oool006`0oooo00<000000?ooo`3oool0?P3oool0
10000000oooo0?ooo`0000100?ooo`030000003oool0000000800000?P3oool4000003d0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02d0oooo001]
0?ooo`030000003oool0oooo03d0oooo00@000000?ooo`3oool00000@03oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;@3oool006T0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool000000440oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02d0oooo001Y0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0?@3oool00`000000oooo000000120?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0h0?oo
o`<000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02d0oooo001Z0?ooo`@0
0000@@3oool2000004<0oooo0`00000m0?ooo`@00000?@3oool00`000000oooo0?ooo`040?ooo`@0
0000<03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00200ooooIP0000030?mo
00@000000`3oO`0:000000<0ogl02@0000030?mo00h000000`3oO`0>000000<0ogl03@0000030?mo
02l000001@3oO`0<000000D0ogl0300000050?mo00`000001@3oO`1G000000D0ogl02000000:0?oo
o`00:@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00T0oooo0`3oO`020?ooo`03
0000003oool0ogl00080ogl00`3oool50?mo0080oooo1@3oO`080?ooo`D0ogl000<0oooo0000003o
ool0103oool50?mo00H0oooo00<000000?ooo`3oool00`3oool50?mo00H0oooo00<000000?ooo`3o
ool00`3oool50?mo00D0oooo00<000000?ooo`3oool00`3oool50?mo00H0oooo00<000000?ooo`3o
ool01@3ooolO000000L0ogl02P0000070?mo00X000001`3oO`0:000000L0ogl0E@0000070?mo0140
oooo000Y0?ooo`030000003oool0oooo03l0oooo0`3oO`040?ooo`<0ogl00P3oool50?mo0080oooo
1@3oO`000`3oool0ogl00?mo000<0?mo00H0oooo1`3oO`05000000L0ogl02P0000070?mo00X00000
1`3oO`09000000L0ogl03@0000090?ooo`030000003oool0oooo01<0oooo1`3oO`0:0?ooo`L0ogl0
2P3oool70?mo00D0oooo00<000000?ooo`3oool00P3oool70?mo03L0oooo00<000000?ooo`3oool0
6`3oool70?mo0140oooo000Y0?ooo`030000003oool0oooo03P0oooo0`3oO`030?ooo`D0ogl00P3o
oolQ0?mo00H000001`3oO`050?ooo`L0ogl02P3oool70?mo00X0oooo1`3oO`090?ooo`L0ogl0;03o
ool70?mo00X0oooo1`3oO`0:0?ooo`L0ogl02P3oool70?mo05D0oooo1`3oO`0A0?ooo`00:@3oool0
0`000000oooo0?ooo`0g0?ooo`D0ogl000<0oooo0?mo003oO`009`3oO`060?ooo`L0ogl01@3oool7
0?mo00X0oooo1`3oO`0:0?ooo`L0ogl02@3oool70?mo02d0oooo1@3oO`0<0?ooo`D0ogl0303oool5
0?mo00`0oooo1@3oO`1G0?ooo`D0ogl04P3oool002T0oooo00<000000?ooo`3oool0<@3oool30?mo
0080oooo8P3oO`000`3oool0ogl00?mo00030?mo0080oooo1@3oO`080?ooo`D0ogl01`3oool50?mo
00`0oooo1@3oO`0<0?ooo`D0ogl02`3oool50?mo02l0oooo0`3oO`0>0?ooo`<0ogl03P3oool30?mo
00h0oooo0`3oO`1I0?ooo`<0ogl04`3oool002T0oooo00<000000?ooo`3oool0;03oool30?mo0003
0?ooo`3oO`00ogl000<0ogl000<0oooo0?mo003oO`00603oO`020?ooo`D0ogl00`3oool30?mo00@0
oooo0`3oO`0:0?ooo`<0ogl02@3oool30?mo00h0oooo0`3oO`0>0?ooo`<0ogl03@3oool30?mo0=D0
oooo000Y0?ooo`030000003oool0oooo02/0oooo4P3oO`000`3oool0ogl00?mo00030?mo0080oooo
1@3oO`020?ooo`<0ogl0103oool30?mo0?l0oooo;`3oool002T0oooo00<000000?ooo`3oool0:@3o
ool=0?mo00030000003oO`00ogl000<0ogl00`3oool30?mo00@0oooo0`3oO`3o0?oooc`0oooo000Y
0?ooo`800000:@3oool>0?mo0080oooo0`3oO`3o0?ooodX0oooo000Y0?ooo`030000003oool0oooo
02H0oooo3`3oO`3o0?oooe00oooo000Y0?ooo`030000003oool0oooo0280oooo3P3oO`00103oool0
ogl00?mo003oO`3o0?oooe40oooo000Y0?ooo`030000003oool0oooo0240oooo3P3oO`3o0?oooeH0
oooo000Y0?ooo`8000008@3oool=0?mo0?l0ooooF03oool002T0oooo0P00000Q0?ooo``0ogl0o`3o
oomI0?ooo`00:@3oool200000240oooo2P3oO`3o0?oooe/0oooo000Y0?ooo`800000803oool:0?mo
0?l0ooooG03oool002T0oooo0P00000O0?ooo`L0ogl0o`3ooomP0?ooo`00:@3oool2000001h0oooo
1`3oO`3o0?ooof40oooo000Y0?ooo`8000007P3oool70?mo0?l0ooooH@3oool002T0oooo0P00000N
0?ooo`L0ogl0o`3ooomQ0?ooo`00:@3oool2000001`0oooo203oO`3o0?ooof80oooo000Y0?ooo`80
00006`3oool80?mo0?l0ooooH`3oool002T0oooo0P00000J0?ooo`L0ogl0o`3ooomU0?ooo`00:@3o
ool2000001X0oooo1`3oO`3o0?ooofD0oooo000Y0?ooo`8000006@3oool80?mo0?l0ooooI@3oool0
02T0oooo0P00000H0?ooo`P0ogl0o`3ooomV0?ooo`00:@3oool2000001L0oooo203oO`3o0?ooofL0
oooo000Y0?ooo`8000005`3oool70?mo0?l0ooooJ03oool002T0oooo0P00000G0?ooo`L0ogl0o`3o
oomX0?ooo`00:@3oool2000001P0oooo1@3oO`3o0?ooofT0oooo000C0?ooo`H00000103oool40000
00P0oooo0P00000I0?ooo`<0ogl0o`3ooomZ0?ooo`004`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`8000006@3oool00`00
0000oooo0?ooo`3o0?ooofX0oooo000D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`8000006@3oool00`000000oooo0?ooo`3o0?ooofX0
oooo000E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`<000005`3oool00`000000oooo0?ooo`3o0?ooof/0oooo000F0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`800000603o
ool00`000000oooo0?ooo`3o0?ooof/0oooo000G0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`800000603oool00`000000oooo0?ooo`3o
0?ooof/0oooo000C0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo00D0oooo0P00000F0?ooo`<0ogl0o`3ooom]0?ooo`004`3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`05
0?ooo`8000005@3oool50?mo0?l0ooooK03oool001@0oooo100000050?ooo`@00000203oool20000
01@0oooo1`3oO`3o0?ooof/0oooo000Y0?ooo`800000503oool70?mo0?l0ooooJ`3oool002T0oooo
0P00000D0?ooo`L0ogl0o`3ooom[0?ooo`00:@3oool2000001D0oooo1@3oO`3o0?ooof`0oooo000Y
0?ooo`8000005P3oool30?mo0?l0ooooK@3oool002T0oooo0P00000F0?ooo`030000003oool0oooo
0?l0ooooK@3oool002P0oooo0`3oO`0B0?ooo`<0ogl000<0oooo0000003oool0o`3ooom^0?ooo`00
9`3oool50?mo0100oooo1@3oO`000`000000oooo0?ooo`3o0?ooofd0oooo000V0?ooo`L0ogl03P3o
ool70?mo0?l0ooooK`3oool002H0oooo1`3oO`0>0?ooo`L0ogl0o`3ooom_0?ooo`009P3oool70?mo
00h0oooo1`3oO`3o0?ooofl0oooo000W0?ooo`D0ogl0403oool50?mo0?l0ooooL03oool002P0oooo
0`3oO`000`000000oooo0?ooo`0?0?ooo`<0ogl000<000000?ooo`3oool0o`3ooom^0?ooo`00:@3o
ool3000001@0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`00:@3oool00`000000oooo0000000D
0?ooo`030000003oool0oooo0?l0ooooKP3oool002T0oooo00<000000?ooo`000000503oool00`00
0000oooo0?ooo`3o0?ooofh0oooo000Y0?ooo`030000003oool0000001<0oooo00<000000?ooo`3o
ool0o`3ooom_0?ooo`00:@3oool00`000000oooo0000000C0?ooo`030000003oool0oooo0?l0oooo
K`3oool002T0oooo00<000000?ooo`0000004`3oool00`000000oooo0?ooo`3o0?ooofl0oooo000Y
0?ooo`030000003oool0000001<0oooo00<000000?ooo`3oool0o`3ooom_0?ooo`00:@3oool00`00
0000oooo0000000C0?ooo`030000003oool0oooo0?l0ooooK`3oool002T0oooo0`00000C0?ooo`03
0000003oool0oooo0?l0ooooK`3oool002T0oooo00<000000?ooo`0000004P3oool00`000000oooo
0?ooo`3o0?ooog00oooo000Y0?ooo`030000003oool000000180oooo00<000000?ooo`3oool0o`3o
oom`0?ooo`00:@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo0?l0ooooL03oool0
02T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`3o0?ooog00oooo000E0?ooo`@0
0000103oool4000000P0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`3o0?ooog00
oooo000G0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`030000003oool000000180oooo00<000000?ooo`3oool0o`3ooom`0?ooo`005`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0000000B0?ooo`030000003oool0oooo0?l0ooooL03oool001<0oooo1P000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0000000A
0?ooo`030000003oool0oooo0?l0ooooL@3oool001@0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0`00000A0?ooo`030000003oool0
oooo0?l0ooooL@3oool001@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000004@3oool00`000000oooo0?ooo`3o
0?ooog40oooo000E0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool000000140oooo00<000000?ooo`3oool0o`3oooma0?oo
o`005@3oool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0000000A0?ooo`030000003oool0oooo0?l0ooooL@3oool001H0oooo
0P0000050?ooo`@00000203oool00`000000oooo0000000A0?ooo`030000003oool0oooo0?l0oooo
L@3oool002T0oooo00<000000?ooo`0000004@3oool00`000000oooo0?ooo`3o0?ooog40oooo000Y
0?ooo`030000003oool000000140oooo00<000000?ooo`3oool0o`3oooma0?ooo`00:@3oool00`00
0000oooo0000000@0?ooo`030000003oool0oooo0?l0ooooLP3oool002T0oooo0`00000@0?ooo`03
0000003oool0oooo0?l0ooooLP3oool002T0oooo00<000000?ooo`000000403oool00`000000oooo
0?ooo`3o0?ooog80oooo000Y0?ooo`030000003oool000000100oooo00<000000?ooo`3oool0o`3o
oomb0?ooo`00:@3oool00`000000oooo0000000@0?ooo`030000003oool0oooo0?l0ooooLP3oool0
02T0oooo00@000000?mo003oO`00ogl03`3oool00`000000oooo0?ooo`3o0?ooog80oooo000Y0?oo
o`D0ogl03P3oool00`000000oooo0?ooo`3o0?ooog80oooo000X0?ooo`L0ogl03@3oool00`000000
oooo0?ooo`3o0?ooog80oooo000X0?ooo`L0ogl03@3oool00`000000oooo0?ooo`3o0?ooog80oooo
000X0?ooo`L0ogl03@3oool00`000000oooo0?ooo`3o0?ooog80oooo000Y0?ooo`D0ogl03@3oool0
0`000000oooo0?ooo`3o0?ooog<0oooo000Y0?ooo`040000003oO`00ogl00?mo00h0oooo00<00000
0?ooo`3oool0o`3ooomc0?ooo`00:@3oool00`000000oooo0000000?0?ooo`030000003oool0oooo
0?l0ooooL`3oool002T0oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`3o0?ooog<0
oooo000Y0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`00:@3o
ool00`000000oooo0000000?0?ooo`030000003oool0oooo0?l0ooooL`3oool002T0oooo00<00000
0?ooo`0000003`3oool00`000000oooo0?ooo`3o0?ooog<0oooo000Y0?ooo`030000003oool00000
00l0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`00:@3oool00`000000oooo0000000?0?ooo`03
0000003oool0oooo0?l0ooooL`3oool002T0oooo0`00000>0?ooo`<0ogl0o`3ooomd0?ooo`00:@3o
ool00`000000oooo0000000=0?ooo`D0ogl0o`3ooomc0?ooo`00:@3oool00`000000oooo0000000<
0?ooo`L0ogl0o`3ooomb0?ooo`00:@3oool00`000000oooo0000000<0?ooo`L0ogl0o`3ooomb0?oo
o`00:@3oool00`000000oooo0000000<0?ooo`L0ogl0o`3ooomb0?ooo`005@3oool4000000@0oooo
100000080?ooo`030000003oool0000000d0oooo1@3oO`3o0?ooog<0oooo000D0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`040000
003oool0oooo000000/0oooo1@3oO`3o0?ooog@0oooo000D0?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0000
00X0oooo1@3oO`3o0?ooogD0oooo000D0?ooo`8000000`3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00D0oooo100000090?ooo`L0ogl0o`3ooomd0?ooo`00503oool00`000000
oooo00000002000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`04
0000003oool0oooo000000T0oooo1`3oO`3o0?ooog@0oooo000D0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0000
00T0oooo1`3oO`3o0?ooog@0oooo000E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000X0oooo1@3oO`3o0?oo
ogD0oooo000F0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`040000003oool0oooo000000/0oooo0`3oO`3o0?ooogH0oooo000G0?ooo`<0
00000`3oool4000000P0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`3o0?oo
og@0oooo000Y0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool0o`3ooomd0?oo
o`00:@3oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo0?l0ooooM@3oool002T0
oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`3o0?ooogD0oooo000Y0?ooo`80
000000<0oooo0000003oool02`3oool00`000000oooo0?ooo`3o0?ooogD0oooo000Y0?ooo`040000
003oool0oooo000000`0oooo00<000000?ooo`3oool0o`3ooome0?ooo`00:@3oool010000000oooo
0?ooo`00000<0?ooo`030000003oool0oooo0?l0ooooM@3oool002T0oooo00@000000?ooo`3oool0
0000303oool00`000000oooo0?ooo`3o0?ooogD0oooo000Y0?ooo`040000003oool0oooo000000`0
oooo00<000000?ooo`3oool0o`3ooome0?ooo`00:@3oool010000000oooo0?ooo`00000<0?ooo`03
0000003oool0oooo0?l0ooooM@3oool002T0oooo00@000000?ooo`3oool00000303oool00`000000
oooo0?ooo`3o0?ooogD0oooo000Y0?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3o
ool0o`3ooome0?ooo`00:@3oool2000000030?ooo`000000oooo00/0oooo00<000000?ooo`3oool0
o`3ooome0?ooo`00:@3oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo0?l0oooo
M@3oool002T0oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`3o0?ooogD0oooo
000Y0?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3oool0o`3ooome0?ooo`00:@3o
ool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0?l0ooooMP3oool002T0oooo00@0
00000?ooo`3oool000002`3oool00`000000oooo0?ooo`3o0?ooogH0oooo000Y0?ooo`040000003o
ool0oooo000000/0oooo00<000000?ooo`3oool0o`3ooomf0?ooo`00:@3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo0?l0ooooMP3oool002T0oooo00@000000?ooo`3oool00000
2`3oool00`000000oooo0?ooo`3o0?ooogH0oooo000Y0?ooo`80000000<0oooo0000003oool02P3o
ool00`000000oooo0?ooo`3o0?ooogH0oooo000Y0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool0o`3ooomf0?ooo`00:@3oool010000000oooo0?ooo`00000;0?ooo`030000003o
ool0oooo0?l0ooooMP3oool002T0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?oo
o`3o0?ooogH0oooo000Y0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0o`3o
oomf0?ooo`00503oool4000000D0oooo100000080?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool0o`3ooomf0?ooo`004`3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`3oool0o`3ooomf0?ooo`004`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000/0
oooo00<000000?ooo`3oool0o`3ooomf0?ooo`004`3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0000
00X0oooo00<000000?ooo`3oool0o`3ooomg0?ooo`00503oool4000000@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`@000002P3oool00`000000oooo0?ooo`3o0?ooogL0
oooo000C0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo00D0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`3o0?oo
ogL0oooo000C0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo00D0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`3o
0?ooogL0oooo000C0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?oo
o`3o0?ooogL0oooo000D0?ooo`@000001@3oool4000000P0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`3o0?ooogL0oooo000Y0?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool0o`3ooomg0?ooo`00:@3oool010000000oooo0?ooo`00000:0?ooo`030000003o
ool0oooo0?l0ooooM`3oool002T0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?oo
o`3o0?ooogL0oooo000Y0?ooo`80000000<0oooo0000003oool02@3oool00`000000oooo0?ooo`3o
0?ooogL0oooo000Y0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0o`3ooomg
0?ooo`00:@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0?l0ooooM`3oool0
02T0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`3o0?ooogL0oooo000Y0?oo
o`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0o`3ooomg0?ooo`00:@3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo0?l0ooooN03oool002T0oooo00@000000?oo
o`3oool000002@3oool00`000000oooo0?ooo`3o0?ooogP0oooo000Y0?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`3oool0o`3ooomh0?ooo`00:@3oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo0?l0ooooN03oool002T0oooo0P0000000`3oool000000?ooo`080?oo
o`030000003oool0oooo0?l0ooooN03oool002T0oooo00@000000?ooo`3oool000001`3oool30?mo
0?l0ooooNP3oool002T0oooo00@000000?ooo`3oool000001P3oool50?mo0?l0ooooN@3oool002T0
oooo00@000000?ooo`3oool000001@3oool70?mo0?l0ooooN03oool002T0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`L0ogl0o`3ooomh0?ooo`00:@3oool01@000000oooo0?ooo`3oool00000
00@0oooo1`3oO`3o0?ooogP0oooo000Y0?ooo`050000003oool0oooo0?ooo`0000001@3oool50?mo
0?l0ooooN@3oool002T0oooo00D000000?ooo`3oool0oooo000000060?ooo`<0ogl0o`3ooomj0?oo
o`00:@3oool200000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooogP0
oooo000Y0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`3o0?ooogP0
oooo000Y0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`3o0?ooogT0
oooo000Y0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`3o0?ooogT0
oooo000Y0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`3o0?ooogT0
oooo000:0?ooo`L000000`3oool4000000D0oooo100000080?ooo`050000003oool0oooo0?ooo`00
00001`3oool00`000000oooo0?ooo`3o0?ooogT0oooo000=0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool01@3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0o`3ooomi0?oo
o`003@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo00000007
0?ooo`030000003oool0oooo0?l0ooooN@3oool000d0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`05
0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`3o0?ooogT0oooo000=
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool01@3oool3000000030?ooo`000000oooo00H0oooo00<0
00000?ooo`3oool0o`3ooomi0?ooo`003@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00D0
00000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo0?l0ooooN@3oool000d0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000
oooo0?ooo`3o0?ooogT0oooo000;0?ooo`<000001@3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?oo
o`0000001`3oool00`000000oooo0?ooo`3o0?ooogT0oooo000=0?ooo`030000003oool0oooo00@0
oooo100000050?ooo`@00000203oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?oo
o`3oool0o`3ooomi0?ooo`00:@3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?oo
o`3oool0o`3ooomi0?ooo`00:@3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?oo
o`3oool0o`3ooomi0?ooo`00:@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?oo
o`3oool0o`3ooomj0?ooo`00:@3oool01@000000oooo0?ooo`3oool0000000D0oooo0`3oO`3o0?oo
og/0oooo000Y0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`D0ogl0o`3ooomj0?ooo`00
:@3oool01@000000oooo0?ooo`3oool0000000<0oooo1`3oO`3o0?ooogT0oooo000Y0?ooo`050000
003oool0oooo0?ooo`0000000`3oool70?mo0?l0ooooN@3oool002T0oooo00D000000?ooo`3oool0
oooo000000030?ooo`L0ogl0o`3ooomi0?ooo`00:@3oool01@000000oooo0?ooo`3oool0000000@0
oooo1@3oO`3o0?ooogX0oooo000Y0?ooo`050000003oool0oooo0?ooo`0000001@3oool30?mo0?l0
ooooN`3oool002T0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0?l0
ooooNP3oool002T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0?l0ooooNP3oool002T0oooo0P0000030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0o`3ooomj0?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0o`3ooomj0?ooo`00:@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooomj0?ooo`00:@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooomj0?ooo`00
:@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
o`3ooomk0?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0o`3ooomk0?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0o`3ooomk0?ooo`00:@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooomk0?ooo`00:@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooomk0?ooo`00
:@3oool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooog/0oooo
000Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3o0?ooog/0oooo000Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`3o0?ooog/0oooo000Y0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`3o0?ooog/0oooo000Y0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooog/0oooo000:0?ooo`L00000
0P3oool6000000@0oooo100000080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`3o0?ooog/0oooo000=0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000o`3ooomm0?ooo`00
3@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
0000o`3ooomn0?ooo`003@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`<000000`3oool010000000oooo
0?ooo`00003o0?ooogh0oooo000=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`00003o0?ooogh0oooo000=0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00003o0?ooogh0oooo000=0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
0?l0ooooOP3oool000/0oooo0`0000050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`00003o0?ooogh0oooo000=0?ooo`030000003oool0oooo00@0oooo100000050?oo
o`@00000203oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000?l0ooooOP3oool0
02T0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00003o0?ooogh0oooo000Y0?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000o`3ooomn0?ooo`00:@3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo00000?l0ooooOP3oool002T0oooo0P0000040?oo
o`040000003oool0oooo00000?l0ooooOP3oool002T0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`00003o0?ooogh0oooo000Y0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`000000o`3ooomo0?ooo`00:@3oool00`000000oooo0?ooo`030?ooo`030000003oool000000?l0
ooooO`3oool002T0oooo00<000000?ooo`3oool0103oool200000?l0ooooO`3oool002T0oooo00<0
00000?ooo`3oool0103oool200000?l0ooooO`3oool002T0oooo00<000000?ooo`3oool0103oool2
00000?l0ooooO`3oool002T0oooo00<000000?ooo`3oool0o`3ooon50?ooo`00:@3oool00`000000
oooo0?ooo`3o0?ooohD0oooo000Y0?ooo`800000o`3ooon60?ooo`00:@3oool00`000000oooo0?oo
o`3o0?ooohD0oooo000Y0?ooo`030000003oool0oooo0?l0ooooQ@3oool002T0oooo00<000000?oo
o`3oool01@3oool30?mo0?l0ooooO@3oool002T0oooo00<000000?ooo`3oool0103oool50?mo0?l0
ooooO03oool002T0oooo00<000000?ooo`3oool00`3oool70?mo0?l0ooooN`3oool002T0oooo00<0
00000?ooo`3oool00`3oool70?mo0?l0ooooN`3oool002T0oooo00<000000?ooo`3oool00`3oool7
0?mo0?l0ooooN`3oool002T0oooo0P0000050?ooo`D0ogl0o`3oooml0?ooo`00:@3oool00`000000
oooo0?ooo`050?ooo`<0ogl0o`3ooomm0?ooo`00:@3oool00`000000oooo0?ooo`3o0?ooohD0oooo
000Y0?ooo`030000003oool0oooo0?l0ooooQ@3oool002T0oooo00<000000?ooo`3oool0o`3ooon5
0?ooo`002P3oool7000000@0oooo100000040?ooo`@00000203oool00`000000oooo0?ooo`3o0?oo
ohD0oooo000=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooon50?ooo`00
3@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooQ@3oool000d0oooo00<0
00000?ooo`3oool00`3oool6000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0?l0ooooQ@3oool000d0oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool300000?l0ooooQ@3oool000d0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooon=0?ooo`003@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`3o0?ooohd0oooo000;0?ooo`<000001`3oool00`000000oooo000000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooon=0?ooo`003@3oool00`000000
oooo0?ooo`060?ooo`8000001@3oool400000?l0ooooT03oool00?l0oooo/@3oool00?l0oooo/@3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-1.22445, -10.6826, \
0.0444745, 0.872257}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell["\<\
As it can be seen, the model fits almost exactly with the experimental \
data.\
\>", "Text"],

Cell[BoxData[
    \(Clear[X1, \ x1, x1bestfit\ ]\)], "Input",
  CellLabel->"In[33]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Method 2", "SubsubsectionIcon"],

Cell[TextData[{
  "Here is solved the same problem but using package  ",
  StyleBox["SystemNDSolve", "Input"],
  ", that apply the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve", "Input"],
  ", combined with ",
  StyleBox[ButtonBox["FindMinimum"],
    ButtonBoxOptions -> {DefaultStyle -> "MainBookLink"}],
  " It can be made as follow "
}], "Text"],

Cell[BoxData[
    \(objective[c1_Real, c2_Real] := 
      Block[{q1}, 
        q1[t3_] = \(SystemNDSolve[
                physiomodel1 /. {koff \[Rule] \ c1, \ 
                    kon \[Rule] \ c2}, \ {0, 0, 0}, 
                inputcatheter1, {t, 0.01, 12}, \ t, \ x]\)[\([\)\(1, 
              2\)\(]\)] /. t \[Rule] t3; \[IndentingNewLine]Plus @@ 
          Apply[\((q1[#1] - #2)\)^2 &, dataPhysio, {1}]]; \)], "Input",
  CellLabel->"In[34]:="],

Cell[TextData[{
  "We have used [[1,2]] because we only need the concentration for ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\)(t)\)]]
}], "SmallText"],

Cell[TextData[{
  "Now we use ",
  StyleBox["FindMinimum", "Input"],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindMinimum[
      objective[koff, kon], {koff, 0.1, 1}, {kon, 0.1, 1}]\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \({601.237865417786`, {koff \[Rule] 0.10217005801697938`, 
        kon \[Rule] 0.6875727916045529`}}\)], "Output",
  CellLabel->"Out[35]="]
}, Open  ]],

Cell[TextData[{
  "It can be used ",
  StyleBox["NMinimize[objective[koff,kon],{koff,kon}] ", "Input"],
  "but it will take a long time."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Clear[objetive]\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(objetive\\)\\\" is similar to existing \
symbol \\\"\\!\\(objective\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message",
  CellLabel->"From In[36]:="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Method 3", "SubsubsectionIcon"],

Cell[TextData[{
  "Here is used",
  " the package function  ",
  StyleBox["X2Fit ", "Input"]
}], "Text"],

Cell[BoxData[
    \(X1[t1_, c1_?NumericQ, 
        c2_?NumericQ] := \(x\_1[t] /. 
          SystemNDSolve[
            physiomodel1 /. {koff \[Rule] \ c1, \ kon \[Rule] \ c2}, \ {0, 0, 
              0}, inputcatheter1, {t, 0.01, 12}, \ t, \ x]\) /. 
        t \[Rule] t1\)], "Input",
  CellLabel->"In[37]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindMinimum[
      X2Fit[{koff, kon}, dataPhysio, \ X1[t, koff, kon], \ \ \ t], {koff, 
        0.1, 1}, \ {kon, 0.1, 1}]\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \({601.237865417786`, {koff \[Rule] 0.10217005801697938`, 
        kon \[Rule] 0.6875727916045529`}}\)], "Output",
  CellLabel->"Out[38]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["FindFit", "Input"],
  " can also be applied"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(FindFit[dataPhysio, \ 
      X1[t, koff, kon], \ {{koff, 0.1, 1}, \ {kon, 0.1, 1}}, \ 
      t]\)\)\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \({koff \[Rule] 0.10214396832174984`, 
      kon \[Rule] 0.6873631464744148`}\)], "Output",
  CellLabel->"Out[39]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[physiomodel1, \ inputcatheter1, \ X1]\)], "Input",
  CellLabel->"In[40]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 4", "SubsectionIcon"],

Cell[TextData[{
  "Here are expanded the previous example for fitting ",
  Cell[BoxData[
      \(TraditionalForm\`V\_Tu\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`k\_off\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`k\_on\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`V\_p\)]],
  ", PS"
}], "Text"],

Cell[BoxData[
    \(X1[s_, \ c1_, c2_, c3_, \ c4_, \ 
        c5_\ ] = \(X\_1[s] /. 
          SystemLTSolve[physiomodel, {0, 0, 0}, inputcatheter, \ t, s, \ 
            X]\) /. {VTu -> \ c1, koff -> c2\ , \ kon -> c3, \ Vp -> \ c4, \ 
          PS -> \ c5}; \)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    \(sse2[VTu_?NumberQ, koff_?NumberQ, kon_?NumberQ, \ Vp_?NumberQ, 
        PS_?NumberQ] := 
      Block[{sol, q1}, 
        q1[t_] = 
          InverseLaplaceTransform[X1[s, VTu, koff, kon, \ Vp, PS], \ s, \ t]; 
        Plus @@ Apply[\((q1[#1] - #2)\)^2 &, dataPhysio, {1}]]\)], "Input",
  CellLabel->"In[42]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindMinimum[
      sse2[VTu, koff, \ kon, Vp, \ PS], {VTu, 10, 20}, {koff, 0.1, 
        0.3}, {kon, 0.4, 0.7}, {Vp, 1, 2}, {PS, 4, 5}, \ 
      MaxIterations \[Rule] 50]\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \({600.6827206293111`, {VTu \[Rule] 6.735969687337835`, 
        koff \[Rule] 0.09457846474937671`, kon \[Rule] 0.6420132798935104`, 
        Vp \[Rule] 0.9803262584878929`, 
        PS \[Rule] 2.7169484278347475`}}\)], "Output",
  CellLabel->"Out[43]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[sse2, \ dataPhysio, \ physiomodel, inputcatheter, \ \ X1, \ Q, \ 
      VTb]\)], "Input",
  CellLabel->"In[44]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 5", "SubsectionIcon"],

Cell[TextData[{
  "Sometime we need not only the values of fitted parameters but also \
additional statistic information such as confidence intervals, ANOVA table an \
so on. In this case we can apply ",
  StyleBox[ButtonBox["NonlinearRegress"],
    ButtonBoxOptions -> {DefaultStyle -> "AddOnsLink"}],
  " but if the model to be fitted it doesn't have an analytic expression ",
  StyleBox[ButtonBox["NonlinearRegress"],
    ButtonBoxOptions -> {DefaultStyle -> "AddOnsLink"}],
  " we can not find the derivatives.  In this case we can used a method that \
was shown to mathgroup by Carl Woll (from Washington University).  This \
method needs that the user supplied to Mathematica the derivatives for each \
coeffs. to be fitted. It can be complex when the number of variables and \
coefficients is big. I have found that the problem can be made easier using \
the numeric derivatives applying the package ",
  StyleBox[ButtonBox["NumericalMath`NLimit`"],
    ButtonBoxOptions -> {DefaultStyle -> "AddOnsLink"}],
  ". "
}], "Text"],

Cell[BoxData[
    \(Needs["\<NumericalMath`NLimit`\>"]\)], "Input",
  CellLabel->"In[45]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?"\<NumericalMath`NLimit`*\>"\)\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[GridBox[{
        {
          StyleBox["NumericalMath`NLimit`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["EulerRatio",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703741-7332837", 
                    "NumericalMath`NLimit`EulerRatio"},
                  ButtonFrame->"None",
                  ButtonNote->"NumericalMath`NLimit`"], 
                ButtonBox[
                  StyleBox["EulerSum",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703741-7332837", 
                    "NumericalMath`NLimit`EulerSum"},
                  ButtonFrame->"None",
                  ButtonNote->"NumericalMath`NLimit`"], 
                ButtonBox[
                  StyleBox["ExtraTerms",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703741-7332837", 
                    "NumericalMath`NLimit`ExtraTerms"},
                  ButtonFrame->"None",
                  ButtonNote->"NumericalMath`NLimit`"], 
                ButtonBox[
                  StyleBox["ND",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703741-7332837", 
                    "NumericalMath`NLimit`ND"},
                  ButtonFrame->"None",
                  ButtonNote->"NumericalMath`NLimit`"], 
                ButtonBox[
                  StyleBox["NLimit",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703741-7332837", 
                    "NumericalMath`NLimit`NLimit"},
                  ButtonFrame->"None",
                  ButtonNote->"NumericalMath`NLimit`"], 
                ButtonBox[
                  StyleBox["Scale",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703741-7332837", 
                    "NumericalMath`NLimit`Scale"},
                  ButtonFrame->"None",
                  ButtonNote->"NumericalMath`NLimit`"], 
                ButtonBox[
                  StyleBox["Terms",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3333703741-7332837", 
                    "NumericalMath`NLimit`Terms"},
                  ButtonFrame->"None",
                  ButtonNote->"NumericalMath`NLimit`"]}
              },
            RowMinHeight->1.05]}
        },
      RowSpacings->{2, 3},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->RGBColor[0.964706, 0.929412, 0.839216],
  ButtonBoxOptions->{Active->True},
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Open  ]],

Cell[TextData[{
  "This figure represent the model of Iodine ICRP 78, compartment 1 \
represents the blood, compartment 2 the thyroid, 3 rest of body, and 4 the \
bladder, ",
  Cell[BoxData[
      \(TraditionalForm\`k\_40\)]],
  " means the rate transfer out of system  to urine) and ",
  Cell[BoxData[
      \(TraditionalForm\`k\_30\)]],
  "means the rate transfer out of system  to ULI in GI system "
}], "Text"],

Cell[TextData[{
  "The problem is to fit the coeffs. ",
  Cell[BoxData[
      \(TraditionalForm\`k\_12\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\_23\)]],
  " in the iodine model below figure using experimental data given in list \
dataIodine. "
}], "Text"],

Cell[BoxData[
    \(dataIodine = {{0, 0.002}, {50, 0.106}, {100, 0.077}, {150, 
          0.056}, {200, 0.041}, {250, 0.032}, {300, 0.023}, {350, 
          0.018}, {400, 0.011}, {450, 0.011}, {500, 0.007}}; \)], "Input",
  CellLabel->"In[47]:="],

Cell["Also is assumed an input to the compartment 1 given by", "Text"],

Cell[BoxData[
    \(iodo129h\  = 
      34.4\ \[ExponentialE]\^\(\(-200. \)\ t\) + 
        1.09\ \[ExponentialE]\^\(\(-110. \)\ t\) + 
        0.808\ \[ExponentialE]\^\(\(-102. \)\ t\) + 
        6.414\ \[ExponentialE]\^\(\(-100. \)\ t\) + 
        5.458\ \[ExponentialE]\^\(\(-24. \)\ t\); \)], "Input",
  CellLabel->"In[48]:="],

Cell["\<\
This input has been previously obtained using the package function \
SystemNDSolve and it represents the input from respiratory tract (by \
inhalation) to thyroid. \
\>", "Text"],

Cell["The model can be built using SystemNDSolve   ", "Text"],

Cell[BoxData[
    \(model[t1_?NumberQ, k12_?NumberQ, \ k23_?NumberQ]\  := \ 
      x\_2[t1] /. 
        SystemNDSolve[
          CompartMatrix[
            3, {{1, 2, k12}, {1, 0, 1.9404}, {2, 3, k23\ }, {3, 0, 
                0.01155}, {3, 1, 0.0462}\ }], \ {0, \ 0, \ 0}, \ {iodo129h, \ 
            0, \ 0}\ , {t, \ 0, \ 500}, t1, x]; \)], "Input",
  CellLabel->"In[49]:="],

Cell[TextData[{
  "The above expression is not an analytic expression, we must supplied to \
Mma the derivatives. It can be obtained using ",
  StyleBox[ButtonBox["NDSolve"],
    ButtonBoxOptions -> {DefaultStyle -> "MainBookLink"}],
  " from the numeric derivation of the SODE of the model but I prefer this \
way that it is easier."
}], "Text"],

Cell[BoxData[
    \(\(\(\(\(Derivative[1, 0, 0]\)[model]\)[n_, a2_, a3_]\)\(:=\)\(ND[
        model[a1, a2, a3], a1, 
        n]\)\(\ \)\( (*In\ this\ example\ we\ don' t\ need\ this\ derivative, 
        but\ it\ is\ included\ to\ show\ the\ pattern*) \)\)\)], "Input",
  CellLabel->"In[50]:="],

Cell[BoxData[
    \(\(\(Derivative[0, 1, 0]\)[model]\)[a1_, n_, a3_] := 
      ND[model[a1, a2, a3], a2, n]\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \(\(\(Derivative[0, 0, 1]\)[model]\)[a1_, a2_, n_] := 
      ND[model[a1, a2, a3], a3, n]\)], "Input",
  CellLabel->"In[52]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(NonlinearRegress[dataIodine, 
        model[t, a12, a23], {t}, {{a12, {0.8, 1}}, {a23, {0.007, 0.008}}}, 
        Method \[Rule] Gradient, 
        RegressionReport \[Rule] {BestFit, EstimatedVariance, 
            ParameterCITable, ANOVATable, FitResiduals}] // Timing\)], "Input",\

  CellLabel->"In[53]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(128.375`\ Second\), ",", 
        RowBox[{"{", 
          
          RowBox[{\(BestFit \[Rule] 
              model[t, 0.8000029860291634`, 0.007829073991099061`]\), 
            ",", \(EstimatedVariance \[Rule] 3.835757722867467`*^-6\), ",", 
            RowBox[{"ParameterCITable", "\[Rule]", 
              TagBox[GridBox[{
                    {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"Asymptotic SE\"\>", \
"\<\"CI\"\>"},
                    {"a12", "0.8000029860291634`", 
                      "0.04565700217953515`", \({0.6967196715168348`, 
                        0.9032863005414921`}\)},
                    {"a23", "0.007829073991099061`", 
                      "0.0006727545002991989`", \({0.006307197579442501`, 
                        0.00935095040275562`}\)}
                    },
                  RowSpacings->1,
                  ColumnSpacings->3,
                  RowAlignments->Baseline,
                  ColumnAlignments->{Left}],
                Function[ BoxForm`e$, 
                  TableForm[ 
                  BoxForm`e$, TableDepth -> 2, TableHeadings -> {{a12, a23}, {
                    "Estimate", "Asymptotic SE", "CI"}}]]]}], ",", 
            RowBox[{"ANOVATable", "\[Rule]", 
              InterpretationBox[GridBox[{
                    {"\<\"\"\>", "\<\"DF\"\>", "\<\"SumOfSq\"\>", "\<\"MeanSq\
\"\>"},
                    {"\<\"Model\"\>", "2", "0.024119478180494192`", 
                      "0.012059739090247096`"},
                    {"\<\"Error\"\>", "9", "0.000034521819505807206`", 
                      "3.835757722867467`*^-6"},
                    {"\<\"Uncorrected Total\"\>", "11", 
                      "0.024154`", "\<\"\"\>"},
                    {"\<\"Corrected Total\"\>", "10", 
                      "0.01074890909090909`", "\<\"\"\>"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->3,
                  RowAlignments->Baseline,
                  ColumnAlignments->{Left}],
                
                TableForm[ {{2, .024119478180494192, .012059739090247096}, {
                  9, .000034521819505807206, .38357577228674671*^-5}, {
                  11, .024153999999999998}, {10, .01074890909090909}}, 
                  TableHeadings -> {{"Model", "Error", "Uncorrected Total", 
                  "Corrected Total"}, {"DF", "SumOfSq", "MeanSq"}}]]}], 
            ",", \(FitResiduals \[Rule] {0.002`, 0.0043411769489574425`, 
                0.0010977385939116152`, \(-0.0008064652462586724`\), \
\(-0.0015216618782058905`\), 
                0.0001706795566027708`, \(-0.0008256542743136051`\), 
                0.00016543745448469038`, \(-0.0023499640781441625`\), 
                0.0010069571021606681`, \(-0.00048024087793106275`\)}\)}], 
          "}"}]}], "}"}]], "Output",
  CellLabel->"Out[53]="]
}, Open  ]],

Cell["It will taken a long time  but the solution look like fine. ", "Text"],

Cell[CellGroupData[{

Cell["Conclution", "SubsubsectionIcon"],

Cell["\<\
You can realize that the previous patterns could be applied to others model \
with two or more parameters for fitting .\
\>", "Text"],

Cell["\<\
The pattern for fitting model  is the following:

Derivative[1,0,0,0, ...,0][model][n_,a2_,a3_,a4_, ...]:=ND[model[a1,a2,a3,a4, \
...,ai],a1,n];
Derivative[0,1,0,0, ...,0][model][a1_,n_,a3_,a4_, ...]:=ND[model[a1,a2,a3,a4, \
...,ai],a2,n];
Derivative[0,0,1,0, ...,0][model][a1_,a2_,n_,a4_, ...]:=ND[model[a1,a2,a3,a4, \
...,ai],a3,n];
....
Derivative[0,0,0, ...,0,1][model][a1_,a2_,a3_, ...,n_]:=ND[model[a1,a2,a3,a4, \
...,ai],ai,n];
  
NonlinearRegress[data,model,variables,parameters,Method\[Rule]Gradient]]
 
It will usually take a long time of computation. \
\>", "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 6", "SubsectionIcon"],

Cell[BoxData[
    \(ClearAll[iodine, \ x1, \ x2, x3]\)], "Input",
  CellLabel->"In[54]:="],

Cell["\<\
In the iodine model it is supposed a constant rate input = 0.1 uds/day  in \
compartment 1  \
\>", "Text"],

Cell["The retention in each compartment can be obtained as usual ", \
"MathCaption"],

Cell[BoxData[
    \({x1[t1_], x2[t1_], \ x3[t1_]} = 
      Map[Last, 
        SystemDSolve[
          CompartMatrix[
            3, {{1, 2, \ 0.8316}, {1, 0, 1.9404}, {2, 3, 0.0086625}\ , {3, 0, 
                0.01155}\ , {3, 1, 0.0462}}], {0, \ 0, \ 0}, {0.1, \ 0, \ 0}, 
          t, t1, \ x]]; \)], "Input",
  CellLabel->"In[55]:="],

Cell["\<\
Now we simulate the experimental measured for different times in compartment \
2 and 3. An random noise it is included\
\>", "MathCaption"],

Cell[BoxData[
    \(sample1 = 
      Table[{t, x2[t] + Random[NormalDistribution[0, 0.1]]}, {t, 10, 300, 
          10}]; \)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \(sample2 = 
      Table[{t, \ \ \ x3[t] + Random[NormalDistribution[0, \ 0.1]]}, {t, \ 
          6, \ 300, \ 14}]; \)], "Input",
  CellLabel->"In[57]:="],

Cell["\<\
Now we suppose that rate transfer coeffs k12 and k23 are unknown. Its can be  \
estimated  using experimental data of x2(t) and x3(t) \
\>", "MathCaption"],

Cell[BoxData[
    \(modelIodine[t1_, k12_?NumberQ, \ 
        k23_?NumberQ] := \ \n\ {\ x\_2[t1], \ x\_3[t1]} /. 
        SystemDSolve[
          CompartMatrix[
            3, {{1, 2, k12}, {1, 0, 1.9404}, {2, 3, k23\ }, {3, 0, 
                0.01155}, {3, 1, 0.0462}\ }]\ , \ {0, \ 0, \ 0}, \ {0.1, \ 
            0, \ 0}\ , t, t1, x]; \)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \(X2[t1_, k12_?NumberQ, \ 
        k23_?NumberQ] := \(modelIodine[t1, k12, \ 
          k23]\)[\([\)\(1\)\(]\)]\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \(X3[t1_, k12_?NumberQ, \ 
        k23_?NumberQ] := \(modelIodine[t1, k12, \ 
          k23]\)[\([\)\(2\)\(]\)]\)], "Input",
  CellLabel->"In[60]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(fittedparameters\  = \ \ FindMinimum[
        X2Fit[{k12, \ k23}, sample1, X2[t1, k12, k23], \ \ sample2, 
          X3[t1, k12, k23], \ t1], {k12, 0.5, 1\ }\ , {k23, 0.02, 
          0.3}]\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \({0.4954741123784808`, {k12 \[Rule] 0.8120635337868687`, 
        k23 \[Rule] 0.008243153419063367`}}\)], "Output",
  CellLabel->"Out[61]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[
      Evaluate[modelIodine[t, k12, \ k23] /. 
          fittedparameters[\([\)\(2\)\(]\)]\ ], \ {t, \ 0, \ 300}, \ 
      Epilog \[Rule] \ {{Hue[0.3], \ PointSize[0.02], 
            Map[Point, \ sample1\ ]\ }, {Hue[0], \ PointSize[0.02], 
            Map[Point, \ sample2\ ]\ }}]\)], "Input",
  CellLabel->"In[62]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0031746 0.0147151 0.14989 [
[.18254 .00222 -6 -9 ]
[.18254 .00222 6 0 ]
[.34127 .00222 -9 -9 ]
[.34127 .00222 9 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.65873 .00222 -9 -9 ]
[.65873 .00222 9 0 ]
[.81746 .00222 -9 -9 ]
[.81746 .00222 9 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .16461 -6 -4.5 ]
[.01131 .16461 0 4.5 ]
[.01131 .3145 -6 -4.5 ]
[.01131 .3145 0 4.5 ]
[.01131 .46439 -6 -4.5 ]
[.01131 .46439 0 4.5 ]
[.01131 .61428 -6 -4.5 ]
[.01131 .61428 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(50)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(100)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(150)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(200)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(250)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(300)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16461 m
.03006 .16461 L
s
[(1)] .01131 .16461 1 0 Mshowa
.02381 .3145 m
.03006 .3145 L
s
[(2)] .01131 .3145 1 0 Mshowa
.02381 .46439 m
.03006 .46439 L
s
[(3)] .01131 .46439 1 0 Mshowa
.02381 .61428 m
.03006 .61428 L
s
[(4)] .01131 .61428 1 0 Mshowa
.125 Mabswid
.02381 .04469 m
.02756 .04469 L
s
.02381 .07467 m
.02756 .07467 L
s
.02381 .10465 m
.02756 .10465 L
s
.02381 .13463 m
.02756 .13463 L
s
.02381 .19458 m
.02756 .19458 L
s
.02381 .22456 m
.02756 .22456 L
s
.02381 .25454 m
.02756 .25454 L
s
.02381 .28452 m
.02756 .28452 L
s
.02381 .34447 m
.02756 .34447 L
s
.02381 .37445 m
.02756 .37445 L
s
.02381 .40443 m
.02756 .40443 L
s
.02381 .43441 m
.02756 .43441 L
s
.02381 .49436 m
.02756 .49436 L
s
.02381 .52434 m
.02756 .52434 L
s
.02381 .55432 m
.02756 .55432 L
s
.02381 .5843 m
.02756 .5843 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .06457 L
.10458 .11572 L
.14415 .1598 L
.18221 .19901 L
.22272 .23765 L
.26171 .27208 L
.30316 .30596 L
.34309 .33615 L
.3815 .3631 L
.42237 .38967 L
.46172 .41337 L
.49955 .43454 L
.53984 .45545 L
.57861 .47412 L
.61984 .49251 L
.65954 .5089 L
.69774 .52354 L
.73838 .53799 L
.77751 .55088 L
.81909 .56356 L
.85916 .57486 L
.89771 .58494 L
.93871 .59489 L
.97619 .60332 L
s
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01473 L
.02846 .01474 L
.02954 .01475 L
.03053 .01477 L
.03279 .01482 L
.03506 .01489 L
.03756 .01498 L
.04262 .01522 L
.05285 .01588 L
.06244 .0167 L
.10458 .02168 L
.14335 .02721 L
.18458 .0333 L
.22428 .03901 L
.26248 .04424 L
.30312 .04946 L
.34225 .05415 L
.38383 .05878 L
.4239 .06291 L
.46245 .06661 L
.50346 .07025 L
.54294 .07349 L
.58091 .07639 L
.62134 .07926 L
.66025 .08182 L
.70161 .08433 L
.74145 .08658 L
.77978 .08858 L
.82057 .09056 L
.85983 .09232 L
.89758 .09389 L
.93779 .09545 L
.97619 .09683 L
s
.2 1 0 r
.02 w
.05556 .06583 Mdot
.0873 .1035 Mdot
.11905 .13935 Mdot
.15079 .16787 Mdot
.18254 .18653 Mdot
.21429 .22365 Mdot
.24603 .24111 Mdot
.27778 .29577 Mdot
.30952 .31795 Mdot
.34127 .32416 Mdot
.37302 .35201 Mdot
.40476 .40309 Mdot
.43651 .379 Mdot
.46825 .43756 Mdot
.5 .42754 Mdot
.53175 .44727 Mdot
.56349 .4736 Mdot
.59524 .48611 Mdot
.62698 .47466 Mdot
.65873 .52724 Mdot
.69048 .52044 Mdot
.72222 .51224 Mdot
.75397 .55655 Mdot
.78571 .53518 Mdot
.81746 .55131 Mdot
.84921 .56059 Mdot
.88095 .58785 Mdot
.9127 .61264 Mdot
.94444 .59147 Mdot
.97619 .61683 Mdot
1 0 0 r
.04286 .0217 Mdot
.0873 .02406 Mdot
.13175 .01717 Mdot
.17619 .0158 Mdot
.22063 .03804 Mdot
.26508 .05373 Mdot
.30952 .04248 Mdot
.35397 .08487 Mdot
.39841 .05584 Mdot
.44286 .10279 Mdot
.4873 .09639 Mdot
.53175 .08163 Mdot
.57619 .0782 Mdot
.62063 .08671 Mdot
.66508 .08176 Mdot
.70952 .07061 Mdot
.75397 .10479 Mdot
.79841 .07714 Mdot
.84286 .08885 Mdot
.8873 .06984 Mdot
.93175 .0975 Mdot
.97619 .06911 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[62]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00D@3oool4000000D0oooo1000000]0?ooo`L000000`3oool4000000D0oooo1000000Y0?oo
o`L000000`3oool4000000D0oooo1000000X0?ooo`H00000103oool4000000D0oooo1000000Y0?oo
o`H00000103oool4000000D0oooo1000000Z0?ooo`@000001@3oool4000000D0oooo1000000?0?oo
o`00D03oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00`0oooo
001E0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`0[0?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool0303oool005D0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
00P0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo02/0oooo00D000000?ooo`3oool0oooo000000040?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0<0?ooo`00E@3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
203oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0:@3oool2000000@0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool0303oool00540oooo100000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0103oool40000
00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`@00000103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo02/0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0<0?ooo`00D@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02/0oooo00D000000?oo
o`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`0<0?ooo`00D@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0:`3oool3000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool09`3oool3000000H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`0<0?ooo`00D@3oool5000000@0oooo1000000`0?oo
o`030000003oool0oooo00@0oooo100000050?ooo`@00000;03oool00`000000oooo0?ooo`040?oo
o`D00000103oool4000002T0oooo100000050?ooo`@000001@3oool4000002X0oooo100000050?oo
o`D00000103oool4000002X0oooo100000050?ooo`@000001@3oool4000000l0oooo003o0?oook40
oooo003o0?oook40oooo000H0?ooo`030000003oool0oooo0?l0ooooUP3oool001P0oooo00<00000
0?ooo`3oool0o`3ooonF0?ooo`00603oool00`000000oooo0?ooo`3o0?oooiH0oooo000H0?ooo`03
0000003oool0oooo03X0oooo0P3o003o0?oooeX0oooo000H0?ooo`030000003oool0oooo02P0oooo
0P3o000>0?ooo`H0o`00o`3ooomH0?ooo`00603oool00`000000oooo0?ooo`040?ooo`80o`00803o
ool60?l000`0oooo1P3o003o0?oooeP0oooo000?0?ooo`h000001P3o000>00000080o`003P000006
0?l000/00000203o003o000004P000003`3oool001P0oooo0P0000030?ooo`H0o`002P0000020?oo
o`H0o`002@3oool00`000000oooo0?l000070?l000<0oooo00<000000?ooo`3oool0103oool80?l0
00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool05`3oool001P0oooo00@000000?ooo`000000oooo203o00000`3o
ool000000?ooo`060?ooo`8000001P3o00090?ooo`030000003oool0o`0000L0o`000`3oool00`00
0000oooo0?ooo`050?ooo`H0o`00303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0G0?ooo`00603oool010000000
oooo0000003oool80?l000X0oooo203o0007000000@0oooo1P3o000<0?ooo`H0o`00?`3oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo01L0oooo000H0?ooo`050000003oool0oooo0000
003oool01P3o000;0?ooo`P0o`001`3oool4000000H0o`003P3oool20?l00?l0ooooFP3oool001P0
oooo00D000000?ooo`3oool0oooo000000060?l000`0oooo1P3o000>0?ooo`80o`001P00003o0?oo
ofH0oooo000H0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o0000o`003P3oool60?l0
01H0oooo1P00000F0?ooo`80o`00o`3ooom80?ooo`00603oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0100oooo0P3o000N0?ooo`H000003P3oool60?l00?l0ooooAP3oool001P0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0f0?ooo`H00000203oool60?l001l0oooo
0P3o003o0?ooobD0oooo000H0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>`3o
ool7000000P0o`00703oool60?l00?l0oooo8`3oool001P0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`110?ooo`P0o`0000<000000?ooo`3oool06@3oool60?l00?l0oooo8`3oool0
01P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`110?ooo`H0o`000P3oool80000
0180oooo203o003o0?ooob80oooo000H0?ooo`<000001`3oool00`000000oooo0?ooo`100?ooo`H0
o`002P3oool300000080o`000P00000;0?ooo`P0o`00o`3ooolR0?ooo`00603oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0480oooo0P3o000=0?ooo`H0o`00200000040?ooo`H0o`00
803oool20?l00?l0oooo0@3oool001P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`1@0?ooo`H0o`00203oool4000000H0o`007P3oool60?l00?h0oooo000H0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0CP3oool80?l000d0oooo0P3o0008000001P0oooo1P3o003n
0?ooo`00603oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04d0oooo203o000G0?oo
o`T000003P3oool80?l00?d0oooo000H0?ooo`030000003oool0oooo00T0oooo0P0co`000`000000
oooo0?ooo`1=0?ooo`H0o`008@3oool8000000H0oooo203o003m0?ooo`00603oool00`000000oooo
0?ooo`070?ooo`H0<ol0CP3oool60?l002T0oooo1`0000060?l00>@0oooo0P3o000H0?ooo`00603o
ool00`000000oooo0?ooo`070?ooo`H0<ol0D03oool20?l00380oooo1P3o000;000006h0oooo0P3o
00150?ooo`80o`00803oool60?l001H0oooo000H0?ooo`030000003oool0oooo00H0oooo200co`25
0?ooo`80o`003@3oool8000006@0oooo1P3o00110?ooo`H0o`007P3oool60?l001H0oooo000H0?oo
o`030000003oool0oooo00H0oooo200co`000`000000oooo0?ooo`2I0?ooo``00000F03oool60?l0
0440oooo1P3o000M0?ooo`P0o`005@3oool001P0oooo00<000000?ooo`3oool01`3oool603?o0080
oooo00<000000?ooo`3oool0Y03oool<000001P0oooo0P3o000a0?ooo`P0o`007`3oool20?l001h0
oooo203o000L0?ooo`P0o`005@3oool001P0oooo00<000000?ooo`3oool01`3oool603?o0080oooo
00<000000?ooo`3oool0/03oool700000080o`003@3oool60?l002l0oooo203o000M0?ooo`H0o`00
703oool80?l001d0oooo1P3o000F0?ooo`00603oool3000000T0oooo0P0co`050?ooo`030000003o
ool0oooo0;@0oooo1P3o0008000000<0oooo1P3o000P0?ooo`80o`003P3oool60?l001h0oooo1P3o
000M0?ooo`H0o`007P3oool60?l001H0oooo000H0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0K@3oool20?l004@0oooo1P3o00080?ooo`800000203o0006000001L0oooo1P3o000<
0?ooo`H0o`007@3oool80?l001`0oooo1P3o000P0?ooo`80o`00603oool001P0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`1Z0?ooo`H0o`00@@3oool80?l000T0oooo203o00060?oo
o`L000000P3o0007000000L0oooo1P3o000>0?ooo`80o`007`3oool80?l000`0oooo0P3o000@0?oo
o`80o`00?03oool001P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1Y0?ooo`H0
o`00@@3oool80?l000X0oooo1P3o000<0?ooo`H0o`001@3oool6000000P0o`000P00000]0?ooo`H0
o`002`3oool60?l004`0oooo000H0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
J03oool80?l00440oooo1P3o000;0?ooo`H0o`00303oool60?l000/0oooo203o00020?oooa000000
7@3oool60?l000/0oooo1P3o001<0?ooo`00603oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo06L0oooo203o000a0?ooo`80o`003P3oool60?l000d0oooo0P3o000=0?ooo`P0o`002`3o
ool60?l001<0oooo4000000?0?ooo`80o`00303oool80?l004/0oooo000H0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0I`3oool60?l00300oooo1P3o000>0?ooo`80o`007P3oool8
0?l000/0oooo1P3o000S0?oooa0000003@3oool80?l001l0oooo0P3o000Z0?ooo`00603oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo06H0oooo1P3o000`0?ooo`H0o`00;`3oool60?l0
00h0oooo0P3o000e0?ooo`h000001P3o000<00000180oooo1P3o000X0?ooo`00603oool00`000000
oooo0?ooo`0F0?ooo`80<ol0J@3oool20?l00280oooo0P3o000=0?ooo`P0o`00;P3oool60?l005<0
oooo1P3o000<0?ooo`l000000`3oool60?l002P0oooo000H0?ooo`030000003oool0oooo01@0oooo
1P0co`290?ooo`H0o`002`3oool80?l00300oooo0P3o000d0?ooo`80o`008@3oool20?l001d0oooo
0P0000080?l000h000006@3oool001P0oooo00<000000?ooo`3oool0503oool603?o08T0oooo1P3o
000<0?ooo`H0o`00I@3oool60?l00400oooo203o000W0?ooo`00603oool00`000000oooo0?ooo`0C
0?ooo`P0<ol0Q`3oool80?l000/0oooo1P3o001U0?ooo`H0o`00@@3oool60?l002P0oooo000H0?oo
o`<000004`3oool803?o08L0oooo203o000=0?ooo`80o`00IP3oool80?l00400oooo1P3o000X0?oo
o`00603oool00`000000oooo0?ooo`0D0?ooo`H0<ol000<0oooo0000003oool0QP3oool60?l007H0
oooo203o00120?ooo`80o`00:P3oool001P0oooo00<000000?ooo`3oool0503oool603?o0080oooo
00<000000?ooo`3oool0Q03oool60?l007L0oooo1P3o001_0?ooo`00603oool00`000000oooo0?oo
o`0F0?ooo`80<ol0103oool00`000000oooo0?ooo`260?ooo`80o`00N@3oool60?l006l0oooo000H
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0o`3oool30?ooo`80o`00L@3oool0
01P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?ooogD0oooo000H0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0o`3ooomd0?ooo`00603oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo0?l0ooooL`3oool001P0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`3o0?ooog80oooo000H0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0o`3oooma0?ooo`00603oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
0?l0ooooL@3oool001P0oooo00<000000?ooo`3oool08`3oool203?o0?l0ooooL@3oool001P0oooo
0`00000Q0?ooo`H0<ol0o`3ooom_0?ooo`00603oool00`000000oooo0?ooo`0Q0?ooo`H0<ol0o`3o
oom_0?ooo`00603oool00`000000oooo0?ooo`0P0?ooo`P0<ol0o`3ooom^0?ooo`00603oool00`00
0000oooo0?ooo`0P0?ooo`P0<ol0o`3ooom^0?ooo`00603oool00`000000oooo0?ooo`0Q0?ooo`H0
<ol000<0oooo0000003oool0o`3ooom/0?ooo`00603oool00`000000oooo0?ooo`0Q0?ooo`H0<ol0
0P3oool00`000000oooo0?ooo`3o0?ooofX0oooo000H0?ooo`030000003oool0oooo02<0oooo0P0c
o`040?ooo`030000003oool0oooo0?l0ooooJP3oool001P0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`3o0?ooofT0oooo000H0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0o`3ooomX0?ooo`002`3oool7000000H0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`3o0?ooofL0oooo000>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0203?o0?l0ooooI03oool000h0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0^0?ooo`H0<ol0o`3ooomR0?ooo`003P3oool00`000000oooo0?ooo`07
0?ooo`@00000;@3oool603?o0?l0ooooHP3oool000h0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0]0?ooo`P0<ol0o`3ooomQ0?ooo`003P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo02d0oooo200co`3o0?ooof40oooo000>0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0;P3oool603?o0?l0ooooHP3oool000`0oooo0`0000090?ooo`030000003o
ool0oooo02h0oooo1P0co`3o0?ooof80oooo000>0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0<03oool203?o0080oooo00<000000?ooo`3oool0o`3ooomO0?ooo`00603oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo00@0oooo0P0co`3o0?oooeP0oooo000H0?ooo`03
0000003oool0oooo03H0oooo00@000000?ooo`3oool0oooo1P0co`3o0?oooeH0oooo000H0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool01P0co`3o0?oooeH0oooo000H0?ooo`030000
003oool0oooo03P0oooo00<0000003?o000co`001P0co`3o0?oooeD0oooo000H0?ooo`030000003o
ool0oooo03T0oooo200co`3o0?oooeD0oooo000H0?ooo`030000003oool0oooo03X0oooo1P0co`3o
0?oooeH0oooo000H0?ooo`<00000>P3oool603?o0?l0ooooEP3oool001P0oooo00<000000?ooo`3o
ool0?03oool203?o0?l0ooooF03oool001P0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`3o0?oooeH0oooo000H0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0o`3o
oomE0?ooo`00603oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0?l0ooooE03oool0
01P0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`3o0?oooe<0oooo000H0?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0o`3ooomB0?ooo`00603oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo0?l0ooooD@3oool001P0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`030?ooo`80<ol0o`3ooom;0?ooo`00603oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo00H0<ol0o`3ooom90?ooo`00603oool00`000000oooo0?ooo`150?oo
o`030000003oool0<ol000D0<ol0o`3ooom90?ooo`00603oool00`000000oooo0?ooo`160?ooo`P0
<ol0o`3ooom80?ooo`00603oool3000004H0oooo200co`3o0?ooodP0oooo000H0?ooo`030000003o
ool0oooo04L0oooo1P0co`3o0?ooodT0oooo000H0?ooo`030000003oool0oooo04L0oooo1P0co`3o
0?ooodT0oooo000H0?ooo`030000003oool0oooo04T0oooo0P0co`0;0?ooo`80<ol0o`3oooln0?oo
o`00603oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00H0oooo1P0co`3o0?oooc`0
oooo000H0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool01@3oool603?o0?l0oooo
?03oool001P0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`030?ooo`P0<ol0o`3o
oolk0?ooo`00603oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0080oooo200co`3o
0?oooc/0oooo000H0?ooo`030000003oool0oooo04l0oooo0P0000030?ooo`H0<ol0o`3oooll0?oo
o`00603oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00H0<ol0o`3oooll0?ooo`00
603oool00`000000oooo0?ooo`1B0?ooo`040000003oool0oooo0?ooo`80<ol0o`3oooln0?ooo`00
603oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0?l0oooo@03oool001P0oooo0`00
001D0?ooo`030000003oool0oooo0?l0oooo?`3oool001P0oooo00<000000?ooo`3oool0E@3oool2
00000?l0oooo?`3oool001P0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3o0?oo
oc`0oooo000H0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`00
603oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0?l0oooo>P3oool001P0oooo00<0
00000?ooo`3oool0FP3oool200000?l0oooo>P3oool001P0oooo00<000000?ooo`3oool0G03oool0
0`000000oooo0?ooo`3o0?ooocL0oooo000H0?ooo`030000003oool0oooo05d0oooo00<000000?oo
o`3oool0o`3ooolf0?ooo`00603oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0?l0
oooo=@3oool001P0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`3o0?oooc@0oooo
000H0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0o`3ooolc0?ooo`00603oool0
0`000000oooo0?ooo`1Q0?ooo`800000o`3ooolc0?ooo`00603oool3000006<0oooo00<000000?oo
o`3oool0o`3oool`0?ooo`00603oool00`000000oooo0?ooo`1S0?ooo`80<ol0o`3ooola0?ooo`00
603oool00`000000oooo0?ooo`1Q0?ooo`H0<ol0o`3oool_0?ooo`00603oool00`000000oooo0?oo
o`1Q0?ooo`H0<ol0o`3oool_0?ooo`00603oool00`000000oooo0?ooo`1P0?ooo`P0<ol0o`3oool^
0?ooo`00603oool00`000000oooo0?ooo`1P0?ooo`P0<ol000<000000?ooo`3oool0o`3oool[0?oo
o`00603oool00`000000oooo0?ooo`1Q0?ooo`H0<ol00P3oool200000?l0oooo:`3oool001P0oooo
00<000000?ooo`3oool0H@3oool603?o00@0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`00603o
ool00`000000oooo0?ooo`1S0?ooo`80<ol01`3oool00`000000oooo0?ooo`3o0?ooobL0oooo000;
0?ooo`H000001`3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0?l0oooo9P3oool0
00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
06h0oooo00<0000003?o000co`00o`3ooolU0?ooo`00303oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo06d0oooo1P0co`3o0?ooob<0oooo000=0?ooo`030000003oool0oooo00P0oooo
1000001/0?ooo`H0<ol0o`3ooolS0?ooo`003P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo06`0oooo200co`080?ooo`80<ol0o`3ooolH0?ooo`003`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo06`0oooo200co`000`000000oooo0?ooo`030?ooo`H0<ol0o`3ooolF
0?ooo`002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0K@3oool603?o0080oooo00<000000?ooo`3oool00P3oool603?o0?l0oooo5P3oool000/0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06d0
oooo1P0co`030?ooo`030000003oool0oooo00P0<ol0o`3ooolE0?ooo`00303oool4000000P0oooo
00<000000?ooo`3oool0K`3oool203?o00H0oooo0P00000803?o0?l0oooo5@3oool001P0oooo00<0
00000?ooo`3oool0N@3oool00`000000<ol003?o000403?o0?l0oooo5P3oool001P0oooo00<00000
0?ooo`3oool0NP3oool603?o0?l0oooo5P3oool001P0oooo00<000000?ooo`3oool0N`3oool00`00
0000<ol003?o003o0?oooaP0oooo000H0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3o
ool0o`3ooolF0?ooo`00603oool00`000000oooo0?ooo`1n0?ooo`800000o`3ooolF0?ooo`00603o
ool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0?l0oooo4`3oool001P0oooo0`000021
0?ooo`8000001P3oool203?o0?l0oooo2`3oool001P0oooo00<000000?ooo`3oool0P`3oool01000
0000oooo0?ooo`3oool603?o0?l0oooo2@3oool001P0oooo00<000000?ooo`3oool0Q03oool00`00
0000oooo0?ooo`0603?o0?l0oooo2@3oool001P0oooo00<000000?ooo`3oool0Q@3oool00`000000
<ol003?o000603?o0?l0oooo203oool001P0oooo00<000000?ooo`3oool0QP3oool803?o0?l0oooo
203oool001P0oooo00<000000?ooo`3oool0Q`3oool603?o0?l0oooo2@3oool001P0oooo00<00000
0?ooo`3oool0Q`3oool603?o0?l0oooo2@3oool001P0oooo00<000000?ooo`3oool0R@3oool203?o
00800000o`3oool90?ooo`00603oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0?l0
oooo1P3oool001P0oooo00<000000?ooo`3oool0SP3oool200000?l0oooo1P3oool001P0oooo00<0
00000?ooo`3oool0T03oool00`000000oooo0?ooo`3o0?ooo`<0oooo000H0?ooo`030000003oool0
oooo0940oooo0P00000?0?ooo`80<ol0l@3oool001P0oooo00<000000?ooo`3oool0T`3oool00`00
0000oooo0?ooo`0:0?ooo`H0<ol0k`3oool001P0oooo0`00002D0?ooo`030000003oool0oooo00T0
oooo1P0co`3_0?ooo`00603oool00`000000oooo0?ooo`2E0?ooo`800000203oool803?o0>h0oooo
000H0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool01@3oool803?o0>h0oooo000H
0?ooo`030000003oool0oooo09P0oooo0P0000060?ooo`H0<ol0k`3oool001P0oooo00<000000?oo
o`3oool0VP3oool00`000000oooo0?ooo`030?ooo`H0<ol0k`3oool001P0oooo00<000000?ooo`3o
ool0V`3oool2000000D0oooo0P0co`3a0?ooo`00603oool00`000000oooo0?ooo`2M0?ooo`030000
003oool0oooo0?D0oooo000H0?ooo`030000003oool0oooo09H0oooo0P0co`060?ooo`800000m@3o
ool001P0oooo00<000000?ooo`3oool0U03oool603?o00H0oooo0P00003c0?ooo`00603oool00`00
0000oooo0?ooo`2D0?ooo`H0<ol0203oool200000?40oooo000H0?ooo`030000003oool0oooo09<0
oooo200co`090?ooo`030000003oool0oooo0>h0oooo000H0?ooo`030000003oool0oooo09<0oooo
200co`0:0?ooo`800000kP3oool001P0oooo0`00002D0?ooo`H0<ol03@3oool200000>`0oooo000H
0?ooo`030000003oool0oooo09@0oooo1P0co`0?0?ooo`800000jP3oool001P0oooo00<000000?oo
o`3oool0UP3oool203?o01<0oooo0P00003X0?ooo`00603oool00`000000oooo0?ooo`2]0?ooo`03
0000003oool0oooo0>D0oooo000H0?ooo`030000003oool0oooo0:h0oooo0P00003U0?ooo`00603o
ool00`000000oooo0?ooo`2`0?ooo`8000002P3oool203?o0=L0oooo000H0?ooo`030000003oool0
oooo0;80oooo00<000000?ooo`3oool01@3oool603?o0=D0oooo000H0?ooo`030000003oool0oooo
0;<0oooo0P0000050?ooo`H0<ol0e@3oool001P0oooo00<000000?ooo`3oool0]@3oool200000080
oooo200co`3D0?ooo`00603oool00`000000oooo0?ooo`2_0?ooo`80<ol01P3oool00`000000oooo
03?o000703?o0=@0oooo000H0?ooo`030000003oool0oooo0:d0oooo1P0co`050?ooo`8000001P0c
o`3E0?ooo`00603oool00`000000oooo0?ooo`2]0?ooo`H0<ol01`3oool603?o0=D0oooo000H0?oo
o`<00000[03oool803?o00P0oooo0P0co`3G0?ooo`00603oool00`000000oooo0?ooo`2/0?ooo`P0
<ol02@3oool2000000X0oooo0P0co`3:0?ooo`00603oool00`000000oooo0?ooo`2]0?ooo`H0<ol0
303oool2000000H0oooo1P0co`380?ooo`00603oool00`000000oooo0?ooo`2]0?ooo`H0<ol03P3o
ool2000000@0oooo1P0co`380?ooo`00603oool00`000000oooo0?ooo`2_0?ooo`80<ol04P3oool2
000000030?ooo`0co`00<ol000H0<ol0a`3oool001P0oooo00<000000?ooo`3oool0a@3oool00`00
0000<ol003?o000603?o0<L0oooo000H0?ooo`030000003oool0oooo0<L0oooo1P0co`380?ooo`00
603oool00`000000oooo0?ooo`370?ooo`H0<ol0b03oool000`0oooo100000080?ooo`030000003o
ool0oooo0<T0oooo0P0co`0300000<L0oooo000;0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`3>0?ooo`800000a@3oool00100oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`3@0?ooo`800000``3oool00100oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`3B0?ooo`800000`@3oool000h0oooo0P0000080?ooo`@00000
d`3oool00`000000<ol003?o000H0?ooo`80<ol0Y03oool00100oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`3C0?ooo`H0<ol0503oool603?o0:80oooo000@0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0d`3oool603?o008000004P3oool603?o0:80oooo000;0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3B0?oo
o`P0<ol000<0oooo0000000000003`3oool803?o0:40oooo000<0?ooo`@00000203oool00`000000
oooo0?ooo`3B0?ooo`P0<ol00`3oool2000000d0oooo200co`2Q0?ooo`00603oool00`000000oooo
0?ooo`3C0?ooo`H0<ol01P3oool2000000030?ooo`0co`00<ol000T0oooo1P0co`2R0?ooo`00603o
ool00`000000oooo0?ooo`3C0?ooo`H0<ol01`3oool603?o00L0oooo1P0co`2R0?ooo`00603oool0
0`000000oooo0?ooo`3E0?ooo`80<ol02@3oool603?o00T0oooo0P0co`2T0?ooo`00603oool00`00
0000oooo0?ooo`3O0?ooo`P0<ol0[P3oool001P0oooo00<000000?ooo`3oool0g`3oool803?o0080
0000[03oool001P0oooo00<000000?ooo`3oool0h03oool603?o00<0oooo0P00002Z0?ooo`00603o
ool00`000000oooo0?ooo`3P0?ooo`H0<ol01@3oool300000:L0oooo000H0?ooo`<00000hP3oool2
03?o00X0oooo0P00002U0?ooo`00603oool00`000000oooo0?ooo`3`0?ooo`<00000XP3oool001P0
oooo00<000000?ooo`3oool0l`3oool3000009l0oooo000H0?ooo`030000003oool0oooo0?H0oooo
0P00000M0?ooo`80<ol0OP3oool001P0oooo00<000000?ooo`3oool0n03oool3000001P0oooo1P0c
o`1l0?ooo`00603oool00`000000oooo0?ooo`3k0?ooo`<000005@3oool603?o07`0oooo000H0?oo
o`030000003oool0oooo0?h0oooo0P00000B0?ooo`P0<ol0N`3oool001P0oooo00<000000?ooo`3o
ool0o`3oool10?ooo`<000001@3oool203?o00P0oooo200co`1k0?ooo`00603oool00`000000oooo
0?ooo`3o0?ooo`@0oooo0`00000603?o00L0oooo1P0co`1l0?ooo`00603oool00`000000oooo0?oo
o`3k0?ooo`80<ol02@3oool603?o00L0oooo1P0co`1l0?ooo`00603oool00`000000oooo0?ooo`3i
0?ooo`H0<ol01P3oool803?o00P0oooo0P0co`1n0?ooo`00603oool00`000000oooo0?ooo`3i0?oo
o`H0<ol01P3oool803?o00030000003oool0oooo08D0oooo000H0?ooo`<00000n03oool803?o00H0
oooo1P0co`020?ooo`800000Q@3oool001P0oooo00<000000?ooo`3oool0n03oool803?o00H0oooo
1P0co`040?ooo`<000006`3oool203?o06D0oooo000H0?ooo`030000003oool0oooo0?T0oooo1P0c
o`090?ooo`80<ol02@3oool3000001H0oooo1P0co`1S0?ooo`00603oool00`000000oooo0?ooo`3i
0?ooo`H0<ol05`3oool2000001@0oooo1P0co`1S0?ooo`00603oool00`000000oooo0?ooo`3k0?oo
o`80<ol06`3oool300000100oooo200co`1R0?ooo`00603oool00`000000oooo0?ooo`3o0?oooa`0
oooo0`00000=0?ooo`P0<ol0HP3oool001P0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`<00000
2`3oool603?o06<0oooo000H0?ooo`030000003oool0oooo0?l0oooo8P3oool3000000P0oooo1P0c
o`090?ooo`80<ol0F03oool001P0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`@000001P3oool2
03?o00T0oooo1P0co`1F0?ooo`00603oool00`000000oooo0?ooo`3o0?ooob<0oooo0P0co`040?oo
o`<000003P3oool603?o05H0oooo000H0?ooo`030000003oool0oooo0?l0oooo8@3oool603?o00D0
oooo0`00000:0?ooo`P0<ol0E@3oool001P0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`H0<ol0
203oool3000000L0oooo200co`080?ooo`80<ol0B`3oool001P0oooo0`00003o0?ooob00oooo200c
o`0:0?ooo`<000001@3oool603?o00L0oooo1P0co`190?ooo`00603oool00`000000oooo0?ooo`3o
0?ooob00oooo200co`0=0?ooo`@0000000<0oooo03?o000co`00100co`070?ooo`H0<ol0B@3oool0
01P0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`H0<ol04P3oool300000080<ol0203oool803?o
04P0oooo000H0?ooo`030000003oool0oooo0?l0oooo8@3oool603?o01D0oooo0`0000070?ooo`P0
<ol0B03oool001P0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`80<ol06P3oool3000000D0oooo
1P0co`190?ooo`00603oool00`000000oooo0?ooo`3o0?oood80oooo0`0000020?ooo`H0<ol0B@3o
ool001P0oooo00<000000?ooo`3oool0o`3ooom50?ooo`@000000P0co`1;0?ooo`00603oool00`00
0000oooo0?ooo`3o0?ooodT0oooo0`00001:0?ooo`00603oool00`000000oooo0?ooo`3o0?oood`0
oooo0`0000170?ooo`00603oool00`000000oooo0?ooo`3o0?ooodl0oooo100000130?ooo`00603o
ool00`000000oooo0?ooo`3o0?oooe<0oooo0`00000203?o03h0oooo000H0?ooo`030000003oool0
oooo0?l0ooooE03oool603?o00030000003oool0oooo0180oooo0P0co`0U0?ooo`00603oool30000
0?l0ooooE03oool603?o00030?ooo`0000000000008000003P3oool603?o02<0oooo000H0?ooo`03
0000003oool0oooo0?l0ooooD`3oool803?o00@0oooo1000000:0?ooo`H0<ol08`3oool001P0oooo
00<000000?ooo`3oool0o`3ooomC0?ooo`P0<ol0203oool4000000D0oooo200co`0R0?ooo`00603o
ool00`000000oooo0?ooo`3o0?oooe@0oooo1P0co`0=0?ooo`@0000000<0oooo03?o000co`001P0c
o`0R0?ooo`00603oool00`000000oooo0?ooo`3o0?oooe@0oooo1P0co`0A0?ooo`8000001P0co`0S
0?ooo`00603oool00`000000oooo0?ooo`3o0?oooeH0oooo0P0co`0E0?ooo`H0<ol00P00000Q0?oo
o`00603oool00`000000oooo0?ooo`3o0?ooofl0oooo0P0co`040?ooo`D00000703oool001P0oooo
00<000000?ooo`3oool0o`3ooomj0?ooo`<000006@3oool000d0oooo100000070?ooo`030000003o
ool0oooo0?l0ooooHP3oool203?o0380oooo000?0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0o`3ooomP0?ooo`H0<ol05P3oool203?o01P0oooo000?0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`H0<ol0503oool603?o01H0oooo000;0?ooo`H0
00001`3oool00`000000oooo0?ooo`3o0?oooel0oooo200co`0C0?ooo`H0<ol05P3oool000`0oooo
00@000000?ooo`3oool00000203oool400000?l0ooooGP3oool803?o0180oooo200co`0E0?ooo`00
303oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0?l0ooooH03oool603?o01<0
oooo200co`0E0?ooo`003@3oool00`000000oooo0000003o0?oooj40oooo000=0?ooo`030000003o
ool000000?l0ooooX@3oool000h0oooo0P00003o0?oooj40oooo003o0?oook40oooo003o0?oook40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-19.3572, -0.307815, \
1.17741, 0.024937}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[62]="]
}, Open  ]],

Cell[BoxData[
    \(ClearAll[sample1, \ sample2, \ fittedparameters]\)], "Input",
  CellLabel->"In[63]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 7", "SubsectionIcon"],

Cell["\<\
Here is the same example considerating the experimental uncertainties\
\>", "Text"],

Cell["\<\
We simulate the experimental measured in compartment 2 and 3 for different \
times  A random noise it is included\
\>", "MathCaption"],

Cell[BoxData[
    \(SeedRandom[101]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(sample1 = 
      Table[{t1, x2[t1] + Random[NormalDistribution[0, \ 0.1]], 
          Abs[Random[NormalDistribution[0, \ 0.1]\ ]]}, {t1, \ 8, \ 300, \ 
          15}]; \)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \(sample2 = 
      Table[{t1, \ x3[t1] + Random[NormalDistribution[0, \ 0.02]], \ 
          Abs[Random[NormalDistribution[0, \ 0.02]]]}, {t1, \ 10, \ 300, \ 
          20}]; \)], "Input",
  CellLabel->"In[66]:="],

Cell[TextData[{
  "Now, it is obtained the best fit for ",
  Cell[BoxData[
      \(TraditionalForm\`k\_12\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\_23\)]],
  "  "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fittedparameters\  = \ \ FindMinimum[
        X2FitE[{k12, \ k23}, sample1, X2[t1, k12, k23], \ \ sample2, 
          X3[t1, k12, k23], \ t1], {k12, 0.5, 1\ }\ , {k23, 0.02, 
          0.3}]\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \({309.7057679087539`, {k12 \[Rule] 0.8653279650543468`, 
        k23 \[Rule] 0.008816524288647223`}}\)], "Output",
  CellLabel->"Out[67]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[\(NMinimize[{X2FitE[{k12, \ k23}, sample1, 
              X2[t1, k12, k23], \ \ sample2, X3[t1, k12, k23], \ t1], \ 
            0 < k12 \[LessEqual] 1}, {k12, k23}]\),
        "Input"], " "}]], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \({309.7057679114845`, {k12 \[Rule] 0.8653279495255506`, 
        k23 \[Rule] 0.008816524014498454`}}\)], "Output",
  CellLabel->"Out[68]="]
}, Open  ]],

Cell[TextData[{
  " ",
  StyleBox["NMinimize", "Input"],
  " should be used when they there are some restrictions in the parameters, \
ex: ",
  StyleBox["NMinimize[{X2FitE[{k12, k23},sample1,X2[t1,k12,k23],  \
sample2,X3[t1,k12,k23], t1], 0<k12\[LessEqual]1},{k12,k23}]", "Input"],
  " , but it will take a long time."
}], "Text"],

Cell[BoxData[
    \(ClearAll[iodine, \ x1, \ x2, x3, \ tt, \ X1, X2\ , sample1, sample2, \ 
      fittedparameters]\)], "Input",
  CellLabel->"In[69]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 8", "SubsectionIcon"],

Cell[TextData[{
  "Here it is supposed an  input (unkown), ",
  StyleBox["inp",
    FontSlant->"Italic"],
  ",   in the compartment 1 in ",
  Cell[BoxData[
      \(TraditionalForm\`t = \ 0\)]],
  " in the the iodine model. Experimental measured for different times are \
taken in compartment 2 and 3. "
}], "Text"],

Cell[BoxData[
    \(\(\(\ \)\({\ x2[inp_, t1_], \ 
        x3[inp_, t1_]} = \ \n\ {\ x\_2[t1], \ x\_3[t1]} /. 
        SystemDSolve[
          CompartMatrix[
            3, {{1, 2, \ 0.8316}, {1, 0, 1.9404}, {2, 3, 0.0086625}\ , {3, 0, 
                0.01155}\ , {3, 1, 0.0462}}], {inp, \ 0, \ 0}, {0, \ 0, \ 0}, 
          t, t1, \ x]; \)\)\)], "Input",
  CellLabel->"In[70]:="],

Cell["\<\
We simulate the experimental measured for different times in compartment 2 \
and 3 including their uncertainties. \
\>", "MathCaption"],

Cell[BoxData[
    \(SeedRandom[104]\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \(sample2\  = 
      Map[{#, x2[13500, #] + Random[NormalDistribution[0, \ 100]], 
            Random[Integer, {50, 100}]} &, {2, 7, 18, 50, 90, 120, 180, 300, 
          360, 420, 600}]; \)], "Input",
  CellLabel->"In[72]:="],

Cell[BoxData[
    \(sample3\  = 
      Map[{#, x3[13500, #] + Random[NormalDistribution[0, \ 100]], 
            Random[Integer, {50, 100}]\ } &, {3, 27, 48, \ 72, 180, \ 360, 
          450, 520}]; \)], "Input",
  CellLabel->"In[73]:="],

Cell["Finally we obtein the input fitting the data", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MLFit[sample2, x2[1, t], sample3, x3[1, t], t]\)], "Input",
  CellLabel->"In[74]:="],

Cell[BoxData[
    \({"Mean" \[Rule] 13421.030012300242`, 
      "s" \[Rule] 124.66508787074288`}\)], "Output",
  CellLabel->"Out[74]="]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{913, 653},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PageFooters->{{Inherited, Cell[ 
        TextData[ {
          "\[Copyright]2003 Guillermo Sanchez. All rights reserved."}], 
        "PageFooter"], Inherited}, {Inherited, Cell[ 
        TextData[ {
          "\[Copyright]2003 Guillermo Sanchez. All rights reserved."}], 
        "PageFooter"], Inherited}},
ShowSelection->True,
Magnification->1.5,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "S3.8.2"->{
    Cell[11588, 401, 1230, 34, 93, "DefinitionBox",
      CellTags->"S3.8.2"],
    Cell[12821, 437, 1415, 39, 93, "DefinitionBox",
      CellTags->"S3.8.2"]},
  "eq 2"->{
    Cell[105244, 2636, 492, 11, 164, "NumberedEquation",
      CellTags->"eq 2"]},
  "FindFit"->{
    Cell[139670, 3335, 178, 5, 40, "Input",
      CellTags->"FindFit"],
    Cell[139851, 3342, 156, 4, 40, "Output",
      CellTags->"FindFit"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"S3.8.2", 264894, 6506},
  {"eq 2", 265065, 6511},
  {"FindFit", 265163, 6514}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 32, 0, 136, "Chapter"],
Cell[1811, 55, 358, 11, 34, "Text"],
Cell[2172, 68, 62, 0, 47, "Commentary"],

Cell[CellGroupData[{
Cell[2259, 72, 65, 2, 40, "Input"],
Cell[2327, 76, 104, 2, 38, "Output"]
}, Open  ]],
Cell[2446, 81, 509, 14, 60, "Text"],

Cell[CellGroupData[{
Cell[2980, 99, 43, 0, 35, "SubsubsectionIcon"],
Cell[3026, 101, 42, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[3093, 105, 87, 2, 70, "Input"],
Cell[3183, 109, 118, 2, 70, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3338, 116, 87, 2, 70, "Input"],
Cell[3428, 120, 117, 2, 70, "Print"]
}, Open  ]],
Cell[3560, 125, 132, 5, 70, "Text"],
Cell[3695, 132, 94, 2, 70, "Input"],
Cell[3792, 136, 105, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3934, 143, 52, 0, 49, "Subsection"],
Cell[3989, 145, 524, 13, 105, "Text"],

Cell[CellGroupData[{
Cell[4538, 162, 86, 2, 40, "Input"],
Cell[4627, 166, 2105, 55, 103, "Print"]
}, Open  ]],
Cell[6747, 224, 1998, 68, 108, "DefinitionBox"],
Cell[8748, 294, 1858, 66, 86, "DefinitionBox"],
Cell[10609, 362, 976, 37, 82, "DefinitionBox"],
Cell[11588, 401, 1230, 34, 93, "DefinitionBox",
  CellTags->"S3.8.2"],
Cell[12821, 437, 1415, 39, 93, "DefinitionBox",
  CellTags->"S3.8.2"],
Cell[14239, 478, 732, 28, 80, "Text"],
Cell[14974, 508, 576, 21, 58, "Text"],
Cell[15553, 531, 653, 25, 87, "Text"],
Cell[16209, 558, 419, 12, 111, "Text"],
Cell[16631, 572, 434, 11, 108, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[17102, 588, 35, 0, 39, "SubsectionIcon"],
Cell[17140, 590, 739, 24, 78, "Text"],
Cell[17882, 616, 25515, 660, 297, 10577, 471, "GraphicsData", "PostScript", \
"Graphics"],
Cell[43400, 1278, 361, 9, 78, "Text"],
Cell[43764, 1289, 221, 4, 92, "Input"],
Cell[43988, 1295, 284, 9, 56, "Text"],
Cell[44275, 1306, 124, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[44424, 1313, 142, 3, 66, "Input"],
Cell[44569, 1318, 100, 2, 38, "Output"]
}, Open  ]],
Cell[44684, 1323, 826, 20, 56, "Text"],
Cell[45513, 1345, 141, 3, 66, "Input"],
Cell[45657, 1350, 419, 13, 61, "Text"],
Cell[46079, 1365, 219, 8, 34, "Text"],
Cell[46301, 1375, 95, 2, 40, "Input"],

Cell[CellGroupData[{
Cell[46421, 1381, 140, 3, 66, "Input"],
Cell[46564, 1386, 3465, 74, 440, "Output"]
}, Open  ]],
Cell[50044, 1463, 85, 2, 34, "Text"],

Cell[CellGroupData[{
Cell[50154, 1469, 186, 4, 66, "Input"],
Cell[50343, 1475, 26400, 530, 276, 3546, 243, "GraphicsData", "PostScript", \
"Graphics"],
Cell[76746, 2007, 155, 4, 38, "Output"]
}, Open  ]],
Cell[76916, 2014, 91, 2, 40, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[77044, 2021, 35, 0, 39, "SubsectionIcon"],
Cell[77082, 2023, 578, 17, 108, "Text"],
Cell[77663, 2042, 150, 3, 66, "Input"],
Cell[77816, 2047, 274, 5, 92, "Input"],

Cell[CellGroupData[{
Cell[78115, 2056, 131, 3, 40, "Input"],
Cell[78249, 2061, 127, 3, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[78413, 2069, 209, 5, 66, "Input"],
Cell[78625, 2076, 26008, 531, 276, 3517, 248, "GraphicsData", "PostScript", \
"Graphics"],
Cell[104636, 2609, 155, 4, 38, "Output"]
}, Open  ]],
Cell[104806, 2616, 89, 2, 40, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[104932, 2623, 35, 0, 39, "SubsectionIcon"],
Cell[104970, 2625, 271, 9, 56, "Text"],
Cell[105244, 2636, 492, 11, 164, "NumberedEquation",
  CellTags->"eq 2"],
Cell[105739, 2649, 657, 20, 100, "Text"],
Cell[106399, 2671, 901, 13, 326, "Input"],

Cell[CellGroupData[{
Cell[107325, 2688, 142, 3, 40, "Input"],
Cell[107470, 2693, 31887, 626, 276, 3846, 275, "GraphicsData", "PostScript", \
"Graphics"],
Cell[139360, 3321, 155, 4, 38, "Output"]
}, Open  ]],
Cell[139530, 3328, 115, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[139670, 3335, 178, 5, 40, "Input",
  CellTags->"FindFit"],
Cell[139851, 3342, 156, 4, 40, "Output",
  CellTags->"FindFit"]
}, Open  ]],
Cell[140022, 3349, 85, 2, 34, "Text"],

Cell[CellGroupData[{
Cell[140132, 3355, 172, 4, 66, "Input"],
Cell[140307, 3361, 30239, 783, 276, 6468, 484, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[170561, 4147, 497, 20, 56, "Text"],
Cell[171061, 4169, 717, 11, 248, "Input"],
Cell[171781, 4182, 163, 5, 34, "Text"],
Cell[171947, 4189, 92, 2, 40, "Input"],
Cell[172042, 4193, 113, 3, 34, "Text"],
Cell[172158, 4198, 338, 7, 176, "Input"],
Cell[172499, 4207, 144, 5, 34, "Text"],
Cell[172646, 4214, 100, 2, 65, "Input"],
Cell[172749, 4218, 202, 8, 36, "Text"],
Cell[172954, 4228, 163, 4, 40, "Input"],
Cell[173120, 4234, 112, 2, 40, "Input"],
Cell[173235, 4238, 289, 11, 34, "Text"],

Cell[CellGroupData[{
Cell[173549, 4253, 37, 0, 35, "SubsubsectionIcon"],
Cell[173589, 4255, 538, 20, 70, "Text"],
Cell[174130, 4277, 165, 4, 70, "Input"],
Cell[174298, 4283, 340, 12, 70, "Text"],
Cell[174641, 4297, 176, 4, 70, "Input"],

Cell[CellGroupData[{
Cell[174842, 4305, 168, 3, 70, "Input"],
Cell[175013, 4310, 134, 3, 70, "Output"]
}, Open  ]],
Cell[175162, 4316, 117, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[175304, 4324, 257, 5, 70, "Input"],
Cell[175564, 4331, 30104, 655, 70, 4959, 339, "GraphicsData", "PostScript", \
"Graphics"],
Cell[205671, 4988, 155, 4, 70, "Output"]
}, Open  ]],
Cell[205841, 4995, 102, 3, 70, "Text"],
Cell[205946, 5000, 86, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[206069, 5007, 37, 0, 27, "SubsubsectionIcon"],
Cell[206109, 5009, 393, 12, 70, "Text"],
Cell[206505, 5023, 449, 9, 70, "Input"],
Cell[206957, 5034, 159, 4, 70, "SmallText"],
Cell[207119, 5040, 87, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[207231, 5048, 129, 3, 70, "Input"],
Cell[207363, 5053, 157, 3, 70, "Output"]
}, Open  ]],
Cell[207535, 5059, 149, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[207709, 5067, 73, 2, 70, "Input"],
Cell[207785, 5071, 397, 7, 70, "Message"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[208231, 5084, 37, 0, 27, "SubsubsectionIcon"],
Cell[208271, 5086, 104, 4, 39, "Text"],
Cell[208378, 5092, 309, 7, 92, "Input"],

Cell[CellGroupData[{
Cell[208712, 5103, 179, 4, 66, "Input"],
Cell[208894, 5109, 157, 3, 38, "Output"]
}, Open  ]],
Cell[209066, 5115, 84, 3, 39, "Text"],

Cell[CellGroupData[{
Cell[209175, 5122, 167, 4, 66, "Input"],
Cell[209345, 5128, 134, 3, 70, "Output"]
}, Open  ]],
Cell[209494, 5134, 101, 2, 40, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[209644, 5142, 35, 0, 39, "SubsectionIcon"],
Cell[209682, 5144, 326, 14, 36, "Text"],
Cell[210011, 5160, 298, 6, 92, "Input"],
Cell[210312, 5168, 330, 7, 118, "Input"],

Cell[CellGroupData[{
Cell[210667, 5179, 228, 5, 70, "Input"],
Cell[210898, 5186, 272, 5, 70, "Output"]
}, Open  ]],
Cell[211185, 5194, 140, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[211362, 5202, 35, 0, 39, "SubsectionIcon"],
Cell[211400, 5204, 1032, 18, 166, "Text"],
Cell[212435, 5224, 92, 2, 40, "Input"],

Cell[CellGroupData[{
Cell[212552, 5230, 91, 2, 70, "Input"],
Cell[212646, 5234, 4072, 102, 70, "Print"]
}, Open  ]],
Cell[216733, 5339, 414, 10, 70, "Text"],
Cell[217150, 5351, 273, 9, 70, "Text"],
Cell[217426, 5362, 246, 4, 70, "Input"],
Cell[217675, 5368, 70, 0, 70, "Text"],
Cell[217748, 5370, 330, 7, 70, "Input"],
Cell[218081, 5379, 188, 4, 70, "Text"],
Cell[218272, 5385, 61, 0, 70, "Text"],
Cell[218336, 5387, 377, 8, 70, "Input"],
Cell[218716, 5397, 346, 7, 70, "Text"],
Cell[219065, 5406, 295, 5, 70, "Input"],
Cell[219363, 5413, 145, 3, 70, "Input"],
Cell[219511, 5418, 145, 3, 70, "Input"],

Cell[CellGroupData[{
Cell[219681, 5425, 329, 7, 70, "Input"],
Cell[220013, 5434, 2872, 57, 70, "Output"]
}, Open  ]],
Cell[222900, 5494, 76, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[223001, 5498, 39, 0, 70, "SubsubsectionIcon"],
Cell[223043, 5500, 143, 3, 70, "Text"],
Cell[223189, 5505, 586, 16, 70, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[223824, 5527, 35, 0, 39, "SubsectionIcon"],
Cell[223862, 5529, 90, 2, 70, "Input"],
Cell[223955, 5533, 116, 3, 70, "Text"],
Cell[224074, 5538, 84, 1, 70, "MathCaption"],
Cell[224161, 5541, 337, 8, 70, "Input"],
Cell[224501, 5551, 149, 3, 70, "MathCaption"],
Cell[224653, 5556, 160, 4, 70, "Input"],
Cell[224816, 5562, 173, 4, 70, "Input"],
Cell[224992, 5568, 165, 3, 70, "MathCaption"],
Cell[225160, 5573, 377, 8, 70, "Input"],
Cell[225540, 5583, 167, 4, 70, "Input"],
Cell[225710, 5589, 167, 4, 70, "Input"],

Cell[CellGroupData[{
Cell[225902, 5597, 247, 5, 70, "Input"],
Cell[226152, 5604, 159, 3, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[226348, 5612, 344, 7, 70, "Input"],
Cell[226695, 5621, 32567, 692, 70, 5155, 348, "GraphicsData", "PostScript", \
"Graphics"],
Cell[259265, 6315, 155, 4, 70, "Output"]
}, Open  ]],
Cell[259435, 6322, 106, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[259578, 6329, 35, 0, 39, "SubsectionIcon"],
Cell[259616, 6331, 93, 2, 34, "Text"],
Cell[259712, 6335, 144, 3, 80, "MathCaption"],
Cell[259859, 6340, 73, 2, 40, "Input"],
Cell[259935, 6344, 226, 5, 66, "Input"],
Cell[260164, 6351, 231, 5, 66, "Input"],
Cell[260398, 6358, 199, 8, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[260622, 6370, 248, 5, 92, "Input"],
Cell[260873, 6377, 158, 3, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[261068, 6385, 270, 6, 66, "Input"],
Cell[261341, 6393, 158, 3, 38, "Output"]
}, Open  ]],
Cell[261514, 6399, 330, 8, 93, "Text"],
Cell[261847, 6409, 153, 3, 66, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[262037, 6417, 35, 0, 39, "SubsectionIcon"],
Cell[262075, 6419, 314, 9, 56, "Text"],
Cell[262392, 6430, 381, 8, 144, "Input"],
Cell[262776, 6440, 145, 3, 80, "MathCaption"],
Cell[262924, 6445, 73, 2, 40, "Input"],
Cell[263000, 6449, 244, 5, 92, "Input"],
Cell[263247, 6456, 237, 5, 66, "Input"],
Cell[263487, 6463, 60, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[263572, 6467, 104, 2, 40, "Input"],
Cell[263679, 6471, 135, 3, 38, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

